Index: libgomp/iter.c
===================================================================
--- libgomp/iter.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgomp/iter.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -218,7 +218,7 @@
 	}
     }
 
-  start = ws->next;
+  start = __atomic_load_n (&ws->next, MEMMODEL_RELAXED);
   while (1)
     {
       long left = end - start;
@@ -301,7 +301,7 @@
   long start, end, nend, incr;
   unsigned long chunk_size;
 
-  start = ws->next;
+  start = __atomic_load_n (&ws->next, MEMMODEL_RELAXED);
   end = ws->end;
   incr = ws->incr;
   chunk_size = ws->chunk_size;
Index: libgomp/iter_ull.c
===================================================================
--- libgomp/iter_ull.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgomp/iter_ull.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -219,7 +219,7 @@
 	}
     }
 
-  start = ws->next_ull;
+  start = __atomic_load_n (&ws->next_ull, MEMMODEL_RELAXED);
   while (1)
     {
       gomp_ull left = end - start;
@@ -305,7 +305,7 @@
   gomp_ull start, end, nend, incr;
   gomp_ull chunk_size;
 
-  start = ws->next_ull;
+  start = __atomic_load_n (&ws->next_ull, MEMMODEL_RELAXED);
   end = ws->end_ull;
   incr = ws->incr_ull;
   chunk_size = ws->chunk_size_ull;
Index: libgomp/ChangeLog
===================================================================
--- libgomp/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgomp/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,13 @@
+2015-08-24  Joost VandeVondele  <vondele@gnu.gcc.org>
+
+	PR libgomp/66761
+	PR libgomp/67303
+	* iter.c (gomp_iter_dynamic_next): Employ an atomic load.
+	(gomp_iter_guided_next): Idem.
+	* iter_ull.c (gomp_iter_ull_dynamic_next): Idem.
+	(gomp_iter_ull_guided_next): Idem.
+	* config/linux/wait.h (do_spin): Idem.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: libgomp/config/linux/wait.h
===================================================================
--- libgomp/config/linux/wait.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgomp/config/linux/wait.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -49,7 +49,9 @@
 {
   unsigned long long i, count = gomp_spin_count_var;
 
-  if (__builtin_expect (gomp_managed_threads > gomp_available_cpus, 0))
+  if (__builtin_expect (__atomic_load_n (&gomp_managed_threads,
+                                         MEMMODEL_RELAXED)
+                        > gomp_available_cpus, 0))
     count = gomp_throttled_spin_count_var;
   for (i = 0; i < count; i++)
     if (__builtin_expect (__atomic_load_n (addr, MEMMODEL_RELAXED) != val, 0))
Index: libsanitizer/ChangeLog
===================================================================
--- libsanitizer/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libsanitizer/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,8 @@
+2015-09-09  Markus Trippelsdorf  <markus@trippelsdorf.de>
+
+	PR sanitizer/67258
+	* ubsan/ubsan_type_hash.cc: Cherry pick upstream r244101.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: libsanitizer/ubsan/ubsan_type_hash.cc
===================================================================
--- libsanitizer/ubsan/ubsan_type_hash.cc	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libsanitizer/ubsan/ubsan_type_hash.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -186,8 +186,8 @@
 
 struct VtablePrefix {
   /// The offset from the vptr to the start of the most-derived object.
-  /// This should never be greater than zero, and will usually be exactly
-  /// zero.
+  /// This will only be greater than zero in some virtual base class vtables
+  /// used during object con-/destruction, and will usually be exactly zero.
   sptr Offset;
   /// The type_info object describing the most-derived class type.
   std::type_info *TypeInfo;
@@ -197,7 +197,7 @@
   if (!*VptrPtr)
     return 0;
   VtablePrefix *Prefix = *VptrPtr - 1;
-  if (Prefix->Offset > 0 || !Prefix->TypeInfo)
+  if (!Prefix->TypeInfo)
     // This can't possibly be a valid vtable.
     return 0;
   return Prefix;
Index: libstdc++-v3/configure
===================================================================
--- libstdc++-v3/configure	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/configure	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -638,6 +638,8 @@
 DOXYGEN
 BUILD_INFO_FALSE
 BUILD_INFO_TRUE
+ENABLE_FILESYSTEM_TS_FALSE
+ENABLE_FILESYSTEM_TS_TRUE
 baseline_subdir_switch
 baseline_dir
 HWCAP_FLAGS
@@ -890,6 +892,7 @@
 enable_libstdcxx_dual_abi
 with_default_libstdcxx_abi
 enable_libstdcxx_threads
+enable_libstdcxx_filesystem_ts
 with_gxx_include_dir
 enable_version_specific_runtime_libs
 '
@@ -1588,6 +1591,8 @@
                           support two versions of std::string [default=yes]
   --enable-libstdcxx-threads
                           enable C++11 threads support [default=auto]
+  --enable-libstdcxx-filesystem-ts
+                          turns on ISO/IEC TS 18822 support [default=auto]
   --enable-version-specific-runtime-libs
                           Specify that runtime libraries should be installed
                           in a compiler-specific directory
@@ -3604,11 +3609,12 @@
 
 # We need awk for the "check" target.  The system "awk" is bad on
 # some platforms.
-# Always define AMTAR for backward compatibility.
+# Always define AMTAR for backward compatibility.  Yes, it's still used
+# in the wild :-(  We should find a proper way to deprecate it ...
+AMTAR='$${TAR-tar}'
 
-AMTAR=${AMTAR-"${am_missing_run}tar"}
+am__tar='$${TAR-tar} chof - "$$tardir"' am__untar='$${TAR-tar} xf -'
 
-am__tar='${AMTAR} chof - "$$tardir"'; am__untar='${AMTAR} xf -'
 
 
 
@@ -3616,7 +3622,6 @@
 
 
 
-
 # -fno-builtin must be present here so that a non-conflicting form of
 # std::exit can be guessed by AC_PROG_CXX, and used in later tests.
 
@@ -4951,7 +4956,7 @@
   # expandable list at autoconf time; the second provides an expandable list
   # (i.e., shell variable) at configure time.
 
-  SUBDIRS='include libsupc++ python src src/c++98 src/c++11 doc po testsuite'
+  SUBDIRS='include libsupc++ src src/c++98 src/c++11 src/filesystem doc po testsuite python'
 
   # These need to be absolute paths, yet at the same time need to
   # canonicalize only relative paths, because then amd will not unmount
@@ -11593,7 +11598,7 @@
   lt_dlunknown=0; lt_dlno_uscore=1; lt_dlneed_uscore=2
   lt_status=$lt_dlunknown
   cat > conftest.$ac_ext <<_LT_EOF
-#line 11596 "configure"
+#line 11601 "configure"
 #include "confdefs.h"
 
 #if HAVE_DLFCN_H
@@ -11699,7 +11704,7 @@
   lt_dlunknown=0; lt_dlno_uscore=1; lt_dlneed_uscore=2
   lt_status=$lt_dlunknown
   cat > conftest.$ac_ext <<_LT_EOF
-#line 11702 "configure"
+#line 11707 "configure"
 #include "confdefs.h"
 
 #if HAVE_DLFCN_H
@@ -15119,7 +15124,7 @@
     #
     # Fake what AC_TRY_COMPILE does.  XXX Look at redoing this new-style.
     cat > conftest.$ac_ext << EOF
-#line 15122 "configure"
+#line 15127 "configure"
 struct S { ~S(); };
 void bar();
 void foo()
@@ -15471,7 +15476,7 @@
   # Fake what AC_TRY_COMPILE does.
 
     cat > conftest.$ac_ext << EOF
-#line 15474 "configure"
+#line 15479 "configure"
 int main()
 {
   typedef bool atomic_type;
@@ -15506,7 +15511,7 @@
     rm -f conftest*
 
     cat > conftest.$ac_ext << EOF
-#line 15509 "configure"
+#line 15514 "configure"
 int main()
 {
   typedef short atomic_type;
@@ -15541,7 +15546,7 @@
     rm -f conftest*
 
     cat > conftest.$ac_ext << EOF
-#line 15544 "configure"
+#line 15549 "configure"
 int main()
 {
   // NB: _Atomic_word not necessarily int.
@@ -15577,7 +15582,7 @@
     rm -f conftest*
 
     cat > conftest.$ac_ext << EOF
-#line 15580 "configure"
+#line 15585 "configure"
 int main()
 {
   typedef long long atomic_type;
@@ -15656,7 +15661,7 @@
   # unnecessary for this test.
 
     cat > conftest.$ac_ext << EOF
-#line 15659 "configure"
+#line 15664 "configure"
 int main()
 {
   _Decimal32 d1;
@@ -15698,7 +15703,7 @@
   # unnecessary for this test.
 
     cat > conftest.$ac_ext << EOF
-#line 15701 "configure"
+#line 15706 "configure"
 template<typename T1, typename T2>
   struct same
   { typedef T2 type; };
@@ -15732,7 +15737,7 @@
     rm -f conftest*
 
     cat > conftest.$ac_ext << EOF
-#line 15735 "configure"
+#line 15740 "configure"
 template<typename T1, typename T2>
   struct same
   { typedef T2 type; };
@@ -78867,6 +78872,508 @@
 
 
 
+# For Filesystem TS.
+for ac_header in fcntl.h dirent.h sys/statvfs.h utime.h
+do :
+  as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
+ac_fn_c_check_header_mongrel "$LINENO" "$ac_header" "$as_ac_Header" "$ac_includes_default"
+eval as_val=\$$as_ac_Header
+   if test "x$as_val" = x""yes; then :
+  cat >>confdefs.h <<_ACEOF
+#define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
+_ACEOF
+
+fi
+
+done
+
+
+   # Check whether --enable-libstdcxx-filesystem-ts was given.
+if test "${enable_libstdcxx_filesystem_ts+set}" = set; then :
+  enableval=$enable_libstdcxx_filesystem_ts;
+      case "$enableval" in
+       yes|no|auto) ;;
+       *) as_fn_error "Unknown argument to enable/disable libstdcxx-filesystem-ts" "$LINENO" 5 ;;
+	  	        esac
+
+else
+  enable_libstdcxx_filesystem_ts=auto
+fi
+
+
+
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether to build Filesystem TS support" >&5
+$as_echo_n "checking whether to build Filesystem TS support... " >&6; }
+  if test x"$ac_cv_header_dirent_h" != x"yes"; then
+    enable_libstdcxx_filesystem_ts=no
+  fi
+  if test x"$enable_libstdcxx_filesystem_ts" = x"auto"; then
+    case "${target_os}" in
+      freebsd*|netbsd*|openbsd*|dragonfly*|darwin*)
+        enable_libstdcxx_filesystem_ts=yes
+        ;;
+      gnu* | linux* | kfreebsd*-gnu | knetbsd*-gnu)
+        enable_libstdcxx_filesystem_ts=yes
+        ;;
+      solaris*)
+        enable_libstdcxx_filesystem_ts=yes
+        ;;
+      *)
+        enable_libstdcxx_filesystem_ts=no
+        ;;
+    esac
+  fi
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $enable_libstdcxx_filesystem_ts" >&5
+$as_echo "$enable_libstdcxx_filesystem_ts" >&6; }
+
+
+
+  ac_ext=cpp
+ac_cpp='$CXXCPP $CPPFLAGS'
+ac_compile='$CXX -c $CXXFLAGS $CPPFLAGS conftest.$ac_ext >&5'
+ac_link='$CXX -o conftest$ac_exeext $CXXFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_cxx_compiler_gnu
+
+  ac_save_CXXFLAGS="$CXXFLAGS"
+  CXXFLAGS="$CXXFLAGS -fno-exceptions"
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for struct dirent.d_type" >&5
+$as_echo_n "checking for struct dirent.d_type... " >&6; }
+  if test "${glibcxx_cv_dirent_d_type+set}" = set; then :
+  $as_echo_n "(cached) " >&6
+else
+      if test x$gcc_no_link = xyes; then
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <dirent.h>
+int
+main ()
+{
+
+       struct dirent d;
+       if (sizeof d.d_type) return 0;
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_compile "$LINENO"; then :
+  glibcxx_cv_dirent_d_type=yes
+else
+  glibcxx_cv_dirent_d_type=no
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+else
+  if test x$gcc_no_link = xyes; then
+  as_fn_error "Link tests are not allowed after GCC_NO_EXECUTABLES." "$LINENO" 5
+fi
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <dirent.h>
+int
+main ()
+{
+
+       struct dirent d;
+       if (sizeof d.d_type) return 0;
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_link "$LINENO"; then :
+  glibcxx_cv_dirent_d_type=yes
+else
+  glibcxx_cv_dirent_d_type=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+fi
+
+fi
+
+  if test $glibcxx_cv_dirent_d_type = yes; then
+
+$as_echo "#define _GLIBCXX_HAVE_STRUCT_DIRENT_D_TYPE 1" >>confdefs.h
+
+  fi
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $glibcxx_cv_dirent_d_type" >&5
+$as_echo "$glibcxx_cv_dirent_d_type" >&6; }
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for realpath" >&5
+$as_echo_n "checking for realpath... " >&6; }
+  if test "${glibcxx_cv_realpath+set}" = set; then :
+  $as_echo_n "(cached) " >&6
+else
+      if test x$gcc_no_link = xyes; then
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <stdlib.h>
+int
+main ()
+{
+char *tmp = realpath((const char*)NULL, (char*)NULL);
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_compile "$LINENO"; then :
+  glibcxx_cv_realpath=yes
+else
+  glibcxx_cv_realpath=no
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+else
+  if test x$gcc_no_link = xyes; then
+  as_fn_error "Link tests are not allowed after GCC_NO_EXECUTABLES." "$LINENO" 5
+fi
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <stdlib.h>
+int
+main ()
+{
+char *tmp = realpath((const char*)NULL, (char*)NULL);
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_link "$LINENO"; then :
+  glibcxx_cv_realpath=yes
+else
+  glibcxx_cv_realpath=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+fi
+
+fi
+
+  if test $glibcxx_cv_realpath = yes; then
+
+$as_echo "#define _GLIBCXX_USE_REALPATH 1" >>confdefs.h
+
+  fi
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $glibcxx_cv_realpath" >&5
+$as_echo "$glibcxx_cv_realpath" >&6; }
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for utimensat" >&5
+$as_echo_n "checking for utimensat... " >&6; }
+  if test "${glibcxx_cv_utimensat+set}" = set; then :
+  $as_echo_n "(cached) " >&6
+else
+      if test x$gcc_no_link = xyes; then
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+        #include <fcntl.h>
+        #include <sys/stat.h>
+
+int
+main ()
+{
+
+        struct timespec ts[2] = { { 0, UTIME_OMIT }, { 1, 1 } };
+        int i = utimensat(AT_FDCWD, "path", ts, 0);
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_compile "$LINENO"; then :
+  glibcxx_cv_utimensat=yes
+else
+  glibcxx_cv_utimensat=no
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+else
+  if test x$gcc_no_link = xyes; then
+  as_fn_error "Link tests are not allowed after GCC_NO_EXECUTABLES." "$LINENO" 5
+fi
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+        #include <fcntl.h>
+        #include <sys/stat.h>
+
+int
+main ()
+{
+
+        struct timespec ts[2] = { { 0, UTIME_OMIT }, { 1, 1 } };
+        int i = utimensat(AT_FDCWD, "path", ts, 0);
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_link "$LINENO"; then :
+  glibcxx_cv_utimensat=yes
+else
+  glibcxx_cv_utimensat=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+fi
+
+fi
+
+  if test $glibcxx_cv_utimensat = yes; then
+
+$as_echo "#define _GLIBCXX_USE_UTIMENSAT 1" >>confdefs.h
+
+  fi
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $glibcxx_cv_utimensat" >&5
+$as_echo "$glibcxx_cv_utimensat" >&6; }
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for struct stat.st_mtim.tv_nsec" >&5
+$as_echo_n "checking for struct stat.st_mtim.tv_nsec... " >&6; }
+  if test "${glibcxx_cv_st_mtim+set}" = set; then :
+  $as_echo_n "(cached) " >&6
+else
+      if test x$gcc_no_link = xyes; then
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+ #include <sys/stat.h>
+int
+main ()
+{
+
+        struct stat st;
+        return st.st_mtim.tv_nsec;
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_compile "$LINENO"; then :
+  glibcxx_cv_st_mtim=yes
+else
+  glibcxx_cv_st_mtim=no
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+else
+  if test x$gcc_no_link = xyes; then
+  as_fn_error "Link tests are not allowed after GCC_NO_EXECUTABLES." "$LINENO" 5
+fi
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+ #include <sys/stat.h>
+int
+main ()
+{
+
+        struct stat st;
+        return st.st_mtim.tv_nsec;
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_link "$LINENO"; then :
+  glibcxx_cv_st_mtim=yes
+else
+  glibcxx_cv_st_mtim=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+fi
+
+fi
+
+  if test $glibcxx_cv_st_mtim = yes; then
+
+$as_echo "#define _GLIBCXX_USE_ST_MTIM 1" >>confdefs.h
+
+  fi
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $glibcxx_cv_st_mtim" >&5
+$as_echo "$glibcxx_cv_st_mtim" >&6; }
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for fchmod" >&5
+$as_echo_n "checking for fchmod... " >&6; }
+  if test "${glibcxx_cv_fchmod+set}" = set; then :
+  $as_echo_n "(cached) " >&6
+else
+      if test x$gcc_no_link = xyes; then
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <sys/stat.h>
+int
+main ()
+{
+fchmod(1, S_IWUSR);
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_compile "$LINENO"; then :
+  glibcxx_cv_fchmod=yes
+else
+  glibcxx_cv_fchmod=no
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+else
+  if test x$gcc_no_link = xyes; then
+  as_fn_error "Link tests are not allowed after GCC_NO_EXECUTABLES." "$LINENO" 5
+fi
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <sys/stat.h>
+int
+main ()
+{
+fchmod(1, S_IWUSR);
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_link "$LINENO"; then :
+  glibcxx_cv_fchmod=yes
+else
+  glibcxx_cv_fchmod=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+fi
+
+fi
+
+  if test $glibcxx_cv_fchmod = yes; then
+
+$as_echo "#define _GLIBCXX_USE_FCHMOD 1" >>confdefs.h
+
+  fi
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $glibcxx_cv_fchmod" >&5
+$as_echo "$glibcxx_cv_fchmod" >&6; }
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for fchmodat" >&5
+$as_echo_n "checking for fchmodat... " >&6; }
+  if test "${glibcxx_cv_fchmodat+set}" = set; then :
+  $as_echo_n "(cached) " >&6
+else
+      if test x$gcc_no_link = xyes; then
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+        #include <fcntl.h>
+        #include <sys/stat.h>
+
+int
+main ()
+{
+fchmodat(AT_FDCWD, "", 0, AT_SYMLINK_NOFOLLOW);
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_compile "$LINENO"; then :
+  glibcxx_cv_fchmodat=yes
+else
+  glibcxx_cv_fchmodat=no
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+else
+  if test x$gcc_no_link = xyes; then
+  as_fn_error "Link tests are not allowed after GCC_NO_EXECUTABLES." "$LINENO" 5
+fi
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+        #include <fcntl.h>
+        #include <sys/stat.h>
+
+int
+main ()
+{
+fchmodat(AT_FDCWD, "", 0, AT_SYMLINK_NOFOLLOW);
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_link "$LINENO"; then :
+  glibcxx_cv_fchmodat=yes
+else
+  glibcxx_cv_fchmodat=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+fi
+
+fi
+
+  if test $glibcxx_cv_fchmodat = yes; then
+
+$as_echo "#define _GLIBCXX_USE_FCHMODAT 1" >>confdefs.h
+
+  fi
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $glibcxx_cv_fchmodat" >&5
+$as_echo "$glibcxx_cv_fchmodat" >&6; }
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for sendfile that can copy files" >&5
+$as_echo_n "checking for sendfile that can copy files... " >&6; }
+  if test "${glibcxx_cv_sendfile+set}" = set; then :
+  $as_echo_n "(cached) " >&6
+else
+      case "${target_os}" in
+      gnu* | linux* | solaris*)
+        if test x$gcc_no_link = xyes; then
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <sys/sendfile.h>
+int
+main ()
+{
+sendfile(1, 2, (off_t*)NULL, sizeof 1);
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_compile "$LINENO"; then :
+  glibcxx_cv_sendfile=yes
+else
+  glibcxx_cv_sendfile=no
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+else
+  if test x$gcc_no_link = xyes; then
+  as_fn_error "Link tests are not allowed after GCC_NO_EXECUTABLES." "$LINENO" 5
+fi
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <sys/sendfile.h>
+int
+main ()
+{
+sendfile(1, 2, (off_t*)NULL, sizeof 1);
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_cxx_try_link "$LINENO"; then :
+  glibcxx_cv_sendfile=yes
+else
+  glibcxx_cv_sendfile=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+fi
+        ;;
+      *)
+        glibcxx_cv_sendfile=no
+        ;;
+    esac
+
+fi
+
+  if test $glibcxx_cv_sendfile = yes; then
+
+$as_echo "#define _GLIBCXX_USE_SENDFILE 1" >>confdefs.h
+
+  fi
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $glibcxx_cv_sendfile" >&5
+$as_echo "$glibcxx_cv_sendfile" >&6; }
+  CXXFLAGS="$ac_save_CXXFLAGS"
+  ac_ext=c
+ac_cpp='$CPP $CPPFLAGS'
+ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext >&5'
+ac_link='$CC -o conftest$ac_exeext $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_c_compiler_gnu
+
+
+
 # Define documentation rules conditionally.
 
 # See if makeinfo has been installed and is modern enough
@@ -79490,8 +79997,17 @@
 fi
 
 
+    if test $enable_libstdcxx_filesystem_ts = yes; then
+  ENABLE_FILESYSTEM_TS_TRUE=
+  ENABLE_FILESYSTEM_TS_FALSE='#'
+else
+  ENABLE_FILESYSTEM_TS_TRUE='#'
+  ENABLE_FILESYSTEM_TS_FALSE=
+fi
 
 
+
+
 cat >confcache <<\_ACEOF
 # This file is a shell script that caches the results of configure
 # tests run on this system so they can be shared between configure
@@ -79715,7 +80231,7 @@
 # append it here.  Only modify Makefiles that have just been created.
 #
 # Also, get rid of this simulated-VPATH thing that automake does.
-ac_config_files="$ac_config_files include/Makefile libsupc++/Makefile python/Makefile src/Makefile src/c++98/Makefile src/c++11/Makefile doc/Makefile po/Makefile testsuite/Makefile"
+ac_config_files="$ac_config_files include/Makefile libsupc++/Makefile src/Makefile src/c++98/Makefile src/c++11/Makefile src/filesystem/Makefile doc/Makefile po/Makefile testsuite/Makefile python/Makefile"
 
 
 ac_config_commands="$ac_config_commands generate-headers"
@@ -79914,6 +80430,10 @@
   as_fn_error "conditional \"GLIBCXX_LDBL_COMPAT\" was never defined.
 Usually this means the macro was only invoked conditionally." "$LINENO" 5
 fi
+if test -z "${ENABLE_FILESYSTEM_TS_TRUE}" && test -z "${ENABLE_FILESYSTEM_TS_FALSE}"; then
+  as_fn_error "conditional \"ENABLE_FILESYSTEM_TS\" was never defined.
+Usually this means the macro was only invoked conditionally." "$LINENO" 5
+fi
 if test -z "${BUILD_INFO_TRUE}" && test -z "${BUILD_INFO_FALSE}"; then
   as_fn_error "conditional \"BUILD_INFO\" was never defined.
 Usually this means the macro was only invoked conditionally." "$LINENO" 5
@@ -80932,13 +81452,14 @@
     "doc/xsl/customization.xsl") CONFIG_FILES="$CONFIG_FILES doc/xsl/customization.xsl" ;;
     "include/Makefile") CONFIG_FILES="$CONFIG_FILES include/Makefile" ;;
     "libsupc++/Makefile") CONFIG_FILES="$CONFIG_FILES libsupc++/Makefile" ;;
-    "python/Makefile") CONFIG_FILES="$CONFIG_FILES python/Makefile" ;;
     "src/Makefile") CONFIG_FILES="$CONFIG_FILES src/Makefile" ;;
     "src/c++98/Makefile") CONFIG_FILES="$CONFIG_FILES src/c++98/Makefile" ;;
     "src/c++11/Makefile") CONFIG_FILES="$CONFIG_FILES src/c++11/Makefile" ;;
+    "src/filesystem/Makefile") CONFIG_FILES="$CONFIG_FILES src/filesystem/Makefile" ;;
     "doc/Makefile") CONFIG_FILES="$CONFIG_FILES doc/Makefile" ;;
     "po/Makefile") CONFIG_FILES="$CONFIG_FILES po/Makefile" ;;
     "testsuite/Makefile") CONFIG_FILES="$CONFIG_FILES testsuite/Makefile" ;;
+    "python/Makefile") CONFIG_FILES="$CONFIG_FILES python/Makefile" ;;
     "generate-headers") CONFIG_COMMANDS="$CONFIG_COMMANDS generate-headers" ;;
 
   *) as_fn_error "invalid argument: \`$ac_config_target'" "$LINENO" 5;;
@@ -82738,7 +83259,7 @@
    . ${multi_basedir}/config-ml.in
    { ml_norecursion=; unset ml_norecursion;}
  ;;
-    "python/Makefile":F) cat > vpsed$$ << \_EOF
+    "src/Makefile":F) cat > vpsed$$ << \_EOF
 s!`test -f '$<' || echo '$(srcdir)/'`!!
 _EOF
    sed -f vpsed$$ $ac_file > tmp$$
@@ -82749,7 +83270,7 @@
    . ${multi_basedir}/config-ml.in
    { ml_norecursion=; unset ml_norecursion;}
  ;;
-    "src/Makefile":F) cat > vpsed$$ << \_EOF
+    "src/c++98/Makefile":F) cat > vpsed$$ << \_EOF
 s!`test -f '$<' || echo '$(srcdir)/'`!!
 _EOF
    sed -f vpsed$$ $ac_file > tmp$$
@@ -82760,7 +83281,7 @@
    . ${multi_basedir}/config-ml.in
    { ml_norecursion=; unset ml_norecursion;}
  ;;
-    "src/c++98/Makefile":F) cat > vpsed$$ << \_EOF
+    "src/c++11/Makefile":F) cat > vpsed$$ << \_EOF
 s!`test -f '$<' || echo '$(srcdir)/'`!!
 _EOF
    sed -f vpsed$$ $ac_file > tmp$$
@@ -82771,7 +83292,7 @@
    . ${multi_basedir}/config-ml.in
    { ml_norecursion=; unset ml_norecursion;}
  ;;
-    "src/c++11/Makefile":F) cat > vpsed$$ << \_EOF
+    "src/filesystem/Makefile":F) cat > vpsed$$ << \_EOF
 s!`test -f '$<' || echo '$(srcdir)/'`!!
 _EOF
    sed -f vpsed$$ $ac_file > tmp$$
@@ -82815,6 +83336,17 @@
    . ${multi_basedir}/config-ml.in
    { ml_norecursion=; unset ml_norecursion;}
  ;;
+    "python/Makefile":F) cat > vpsed$$ << \_EOF
+s!`test -f '$<' || echo '$(srcdir)/'`!!
+_EOF
+   sed -f vpsed$$ $ac_file > tmp$$
+   mv tmp$$ $ac_file
+   rm vpsed$$
+   echo 'MULTISUBDIR =' >> $ac_file
+   ml_norecursion=yes
+   . ${multi_basedir}/config-ml.in
+   { ml_norecursion=; unset ml_norecursion;}
+ ;;
     "generate-headers":C) (cd include && ${MAKE-make} pch_build= ) ;;
 
   esac
Index: libstdc++-v3/python/Makefile.in
===================================================================
--- libstdc++-v3/python/Makefile.in	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/python/Makefile.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11.1 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -68,6 +85,11 @@
 depcomp =
 am__depfiles_maybe =
 SOURCES =
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 am__vpath_adj_setup = srcdirstrip=`echo "$(srcdir)" | sed 's|.|.|g'`;
 am__vpath_adj = case $$p in \
     $(srcdir)/*) f=`echo "$$p" | sed "s|^$$srcdirstrip/||"`;; \
@@ -89,6 +111,12 @@
 am__base_list = \
   sed '$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;s/\n/ /g' | \
   sed '$$!N;$$!N;$$!N;$$!N;s/\n/ /g'
+am__uninstall_files_from_dir = { \
+  test -z "$$files" \
+    || { test ! -d "$$dir" && test ! -f "$$dir" && test ! -r "$$dir"; } \
+    || { echo " ( cd '$$dir' && rm -f" $$files ")"; \
+         $(am__cd) "$$dir" && rm -f $$files; }; \
+  }
 am__installdirs = "$(DESTDIR)$(pythondir)"
 DATA = $(nobase_python_DATA)
 ABI_TWEAKS_SRCDIR = @ABI_TWEAKS_SRCDIR@
@@ -345,6 +373,7 @@
 	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
 	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
 	esac;
+$(top_srcdir)/fragment.am:
 
 $(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
 	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
@@ -362,8 +391,11 @@
 	-rm -rf .libs _libs
 install-nobase_pythonDATA: $(nobase_python_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(pythondir)" || $(MKDIR_P) "$(DESTDIR)$(pythondir)"
 	@list='$(nobase_python_DATA)'; test -n "$(pythondir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(pythondir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(pythondir)" || exit 1; \
+	fi; \
 	$(am__nobase_list) | while read dir files; do \
 	  xfiles=; for file in $$files; do \
 	    if test -f "$$file"; then xfiles="$$xfiles $$file"; \
@@ -370,7 +402,7 @@
 	    else xfiles="$$xfiles $(srcdir)/$$file"; fi; done; \
 	  test -z "$$xfiles" || { \
 	    test "x$$dir" = x. || { \
-	      echo "$(MKDIR_P) '$(DESTDIR)$(pythondir)/$$dir'"; \
+	      echo " $(MKDIR_P) '$(DESTDIR)$(pythondir)/$$dir'"; \
 	      $(MKDIR_P) "$(DESTDIR)$(pythondir)/$$dir"; }; \
 	    echo " $(INSTALL_DATA) $$xfiles '$(DESTDIR)$(pythondir)/$$dir'"; \
 	    $(INSTALL_DATA) $$xfiles "$(DESTDIR)$(pythondir)/$$dir" || exit $$?; }; \
@@ -380,9 +412,7 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(nobase_python_DATA)'; test -n "$(pythondir)" || list=; \
 	$(am__nobase_strip_setup); files=`$(am__nobase_strip)`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(pythondir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(pythondir)" && rm -f $$files
+	dir='$(DESTDIR)$(pythondir)'; $(am__uninstall_files_from_dir)
 tags: TAGS
 TAGS:
 
@@ -406,10 +436,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:
@@ -512,7 +547,7 @@
 install-data-local: gdb.py
 	@$(mkdir_p) $(DESTDIR)$(toolexeclibdir)
 	@here=`pwd`; cd $(DESTDIR)$(toolexeclibdir); \
-	  for file in libstdc++*; do \
+	  for file in libstdc++.*; do \
 	    case $$file in \
 	      *-gdb.py) ;; \
 	      *.la) ;; \
Index: libstdc++-v3/python/libstdcxx/v6/printers.py
===================================================================
--- libstdc++-v3/python/libstdcxx/v6/printers.py	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/python/libstdcxx/v6/printers.py	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -980,6 +980,57 @@
     def display_hint (self):
         return 'string'
 
+class StdExpPathPrinter:
+    "Print a std::experimental::filesystem::path"
+
+    def __init__ (self, typename, val):
+        self.val = val
+        start = self.val['_M_cmpts']['_M_impl']['_M_start']
+        finish = self.val['_M_cmpts']['_M_impl']['_M_finish']
+        self.num_cmpts = int (finish - start)
+
+    def _path_type(self):
+        t = str(self.val['_M_type'])
+        if t[-9:] == '_Root_dir':
+            return "root-directory"
+        if t[-10:] == '_Root_name':
+            return "root-name"
+        return None
+
+    def to_string (self):
+        path = "%s" % self.val ['_M_pathname']
+        if self.num_cmpts == 0:
+            t = self._path_type()
+            if t:
+                path = '%s [%s]' % (path, t)
+        return "filesystem::path %s" % path
+
+    class _iterator(Iterator):
+        def __init__(self, cmpts):
+            self.item = cmpts['_M_impl']['_M_start']
+            self.finish = cmpts['_M_impl']['_M_finish']
+            self.count = 0
+
+        def __iter__(self):
+            return self
+
+        def __next__(self):
+            if self.item == self.finish:
+                raise StopIteration
+            item = self.item.dereference()
+            count = self.count
+            self.count = self.count + 1
+            self.item = self.item + 1
+            path = item['_M_pathname']
+            t = StdExpPathPrinter(item.type.name, item)._path_type()
+            if not t:
+                t = count
+            return ('[%s]' % t, path)
+
+    def children(self):
+        return self._iterator(self.val['_M_cmpts'])
+
+
 # A "regular expression" printer which conforms to the
 # "SubPrettyPrinter" protocol from gdb.printing.
 class RxPrinter(object):
@@ -1365,6 +1416,11 @@
                                   'optional', StdExpOptionalPrinter)
     libstdcxx_printer.add_version('std::experimental::fundamentals_v1::',
                                   'basic_string_view', StdExpStringViewPrinter)
+    # Filesystem TS components
+    libstdcxx_printer.add_version('std::experimental::filesystem::v1::',
+                                  'path', StdExpPathPrinter)
+    libstdcxx_printer.add_version('std::experimental::filesystem::v1::__cxx11::',
+                                  'path', StdExpPathPrinter)
 
     # Extensions.
     libstdcxx_printer.add_version('__gnu_cxx::', 'slist', StdSlistPrinter)
Index: libstdc++-v3/python/Makefile.am
===================================================================
--- libstdc++-v3/python/Makefile.am	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/python/Makefile.am	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -49,7 +49,7 @@
 ## fragile, but there does not seem to be a better option, because
 ## libtool hides the real names from us.
 	@here=`pwd`; cd $(DESTDIR)$(toolexeclibdir); \
-	  for file in libstdc++*; do \
+	  for file in libstdc++.*; do \
 	    case $$file in \
 	      *-gdb.py) ;; \
 	      *.la) ;; \
Index: libstdc++-v3/Makefile.in
===================================================================
--- libstdc++-v3/Makefile.in	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/Makefile.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11.1 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -15,6 +15,23 @@
 
 @SET_MAKE@
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -88,6 +105,11 @@
 	install-pdf-recursive install-ps-recursive install-recursive \
 	installcheck-recursive installdirs-recursive pdf-recursive \
 	ps-recursive uninstall-recursive
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 RECURSIVE_CLEAN_TARGETS = mostlyclean-recursive clean-recursive	\
   distclean-recursive maintainer-clean-recursive
 AM_RECURSIVE_TARGETS = $(RECURSIVE_TARGETS:-recursive=) \
@@ -392,7 +414,7 @@
 	$(MAKE) $(AM_MAKEFLAGS) all-recursive
 
 .SUFFIXES:
-am--refresh:
+am--refresh: Makefile
 	@:
 $(srcdir)/Makefile.in: @MAINTAINER_MODE_TRUE@ $(srcdir)/Makefile.am $(top_srcdir)/fragment.am $(am__configure_deps)
 	@for dep in $?; do \
@@ -417,6 +439,7 @@
 	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $@ $(am__depfiles_maybe)'; \
 	    cd $(top_builddir) && $(SHELL) ./config.status $@ $(am__depfiles_maybe);; \
 	esac;
+$(top_srcdir)/fragment.am:
 
 $(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
 	$(SHELL) ./config.status --recheck
@@ -428,10 +451,8 @@
 $(am__aclocal_m4_deps):
 
 config.h: stamp-h1
-	@if test ! -f $@; then \
-	  rm -f stamp-h1; \
-	  $(MAKE) $(AM_MAKEFLAGS) stamp-h1; \
-	else :; fi
+	@if test ! -f $@; then rm -f stamp-h1; else :; fi
+	@if test ! -f $@; then $(MAKE) $(AM_MAKEFLAGS) stamp-h1; else :; fi
 
 stamp-h1: $(srcdir)/config.h.in $(top_builddir)/config.status
 	@rm -f stamp-h1
@@ -590,10 +611,15 @@
 
 installcheck: installcheck-recursive
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:
Index: libstdc++-v3/scripts/testsuite_flags.in
===================================================================
--- libstdc++-v3/scripts/testsuite_flags.in	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/scripts/testsuite_flags.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -77,7 +77,8 @@
       echo ${PCHFLAGS}
       ;;
     --cxxldflags)
-      SECTIONLDFLAGS="@SECTION_LDFLAGS@ @LIBICONV@"
+      SECTIONLDFLAGS="@SECTION_LDFLAGS@ @LIBICONV@
+                      -L${BUILD_DIR}/src/filesystem/.libs"
       echo ${SECTIONLDFLAGS}
       ;;
     *)
Index: libstdc++-v3/src/Makefile.in
===================================================================
--- libstdc++-v3/src/Makefile.in	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/src/Makefile.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11.1 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -86,6 +103,12 @@
 am__base_list = \
   sed '$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;s/\n/ /g' | \
   sed '$$!N;$$!N;$$!N;$$!N;s/\n/ /g'
+am__uninstall_files_from_dir = { \
+  test -z "$$files" \
+    || { test ! -d "$$dir" && test ! -f "$$dir" && test ! -r "$$dir"; } \
+    || { echo " ( cd '$$dir' && rm -f" $$files ")"; \
+         $(am__cd) "$$dir" && rm -f $$files; }; \
+  }
 am__installdirs = "$(DESTDIR)$(toolexeclibdir)"
 LTLIBRARIES = $(toolexeclib_LTLIBRARIES)
 am__DEPENDENCIES_1 =
@@ -117,6 +140,11 @@
 	install-pdf-recursive install-ps-recursive install-recursive \
 	installcheck-recursive installdirs-recursive pdf-recursive \
 	ps-recursive uninstall-recursive
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 RECURSIVE_CLEAN_TARGETS = mostlyclean-recursive clean-recursive	\
   distclean-recursive maintainer-clean-recursive
 AM_RECURSIVE_TARGETS = $(RECURSIVE_TARGETS:-recursive=) \
@@ -123,7 +151,7 @@
 	$(RECURSIVE_CLEAN_TARGETS:-recursive=) tags TAGS ctags CTAGS
 ETAGS = etags
 CTAGS = ctags
-DIST_SUBDIRS = $(SUBDIRS)
+DIST_SUBDIRS = c++98 c++11 filesystem
 ABI_TWEAKS_SRCDIR = @ABI_TWEAKS_SRCDIR@
 ACLOCAL = @ACLOCAL@
 ALLOCATOR_H = @ALLOCATOR_H@
@@ -346,7 +374,9 @@
 
 # -I/-D flags to pass when compiling.
 AM_CPPFLAGS = $(GLIBCXX_INCLUDES)
-SUBDIRS = c++98 c++11
+@ENABLE_FILESYSTEM_TS_FALSE@filesystem_dir = 
+@ENABLE_FILESYSTEM_TS_TRUE@filesystem_dir = filesystem
+SUBDIRS = c++98 c++11 $(filesystem_dir)
 @VTV_CYGMIN_FALSE@toolexeclib_LTLIBRARIES = libstdc++.la
 
 # Cross compiler support.
@@ -529,6 +559,7 @@
 	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
 	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
 	esac;
+$(top_srcdir)/fragment.am:
 
 $(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
 	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
@@ -540,7 +571,6 @@
 $(am__aclocal_m4_deps):
 install-toolexeclibLTLIBRARIES: $(toolexeclib_LTLIBRARIES)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibdir)"
 	@list='$(toolexeclib_LTLIBRARIES)'; test -n "$(toolexeclibdir)" || list=; \
 	list2=; for p in $$list; do \
 	  if test -f $$p; then \
@@ -548,6 +578,8 @@
 	  else :; fi; \
 	done; \
 	test -z "$$list2" || { \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibdir)" || exit 1; \
 	  echo " $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 '$(DESTDIR)$(toolexeclibdir)'"; \
 	  $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 "$(DESTDIR)$(toolexeclibdir)"; \
 	}
@@ -569,9 +601,9 @@
 	  echo "rm -f \"$${dir}/so_locations\""; \
 	  rm -f "$${dir}/so_locations"; \
 	done
-libstdc++.la: $(libstdc___la_OBJECTS) $(libstdc___la_DEPENDENCIES) 
+libstdc++.la: $(libstdc___la_OBJECTS) $(libstdc___la_DEPENDENCIES) $(EXTRA_libstdc___la_DEPENDENCIES) 
 	$(libstdc___la_LINK) $(am_libstdc___la_rpath) $(libstdc___la_OBJECTS) $(libstdc___la_LIBADD) $(LIBS)
-libvtv.la: $(libvtv_la_OBJECTS) $(libvtv_la_DEPENDENCIES) 
+libvtv.la: $(libvtv_la_OBJECTS) $(libvtv_la_DEPENDENCIES) $(EXTRA_libvtv_la_DEPENDENCIES) 
 	$(libvtv_la_LINK) $(am_libvtv_la_rpath) $(libvtv_la_OBJECTS) $(libvtv_la_LIBADD) $(LIBS)
 
 mostlyclean-compile:
@@ -747,10 +779,15 @@
 
 installcheck: installcheck-recursive
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:
@@ -859,6 +896,7 @@
 
 vpath % $(top_srcdir)/src/c++98
 vpath % $(top_srcdir)/src/c++11
+@ENABLE_FILESYSTEM_TS_TRUE@vpath % $(top_srcdir)/src/filesystem
 
 # Use special rules for compatibility-ldbl.cc compilation, as we need to
 # pass -mlong-double-64.
Index: libstdc++-v3/src/filesystem/path.cc
===================================================================
--- libstdc++-v3/src/filesystem/path.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/src/filesystem/path.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,471 @@
+// Class filesystem::path -*- C++ -*-
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// Under Section 7 of GPL version 3, you are granted additional
+// permissions described in the GCC Runtime Library Exception, version
+// 3.1, as published by the Free Software Foundation.
+
+// You should have received a copy of the GNU General Public License and
+// a copy of the GCC Runtime Library Exception along with this program;
+// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
+// <http://www.gnu.org/licenses/>.
+
+#include <experimental/filesystem>
+
+using std::experimental::filesystem::path;
+
+std::experimental::filesystem::filesystem_error::~filesystem_error() = default;
+
+constexpr path::value_type path::preferred_separator;
+
+path&
+path::remove_filename()
+{
+  if (_M_type == _Type::_Multi)
+    {
+      if (!_M_cmpts.empty())
+	{
+	  auto cmpt = std::prev(_M_cmpts.end());
+	  _M_pathname.erase(cmpt->_M_pos);
+	  _M_cmpts.erase(cmpt);
+	  _M_trim();
+	}
+    }
+  else
+    clear();
+  return *this;
+}
+
+path&
+path::replace_filename(const path& replacement)
+{
+  remove_filename();
+  operator/=(replacement);
+  return *this;
+}
+
+path&
+path::replace_extension(const path& replacement)
+{
+  auto ext = _M_find_extension();
+  if (ext.first && ext.second != string_type::npos)
+    {
+      if (ext.first == &_M_pathname)
+	_M_pathname.erase(ext.second);
+      else
+	{
+	  const auto& back = _M_cmpts.back();
+	  if (ext.first != &back._M_pathname)
+	    _GLIBCXX_THROW_OR_ABORT(
+		std::logic_error("path::replace_extension failed"));
+	  _M_pathname.erase(back._M_pos + ext.second);
+	}
+    }
+  if (!replacement.empty() && replacement.native()[0] != '.')
+    _M_pathname += '.';
+  _M_pathname += replacement.native();
+  _M_split_cmpts();
+  return *this;
+}
+
+namespace
+{
+  template<typename Iter1, typename Iter2>
+    int do_compare(Iter1 begin1, Iter1 end1, Iter2 begin2, Iter2 end2)
+    {
+      int cmpt = 1;
+      while (begin1 != end1 && begin2 != end2)
+	{
+	  if (begin1->native() < begin2->native())
+	    return -cmpt;
+	  if (begin1->native() > begin2->native())
+	    return +cmpt;
+	  ++begin1;
+	  ++begin2;
+	  ++cmpt;
+	}
+      if (begin1 == end1)
+	{
+	  if (begin2 == end2)
+	    return 0;
+	  return -cmpt;
+	}
+      return +cmpt;
+    }
+}
+
+int
+path::compare(const path& p) const noexcept
+{
+  struct CmptRef
+  {
+    const path* ptr;
+    const string_type& native() const noexcept { return ptr->native(); }
+  };
+
+  if (_M_type == _Type::_Multi && p._M_type == _Type::_Multi)
+    return do_compare(_M_cmpts.begin(), _M_cmpts.end(),
+		      p._M_cmpts.begin(), p._M_cmpts.end());
+  else if (_M_type == _Type::_Multi)
+    {
+      CmptRef c[1] = { { &p } };
+      return do_compare(_M_cmpts.begin(), _M_cmpts.end(), c, c+1);
+    }
+  else if (p._M_type == _Type::_Multi)
+    {
+      CmptRef c[1] = { { this } };
+      return do_compare(c, c+1, p._M_cmpts.begin(), p._M_cmpts.end());
+    }
+  else
+    return _M_pathname.compare(p._M_pathname);
+}
+
+path
+path::root_name() const
+{
+  path __ret;
+  if (_M_type == _Type::_Root_name)
+    __ret = *this;
+  else if (_M_cmpts.size() && _M_cmpts.begin()->_M_type == _Type::_Root_name)
+    __ret = *_M_cmpts.begin();
+  return __ret;
+}
+
+path
+path::root_directory() const
+{
+  path __ret;
+  if (_M_type == _Type::_Root_dir)
+    __ret = *this;
+  else if (!_M_cmpts.empty())
+    {
+      auto __it = _M_cmpts.begin();
+      if (__it->_M_type == _Type::_Root_name)
+        ++__it;
+      if (__it != _M_cmpts.end() && __it->_M_type == _Type::_Root_dir)
+        __ret = *__it;
+    }
+  return __ret;
+}
+
+
+path
+path::root_path() const
+{
+  path __ret;
+  if (_M_type == _Type::_Root_name || _M_type == _Type::_Root_dir)
+    __ret = *this;
+  else if (!_M_cmpts.empty())
+    {
+      auto __it = _M_cmpts.begin();
+      if (__it->_M_type == _Type::_Root_name)
+        {
+          __ret = *__it++;
+          if (__it != _M_cmpts.end() && __it->_M_type == _Type::_Root_dir)
+            {
+              __ret._M_pathname += preferred_separator;
+              __ret._M_split_cmpts();
+            }
+        }
+      else if (__it->_M_type == _Type::_Root_dir)
+        __ret = *__it;
+    }
+  return __ret;
+}
+
+path
+path::relative_path() const
+{
+  path __ret;
+  if (_M_type == _Type::_Filename)
+    __ret = *this;
+  else if (!_M_cmpts.empty())
+    {
+      auto __it = _M_cmpts.begin();
+      if (__it->_M_type == _Type::_Root_name)
+        ++__it;
+      if (__it != _M_cmpts.end() && __it->_M_type == _Type::_Root_dir)
+        ++__it;
+      if (__it != _M_cmpts.end())
+        __ret.assign(_M_pathname.substr(__it->_M_pos));
+    }
+  return __ret;
+}
+
+path
+path::parent_path() const
+{
+  path __ret;
+  if (_M_cmpts.size() < 2)
+    return __ret;
+  for (auto __it = _M_cmpts.begin(), __end = std::prev(_M_cmpts.end());
+       __it != __end; ++__it)
+    {
+      __ret /= *__it;
+    }
+  return __ret;
+}
+
+bool
+path::has_root_name() const
+{
+  if (_M_type == _Type::_Root_name)
+    return true;
+  if (!_M_cmpts.empty() && _M_cmpts.begin()->_M_type == _Type::_Root_name)
+    return true;
+  return false;
+}
+
+bool
+path::has_root_directory() const
+{
+  if (_M_type == _Type::_Root_dir)
+    return true;
+  if (!_M_cmpts.empty())
+    {
+      auto __it = _M_cmpts.begin();
+      if (__it->_M_type == _Type::_Root_name)
+        ++__it;
+      if (__it != _M_cmpts.end() && __it->_M_type == _Type::_Root_dir)
+        return true;
+    }
+  return false;
+}
+
+bool
+path::has_root_path() const
+{
+  if (_M_type == _Type::_Root_name || _M_type == _Type::_Root_dir)
+    return true;
+  if (!_M_cmpts.empty())
+    {
+      auto __type = _M_cmpts.front()._M_type;
+      if (__type == _Type::_Root_name || __type == _Type::_Root_dir)
+        return true;
+    }
+  return false;
+}
+
+bool
+path::has_relative_path() const
+{
+  if (_M_type == _Type::_Filename)
+    return true;
+  if (!_M_cmpts.empty())
+    {
+      auto __it = _M_cmpts.begin();
+      if (__it->_M_type == _Type::_Root_name)
+        ++__it;
+      if (__it != _M_cmpts.end() && __it->_M_type == _Type::_Root_dir)
+        ++__it;
+      if (__it != _M_cmpts.end())
+        return true;
+    }
+  return false;
+}
+
+
+bool
+path::has_parent_path() const
+{
+  return _M_cmpts.size() > 1;
+}
+
+bool
+path::has_filename() const
+{
+  return !empty();
+}
+
+std::pair<const path::string_type*, std::size_t>
+path::_M_find_extension() const
+{
+  const std::string* s = nullptr;
+
+  if (_M_type != _Type::_Multi)
+    s = &_M_pathname;
+  else if (!_M_cmpts.empty())
+    {
+      const auto& c = _M_cmpts.back();
+      if (c._M_type == _Type::_Filename)
+	s = &c._M_pathname;
+    }
+
+  if (s)
+    {
+      if (auto sz = s->size())
+	{
+	  if (sz <= 2 && (*s)[0] == '.')
+	    {
+	      if (sz == 1 || (*s)[1] == '.')  // filename is "." or ".."
+		return { s, string_type::npos };
+	      else
+		return { s, 0 };  // filename is like ".?"
+	    }
+	  return { s, s->rfind('.') };
+	}
+    }
+  return {};
+}
+
+void
+path::_M_split_cmpts()
+{
+  _M_type = _Type::_Multi;
+  _M_cmpts.clear();
+
+  if (_M_pathname.empty())
+    return;
+
+  size_t pos = 0;
+  const size_t len = _M_pathname.size();
+
+  // look for root name or root directory
+  if (_S_is_dir_sep(_M_pathname[0]))
+    {
+      // look for root name, such as "//" or "//foo"
+      if (len > 1 && _M_pathname[1] == _M_pathname[0])
+	{
+	  if (len == 2)
+	    {
+	      // entire path is just "//"
+	      _M_type = _Type::_Root_name;
+	      return;
+	    }
+
+	  if (!_S_is_dir_sep(_M_pathname[2]))
+	    {
+	      // got root name, find its end
+	      pos = 3;
+	      while (pos < len && !_S_is_dir_sep(_M_pathname[pos]))
+		++pos;
+	      _M_add_root_name(pos);
+	      if (pos < len) // also got root directory
+		_M_add_root_dir(pos);
+	    }
+	  else
+	    {
+	      // got something like "///foo" which is just a root directory
+	      // composed of multiple redundant directory separators
+	      _M_add_root_dir(0);
+	    }
+	}
+      else // got root directory
+	_M_add_root_dir(0);
+      ++pos;
+    }
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+  else if (len > 1 && _M_pathname[1] == L':')
+    {
+      // got disk designator
+      _M_add_root_name(2);
+      if (len > 2 && _S_is_dir_sep(_M_pathname[2]))
+	_M_add_root_dir(2);
+      pos = 2;
+    }
+#endif
+
+  size_t back = pos;
+  while (pos < len)
+    {
+      if (_S_is_dir_sep(_M_pathname[pos]))
+	{
+	  if (back != pos)
+	    _M_add_filename(back, pos - back);
+	  back = ++pos;
+	}
+      else
+	++pos;
+    }
+
+  if (back != pos)
+    _M_add_filename(back, pos - back);
+  else if (_S_is_dir_sep(_M_pathname.back()))
+    {
+      // [path.itr]/8
+      // "Dot, if one or more trailing non-root slash characters are present."
+      if (_M_cmpts.back()._M_type == _Type::_Filename)
+	{
+	  const auto& last = _M_cmpts.back();
+	  pos = last._M_pos + last._M_pathname.size();
+	  _M_cmpts.emplace_back(string_type(1, '.'), _Type::_Filename, pos);
+	}
+    }
+
+  _M_trim();
+}
+
+void
+path::_M_add_root_name(size_t n)
+{
+  _M_cmpts.emplace_back(_M_pathname.substr(0, n), _Type::_Root_name, 0);
+}
+
+void
+path::_M_add_root_dir(size_t pos)
+{
+  _M_cmpts.emplace_back(_M_pathname.substr(pos, 1), _Type::_Root_dir, pos);
+}
+
+void
+path::_M_add_filename(size_t pos, size_t n)
+{
+  _M_cmpts.emplace_back(_M_pathname.substr(pos, n), _Type::_Filename, pos);
+}
+
+void
+path::_M_trim()
+{
+  if (_M_cmpts.size() == 1)
+    {
+      _M_type = _M_cmpts.front()._M_type;
+      _M_cmpts.clear();
+    }
+}
+
+path::string_type
+path::_S_convert_loc(const char* __first, const char* __last,
+               const std::locale& __loc)
+{
+  auto& __cvt = std::use_facet<codecvt<wchar_t, char, mbstate_t>>(__loc);
+  basic_string<wchar_t> __ws;
+  if (!__str_codecvt_in(__first, __last, __ws, __cvt))
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error(
+	  "Cannot convert character sequence",
+	  std::make_error_code(errc::illegal_byte_sequence)));
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+  return __ws;
+#else
+  return _Cvt<wchar_t>::_S_convert(__ws.data(), __ws.data() + __ws.size());
+#endif
+}
+
+std::size_t
+std::experimental::filesystem::hash_value(const path& p) noexcept
+{
+  // [path.non-member]
+  // "If for two paths, p1 == p2 then hash_value(p1) == hash_value(p2)."
+  // Equality works as if by traversing the range [begin(), end()), meaning
+  // e.g. path("a//b") == path("a/b"), so we cannot simply hash _M_pathname
+  // but need to iterate over individual elements. Use the hash_combine from
+  // http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2014/n3876.pdf
+  size_t seed = 0;
+  for (const auto& x : p)
+    {
+      seed ^= std::hash<path::string_type>()(x.native()) + 0x9e3779b9
+	+ (seed<<6) + (seed>>2);
+    }
+  return seed;
+}
Index: libstdc++-v3/src/filesystem/Makefile.in
===================================================================
--- libstdc++-v3/src/filesystem/Makefile.in	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/src/filesystem/Makefile.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,696 @@
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
+# @configure_input@
+
+# Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
+# This Makefile.in is free software; the Free Software Foundation
+# gives unlimited permission to copy and/or distribute it,
+# with or without modifications, as long as this notice is preserved.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY, to the extent permitted by law; without
+# even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+# PARTICULAR PURPOSE.
+
+@SET_MAKE@
+
+VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
+pkgdatadir = $(datadir)/@PACKAGE@
+pkgincludedir = $(includedir)/@PACKAGE@
+pkglibdir = $(libdir)/@PACKAGE@
+pkglibexecdir = $(libexecdir)/@PACKAGE@
+am__cd = CDPATH="$${ZSH_VERSION+.}$(PATH_SEPARATOR)" && cd
+install_sh_DATA = $(install_sh) -c -m 644
+install_sh_PROGRAM = $(install_sh) -c
+install_sh_SCRIPT = $(install_sh) -c
+INSTALL_HEADER = $(INSTALL_DATA)
+transform = $(program_transform_name)
+NORMAL_INSTALL = :
+PRE_INSTALL = :
+POST_INSTALL = :
+NORMAL_UNINSTALL = :
+PRE_UNINSTALL = :
+POST_UNINSTALL = :
+build_triplet = @build@
+host_triplet = @host@
+target_triplet = @target@
+DIST_COMMON = $(top_srcdir)/fragment.am $(srcdir)/Makefile.in \
+	$(srcdir)/Makefile.am
+subdir = src/filesystem
+ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
+am__aclocal_m4_deps = $(top_srcdir)/../config/acx.m4 \
+	$(top_srcdir)/../config/enable.m4 \
+	$(top_srcdir)/../config/futex.m4 \
+	$(top_srcdir)/../config/iconv.m4 \
+	$(top_srcdir)/../config/lead-dot.m4 \
+	$(top_srcdir)/../config/lib-ld.m4 \
+	$(top_srcdir)/../config/lib-link.m4 \
+	$(top_srcdir)/../config/lib-prefix.m4 \
+	$(top_srcdir)/../config/lthostflags.m4 \
+	$(top_srcdir)/../config/multi.m4 \
+	$(top_srcdir)/../config/no-executables.m4 \
+	$(top_srcdir)/../config/override.m4 \
+	$(top_srcdir)/../config/stdint.m4 \
+	$(top_srcdir)/../config/unwind_ipinfo.m4 \
+	$(top_srcdir)/../libtool.m4 $(top_srcdir)/../ltoptions.m4 \
+	$(top_srcdir)/../ltsugar.m4 $(top_srcdir)/../ltversion.m4 \
+	$(top_srcdir)/../lt~obsolete.m4 $(top_srcdir)/crossconfig.m4 \
+	$(top_srcdir)/linkage.m4 $(top_srcdir)/acinclude.m4 \
+	$(top_srcdir)/../config/gc++filt.m4 \
+	$(top_srcdir)/../config/tls.m4 $(top_srcdir)/../config/gthr.m4 \
+	$(top_srcdir)/configure.ac
+am__configure_deps = $(am__aclocal_m4_deps) $(CONFIGURE_DEPENDENCIES) \
+	$(ACLOCAL_M4)
+CONFIG_HEADER = $(top_builddir)/config.h
+CONFIG_CLEAN_FILES =
+CONFIG_CLEAN_VPATH_FILES =
+am__vpath_adj_setup = srcdirstrip=`echo "$(srcdir)" | sed 's|.|.|g'`;
+am__vpath_adj = case $$p in \
+    $(srcdir)/*) f=`echo "$$p" | sed "s|^$$srcdirstrip/||"`;; \
+    *) f=$$p;; \
+  esac;
+am__strip_dir = f=`echo $$p | sed -e 's|^.*/||'`;
+am__install_max = 40
+am__nobase_strip_setup = \
+  srcdirstrip=`echo "$(srcdir)" | sed 's/[].[^$$\\*|]/\\\\&/g'`
+am__nobase_strip = \
+  for p in $$list; do echo "$$p"; done | sed -e "s|$$srcdirstrip/||"
+am__nobase_list = $(am__nobase_strip_setup); \
+  for p in $$list; do echo "$$p $$p"; done | \
+  sed "s| $$srcdirstrip/| |;"' / .*\//!s/ .*/ ./; s,\( .*\)/[^/]*$$,\1,' | \
+  $(AWK) 'BEGIN { files["."] = "" } { files[$$2] = files[$$2] " " $$1; \
+    if (++n[$$2] == $(am__install_max)) \
+      { print $$2, files[$$2]; n[$$2] = 0; files[$$2] = "" } } \
+    END { for (dir in files) print dir, files[dir] }'
+am__base_list = \
+  sed '$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;s/\n/ /g' | \
+  sed '$$!N;$$!N;$$!N;$$!N;s/\n/ /g'
+am__uninstall_files_from_dir = { \
+  test -z "$$files" \
+    || { test ! -d "$$dir" && test ! -f "$$dir" && test ! -r "$$dir"; } \
+    || { echo " ( cd '$$dir' && rm -f" $$files ")"; \
+         $(am__cd) "$$dir" && rm -f $$files; }; \
+  }
+am__installdirs = "$(DESTDIR)$(toolexeclibdir)"
+LTLIBRARIES = $(toolexeclib_LTLIBRARIES)
+libstdc__fs_la_LIBADD =
+am__objects_1 = dir.lo ops.lo path.lo
+am_libstdc__fs_la_OBJECTS = $(am__objects_1)
+libstdc__fs_la_OBJECTS = $(am_libstdc__fs_la_OBJECTS)
+DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
+depcomp =
+am__depfiles_maybe =
+CXXCOMPILE = $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+CXXLD = $(CXX)
+SOURCES = $(libstdc__fs_la_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
+ETAGS = etags
+CTAGS = ctags
+ABI_TWEAKS_SRCDIR = @ABI_TWEAKS_SRCDIR@
+ACLOCAL = @ACLOCAL@
+ALLOCATOR_H = @ALLOCATOR_H@
+ALLOCATOR_NAME = @ALLOCATOR_NAME@
+AMTAR = @AMTAR@
+AR = @AR@
+AS = @AS@
+ATOMICITY_SRCDIR = @ATOMICITY_SRCDIR@
+ATOMIC_FLAGS = @ATOMIC_FLAGS@
+ATOMIC_WORD_SRCDIR = @ATOMIC_WORD_SRCDIR@
+AUTOCONF = @AUTOCONF@
+AUTOHEADER = @AUTOHEADER@
+AUTOMAKE = @AUTOMAKE@
+AWK = @AWK@
+BASIC_FILE_CC = @BASIC_FILE_CC@
+BASIC_FILE_H = @BASIC_FILE_H@
+CC = @CC@
+CCODECVT_CC = @CCODECVT_CC@
+CCOLLATE_CC = @CCOLLATE_CC@
+CCTYPE_CC = @CCTYPE_CC@
+CFLAGS = @CFLAGS@
+CLOCALE_CC = @CLOCALE_CC@
+CLOCALE_H = @CLOCALE_H@
+CLOCALE_INTERNAL_H = @CLOCALE_INTERNAL_H@
+CMESSAGES_CC = @CMESSAGES_CC@
+CMESSAGES_H = @CMESSAGES_H@
+CMONEY_CC = @CMONEY_CC@
+CNUMERIC_CC = @CNUMERIC_CC@
+CPP = @CPP@
+CPPFLAGS = @CPPFLAGS@
+CPU_DEFINES_SRCDIR = @CPU_DEFINES_SRCDIR@
+CPU_OPT_BITS_RANDOM = @CPU_OPT_BITS_RANDOM@
+CPU_OPT_EXT_RANDOM = @CPU_OPT_EXT_RANDOM@
+CSTDIO_H = @CSTDIO_H@
+CTIME_CC = @CTIME_CC@
+CTIME_H = @CTIME_H@
+CXX = @CXX@
+CXXCPP = @CXXCPP@
+CXXFILT = @CXXFILT@
+CXXFLAGS = @CXXFLAGS@
+CYGPATH_W = @CYGPATH_W@
+C_INCLUDE_DIR = @C_INCLUDE_DIR@
+DBLATEX = @DBLATEX@
+DEBUG_FLAGS = @DEBUG_FLAGS@
+DEFS = @DEFS@
+DOT = @DOT@
+DOXYGEN = @DOXYGEN@
+DSYMUTIL = @DSYMUTIL@
+DUMPBIN = @DUMPBIN@
+ECHO_C = @ECHO_C@
+ECHO_N = @ECHO_N@
+ECHO_T = @ECHO_T@
+EGREP = @EGREP@
+ERROR_CONSTANTS_SRCDIR = @ERROR_CONSTANTS_SRCDIR@
+EXEEXT = @EXEEXT@
+EXTRA_CXX_FLAGS = @EXTRA_CXX_FLAGS@
+FGREP = @FGREP@
+GLIBCXX_INCLUDES = @GLIBCXX_INCLUDES@
+GLIBCXX_LIBS = @GLIBCXX_LIBS@
+GREP = @GREP@
+HWCAP_FLAGS = @HWCAP_FLAGS@
+INSTALL = @INSTALL@
+INSTALL_DATA = @INSTALL_DATA@
+INSTALL_PROGRAM = @INSTALL_PROGRAM@
+INSTALL_SCRIPT = @INSTALL_SCRIPT@
+INSTALL_STRIP_PROGRAM = @INSTALL_STRIP_PROGRAM@
+LD = @LD@
+LDFLAGS = @LDFLAGS@
+LIBICONV = @LIBICONV@
+LIBOBJS = @LIBOBJS@
+LIBS = @LIBS@
+LIBTOOL = @LIBTOOL@
+LIPO = @LIPO@
+LN_S = @LN_S@
+LTLIBICONV = @LTLIBICONV@
+LTLIBOBJS = @LTLIBOBJS@
+MAINT = @MAINT@
+MAKEINFO = @MAKEINFO@
+MKDIR_P = @MKDIR_P@
+NM = @NM@
+NMEDIT = @NMEDIT@
+OBJDUMP = @OBJDUMP@
+OBJEXT = @OBJEXT@
+OPTIMIZE_CXXFLAGS = @OPTIMIZE_CXXFLAGS@
+OPT_LDFLAGS = @OPT_LDFLAGS@
+OS_INC_SRCDIR = @OS_INC_SRCDIR@
+OTOOL = @OTOOL@
+OTOOL64 = @OTOOL64@
+PACKAGE = @PACKAGE@
+PACKAGE_BUGREPORT = @PACKAGE_BUGREPORT@
+PACKAGE_NAME = @PACKAGE_NAME@
+PACKAGE_STRING = @PACKAGE_STRING@
+PACKAGE_TARNAME = @PACKAGE_TARNAME@
+PACKAGE_URL = @PACKAGE_URL@
+PACKAGE_VERSION = @PACKAGE_VERSION@
+PATH_SEPARATOR = @PATH_SEPARATOR@
+PDFLATEX = @PDFLATEX@
+RANLIB = @RANLIB@
+SECTION_FLAGS = @SECTION_FLAGS@
+SECTION_LDFLAGS = @SECTION_LDFLAGS@
+SED = @SED@
+SET_MAKE = @SET_MAKE@
+SHELL = @SHELL@
+STRIP = @STRIP@
+SYMVER_FILE = @SYMVER_FILE@
+TOPLEVEL_INCLUDES = @TOPLEVEL_INCLUDES@
+USE_NLS = @USE_NLS@
+VERSION = @VERSION@
+VTV_CXXFLAGS = @VTV_CXXFLAGS@
+VTV_CXXLINKFLAGS = @VTV_CXXLINKFLAGS@
+VTV_PCH_CXXFLAGS = @VTV_PCH_CXXFLAGS@
+WARN_FLAGS = @WARN_FLAGS@
+WERROR = @WERROR@
+XMLLINT = @XMLLINT@
+XSLTPROC = @XSLTPROC@
+XSL_STYLE_DIR = @XSL_STYLE_DIR@
+abs_builddir = @abs_builddir@
+abs_srcdir = @abs_srcdir@
+abs_top_builddir = @abs_top_builddir@
+abs_top_srcdir = @abs_top_srcdir@
+ac_ct_CC = @ac_ct_CC@
+ac_ct_CXX = @ac_ct_CXX@
+ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
+am__leading_dot = @am__leading_dot@
+am__tar = @am__tar@
+am__untar = @am__untar@
+baseline_dir = @baseline_dir@
+baseline_subdir_switch = @baseline_subdir_switch@
+bindir = @bindir@
+build = @build@
+build_alias = @build_alias@
+build_cpu = @build_cpu@
+build_os = @build_os@
+build_vendor = @build_vendor@
+builddir = @builddir@
+check_msgfmt = @check_msgfmt@
+datadir = @datadir@
+datarootdir = @datarootdir@
+docdir = @docdir@
+dvidir = @dvidir@
+enable_shared = @enable_shared@
+enable_static = @enable_static@
+exec_prefix = @exec_prefix@
+glibcxx_MOFILES = @glibcxx_MOFILES@
+glibcxx_PCHFLAGS = @glibcxx_PCHFLAGS@
+glibcxx_POFILES = @glibcxx_POFILES@
+glibcxx_builddir = @glibcxx_builddir@
+glibcxx_compiler_pic_flag = @glibcxx_compiler_pic_flag@
+glibcxx_compiler_shared_flag = @glibcxx_compiler_shared_flag@
+glibcxx_cxx98_abi = @glibcxx_cxx98_abi@
+glibcxx_localedir = @glibcxx_localedir@
+glibcxx_lt_pic_flag = @glibcxx_lt_pic_flag@
+glibcxx_prefixdir = @glibcxx_prefixdir@
+glibcxx_srcdir = @glibcxx_srcdir@
+glibcxx_toolexecdir = @glibcxx_toolexecdir@
+glibcxx_toolexeclibdir = @glibcxx_toolexeclibdir@
+gxx_include_dir = @gxx_include_dir@
+host = @host@
+host_alias = @host_alias@
+host_cpu = @host_cpu@
+host_os = @host_os@
+host_vendor = @host_vendor@
+htmldir = @htmldir@
+includedir = @includedir@
+infodir = @infodir@
+install_sh = @install_sh@
+libdir = @libdir@
+libexecdir = @libexecdir@
+libtool_VERSION = @libtool_VERSION@
+localedir = @localedir@
+localstatedir = @localstatedir@
+lt_host_flags = @lt_host_flags@
+mandir = @mandir@
+mkdir_p = @mkdir_p@
+multi_basedir = @multi_basedir@
+oldincludedir = @oldincludedir@
+pdfdir = @pdfdir@
+port_specific_symbol_files = @port_specific_symbol_files@
+prefix = @prefix@
+program_transform_name = @program_transform_name@
+psdir = @psdir@
+python_mod_dir = @python_mod_dir@
+sbindir = @sbindir@
+sharedstatedir = @sharedstatedir@
+srcdir = @srcdir@
+sysconfdir = @sysconfdir@
+target = @target@
+target_alias = @target_alias@
+target_cpu = @target_cpu@
+target_os = @target_os@
+target_vendor = @target_vendor@
+thread_header = @thread_header@
+top_build_prefix = @top_build_prefix@
+top_builddir = @top_builddir@
+top_srcdir = @top_srcdir@
+toplevel_builddir = @toplevel_builddir@
+toplevel_srcdir = @toplevel_srcdir@
+
+# May be used by various substitution variables.
+gcc_version := $(shell cat $(top_srcdir)/../gcc/BASE-VER)
+MAINT_CHARSET = latin1
+mkinstalldirs = $(SHELL) $(toplevel_srcdir)/mkinstalldirs
+PWD_COMMAND = $${PWDCMD-pwd}
+STAMP = echo timestamp >
+toolexecdir = $(glibcxx_toolexecdir)
+toolexeclibdir = $(glibcxx_toolexeclibdir)
+@ENABLE_WERROR_FALSE@WERROR_FLAG = 
+@ENABLE_WERROR_TRUE@WERROR_FLAG = $(WERROR)
+@ENABLE_EXTERN_TEMPLATE_FALSE@XTEMPLATE_FLAGS = 
+@ENABLE_EXTERN_TEMPLATE_TRUE@XTEMPLATE_FLAGS = -fno-implicit-templates
+
+# These bits are all figured out from configure.  Look in acinclude.m4
+# or configure.ac to see how they are set.  See GLIBCXX_EXPORT_FLAGS.
+CONFIG_CXXFLAGS = \
+	$(SECTION_FLAGS) $(HWCAP_FLAGS) -frandom-seed=$@
+
+WARN_CXXFLAGS = \
+	$(WARN_FLAGS) $(WERROR_FLAG) -fdiagnostics-show-location=once 
+
+
+# -I/-D flags to pass when compiling.
+AM_CPPFLAGS = $(GLIBCXX_INCLUDES)
+toolexeclib_LTLIBRARIES = libstdc++fs.la
+headers = 
+sources = \
+	dir.cc \
+	ops.cc \
+	path.cc
+
+
+# vpath % $(top_srcdir)/src/filesystem
+libstdc__fs_la_SOURCES = $(sources)
+
+# AM_CXXFLAGS needs to be in each subdirectory so that it can be
+# modified in a per-library or per-sub-library way.  Need to manually
+# set this option because CONFIG_CXXFLAGS has to be after
+# OPTIMIZE_CXXFLAGS on the compile line so that -O2 can be overridden
+# as the occasion call for it.
+AM_CXXFLAGS = \
+	$(glibcxx_lt_pic_flag) $(glibcxx_compiler_shared_flag) \
+	-std=gnu++14 \
+	$(WARN_CXXFLAGS) $(OPTIMIZE_CXXFLAGS)  $(CONFIG_CXXFLAGS)
+
+AM_MAKEFLAGS = \
+	"gxx_include_dir=$(gxx_include_dir)"
+
+
+# Libtool notes
+
+# 1) In general, libtool expects an argument such as `--tag=CXX' when
+# using the C++ compiler, because that will enable the settings
+# detected when C++ support was being configured.  However, when no
+# such flag is given in the command line, libtool attempts to figure
+# it out by matching the compiler name in each configuration section
+# against a prefix of the command line.  The problem is that, if the
+# compiler name and its initial flags stored in the libtool
+# configuration file don't match those in the command line, libtool
+# can't decide which configuration to use, and it gives up.  The
+# correct solution is to add `--tag CXX' to LTCXXCOMPILE and maybe
+# CXXLINK, just after $(LIBTOOL), so that libtool doesn't have to
+# attempt to infer which configuration to use.
+# 
+# The second tag argument, `--tag disable-shared` means that libtool
+# only compiles each source once, for static objects. In actuality,
+# glibcxx_lt_pic_flag and glibcxx_compiler_shared_flag are added to
+# the libtool command that is used create the object, which is
+# suitable for shared libraries.  The `--tag disable-shared` must be
+# placed after --tag CXX lest things CXX undo the affect of
+# disable-shared.
+
+# 2) Need to explicitly set LTCXXCOMPILE so that EXTRA_CXX_FLAGS is
+# last. (That way, things like -O2 passed down from the toplevel can
+# be overridden by --enable-debug.)
+LTCXXCOMPILE = \
+	$(LIBTOOL) --tag CXX --tag disable-shared \
+	$(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=compile $(CXX) $(TOPLEVEL_INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) $(EXTRA_CXX_FLAGS)
+
+LTLDFLAGS = $(shell $(SHELL) $(top_srcdir)/../libtool-ldflags $(LDFLAGS))
+
+# 3) We'd have a problem when building the shared libstdc++ object if
+# the rules automake generates would be used.  We cannot allow g++ to
+# be used since this would add -lstdc++ to the link line which of
+# course is problematic at this point.  So, we get the top-level
+# directory to configure libstdc++-v3 to use gcc as the C++
+# compilation driver.
+CXXLINK = \
+	$(LIBTOOL) --tag CXX --tag disable-shared \
+	$(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=link $(CXX) \
+	$(OPT_LDFLAGS) $(SECTION_LDFLAGS) $(AM_CXXFLAGS) $(LTLDFLAGS) -o $@
+
+
+# By adding these files here, automake will remove them for 'make clean'
+CLEANFILES = stamp-*
+all: all-am
+
+.SUFFIXES:
+.SUFFIXES: .cc .lo .o .obj
+$(srcdir)/Makefile.in: @MAINTAINER_MODE_TRUE@ $(srcdir)/Makefile.am $(top_srcdir)/fragment.am $(am__configure_deps)
+	@for dep in $?; do \
+	  case '$(am__configure_deps)' in \
+	    *$$dep*) \
+	      ( cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh ) \
+	        && { if test -f $@; then exit 0; else break; fi; }; \
+	      exit 1;; \
+	  esac; \
+	done; \
+	echo ' cd $(top_srcdir) && $(AUTOMAKE) --foreign --ignore-deps src/filesystem/Makefile'; \
+	$(am__cd) $(top_srcdir) && \
+	  $(AUTOMAKE) --foreign --ignore-deps src/filesystem/Makefile
+.PRECIOUS: Makefile
+Makefile: $(srcdir)/Makefile.in $(top_builddir)/config.status
+	@case '$?' in \
+	  *config.status*) \
+	    cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh;; \
+	  *) \
+	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
+	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
+	esac;
+$(top_srcdir)/fragment.am:
+
+$(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+
+$(top_srcdir)/configure: @MAINTAINER_MODE_TRUE@ $(am__configure_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(ACLOCAL_M4): @MAINTAINER_MODE_TRUE@ $(am__aclocal_m4_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(am__aclocal_m4_deps):
+install-toolexeclibLTLIBRARIES: $(toolexeclib_LTLIBRARIES)
+	@$(NORMAL_INSTALL)
+	@list='$(toolexeclib_LTLIBRARIES)'; test -n "$(toolexeclibdir)" || list=; \
+	list2=; for p in $$list; do \
+	  if test -f $$p; then \
+	    list2="$$list2 $$p"; \
+	  else :; fi; \
+	done; \
+	test -z "$$list2" || { \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibdir)" || exit 1; \
+	  echo " $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 '$(DESTDIR)$(toolexeclibdir)'"; \
+	  $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 "$(DESTDIR)$(toolexeclibdir)"; \
+	}
+
+uninstall-toolexeclibLTLIBRARIES:
+	@$(NORMAL_UNINSTALL)
+	@list='$(toolexeclib_LTLIBRARIES)'; test -n "$(toolexeclibdir)" || list=; \
+	for p in $$list; do \
+	  $(am__strip_dir) \
+	  echo " $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=uninstall rm -f '$(DESTDIR)$(toolexeclibdir)/$$f'"; \
+	  $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=uninstall rm -f "$(DESTDIR)$(toolexeclibdir)/$$f"; \
+	done
+
+clean-toolexeclibLTLIBRARIES:
+	-test -z "$(toolexeclib_LTLIBRARIES)" || rm -f $(toolexeclib_LTLIBRARIES)
+	@list='$(toolexeclib_LTLIBRARIES)'; for p in $$list; do \
+	  dir="`echo $$p | sed -e 's|/[^/]*$$||'`"; \
+	  test "$$dir" != "$$p" || dir=.; \
+	  echo "rm -f \"$${dir}/so_locations\""; \
+	  rm -f "$${dir}/so_locations"; \
+	done
+libstdc++fs.la: $(libstdc__fs_la_OBJECTS) $(libstdc__fs_la_DEPENDENCIES) $(EXTRA_libstdc__fs_la_DEPENDENCIES) 
+	$(CXXLINK) -rpath $(toolexeclibdir) $(libstdc__fs_la_OBJECTS) $(libstdc__fs_la_LIBADD) $(LIBS)
+
+mostlyclean-compile:
+	-rm -f *.$(OBJEXT)
+
+distclean-compile:
+	-rm -f *.tab.c
+
+.cc.o:
+	$(CXXCOMPILE) -c -o $@ $<
+
+.cc.obj:
+	$(CXXCOMPILE) -c -o $@ `$(CYGPATH_W) '$<'`
+
+.cc.lo:
+	$(LTCXXCOMPILE) -c -o $@ $<
+
+mostlyclean-libtool:
+	-rm -f *.lo
+
+clean-libtool:
+	-rm -rf .libs _libs
+
+ID: $(HEADERS) $(SOURCES) $(LISP) $(TAGS_FILES)
+	list='$(SOURCES) $(HEADERS) $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	mkid -fID $$unique
+tags: TAGS
+
+TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	set x; \
+	here=`pwd`; \
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	shift; \
+	if test -z "$(ETAGS_ARGS)$$*$$unique"; then :; else \
+	  test -n "$$unique" || unique=$$empty_fix; \
+	  if test $$# -gt 0; then \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      "$$@" $$unique; \
+	  else \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      $$unique; \
+	  fi; \
+	fi
+ctags: CTAGS
+CTAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	test -z "$(CTAGS_ARGS)$$unique" \
+	  || $(CTAGS) $(CTAGSFLAGS) $(AM_CTAGSFLAGS) $(CTAGS_ARGS) \
+	     $$unique
+
+GTAGS:
+	here=`$(am__cd) $(top_builddir) && pwd` \
+	  && $(am__cd) $(top_srcdir) \
+	  && gtags -i $(GTAGS_ARGS) "$$here"
+
+distclean-tags:
+	-rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
+check-am: all-am
+check: check-am
+all-am: Makefile $(LTLIBRARIES)
+installdirs:
+	for dir in "$(DESTDIR)$(toolexeclibdir)"; do \
+	  test -z "$$dir" || $(MKDIR_P) "$$dir"; \
+	done
+install: install-am
+install-exec: install-exec-am
+install-data: install-data-am
+uninstall: uninstall-am
+
+install-am: all-am
+	@$(MAKE) $(AM_MAKEFLAGS) install-exec-am install-data-am
+
+installcheck: installcheck-am
+install-strip:
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
+mostlyclean-generic:
+
+clean-generic:
+	-test -z "$(CLEANFILES)" || rm -f $(CLEANFILES)
+
+distclean-generic:
+	-test -z "$(CONFIG_CLEAN_FILES)" || rm -f $(CONFIG_CLEAN_FILES)
+	-test . = "$(srcdir)" || test -z "$(CONFIG_CLEAN_VPATH_FILES)" || rm -f $(CONFIG_CLEAN_VPATH_FILES)
+
+maintainer-clean-generic:
+	@echo "This command is intended for maintainers to use"
+	@echo "it deletes files that may require special tools to rebuild."
+clean: clean-am
+
+clean-am: clean-generic clean-libtool clean-toolexeclibLTLIBRARIES \
+	mostlyclean-am
+
+distclean: distclean-am
+	-rm -f Makefile
+distclean-am: clean-am distclean-compile distclean-generic \
+	distclean-tags
+
+dvi: dvi-am
+
+dvi-am:
+
+html: html-am
+
+html-am:
+
+info: info-am
+
+info-am:
+
+install-data-am:
+
+install-dvi: install-dvi-am
+
+install-dvi-am:
+
+install-exec-am: install-toolexeclibLTLIBRARIES
+
+install-html: install-html-am
+
+install-html-am:
+
+install-info: install-info-am
+
+install-info-am:
+
+install-man:
+
+install-pdf: install-pdf-am
+
+install-pdf-am:
+
+install-ps: install-ps-am
+
+install-ps-am:
+
+installcheck-am:
+
+maintainer-clean: maintainer-clean-am
+	-rm -f Makefile
+maintainer-clean-am: distclean-am maintainer-clean-generic
+
+mostlyclean: mostlyclean-am
+
+mostlyclean-am: mostlyclean-compile mostlyclean-generic \
+	mostlyclean-libtool
+
+pdf: pdf-am
+
+pdf-am:
+
+ps: ps-am
+
+ps-am:
+
+uninstall-am: uninstall-toolexeclibLTLIBRARIES
+
+.MAKE: install-am install-strip
+
+.PHONY: CTAGS GTAGS all all-am check check-am clean clean-generic \
+	clean-libtool clean-toolexeclibLTLIBRARIES ctags distclean \
+	distclean-compile distclean-generic distclean-libtool \
+	distclean-tags dvi dvi-am html html-am info info-am install \
+	install-am install-data install-data-am install-dvi \
+	install-dvi-am install-exec install-exec-am install-html \
+	install-html-am install-info install-info-am install-man \
+	install-pdf install-pdf-am install-ps install-ps-am \
+	install-strip install-toolexeclibLTLIBRARIES installcheck \
+	installcheck-am installdirs maintainer-clean \
+	maintainer-clean-generic mostlyclean mostlyclean-compile \
+	mostlyclean-generic mostlyclean-libtool pdf pdf-am ps ps-am \
+	tags uninstall uninstall-am uninstall-toolexeclibLTLIBRARIES
+
+
+# Tell versions [3.59,3.63) of GNU make to not export all variables.
+# Otherwise a system limit (for SysV at least) may be exceeded.
+.NOEXPORT:
Index: libstdc++-v3/src/filesystem/dir.cc
===================================================================
--- libstdc++-v3/src/filesystem/dir.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/src/filesystem/dir.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,403 @@
+// Class filesystem::directory_entry etc. -*- C++ -*-
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// Under Section 7 of GPL version 3, you are granted additional
+// permissions described in the GCC Runtime Library Exception, version
+// 3.1, as published by the Free Software Foundation.
+
+// You should have received a copy of the GNU General Public License and
+// a copy of the GCC Runtime Library Exception along with this program;
+// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
+// <http://www.gnu.org/licenses/>.
+
+#include <experimental/filesystem>
+#include <utility>
+#include <stack>
+#include <string.h>
+#include <errno.h>
+#ifdef _GLIBCXX_HAVE_DIRENT_H
+# ifdef _GLIBCXX_HAVE_SYS_TYPES_H
+#  include <sys/types.h>
+# endif
+# include <dirent.h>
+#else
+# error "the <dirent.h> header is needed to build the Filesystem TS"
+#endif
+
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+# undef opendir
+# define opendir _wopendir
+#endif
+
+namespace fs = std::experimental::filesystem;
+
+namespace
+{
+  struct ErrorCode
+  {
+    ErrorCode(std::error_code* p) : ec(p) { }
+
+    ErrorCode(ErrorCode&& e) : ec(std::exchange(e.ec, nullptr)) { }
+
+    ~ErrorCode() { if (ec) ec->clear(); }
+
+    void assign(int err)
+    {
+      ec->assign(err, std::generic_category());
+      ec = nullptr;
+    }
+
+    explicit operator bool() { return ec != nullptr; }
+
+    std::error_code* ec;
+  };
+}
+
+struct fs::_Dir
+{
+  _Dir() : dirp(nullptr) { }
+
+  _Dir(DIR* dirp, const fs::path& path) : dirp(dirp), path(path) { }
+
+  _Dir(_Dir&& d)
+  : dirp(std::exchange(d.dirp, nullptr)), path(std::move(d.path)),
+    entry(std::move(d.entry)), type(d.type)
+  { }
+
+  _Dir& operator=(_Dir&&) = delete;
+
+  ~_Dir() { if (dirp) ::closedir(dirp); }
+
+  bool advance(ErrorCode);
+
+  DIR*			dirp;
+  fs::path		path;
+  directory_entry	entry;
+  file_type		type = file_type::none;
+};
+
+namespace
+{
+  template<typename Bitmask>
+    inline bool is_set(Bitmask obj, Bitmask bits)
+    {
+      return (obj & bits) != Bitmask::none;
+    }
+
+  fs::_Dir
+  opendir(const fs::path& p, fs::directory_options options, ErrorCode ec)
+  {
+    if (DIR* dirp = ::opendir(p.c_str()))
+      return {dirp, p};
+
+    const int err = errno;
+    if (err == EACCES
+        && is_set(options, fs::directory_options::skip_permission_denied))
+      return {};
+
+    if (!ec)
+      _GLIBCXX_THROW_OR_ABORT(fs::filesystem_error(
+            "directory iterator cannot open directory", p,
+            std::error_code(err, std::generic_category())));
+
+    ec.assign(err);
+    return {};
+  }
+
+  inline std::shared_ptr<fs::_Dir>
+  make_shared_dir(fs::_Dir&& dir)
+  {
+    if (dir.dirp)
+      return std::make_shared<fs::_Dir>(std::move(dir));
+    return {};
+  }
+
+  inline fs::file_type
+  get_file_type(const dirent& d __attribute__((__unused__)))
+  {
+#ifdef _GLIBCXX_HAVE_STRUCT_DIRENT_D_TYPE
+    switch (d.d_type)
+    {
+    case DT_BLK:
+      return fs::file_type::block;
+    case DT_CHR:
+      return fs::file_type::character;
+    case DT_DIR:
+      return fs::file_type::directory;
+    case DT_FIFO:
+      return fs::file_type::fifo;
+    case DT_LNK:
+      return fs::file_type::symlink;
+    case DT_REG:
+      return fs::file_type::regular;
+    case DT_SOCK:
+      return fs::file_type::socket;
+    case DT_UNKNOWN:
+      return fs::file_type::unknown;
+    default:
+      return fs::file_type::none;
+    }
+#else
+    return fs::file_type::none;
+#endif
+  }
+
+  int
+  native_readdir(DIR* dirp, ::dirent*& entryp)
+  {
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+    errno = 0;
+    if ((entryp = ::readdir(dirp)))
+      return 0;
+    return errno;
+#else
+    return ::readdir_r(dirp, entryp, &entryp);
+#endif
+  }
+}
+
+bool
+fs::_Dir::advance(ErrorCode ec)
+{
+  ::dirent ent;
+  ::dirent* result = &ent;
+  if (int err = native_readdir(dirp, result))
+    {
+      if (!ec)
+	_GLIBCXX_THROW_OR_ABORT(filesystem_error(
+	      "directory iterator cannot advance",
+	      std::error_code(err, std::generic_category())));
+      ec.assign(err);
+      return true;
+    }
+  else if (result != nullptr)
+    {
+      // skip past dot and dot-dot
+      if (!strcmp(ent.d_name, ".") || !strcmp(ent.d_name, ".."))
+	return advance(std::move(ec));
+      entry = fs::directory_entry{path / ent.d_name};
+      type = get_file_type(ent);
+      return true;
+    }
+  else
+    {
+      // reached the end
+      entry = {};
+      type = fs::file_type::none;
+      return false;
+    }
+}
+
+fs::directory_iterator::
+directory_iterator(const path& p, directory_options options, error_code* ec)
+: directory_iterator(make_shared_dir(opendir(p, options, ec)), ec)
+{ }
+
+fs::directory_iterator::
+directory_iterator(std::shared_ptr<_Dir> dir, error_code* ec)
+: _M_dir(std::move(dir))
+{
+  if (_M_dir && !_M_dir->advance(ec))
+    _M_dir.reset();
+}
+
+const fs::directory_entry&
+fs::directory_iterator::operator*() const
+{
+  if (!_M_dir)
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error(
+	  "non-dereferenceable directory iterator",
+	  std::make_error_code(errc::invalid_argument)));
+  return _M_dir->entry;
+}
+
+fs::directory_iterator&
+fs::directory_iterator::operator++()
+{
+  if (!_M_dir)
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error(
+	  "cannot advance non-dereferenceable directory iterator",
+	  std::make_error_code(errc::invalid_argument)));
+  if (!_M_dir->advance(nullptr))
+    _M_dir.reset();
+  return *this;
+}
+
+fs::directory_iterator&
+fs::directory_iterator::increment(error_code& ec) noexcept
+{
+  if (!_M_dir)
+    {
+      ec = std::make_error_code(errc::invalid_argument);
+      return *this;
+    }
+  if (!_M_dir->advance(&ec))
+    _M_dir.reset();
+  return *this;
+}
+
+using Dir_iter_pair = std::pair<fs::_Dir, fs::directory_iterator>;
+
+struct fs::recursive_directory_iterator::_Dir_stack : std::stack<_Dir>
+{
+  void clear() { c.clear(); }
+};
+
+fs::recursive_directory_iterator::
+recursive_directory_iterator(const path& p, directory_options options,
+                                 error_code* ec)
+: _M_options(options), _M_pending(true)
+{
+  if (DIR* dirp = ::opendir(p.c_str()))
+    {
+      _M_dirs = std::make_shared<_Dir_stack>();
+      _M_dirs->push(_Dir{ dirp, p });
+      if (!_M_dirs->top().advance(ec))
+	_M_dirs.reset();
+    }
+  else
+    {
+      const int err = errno;
+      if (err == EACCES
+	  && is_set(options, fs::directory_options::skip_permission_denied))
+	return;
+
+      if (!ec)
+	_GLIBCXX_THROW_OR_ABORT(filesystem_error(
+	      "recursive directory iterator cannot open directory", p,
+	      std::error_code(err, std::generic_category())));
+
+      ec->assign(err, std::generic_category());
+    }
+}
+
+fs::recursive_directory_iterator::~recursive_directory_iterator() = default;
+
+int
+fs::recursive_directory_iterator::depth() const
+{
+  return int(_M_dirs->size()) - 1;
+}
+
+const fs::directory_entry&
+fs::recursive_directory_iterator::operator*() const
+{
+  return _M_dirs->top().entry;
+}
+
+fs::recursive_directory_iterator&
+fs::recursive_directory_iterator::
+operator=(const recursive_directory_iterator& other) noexcept = default;
+
+fs::recursive_directory_iterator&
+fs::recursive_directory_iterator::
+operator=(recursive_directory_iterator&& other) noexcept = default;
+
+fs::recursive_directory_iterator&
+fs::recursive_directory_iterator::operator++()
+{
+  error_code ec;
+  increment(ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error(
+	  "cannot increment recursive directory iterator", ec));
+  return *this;
+}
+
+namespace
+{
+  bool
+  recurse(const fs::_Dir& d, fs::directory_options options, std::error_code& ec)
+  {
+    bool follow_symlink
+      = is_set(options, fs::directory_options::follow_directory_symlink);
+#ifdef _GLIBCXX_HAVE_STRUCT_DIRENT_D_TYPE
+    if (d.type == fs::file_type::directory)
+      return true;
+    if (d.type == fs::file_type::symlink && follow_symlink)
+      return d.entry.status().type() == fs::file_type::directory;
+    if (d.type != fs::file_type::none && d.type != fs::file_type::unknown)
+      return false;
+#endif
+    const fs::path& path = d.entry.path();
+    auto type = fs::symlink_status(path, ec).type();
+    if (ec.value())
+      return false;
+    if (type == fs::file_type::symlink)
+      {
+	if (!follow_symlink)
+	  return false;
+	type = fs::status(path, ec).type();
+      }
+    return type == fs::file_type::directory;
+  }
+}
+
+fs::recursive_directory_iterator&
+fs::recursive_directory_iterator::increment(error_code& ec) noexcept
+{
+  if (!_M_dirs)
+    {
+      ec = std::make_error_code(errc::invalid_argument);
+      return *this;
+    }
+
+  auto& top = _M_dirs->top();
+
+  if (std::exchange(_M_pending, true) && recurse(top, _M_options, ec))
+    {
+      _Dir dir = opendir(top.entry.path(), _M_options, &ec);
+      if (ec.value())
+	return *this;
+      if (dir.dirp)
+	{
+	  _M_dirs->push(std::move(dir));
+	  if (!_M_dirs->top().advance(&ec)) // dir is empty
+	    pop();
+	  return *this;
+	}
+      // else skip permission denied and continue in parent dir
+    }
+
+  ec.clear();
+  while (!_M_dirs->top().advance(&ec) && !ec.value())
+    {
+      _M_dirs->pop();
+      if (_M_dirs->empty())
+	{
+	  _M_dirs.reset();
+	  return *this;
+	}
+    }
+  return *this;
+}
+
+void
+fs::recursive_directory_iterator::pop()
+{
+  if (!_M_dirs)
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error(
+	  "cannot pop non-dereferenceable recursive directory iterator",
+	  std::make_error_code(errc::invalid_argument)));
+
+  do {
+    _M_dirs->pop();
+    if (_M_dirs->empty())
+      {
+	_M_dirs.reset();
+	return;
+      }
+  } while (!_M_dirs->top().advance(nullptr));
+}
Index: libstdc++-v3/src/filesystem/ops.cc
===================================================================
--- libstdc++-v3/src/filesystem/ops.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/src/filesystem/ops.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,1233 @@
+// Filesystem operations -*- C++ -*-
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// Under Section 7 of GPL version 3, you are granted additional
+// permissions described in the GCC Runtime Library Exception, version
+// 3.1, as published by the Free Software Foundation.
+
+// You should have received a copy of the GNU General Public License and
+// a copy of the GCC Runtime Library Exception along with this program;
+// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
+// <http://www.gnu.org/licenses/>.
+
+#include <experimental/filesystem>
+#include <functional>
+#include <stack>
+#include <stdlib.h>
+#include <stdio.h>
+#include <errno.h>
+#ifdef _GLIBCXX_HAVE_UNISTD_H
+# include <unistd.h>
+# if defined(_GLIBCXX_HAVE_SYS_STAT_H) && defined(_GLIBCXX_HAVE_SYS_TYPES_H)
+#  include <sys/types.h>
+#  include <sys/stat.h>
+# endif
+#endif
+#ifdef _GLIBCXX_HAVE_FCNTL_H
+# include <fcntl.h>
+#endif
+#ifdef _GLIBCXX_HAVE_SYS_STATVFS_H
+# include <sys/statvfs.h>
+#endif
+#ifdef _GLIBCXX_USE_SENDFILE
+# include <sys/sendfile.h>
+#else
+# include <ext/stdio_filebuf.h>
+# include <ostream>
+#endif
+#if _GLIBCXX_HAVE_UTIME_H
+# include <utime.h>
+#endif
+
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+# undef utime
+# define utime _wutime
+# undef chmod
+# define chmod _wchmod
+#endif
+
+namespace fs = std::experimental::filesystem;
+
+fs::path
+fs::absolute(const path& p, const path& base)
+{
+  const bool has_root_dir = p.has_root_directory();
+  const bool has_root_name = p.has_root_name();
+  path abs;
+  if (has_root_dir && has_root_name)
+    abs = p;
+  else
+    {
+      abs = base.is_absolute() ? base : absolute(base);
+      if (has_root_dir)
+	abs = abs.root_name() / p;
+      else if (has_root_name)
+	abs = p.root_name() / abs.root_directory() / abs.relative_path()
+	  / p.relative_path();
+      else
+	abs = abs / p;
+    }
+  return abs;
+}
+
+namespace
+{
+  struct free_as_in_malloc
+  {
+    void operator()(void* p) const { ::free(p); }
+  };
+
+  using char_ptr = std::unique_ptr<char[], free_as_in_malloc>;
+}
+
+fs::path
+fs::canonical(const path& p, const path& base, error_code& ec)
+{
+  path can;
+#ifdef _GLIBCXX_USE_REALPATH
+  if (char_ptr rp = char_ptr{::realpath(absolute(p, base).c_str(), nullptr)})
+    {
+      can.assign(rp.get());
+      ec.clear();
+    }
+  else
+    ec.assign(errno, std::generic_category());
+#else
+  ec = std::make_error_code(std::errc::not_supported);
+#endif
+  return can;
+}
+
+fs::path
+fs::canonical(const path& p, error_code& ec)
+{
+  path cur = current_path(ec);
+  if (ec.value())
+    return {};
+  return canonical(p, cur, ec);
+}
+
+fs::path
+fs::canonical(const path& p, const path& base)
+{
+  error_code ec;
+  path can = canonical(p, base, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot canonicalize", p, ec));
+  return can;
+}
+
+void
+fs::copy(const path& from, const path& to, copy_options options)
+{
+  error_code ec;
+  copy(from, to, options, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot copy", from, to, ec));
+}
+
+namespace
+{
+  template<typename Bitmask>
+    inline bool is_set(Bitmask obj, Bitmask bits)
+    {
+      return (obj & bits) != Bitmask::none;
+    }
+}
+
+#ifdef _GLIBCXX_HAVE_SYS_STAT_H
+namespace
+{
+  typedef struct ::stat stat_type;
+
+  inline fs::file_type
+  make_file_type(const stat_type& st)
+  {
+    using fs::file_type;
+#ifdef _GLIBCXX_HAVE_S_ISREG
+    if (S_ISREG(st.st_mode))
+      return file_type::regular;
+    else if (S_ISDIR(st.st_mode))
+      return file_type::directory;
+    else if (S_ISCHR(st.st_mode))
+      return file_type::character;
+    else if (S_ISBLK(st.st_mode))
+      return file_type::block;
+    else if (S_ISFIFO(st.st_mode))
+      return file_type::fifo;
+    else if (S_ISLNK(st.st_mode))
+      return file_type::symlink;
+    else if (S_ISSOCK(st.st_mode))
+      return file_type::socket;
+#endif
+    return file_type::unknown;
+
+  }
+
+  inline fs::file_status
+  make_file_status(const stat_type& st)
+  {
+    return fs::file_status{
+	make_file_type(st),
+	static_cast<fs::perms>(st.st_mode) & fs::perms::mask
+    };
+  }
+
+  inline bool
+  is_not_found_errno(int err)
+  {
+    return err == ENOENT || err == ENOTDIR;
+  }
+
+  inline fs::file_time_type
+  file_time(const stat_type& st)
+  {
+    using namespace std::chrono;
+    return fs::file_time_type{
+#ifdef _GLIBCXX_USE_ST_MTIM
+	seconds{st.st_mtim.tv_sec} + nanoseconds{st.st_mtim.tv_nsec}
+#else
+	seconds{st.st_mtime}
+#endif
+    };
+  }
+
+  bool
+  do_copy_file(const fs::path& from, const fs::path& to,
+	       fs::copy_options option,
+	       stat_type* from_st, stat_type* to_st,
+	       std::error_code& ec) noexcept
+  {
+    stat_type st1, st2;
+    fs::file_status t, f;
+
+    if (to_st == nullptr)
+      {
+	if (::stat(to.c_str(), &st1))
+	  {
+	    int err = errno;
+	    if (!is_not_found_errno(err))
+	      {
+		ec.assign(err, std::generic_category());
+		return false;
+	      }
+	  }
+	else
+	  to_st = &st1;
+      }
+    else if (to_st == from_st)
+      to_st = nullptr;
+
+    if (to_st == nullptr)
+      t = fs::file_status{fs::file_type::not_found};
+    else
+      t = make_file_status(*to_st);
+
+    if (from_st == nullptr)
+      {
+	if (::stat(from.c_str(), &st2))
+	  {
+	    ec.assign(errno, std::generic_category());
+	    return false;
+	  }
+	else
+	  from_st = &st2;
+      }
+    f = make_file_status(*from_st);
+
+    using opts = fs::copy_options;
+
+    if (exists(t))
+      {
+	if (!is_other(t) && !is_other(f)
+	    && to_st->st_dev == from_st->st_dev
+	    && to_st->st_ino == from_st->st_ino)
+	  {
+	    ec = std::make_error_code(std::errc::file_exists);
+	    return false;
+	  }
+
+	if (is_set(option, opts::skip_existing))
+	  {
+	    ec.clear();
+	    return false;
+	  }
+	else if (is_set(option, opts::update_existing))
+	  {
+	    if (file_time(*from_st) <= file_time(*to_st))
+	      {
+		ec.clear();
+		return false;
+	      }
+	  }
+	else if (!is_set(option, opts::overwrite_existing))
+	  {
+	    ec = std::make_error_code(std::errc::file_exists);
+	    return false;
+	  }
+      }
+
+    struct CloseFD {
+      ~CloseFD() { if (fd != -1) ::close(fd); }
+      int fd;
+    };
+
+    CloseFD in = { ::open(from.c_str(), O_RDONLY) };
+    if (in.fd == -1)
+      {
+	ec.assign(errno, std::generic_category());
+	return false;
+      }
+    int oflag = O_WRONLY|O_CREAT;
+    if (is_set(option, opts::overwrite_existing|opts::update_existing))
+      oflag |= O_TRUNC;
+    else
+      oflag |= O_EXCL;
+    CloseFD out = { ::open(to.c_str(), oflag, S_IWUSR) };
+    if (out.fd == -1)
+      {
+	if (errno == EEXIST && is_set(option, opts::skip_existing))
+	  ec.clear();
+	else
+	  ec.assign(errno, std::generic_category());
+	return false;
+      }
+
+#ifdef _GLIBCXX_USE_SENDFILE
+    auto n = ::sendfile(out.fd, in.fd, nullptr, from_st->st_size);
+    if (n != from_st->st_size)
+      {
+	ec.assign(errno, std::generic_category());
+	return false;
+      }
+#else
+    __gnu_cxx::stdio_filebuf<char> sbin(in.fd, std::ios::in);
+    __gnu_cxx::stdio_filebuf<char> sbout(out.fd, std::ios::out);
+    if ( !(std::ostream(&sbout) << &sbin) )
+      {
+	ec = std::make_error_code(std::errc::io_error);
+	return false;
+      }
+#endif
+
+#ifdef _GLIBCXX_USE_FCHMOD
+    if (::fchmod(out.fd, from_st->st_mode))
+#elif _GLIBCXX_USE_FCHMODAT
+    if (::fchmodat(AT_FDCWD, to.c_str(), from_st->st_mode, 0))
+#else
+    if (::chmod(to.c_str(), from_st->st_mode))
+#endif
+      {
+	ec.assign(errno, std::generic_category());
+	return false;
+      }
+    ec.clear();
+    return true;
+  }
+}
+#endif
+
+void
+fs::copy(const path& from, const path& to, copy_options options,
+	 error_code& ec) noexcept
+{
+  bool skip_symlinks = is_set(options, copy_options::skip_symlinks);
+  bool create_symlinks = is_set(options, copy_options::create_symlinks);
+  bool use_lstat = create_symlinks || skip_symlinks;
+
+  file_status f, t;
+  stat_type from_st, to_st;
+  if (use_lstat
+      ? ::lstat(from.c_str(), &from_st)
+      : ::stat(from.c_str(), &from_st))
+    {
+      ec.assign(errno, std::generic_category());
+      return;
+    }
+  if (use_lstat
+      ? ::lstat(to.c_str(), &to_st)
+      : ::stat(to.c_str(), &to_st))
+    {
+      if (!is_not_found_errno(errno))
+	{
+	  ec.assign(errno, std::generic_category());
+	  return;
+	}
+      t = file_status{file_type::not_found};
+    }
+  else
+    t = make_file_status(to_st);
+  f = make_file_status(from_st);
+
+  if (exists(t) && !is_other(t) && !is_other(f)
+      && to_st.st_dev == from_st.st_dev && to_st.st_ino == from_st.st_ino)
+    {
+      ec = std::make_error_code(std::errc::file_exists);
+      return;
+    }
+  if (is_other(f) || is_other(t))
+    {
+      ec = std::make_error_code(std::errc::not_supported);
+      return;
+    }
+  if (is_directory(f) && is_regular_file(t))
+    {
+      ec = std::make_error_code(std::errc::is_a_directory);
+      return;
+    }
+
+  if (is_symlink(f))
+    {
+      if (skip_symlinks)
+	ec.clear();
+      else if (!exists(t) && is_set(options, copy_options::copy_symlinks))
+	copy_symlink(from, to, ec);
+      else
+	// Not clear what should be done here.
+	// "Otherwise report an error as specified in Error reporting (7)."
+	ec = std::make_error_code(std::errc::invalid_argument);
+    }
+  else if (is_regular_file(f))
+    {
+      if (is_set(options, copy_options::directories_only))
+	ec.clear();
+      else if (create_symlinks)
+	create_symlink(from, to, ec);
+      else if (is_set(options, copy_options::create_hard_links))
+	create_hard_link(from, to, ec);
+      else if (is_directory(t))
+	do_copy_file(from, to / from.filename(), options, &from_st, 0, ec);
+      else
+	{
+	  auto ptr = exists(t) ? &to_st : &from_st;
+	  do_copy_file(from, to, options, &from_st, ptr,  ec);
+	}
+    }
+  else if (is_directory(f) && (is_set(options, copy_options::recursive)
+			       || options == copy_options::none))
+    {
+      if (!exists(t))
+	if (!create_directory(to, from, ec))
+	  return;
+      // set an unused bit in options to disable further recursion
+      if (!is_set(options, copy_options::recursive))
+	options |= static_cast<copy_options>(4096);
+      for (const directory_entry& x : directory_iterator(from))
+	copy(x.path(), to/x.path().filename(), options, ec);
+    }
+  // "Otherwise no effects." (should ec.clear() be called?)
+}
+
+bool
+fs::copy_file(const path& from, const path& to, copy_options option)
+{
+  error_code ec;
+  bool result = copy_file(from, to, option, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot copy file", from, to,
+	  ec));
+  return result;
+}
+
+bool
+fs::copy_file(const path& from, const path& to, copy_options option,
+	      error_code& ec) noexcept
+{
+#ifdef _GLIBCXX_HAVE_SYS_STAT_H
+  return do_copy_file(from, to, option, nullptr, nullptr, ec);
+#else
+  ec = std::make_error_code(std::errc::not_supported);
+  return false;
+#endif
+}
+
+
+void
+fs::copy_symlink(const path& existing_symlink, const path& new_symlink)
+{
+  error_code ec;
+  copy_symlink(existing_symlink, new_symlink, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot copy symlink",
+	  existing_symlink, new_symlink, ec));
+}
+
+void
+fs::copy_symlink(const path& existing_symlink, const path& new_symlink,
+		 error_code& ec) noexcept
+{
+  auto p = read_symlink(existing_symlink, ec);
+  if (ec.value())
+    return;
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+  if (is_directory(p))
+    {
+      create_directory_symlink(p, new_symlink, ec);
+      return;
+    }
+#endif
+  create_symlink(p, new_symlink, ec);
+}
+
+
+bool
+fs::create_directories(const path& p)
+{
+  error_code ec;
+  bool result = create_directories(p, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot create directories", p,
+	  ec));
+  return result;
+}
+
+bool
+fs::create_directories(const path& p, error_code& ec) noexcept
+{
+  std::stack<path> missing;
+  path pp = p;
+  ec.clear();
+  while (!p.empty() && !exists(pp, ec) && !ec.value())
+    {
+      missing.push(pp);
+      pp = pp.parent_path();
+    }
+  while (!missing.empty() && !ec.value())
+    {
+      create_directory(missing.top(), ec);
+      missing.pop();
+    }
+  return missing.empty();
+}
+
+namespace
+{
+  bool
+  create_dir(const fs::path& p, fs::perms perm, std::error_code& ec)
+  {
+#ifdef _GLIBCXX_HAVE_SYS_STAT_H
+    ::mode_t mode = static_cast<std::underlying_type_t<fs::perms>>(perm);
+    if (::mkdir(p.c_str(), mode))
+      {
+	ec.assign(errno, std::generic_category());
+	return false;
+      }
+    else
+      {
+	ec.clear();
+	return true;
+      }
+#else
+    ec = std::make_error_code(std::errc::not_supported);
+    return false;
+#endif
+  }
+} // namespace
+
+bool
+fs::create_directory(const path& p)
+{
+  error_code ec;
+  bool result = create_directory(p, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot create directory", p,
+	  ec));
+  return result;
+}
+
+bool
+fs::create_directory(const path& p, error_code& ec) noexcept
+{
+  return create_dir(p, perms::all, ec);
+}
+
+
+bool
+fs::create_directory(const path& p, const path& attributes)
+{
+  error_code ec;
+  bool result = create_directory(p, attributes, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot create directory", p,
+	  ec));
+  return result;
+}
+
+bool
+fs::create_directory(const path& p, const path& attributes,
+		     error_code& ec) noexcept
+{
+#ifdef _GLIBCXX_HAVE_SYS_STAT_H
+  stat_type st;
+  if (::stat(attributes.c_str(), &st))
+    {
+      ec.assign(errno, std::generic_category());
+      return false;
+    }
+  return create_dir(p, static_cast<perms>(st.st_mode), ec);
+#else
+  ec = std::make_error_code(std::errc::not_supported);
+  return false;
+#endif
+}
+
+
+void
+fs::create_directory_symlink(const path& to, const path& new_symlink)
+{
+  error_code ec;
+  create_directory_symlink(to, new_symlink, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot create directory symlink",
+	  to, new_symlink, ec));
+}
+
+void
+fs::create_directory_symlink(const path& to, const path& new_symlink,
+			     error_code& ec) noexcept
+{
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+  ec = std::make_error_code(std::errc::not_supported);
+#else
+  create_symlink(to, new_symlink, ec);
+#endif
+}
+
+
+void
+fs::create_hard_link(const path& to, const path& new_hard_link)
+{
+  error_code ec;
+  create_hard_link(to, new_hard_link, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot create hard link",
+	  to, new_hard_link, ec));
+}
+
+void
+fs::create_hard_link(const path& to, const path& new_hard_link,
+		     error_code& ec) noexcept
+{
+#ifdef _GLIBCXX_HAVE_UNISTD_H
+  if (::link(to.c_str(), new_hard_link.c_str()))
+    ec.assign(errno, std::generic_category());
+  else
+    ec.clear();
+#else
+  ec = std::make_error_code(std::errc::not_supported);
+#endif
+}
+
+void
+fs::create_symlink(const path& to, const path& new_symlink)
+{
+  error_code ec;
+  create_symlink(to, new_symlink, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot create symlink",
+	  to, new_symlink, ec));
+}
+
+void
+fs::create_symlink(const path& to, const path& new_symlink,
+		   error_code& ec) noexcept
+{
+#ifdef _GLIBCXX_HAVE_UNISTD_H
+  if (::symlink(to.c_str(), new_symlink.c_str()))
+    ec.assign(errno, std::generic_category());
+  else
+    ec.clear();
+#else
+  ec = std::make_error_code(std::errc::not_supported);
+#endif
+}
+
+
+fs::path
+fs::current_path()
+{
+  error_code ec;
+  path p = current_path(ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot get current path", ec));
+  return p;
+}
+
+fs::path
+fs::current_path(error_code& ec)
+{
+  path p;
+#ifdef _GLIBCXX_HAVE_UNISTD_H
+#ifdef __GLIBC__
+  if (char_ptr cwd = char_ptr{::getcwd(nullptr, 0)})
+    {
+      p.assign(cwd.get());
+      ec.clear();
+    }
+  else
+    ec.assign(errno, std::generic_category());
+#else
+  long path_max = pathconf(".", _PC_PATH_MAX);
+  size_t size;
+  if (path_max == -1)
+      size = 1024;
+  else if (path_max > 10240)
+      size = 10240;
+  else
+      size = path_max;
+  for (char_ptr buf; p.empty(); size *= 2)
+    {
+      buf.reset((char*)malloc(size));
+      if (buf)
+	{
+	  if (getcwd(buf.get(), size))
+	    {
+	      p.assign(buf.get());
+	      ec.clear();
+	    }
+	  else if (errno != ERANGE)
+	    {
+	      ec.assign(errno, std::generic_category());
+	      return {};
+	    }
+	}
+      else
+	{
+	  ec = std::make_error_code(std::errc::not_enough_memory);
+	  return {};
+	}
+    }
+#endif  // __GLIBC__
+#else   // _GLIBCXX_HAVE_UNISTD_H
+  ec = std::make_error_code(std::errc::not_supported);
+#endif
+  return p;
+}
+
+void
+fs::current_path(const path& p)
+{
+  error_code ec;
+  current_path(p, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot set current path", ec));
+}
+
+void
+fs::current_path(const path& p, error_code& ec) noexcept
+{
+#ifdef _GLIBCXX_HAVE_UNISTD_H
+  if (::chdir(p.c_str()))
+    ec.assign(errno, std::generic_category());
+  else
+    ec.clear();
+#else
+  ec = std::make_error_code(std::errc::not_supported);
+#endif
+}
+
+bool
+fs::equivalent(const path& p1, const path& p2)
+{
+  error_code ec;
+  auto result = equivalent(p1, p2, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot check file equivalence",
+	  p1, p2, ec));
+  return result;
+}
+
+bool
+fs::equivalent(const path& p1, const path& p2, error_code& ec) noexcept
+{
+#ifdef _GLIBCXX_HAVE_SYS_STAT_H
+  stat_type st1, st2;
+  if (::stat(p1.c_str(), &st1) == 0 && ::stat(p2.c_str(), &st2) == 0)
+    {
+      file_status s1 = make_file_status(st1);
+      file_status s2 = make_file_status(st2);
+      if (is_other(s1) && is_other(s2))
+	{
+	  ec = std::make_error_code(std::errc::not_supported);
+	  return false;
+	}
+      ec.clear();
+      return st1.st_dev == st2.st_dev && st1.st_ino == st2.st_ino;
+    }
+  else if (is_not_found_errno(errno))
+    {
+      ec = std::make_error_code(std::errc::no_such_file_or_directory);
+      return false;
+    }
+  ec.assign(errno, std::generic_category());
+#else
+  ec = std::make_error_code(std::errc::not_supported);
+#endif
+  return false;
+}
+
+std::uintmax_t
+fs::file_size(const path& p)
+{
+  error_code ec;
+  auto sz = file_size(p, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot get file size", p, ec));
+  return sz;
+}
+
+namespace
+{
+  template<typename Accessor, typename T>
+    inline T
+    do_stat(const fs::path& p, std::error_code& ec, Accessor f, T deflt)
+    {
+#ifdef _GLIBCXX_HAVE_SYS_STAT_H
+      stat_type st;
+      if (::stat(p.c_str(), &st))
+	{
+	  ec.assign(errno, std::generic_category());
+	  return deflt;
+	}
+      ec.clear();
+      return f(st);
+#else
+      ec = std::make_error_code(std::errc::not_supported);
+      return deflt;
+#endif
+    }
+}
+
+std::uintmax_t
+fs::file_size(const path& p, error_code& ec) noexcept
+{
+  struct S
+  {
+    S(const stat_type& st) : type(make_file_type(st)), size(st.st_size) { }
+    S() : type(file_type::not_found) { }
+    file_type type;
+    size_t size;
+  };
+  auto s = do_stat(p, ec, [](const auto& st) { return S{st}; }, S{});
+  if (s.type == file_type::regular)
+    return s.size;
+  if (!ec)
+    {
+      if (s.type == file_type::directory)
+	ec = std::make_error_code(std::errc::is_a_directory);
+      else
+	ec = std::make_error_code(std::errc::not_supported);
+    }
+  return -1;
+}
+
+std::uintmax_t
+fs::hard_link_count(const path& p)
+{
+  error_code ec;
+  auto count = hard_link_count(p, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot get link count", p, ec));
+  return count;
+}
+
+std::uintmax_t
+fs::hard_link_count(const path& p, error_code& ec) noexcept
+{
+  return do_stat(p, ec, std::mem_fn(&stat::st_nlink),
+		 static_cast<uintmax_t>(-1));
+}
+
+bool
+fs::is_empty(const path& p)
+{
+  return fs::is_directory(status(p))
+    ? fs::directory_iterator(p) == fs::directory_iterator()
+    : fs::file_size(p) == 0;
+}
+
+bool
+fs::is_empty(const path& p, error_code& ec) noexcept
+{
+  auto s = status(p, ec);
+  if (ec.value())
+    return false;
+  return fs::is_directory(s)
+    ? fs::directory_iterator(p, ec) == fs::directory_iterator()
+    : fs::file_size(p, ec) == 0;
+}
+
+fs::file_time_type
+fs::last_write_time(const path& p)
+{
+  error_code ec;
+  auto t = last_write_time(p, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot get file time", p, ec));
+  return t;
+}
+
+fs::file_time_type
+fs::last_write_time(const path& p, error_code& ec) noexcept
+{
+  return do_stat(p, ec, [](const auto& st) { return file_time(st); },
+		 file_time_type::min());
+}
+
+void
+fs::last_write_time(const path& p, file_time_type new_time)
+{
+  error_code ec;
+  last_write_time(p, new_time, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot set file time", p, ec));
+}
+
+void
+fs::last_write_time(const path& p __attribute__((__unused__)),
+		    file_time_type new_time, error_code& ec) noexcept
+{
+  auto d = new_time.time_since_epoch();
+  auto s = chrono::duration_cast<chrono::seconds>(d);
+#if _GLIBCXX_USE_UTIMENSAT
+  auto ns = chrono::duration_cast<chrono::nanoseconds>(d - s);
+  struct ::timespec ts[2];
+  ts[0].tv_sec = 0;
+  ts[0].tv_nsec = UTIME_OMIT;
+  ts[1].tv_sec = static_cast<std::time_t>(s.count());
+  ts[1].tv_nsec = static_cast<long>(ns.count());
+  if (::utimensat(AT_FDCWD, p.c_str(), ts, 0))
+    ec.assign(errno, std::generic_category());
+  else
+    ec.clear();
+#elif _GLIBCXX_HAVE_UTIME_H
+  ::utimbuf times;
+  times.modtime = s.count();
+  times.actime = do_stat(p, ec, [](const auto& st) { return st.st_atime; },
+			 times.modtime);
+  if (::utime(p.c_str(), &times))
+    ec.assign(errno, std::generic_category());
+  else
+    ec.clear();
+#else
+  ec = std::make_error_code(std::errc::not_supported);
+#endif
+}
+
+void
+fs::permissions(const path& p, perms prms)
+{
+  error_code ec;
+  permissions(p, prms, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot set permissions", p, ec));
+}
+
+void fs::permissions(const path& p, perms prms, error_code& ec) noexcept
+{
+#if _GLIBCXX_USE_FCHMODAT
+  if (::fchmodat(AT_FDCWD, p.c_str(), static_cast<mode_t>(prms), 0))
+#else
+  if (::chmod(p.c_str(), static_cast<mode_t>(prms)))
+#endif
+    ec.assign(errno, std::generic_category());
+  else
+    ec.clear();
+}
+
+fs::path
+fs::read_symlink(const path& p)
+{
+  error_code ec;
+  path tgt = read_symlink(p, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("read_symlink", p, ec));
+  return tgt;
+}
+
+fs::path fs::read_symlink(const path& p, error_code& ec)
+{
+#ifdef _GLIBCXX_HAVE_SYS_STAT_H
+  stat_type st;
+  if (::lstat(p.c_str(), &st))
+    {
+      ec.assign(errno, std::generic_category());
+      return {};
+    }
+  std::string buf(st.st_size, '\0');
+  ssize_t len = ::readlink(p.c_str(), &buf.front(), buf.size());
+  if (len == -1)
+    {
+      ec.assign(errno, std::generic_category());
+      return {};
+    }
+  return path{buf.data(), buf.data()+len};
+#else
+  ec = std::make_error_code(std::errc::not_supported);
+  return {};
+#endif
+}
+
+
+bool
+fs::remove(const path& p)
+{
+  error_code ec;
+  bool result = fs::remove(p, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot remove", p, ec));
+  return result;
+}
+
+bool
+fs::remove(const path& p, error_code& ec) noexcept
+{
+  if (exists(symlink_status(p, ec)))
+    {
+      if (::remove(p.c_str()) == 0)
+	{
+	  ec.clear();
+	  return true;
+	}
+      else
+	ec.assign(errno, std::generic_category());
+    }
+  return false;
+}
+
+
+std::uintmax_t
+fs::remove_all(const path& p)
+{
+  error_code ec;
+  bool result = remove_all(p, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot remove all", p, ec));
+  return result;
+}
+
+std::uintmax_t
+fs::remove_all(const path& p, error_code& ec) noexcept
+{
+  auto fs = symlink_status(p, ec);
+  uintmax_t count = 0;
+  if (ec.value() == 0 && fs.type() == file_type::directory)
+    for (directory_iterator d(p, ec), end; ec.value() == 0 && d != end; ++d)
+      count += fs::remove(d->path(), ec);
+  if (ec.value())
+    return -1;
+  return fs::remove(p, ec) ? ++count : -1;  // fs:remove() calls ec.clear()
+}
+
+void
+fs::rename(const path& from, const path& to)
+{
+  error_code ec;
+  rename(from, to, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot rename", from, to, ec));
+}
+
+void
+fs::rename(const path& from, const path& to, error_code& ec) noexcept
+{
+  if (::rename(from.c_str(), to.c_str()))
+    ec.assign(errno, std::generic_category());
+  else
+    ec.clear();
+}
+
+void
+fs::resize_file(const path& p, uintmax_t size)
+{
+  error_code ec;
+  resize_file(p, size, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot resize file", p, ec));
+}
+
+void
+fs::resize_file(const path& p, uintmax_t size, error_code& ec) noexcept
+{
+#ifdef _GLIBCXX_HAVE_UNISTD_H
+  if (size > static_cast<uintmax_t>(std::numeric_limits<off_t>::max()))
+    ec.assign(EINVAL, std::generic_category());
+  else if (::truncate(p.c_str(), size))
+    ec.assign(errno, std::generic_category());
+  else
+    ec.clear();
+#else
+  ec = std::make_error_code(std::errc::not_supported);
+#endif
+}
+
+
+fs::space_info
+fs::space(const path& p)
+{
+  error_code ec;
+  space_info s = space(p, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("cannot get free space", p, ec));
+  return s;
+}
+
+fs::space_info
+fs::space(const path& p, error_code& ec) noexcept
+{
+  space_info info = {
+    static_cast<uintmax_t>(-1),
+    static_cast<uintmax_t>(-1),
+    static_cast<uintmax_t>(-1)
+  };
+#ifdef _GLIBCXX_HAVE_SYS_STATVFS_H
+  struct ::statvfs f;
+  if (::statvfs(p.c_str(), &f))
+      ec.assign(errno, std::generic_category());
+  else
+    {
+      info = space_info{
+	f.f_blocks * f.f_frsize,
+	f.f_bfree * f.f_frsize,
+	f.f_bavail * f.f_frsize
+      };
+      ec.clear();
+    }
+#else
+  ec = std::make_error_code(std::errc::not_supported);
+#endif
+  return info;
+}
+
+#ifdef _GLIBCXX_HAVE_SYS_STAT_H
+fs::file_status
+fs::status(const fs::path& p, std::error_code& ec) noexcept
+{
+  file_status status;
+  stat_type st;
+  if (::stat(p.c_str(), &st))
+    {
+      int err = errno;
+      ec.assign(err, std::generic_category());
+      if (is_not_found_errno(err))
+	status.type(file_type::not_found);
+    }
+  else
+    {
+      status = make_file_status(st);
+      ec.clear();
+    }
+  return status;
+}
+
+fs::file_status
+fs::symlink_status(const fs::path& p, std::error_code& ec) noexcept
+{
+  file_status status;
+  stat_type st;
+  if (::lstat(p.c_str(), &st))
+    {
+      int err = errno;
+      ec.assign(err, std::generic_category());
+      if (is_not_found_errno(err))
+	status.type(file_type::not_found);
+    }
+  else
+    {
+      status = make_file_status(st);
+      ec.clear();
+    }
+  return status;
+}
+#endif
+
+fs::file_status
+fs::status(const fs::path& p)
+{
+  std::error_code ec;
+  auto result = status(p, ec);
+  if (result.type() == file_type::none)
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("status", p, ec));
+  return result;
+}
+
+fs::file_status
+fs::symlink_status(const fs::path& p)
+{
+  std::error_code ec;
+  auto result = symlink_status(p, ec);
+  if (result.type() == file_type::none)
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("symlink_status", p, ec));
+  return result;
+}
+
+fs::path
+fs::system_complete(const path& p)
+{
+  error_code ec;
+  path comp = system_complete(p, ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("system_complete", p, ec));
+  return comp;
+}
+
+fs::path
+fs::system_complete(const path& p, error_code& ec)
+{
+  path base = current_path(ec);
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+  if (p.is_absolute() || !p.has_root_name()
+      || p.root_name() == base.root_name())
+    return absolute(p, base);
+  // else TODO
+  ec = std::make_error_code(std::errc::not_supported);
+  return {};
+#else
+  if (ec.value())
+    return {};
+  return absolute(p, base);
+#endif
+}
+
+fs::path fs::temp_directory_path()
+{
+  error_code ec;
+  path tmp = temp_directory_path(ec);
+  if (ec.value())
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error("temp_directory_path", ec));
+  return tmp;
+}
+
+fs::path fs::temp_directory_path(error_code& ec)
+{
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+  ec = std::make_error_code(std::errc::not_supported);
+  return {}; // TODO
+#else
+  const char* tmpdir = nullptr;
+  const char* env[] = { "TMPDIR", "TMP", "TEMP", "TEMPDIR", nullptr };
+  for (auto e = env; tmpdir == nullptr && *e != nullptr; ++e)
+    tmpdir = ::getenv(*e);
+  path p = tmpdir ? tmpdir : "/tmp";
+  if (exists(p) && is_directory(p))
+    {
+      ec.clear();
+      return p;
+    }
+  ec = std::make_error_code(std::errc::not_a_directory);
+  return {};
+#endif
+}
+
Index: libstdc++-v3/src/filesystem/Makefile.am
===================================================================
--- libstdc++-v3/src/filesystem/Makefile.am	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/src/filesystem/Makefile.am	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,100 @@
+## Makefile for the GNU C++ Filesystem library.
+##
+## Copyright (C) 2014-2015 Free Software Foundation, Inc.
+##
+## Process this file with automake to produce Makefile.in.
+##
+## This file is part of GCC.
+##
+## GCC is free software; you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 3, or (at your option)
+## any later version.
+##
+## GCC is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with GCC; see the file COPYING3.  If not see
+## <http://www.gnu.org/licenses/>.
+
+include $(top_srcdir)/fragment.am
+
+toolexeclib_LTLIBRARIES = libstdc++fs.la
+
+headers =
+
+sources = \
+	dir.cc \
+	ops.cc \
+	path.cc
+
+# vpath % $(top_srcdir)/src/filesystem
+
+libstdc__fs_la_SOURCES = $(sources)
+
+# AM_CXXFLAGS needs to be in each subdirectory so that it can be
+# modified in a per-library or per-sub-library way.  Need to manually
+# set this option because CONFIG_CXXFLAGS has to be after
+# OPTIMIZE_CXXFLAGS on the compile line so that -O2 can be overridden
+# as the occasion call for it.
+AM_CXXFLAGS = \
+	$(glibcxx_lt_pic_flag) $(glibcxx_compiler_shared_flag) \
+	-std=gnu++14 \
+	$(WARN_CXXFLAGS) $(OPTIMIZE_CXXFLAGS)  $(CONFIG_CXXFLAGS)
+
+AM_MAKEFLAGS = \
+	"gxx_include_dir=$(gxx_include_dir)"
+
+
+# Libtool notes
+
+# 1) In general, libtool expects an argument such as `--tag=CXX' when
+# using the C++ compiler, because that will enable the settings
+# detected when C++ support was being configured.  However, when no
+# such flag is given in the command line, libtool attempts to figure
+# it out by matching the compiler name in each configuration section
+# against a prefix of the command line.  The problem is that, if the
+# compiler name and its initial flags stored in the libtool
+# configuration file don't match those in the command line, libtool
+# can't decide which configuration to use, and it gives up.  The
+# correct solution is to add `--tag CXX' to LTCXXCOMPILE and maybe
+# CXXLINK, just after $(LIBTOOL), so that libtool doesn't have to
+# attempt to infer which configuration to use.
+# 
+# The second tag argument, `--tag disable-shared` means that libtool
+# only compiles each source once, for static objects. In actuality,
+# glibcxx_lt_pic_flag and glibcxx_compiler_shared_flag are added to
+# the libtool command that is used create the object, which is
+# suitable for shared libraries.  The `--tag disable-shared` must be
+# placed after --tag CXX lest things CXX undo the affect of
+# disable-shared.
+
+# 2) Need to explicitly set LTCXXCOMPILE so that EXTRA_CXX_FLAGS is
+# last. (That way, things like -O2 passed down from the toplevel can
+# be overridden by --enable-debug.)
+LTCXXCOMPILE = \
+	$(LIBTOOL) --tag CXX --tag disable-shared \
+	$(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=compile $(CXX) $(TOPLEVEL_INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) $(EXTRA_CXX_FLAGS)
+
+LTLDFLAGS = $(shell $(SHELL) $(top_srcdir)/../libtool-ldflags $(LDFLAGS))
+
+# 3) We'd have a problem when building the shared libstdc++ object if
+# the rules automake generates would be used.  We cannot allow g++ to
+# be used since this would add -lstdc++ to the link line which of
+# course is problematic at this point.  So, we get the top-level
+# directory to configure libstdc++-v3 to use gcc as the C++
+# compilation driver.
+CXXLINK = \
+	$(LIBTOOL) --tag CXX --tag disable-shared \
+	$(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=link $(CXX) \
+	$(OPT_LDFLAGS) $(SECTION_LDFLAGS) $(AM_CXXFLAGS) $(LTLDFLAGS) -o $@
+
+# By adding these files here, automake will remove them for 'make clean'
+CLEANFILES = stamp-*
+
Index: libstdc++-v3/src/Makefile.am
===================================================================
--- libstdc++-v3/src/Makefile.am	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/src/Makefile.am	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -22,8 +22,14 @@
 
 include $(top_srcdir)/fragment.am
 
-SUBDIRS = c++98 c++11
+if ENABLE_FILESYSTEM_TS
+filesystem_dir = filesystem
+else
+filesystem_dir =
+endif
 
+SUBDIRS = c++98 c++11 $(filesystem_dir)
+
 # Cross compiler support.
 if VTV_CYGMIN
 toolexeclib_LTLIBRARIES = libvtv.la libstdc++.la
@@ -52,6 +58,9 @@
 
 vpath % $(top_srcdir)/src/c++98
 vpath % $(top_srcdir)/src/c++11
+if ENABLE_FILESYSTEM_TS
+vpath % $(top_srcdir)/src/filesystem
+endif
 
 if GLIBCXX_LDBL_COMPAT
 ldbl_compat_sources = compatibility-ldbl.cc
Index: libstdc++-v3/src/c++98/Makefile.in
===================================================================
--- libstdc++-v3/src/c++98/Makefile.in	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/src/c++98/Makefile.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11.1 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -99,6 +116,11 @@
 	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
 CXXLD = $(CXX)
 SOURCES = $(libc__98convenience_la_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 ABI_TWEAKS_SRCDIR = @ABI_TWEAKS_SRCDIR@
@@ -501,6 +523,7 @@
 	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
 	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
 	esac;
+$(top_srcdir)/fragment.am:
 
 $(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
 	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
@@ -519,7 +542,7 @@
 	  echo "rm -f \"$${dir}/so_locations\""; \
 	  rm -f "$${dir}/so_locations"; \
 	done
-libc++98convenience.la: $(libc__98convenience_la_OBJECTS) $(libc__98convenience_la_DEPENDENCIES) 
+libc++98convenience.la: $(libc__98convenience_la_OBJECTS) $(libc__98convenience_la_DEPENDENCIES) $(EXTRA_libc__98convenience_la_DEPENDENCIES) 
 	$(CXXLINK)  $(libc__98convenience_la_OBJECTS) $(libc__98convenience_la_LIBADD) $(LIBS)
 
 mostlyclean-compile:
@@ -608,10 +631,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:
Index: libstdc++-v3/src/c++11/Makefile.in
===================================================================
--- libstdc++-v3/src/c++11/Makefile.in	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/src/c++11/Makefile.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11.1 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -98,6 +115,11 @@
 	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
 CXXLD = $(CXX)
 SOURCES = $(libc__11convenience_la_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 ABI_TWEAKS_SRCDIR = @ABI_TWEAKS_SRCDIR@
@@ -485,6 +507,7 @@
 	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
 	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
 	esac;
+$(top_srcdir)/fragment.am:
 
 $(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
 	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
@@ -503,7 +526,7 @@
 	  echo "rm -f \"$${dir}/so_locations\""; \
 	  rm -f "$${dir}/so_locations"; \
 	done
-libc++11convenience.la: $(libc__11convenience_la_OBJECTS) $(libc__11convenience_la_DEPENDENCIES) 
+libc++11convenience.la: $(libc__11convenience_la_OBJECTS) $(libc__11convenience_la_DEPENDENCIES) $(EXTRA_libc__11convenience_la_DEPENDENCIES) 
 	$(CXXLINK)  $(libc__11convenience_la_OBJECTS) $(libc__11convenience_la_LIBADD) $(LIBS)
 
 mostlyclean-compile:
@@ -592,10 +615,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:
Index: libstdc++-v3/src/c++11/codecvt.cc
===================================================================
--- libstdc++-v3/src/c++11/codecvt.cc	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/src/c++11/codecvt.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1264,7 +1264,11 @@
 {
   range<const char> from{ __from, __from_end };
   range<char16_t> to{ __to, __to_end };
-  auto res = utf16_in(from, to, _M_maxcode, _M_mode);
+  codecvt_mode mode = codecvt_mode(_M_mode | (consume_header|generate_header));
+#if __BYTE_ORDER__ != __ORDER_BIG_ENDIAN__
+  mode = codecvt_mode(mode | little_endian);
+#endif
+  auto res = utf16_in(from, to, _M_maxcode, mode);
   __from_next = from.next;
   __to_next = to.next;
   return res;
Index: libstdc++-v3/configure.ac
===================================================================
--- libstdc++-v3/configure.ac	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/configure.ac	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -402,6 +402,11 @@
 # For gthread support.  Depends on GLIBCXX_ENABLE_SYMVERS.
 GLIBCXX_CHECK_GTHREADS
 
+# For Filesystem TS.
+AC_CHECK_HEADERS([fcntl.h dirent.h sys/statvfs.h utime.h])
+GLIBCXX_ENABLE_FILESYSTEM_TS
+GLIBCXX_CHECK_FILESYSTEM_DEPS
+
 # Define documentation rules conditionally.
 
 # See if makeinfo has been installed and is modern enough
Index: libstdc++-v3/doc/Makefile.in
===================================================================
--- libstdc++-v3/doc/Makefile.in	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/doc/Makefile.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11.1 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -15,6 +15,23 @@
 
 @SET_MAKE@
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 depcomp =
 am__depfiles_maybe =
 SOURCES =
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ABI_TWEAKS_SRCDIR = @ABI_TWEAKS_SRCDIR@
 ACLOCAL = @ACLOCAL@
 ALLOCATOR_H = @ALLOCATOR_H@
@@ -604,6 +626,7 @@
 	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
 	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
 	esac;
+$(top_srcdir)/fragment.am:
 
 $(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
 	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
@@ -639,10 +662,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:
Index: libstdc++-v3/po/Makefile.in
===================================================================
--- libstdc++-v3/po/Makefile.in	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/po/Makefile.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11.1 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -15,6 +15,23 @@
 
 @SET_MAKE@
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 depcomp =
 am__depfiles_maybe =
 SOURCES =
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ABI_TWEAKS_SRCDIR = @ABI_TWEAKS_SRCDIR@
 ACLOCAL = @ACLOCAL@
 ALLOCATOR_H = @ALLOCATOR_H@
@@ -330,6 +352,7 @@
 	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
 	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
 	esac;
+$(top_srcdir)/fragment.am:
 
 $(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
 	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
@@ -365,10 +388,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:
Index: libstdc++-v3/include/Makefile.in
===================================================================
--- libstdc++-v3/include/Makefile.in	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/include/Makefile.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11.1 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -15,6 +15,23 @@
 
 @SET_MAKE@
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 depcomp =
 am__depfiles_maybe =
 SOURCES =
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ABI_TWEAKS_SRCDIR = @ABI_TWEAKS_SRCDIR@
 ACLOCAL = @ACLOCAL@
 ALLOCATOR_H = @ALLOCATOR_H@
@@ -396,6 +418,7 @@
 	${bits_srcdir}/postypes.h \
 	${bits_srcdir}/predefined_ops.h \
 	${bits_srcdir}/ptr_traits.h \
+	${bits_srcdir}/quoted_string.h \
 	${bits_srcdir}/random.h \
 	${bits_srcdir}/random.tcc \
 	${bits_srcdir}/range_access.h \
@@ -917,12 +940,21 @@
 	${experimental_srcdir}/optional \
 	${experimental_srcdir}/ratio \
 	${experimental_srcdir}/string_view \
+	${experimental_srcdir}/string_view.tcc \
 	${experimental_srcdir}/system_error \
-	${experimental_srcdir}/string_view.tcc \
 	${experimental_srcdir}/tuple \
-	${experimental_srcdir}/type_traits
+	${experimental_srcdir}/type_traits \
+	${experimental_filesystem_headers}
 
+@ENABLE_FILESYSTEM_TS_FALSE@experimental_filesystem_headers = 
+@ENABLE_FILESYSTEM_TS_TRUE@experimental_filesystem_headers = \
+@ENABLE_FILESYSTEM_TS_TRUE@	${experimental_srcdir}/filesystem \
+@ENABLE_FILESYSTEM_TS_TRUE@	${experimental_srcdir}/fs_dir.h \
+@ENABLE_FILESYSTEM_TS_TRUE@	${experimental_srcdir}/fs_fwd.h \
+@ENABLE_FILESYSTEM_TS_TRUE@	${experimental_srcdir}/fs_ops.h \
+@ENABLE_FILESYSTEM_TS_TRUE@	${experimental_srcdir}/fs_path.h
 
+
 # This is the common subset of C++ files that all three "C" header models use.
 c_base_srcdir = $(C_INCLUDE_DIR)
 c_base_builddir = .
@@ -1232,6 +1264,7 @@
 	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
 	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
 	esac;
+$(top_srcdir)/fragment.am:
 
 $(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
 	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
@@ -1267,10 +1300,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:
Index: libstdc++-v3/include/std/shared_mutex
===================================================================
--- libstdc++-v3/include/std/shared_mutex	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/include/std/shared_mutex	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -74,7 +74,7 @@
     {
       int __ret = pthread_rwlock_init(&_M_rwlock, NULL);
       if (__ret == ENOMEM)
-	throw bad_alloc();
+	__throw_bad_alloc();
       else if (__ret == EAGAIN)
 	__throw_system_error(int(errc::resource_unavailable_try_again));
       else if (__ret == EPERM)
Index: libstdc++-v3/include/std/iomanip
===================================================================
--- libstdc++-v3/include/std/iomanip	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/include/std/iomanip	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -42,7 +42,7 @@
 #if __cplusplus >= 201103L
 #include <locale>
 #if __cplusplus > 201103L
-#include <sstream> // used in quoted.
+#include <bits/quoted_string.h>
 #endif
 #endif
 
@@ -450,127 +450,6 @@
 
 #define __cpp_lib_quoted_string_io 201304
 
-_GLIBCXX_END_NAMESPACE_VERSION
-  namespace __detail {
-  _GLIBCXX_BEGIN_NAMESPACE_VERSION
-
-    /**
-     * @brief Struct for delimited strings.
-     */
-    template<typename _String, typename _CharT>
-      struct _Quoted_string
-      {
-	static_assert(is_reference<_String>::value
-		   || is_pointer<_String>::value,
-		      "String type must be pointer or reference");
-
-	_Quoted_string(_String __str, _CharT __del, _CharT __esc)
-	: _M_string(__str), _M_delim{__del}, _M_escape{__esc}
-	{ }
-
-	_Quoted_string&
-	operator=(_Quoted_string&) = delete;
-
-	_String _M_string;
-	_CharT _M_delim;
-	_CharT _M_escape;
-      };
-
-    /**
-     * @brief Inserter for quoted strings.
-     *
-     *  _GLIBCXX_RESOLVE_LIB_DEFECTS
-     *  DR 2344 quoted()'s interaction with padding is unclear
-     */
-    template<typename _CharT, typename _Traits>
-      auto&
-      operator<<(std::basic_ostream<_CharT, _Traits>& __os,
-		 const _Quoted_string<const _CharT*, _CharT>& __str)
-      {
-	std::basic_ostringstream<_CharT, _Traits> __ostr;
-	__ostr << __str._M_delim;
-	for (const _CharT* __c = __str._M_string; *__c; ++__c)
-	  {
-	    if (*__c == __str._M_delim || *__c == __str._M_escape)
-	      __ostr << __str._M_escape;
-	    __ostr << *__c;
-	  }
-	__ostr << __str._M_delim;
-
-	return __os << __ostr.str();
-      }
-
-    /**
-     * @brief Inserter for quoted strings.
-     *
-     *  _GLIBCXX_RESOLVE_LIB_DEFECTS
-     *  DR 2344 quoted()'s interaction with padding is unclear
-     */
-    template<typename _CharT, typename _Traits, typename _String>
-      auto&
-      operator<<(std::basic_ostream<_CharT, _Traits>& __os,
-		 const _Quoted_string<_String, _CharT>& __str)
-      {
-	std::basic_ostringstream<_CharT, _Traits> __ostr;
-	__ostr << __str._M_delim;
-	for (auto& __c : __str._M_string)
-	  {
-	    if (__c == __str._M_delim || __c == __str._M_escape)
-	      __ostr << __str._M_escape;
-	    __ostr << __c;
-	  }
-	__ostr << __str._M_delim;
-
-	return __os << __ostr.str();
-      }
-
-    /**
-     * @brief Extractor for delimited strings.
-     *        The left and right delimiters can be different.
-     */
-    template<typename _CharT, typename _Traits, typename _Alloc>
-      auto&
-      operator>>(std::basic_istream<_CharT, _Traits>& __is,
-		 const _Quoted_string<basic_string<_CharT, _Traits, _Alloc>&,
-				      _CharT>& __str)
-      {
-	_CharT __c;
-	__is >> __c;
-	if (!__is.good())
-	  return __is;
-	if (__c != __str._M_delim)
-	  {
-	    __is.unget();
-	    __is >> __str._M_string;
-	    return __is;
-	  }
-	__str._M_string.clear();
-	std::ios_base::fmtflags __flags
-	  = __is.flags(__is.flags() & ~std::ios_base::skipws);
-	do
-	  {
-	    __is >> __c;
-	    if (!__is.good())
-	      break;
-	    if (__c == __str._M_escape)
-	      {
-		__is >> __c;
-		if (!__is.good())
-		  break;
-	      }
-	    else if (__c == __str._M_delim)
-	      break;
-	    __str._M_string += __c;
-	  }
-	while (true);
-	__is.setf(__flags);
-
-	return __is;
-      }
-  _GLIBCXX_END_NAMESPACE_VERSION
-  } // namespace __detail
-_GLIBCXX_BEGIN_NAMESPACE_VERSION
-
   /**
    * @brief Manipulator for quoted strings.
    * @param __string String to quote.
Index: libstdc++-v3/include/experimental/fs_ops.h
===================================================================
--- libstdc++-v3/include/experimental/fs_ops.h	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/include/experimental/fs_ops.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,291 @@
+// Filesystem operational functions -*- C++ -*-
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your __option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// Under Section 7 of GPL version 3, you are granted additional
+// permissions described in the GCC Runtime Library Exception, version
+// 3.1, as published by the Free Software Foundation.
+
+// You should have received a copy of the GNU General Public License and
+// a copy of the GCC Runtime Library Exception along with this program;
+// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
+// <http://www.gnu.org/licenses/>.
+
+/** @file experimental/filesystem
+ *  This is a TS C++ Library header.
+ */
+
+#ifndef _GLIBCXX_EXPERIMENTAL_FS_OPS_H
+#define _GLIBCXX_EXPERIMENTAL_FS_OPS_H 1
+
+#if __cplusplus < 201103L
+# include <bits/c++0x_warning.h>
+#else
+
+#include <cstdint>
+
+namespace std _GLIBCXX_VISIBILITY(default)
+{
+namespace experimental
+{
+namespace filesystem
+{
+inline namespace v1
+{
+_GLIBCXX_BEGIN_NAMESPACE_VERSION
+
+  /**
+   * @ingroup filesystem
+   * @{
+   */
+
+  path absolute(const path& __p, const path& __base = current_path());
+
+  path canonical(const path& __p, const path& __base = current_path());
+  path canonical(const path& __p, error_code& __ec);
+  path canonical(const path& __p, const path& __base, error_code& __ec);
+
+  inline void
+  copy(const path& __from, const path& __to)
+  { copy(__from, __to, copy_options::none); }
+
+  inline void
+  copy(const path& __from, const path& __to, error_code& __ec) noexcept
+  { copy(__from, __to, copy_options::none, __ec); }
+
+  void copy(const path& __from, const path& __to, copy_options __options);
+  void copy(const path& __from, const path& __to, copy_options __options,
+	    error_code& __ec) noexcept;
+
+  inline bool
+  copy_file(const path& __from, const path& __to)
+  { return copy_file(__from, __to, copy_options::none); }
+
+  inline bool
+  copy_file(const path& __from, const path& __to, error_code& __ec) noexcept
+  { return copy_file(__from, __to, copy_options::none, __ec); }
+
+  bool copy_file(const path& __from, const path& __to, copy_options __option);
+  bool copy_file(const path& __from, const path& __to, copy_options __option,
+		 error_code& __ec) noexcept;
+
+  void copy_symlink(const path& __existing_symlink, const path& __new_symlink);
+  void copy_symlink(const path& __existing_symlink, const path& __new_symlink,
+		    error_code& __ec) noexcept;
+
+  bool create_directories(const path& __p);
+  bool create_directories(const path& __p, error_code& __ec) noexcept;
+
+  bool create_directory(const path& __p);
+  bool create_directory(const path& __p, error_code& __ec) noexcept;
+
+  bool create_directory(const path& __p, const path& attributes);
+  bool create_directory(const path& __p, const path& attributes,
+			error_code& __ec) noexcept;
+
+  void create_directory_symlink(const path& __to, const path& __new_symlink);
+  void create_directory_symlink(const path& __to, const path& __new_symlink,
+				error_code& __ec) noexcept;
+
+  void create_hard_link(const path& __to, const path& __new_hard_link);
+  void create_hard_link(const path& __to, const path& __new_hard_link,
+			error_code& __ec) noexcept;
+
+  void create_symlink(const path& __to, const path& __new_symlink);
+  void create_symlink(const path& __to, const path& __new_symlink,
+		      error_code& __ec) noexcept;
+
+  path current_path();
+  path current_path(error_code& __ec);
+  void current_path(const path& __p);
+  void current_path(const path& __p, error_code& __ec) noexcept;
+
+  inline bool
+  exists(file_status __s) noexcept
+  { return status_known(__s) && __s.type() != file_type::not_found; }
+
+  inline bool
+  exists(const path& __p)
+  { return exists(status(__p)); }
+
+  inline bool
+  exists(const path& __p, error_code& __ec) noexcept
+  { return exists(status(__p, __ec)); }
+
+  bool
+  equivalent(const path& __p1, const path& __p2);
+
+  bool
+  equivalent(const path& __p1, const path& __p2, error_code& __ec) noexcept;
+
+  uintmax_t file_size(const path& __p);
+  uintmax_t file_size(const path& __p, error_code& __ec) noexcept;
+
+  uintmax_t hard_link_count(const path& __p);
+  uintmax_t hard_link_count(const path& __p, error_code& __ec) noexcept;
+
+  inline bool
+  is_block_file(file_status __s) noexcept
+  { return __s.type() == file_type::block; }
+
+  inline bool
+  is_block_file(const path& __p)
+  { return is_block_file(status(__p)); }
+
+  inline bool
+  is_block_file(const path& __p, error_code& __ec) noexcept
+  { return is_block_file(status(__p, __ec)); }
+
+  inline bool
+  is_character_file(file_status __s) noexcept
+  { return __s.type() == file_type::character; }
+
+  inline bool
+  is_character_file(const path& __p)
+  { return is_character_file(status(__p)); }
+
+  inline bool
+  is_character_file(const path& __p, error_code& __ec) noexcept
+  { return is_character_file(status(__p, __ec)); }
+
+  inline bool
+  is_directory(file_status __s) noexcept
+  { return __s.type() == file_type::directory; }
+
+  inline bool
+  is_directory(const path& __p)
+  { return is_directory(status(__p)); }
+
+  inline bool
+  is_directory(const path& __p, error_code& __ec) noexcept
+  { return is_directory(status(__p, __ec)); }
+
+  bool is_empty(const path& __p);
+  bool is_empty(const path& __p, error_code& __ec) noexcept;
+
+  inline bool
+  is_fifo(file_status __s) noexcept
+  { return __s.type() == file_type::fifo; }
+
+  inline bool
+  is_fifo(const path& __p)
+  { return is_fifo(status(__p)); }
+
+  inline bool
+  is_fifo(const path& __p, error_code& __ec) noexcept
+  { return is_fifo(status(__p, __ec)); }
+
+  inline bool
+  is_other(file_status __s) noexcept
+  {
+    return exists(__s) && !is_regular_file(__s) && !is_directory(__s)
+      && !is_symlink(__s);
+  }
+
+  inline bool
+  is_other(const path& __p)
+  { return is_other(status(__p)); }
+
+  inline bool
+  is_other(const path& __p, error_code& __ec) noexcept
+  { return is_other(status(__p, __ec)); }
+
+  inline bool
+  is_regular_file(file_status __s) noexcept
+  { return __s.type() == file_type::regular; }
+
+  inline bool
+  is_regular_file(const path& __p)
+  { return is_regular_file(status(__p)); }
+
+  inline bool
+  is_regular_file(const path& __p, error_code& __ec) noexcept
+  { return is_regular_file(status(__p, __ec)); }
+
+  inline bool
+  is_socket(file_status __s) noexcept
+  { return __s.type() == file_type::socket; }
+
+  inline bool
+  is_socket(const path& __p)
+  { return is_socket(status(__p)); }
+
+  inline bool
+  is_socket(const path& __p, error_code& __ec) noexcept
+  { return is_socket(status(__p, __ec)); }
+
+  inline bool
+  is_symlink(file_status __s) noexcept
+  { return __s.type() == file_type::symlink; }
+
+  inline bool
+  is_symlink(const path& __p)
+  { return is_symlink(symlink_status(__p)); }
+
+  inline bool
+  is_symlink(const path& __p, error_code& __ec) noexcept
+  { return is_symlink(symlink_status(__p, __ec)); }
+
+  file_time_type  last_write_time(const path& __p);
+  file_time_type  last_write_time(const path& __p, error_code& __ec) noexcept;
+  void last_write_time(const path& __p, file_time_type __new_time);
+  void last_write_time(const path& __p, file_time_type __new_time,
+		       error_code& __ec) noexcept;
+
+  void permissions(const path& __p, perms __prms);
+  void permissions(const path& __p, perms __prms, error_code& __ec) noexcept;
+
+  path read_symlink(const path& __p);
+  path read_symlink(const path& __p, error_code& __ec);
+
+  bool remove(const path& __p);
+  bool remove(const path& __p, error_code& __ec) noexcept;
+
+  uintmax_t remove_all(const path& __p);
+  uintmax_t remove_all(const path& __p, error_code& __ec) noexcept;
+
+  void rename(const path& __from, const path& __to);
+  void rename(const path& __from, const path& __to, error_code& __ec) noexcept;
+
+  void resize_file(const path& __p, uintmax_t __size);
+  void resize_file(const path& __p, uintmax_t __size, error_code& __ec) noexcept;
+
+  space_info space(const path& __p);
+  space_info space(const path& __p, error_code& __ec) noexcept;
+
+  file_status status(const path& __p);
+  file_status status(const path& __p, error_code& __ec) noexcept;
+
+  inline bool status_known(file_status __s) noexcept
+  { return __s.type() != file_type::none; }
+
+  file_status symlink_status(const path& __p);
+  file_status symlink_status(const path& __p, error_code& __ec) noexcept;
+
+  path system_complete(const path& __p);
+  path system_complete(const path& __p, error_code& __ec);
+
+  path temp_directory_path();
+  path temp_directory_path(error_code& __ec);
+
+  // @} group filesystem
+_GLIBCXX_END_NAMESPACE_VERSION
+} // namespace v1
+} // namespace filesystem
+} // namespace experimental
+} // namespace std
+
+#endif // C++11
+
+#endif // _GLIBCXX_EXPERIMENTAL_FS_OPS_H
Index: libstdc++-v3/include/experimental/filesystem
===================================================================
--- libstdc++-v3/include/experimental/filesystem	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/include/experimental/filesystem	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,77 @@
+// <experimental/filesystem> -*- C++ -*-
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// Under Section 7 of GPL version 3, you are granted additional
+// permissions described in the GCC Runtime Library Exception, version
+// 3.1, as published by the Free Software Foundation.
+
+// You should have received a copy of the GNU General Public License and
+// a copy of the GCC Runtime Library Exception along with this program;
+// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
+// <http://www.gnu.org/licenses/>.
+
+/** @file experimental/filesystem
+ *  This is a TS C++ Library header.
+ */
+
+#ifndef _GLIBCXX_EXPERIMENTAL_FILESYSTEM
+#define _GLIBCXX_EXPERIMENTAL_FILESYSTEM 1
+
+#pragma GCC system_header
+
+#if __cplusplus < 201103L
+# include <bits/c++0x_warning.h>
+#else
+
+#include <experimental/fs_fwd.h>
+#include <experimental/fs_path.h>
+#include <experimental/fs_dir.h>
+#include <experimental/fs_ops.h>
+
+#define __cpp_lib_experimental_filesystem 201406
+
+namespace std _GLIBCXX_VISIBILITY(default)
+{
+namespace experimental
+{
+namespace filesystem
+{
+inline namespace v1
+{
+_GLIBCXX_BEGIN_NAMESPACE_VERSION
+
+  /**
+   * @ingroup filesystem
+   */
+    inline std::string filesystem_error::_M_gen_what()
+    {
+      std::string __what = "filesystem error: ";
+      __what += system_error::what();
+      if (!_M_path1.empty())
+	  __what += " [" + _M_path1.string() + ']';
+      if (!_M_path2.empty())
+	  __what += " [" + _M_path2.string() + ']';
+      return __what;
+    }
+
+_GLIBCXX_END_NAMESPACE_VERSION
+} // namespace v1
+} // namespace filesystem
+} // namespace experimental
+} // namespace std
+
+#endif // C++11
+
+#endif // _GLIBCXX_EXPERIMENTAL_FILESYSTEM
Index: libstdc++-v3/include/experimental/fs_dir.h
===================================================================
--- libstdc++-v3/include/experimental/fs_dir.h	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/include/experimental/fs_dir.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,326 @@
+// Filesystem directory utilities -*- C++ -*-
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// Under Section 7 of GPL version 3, you are granted additional
+// permissions described in the GCC Runtime Library Exception, version
+// 3.1, as published by the Free Software Foundation.
+
+// You should have received a copy of the GNU General Public License and
+// a copy of the GCC Runtime Library Exception along with this program;
+// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
+// <http://www.gnu.org/licenses/>.
+
+/** @file experimental/fs_dir.h
+ *  This is an internal header file, included by other library headers.
+ *  Do not attempt to use it directly. @headername{experimental/filesystem}
+ */
+
+#ifndef _GLIBCXX_EXPERIMENTAL_FS_DIR_H
+#define _GLIBCXX_EXPERIMENTAL_FS_DIR_H 1
+
+#if __cplusplus < 201103L
+# include <bits/c++0x_warning.h>
+#else
+# include <typeinfo>
+# include <ext/concurrence.h>
+# include <bits/unique_ptr.h>
+# include <bits/shared_ptr.h>
+
+namespace std _GLIBCXX_VISIBILITY(default)
+{
+namespace experimental
+{
+namespace filesystem
+{
+inline namespace v1
+{
+_GLIBCXX_BEGIN_NAMESPACE_VERSION
+
+  /**
+   * @ingroup filesystem
+   * @{
+   */
+
+  class file_status
+  {
+  public:
+    // constructors
+    explicit
+    file_status(file_type __ft = file_type::none,
+	        perms __prms = perms::unknown) noexcept
+    : _M_type(__ft), _M_perms(__prms) { }
+
+    file_status(const file_status&) noexcept = default;
+    file_status(file_status&&) noexcept = default;
+    ~file_status() = default;
+
+    file_status& operator=(const file_status&) noexcept = default;
+    file_status& operator=(file_status&&) noexcept = default;
+
+    // observers
+    file_type  type() const noexcept { return _M_type; }
+    perms      permissions() const noexcept { return _M_perms; }
+
+    // modifiers
+    void       type(file_type __ft) noexcept { _M_type = __ft; }
+    void       permissions(perms __prms) noexcept { _M_perms = __prms; }
+
+  private:
+    file_type	_M_type;
+    perms	_M_perms;
+  };
+
+_GLIBCXX_BEGIN_NAMESPACE_CXX11
+
+  class directory_entry
+  {
+  public:
+    // constructors and destructor
+    directory_entry() noexcept = default;
+    directory_entry(const directory_entry&) = default;
+    directory_entry(directory_entry&&) noexcept = default;
+    explicit directory_entry(const filesystem::path& __p) : _M_path(__p) { }
+    ~directory_entry() = default;
+
+    // modifiers
+    directory_entry& operator=(const directory_entry&) = default;
+    directory_entry& operator=(directory_entry&&) noexcept = default;
+
+    void assign(const filesystem::path& __p) { _M_path = __p; }
+
+    void
+    replace_filename(const filesystem::path& __p)
+    { _M_path = _M_path.parent_path() / __p; }
+
+    // observers
+    const filesystem::path&  path() const noexcept { return _M_path; }
+    operator const filesystem::path&() const noexcept { return _M_path; }
+
+    file_status
+    status() const
+    { return filesystem::status(_M_path); }
+
+    file_status
+    status(error_code& __ec) const noexcept
+    { return filesystem::status(_M_path, __ec); }
+
+    file_status
+    symlink_status() const
+    { return filesystem::symlink_status(_M_path); }
+
+    file_status
+    symlink_status(error_code& __ec) const noexcept
+    { return filesystem::symlink_status(_M_path, __ec); }
+
+    bool
+    operator< (const directory_entry& __rhs) const noexcept
+    { return _M_path < __rhs._M_path; }
+
+    bool
+    operator==(const directory_entry& __rhs) const noexcept
+    { return _M_path == __rhs._M_path; }
+
+    bool
+    operator!=(const directory_entry& __rhs) const noexcept
+    { return _M_path != __rhs._M_path; }
+
+    bool
+    operator<=(const directory_entry& __rhs) const noexcept
+    { return _M_path <= __rhs._M_path; }
+
+    bool
+    operator> (const directory_entry& __rhs) const noexcept
+    { return _M_path > __rhs._M_path; }
+
+    bool
+    operator>=(const directory_entry& __rhs) const noexcept
+    { return _M_path >= __rhs._M_path; }
+
+  private:
+    filesystem::path    _M_path;
+  };
+
+  struct _Dir;
+  class recursive_directory_iterator;
+
+  class directory_iterator
+  {
+  public:
+    typedef directory_entry        value_type;
+    typedef ptrdiff_t              difference_type;
+    typedef const directory_entry* pointer;
+    typedef const directory_entry& reference;
+    typedef input_iterator_tag     iterator_category;
+
+    directory_iterator() noexcept = default;
+
+    explicit
+    directory_iterator(const path& __p)
+    : directory_iterator(__p, directory_options::none, nullptr) { }
+
+    directory_iterator(const path& __p, directory_options __options)
+    : directory_iterator(__p, __options, nullptr) { }
+
+    directory_iterator(const path& __p, error_code& __ec) noexcept
+    : directory_iterator(__p, directory_options::none, __ec) { }
+
+    directory_iterator(const path& __p,
+      directory_options __options, error_code& __ec) noexcept
+    : directory_iterator(__p, __options, &__ec) { }
+
+    directory_iterator(const directory_iterator& __rhs) = default;
+
+    directory_iterator(directory_iterator&& __rhs) noexcept = default;
+
+    ~directory_iterator() = default;
+
+    directory_iterator& operator=(const directory_iterator& __rhs) = default;
+    directory_iterator& operator=(directory_iterator&& __rhs) noexcept = default;
+
+    const directory_entry& operator*() const;
+    const directory_entry* operator->() const { return &**this; }
+    directory_iterator&    operator++();
+    directory_iterator&    increment(error_code& __ec) noexcept;
+
+    directory_iterator operator++(int)
+    {
+      auto __tmp = *this;
+      ++*this;
+      return __tmp;
+    }
+
+    friend bool
+    operator==(const directory_iterator& __lhs,
+               const directory_iterator& __rhs)
+    { return __lhs._M_dir == __rhs._M_dir; }
+
+  private:
+    directory_iterator(const path&, directory_options, error_code*);
+    directory_iterator(std::shared_ptr<_Dir>, error_code*);
+
+    friend class recursive_directory_iterator;
+
+    std::shared_ptr<_Dir> _M_dir;
+  };
+
+  inline directory_iterator
+  begin(directory_iterator __iter) { return __iter; }
+
+  inline directory_iterator
+  end(directory_iterator) { return directory_iterator(); }
+
+  inline bool
+  operator!=(const directory_iterator& __lhs, const directory_iterator& __rhs)
+  { return !(__lhs == __rhs); }
+
+  class recursive_directory_iterator
+  {
+  public:
+    typedef directory_entry        value_type;
+    typedef ptrdiff_t              difference_type;
+    typedef const directory_entry* pointer;
+    typedef const directory_entry& reference;
+    typedef input_iterator_tag     iterator_category;
+
+    recursive_directory_iterator() noexcept = default;
+
+    explicit
+    recursive_directory_iterator(const path& __p)
+    : recursive_directory_iterator(__p, directory_options::none, nullptr) { }
+
+    recursive_directory_iterator(const path& __p, directory_options __options)
+    : recursive_directory_iterator(__p, __options, nullptr) { }
+
+    recursive_directory_iterator(const path& __p,
+                                 directory_options __options,
+                                 error_code& __ec) noexcept
+    : recursive_directory_iterator(__p, __options, &__ec) { }
+
+    recursive_directory_iterator(const path& __p, error_code& __ec) noexcept
+    : recursive_directory_iterator(__p, directory_options::none, &__ec) { }
+
+    recursive_directory_iterator(
+        const recursive_directory_iterator&) = default;
+
+    recursive_directory_iterator(
+        recursive_directory_iterator&&) noexcept = default;
+
+    ~recursive_directory_iterator();
+
+    // observers
+    directory_options  options() const { return _M_options; }
+    int                depth() const;
+    bool               recursion_pending() const { return _M_pending; }
+
+    const directory_entry& operator*() const;
+    const directory_entry* operator->() const { return &**this; }
+
+    // modifiers
+    recursive_directory_iterator&
+      operator=(const recursive_directory_iterator& __rhs) noexcept;
+    recursive_directory_iterator&
+      operator=(recursive_directory_iterator&& __rhs) noexcept;
+
+    recursive_directory_iterator& operator++();
+    recursive_directory_iterator& increment(error_code& __ec) noexcept;
+
+    recursive_directory_iterator operator++(int)
+    {
+      auto __tmp = *this;
+      ++*this;
+      return __tmp;
+    }
+
+    void pop();
+
+    void disable_recursion_pending() { _M_pending = false; }
+
+    friend bool
+    operator==(const recursive_directory_iterator& __lhs,
+               const recursive_directory_iterator& __rhs)
+    { return __lhs._M_dirs == __rhs._M_dirs; }
+
+  private:
+    recursive_directory_iterator(const path&, directory_options, error_code*);
+
+    struct _Dir_stack;
+    std::shared_ptr<_Dir_stack> _M_dirs;
+    directory_options _M_options;
+    bool _M_pending;
+  };
+
+  inline recursive_directory_iterator
+  begin(recursive_directory_iterator __iter) { return __iter; }
+
+  inline recursive_directory_iterator
+  end(recursive_directory_iterator) { return recursive_directory_iterator(); }
+
+  inline bool
+  operator!=(const recursive_directory_iterator& __lhs,
+             const recursive_directory_iterator& __rhs)
+  { return !(__lhs == __rhs); }
+
+_GLIBCXX_END_NAMESPACE_CXX11
+
+  // @} group filesystem
+_GLIBCXX_END_NAMESPACE_VERSION
+} // namespace v1
+} // namespace filesystem
+} // namespace experimental
+} // namespace std
+
+#endif // C++11
+
+#endif // _GLIBCXX_EXPERIMENTAL_FS_DIR_H
Index: libstdc++-v3/include/experimental/fs_fwd.h
===================================================================
--- libstdc++-v3/include/experimental/fs_fwd.h	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/include/experimental/fs_fwd.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,289 @@
+// Filesystem declarations -*- C++ -*-
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// Under Section 7 of GPL version 3, you are granted additional
+// permissions described in the GCC Runtime Library Exception, version
+// 3.1, as published by the Free Software Foundation.
+
+// You should have received a copy of the GNU General Public License and
+// a copy of the GCC Runtime Library Exception along with this program;
+// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
+// <http://www.gnu.org/licenses/>.
+
+/** @file experimental/filesystem
+ *  This is a TS C++ Library header.
+ */
+
+#ifndef _GLIBCXX_EXPERIMENTAL_FS_FWD_H
+#define _GLIBCXX_EXPERIMENTAL_FS_FWD_H 1
+
+#if __cplusplus < 201103L
+# include <bits/c++0x_warning.h>
+#else
+
+#include <system_error>
+#include <cstdint>
+#include <chrono>
+
+namespace std _GLIBCXX_VISIBILITY(default)
+{
+namespace experimental
+{
+namespace filesystem
+{
+inline namespace v1
+{
+_GLIBCXX_BEGIN_NAMESPACE_VERSION
+
+#if _GLIBCXX_USE_CXX11_ABI
+  inline namespace __cxx11 __attribute__((__abi_tag__ ("cxx11"))) { }
+#endif
+
+  /**
+   * @defgroup filesystem
+   * @ingroup experimental
+   *
+   * Utilities for performing operations on file systems and their components,
+   * such as paths, regular files, and directories.
+   *
+   * @{
+   */
+
+  class file_status;
+_GLIBCXX_BEGIN_NAMESPACE_CXX11
+  class path;
+  class filesystem_error;
+  class directory_entry;
+  class directory_iterator;
+  class recursive_directory_iterator;
+_GLIBCXX_END_NAMESPACE_CXX11
+
+  struct space_info
+  {
+    uintmax_t capacity;
+    uintmax_t free;
+    uintmax_t available;
+  };
+
+  enum class file_type : signed char {
+      none = 0, not_found = -1, regular = 1, directory = 2, symlink = 3,
+      block = 4, character = 5, fifo = 6, socket = 7, unknown = 8
+  };
+
+  /// Bitmask type
+  enum class copy_options : unsigned short {
+      none = 0,
+      skip_existing = 1, overwrite_existing = 2, update_existing = 4,
+      recursive = 8,
+      copy_symlinks = 16, skip_symlinks = 32,
+      directories_only = 64, create_symlinks = 128, create_hard_links = 256
+  };
+
+  constexpr copy_options
+  operator&(copy_options __x, copy_options __y)
+  {
+    using __utype = typename std::underlying_type<copy_options>::type;
+    return static_cast<copy_options>(
+	static_cast<__utype>(__x) & static_cast<__utype>(__y));
+  }
+
+  constexpr copy_options
+  operator|(copy_options __x, copy_options __y)
+  {
+    using __utype = typename std::underlying_type<copy_options>::type;
+    return static_cast<copy_options>(
+	static_cast<__utype>(__x) | static_cast<__utype>(__y));
+  }
+
+  constexpr copy_options
+  operator^(copy_options __x, copy_options __y)
+  {
+    using __utype = typename std::underlying_type<copy_options>::type;
+    return static_cast<copy_options>(
+	static_cast<__utype>(__x) ^ static_cast<__utype>(__y));
+  }
+
+  constexpr copy_options
+  operator~(copy_options __x)
+  {
+    using __utype = typename std::underlying_type<copy_options>::type;
+    return static_cast<copy_options>(~static_cast<__utype>(__x));
+  }
+
+  inline copy_options&
+  operator&=(copy_options& __x, copy_options __y)
+  { return __x = __x & __y; }
+
+  inline copy_options&
+  operator|=(copy_options& __x, copy_options __y)
+  { return __x = __x | __y; }
+
+  inline copy_options&
+  operator^=(copy_options& __x, copy_options __y)
+  { return __x = __x ^ __y; }
+
+
+  /// Bitmask type
+  enum class perms : unsigned {
+      none		=  0,
+      owner_read	=  0400,
+      owner_write	=  0200,
+      owner_exec	=  0100,
+      owner_all		=  0700,
+      group_read	=   040,
+      group_write	=   020,
+      group_exec	=   010,
+      group_all		=   070,
+      others_read	=    04,
+      others_write	=    02,
+      others_exec	=    01,
+      others_all	=    07,
+      all		=  0777,
+      set_uid		= 04000,
+      set_gid		= 02000,
+      sticky_bit	= 01000,
+      mask		= 07777,
+      unknown		=  0xFFFF,
+      add_perms		= 0x10000,
+      remove_perms	= 0x20000,
+      resolve_symlinks	= 0x40000
+  };
+
+  constexpr perms
+  operator&(perms __x, perms __y)
+  {
+    using __utype = typename std::underlying_type<perms>::type;
+    return static_cast<perms>(
+	static_cast<__utype>(__x) & static_cast<__utype>(__y));
+  }
+
+  constexpr perms
+  operator|(perms __x, perms __y)
+  {
+    using __utype = typename std::underlying_type<perms>::type;
+    return static_cast<perms>(
+	static_cast<__utype>(__x) | static_cast<__utype>(__y));
+  }
+
+  constexpr perms
+  operator^(perms __x, perms __y)
+  {
+    using __utype = typename std::underlying_type<perms>::type;
+    return static_cast<perms>(
+	static_cast<__utype>(__x) ^ static_cast<__utype>(__y));
+  }
+
+  constexpr perms
+  operator~(perms __x)
+  {
+    using __utype = typename std::underlying_type<perms>::type;
+    return static_cast<perms>(~static_cast<__utype>(__x));
+  }
+
+  inline perms&
+  operator&=(perms& __x, perms __y)
+  { return __x = __x & __y; }
+
+  inline perms&
+  operator|=(perms& __x, perms __y)
+  { return __x = __x | __y; }
+
+  inline perms&
+  operator^=(perms& __x, perms __y)
+  { return __x = __x ^ __y; }
+
+  // Bitmask type
+  enum class directory_options : unsigned char {
+      none = 0, follow_directory_symlink = 1, skip_permission_denied = 2
+  };
+
+  constexpr directory_options
+  operator&(directory_options __x, directory_options __y)
+  {
+    using __utype = typename std::underlying_type<directory_options>::type;
+    return static_cast<directory_options>(
+	static_cast<__utype>(__x) & static_cast<__utype>(__y));
+  }
+
+  constexpr directory_options
+  operator|(directory_options __x, directory_options __y)
+  {
+    using __utype = typename std::underlying_type<directory_options>::type;
+    return static_cast<directory_options>(
+	static_cast<__utype>(__x) | static_cast<__utype>(__y));
+  }
+
+  constexpr directory_options
+  operator^(directory_options __x, directory_options __y)
+  {
+    using __utype = typename std::underlying_type<directory_options>::type;
+    return static_cast<directory_options>(
+	static_cast<__utype>(__x) ^ static_cast<__utype>(__y));
+  }
+
+  constexpr directory_options
+  operator~(directory_options __x)
+  {
+    using __utype = typename std::underlying_type<directory_options>::type;
+    return static_cast<directory_options>(~static_cast<__utype>(__x));
+  }
+
+  inline directory_options&
+  operator&=(directory_options& __x, directory_options __y)
+  { return __x = __x & __y; }
+
+  inline directory_options&
+  operator|=(directory_options& __x, directory_options __y)
+  { return __x = __x | __y; }
+
+  inline directory_options&
+  operator^=(directory_options& __x, directory_options __y)
+  { return __x = __x ^ __y; }
+
+  typedef chrono::time_point<chrono::system_clock> file_time_type;
+
+  // operational functions
+
+  void copy(const path& __from, const path& __to, copy_options __options);
+  void copy(const path& __from, const path& __to, copy_options __options,
+	    error_code&) noexcept;
+
+  bool copy_file(const path& __from, const path& __to, copy_options __option);
+  bool copy_file(const path& __from, const path& __to, copy_options __option,
+		 error_code&) noexcept;
+
+  path current_path();
+
+  file_status status(const path&);
+  file_status status(const path&, error_code&) noexcept;
+
+  bool status_known(file_status) noexcept;
+
+  file_status symlink_status(const path&);
+  file_status symlink_status(const path&, error_code&) noexcept;
+
+  bool is_regular_file(file_status) noexcept;
+  bool is_symlink(file_status) noexcept;
+
+  // @} group filesystem
+_GLIBCXX_END_NAMESPACE_VERSION
+} // namespace v1
+} // namespace filesystem
+} // namespace experimental
+} // namespace std
+
+#endif // C++11
+
+#endif // _GLIBCXX_EXPERIMENTAL_FS_FWD_H
Index: libstdc++-v3/include/experimental/functional
===================================================================
--- libstdc++-v3/include/experimental/functional	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/include/experimental/functional	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -376,8 +376,11 @@
 
   /// Generalized negator.
   template<typename _Fn>
-    struct _Not_fn
+    class _Not_fn
     {
+      _Fn _M_fn;
+
+    public:
       template<typename _Fn2>
 	explicit
 	_Not_fn(_Fn2&& __fn) : _M_fn(std::forward<_Fn2>(__fn)) { }
@@ -389,34 +392,43 @@
       ~_Not_fn() = default;
 
       template<typename... _Args>
-	decltype(auto)
+	auto
 	operator()(_Args&&... __args)
+	noexcept(noexcept(!_M_fn(std::forward<_Args>(__args)...)))
+	-> decltype(!_M_fn(std::forward<_Args>(__args)...))
 	{ return !_M_fn(std::forward<_Args>(__args)...); }
 
       template<typename... _Args>
-	decltype(auto)
+	auto
 	operator()(_Args&&... __args) const
+	noexcept(noexcept(!_M_fn(std::forward<_Args>(__args)...)))
+	-> decltype(!_M_fn(std::forward<_Args>(__args)...))
 	{ return !_M_fn(std::forward<_Args>(__args)...); }
 
       template<typename... _Args>
-	decltype(auto)
+	auto
 	operator()(_Args&&... __args) volatile
+	noexcept(noexcept(!_M_fn(std::forward<_Args>(__args)...)))
+	-> decltype(!_M_fn(std::forward<_Args>(__args)...))
 	{ return !_M_fn(std::forward<_Args>(__args)...); }
 
       template<typename... _Args>
-	decltype(auto)
+	auto
 	operator()(_Args&&... __args) const volatile
+	noexcept(noexcept(!_M_fn(std::forward<_Args>(__args)...)))
+	-> decltype(!_M_fn(std::forward<_Args>(__args)...))
 	{ return !_M_fn(std::forward<_Args>(__args)...); }
-
-    private:
-      _Fn _M_fn;
     };
 
   /// [func.not_fn] Function template not_fn
-  template <class _Fn>
+  template<typename _Fn>
     inline auto
     not_fn(_Fn&& __fn)
-    { return _Not_fn<std::decay_t<_Fn>>{std::forward<_Fn>(__fn)}; }
+    noexcept(std::is_nothrow_constructible<std::decay_t<_Fn>, _Fn&&>::value)
+    {
+      using __maybe_type = _Maybe_wrap_member_pointer<std::decay_t<_Fn>>;
+      return _Not_fn<typename __maybe_type::type>{std::forward<_Fn>(__fn)};
+    }
 
 _GLIBCXX_END_NAMESPACE_VERSION
 } // namespace fundamentals_v2
Index: libstdc++-v3/include/experimental/fs_path.h
===================================================================
--- libstdc++-v3/include/experimental/fs_path.h	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/include/experimental/fs_path.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,1016 @@
+// Class filesystem::path -*- C++ -*-
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// Under Section 7 of GPL version 3, you are granted additional
+// permissions described in the GCC Runtime Library Exception, version
+// 3.1, as published by the Free Software Foundation.
+
+// You should have received a copy of the GNU General Public License and
+// a copy of the GCC Runtime Library Exception along with this program;
+// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
+// <http://www.gnu.org/licenses/>.
+
+/** @file experimental/fs_path.h
+ *  This is an internal header file, included by other library headers.
+ *  Do not attempt to use it directly. @headername{experimental/filesystem}
+ */
+
+#ifndef _GLIBCXX_EXPERIMENTAL_FS_PATH_H
+#define _GLIBCXX_EXPERIMENTAL_FS_PATH_H 1
+
+#if __cplusplus < 201103L
+# include <bits/c++0x_warning.h>
+#else
+
+#include <utility>
+#include <type_traits>
+#include <vector>
+#include <locale>
+#include <iosfwd>
+#include <codecvt>
+#include <system_error>
+#include <bits/stl_algobase.h>
+#include <bits/quoted_string.h>
+#include <bits/locale_conv.h>
+
+#if defined(_WIN32) && !defined(__CYGWIN__)
+# define _GLIBCXX_FILESYSTEM_IS_WINDOWS 1
+# include <algorithm>
+#endif
+
+namespace std _GLIBCXX_VISIBILITY(default)
+{
+namespace experimental
+{
+namespace filesystem
+{
+inline namespace v1
+{
+_GLIBCXX_BEGIN_NAMESPACE_VERSION
+_GLIBCXX_BEGIN_NAMESPACE_CXX11
+
+  /**
+   * @ingroup filesystem
+   * @{
+   */
+
+  /// A filesystem path.
+  class path
+  {
+    template<typename _CharT>
+      struct __is_encoded_char : std::false_type { };
+
+    template<typename _Iter,
+	     typename _Iter_traits = std::iterator_traits<_Iter>>
+      using __is_path_iter_src
+	= __and_<__is_encoded_char<typename _Iter_traits::value_type>,
+		 std::is_base_of<std::input_iterator_tag,
+				 typename _Iter_traits::iterator_category>>;
+
+    template<typename _Iter>
+      static __is_path_iter_src<_Iter>
+      __is_path_src(_Iter, int);
+
+    template<typename _CharT, typename _Traits, typename _Alloc>
+      static __is_encoded_char<_CharT>
+      __is_path_src(const basic_string<_CharT, _Traits, _Alloc>&, int);
+
+    template<typename _Unknown>
+      static std::false_type
+      __is_path_src(const _Unknown&, ...);
+
+    template<typename _Tp1, typename _Tp2>
+      struct __constructible_from;
+
+    template<typename _Iter>
+      struct __constructible_from<_Iter, _Iter>
+      : __is_path_iter_src<_Iter>
+      { };
+
+    template<typename _Source>
+      struct __constructible_from<_Source, void>
+      : decltype(__is_path_src(std::declval<_Source>(), 0))
+      { };
+
+    template<typename _Tp1, typename _Tp2 = void>
+      using _Path = typename
+	std::enable_if<__and_<__not_<is_same<_Tp1, path>>,
+			      __constructible_from<_Tp1, _Tp2>>::value,
+		       path>::type;
+
+    template<typename _Source>
+      static _Source
+      _S_range_begin(_Source __begin) { return __begin; }
+
+    struct __null_terminated { };
+
+    template<typename _Source>
+      static __null_terminated
+      _S_range_end(_Source) { return {}; }
+
+    template<typename _CharT, typename _Traits, typename _Alloc>
+      static const _CharT*
+      _S_range_begin(const basic_string<_CharT, _Traits, _Alloc>& __str)
+      { return __str.data(); }
+
+    template<typename _CharT, typename _Traits, typename _Alloc>
+      static const _CharT*
+      _S_range_end(const basic_string<_CharT, _Traits, _Alloc>& __str)
+      { return __str.data() + __str.size(); }
+
+    template<typename _Tp,
+	     typename _Iter = decltype(_S_range_begin(std::declval<_Tp>())),
+	     typename _Val = typename std::iterator_traits<_Iter>::value_type>
+      using __value_type_is_char
+	= typename std::enable_if<std::is_same<_Val, char>::value>::type;
+
+  public:
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+    typedef wchar_t				value_type;
+    static constexpr value_type			preferred_separator = L'\\';
+#else
+    typedef char				value_type;
+    static constexpr value_type			preferred_separator = '/';
+#endif
+    typedef std::basic_string<value_type>	string_type;
+
+    // constructors and destructor
+
+    path() noexcept { }
+
+    path(const path& __p) = default;
+
+    path(path&& __p) noexcept
+    : _M_pathname(std::move(__p._M_pathname)), _M_type(__p._M_type)
+    {
+      _M_split_cmpts();
+      __p.clear();
+    }
+
+    template<typename _Source,
+	     typename _Require = _Path<_Source>>
+      path(_Source const& __source)
+      : _M_pathname(_S_convert(_S_range_begin(__source),
+			       _S_range_end(__source)))
+      { _M_split_cmpts(); }
+
+    template<typename _InputIterator,
+	     typename _Require = _Path<_InputIterator, _InputIterator>>
+      path(_InputIterator __first, _InputIterator __last)
+      : _M_pathname(_S_convert(__first, __last))
+      { _M_split_cmpts(); }
+
+    template<typename _Source,
+	     typename _Require = _Path<_Source>,
+	     typename _Require2 = __value_type_is_char<_Source>>
+      path(_Source const& __source, const locale& __loc)
+      : _M_pathname(_S_convert_loc(_S_range_begin(__source),
+				   _S_range_end(__source), __loc))
+      { _M_split_cmpts(); }
+
+    template<typename _InputIterator,
+	     typename _Require = _Path<_InputIterator, _InputIterator>,
+	     typename _Require2 = __value_type_is_char<_InputIterator>>
+      path(_InputIterator __first, _InputIterator __last, const locale& __loc)
+      : _M_pathname(_S_convert_loc(__first, __last, __loc))
+      { _M_split_cmpts(); }
+
+    ~path() = default;
+
+    // assignments
+
+    path& operator=(const path& __p) = default;
+    path& operator=(path&& __p) noexcept;
+
+    template<typename _Source>
+      _Path<_Source>&
+      operator=(_Source const& __source)
+      { return *this = path(__source); }
+
+    template<typename _Source>
+      _Path<_Source>&
+      assign(_Source const& __source)
+      { return *this = path(__source); }
+
+    template<typename _InputIterator>
+      _Path<_InputIterator, _InputIterator>&
+      assign(_InputIterator __first, _InputIterator __last)
+      { return *this = path(__first, __last); }
+
+    // appends
+
+    path& operator/=(const path& __p) { return _M_append(__p._M_pathname); }
+
+    template <class _Source>
+      _Path<_Source>&
+      operator/=(_Source const& __source)
+      { return append(__source); }
+
+    template<typename _Source>
+      _Path<_Source>&
+      append(_Source const& __source)
+      {
+	return _M_append(_S_convert(_S_range_begin(__source),
+				    _S_range_end(__source)));
+      }
+
+    template<typename _InputIterator>
+      _Path<_InputIterator, _InputIterator>&
+      append(_InputIterator __first, _InputIterator __last)
+      { return _M_append(_S_convert(__first, __last)); }
+
+    // concatenation
+
+    path& operator+=(const path& __x);
+    path& operator+=(const string_type& __x);
+    path& operator+=(const value_type* __x);
+    path& operator+=(value_type __x);
+
+    template<typename _Source>
+      _Path<_Source>&
+      operator+=(_Source const& __x) { return concat(__x); }
+
+    template<typename _CharT>
+      _Path<_CharT*, _CharT*>&
+      operator+=(_CharT __x);
+
+    template<typename _Source>
+      _Path<_Source>&
+      concat(_Source const& __x)
+      { return *this += _S_convert(_S_range_begin(__x), _S_range_end(__x)); }
+
+    template<typename _InputIterator>
+      _Path<_InputIterator, _InputIterator>&
+      concat(_InputIterator __first, _InputIterator __last)
+      { return *this += _S_convert(__first, __last); }
+
+    // modifiers
+
+    void clear() noexcept { _M_pathname.clear(); _M_split_cmpts(); }
+
+    path& make_preferred();
+    path& remove_filename();
+    path& replace_filename(const path& __replacement);
+    path& replace_extension(const path& __replacement = path());
+
+    void swap(path& __rhs) noexcept;
+
+    // native format observers
+
+    const string_type&  native() const noexcept { return _M_pathname; }
+    const value_type*   c_str() const noexcept { return _M_pathname.c_str(); }
+    operator string_type() const { return _M_pathname; }
+
+    template<typename _CharT, typename _Traits = std::char_traits<_CharT>,
+	     typename _Allocator = std::allocator<_CharT>>
+      std::basic_string<_CharT, _Traits, _Allocator>
+      string(const _Allocator& __a = _Allocator()) const;
+
+    std::string    string() const;
+    std::wstring   wstring() const;
+    std::string    u8string() const;
+    std::u16string u16string() const;
+    std::u32string u32string() const;
+
+    // generic format observers
+    template<typename _CharT, typename _Traits = std::char_traits<_CharT>,
+	     typename _Allocator = std::allocator<_CharT>>
+      std::basic_string<_CharT, _Traits, _Allocator>
+      generic_string(const _Allocator& __a = _Allocator()) const;
+
+    std::string    generic_string() const;
+    std::wstring   generic_wstring() const;
+    std::string    generic_u8string() const;
+    std::u16string generic_u16string() const;
+    std::u32string generic_u32string() const;
+
+    // compare
+
+    int compare(const path& __p) const noexcept;
+    int compare(const string_type& __s) const;
+    int compare(const value_type* __s) const;
+
+    // decomposition
+
+    path root_name() const;
+    path root_directory() const;
+    path root_path() const;
+    path relative_path() const;
+    path parent_path() const;
+    path filename() const;
+    path stem() const;
+    path extension() const;
+
+    // query
+
+    bool empty() const noexcept { return _M_pathname.empty(); }
+    bool has_root_name() const;
+    bool has_root_directory() const;
+    bool has_root_path() const;
+    bool has_relative_path() const;
+    bool has_parent_path() const;
+    bool has_filename() const;
+    bool has_stem() const;
+    bool has_extension() const;
+    bool is_absolute() const;
+    bool is_relative() const { return !is_absolute(); }
+
+    // iterators
+    class iterator;
+    typedef iterator const_iterator;
+
+    iterator begin() const;
+    iterator end() const;
+
+  private:
+    enum class _Type : unsigned char {
+	_Multi, _Root_name, _Root_dir, _Filename
+    };
+
+    path(string_type __str, _Type __type) : _M_pathname(__str), _M_type(__type)
+    {
+      _GLIBCXX_DEBUG_ASSERT(!empty());
+      _GLIBCXX_DEBUG_ASSERT(_M_type != _Type::_Multi);
+    }
+
+    enum class _Split { _Stem, _Extension };
+
+    path& _M_append(const string_type& __str)
+    {
+      if (!_M_pathname.empty() && !_S_is_dir_sep(_M_pathname.back())
+	  && !__str.empty() && !_S_is_dir_sep(__str.front()))
+	_M_pathname += preferred_separator;
+      _M_pathname += __str;
+      _M_split_cmpts();
+      return *this;
+    }
+
+    pair<const string_type*, size_t> _M_find_extension() const;
+
+    template<typename _CharT>
+      struct _Cvt;
+
+    static string_type
+    _S_convert(value_type* __src, __null_terminated)
+    { return string_type(__src); }
+
+    static string_type
+    _S_convert(const value_type* __src, __null_terminated)
+    { return string_type(__src); }
+
+    template<typename _Iter>
+      static string_type
+      _S_convert(_Iter __first, _Iter __last)
+      {
+	using __value_type = typename std::iterator_traits<_Iter>::value_type;
+	return _Cvt<__value_type>::_S_convert(__first, __last);
+      }
+
+    template<typename _InputIterator>
+      static string_type
+      _S_convert(_InputIterator __src, __null_terminated)
+      {
+	using _Tp = typename std::iterator_traits<_InputIterator>::value_type;
+	std::basic_string<_Tp> __tmp;
+	while (*__src != _Tp{})
+	  __tmp.push_back(*__src++);
+	return _S_convert(__tmp.data(), __tmp.data() + __tmp.size());
+      }
+
+    static string_type
+    _S_convert_loc(const char* __first, const char* __last,
+		   const std::locale& __loc);
+
+    template<typename _Iter>
+      static string_type
+      _S_convert_loc(_Iter __first, _Iter __last, const std::locale& __loc)
+      {
+	const std::string __str(__first, __last);
+	return _S_convert_loc(__str.data(), __str.data()+__str.size(), __loc);
+      }
+
+    template<typename _InputIterator>
+      static string_type
+      _S_convert_loc(_InputIterator __src, __null_terminated,
+		     const std::locale& __loc)
+      {
+	std::string __tmp;
+	while (*__src != '\0')
+	  __tmp.push_back(*__src++);
+	return _S_convert_loc(__tmp.data(), __tmp.data()+__tmp.size(), __loc);
+      }
+
+    bool _S_is_dir_sep(value_type __ch)
+    {
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+      return __ch == L'/' || __ch == preferred_separator;
+#else
+      return __ch == '/';
+#endif
+    }
+
+    void _M_split_cmpts();
+    void _M_trim();
+    void _M_add_root_name(size_t __n);
+    void _M_add_root_dir(size_t __pos);
+    void _M_add_filename(size_t __pos, size_t __n);
+
+    string_type _M_pathname;
+
+    struct _Cmpt;
+    using _List = _GLIBCXX_STD_C::vector<_Cmpt>;
+    _List _M_cmpts; // empty unless _M_type == _Type::_Multi
+    _Type _M_type = _Type::_Multi;
+  };
+
+  inline void swap(path& __lhs, path& __rhs) noexcept { __lhs.swap(__rhs); }
+
+  size_t hash_value(const path& __p) noexcept;
+
+  /// Compare paths
+  inline bool operator<(const path& __lhs, const path& __rhs) noexcept
+  { return __lhs.compare(__rhs) < 0; }
+
+  /// Compare paths
+  inline bool operator<=(const path& __lhs, const path& __rhs) noexcept
+  { return !(__rhs < __lhs); }
+
+  /// Compare paths
+  inline bool operator>(const path& __lhs, const path& __rhs) noexcept
+  { return __rhs < __lhs; }
+
+  /// Compare paths
+  inline bool operator>=(const path& __lhs, const path& __rhs) noexcept
+  { return !(__lhs < __rhs); }
+
+  /// Compare paths
+  inline bool operator==(const path& __lhs, const path& __rhs) noexcept
+  { return __lhs.compare(__rhs) == 0; }
+
+  /// Compare paths
+  inline bool operator!=(const path& __lhs, const path& __rhs) noexcept
+  { return !(__lhs == __rhs); }
+
+  /// Append one path to another
+  inline path operator/(const path& __lhs, const path& __rhs)
+  { return path(__lhs) /= __rhs; }
+
+  /// Write a path to a stream
+  template<typename _CharT, typename _Traits>
+    basic_ostream<_CharT, _Traits>&
+    operator<<(basic_ostream<_CharT, _Traits>& __os, const path& __p)
+    {
+      auto __tmp = __p.string<_CharT, _Traits>();
+      using __quoted_string
+	= std::__detail::_Quoted_string<decltype(__tmp)&, _CharT>;
+      __os << __quoted_string{__tmp, '"', '\\'};
+      return __os;
+    }
+
+  /// Read a path from a stream
+  template<typename _CharT, typename _Traits>
+    basic_istream<_CharT, _Traits>&
+    operator>>(basic_istream<_CharT, _Traits>& __is, path& __p)
+    {
+      basic_string<_CharT, _Traits> __tmp;
+      using __quoted_string
+	= std::__detail::_Quoted_string<decltype(__tmp)&, _CharT>;
+      if (__is >> __quoted_string{ __tmp, '"', '\\' })
+	__p = std::move(__tmp);
+      return __is;
+    }
+
+  // TODO constrain with _Path<Source> and __value_type_is_char
+  template<typename _Source>
+    inline path
+    u8path(const _Source& __source)
+    {
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+      return path{ path::string_type{__source} };
+#else
+      return path{ __source };
+#endif
+    }
+
+  // TODO constrain with _Path<InputIterator, InputIterator> and __value_type_is_char
+  template<typename _InputIterator>
+    inline path
+    u8path(_InputIterator __first, _InputIterator __last)
+    {
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+      return path{ path::string_type{__first, __last} };
+#else
+      return path{ __first, __last };
+#endif
+    }
+
+  class filesystem_error : public std::system_error
+  {
+  public:
+    filesystem_error(const string& __what_arg, error_code __ec)
+    : system_error(__ec, __what_arg) { }
+
+    filesystem_error(const string& __what_arg, const path& __p1,
+		     error_code __ec)
+    : system_error(__ec, __what_arg), _M_path1(__p1) { }
+
+    filesystem_error(const string& __what_arg, const path& __p1,
+		     const path& __p2, error_code __ec)
+    : system_error(__ec, __what_arg), _M_path1(__p1), _M_path2(__p2)
+    { }
+
+    ~filesystem_error();
+
+    const path& path1() const noexcept { return _M_path1; }
+    const path& path2() const noexcept { return _M_path2; }
+    const char* what() const noexcept { return _M_what.c_str(); }
+
+  private:
+    std::string _M_gen_what();
+
+    path _M_path1;
+    path _M_path2;
+    std::string _M_what = _M_gen_what();
+  };
+
+  struct path::_Cmpt : path
+  {
+    _Cmpt(string_type __s, _Type __t, size_t __pos)
+      : path(std::move(__s), __t), _M_pos(__pos) { }
+
+    _Cmpt() : _M_pos(-1) { }
+
+    size_t _M_pos;
+  };
+
+  template<>
+    struct path::__is_encoded_char<char> : std::true_type
+    { using value_type = char; };
+
+  template<>
+    struct path::__is_encoded_char<wchar_t> : std::true_type
+    { using value_type = wchar_t; };
+
+  template<>
+    struct path::__is_encoded_char<char16_t> : std::true_type
+    { using value_type = char16_t; };
+
+  template<>
+    struct path::__is_encoded_char<char32_t> : std::true_type
+    { using value_type = char32_t; };
+
+  // specialize _Cvt for degenerate 'noconv' case
+  template<>
+    struct path::_Cvt<path::value_type>
+    {
+      template<typename _Iter>
+	static string_type
+	_S_convert(_Iter __first, _Iter __last)
+	{ return string_type{__first, __last}; }
+    };
+
+  template<typename _CharT>
+    struct path::_Cvt
+    {
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+      static string_type
+      _S_wconvert(const char* __f, const char* __l, true_type)
+      {
+	using _Cvt = std::codecvt<wchar_t, char, mbstate_t>;
+	const auto& __cvt = std::use_facet<_Cvt>(std::locale{});
+	std::wstring __wstr;
+	if (__str_codecvt_in(__f, __l, __wstr, __cvt))
+	    return __wstr;
+	_GLIBCXX_THROW_OR_ABORT(filesystem_error(
+	      "Cannot convert character sequence",
+	      std::make_error_code(errc::illegal_byte_sequence)));
+      }
+
+      static string_type
+      _S_wconvert(const _CharT* __f, const _CharT* __l, false_type)
+      {
+	std::codecvt_utf8<_CharT> __cvt;
+	std::string __str;
+	if (__str_codecvt_out(__f, __l, __str, __cvt))
+	  {
+	    const char* __f2 = __str.data();
+	    const char* __l2 = __f2 + __str.size();
+	    std::codecvt_utf8<wchar_t> __wcvt;
+	    std::wstring __wstr;
+	    if (__str_codecvt_in(__f2, __l2, __wstr, __wcvt))
+	      return __wstr;
+	  }
+	_GLIBCXX_THROW_OR_ABORT(filesystem_error(
+	      "Cannot convert character sequence",
+	      std::make_error_code(errc::illegal_byte_sequence)));
+      }
+
+      static string_type
+      _S_convert(const _CharT* __f, const _CharT* __l)
+      {
+	return _S_wconvert(__f, __l, is_same<_CharT, char>{});
+      }
+#else
+      static string_type
+      _S_convert(const _CharT* __f, const _CharT* __l)
+      {
+	std::codecvt_utf8<_CharT> __cvt;
+	std::string __str;
+	if (__str_codecvt_out(__f, __l, __str, __cvt))
+	  return __str;
+	_GLIBCXX_THROW_OR_ABORT(filesystem_error(
+	      "Cannot convert character sequence",
+	      std::make_error_code(errc::illegal_byte_sequence)));
+      }
+#endif
+
+      static string_type
+      _S_convert(_CharT* __f, _CharT* __l)
+      {
+	return _S_convert(const_cast<const _CharT*>(__f),
+			  const_cast<const _CharT*>(__l));
+      }
+
+      template<typename _Iter>
+	static string_type
+	_S_convert(_Iter __first, _Iter __last)
+	{
+	  const std::basic_string<_CharT> __str(__first, __last);
+	  return _S_convert(__str.data(), __str.data() + __str.size());
+	}
+
+      template<typename _Iter, typename _Cont>
+	static string_type
+	_S_convert(__gnu_cxx::__normal_iterator<_Iter, _Cont> __first,
+		  __gnu_cxx::__normal_iterator<_Iter, _Cont> __last)
+	{ return _S_convert(__first.base(), __last.base()); }
+    };
+
+  /// An iterator for the components of a path
+  class path::iterator
+  {
+  public:
+    using difference_type	= std::ptrdiff_t;
+    using value_type		= path;
+    using reference		= const path&;
+    using pointer		= const path*;
+    using iterator_category	= std::bidirectional_iterator_tag;
+
+    iterator() : _M_path(nullptr), _M_cur(), _M_at_end() { }
+
+    iterator(const iterator&) = default;
+    iterator& operator=(const iterator&) = default;
+
+    reference operator*() const;
+    pointer   operator->() const { return std::__addressof(**this); }
+
+    iterator& operator++();
+    iterator  operator++(int) { auto __tmp = *this; ++_M_cur; return __tmp; }
+
+    iterator& operator--();
+    iterator  operator--(int) { auto __tmp = *this; --_M_cur; return __tmp; }
+
+    friend bool operator==(const iterator& __lhs, const iterator& __rhs)
+    { return __lhs._M_equals(__rhs); }
+
+    friend bool operator!=(const iterator& __lhs, const iterator& __rhs)
+    { return !__lhs._M_equals(__rhs); }
+
+  private:
+    friend class path;
+
+    iterator(const path* __path, path::_List::const_iterator __iter)
+    : _M_path(__path), _M_cur(__iter), _M_at_end()
+    { }
+
+    iterator(const path* __path, bool __at_end)
+    : _M_path(__path), _M_cur(), _M_at_end(__at_end)
+    { }
+
+    bool _M_equals(iterator) const;
+
+    const path* 		_M_path;
+    path::_List::const_iterator _M_cur;
+    bool			_M_at_end;  // only used when type != _Multi
+  };
+
+
+  inline path&
+  path::operator=(path&& __p) noexcept
+  {
+    _M_pathname = std::move(__p._M_pathname);
+    _M_cmpts = std::move(__p._M_cmpts);
+    _M_type = __p._M_type;
+    __p.clear();
+    return *this;
+  }
+
+  inline path&
+  path::operator+=(const path& __p)
+  {
+    return operator+=(__p.native());
+  }
+
+  inline path&
+  path::operator+=(const string_type& __x)
+  {
+    _M_pathname += __x;
+    _M_split_cmpts();
+    return *this;
+  }
+
+  inline path&
+  path::operator+=(const value_type* __x)
+  {
+    _M_pathname += __x;
+    _M_split_cmpts();
+    return *this;
+  }
+
+  inline path&
+  path::operator+=(value_type __x)
+  {
+    _M_pathname += __x;
+    _M_split_cmpts();
+    return *this;
+  }
+
+  template<typename _CharT>
+    inline path::_Path<_CharT*, _CharT*>&
+    path::operator+=(_CharT __x)
+    {
+      auto* __addr = std::__addressof(__x);
+      return concat(__addr, __addr + 1);
+    }
+
+  inline path&
+  path::make_preferred()
+  {
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+    std::replace(_M_pathname.begin(), _M_pathname.end(), L'/',
+		 preferred_separator);
+#endif
+    return *this;
+  }
+
+  inline void path::swap(path& __rhs) noexcept
+  {
+    _M_pathname.swap(__rhs._M_pathname);
+    _M_cmpts.swap(__rhs._M_cmpts);
+    std::swap(_M_type, __rhs._M_type);
+  }
+
+  template<typename _CharT, typename _Traits, typename _Allocator>
+    inline std::basic_string<_CharT, _Traits, _Allocator>
+    path::string(const _Allocator& __a) const
+    {
+      if (is_same<_CharT, value_type>::value)
+	return { _M_pathname.begin(), _M_pathname.end(), __a };
+
+      const value_type* __first = _M_pathname.data();
+      const value_type* __last = __first + _M_pathname.size();
+
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+      using _CharAlloc = __alloc_rebind<_Allocator, char>;
+      using _String = basic_string<char, char_traits<char>, _CharAlloc>;
+      using _WString = basic_string<_CharT, _Traits, _Allocator>;
+
+      // use codecvt_utf8<wchar_t> to convert native string to UTF-8
+      codecvt_utf8<value_type> __cvt;
+      _String __u8str{_CharAlloc{__a}};
+      if (__str_codecvt_out(__first, __last, __u8str, __cvt))
+	{
+	  struct
+	  {
+	    const _String*
+	    operator()(const _String& __from, _String&, true_type)
+	    { return std::__addressof(__from); }
+
+	    _WString*
+	    operator()(const _String& __from, _WString& __to, false_type)
+	    {
+	      // use codecvt_utf8<_CharT> to convert UTF-8 to wide string
+	      codecvt_utf8<_CharT> __cvt;
+	      const char* __f = __from.data();
+	      const char* __l = __f + __from.size();
+	      if (__str_codecvt_in(__f, __l, __to, __cvt))
+		return std::__addressof(__to);
+	      return nullptr;
+	    }
+	  } __dispatch;
+	  _WString __wstr;
+	  if (auto* __p = __dispatch(__u8str, __wstr, is_same<_CharT, char>{}))
+	    return *__p;
+	}
+#else
+      codecvt_utf8<_CharT> __cvt;
+      basic_string<_CharT, _Traits, _Allocator> __wstr{__a};
+      if (__str_codecvt_in(__first, __last, __wstr, __cvt))
+	return __wstr;
+#endif
+      _GLIBCXX_THROW_OR_ABORT(filesystem_error(
+	    "Cannot convert character sequence",
+	    std::make_error_code(errc::illegal_byte_sequence)));
+    }
+
+  inline std::string
+  path::string() const { return string<char>(); }
+
+  inline std::wstring
+  path::wstring() const { return string<wchar_t>(); }
+
+  inline std::string
+  path::u8string() const
+  {
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+    std::string __str;
+    // convert from native encoding to UTF-8
+    codecvt_utf8<value_type> __cvt;
+    const value_type* __first = _M_pathname.data();
+    const value_type* __last = __first + _M_pathname.size();
+    if (__str_codecvt_out(__first, __last, __str, __cvt))
+      return __str;
+    _GLIBCXX_THROW_OR_ABORT(filesystem_error(
+	  "Cannot convert character sequence",
+	  std::make_error_code(errc::illegal_byte_sequence)));
+#else
+    return _M_pathname;
+#endif
+  }
+
+  inline std::u16string
+  path::u16string() const { return string<char16_t>(); }
+
+  inline std::u32string
+  path::u32string() const { return string<char32_t>(); }
+
+#ifndef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+  template<typename _CharT, typename _Traits, typename _Allocator>
+    inline std::basic_string<_CharT, _Traits, _Allocator>
+    path::generic_string(const _Allocator& __a) const
+    { return string<_CharT, _Traits, _Allocator>(__a); }
+
+  inline std::string
+  path::generic_string() const { return string(); }
+
+  inline std::wstring
+  path::generic_wstring() const { return wstring(); }
+
+  inline std::string
+  path::generic_u8string() const { return u8string(); }
+
+  inline std::u16string
+  path::generic_u16string() const { return u16string(); }
+
+  inline std::u32string
+  path::generic_u32string() const { return u32string(); }
+#endif
+
+  inline int
+  path::compare(const string_type& __s) const { return compare(path(__s)); }
+
+  inline int
+  path::compare(const value_type* __s) const { return compare(path(__s)); }
+
+  inline path
+  path::filename() const { return empty() ? path() : *--end(); }
+
+  inline path
+  path::stem() const
+  {
+    auto ext = _M_find_extension();
+    if (ext.first && ext.second != 0)
+      return path{ext.first->substr(0, ext.second)};
+    return {};
+  }
+
+  inline path
+  path::extension() const
+  {
+    auto ext = _M_find_extension();
+    if (ext.first && ext.second != string_type::npos)
+      return path{ext.first->substr(ext.second)};
+    return {};
+  }
+
+  inline bool
+  path::has_stem() const
+  {
+    auto ext = _M_find_extension();
+    return ext.first && ext.second != 0;
+  }
+
+  inline bool
+  path::has_extension() const
+  {
+    auto ext = _M_find_extension();
+    return ext.first && ext.second != string_type::npos;
+  }
+
+  inline bool
+  path::is_absolute() const
+  {
+#ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
+    return has_root_name();
+#else
+    return has_root_directory();
+#endif
+  }
+
+  inline path::iterator
+  path::begin() const
+  {
+    if (_M_type == _Type::_Multi)
+      return iterator(this, _M_cmpts.begin());
+    return iterator(this, false);
+  }
+
+  inline path::iterator
+  path::end() const
+  {
+    if (_M_type == _Type::_Multi)
+      return iterator(this, _M_cmpts.end());
+    return iterator(this, true);
+  }
+
+  inline path::iterator&
+  path::iterator::operator++()
+  {
+    _GLIBCXX_DEBUG_ASSERT(_M_path != nullptr);
+    if (_M_path->_M_type == _Type::_Multi)
+      {
+	_GLIBCXX_DEBUG_ASSERT(_M_cur != _M_path->_M_cmpts.end());
+	++_M_cur;
+      }
+    else
+      {
+	_GLIBCXX_DEBUG_ASSERT(!_M_at_end);
+	_M_at_end = true;
+      }
+    return *this;
+  }
+
+  inline path::iterator&
+  path::iterator::operator--()
+  {
+    _GLIBCXX_DEBUG_ASSERT(_M_path != nullptr);
+    if (_M_path->_M_type == _Type::_Multi)
+      {
+	_GLIBCXX_DEBUG_ASSERT(_M_cur != _M_path->_M_cmpts.begin());
+	--_M_cur;
+      }
+    else
+      {
+	_GLIBCXX_DEBUG_ASSERT(_M_at_end);
+	_M_at_end = false;
+      }
+    return *this;
+  }
+
+  inline path::iterator::reference
+  path::iterator::operator*() const
+  {
+    _GLIBCXX_DEBUG_ASSERT(_M_path != nullptr);
+    if (_M_path->_M_type == _Type::_Multi)
+      {
+	_GLIBCXX_DEBUG_ASSERT(_M_cur != _M_path->_M_cmpts.end());
+	return *_M_cur;
+      }
+    return *_M_path;
+  }
+
+  inline bool
+  path::iterator::_M_equals(iterator __rhs) const
+  {
+    if (_M_path != __rhs._M_path)
+      return false;
+    if (_M_path == nullptr)
+      return true;
+    if (_M_path->_M_type == path::_Type::_Multi)
+      return _M_cur == __rhs._M_cur;
+    return _M_at_end == __rhs._M_at_end;
+  }
+
+  // @} group filesystem
+_GLIBCXX_END_NAMESPACE_CXX11
+_GLIBCXX_END_NAMESPACE_VERSION
+} // namespace v1
+} // namespace filesystem
+} // namespace experimental
+} // namespace std
+
+#endif // C++11
+
+#endif // _GLIBCXX_EXPERIMENTAL_FS_PATH_H
Index: libstdc++-v3/include/bits/regex_compiler.h
===================================================================
--- libstdc++-v3/include/bits/regex_compiler.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/include/bits/regex_compiler.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -116,8 +116,10 @@
 	void
 	_M_insert_bracket_matcher(bool __neg);
 
+      // Returns true if successfully matched one term and should continue.
+      // Returns false if the compiler should move on.
       template<bool __icase, bool __collate>
-	void
+	bool
 	_M_expression_term(pair<bool, _CharT>& __last_char,
 			   _BracketMatcher<_TraitsT, __icase, __collate>&
 			   __matcher);
@@ -389,8 +391,8 @@
 #endif
       }
 
-      void
-      _M_add_collating_element(const _StringT& __s)
+      _StringT
+      _M_add_collate_element(const _StringT& __s)
       {
 	auto __st = _M_traits.lookup_collatename(__s.data(),
 						 __s.data() + __s.size());
@@ -400,6 +402,7 @@
 #ifdef _GLIBCXX_DEBUG
 	_M_is_ready = false;
 #endif
+	return __st;
       }
 
       void
Index: libstdc++-v3/include/bits/locale_conv.h
===================================================================
--- libstdc++-v3/include/bits/locale_conv.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/include/bits/locale_conv.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -51,7 +51,114 @@
    * @{
    */
 
+  template<typename _OutStr, typename _InChar, typename _Codecvt,
+	   typename _State, typename _Fn>
+    bool
+    __do_str_codecvt(const _InChar* __first, const _InChar* __last,
+		     _OutStr& __outstr, const _Codecvt& __cvt, _State& __state,
+		     size_t& __count, _Fn __fn)
+    {
+      if (__first == __last)
+	{
+	  __outstr.clear();
+	  __count = 0;
+	  return true;
+	}
+
+      size_t __outchars = 0;
+      auto __next = __first;
+      const auto __maxlen = __cvt.max_length() + 1;
+
+      codecvt_base::result __result;
+      do
+	{
+	  __outstr.resize(__outstr.size() + (__last - __next) * __maxlen);
+	  auto __outnext = &__outstr.front() + __outchars;
+	  auto const __outlast = &__outstr.back() + 1;
+	  __result = (__cvt.*__fn)(__state, __next, __last, __next,
+					__outnext, __outlast, __outnext);
+	  __outchars = __outnext - &__outstr.front();
+	}
+      while (__result == codecvt_base::partial && __next != __last
+	     && (__outstr.size() - __outchars) < __maxlen);
+
+      if (__result == codecvt_base::error)
+	return false;
+
+      if (__result == codecvt_base::noconv)
+	{
+	  __outstr.assign(__first, __last);
+	  __count = __last - __first;
+	}
+      else
+	{
+	  __outstr.resize(__outchars);
+	  __count = __next - __first;
+	}
+
+      return true;
+    }
+
+  // Convert narrow character string to wide.
+  template<typename _CharT, typename _Traits, typename _Alloc, typename _State>
+    inline bool
+    __str_codecvt_in(const char* __first, const char* __last,
+		     basic_string<_CharT, _Traits, _Alloc>& __outstr,
+		     const codecvt<_CharT, char, _State>& __cvt,
+		     _State& __state, size_t& __count)
+    {
+      using _Codecvt = codecvt<_CharT, char, _State>;
+      using _ConvFn
+	= codecvt_base::result
+	  (_Codecvt::*)(_State&, const char*, const char*, const char*&,
+			_CharT*, _CharT*, _CharT*&) const;
+      _ConvFn __fn = &codecvt<_CharT, char, _State>::in;
+      return __do_str_codecvt(__first, __last, __outstr, __cvt, __state,
+			      __count, __fn);
+    }
+
+  template<typename _CharT, typename _Traits, typename _Alloc, typename _State>
+    inline bool
+    __str_codecvt_in(const char* __first, const char* __last,
+		     basic_string<_CharT, _Traits, _Alloc>& __outstr,
+		     const codecvt<_CharT, char, _State>& __cvt)
+    {
+      _State __state = {};
+      size_t __n;
+      return __str_codecvt_in(__first, __last, __outstr, __cvt, __state, __n);
+    }
+
+  // Convert wide character string to narrow.
+  template<typename _CharT, typename _Traits, typename _Alloc, typename _State>
+    inline bool
+    __str_codecvt_out(const _CharT* __first, const _CharT* __last,
+		      basic_string<char, _Traits, _Alloc>& __outstr,
+		      const codecvt<_CharT, char, _State>& __cvt,
+		      _State& __state, size_t& __count)
+    {
+      using _Codecvt = codecvt<_CharT, char, _State>;
+      using _ConvFn
+	= codecvt_base::result
+	  (_Codecvt::*)(_State&, const _CharT*, const _CharT*, const _CharT*&,
+			char*, char*, char*&) const;
+      _ConvFn __fn = &codecvt<_CharT, char, _State>::out;
+      return __do_str_codecvt(__first, __last, __outstr, __cvt, __state,
+			      __count, __fn);
+    }
+
+  template<typename _CharT, typename _Traits, typename _Alloc, typename _State>
+    inline bool
+    __str_codecvt_out(const _CharT* __first, const _CharT* __last,
+		      basic_string<char, _Traits, _Alloc>& __outstr,
+		      const codecvt<_CharT, char, _State>& __cvt)
+    {
+      _State __state = {};
+      size_t __n;
+      return __str_codecvt_out(__first, __last, __outstr, __cvt, __state, __n);
+    }
+
 _GLIBCXX_BEGIN_NAMESPACE_CXX11
+
   /// String conversions
   template<typename _Codecvt, typename _Elem = wchar_t,
 	   typename _Wide_alloc = allocator<_Elem>,
@@ -137,9 +244,15 @@
       wide_string
       from_bytes(const char* __first, const char* __last)
       {
-	auto __errstr = _M_with_strings ? &_M_wide_err_string : nullptr;
-	_ConvFn<char, _Elem> __fn = &_Codecvt::in;
-	return _M_conv(__first, __last, __errstr, __fn);
+	if (!_M_with_cvtstate)
+	  _M_state = state_type();
+	wide_string __out{ _M_wide_err_string.get_allocator() };
+	if (__str_codecvt_in(__first, __last, __out, *_M_cvt, _M_state,
+			     _M_count))
+	  return __out;
+	if (_M_with_strings)
+	  return _M_wide_err_string;
+	__throw_range_error("wstring_convert::from_bytes");
       }
       /// @}
 
@@ -167,9 +280,15 @@
       byte_string
       to_bytes(const _Elem* __first, const _Elem* __last)
       {
-	auto __errstr = _M_with_strings ? &_M_byte_err_string : nullptr;
-	_ConvFn<_Elem, char> __fn = &_Codecvt::out;
-	return _M_conv(__first, __last, __errstr, __fn);
+	if (!_M_with_cvtstate)
+	  _M_state = state_type();
+	byte_string __out{ _M_byte_err_string.get_allocator() };
+	if (__str_codecvt_out(__first, __last, __out, *_M_cvt, _M_state,
+			      _M_count))
+	  return __out;
+	if (_M_with_strings)
+	  return _M_byte_err_string;
+	__throw_range_error("wstring_convert::to_bytes");
       }
       /// @}
 
@@ -182,63 +301,6 @@
       state_type state() const { return _M_state; }
 
     private:
-      template<typename _InC, typename _OutC>
-	using _ConvFn
-	  = codecvt_base::result
-	    (_Codecvt::*)(state_type&, const _InC*, const _InC*, const _InC*&,
-			  _OutC*, _OutC*, _OutC*&) const;
-
-      template<typename _InChar, typename _OutStr, typename _MemFn>
-	_OutStr
-	_M_conv(const _InChar* __first, const _InChar* __last,
-		const _OutStr* __err, _MemFn __memfn)
-	{
-	  auto __outstr = __err ? _OutStr(__err->get_allocator()) : _OutStr();
-
-	  if (__first == __last)
-	    {
-	      _M_count = 0;
-	      return __outstr;
-	    }
-
-	  if (!_M_with_cvtstate)
-	    _M_state = state_type();
-
-	  size_t __outchars = 0;
-	  auto __next = __first;
-	  const auto __maxlen = _M_cvt->max_length() + 1;
-
-	  codecvt_base::result __result;
-	  do
-	    {
-	      __outstr.resize(__outstr.size() + (__last - __next) * __maxlen);
-	      auto __outnext = &__outstr.front() + __outchars;
-	      auto const __outlast = &__outstr.back() + 1;
-	      __result = ((*_M_cvt).*__memfn)(_M_state, __next, __last, __next,
-					    __outnext, __outlast, __outnext);
-	      __outchars = __outnext - &__outstr.front();
-	    }
-	  while (__result == codecvt_base::partial && __next != __last
-		 && (__outstr.size() - __outchars) < __maxlen);
-
-	  if (__result == codecvt_base::noconv)
-	    {
-	      __outstr.assign(__first, __last);
-	      _M_count = __outstr.size();
-	      return __outstr;
-	    }
-
-	  __outstr.resize(__outchars);
-	  _M_count = __next - __first;
-
-	  if (__result != codecvt_base::error)
-	    return __outstr;
-	  else if (__err)
-	    return *__err;
-	  else
-	    __throw_range_error("wstring_convert");
-	}
-
       unique_ptr<_Codecvt>	_M_cvt;
       byte_string		_M_byte_err_string;
       wide_string		_M_wide_err_string;
@@ -247,6 +309,7 @@
       bool			_M_with_cvtstate = false;
       bool			_M_with_strings = false;
     };
+
 _GLIBCXX_END_NAMESPACE_CXX11
 
   /// Buffer conversions
Index: libstdc++-v3/include/bits/atomic_futex.h
===================================================================
--- libstdc++-v3/include/bits/atomic_futex.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/include/bits/atomic_futex.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -93,15 +93,15 @@
     {
       for (;;)
 	{
-	  // Don't bother checking the value again because we expect the caller to
-	  // have done it recently.
+	  // Don't bother checking the value again because we expect the caller
+	  // to have done it recently.
 	  // memory_order_relaxed is sufficient because we can rely on just the
 	  // modification order (store_notify uses an atomic RMW operation too),
 	  // and the futex syscalls synchronize between themselves.
 	  _M_data.fetch_or(_Waiter_bit, memory_order_relaxed);
-	  bool __ret;
-	  __ret = _M_futex_wait_until((unsigned*)(void*)&_M_data,
-	      __assumed | _Waiter_bit, __has_timeout, __s, __ns);
+	  bool __ret = _M_futex_wait_until((unsigned*)(void*)&_M_data,
+					   __assumed | _Waiter_bit,
+					   __has_timeout, __s, __ns);
 	  // Fetch the current value after waiting (clears _Waiter_bit).
 	  __assumed = _M_load(__mo);
 	  if (!__ret || ((__operand == __assumed) == __equal))
@@ -119,7 +119,7 @@
 	bool __equal, memory_order __mo)
     {
       return _M_load_and_test_until(__assumed, __operand, __equal, __mo,
-	  false, chrono::seconds(0), chrono::nanoseconds(0));
+				    false, {}, {});
     }
 
     // If a timeout occurs, returns a current value after the timeout;
@@ -146,7 +146,8 @@
     _M_load_when_not_equal(unsigned __val, memory_order __mo)
     {
       unsigned __i = _M_load(__mo);
-      if ((__i & ~_Waiter_bit) != __val) return;
+      if ((__i & ~_Waiter_bit) != __val)
+	return (__i & ~_Waiter_bit);
       // TODO Spin-wait first.
       return _M_load_and_test(__i, __val, false, __mo);
     }
Index: libstdc++-v3/include/bits/regex_scanner.tcc
===================================================================
--- libstdc++-v3/include/bits/regex_scanner.tcc	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/include/bits/regex_scanner.tcc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -99,6 +99,12 @@
       auto __c = *_M_current++;
       const char* __pos;
 
+      if (std::strchr(_M_spec_char, _M_ctype.narrow(__c, '\0')) == nullptr)
+	{
+	  _M_token = _S_token_ord_char;
+	  _M_value.assign(1, __c);
+	  return;
+	}
       if (__c == '\\')
 	{
 	  if (_M_current == _M_end)
Index: libstdc++-v3/include/bits/quoted_string.h
===================================================================
--- libstdc++-v3/include/bits/quoted_string.h	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/include/bits/quoted_string.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,164 @@
+// Helpers for quoted stream manipulators -*- C++ -*-
+
+// Copyright (C) 2013-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// Under Section 7 of GPL version 3, you are granted additional
+// permissions described in the GCC Runtime Library Exception, version
+// 3.1, as published by the Free Software Foundation.
+
+// You should have received a copy of the GNU General Public License and
+// a copy of the GCC Runtime Library Exception along with this program;
+// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
+// <http://www.gnu.org/licenses/>.
+
+/** @file bits/quoted_string.h
+ *  This is an internal header file, included by other library headers.
+ *  Do not attempt to use it directly. @headername{iomanip}
+ */
+
+#ifndef _GLIBCXX_QUOTED_STRING_H
+#define _GLIBCXX_QUOTED_STRING_H 1
+
+#pragma GCC system_header
+
+#if __cplusplus < 201103L
+# include <bits/c++0x_warning.h>
+#else
+#include <sstream>
+
+namespace std _GLIBCXX_VISIBILITY(default)
+{
+  namespace __detail {
+  _GLIBCXX_BEGIN_NAMESPACE_VERSION
+
+    /**
+     * @brief Struct for delimited strings.
+     */
+    template<typename _String, typename _CharT>
+      struct _Quoted_string
+      {
+	static_assert(is_reference<_String>::value
+		   || is_pointer<_String>::value,
+		      "String type must be pointer or reference");
+
+	_Quoted_string(_String __str, _CharT __del, _CharT __esc)
+	: _M_string(__str), _M_delim{__del}, _M_escape{__esc}
+	{ }
+
+	_Quoted_string&
+	operator=(_Quoted_string&) = delete;
+
+	_String _M_string;
+	_CharT _M_delim;
+	_CharT _M_escape;
+      };
+
+    /**
+     * @brief Inserter for quoted strings.
+     *
+     *  _GLIBCXX_RESOLVE_LIB_DEFECTS
+     *  DR 2344 quoted()'s interaction with padding is unclear
+     */
+    template<typename _CharT, typename _Traits>
+      std::basic_ostream<_CharT, _Traits>&
+      operator<<(std::basic_ostream<_CharT, _Traits>& __os,
+		 const _Quoted_string<const _CharT*, _CharT>& __str)
+      {
+	std::basic_ostringstream<_CharT, _Traits> __ostr;
+	__ostr << __str._M_delim;
+	for (const _CharT* __c = __str._M_string; *__c; ++__c)
+	  {
+	    if (*__c == __str._M_delim || *__c == __str._M_escape)
+	      __ostr << __str._M_escape;
+	    __ostr << *__c;
+	  }
+	__ostr << __str._M_delim;
+
+	return __os << __ostr.str();
+      }
+
+    /**
+     * @brief Inserter for quoted strings.
+     *
+     *  _GLIBCXX_RESOLVE_LIB_DEFECTS
+     *  DR 2344 quoted()'s interaction with padding is unclear
+     */
+    template<typename _CharT, typename _Traits, typename _String>
+      std::basic_ostream<_CharT, _Traits>&
+      operator<<(std::basic_ostream<_CharT, _Traits>& __os,
+		 const _Quoted_string<_String, _CharT>& __str)
+      {
+	std::basic_ostringstream<_CharT, _Traits> __ostr;
+	__ostr << __str._M_delim;
+	for (auto& __c : __str._M_string)
+	  {
+	    if (__c == __str._M_delim || __c == __str._M_escape)
+	      __ostr << __str._M_escape;
+	    __ostr << __c;
+	  }
+	__ostr << __str._M_delim;
+
+	return __os << __ostr.str();
+      }
+
+    /**
+     * @brief Extractor for delimited strings.
+     *        The left and right delimiters can be different.
+     */
+    template<typename _CharT, typename _Traits, typename _Alloc>
+      std::basic_istream<_CharT, _Traits>&
+      operator>>(std::basic_istream<_CharT, _Traits>& __is,
+		 const _Quoted_string<basic_string<_CharT, _Traits, _Alloc>&,
+				      _CharT>& __str)
+      {
+	_CharT __c;
+	__is >> __c;
+	if (!__is.good())
+	  return __is;
+	if (__c != __str._M_delim)
+	  {
+	    __is.unget();
+	    __is >> __str._M_string;
+	    return __is;
+	  }
+	__str._M_string.clear();
+	std::ios_base::fmtflags __flags
+	  = __is.flags(__is.flags() & ~std::ios_base::skipws);
+	do
+	  {
+	    __is >> __c;
+	    if (!__is.good())
+	      break;
+	    if (__c == __str._M_escape)
+	      {
+		__is >> __c;
+		if (!__is.good())
+		  break;
+	      }
+	    else if (__c == __str._M_delim)
+	      break;
+	    __str._M_string += __c;
+	  }
+	while (true);
+	__is.setf(__flags);
+
+	return __is;
+      }
+
+  _GLIBCXX_END_NAMESPACE_VERSION
+  } // namespace __detail
+} // namespace std
+
+#endif // C++11
+#endif /* _GLIBCXX_QUOTED_STRING_H */
Index: libstdc++-v3/include/bits/range_access.h
===================================================================
--- libstdc++-v3/include/bits/range_access.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/include/bits/range_access.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -98,6 +98,14 @@
     { return __arr + _Nm; }
 
 #if __cplusplus >= 201402L
+
+  template<typename _Tp> class valarray;
+  // These overloads must be declared for cbegin and cend to use them.
+  template<typename _Tp> _Tp* begin(valarray<_Tp>&);
+  template<typename _Tp> const _Tp* begin(const valarray<_Tp>&);
+  template<typename _Tp> _Tp* end(valarray<_Tp>&);
+  template<typename _Tp> const _Tp* end(const valarray<_Tp>&);
+
   /**
    *  @brief  Return an iterator pointing to the first element of
    *          the const container.
Index: libstdc++-v3/include/bits/regex_compiler.tcc
===================================================================
--- libstdc++-v3/include/bits/regex_compiler.tcc	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/include/bits/regex_compiler.tcc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -424,8 +424,7 @@
 	    __last_char.first = true;
 	    __last_char.second = _M_value[0];
 	  }
-      while (!_M_match_token(_ScannerT::_S_token_bracket_end))
-	_M_expression_term(__last_char, __matcher);
+      while (_M_expression_term(__last_char, __matcher));
       __matcher._M_ready();
       _M_stack.push(_StateSeqT(
 		      *_M_nfa,
@@ -434,21 +433,31 @@
 
   template<typename _TraitsT>
   template<bool __icase, bool __collate>
-    void
+    bool
     _Compiler<_TraitsT>::
     _M_expression_term(pair<bool, _CharT>& __last_char,
 		       _BracketMatcher<_TraitsT, __icase, __collate>& __matcher)
     {
+      if (_M_match_token(_ScannerT::_S_token_bracket_end))
+	return false;
+
       if (_M_match_token(_ScannerT::_S_token_collsymbol))
-	__matcher._M_add_collating_element(_M_value);
+	{
+	  auto __symbol = __matcher._M_add_collate_element(_M_value);
+	  if (__symbol.size() == 1)
+	    {
+	      __last_char.first = true;
+	      __last_char.second = __symbol[0];
+	    }
+	}
       else if (_M_match_token(_ScannerT::_S_token_equiv_class_name))
 	__matcher._M_add_equivalence_class(_M_value);
       else if (_M_match_token(_ScannerT::_S_token_char_class_name))
 	__matcher._M_add_character_class(_M_value, false);
-      // POSIX doesn't permit '-' as a start-range char (say [a-z--0]),
-      // except when the '-' is the first character in the bracket expression
-      // ([--0]). ECMAScript treats all '-' after a range as a normal character.
-      // Also see above, where _M_expression_term gets called.
+      // POSIX doesn't allow '-' as a start-range char (say [a-z--0]),
+      // except when the '-' is the first or last character in the bracket
+      // expression ([--0]). ECMAScript treats all '-' after a range as a
+      // normal character. Also see above, where _M_expression_term gets called.
       //
       // As a result, POSIX rejects [-----], but ECMAScript doesn't.
       // Boost (1.57.0) always uses POSIX style even in its ECMAScript syntax.
@@ -459,10 +468,14 @@
 	{
 	  if (!__last_char.first)
 	    {
+	      __matcher._M_add_char(_M_value[0]);
 	      if (_M_value[0] == '-'
 		  && !(_M_flags & regex_constants::ECMAScript))
-		__throw_regex_error(regex_constants::error_range);
-	      __matcher._M_add_char(_M_value[0]);
+		{
+		  if (_M_match_token(_ScannerT::_S_token_bracket_end))
+		    return false;
+		  __throw_regex_error(regex_constants::error_range);
+		}
 	      __last_char.first = true;
 	      __last_char.second = _M_value[0];
 	    }
@@ -496,6 +509,8 @@
 						     _M_value[0]));
       else
 	__throw_regex_error(regex_constants::error_brack);
+
+      return true;
     }
 
   template<typename _TraitsT>
Index: libstdc++-v3/include/Makefile.am
===================================================================
--- libstdc++-v3/include/Makefile.am	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/include/Makefile.am	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -128,6 +128,7 @@
 	${bits_srcdir}/postypes.h \
 	${bits_srcdir}/predefined_ops.h \
 	${bits_srcdir}/ptr_traits.h \
+	${bits_srcdir}/quoted_string.h \
 	${bits_srcdir}/random.h \
 	${bits_srcdir}/random.tcc \
 	${bits_srcdir}/range_access.h \
@@ -650,11 +651,23 @@
 	${experimental_srcdir}/optional \
 	${experimental_srcdir}/ratio \
 	${experimental_srcdir}/string_view \
+	${experimental_srcdir}/string_view.tcc \
 	${experimental_srcdir}/system_error \
-	${experimental_srcdir}/string_view.tcc \
 	${experimental_srcdir}/tuple \
-	${experimental_srcdir}/type_traits
+	${experimental_srcdir}/type_traits \
+	${experimental_filesystem_headers}
 
+if ENABLE_FILESYSTEM_TS
+experimental_filesystem_headers = \
+	${experimental_srcdir}/filesystem \
+	${experimental_srcdir}/fs_dir.h \
+	${experimental_srcdir}/fs_fwd.h \
+	${experimental_srcdir}/fs_ops.h \
+	${experimental_srcdir}/fs_path.h
+else
+experimental_filesystem_headers =
+endif
+
 # This is the common subset of C++ files that all three "C" header models use.
 c_base_srcdir = $(C_INCLUDE_DIR)
 c_base_builddir = .
Index: libstdc++-v3/libsupc++/Makefile.in
===================================================================
--- libstdc++-v3/libsupc++/Makefile.in	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/libsupc++/Makefile.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11.1 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -17,6 +17,23 @@
 
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -87,6 +104,12 @@
 am__base_list = \
   sed '$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;s/\n/ /g' | \
   sed '$$!N;$$!N;$$!N;$$!N;s/\n/ /g'
+am__uninstall_files_from_dir = { \
+  test -z "$$files" \
+    || { test ! -d "$$dir" && test ! -f "$$dir" && test ! -r "$$dir"; } \
+    || { echo " ( cd '$$dir' && rm -f" $$files ")"; \
+         $(am__cd) "$$dir" && rm -f $$files; }; \
+  }
 am__installdirs = "$(DESTDIR)$(toolexeclibdir)" "$(DESTDIR)$(bitsdir)" \
 	"$(DESTDIR)$(stddir)"
 LTLIBRARIES = $(noinst_LTLIBRARIES) $(toolexeclib_LTLIBRARIES)
@@ -129,6 +152,11 @@
 	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
 CXXLD = $(CXX)
 SOURCES = $(libsupc___la_SOURCES) $(libsupc__convenience_la_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 HEADERS = $(bits_HEADERS) $(std_HEADERS)
 ETAGS = etags
 CTAGS = ctags
@@ -544,6 +572,7 @@
 	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
 	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
 	esac;
+$(top_srcdir)/fragment.am:
 
 $(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
 	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
@@ -564,7 +593,6 @@
 	done
 install-toolexeclibLTLIBRARIES: $(toolexeclib_LTLIBRARIES)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibdir)"
 	@list='$(toolexeclib_LTLIBRARIES)'; test -n "$(toolexeclibdir)" || list=; \
 	list2=; for p in $$list; do \
 	  if test -f $$p; then \
@@ -572,6 +600,8 @@
 	  else :; fi; \
 	done; \
 	test -z "$$list2" || { \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibdir)" || exit 1; \
 	  echo " $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 '$(DESTDIR)$(toolexeclibdir)'"; \
 	  $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 "$(DESTDIR)$(toolexeclibdir)"; \
 	}
@@ -593,9 +623,9 @@
 	  echo "rm -f \"$${dir}/so_locations\""; \
 	  rm -f "$${dir}/so_locations"; \
 	done
-libsupc++.la: $(libsupc___la_OBJECTS) $(libsupc___la_DEPENDENCIES) 
+libsupc++.la: $(libsupc___la_OBJECTS) $(libsupc___la_DEPENDENCIES) $(EXTRA_libsupc___la_DEPENDENCIES) 
 	$(CXXLINK) -rpath $(toolexeclibdir) $(libsupc___la_OBJECTS) $(libsupc___la_LIBADD) $(LIBS)
-libsupc++convenience.la: $(libsupc__convenience_la_OBJECTS) $(libsupc__convenience_la_DEPENDENCIES) 
+libsupc++convenience.la: $(libsupc__convenience_la_OBJECTS) $(libsupc__convenience_la_DEPENDENCIES) $(EXTRA_libsupc__convenience_la_DEPENDENCIES) 
 	$(CXXLINK)  $(libsupc__convenience_la_OBJECTS) $(libsupc__convenience_la_LIBADD) $(LIBS)
 
 mostlyclean-compile:
@@ -696,10 +726,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:
Index: libstdc++-v3/libsupc++/eh_ptr.cc
===================================================================
--- libstdc++-v3/libsupc++/eh_ptr.cc	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/libsupc++/eh_ptr.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -245,6 +245,9 @@
   __GXX_INIT_DEPENDENT_EXCEPTION_CLASS(dep->unwindHeader.exception_class);
   dep->unwindHeader.exception_cleanup = __gxx_dependent_exception_cleanup;
 
+  __cxa_eh_globals *globals = __cxa_get_globals ();
+  globals->uncaughtExceptions += 1;
+
 #ifdef _GLIBCXX_SJLJ_EXCEPTIONS
   _Unwind_SjLj_RaiseException (&dep->unwindHeader);
 #else
Index: libstdc++-v3/ChangeLog
===================================================================
--- libstdc++-v3/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,190 @@
+2015-09-03  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/std/shared_mutex (shared_timed_mutex::shared_timed_mutex):
+	Replace throw with __throw_bad_alloc.
+
+	PR libstdc++/66998
+	* include/experimental/functional (_Not_fn): Add exception
+	specifications and non-deduced return types.
+	(not_fn): Add exception specification and wrap pointer-to-member.
+	* testsuite/experimental/functional/not_fn.cc: Test in SFINAE context
+	and test pointer-to-member.
+
+	Backport from mainline
+	2015-08-27  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/67374
+	* include/bits/range_access.h (valarray, begin, end): Declare.
+	* testsuite/26_numerics/valarray/range_access.cc: Test const
+	overloads.
+	* testsuite/26_numerics/valarray/range_access2.cc: New.
+
+	Backport from mainline
+	2015-07-24  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/bits/atomic_futex.h [_GLIBCXX_HAVE_LINUX_FUTEX]
+	(_M_load_and_test_until): Whitespace.
+	(_M_load_and_test): Value-initialize the unused durations.
+	(_M_load_when_equal): Add missing return value.
+
+	Backport from mainline
+	2015-07-13  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/66855
+	* src/c++11/codecvt.cc (__codecvt_utf8_utf16_base::do_in): Override
+	endianness bit in mode.
+	* testsuite/22_locale/codecvt/codecvt_utf8_utf16/66855.cc: New.
+
+	Backport from mainline
+	2015-04-27  Dmitry Prokoptsev  <dprokoptsev@gmail.com>
+		    Michael Hanselmann  <public@hansmi.ch>
+
+	PR libstdc++/62258
+	* libsupc++/eh_ptr.cc (rethrow_exception): Increment count of
+	uncaught exceptions.
+	* testsuite/18_support/exception_ptr/62258.cc: New.
+
+2015-08-28  Tim Shen  <timshen@google.com>
+
+	Backport from mainline
+	2015-08-28  Tim Shen  <timshen@google.com>
+
+	PR libstdc++/67362
+	* include/bits/regex_scanner.tcc (_Scanner<>::_M_scan_normal):
+	Always returns ordinary char token if the char isn't
+	considered a special char.
+	* testsuite/28_regex/regression.cc: New test file for collecting
+	regression testcases from, typically, bugzilla.
+
+2015-08-20  Jonathan Wakely  <jwakely@redhat.com>
+
+	* python/Makefile.am: Ensure gdb.py is installed for libstdc++ not
+	libstdc++fs.
+	* python/Makefile.in: Regenerate.
+
+2015-08-18  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backport Filesystem TS from mainline
+	* acinclude.m4 (GLIBCXX_ENABLE_FILESYSTEM_TS,
+	GLIBCXX_CHECK_FILESYSTEM_DEPS): Define.
+	* configure.ac: Use them.
+	* configure: Regenerate.
+	* config.h.in: Regenerate.
+	* include/Makefile.am: Add filesystem headers. Fix order of headers.
+	* include/Makefile.in: Regenerate.
+	* include/bits/locale_conv.h (__do_str_codecvt, __str_codecvt_in,
+	__str_codecvt_out, wstring_convert): Refactor to move all conversion
+	logic to non-member functions.
+	* include/bits/quoted_string.h (_Quoted_string, operator<<,
+	operator>>): Move from <iomanip> to new header.
+	* include/experimental/filesystem: New.
+	* include/experimental/fs_dir.h: New.
+	* include/experimental/fs_fwd.h: New.
+	* include/experimental/fs_ops.h: New.
+	* include/experimental/fs_path.h: New.
+	* include/std/iomanip (_Quoted_string, operator<<, operator>>): Move
+	to <bits/quoted_string.h>.
+	* libstdcxx/v6/printers.py (StdExpPathPrinter): Define.
+	* scripts/testsuite_flags.in: Add filesystem dir to ldflags.
+	* src/Makefile.am: Add filesystem sub-dir.
+	* src/Makefile.in: Regenerate.
+	* src/filesystem/Makefile.am: New.
+	* src/filesystem/Makefile.in: New.
+	* src/filesystem/dir.cc: New.
+	* src/filesystem/ops.cc: New.
+	* src/filesystem/path.cc: New.
+	* testsuite/experimental/filesystem/operations/absolute.cc: New.
+	* testsuite/experimental/filesystem/operations/copy.cc: New.
+	* testsuite/experimental/filesystem/operations/current_path.cc: New.
+	* testsuite/experimental/filesystem/operations/exists.cc: New.
+	* testsuite/experimental/filesystem/operations/file_size.cc: New.
+	* testsuite/experimental/filesystem/operations/status.cc: New.
+	* testsuite/experimental/filesystem/operations/temp_directory_path.cc:
+	New.
+	* testsuite/experimental/filesystem/path/append/path.cc: New.
+	* testsuite/experimental/filesystem/path/assign/assign.cc: New.
+	* testsuite/experimental/filesystem/path/assign/copy.cc: New.
+	* testsuite/experimental/filesystem/path/compare/compare.cc: New.
+	* testsuite/experimental/filesystem/path/compare/path.cc: New.
+	* testsuite/experimental/filesystem/path/compare/strings.cc: New.
+	* testsuite/experimental/filesystem/path/concat/path.cc: New.
+	* testsuite/experimental/filesystem/path/concat/strings.cc: New.
+	* testsuite/experimental/filesystem/path/construct/copy.cc: New.
+	* testsuite/experimental/filesystem/path/construct/default.cc: New.
+	* testsuite/experimental/filesystem/path/construct/locale.cc: New.
+	* testsuite/experimental/filesystem/path/construct/range.cc: New.
+	* testsuite/experimental/filesystem/path/decompose/extension.cc: New.
+	* testsuite/experimental/filesystem/path/decompose/filename.cc: New.
+	* testsuite/experimental/filesystem/path/decompose/parent_path.cc:
+	New.
+	* testsuite/experimental/filesystem/path/decompose/relative_path.cc:
+	New.
+	* testsuite/experimental/filesystem/path/decompose/root_directory.cc:
+	New.
+	* testsuite/experimental/filesystem/path/decompose/root_name.cc: New.
+	* testsuite/experimental/filesystem/path/decompose/root_path.cc: New.
+	* testsuite/experimental/filesystem/path/decompose/stem.cc: New.
+	* testsuite/experimental/filesystem/path/generic/generic_string.cc:
+	New.
+	* testsuite/experimental/filesystem/path/itr/traversal.cc: New.
+	* testsuite/experimental/filesystem/path/modifiers/clear.cc: New.
+	* testsuite/experimental/filesystem/path/modifiers/make_preferred.cc:
+	New.
+	* testsuite/experimental/filesystem/path/modifiers/remove_filename.cc:
+	New.
+	* testsuite/experimental/filesystem/path/modifiers/
+	replace_extension.cc: New.
+	* testsuite/experimental/filesystem/path/modifiers/replace_filename.cc:
+	New.
+	* testsuite/experimental/filesystem/path/modifiers/swap.cc: New.
+	* testsuite/experimental/filesystem/path/nonmember/hash_value.cc:
+	New.
+	* testsuite/experimental/filesystem/path/query/empty.cc: New.
+	* testsuite/experimental/filesystem/path/query/has_extension.cc: New.
+	* testsuite/experimental/filesystem/path/query/has_filename.cc: New.
+	* testsuite/experimental/filesystem/path/query/has_parent_path.cc:
+	New.
+	* testsuite/experimental/filesystem/path/query/has_relative_path.cc:
+	New.
+	* testsuite/experimental/filesystem/path/query/has_root_directory.cc:
+	New.
+	* testsuite/experimental/filesystem/path/query/has_root_name.cc: New.
+	* testsuite/experimental/filesystem/path/query/has_root_path.cc: New.
+	* testsuite/experimental/filesystem/path/query/has_stem.cc: New.
+	* testsuite/experimental/filesystem/path/query/is_relative.cc: New.
+	* testsuite/lib/dg-options.exp (dg-require-filesystem-ts): Define.
+	* testsuite/lib/libstdc++.exp (check_v3_target_filesystem_ts): Define.
+	* testsuite/util/testsuite_fs.h: New.
+
+2015-08-18  Jonathan Wakely  <jwakely@redhat.com>
+
+	* Makefile.in: Regenerate with automake-1.11.6.
+	* aclocal.m4: Likewise.
+	* configure: Likewise.
+	* doc/Makefile.in: Likewise.
+	* include/Makefile.in: Likewise.
+	* libsupc++/Makefile.in: Likewise.
+	* po/Makefile.in: Likewise.
+	* python/Makefile.in: Likewise.
+	* src/Makefile.in: Likewise.
+	* src/c++11/Makefile.in: Likewise.
+	* src/c++98/Makefile.in: Likewise.
+	* testsuite/Makefile.in: Likewise.
+
+2015-07-29  Tim Shen  <timshen@google.com>
+
+	Backport from mainline
+	2015-07-29  Tim Shen  <timshen@google.com>
+
+	PR libstdc++/67015
+	* include/bits/regex_compiler.h (_Compiler<>::_M_expression_term,
+	_BracketMatcher<>::_M_add_collating_element): Change signature
+	to make checking the and of bracket expression easier.
+	* include/bits/regex_compiler.tcc (_Compiler<>::_M_expression_term):
+	Treat '-' as a valid literal if it's at the end of bracket expression.
+	* testsuite/28_regex/algorithms/regex_match/cstring_bracket_01.cc:
+	New testcases.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: libstdc++-v3/testsuite/Makefile.in
===================================================================
--- libstdc++-v3/testsuite/Makefile.in	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/testsuite/Makefile.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11.1 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -15,6 +15,23 @@
 
 @SET_MAKE@
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 depcomp =
 am__depfiles_maybe =
 SOURCES =
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ABI_TWEAKS_SRCDIR = @ABI_TWEAKS_SRCDIR@
 ACLOCAL = @ACLOCAL@
 ALLOCATOR_H = @ALLOCATOR_H@
@@ -370,6 +392,7 @@
 	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
 	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
 	esac;
+$(top_srcdir)/fragment.am:
 
 $(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
 	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
@@ -405,10 +428,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:
Index: libstdc++-v3/testsuite/28_regex/regression.cc
===================================================================
--- libstdc++-v3/testsuite/28_regex/regression.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/28_regex/regression.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,42 @@
+// { dg-options "-std=gnu++11" }
+
+//
+// Copyright (C) 2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+//
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+#include <testsuite_hooks.h>
+#include <testsuite_regex.h>
+
+using namespace __gnu_test;
+using namespace std;
+
+// PR libstdc++/67362
+void
+test01()
+{
+  bool test __attribute__((unused)) = true;
+
+  regex re("((.)", regex_constants::basic);
+}
+
+int
+main()
+{
+  test01();
+  return 0;
+}
+
Index: libstdc++-v3/testsuite/28_regex/algorithms/regex_match/cstring_bracket_01.cc
===================================================================
--- libstdc++-v3/testsuite/28_regex/algorithms/regex_match/cstring_bracket_01.cc	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/testsuite/28_regex/algorithms/regex_match/cstring_bracket_01.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -82,6 +82,22 @@
     VERIFY(e.code() == std::regex_constants::error_range);
   }
   std::regex re("[-----]", std::regex::ECMAScript);
+
+  VERIFY(!regex_match("b", regex("[-ac]", regex_constants::extended)));
+  VERIFY(!regex_match("b", regex("[ac-]", regex_constants::extended)));
+  VERIFY(regex_match("b", regex("[^-ac]", regex_constants::extended)));
+  VERIFY(regex_match("b", regex("[^ac-]", regex_constants::extended)));
+  VERIFY(regex_match("&", regex("[%--]", regex_constants::extended)));
+  VERIFY(regex_match(".", regex("[--@]", regex_constants::extended)));
+  try
+  {
+    regex("[a--@]", regex_constants::extended);
+    VERIFY(false);
+  }
+  catch (const std::regex_error& e)
+  {
+  }
+  VERIFY(regex_match("].", regex("[][.hyphen.]-0]*", regex_constants::extended)));
 }
 
 void
@@ -115,6 +131,44 @@
   VERIFY(regex_match_debug("w", re));
 }
 
+// libstdc++/67015
+void
+test05()
+{
+  bool test __attribute__((unused)) = true;
+
+  regex lanana_namespace("^[a-z0-9]+$", regex::extended);
+  regex lsb_namespace("^_?([a-z0-9_.]+-, regex::extended)+[a-z0-9]+$");
+  regex debian_dpkg_conffile_cruft("dpkg-(old|dist|new|tmp, regex::extended)$");
+  regex debian_cron_namespace("^[a-z0-9][a-z0-9-]*$", regex::extended);
+  VERIFY(regex_match("test", debian_cron_namespace));
+  VERIFY(!regex_match("-a", debian_cron_namespace));
+  VERIFY(regex_match("a-", debian_cron_namespace));
+  regex debian_cron_namespace_ok("^[a-z0-9][-a-z0-9]*$", regex::extended);
+  VERIFY(regex_match("test", debian_cron_namespace_ok));
+  VERIFY(!regex_match("-a", debian_cron_namespace_ok));
+  VERIFY(regex_match("a-", debian_cron_namespace_ok));
+}
+
+// libstdc++/67015
+void
+test06()
+{
+  bool test __attribute__((unused)) = true;
+
+  regex lanana_namespace("^[a-z0-9]+$");
+  regex lsb_namespace("^_?([a-z0-9_.]+-)+[a-z0-9]+$");
+  regex debian_dpkg_conffile_cruft("dpkg-(old|dist|new|tmp)$");
+  regex debian_cron_namespace("^[a-z0-9][a-z0-9-]*$");
+  VERIFY(regex_match("test", debian_cron_namespace));
+  VERIFY(!regex_match("-a", debian_cron_namespace));
+  VERIFY(regex_match("a-", debian_cron_namespace));
+  regex debian_cron_namespace_ok("^[a-z0-9][-a-z0-9]*$");
+  VERIFY(regex_match("test", debian_cron_namespace_ok));
+  VERIFY(!regex_match("-a", debian_cron_namespace_ok));
+  VERIFY(regex_match("a-", debian_cron_namespace_ok));
+}
+
 int
 main()
 {
@@ -122,5 +176,8 @@
   test02();
   test03();
   test04();
+  test05();
+  test06();
+
   return 0;
 }
Index: libstdc++-v3/testsuite/18_support/exception_ptr/62258.cc
===================================================================
--- libstdc++-v3/testsuite/18_support/exception_ptr/62258.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/18_support/exception_ptr/62258.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,61 @@
+// { dg-options "-std=gnu++11" }
+// { dg-require-atomic-builtins "" }
+
+// Copyright (C) 2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// PR libstdc++/62258
+
+#include <exception>
+#include <testsuite_hooks.h>
+
+struct check_on_destruct
+{
+  ~check_on_destruct();
+};
+
+check_on_destruct::~check_on_destruct()
+{
+  VERIFY(std::uncaught_exception());
+}
+
+int main ()
+{
+  VERIFY(!std::uncaught_exception());
+
+  try
+    {
+      check_on_destruct check;
+
+      try
+        {
+          throw 1;
+        }
+      catch (...)
+        {
+          VERIFY(!std::uncaught_exception());
+
+          std::rethrow_exception(std::current_exception());
+        }
+    }
+  catch (...)
+    {
+      VERIFY(!std::uncaught_exception());
+    }
+
+  VERIFY(!std::uncaught_exception());
+}
Index: libstdc++-v3/testsuite/22_locale/codecvt/codecvt_utf8_utf16/66855.cc
===================================================================
--- libstdc++-v3/testsuite/22_locale/codecvt/codecvt_utf8_utf16/66855.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/22_locale/codecvt/codecvt_utf8_utf16/66855.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,52 @@
+// Copyright (C) 2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++11" }
+
+#include <codecvt>
+#include <testsuite_hooks.h>
+
+void
+test01()
+{
+  std::codecvt_utf8_utf16<char16_t> cvt;
+  char16_t utf16[] = u"\ub098\ub294\ud0dc\uc624";
+  const char16_t* nf16;
+  char utf8[16];
+  char* nt8;
+  std::mbstate_t st{};
+  auto res = cvt.out(st, utf16, utf16+4, nf16, utf8, utf8+16, nt8);
+  VERIFY( res == std::codecvt_base::ok );
+
+  st = {};
+  char16_t buf[4] = {};
+  const char* nf8 = nt8;
+  char16_t* nt16;
+  res = cvt.in(st, utf8, nf8, nf8, buf, buf+4, nt16);
+  VERIFY( res == std::codecvt_base::ok );
+  VERIFY( nt16 == buf+4 );
+  VERIFY( buf[0] == utf16[0] );
+  VERIFY( buf[1] == utf16[1] );
+  VERIFY( buf[2] == utf16[2] );
+  VERIFY( buf[3] == utf16[3] );
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/lib/libstdc++.exp
===================================================================
--- libstdc++-v3/testsuite/lib/libstdc++.exp	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/testsuite/lib/libstdc++.exp	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1894,6 +1894,59 @@
     return $et_little_endian
 }
 
+proc check_v3_target_filesystem_ts { } {
+    global cxxflags
+    global DEFAULT_CXXFLAGS
+    global et_filesystem_ts
+    global tool
+
+    if { ![info exists et_filesystem_ts_target_name] } {
+	set et_filesystem_ts_target_name ""
+    }
+
+    # If the target has changed since we set the cached value, clear it.
+    set current_target [current_target_name]
+    if { $current_target != $et_filesystem_ts_target_name } {
+	verbose "check_v3_target_filesystem_ts: `$et_filesystem_ts_target_name'" 2
+	set et_filesystem_ts_target_name $current_target
+	if [info exists et_filesystem_ts] {
+	    verbose "check_v3_target_filesystem_ts: removing cached result" 2
+	    unset et_filesystem_ts
+	}
+    }
+
+    if [info exists et_filesystem_ts] {
+	verbose "check_v3_target_filesystem_ts: using cached result" 2
+    } else {
+	set et_filesystem_ts 0
+
+	# Set up and preprocess a C++ test program that depends
+	# on debug mode activated.
+	set src filesystem_ts[pid].cc
+
+	set f [open $src "w"]
+	puts $f "#include <experimental/filesystem>"
+	puts $f "#if ! __cpp_lib_experimental_filesystem"
+	puts $f "#  error No Filesystem TS support"
+	puts $f "#endif"
+	close $f
+
+	set cxxflags_saved $cxxflags
+	set cxxflags "$cxxflags $DEFAULT_CXXFLAGS -Werror -std=gnu++11"
+
+	set lines [v3_target_compile $src /dev/null preprocess ""]
+	set cxxflags $cxxflags_saved
+	file delete $src
+
+	if [string match "" $lines] {
+	    # No error message, preprocessing succeeded.
+	    set et_filesystem_ts 1
+	}
+    }
+    verbose "check_v3_target_filesystem_ts: $et_filesystem_ts" 2
+    return $et_filesystem_ts
+}
+
 set additional_prunes ""
 
 if { [info exists env(GCC_RUNTEST_PARALLELIZE_DIR)] \
Index: libstdc++-v3/testsuite/lib/dg-options.exp
===================================================================
--- libstdc++-v3/testsuite/lib/dg-options.exp	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/testsuite/lib/dg-options.exp	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -223,6 +223,15 @@
     return
 }
 
+proc dg-require-filesystem-ts { args } {
+    if { ![ check_v3_target_filesystem_ts ] } {
+	upvar dg-do-what dg-do-what
+	set dg-do-what [list [lindex ${dg-do-what} 0] "N" "P"]
+	return
+    }
+    return
+}
+
 proc add_options_for_no_pch { flags } {
     # This forces any generated and possibly included PCH to be invalid.
     return "-D__GLIBCXX__=99999999"
Index: libstdc++-v3/testsuite/26_numerics/valarray/range_access2.cc
===================================================================
--- libstdc++-v3/testsuite/26_numerics/valarray/range_access2.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/26_numerics/valarray/range_access2.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,36 @@
+// { dg-do compile }
+// { dg-options "-std=gnu++14" }
+
+// Copyright (C) 2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 26.6.10 valarray range access: [valarray.range]
+
+#include <iterator>
+#include <valarray>
+
+// PR libstdc++/67374
+void
+test01()
+{
+  std::valarray<double> va{1.0, 2.0, 3.0};
+  std::cbegin(va);
+  std::cend(va);
+  const auto& cva = va;
+  std::cbegin(cva);
+  std::cend(cva);
+}
Index: libstdc++-v3/testsuite/26_numerics/valarray/range_access.cc
===================================================================
--- libstdc++-v3/testsuite/26_numerics/valarray/range_access.cc	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/testsuite/26_numerics/valarray/range_access.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -28,4 +28,7 @@
   std::valarray<double> va{1.0, 2.0, 3.0};
   std::begin(va);
   std::end(va);
+  const auto& cva = va;
+  std::begin(cva);
+  std::end(cva);
 }
Index: libstdc++-v3/testsuite/experimental/functional/not_fn.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/functional/not_fn.cc	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/testsuite/experimental/functional/not_fn.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -20,6 +20,8 @@
 #include <experimental/functional>
 #include <testsuite_hooks.h>
 
+using std::experimental::not_fn;
+
 int func(int, char) { return 0; }
 
 struct F
@@ -33,8 +35,6 @@
 void
 test01()
 {
-  using std::experimental::not_fn;
-
   auto f1 = not_fn(func);
   VERIFY( f1(1, '2') == true );
 
@@ -50,8 +50,36 @@
   VERIFY( f5(1) == false );
 }
 
+template<typename F, typename Arg>
+auto foo(F f, Arg arg) -> decltype(not_fn(f)(arg)) { return not_fn(f)(arg); }
+
+template<typename F, typename Arg>
+auto foo(F f, Arg arg) -> decltype(not_fn(f)()) { return not_fn(f)(); }
+
+struct negator
+{
+    bool operator()(int) const { return false; }
+    void operator()() const {}
+};
+
+void 
+test02()
+{
+  foo(negator{}, 1); // PR libstdc++/66998
+}
+
+void
+test03()
+{
+  struct X { bool b; };
+  X x{ false };
+  VERIFY( not_fn(&X::b)(x) );
+}
+
 int
 main()
 {
   test01();
+  test02();
+  test03();
 }
Index: libstdc++-v3/testsuite/experimental/filesystem/operations/absolute.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/operations/absolute.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/operations/absolute.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,55 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 15.1 Absolute [fs.op.absolute]
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+    VERIFY( absolute(p).is_absolute() );
+}
+
+void
+test02()
+{
+  path p1("/");
+  VERIFY( absolute(p1) == p1 );
+  VERIFY( absolute(p1, "/bar") == p1 );
+  path p2("/foo");
+  VERIFY( absolute(p2) == p2 );
+  VERIFY( absolute(p2, "/bar") == p2 );
+  path p3("foo");
+  VERIFY( absolute(p3) != p3 );
+  VERIFY( absolute(p3, "/bar") == "/bar/foo" );
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/operations/current_path.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/operations/current_path.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/operations/current_path.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,57 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 15.11 Current path [fs.op.current_path]
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+#include <testsuite_hooks.h>
+
+namespace fs = std::experimental::filesystem;
+
+void
+test01()
+{
+  fs::path dot(".");
+  fs::path cwd = fs::current_path();
+  std::error_code ec;
+  fs::path cwd2 = fs::current_path(ec);
+  VERIFY( cwd == cwd2 );
+}
+
+void
+test02()
+{
+  auto oldwd = fs::current_path();
+  auto tmpdir = fs::temp_directory_path();
+  current_path(tmpdir);
+  VERIFY( canonical(fs::current_path()) == canonical(tmpdir) );
+  std::error_code ec;
+  current_path(oldwd, ec);
+  VERIFY( canonical(fs::current_path()) == canonical(oldwd) );
+  VERIFY( canonical(fs::current_path(ec)) == canonical(oldwd) );
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/operations/exists.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/operations/exists.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/operations/exists.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,58 @@
+// Copyright (C) 2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  VERIFY( exists(path{"/"}) );
+  VERIFY( exists(path{"/."}) );
+  VERIFY( exists(path{"."}) );
+}
+
+void
+test02()
+{
+  path rel{"xXxXx"};
+  while (exists(rel))
+    rel /= "x";
+  VERIFY( !exists(rel) );
+}
+
+void
+test03()
+{
+  path abs{"/xXxXx"};
+  while (exists(abs))
+    abs /= "x";
+  VERIFY( !exists(abs) );
+}
+
+int
+main()
+{
+  test01();
+  test02();
+  test03();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/operations/status.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/operations/status.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/operations/status.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,58 @@
+// Copyright (C) 2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+namespace fs = std::experimental::filesystem;
+
+void
+test01()
+{
+  std::error_code ec;
+  fs::file_status st1 = fs::status(".", ec);
+  VERIFY( !ec );
+  VERIFY( st1.type() == fs::file_type::directory );
+
+  fs::file_status st2 = fs::status(".");
+  VERIFY( st2.type() == fs::file_type::directory );
+}
+
+void
+test02()
+{
+  fs::path p = __gnu_test::nonexistent_path();
+
+  std::error_code ec;
+  fs::file_status st1 = fs::status(p, ec);
+  VERIFY( ec );
+  VERIFY( st1.type() == fs::file_type::not_found );
+
+  fs::file_status st2 = fs::status(p);
+  VERIFY( st2.type() == fs::file_type::not_found );
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/operations/temp_directory_path.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/operations/temp_directory_path.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/operations/temp_directory_path.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,80 @@
+// Copyright (C) 2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+#include <experimental/filesystem>
+#include <stdlib.h>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+void
+clean_env()
+{
+  ::unsetenv("TMPDIR");
+  ::unsetenv("TMP");
+  ::unsetenv("TEMPDIR");
+  ::unsetenv("TEMP");
+}
+
+namespace fs = std::experimental::filesystem;
+
+void
+test01()
+{
+  clean_env();
+
+  if (!fs::exists("/tmp"))
+    return; // just give up
+
+  std::error_code ec;
+  fs::path p1 = fs::temp_directory_path(ec);
+  VERIFY( exists(p1) );
+
+  fs::path p2 = fs::temp_directory_path();
+  VERIFY( p1 == p2 );
+}
+
+void
+test02()
+{
+  clean_env();
+
+  if (::setenv("TMPDIR", __gnu_test::nonexistent_path().string().c_str(), 1))
+    return; // just give up
+
+  std::error_code ec;
+  fs::path p = fs::temp_directory_path(ec);
+  VERIFY( ec );
+
+  std::error_code ec2;
+  try {
+    p = fs::temp_directory_path();
+  } catch (const fs::filesystem_error& e) {
+    ec2 = e.code();
+  }
+  VERIFY( ec2 == ec );
+}
+
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/operations/file_size.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/operations/file_size.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/operations/file_size.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,70 @@
+// Copyright (C) 2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+namespace fs = std::experimental::filesystem;
+
+void
+test01()
+{
+  std::error_code ec;
+  size_t size = fs::file_size(".", ec);
+  VERIFY( ec == std::errc::is_a_directory );
+  VERIFY( size == -1 );
+
+  try {
+    size = fs::file_size(".");
+    ec.clear();
+  } catch (const fs::filesystem_error& e) {
+    ec = e.code();
+  }
+  VERIFY( ec == std::errc::is_a_directory );
+  VERIFY( size == -1 );
+}
+
+void
+test02()
+{
+  fs::path p = __gnu_test::nonexistent_path();
+
+  std::error_code ec;
+  size_t size = fs::file_size(p, ec);
+  VERIFY( ec );
+  VERIFY( size == -1 );
+
+  try {
+    size = fs::file_size(p);
+    ec.clear();
+  } catch (const fs::filesystem_error& e) {
+    ec = e.code();
+  }
+  VERIFY( ec );
+  VERIFY( size == -1 );
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/operations/copy.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/operations/copy.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/operations/copy.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,55 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 15.3 Copy [fs.op.copy]
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+    VERIFY( absolute(p).is_absolute() );
+}
+
+void
+test02()
+{
+  path p1("/");
+  VERIFY( absolute(p1) == p1 );
+  VERIFY( absolute(p1, "/bar") == p1 );
+  path p2("/foo");
+  VERIFY( absolute(p2) == p2 );
+  VERIFY( absolute(p2, "/bar") == p2 );
+  path p3("foo");
+  VERIFY( absolute(p3) != p3 );
+  VERIFY( absolute(p3, "/bar") == "/bar/foo" );
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/make_preferred.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/make_preferred.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/make_preferred.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,63 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.5 path modifiers [path.modifiers]
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+template<typename T, T sep>
+struct checker
+{
+  static void check(const char* s) { }
+};
+
+template<>
+struct checker<char, '/'>
+{
+  static void check()
+  {
+    VERIFY( path("foo/bar").make_preferred() == "foo/bar" );
+  }
+};
+
+template<>
+struct checker<wchar_t, L'\\'>
+{
+  static void check()
+  {
+    VERIFY( path("foo/bar").make_preferred() == L"foo\\bar" );
+  }
+};
+
+void
+test01()
+{
+  checker<path::value_type, path::preferred_separator>::check();
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/replace_filename.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/replace_filename.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/replace_filename.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,52 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.5 path modifiers [path.modifiers]
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  VERIFY( path("/foo").replace_filename("bar") == "/bar" );
+  VERIFY( path("/").replace_filename("bar") == "bar" );
+}
+
+void
+test02()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    path p2(p);
+    p2.replace_filename(p.filename());
+    VERIFY( p2 == p );
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/remove_filename.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/remove_filename.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/remove_filename.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,53 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.5 path modifiers [path.modifiers]
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  VERIFY( path("/foo").remove_filename() == "/" );
+  VERIFY( path("/").remove_filename() == "" );
+}
+
+void
+test02()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    path p2(p);
+    p2.remove_filename();
+    p2 /= p.filename();
+    VERIFY( p2 == p );
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/clear.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/clear.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/clear.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,45 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.5 path modifiers [path.modifiers]
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (path p : __gnu_test::test_paths)
+  {
+    path empty;
+    p.clear();
+    VERIFY( p.empty() );
+    __gnu_test::compare_paths(p, empty);
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/replace_extension.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/replace_extension.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/replace_extension.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,52 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.5 path modifiers [path.modifiers]
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  VERIFY( path("/foo.txt").replace_extension("cpp") == "/foo.cpp" );
+  VERIFY( path("/foo.txt").replace_extension(".cpp") == "/foo.cpp" );
+  VERIFY( path("/").replace_extension("bar") == "/.bar" );
+}
+
+void
+test02()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    path p2 = p;
+    VERIFY(p2.replace_extension(p2.extension()) == p);
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/swap.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/swap.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/modifiers/swap.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,44 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.5 path modifiers [path.modifiers]
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  const path p("/foo/bar");
+  path p1;
+  path p2 = p;
+  p1.swap(p2);
+  VERIFY( p2.empty() );
+  __gnu_test::compare_paths(p1, p);
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/nonmember/hash_value.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/nonmember/hash_value.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/nonmember/hash_value.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,51 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.6 path non-member functions [path.non-member]
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  VERIFY( hash_value(path("a//b")) == hash_value(path("a/b")) );
+  VERIFY( hash_value(path("a/")) == hash_value(path("a/.")) );
+}
+
+void
+test02()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    path pp = p.native();
+    VERIFY( hash_value(p) == hash_value(pp) );
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/assign/assign.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/assign/assign.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/assign/assign.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,89 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+using __gnu_test::compare_paths;
+
+void
+test01()
+{
+  for (std::string s : __gnu_test::test_paths)
+  {
+    path p0 = s, p1, p2, p3, p4;
+
+    p1 = s;
+    compare_paths(p0, p1);
+
+    p2 = s.c_str();
+    compare_paths(p0, p2);
+
+    std::wstring ws(s.begin(), s.end());
+
+    p3 = ws;
+    compare_paths(p0, p3);
+
+    p4 = ws.c_str();
+    compare_paths(p0, p4);
+  }
+}
+
+void
+test02()
+{
+  for (std::string s : __gnu_test::test_paths)
+  {
+    path p0 = s, p1, p2, p3, p4, p5, p6, p7, p8;
+
+    p1.assign(s);
+    compare_paths(p0, p1);
+
+    p2.assign( s.begin(), s.end() );
+    compare_paths(p0, p2);
+
+    p3.assign( s.c_str() );
+    compare_paths(p0, p3);
+
+    p4.assign( s.c_str(), s.c_str() + s.size() );
+    compare_paths(p0, p4);
+
+    std::wstring ws(s.begin(), s.end());
+
+    p5.assign(ws);
+    compare_paths(p0, p5);
+
+    p6.assign( ws.begin(), ws.end() );
+    compare_paths(p0, p6);
+
+    p7.assign( ws.c_str() );
+    compare_paths(p0, p7);
+
+    p8.assign( ws.c_str(), ws.c_str() + ws.size() );
+    compare_paths(p0, p8);
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/assign/copy.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/assign/copy.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/assign/copy.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,55 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+using __gnu_test::compare_paths;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    path copy;
+    copy = p;
+    __gnu_test::compare_paths(p, copy);
+  }
+}
+
+void
+test02()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    path copy = p;
+    path move;
+    move = std::move(copy);
+    __gnu_test::compare_paths(p, move);
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/construct/range.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/construct/range.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/construct/range.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,60 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.1 path constructors [path.construct]
+
+#include <experimental/filesystem>
+#include <string>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+using __gnu_test::compare_paths;
+
+void
+test01()
+{
+  for (std::string s : __gnu_test::test_paths)
+  {
+    path p1 = s;
+    path p2( s.begin(), s.end() );
+    path p3( s.c_str() );
+    path p4( s.c_str(), s.c_str() + s.size() );
+
+    std::wstring ws(s.begin(), s.end());
+    path p5 = ws;
+    path p6( ws.begin(), ws.end() );
+    path p7( ws.c_str() );
+    path p8( ws.c_str(), ws.c_str() + ws.size() );
+
+    compare_paths(p1, p2);
+    compare_paths(p1, p3);
+    compare_paths(p1, p4);
+    compare_paths(p1, p5);
+    compare_paths(p1, p6);
+    compare_paths(p1, p7);
+    compare_paths(p1, p8);
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/construct/locale.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/construct/locale.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/construct/locale.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,39 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.1 path constructors [path.construct]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  path p("/foo/bar", std::locale::classic());
+  VERIFY( p.string() == "/foo/bar" );
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/construct/default.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/construct/default.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/construct/default.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,50 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.1 path constructors [path.construct]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  path p;
+  VERIFY(  p.empty() );
+  VERIFY( !p.has_root_path() );
+  VERIFY( !p.has_root_name() );
+  VERIFY( !p.has_root_directory() );
+  VERIFY( !p.has_relative_path() );
+  VERIFY( !p.has_parent_path() );
+  VERIFY( !p.has_filename() );
+  VERIFY( !p.has_stem() );
+  VERIFY( !p.has_extension() );
+  VERIFY( !p.is_absolute() );
+  VERIFY(  p.is_relative() );
+  VERIFY( std::distance(p.begin(), p.end()) == 0 );
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/construct/copy.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/construct/copy.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/construct/copy.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,54 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.1 path constructors [path.construct]
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    path copy = p;
+    __gnu_test::compare_paths(p, copy);
+  }
+}
+
+void
+test02()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    path copy = p;
+    path move = std::move(copy);
+    __gnu_test::compare_paths(p, move);
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/query/has_filename.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/query/has_filename.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/query/has_filename.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,43 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <vector>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    VERIFY( p.has_filename() == !p.filename().empty() );
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/query/empty.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/query/empty.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/query/empty.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,43 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <vector>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const std::string& s : __gnu_test::test_paths)
+  {
+    VERIFY( s.empty() == path(s).empty() );
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/query/has_root_name.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/query/has_root_name.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/query/has_root_name.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,43 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <vector>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    VERIFY( p.has_root_name() == !p.root_name().empty() );
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/query/has_parent_path.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/query/has_parent_path.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/query/has_parent_path.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,43 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <vector>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    VERIFY( p.has_parent_path() == !p.parent_path().empty() );
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/query/has_relative_path.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/query/has_relative_path.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/query/has_relative_path.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,43 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <vector>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    VERIFY( p.has_relative_path() == !p.relative_path().empty() );
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/query/has_root_directory.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/query/has_root_directory.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/query/has_root_directory.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,43 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <vector>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    VERIFY( p.has_root_directory() == !p.root_directory().empty() );
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/query/has_stem.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/query/has_stem.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/query/has_stem.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,43 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <vector>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    VERIFY( p.has_stem() == !p.stem().empty() );
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/query/is_relative.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/query/is_relative.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/query/is_relative.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,43 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <vector>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    VERIFY( p.is_relative() == !p.is_absolute() );
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/query/has_extension.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/query/has_extension.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/query/has_extension.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,43 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <vector>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    VERIFY( p.has_extension() == !p.extension().empty() );
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/query/has_root_path.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/query/has_root_path.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/query/has_root_path.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,43 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <vector>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    VERIFY( p.has_root_path() == !p.root_path().empty() );
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/compare/path.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/compare/path.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/compare/path.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,50 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.8 path compare [path.compare]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  const path p0 = "/a/a/b/b";
+  for (const path& p : __gnu_test::test_paths)
+  {
+    VERIFY( p.compare(p) == 0 );
+    int cmp = p.compare(p0);
+    if (cmp == 0)
+      VERIFY( p0.compare(p) == 0 );
+    else if (cmp < 0)
+      VERIFY( p0.compare(p) > 0 );
+    else if (cmp > 0)
+      VERIFY( p0.compare(p) < 0 );
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/compare/compare.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/compare/compare.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/compare/compare.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,50 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.8 path compare [path.compare]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  path p("/foo/bar");
+  VERIFY( p.compare(p) == 0 );
+  VERIFY( p.compare("/foo//bar") == 0 );
+
+  path q("/foo/baz");
+  VERIFY( p.compare(q) < 0 );
+  VERIFY( q.compare(p) > 0 );
+
+  path r("/foo/bar/.");
+  VERIFY( p.compare(r) < 0 );
+
+  VERIFY( path("a/b/").compare("a/b/.") == 0 );
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/compare/strings.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/compare/strings.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/compare/strings.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,48 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.8 path compare [path.compare]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  const std::string s0 = "/a/a/b/b";
+  const path p0 = s0;
+  for (const std::string& s : __gnu_test::test_paths)
+  {
+    path p(s);
+    VERIFY( p.compare(s) == 0 );
+    VERIFY( p.compare(s.c_str()) == 0 );
+    VERIFY( p.compare(p0) == p.compare(s0) );
+    VERIFY( p.compare(p0) == p.compare(s0.c_str()) );
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/native/TODO
===================================================================
Index: libstdc++-v3/testsuite/experimental/filesystem/path/append/path.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/append/path.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/append/path.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,63 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.3 path appends [path.append]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  const path p("/foo/bar");
+
+  path pp = p;
+  pp /= p;
+  VERIFY( pp.native() == "/foo/bar/foo/bar" );
+
+  path q("baz");
+
+  path qq = q;
+  qq /= q;
+  VERIFY( qq.native() == "baz/baz" );
+
+  q /= p;
+  VERIFY( q.native() == "baz/foo/bar" );
+
+  path r = "";
+  r /= path();
+  VERIFY( r.empty() );
+
+  r /= path("rel");
+  VERIFY( !r.is_absolute() );
+
+  path s = "dir/";
+  s /= path("/file");
+  VERIFY( s.native() == "dir//file" );
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/concat/path.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/concat/path.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/concat/path.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,68 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.4 path concatenation [path.concat]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  const path p("/foo/bar");
+
+  path pp = p;
+  pp += p;
+  VERIFY( pp.native() == "/foo/bar/foo/bar" );
+  VERIFY( std::distance(pp.begin(), pp.end()) == 5 );
+
+  path q("foo/bar");
+
+  path qq = q;
+  qq += q;
+  VERIFY( qq.native() == "foo/barfoo/bar" );
+  VERIFY( std::distance(qq.begin(), qq.end()) == 3 );
+
+  q += p;
+  VERIFY( q.native() == "foo/bar/foo/bar" );
+  VERIFY( std::distance(q.begin(), q.end()) == 4 );
+}
+
+void
+test02()
+{
+  for (path p : __gnu_test::test_paths)
+  {
+    auto prior_native = p.native();
+    path x("//blah/di/blah");
+    p += x;
+    VERIFY( p.native() == prior_native + x.native() );
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/concat/strings.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/concat/strings.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/concat/strings.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,51 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.4 path concatenation [path.concat]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  path p("/");
+  p += path::string_type("foo");
+  VERIFY( p.filename() == "foo" );
+  p += "bar";
+  VERIFY( p.filename() == "foobar" );
+  p += '/';
+  VERIFY( p.parent_path() == "/foobar" && p.filename() == "." );
+  p += L"baz.txt";
+  VERIFY( p.filename() == "baz.txt" );
+  p.concat("/dir/");
+  VERIFY( p.parent_path() == "/foobar/baz.txt/dir" && p.filename() == "." );
+  std::string file = "file";
+  p.concat(file.begin(), file.end());
+  VERIFY( p.filename() == "file" );
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/factory/TODO
===================================================================
Index: libstdc++-v3/testsuite/experimental/filesystem/path/io/TODO
===================================================================
Index: libstdc++-v3/testsuite/experimental/filesystem/path/generic/generic_string.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/generic/generic_string.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/generic/generic_string.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,48 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.7 path generic format observers [path.generic.obs]
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+#include <testsuite_hooks.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    path p2(p), p3;
+    p2.swap(p3);
+    VERIFY( p2 == path() );
+    VERIFY( p3 == p );
+    p2.swap(p3);
+    VERIFY( p2 == p );
+    VERIFY( p3 == path() );
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/decompose/extension.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/decompose/extension.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/decompose/extension.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,61 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <vector>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  VERIFY( path("/foo/bar.txt").extension() == path(".txt") );
+  VERIFY( path("/foo/bar.baz.txt").extension() == path(".txt") );
+  VERIFY( path(".bar.baz.txt").extension() == path(".txt") );
+
+  VERIFY( path(".hidden").extension() == path(".hidden") );
+
+  VERIFY( path().extension() == path() );
+  VERIFY( path(".").extension() == path() );
+  VERIFY( path("..").extension() == path() );
+}
+
+void
+test02()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    auto stem = p.stem();
+    auto ext = p.extension();
+    auto file = p.filename();
+    VERIFY( stem.native() + ext.native() == file.native() );
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/decompose/root_path.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/decompose/root_path.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/decompose/root_path.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,55 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  path p1 = "foo/bar";
+  VERIFY( p1.root_path() == path() );
+  path p2 = "/foo/bar";
+  VERIFY( p2.root_path() == path("/") );
+}
+
+void
+test02()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    path rootp = p.root_path();
+    path rootn = p.root_name();
+    path rootd = p.root_directory();
+    VERIFY( rootp == (rootn / rootd) );
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/decompose/filename.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/decompose/filename.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/decompose/filename.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,58 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  VERIFY( path("/foo/bar.txt").filename() == "bar.txt"  );
+  VERIFY( path("/").filename()            == "/"        );
+  VERIFY( path(".").filename()            == "."        );
+  VERIFY( path("..").filename()           == ".."       );
+}
+
+void
+test02()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    path f = p.filename();
+    if (p.empty())
+      VERIFY( f.empty() );
+    else
+      VERIFY( f == *--p.end() );
+    if (p != p.root_path())
+      VERIFY( !f.has_root_path() );
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/decompose/root_name.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/decompose/root_name.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/decompose/root_name.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,42 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  VERIFY( path("/foo/bar.txt").extension() == ".txt" );
+  VERIFY( path("/foo/bar.baz.txt").extension() == ".txt" );
+  VERIFY( path(".").extension().empty() );
+  VERIFY( path("..").extension().empty() );
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/decompose/parent_path.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/decompose/parent_path.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/decompose/parent_path.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,63 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  path p0;
+  VERIFY( p0.parent_path() == p0 );
+  path p1 = "foo";
+  VERIFY( p1.parent_path() == p0 );
+  path p2 = "foo/bar";
+  VERIFY( p2.parent_path() == p1 );
+  path p3 = "/foo/bar";
+  VERIFY( p3.parent_path() == path("/foo") );
+}
+
+void
+test02()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    if (p.begin() == p.end())
+      continue;
+    path pp;
+    for (auto i = p.begin(), end = --p.end(); i != end; ++i)
+    {
+      pp /= *i;
+    }
+    VERIFY( p.parent_path() == pp );
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/decompose/relative_path.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/decompose/relative_path.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/decompose/relative_path.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,65 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  path p1 = "foo";
+  VERIFY( p1.relative_path() == p1 );
+  path p2 = "foo/bar";
+  VERIFY( p2.relative_path() == p2 );
+  path p3 = "/foo/bar";
+  VERIFY( p3.relative_path() == p2 );
+}
+
+void
+test02()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    bool after_root = false;
+    const path prel = p.relative_path();
+    VERIFY( !prel.has_root_name() );
+    path rel;
+    for (const auto& cmpt : p)
+    {
+      if (!cmpt.has_root_path())
+        after_root = true;
+      if (after_root)
+        rel /= cmpt;
+    }
+    VERIFY( prel == rel );
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/decompose/root_directory.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/decompose/root_directory.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/decompose/root_directory.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,60 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  path p1 = "foo/bar";
+  VERIFY( p1.root_directory() == path() );
+  path p2 = "/foo/bar";
+  VERIFY( p2.root_directory() == path("/") );
+  path p3 = "//foo";
+  VERIFY( p3.root_directory() == path() );
+  path p4 = "///foo";
+  VERIFY( p4.root_directory() == path("/") );
+}
+
+void
+test02()
+{
+  for (const path& p : __gnu_test::test_paths)
+  {
+    path rootdir = p.root_directory();
+    // If root-directory is composed of 'slash name',
+    // 'slash' is excluded from the returned string.
+    if (!rootdir.empty() && rootdir.native() != "/")
+      VERIFY( rootdir.native()[0] != '/' );
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/decompose/stem.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/decompose/stem.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/decompose/stem.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,53 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.4.9 path decomposition [path.decompose]
+
+#include <experimental/filesystem>
+#include <vector>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  VERIFY( path("/foo/bar.txt").stem() == path("bar") );
+  path p = "foo.bar.baz.tar";
+  std::vector<std::string> v;
+  for (; !p.extension().empty(); p = p.stem())
+    v.push_back(p.extension().native());
+  VERIFY( v.at(0) == ".tar" );
+  VERIFY( v.at(1) == ".baz" );
+  VERIFY( v.at(2) == ".bar" );
+
+  VERIFY( path(".hidden").stem() == path() );
+
+  VERIFY( path().stem() == path() );
+  VERIFY( path(".").stem() == path(".") );
+  VERIFY( path("..").stem() == path("..") );
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/experimental/filesystem/path/itr/traversal.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/itr/traversal.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/itr/traversal.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,86 @@
+// { dg-options "-std=gnu++11 -lstdc++fs" }
+// { dg-require-filesystem-ts "" }
+
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// 8.5 path iterators [path.itr]
+
+#include <experimental/filesystem>
+#include <vector>
+#include <algorithm>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+using std::experimental::filesystem::path;
+
+void
+test01()
+{
+  path p;
+  VERIFY( p.begin() == p.end() );
+
+  std::vector<path> v, v2;
+
+  p = "/";
+  v.assign(p.begin(), p.end());
+  v2 = { "/" };
+  VERIFY( v == v2 );
+
+  p = "filename";
+  v.assign(p.begin(), p.end());
+  v2 = { "filename" };
+  VERIFY( v == v2 );
+
+  p = "dir/";
+  v.assign(p.begin(), p.end());
+  v2 = { "dir", "." };
+  VERIFY( v == v2 );
+
+  p = "//rootname/dir/";
+  v.assign(p.begin(), p.end());
+  v2 = { "//rootname", "/", "dir", "." };
+  VERIFY( v == v2 );
+
+  p = "//rootname/dir/filename";
+  v.assign(p.begin(), p.end());
+  v2 = { "//rootname", "/", "dir", "filename" };
+  VERIFY( v == v2 );
+}
+
+void
+test02()
+{
+  using reverse_iterator = std::reverse_iterator<path::iterator>;
+  std::vector<path> fwd, rev;
+
+  for (const path& p : __gnu_test::test_paths)
+  {
+    const auto begin = p.begin(), end = p.end();
+    fwd.assign(begin, end);
+    rev.assign(reverse_iterator(end), reverse_iterator(begin));
+    VERIFY( fwd.size() == rev.size() );
+    VERIFY( std::equal(fwd.begin(), fwd.end(), rev.rbegin()) );
+  }
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/util/testsuite_fs.h
===================================================================
--- libstdc++-v3/testsuite/util/testsuite_fs.h	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/util/testsuite_fs.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,93 @@
+// -*- C++ -*-
+// Filesystem utils for the C++ library testsuite.
+//
+// Copyright (C) 2014-2015 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+//
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+//
+
+#ifndef _TESTSUITE_FS_H
+#define _TESTSUITE_FS_H 1
+
+#include <experimental/filesystem>
+#include <iostream>
+#include <string>
+#include <cstdio>
+#include <stdlib.h>
+#include <unistd.h>
+
+namespace __gnu_test
+{
+#define PATH_CHK(p1, p2, fn) \
+    if ( p1.fn() != p2.fn() ) \
+      throw std::experimental::filesystem::filesystem_error( #fn, p1, p2, \
+	  std::make_error_code(std::errc::invalid_argument) )
+
+  void
+  compare_paths(const std::experimental::filesystem::path& p1,
+		const std::experimental::filesystem::path& p2)
+  {
+    // std::cout << "Comparing " << p1 << " and " << p2 << std::endl;
+    PATH_CHK( p1, p2, string );
+    PATH_CHK( p1, p2, empty );
+    PATH_CHK( p1, p2, has_root_path );
+    PATH_CHK( p1, p2, has_root_name );
+    PATH_CHK( p1, p2, has_root_directory );
+    PATH_CHK( p1, p2, has_relative_path );
+    PATH_CHK( p1, p2, has_parent_path );
+    PATH_CHK( p1, p2, has_filename );
+    PATH_CHK( p1, p2, has_stem );
+    PATH_CHK( p1, p2, has_extension );
+    PATH_CHK( p1, p2, is_absolute );
+    PATH_CHK( p1, p2, is_relative );
+    auto d1 = std::distance(p1.begin(), p1.end());
+    auto d2 = std::distance(p2.begin(), p2.end());
+    if( d1 != d2 )
+      throw std::experimental::filesystem::filesystem_error(
+	  "distance(begin, end)", p1, p2,
+	  std::make_error_code(std::errc::invalid_argument) );
+  }
+
+  const std::string test_paths[] = {
+    "", "/", "//", "/.", "/./", "/a", "/a/", "/a//", "/a/b/c/d", "/a//b",
+    "a", "a/b", "a/b/", "a/b/c", "a/b/c.d", "a/b/..", "a/b/c.", "a/b/.c"
+  };
+
+  // This is NOT supposed to be a secure way to get a unique name!
+  // We just need a path that doesn't exist for testing purposes.
+  std::experimental::filesystem::path
+  nonexistent_path()
+  {
+    std::experimental::filesystem::path p;
+#if defined(_GNU_SOURCE) || _XOPEN_SOURCE >= 500 || _POSIX_C_SOURCE >= 200112L
+    char tmp[] = "test.XXXXXX";
+    int fd = ::mkstemp(tmp);
+    if (fd == -1)
+      throw std::experimental::filesystem::filesystem_error("mkstemp failed",
+	  std::error_code(errno, std::generic_category()));
+    ::unlink(tmp);
+    ::close(fd);
+    p = tmp;
+#else
+    char buf[64];
+    std::sprintf(buf, "test.%lu", (unsigned long)::getpid());
+    p = buf;
+#endif
+    return p;
+  }
+
+} // namespace __gnu_test
+#endif
Index: libstdc++-v3/config.h.in
===================================================================
--- libstdc++-v3/config.h.in	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/config.h.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -54,6 +54,9 @@
 /* Define to 1 if you have the `cosl' function. */
 #undef HAVE_COSL
 
+/* Define to 1 if you have the <dirent.h> header file. */
+#undef HAVE_DIRENT_H
+
 /* Define to 1 if you have the <dlfcn.h> header file. */
 #undef HAVE_DLFCN_H
 
@@ -132,6 +135,9 @@
 /* Define to 1 if you have the `fabsl' function. */
 #undef HAVE_FABSL
 
+/* Define to 1 if you have the <fcntl.h> header file. */
+#undef HAVE_FCNTL_H
+
 /* Define to 1 if you have the <fenv.h> header file. */
 #undef HAVE_FENV_H
 
@@ -406,6 +412,9 @@
 /* Define to 1 if you have the <sys/sem.h> header file. */
 #undef HAVE_SYS_SEM_H
 
+/* Define to 1 if you have the <sys/statvfs.h> header file. */
+#undef HAVE_SYS_STATVFS_H
+
 /* Define to 1 if you have the <sys/stat.h> header file. */
 #undef HAVE_SYS_STAT_H
 
@@ -451,6 +460,9 @@
 /* Defined if usleep exists. */
 #undef HAVE_USLEEP
 
+/* Define to 1 if you have the <utime.h> header file. */
+#undef HAVE_UTIME_H
+
 /* Defined if vfwscanf exists. */
 #undef HAVE_VFWSCANF
 
@@ -726,6 +738,9 @@
 /* Define if gthreads library is available. */
 #undef _GLIBCXX_HAS_GTHREADS
 
+/* Define to 1 if `d_type' is a member of `struct dirent'. */
+#undef _GLIBCXX_HAVE_STRUCT_DIRENT_D_TYPE
+
 /* Define to 1 if a full hosted library is built, or 0 if freestanding. */
 #undef _GLIBCXX_HOSTED
 
@@ -824,6 +839,12 @@
    this host. */
 #undef _GLIBCXX_USE_DECIMAL_FLOAT
 
+/* Define if fchmod is available in <sys/stat.h>. */
+#undef _GLIBCXX_USE_FCHMOD
+
+/* Define if fchmodat is available in <sys/stat.h>. */
+#undef _GLIBCXX_USE_FCHMODAT
+
 /* Define if __float128 is supported on this host. */
 #undef _GLIBCXX_USE_FLOAT128
 
@@ -858,6 +879,9 @@
    of TR1 (Chapter 5.1). */
 #undef _GLIBCXX_USE_RANDOM_TR1
 
+/* Define if realpath is available in <stdlib.h>. */
+#undef _GLIBCXX_USE_REALPATH
+
 /* Defined if sched_yield is available. */
 #undef _GLIBCXX_USE_SCHED_YIELD
 
@@ -867,6 +891,12 @@
 /* Define if _SC_NPROC_ONLN is available in <unistd.h>. */
 #undef _GLIBCXX_USE_SC_NPROC_ONLN
 
+/* Define if sendfile is available in <sys/stat.h>. */
+#undef _GLIBCXX_USE_SENDFILE
+
+/* Define if struct stat has timespec members. */
+#undef _GLIBCXX_USE_ST_MTIM
+
 /* Define if sysctl(), CTL_HW and HW_NCPU are available in <sys/sysctl.h>. */
 #undef _GLIBCXX_USE_SYSCTL_HW_NCPU
 
@@ -873,6 +903,10 @@
 /* Define if obsolescent tmpnam is available in <stdio.h>. */
 #undef _GLIBCXX_USE_TMPNAM
 
+/* Define if utimensat and UTIME_OMIT are available in <sys/stat.h> and
+   AT_FDCWD in <fcntl.h>. */
+#undef _GLIBCXX_USE_UTIMENSAT
+
 /* Define if code specialized for wchar_t should be used. */
 #undef _GLIBCXX_USE_WCHAR_T
 
Index: libstdc++-v3/acinclude.m4
===================================================================
--- libstdc++-v3/acinclude.m4	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/acinclude.m4	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -49,7 +49,7 @@
   # Keep these sync'd with the list in Makefile.am.  The first provides an
   # expandable list at autoconf time; the second provides an expandable list
   # (i.e., shell variable) at configure time.
-  m4_define([glibcxx_SUBDIRS],[include libsupc++ python src src/c++98 src/c++11 doc po testsuite])
+  m4_define([glibcxx_SUBDIRS],[include libsupc++ src src/c++98 src/c++11 src/filesystem doc po testsuite python])
   SUBDIRS='glibcxx_SUBDIRS'
 
   # These need to be absolute paths, yet at the same time need to
@@ -3905,7 +3905,168 @@
   GLIBCXX_CONDITIONAL(ENABLE_CXX11_ABI, test $glibcxx_cxx11_abi = 1)
 ])
 
+dnl
+dnl Check to see whether to build libstdc++fs.a
+dnl
+dnl --enable-libstdcxx-filesystem-ts
+dnl
+AC_DEFUN([GLIBCXX_ENABLE_FILESYSTEM_TS], [
+  GLIBCXX_ENABLE(libstdcxx-filesystem-ts,auto,,
+    [turns on ISO/IEC TS 18822 support],
+    [permit yes|no|auto])
 
+  AC_MSG_CHECKING([whether to build Filesystem TS support])
+  if test x"$ac_cv_header_dirent_h" != x"yes"; then
+    enable_libstdcxx_filesystem_ts=no
+  fi
+  if test x"$enable_libstdcxx_filesystem_ts" = x"auto"; then
+    case "${target_os}" in
+      freebsd*|netbsd*|openbsd*|dragonfly*|darwin*)
+        enable_libstdcxx_filesystem_ts=yes
+        ;;
+      gnu* | linux* | kfreebsd*-gnu | knetbsd*-gnu)
+        enable_libstdcxx_filesystem_ts=yes
+        ;;
+      solaris*)
+        enable_libstdcxx_filesystem_ts=yes
+        ;;
+      *)
+        enable_libstdcxx_filesystem_ts=no
+        ;;
+    esac
+  fi
+  AC_MSG_RESULT($enable_libstdcxx_filesystem_ts)
+  GLIBCXX_CONDITIONAL(ENABLE_FILESYSTEM_TS, test $enable_libstdcxx_filesystem_ts = yes)
+])
+
+dnl
+dnl Check whether the library calls required by the Filesystem TS are present
+dnl and define _GLIBCXX_USE_REALPATH and _GLIBCXX_USE_UTIMENSAT.
+dnl
+AC_DEFUN([GLIBCXX_CHECK_FILESYSTEM_DEPS], [dnl
+dnl
+  AC_LANG_SAVE
+  AC_LANG_CPLUSPLUS
+  ac_save_CXXFLAGS="$CXXFLAGS"
+  CXXFLAGS="$CXXFLAGS -fno-exceptions"
+dnl
+  AC_MSG_CHECKING([for struct dirent.d_type])
+  AC_CACHE_VAL(glibcxx_cv_dirent_d_type, [dnl
+    GCC_TRY_COMPILE_OR_LINK(
+      [#include <dirent.h>],
+      [
+       struct dirent d;
+       if (sizeof d.d_type) return 0;
+      ],
+      [glibcxx_cv_dirent_d_type=yes],
+      [glibcxx_cv_dirent_d_type=no])
+  ])
+  if test $glibcxx_cv_dirent_d_type = yes; then
+    AC_DEFINE(_GLIBCXX_HAVE_STRUCT_DIRENT_D_TYPE, 1, [Define to 1 if `d_type' is a member of `struct dirent'.])
+  fi
+  AC_MSG_RESULT($glibcxx_cv_dirent_d_type)
+dnl
+  AC_MSG_CHECKING([for realpath])
+  AC_CACHE_VAL(glibcxx_cv_realpath, [dnl
+    GCC_TRY_COMPILE_OR_LINK(
+      [#include <stdlib.h>],
+      [char *tmp = realpath((const char*)NULL, (char*)NULL);],
+      [glibcxx_cv_realpath=yes],
+      [glibcxx_cv_realpath=no])
+  ])
+  if test $glibcxx_cv_realpath = yes; then
+    AC_DEFINE(_GLIBCXX_USE_REALPATH, 1, [Define if realpath is available in <stdlib.h>.])
+  fi
+  AC_MSG_RESULT($glibcxx_cv_realpath)
+dnl
+  AC_MSG_CHECKING([for utimensat])
+  AC_CACHE_VAL(glibcxx_cv_utimensat, [dnl
+    GCC_TRY_COMPILE_OR_LINK(
+      [
+        #include <fcntl.h>
+        #include <sys/stat.h>
+      ],
+      [
+        struct timespec ts[2] = { { 0, UTIME_OMIT }, { 1, 1 } };
+        int i = utimensat(AT_FDCWD, "path", ts, 0);
+      ],
+      [glibcxx_cv_utimensat=yes],
+      [glibcxx_cv_utimensat=no])
+  ])
+  if test $glibcxx_cv_utimensat = yes; then
+    AC_DEFINE(_GLIBCXX_USE_UTIMENSAT, 1, [Define if utimensat and UTIME_OMIT are available in <sys/stat.h> and AT_FDCWD in <fcntl.h>.])
+  fi
+  AC_MSG_RESULT($glibcxx_cv_utimensat)
+dnl
+  AC_MSG_CHECKING([for struct stat.st_mtim.tv_nsec])
+  AC_CACHE_VAL(glibcxx_cv_st_mtim, [dnl
+    GCC_TRY_COMPILE_OR_LINK(
+      [ #include <sys/stat.h> ],
+      [
+        struct stat st;
+        return st.st_mtim.tv_nsec;
+      ],
+      [glibcxx_cv_st_mtim=yes],
+      [glibcxx_cv_st_mtim=no])
+  ])
+  if test $glibcxx_cv_st_mtim = yes; then
+    AC_DEFINE(_GLIBCXX_USE_ST_MTIM, 1, [Define if struct stat has timespec members.])
+  fi
+  AC_MSG_RESULT($glibcxx_cv_st_mtim)
+dnl
+  AC_MSG_CHECKING([for fchmod])
+  AC_CACHE_VAL(glibcxx_cv_fchmod, [dnl
+    GCC_TRY_COMPILE_OR_LINK(
+      [#include <sys/stat.h>],
+      [fchmod(1, S_IWUSR);],
+      [glibcxx_cv_fchmod=yes],
+      [glibcxx_cv_fchmod=no])
+  ])
+  if test $glibcxx_cv_fchmod = yes; then
+    AC_DEFINE(_GLIBCXX_USE_FCHMOD, 1, [Define if fchmod is available in <sys/stat.h>.])
+  fi
+  AC_MSG_RESULT($glibcxx_cv_fchmod)
+dnl
+  AC_MSG_CHECKING([for fchmodat])
+  AC_CACHE_VAL(glibcxx_cv_fchmodat, [dnl
+    GCC_TRY_COMPILE_OR_LINK(
+      [
+        #include <fcntl.h>
+        #include <sys/stat.h>
+      ],
+      [fchmodat(AT_FDCWD, "", 0, AT_SYMLINK_NOFOLLOW);],
+      [glibcxx_cv_fchmodat=yes],
+      [glibcxx_cv_fchmodat=no])
+  ])
+  if test $glibcxx_cv_fchmodat = yes; then
+    AC_DEFINE(_GLIBCXX_USE_FCHMODAT, 1, [Define if fchmodat is available in <sys/stat.h>.])
+  fi
+  AC_MSG_RESULT($glibcxx_cv_fchmodat)
+dnl
+  AC_MSG_CHECKING([for sendfile that can copy files])
+  AC_CACHE_VAL(glibcxx_cv_sendfile, [dnl
+    case "${target_os}" in
+      gnu* | linux* | solaris*)
+        GCC_TRY_COMPILE_OR_LINK(
+          [#include <sys/sendfile.h>],
+          [sendfile(1, 2, (off_t*)NULL, sizeof 1);],
+          [glibcxx_cv_sendfile=yes],
+          [glibcxx_cv_sendfile=no])
+        ;;
+      *)
+        glibcxx_cv_sendfile=no
+        ;;
+    esac
+  ])
+  if test $glibcxx_cv_sendfile = yes; then
+    AC_DEFINE(_GLIBCXX_USE_SENDFILE, 1, [Define if sendfile is available in <sys/stat.h>.])
+  fi
+  AC_MSG_RESULT($glibcxx_cv_sendfile)
+dnl
+  CXXFLAGS="$ac_save_CXXFLAGS"
+  AC_LANG_RESTORE
+])
+
 # Macros from the top-level gcc directory.
 m4_include([../config/gc++filt.m4])
 m4_include([../config/tls.m4])
Index: libstdc++-v3/aclocal.m4
===================================================================
--- libstdc++-v3/aclocal.m4	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libstdc++-v3/aclocal.m4	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,7 +1,8 @@
-# generated automatically by aclocal 1.11.1 -*- Autoconf -*-
+# generated automatically by aclocal 1.11.6 -*- Autoconf -*-
 
 # Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-# 2005, 2006, 2007, 2008, 2009  Free Software Foundation, Inc.
+# 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation,
+# Inc.
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -19,12 +20,15 @@
 If you have problems, you may need to regenerate the build system entirely.
 To do so, use the procedure documented by the package, typically `autoreconf'.])])
 
-# Copyright (C) 2002, 2003, 2005, 2006, 2007, 2008  Free Software Foundation, Inc.
+# Copyright (C) 2002, 2003, 2005, 2006, 2007, 2008, 2011 Free Software
+# Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # AM_AUTOMAKE_VERSION(VERSION)
 # ----------------------------
 # Automake X.Y traces this macro to ensure aclocal.m4 has been
@@ -34,7 +38,7 @@
 [am__api_version='1.11'
 dnl Some users find AM_AUTOMAKE_VERSION and mistake it for a way to
 dnl require some minimum version.  Point them to the right macro.
-m4_if([$1], [1.11.1], [],
+m4_if([$1], [1.11.6], [],
       [AC_FATAL([Do not call $0, use AM_INIT_AUTOMAKE([$1]).])])dnl
 ])
 
@@ -50,7 +54,7 @@
 # Call AM_AUTOMAKE_VERSION and AM_AUTOMAKE_VERSION so they can be traced.
 # This function is AC_REQUIREd by AM_INIT_AUTOMAKE.
 AC_DEFUN([AM_SET_CURRENT_AUTOMAKE_VERSION],
-[AM_AUTOMAKE_VERSION([1.11.1])dnl
+[AM_AUTOMAKE_VERSION([1.11.6])dnl
 m4_ifndef([AC_AUTOCONF_VERSION],
   [m4_copy([m4_PACKAGE_VERSION], [AC_AUTOCONF_VERSION])])dnl
 _AM_AUTOCONF_VERSION(m4_defn([AC_AUTOCONF_VERSION]))])
@@ -57,12 +61,14 @@
 
 # AM_AUX_DIR_EXPAND                                         -*- Autoconf -*-
 
-# Copyright (C) 2001, 2003, 2005  Free Software Foundation, Inc.
+# Copyright (C) 2001, 2003, 2005, 2011 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # For projects using AC_CONFIG_AUX_DIR([foo]), Autoconf sets
 # $ac_aux_dir to `$srcdir/foo'.  In other projects, it is set to
 # `$srcdir', `$srcdir/..', or `$srcdir/../..'.
@@ -283,12 +289,15 @@
 done
 echo "timestamp for $_am_arg" >`AS_DIRNAME(["$_am_arg"])`/stamp-h[]$_am_stamp_count])
 
-# Copyright (C) 2001, 2003, 2005, 2008  Free Software Foundation, Inc.
+# Copyright (C) 2001, 2003, 2005, 2008, 2011 Free Software Foundation,
+# Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # AM_PROG_INSTALL_SH
 # ------------------
 # Define $install_sh.
@@ -307,8 +316,8 @@
 # Add --enable-maintainer-mode option to configure.         -*- Autoconf -*-
 # From Jim Meyering
 
-# Copyright (C) 1996, 1998, 2000, 2001, 2002, 2003, 2004, 2005, 2008
-# Free Software Foundation, Inc.
+# Copyright (C) 1996, 1998, 2000, 2001, 2002, 2003, 2004, 2005, 2008,
+# 2011 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -328,7 +337,7 @@
        [disable], [m4_define([am_maintainer_other], [enable])],
        [m4_define([am_maintainer_other], [enable])
         m4_warn([syntax], [unexpected argument to AM@&t@_MAINTAINER_MODE: $1])])
-AC_MSG_CHECKING([whether to am_maintainer_other maintainer-specific portions of Makefiles])
+AC_MSG_CHECKING([whether to enable maintainer-specific portions of Makefiles])
   dnl maintainer-mode's default is 'disable' unless 'enable' is passed
   AC_ARG_ENABLE([maintainer-mode],
 [  --][am_maintainer_other][-maintainer-mode  am_maintainer_other make rules and dependencies not useful
@@ -387,12 +396,15 @@
 fi
 ])
 
-# Copyright (C) 2003, 2004, 2005, 2006  Free Software Foundation, Inc.
+# Copyright (C) 2003, 2004, 2005, 2006, 2011 Free Software Foundation,
+# Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # AM_PROG_MKDIR_P
 # ---------------
 # Check for `mkdir -p'.
@@ -415,13 +427,14 @@
 
 # Helper functions for option handling.                     -*- Autoconf -*-
 
-# Copyright (C) 2001, 2002, 2003, 2005, 2008  Free Software Foundation, Inc.
+# Copyright (C) 2001, 2002, 2003, 2005, 2008, 2010 Free Software
+# Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
-# serial 4
+# serial 5
 
 # _AM_MANGLE_OPTION(NAME)
 # -----------------------
@@ -429,13 +442,13 @@
 [[_AM_OPTION_]m4_bpatsubst($1, [[^a-zA-Z0-9_]], [_])])
 
 # _AM_SET_OPTION(NAME)
-# ------------------------------
+# --------------------
 # Set option NAME.  Presently that only means defining a flag for this option.
 AC_DEFUN([_AM_SET_OPTION],
 [m4_define(_AM_MANGLE_OPTION([$1]), 1)])
 
 # _AM_SET_OPTIONS(OPTIONS)
-# ----------------------------------
+# ------------------------
 # OPTIONS is a space-separated list of Automake options.
 AC_DEFUN([_AM_SET_OPTIONS],
 [m4_foreach_w([_AM_Option], [$1], [_AM_SET_OPTION(_AM_Option)])])
@@ -511,12 +524,14 @@
 fi
 AC_MSG_RESULT(yes)])
 
-# Copyright (C) 2001, 2003, 2005  Free Software Foundation, Inc.
+# Copyright (C) 2001, 2003, 2005, 2011 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # AM_PROG_INSTALL_STRIP
 # ---------------------
 # One issue with vendor `install' (even GNU) is that you can't
@@ -539,13 +554,13 @@
 INSTALL_STRIP_PROGRAM="\$(install_sh) -c -s"
 AC_SUBST([INSTALL_STRIP_PROGRAM])])
 
-# Copyright (C) 2006, 2008  Free Software Foundation, Inc.
+# Copyright (C) 2006, 2008, 2010 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
-# serial 2
+# serial 3
 
 # _AM_SUBST_NOTMAKE(VARIABLE)
 # ---------------------------
@@ -554,13 +569,13 @@
 AC_DEFUN([_AM_SUBST_NOTMAKE])
 
 # AM_SUBST_NOTMAKE(VARIABLE)
-# ---------------------------
+# --------------------------
 # Public sister of _AM_SUBST_NOTMAKE.
 AC_DEFUN([AM_SUBST_NOTMAKE], [_AM_SUBST_NOTMAKE($@)])
 
 # Check how to create a tarball.                            -*- Autoconf -*-
 
-# Copyright (C) 2004, 2005  Free Software Foundation, Inc.
+# Copyright (C) 2004, 2005, 2012 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -582,10 +597,11 @@
 # a tarball read from stdin.
 #     $(am__untar) < result.tar
 AC_DEFUN([_AM_PROG_TAR],
-[# Always define AMTAR for backward compatibility.
-AM_MISSING_PROG([AMTAR], [tar])
+[# Always define AMTAR for backward compatibility.  Yes, it's still used
+# in the wild :-(  We should find a proper way to deprecate it ...
+AC_SUBST([AMTAR], ['$${TAR-tar}'])
 m4_if([$1], [v7],
-     [am__tar='${AMTAR} chof - "$$tardir"'; am__untar='${AMTAR} xf -'],
+     [am__tar='$${TAR-tar} chof - "$$tardir"' am__untar='$${TAR-tar} xf -'],
      [m4_case([$1], [ustar],, [pax],,
               [m4_fatal([Unknown tar format])])
 AC_MSG_CHECKING([how to create a $1 tar archive])
Index: boehm-gc/ChangeLog
===================================================================
--- boehm-gc/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ boehm-gc/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,11 @@
+2015-09-10  Rainer Orth  <ro@CeBiTec.Uni-Bielefeld.DE>
+
+	Backport from mainline
+	2015-08-27  Rainer Orth  <ro@CeBiTec.Uni-Bielefeld.DE>
+
+	* os_dep.c [GC_SOLARIS_THREADS] (GC_dirty_init): Use
+	/proc/<pid>/pagedata instead of PIOCOPENPD.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: boehm-gc/os_dep.c
===================================================================
--- boehm-gc/os_dep.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ boehm-gc/os_dep.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -3184,13 +3184,11 @@
 	    	      		(GC_words_allocd + GC_words_allocd_before_gc));
 #	endif       
     }
-    sprintf(buf, "/proc/%d", getpid());
-    fd = open(buf, O_RDONLY);
-    if (fd < 0) {
+    sprintf(buf, "/proc/%d/pagedata", getpid());
+    GC_proc_fd = open(buf, O_RDONLY);
+    if (GC_proc_fd < 0) {
     	ABORT("/proc open failed");
     }
-    GC_proc_fd = syscall(SYS_ioctl, fd, PIOCOPENPD, 0);
-    close(fd);
     syscall(SYS_fcntl, GC_proc_fd, F_SETFD, FD_CLOEXEC);
     if (GC_proc_fd < 0) {
     	ABORT("/proc ioctl failed");
Index: contrib/ChangeLog
===================================================================
--- contrib/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ contrib/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,8 @@
+2015-09-11  Markus Trippelsdorf  <markus@trippelsdorf.de>
+
+	* download_prerequisites: Make sure that script is run from
+	top level source directory.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: contrib/download_prerequisites
===================================================================
--- contrib/download_prerequisites	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ contrib/download_prerequisites	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -24,6 +24,11 @@
 # be downloaded.
 GRAPHITE_LOOP_OPT=yes
 
+if [ ! -e gcc/BASE-VER ] ; then
+	echo "You must run this script in the top level GCC source directory."
+	exit 1
+fi
+
 # Necessary to build GCC.
 MPFR=mpfr-2.4.2
 GMP=gmp-4.3.2
Index: libgcc/ChangeLog
===================================================================
--- libgcc/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgcc/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,11 @@
+2015-07-23  Chung-Lin Tang  <cltang@codesourcery.com>
+
+	Backport from mainline:
+	2015-07-22  Chung-Lin Tang  <cltang@codesourcery.com>
+
+	* config/nios2/linux-atomic.c (<asm/unistd.h>): Remove #include.
+	(EFAULT,EBUSY,ENOSYS): Delete unused #defines.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: libgcc/config/nios2/linux-atomic.c
===================================================================
--- libgcc/config/nios2/linux-atomic.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgcc/config/nios2/linux-atomic.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -20,11 +20,6 @@
 see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
 <http://www.gnu.org/licenses/>.  */
 
-#include <asm/unistd.h>
-#define EFAULT  14
-#define EBUSY   16
-#define ENOSYS  38
-
 /* We implement byte, short and int versions of each atomic operation
    using the kernel helper defined below.  There is no support for
    64-bit operations yet.  */
Index: gcc/doc/extend.texi
===================================================================
--- gcc/doc/extend.texi	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/doc/extend.texi	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -8423,9 +8423,9 @@
 than invoke a runtime library call or inline a switch statement.  This is
 standard compliant, safe, and the simplest approach for now.
 
-The memory model parameter is a signed int, but only the lower 8 bits are
+The memory model parameter is a signed int, but only the lower 16 bits are
 reserved for the memory model.  The remainder of the signed int is reserved
-for future use and should be 0.  Use of the predefined atomic values
+for target use and should be 0.  Use of the predefined atomic values
 ensures proper usage.
 
 @deftypefn {Built-in Function} @var{type} __atomic_load_n (@var{type} *ptr, int memmodel)
Index: gcc/ipa-chkp.c
===================================================================
--- gcc/ipa-chkp.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/ipa-chkp.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -104,7 +104,7 @@
 
 /* Return 1 calls to FNDECL should be replaced with
    a call to wrapper function.  */
-static bool
+bool
 chkp_wrap_function (tree fndecl)
 {
   if (!flag_chkp_use_wrappers)
@@ -139,6 +139,51 @@
   return false;
 }
 
+static const char *
+chkp_wrap_function_name (tree fndecl)
+{
+  gcc_assert (DECL_BUILT_IN_CLASS (fndecl) == BUILT_IN_NORMAL);
+
+  switch (DECL_FUNCTION_CODE (fndecl))
+    {
+    case BUILT_IN_STRLEN:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "strlen";
+    case BUILT_IN_STRCPY:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "strcpy";
+    case BUILT_IN_STRNCPY:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "strncpy";
+    case BUILT_IN_STPCPY:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "stpcpy";
+    case BUILT_IN_STPNCPY:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "stpncpy";
+    case BUILT_IN_STRCAT:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "strcat";
+    case BUILT_IN_STRNCAT:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "strncat";
+    case BUILT_IN_MEMCPY:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "memcpy";
+    case BUILT_IN_MEMPCPY:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "mempcpy";
+    case BUILT_IN_MEMSET:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "memset";
+    case BUILT_IN_MEMMOVE:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "memmove";
+    case BUILT_IN_BZERO:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "bzero";
+    case BUILT_IN_MALLOC:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "malloc";
+    case BUILT_IN_CALLOC:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "calloc";
+    case BUILT_IN_REALLOC:
+      return CHKP_WRAPPER_SYMBOL_PREFIX "realloc";
+
+    default:
+      gcc_unreachable ();
+    }
+
+  return "";
+}
+
 /* Build a clone of FNDECL with a modified name.  */
 
 static tree
@@ -164,9 +209,8 @@
      instrumented version.  */
   if (chkp_wrap_function(fndecl))
     {
-      s = CHKP_WRAPPER_SYMBOL_PREFIX;
-      s += IDENTIFIER_POINTER (DECL_ASSEMBLER_NAME (fndecl));
-      new_name = get_identifier (s.c_str ());
+      new_name = get_identifier (chkp_wrap_function_name (fndecl));
+      DECL_VISIBILITY (new_decl) = VISIBILITY_DEFAULT;
     }
   else
     {
@@ -541,25 +585,10 @@
 
       if (gimple_has_body_p (fndecl))
 	{
-	  /* If function will not be instrumented, then it's instrumented
-	     version is a thunk for the original.  */
-	  if (!chkp_instrumentable_p (fndecl))
-	    {
-	      clone->remove_callees ();
-	      clone->remove_all_references ();
-	      clone->thunk.thunk_p = true;
-	      clone->thunk.add_pointer_bounds_args = true;
-	      clone->create_edge (node, NULL, 0, CGRAPH_FREQ_BASE);
-	      /* Thunk shouldn't be a cdtor.  */
-	      DECL_STATIC_CONSTRUCTOR (clone->decl) = 0;
-	      DECL_STATIC_DESTRUCTOR (clone->decl) = 0;
-	    }
-	  else
-	    {
-	      tree_function_versioning (fndecl, new_decl, NULL, false,
-					NULL, false, NULL, NULL);
-	      clone->lowered = true;
-	    }
+	  gcc_assert (chkp_instrumentable_p (fndecl));
+	  tree_function_versioning (fndecl, new_decl, NULL, false,
+				    NULL, false, NULL, NULL);
+	  clone->lowered = true;
 	}
 
       /* New params are inserted after versioning because it
@@ -586,12 +615,7 @@
 
       /* Clone all aliases.  */
       for (i = 0; node->iterate_direct_aliases (i, ref); i++)
-	{
-	  struct cgraph_node *alias = dyn_cast <cgraph_node *> (ref->referring);
-	  struct cgraph_node *chkp_alias
-	    = chkp_maybe_create_clone (alias->decl);
-	  chkp_alias->create_reference (clone, IPA_REF_ALIAS, NULL);
-	}
+	chkp_maybe_create_clone (ref->referring->decl);
 
       /* Clone all thunks.  */
       for (e = node->callers; e; e = e->next_caller)
@@ -615,7 +639,10 @@
 
 	  ref = node->ref_list.first_reference ();
 	  if (ref)
-	    chkp_maybe_create_clone (ref->referred->decl);
+	    {
+	      target = chkp_maybe_create_clone (ref->referred->decl);
+	      clone->create_reference (target, IPA_REF_ALIAS);
+	    }
 
 	  if (node->alias_target)
 	    {
Index: gcc/ipa-chkp.h
===================================================================
--- gcc/ipa-chkp.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/ipa-chkp.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -24,5 +24,6 @@
 extern tree chkp_maybe_clone_builtin_fndecl (tree fndecl);
 extern cgraph_node *chkp_maybe_create_clone (tree fndecl);
 extern bool chkp_instrumentable_p (tree fndecl);
+extern bool chkp_wrap_function (tree fndecl);
 
 #endif /* GCC_IPA_CHKP_H */
Index: gcc/tree-chkp.c
===================================================================
--- gcc/tree-chkp.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/tree-chkp.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -479,6 +479,21 @@
   return false;
 }
 
+/* Emit code to build zero bounds and return RTL holding
+   the result.  */
+rtx
+chkp_expand_zero_bounds ()
+{
+  tree zero_bnd;
+
+  if (flag_chkp_use_static_const_bounds)
+    zero_bnd = chkp_get_zero_bounds_var ();
+  else
+    zero_bnd = chkp_build_make_bounds_call (integer_zero_node,
+					    integer_zero_node);
+  return expand_normal (zero_bnd);
+}
+
 /* Emit code to store zero bounds for PTR located at MEM.  */
 void
 chkp_expand_bounds_reset_for_mem (tree mem, tree ptr)
@@ -1161,7 +1176,20 @@
   return bnd_var;
 }
 
+/* If BND is an abnormal bounds copy, return a copied value.
+   Otherwise return BND.  */
+static tree
+chkp_get_orginal_bounds_for_abnormal_copy (tree bnd)
+{
+  if (bitmap_bit_p (chkp_abnormal_copies, SSA_NAME_VERSION (bnd)))
+    {
+      gimple bnd_def = SSA_NAME_DEF_STMT (bnd);
+      gcc_checking_assert (gimple_code (bnd_def) == GIMPLE_ASSIGN);
+      bnd = gimple_assign_rhs1 (bnd_def);
+    }
 
+  return bnd;
+}
 
 /* Register bounds BND for object PTR in global bounds table.
    A copy of bounds may be created for abnormal ssa names.
@@ -1205,11 +1233,7 @@
       /* For abnormal copies we may just find original
 	 bounds and use them.  */
       if (!abnormal_ptr && !SSA_NAME_IS_DEFAULT_DEF (bnd))
-	{
-	  gimple bnd_def = SSA_NAME_DEF_STMT (bnd);
-	  gcc_checking_assert (gimple_code (bnd_def) == GIMPLE_ASSIGN);
-	  bnd = gimple_assign_rhs1 (bnd_def);
-	}
+	bnd = chkp_get_orginal_bounds_for_abnormal_copy (bnd);
       /* For undefined values we usually use none bounds
 	 value but in case of abnormal edge it may cause
 	 coalescing failures.  Use default definition of
@@ -1241,6 +1265,7 @@
 	    copy = make_temp_ssa_name (pointer_bounds_type_node,
 				       gimple_build_nop (),
 				       CHKP_BOUND_TMP_NAME);
+	  bnd = chkp_get_orginal_bounds_for_abnormal_copy (bnd);
 	  assign = gimple_build_assign (copy, bnd);
 
 	  if (dump_file && (dump_flags & TDF_DETAILS))
@@ -2513,6 +2538,7 @@
   tree rhs1 = gimple_assign_rhs1 (assign);
   tree bounds = NULL_TREE;
   gimple_stmt_iterator iter = gsi_for_stmt (assign);
+  tree base = NULL;
 
   if (dump_file && (dump_flags & TDF_DETAILS))
     {
@@ -2539,6 +2565,7 @@
     case INTEGER_CST:
       /* Bounds are just propagated from RHS.  */
       bounds = chkp_find_bounds (rhs1, &iter);
+      base = rhs1;
       break;
 
     case VIEW_CONVERT_EXPR:
@@ -2609,6 +2636,8 @@
 	     (e.g. pointer minus pointer).  In such case
 	     use default invalid op bounds.  */
 	  bounds = chkp_get_invalid_op_bounds ();
+
+	base = (bounds == bnd1) ? rhs1 : (bounds == bnd2) ? rhs2 : NULL;
       }
       break;
 
@@ -2704,6 +2733,19 @@
 
   gcc_assert (bounds);
 
+  /* We may reuse bounds of other pointer we copy/modify.  But it is not
+     allowed for abnormal ssa names.  If we produced a pointer using
+     abnormal ssa name, we better make a bounds copy to avoid coalescing
+     issues.  */
+  if (base
+      && TREE_CODE (base) == SSA_NAME
+      && SSA_NAME_OCCURS_IN_ABNORMAL_PHI (base))
+    {
+      gimple stmt = gimple_build_assign (chkp_get_tmp_reg (NULL), bounds);
+      gsi_insert_after (&iter, stmt, GSI_SAME_STMT);
+      bounds = gimple_assign_lhs (stmt);
+    }
+
   if (node)
     bounds = chkp_maybe_copy_and_register_bounds (node, bounds);
 
@@ -4090,7 +4132,7 @@
 			       void *data ATTRIBUTE_UNUSED)
 {
   if (TREE_CODE (*op) == FUNCTION_DECL
-      && !lookup_attribute ("bnd_legacy", DECL_ATTRIBUTES (*op))
+      && chkp_instrumentable_p (*op)
       && (DECL_BUILT_IN_CLASS (*op) == NOT_BUILT_IN
 	  /* For builtins we replace pointers only for selected
 	     function and functions having definitions.  */
Index: gcc/tree-chkp.h
===================================================================
--- gcc/tree-chkp.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/tree-chkp.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -53,6 +53,7 @@
 					 struct cgraph_edge *edge);
 extern bool chkp_gimple_call_builtin_p (gimple call,
 					enum built_in_function code);
+extern rtx chkp_expand_zero_bounds (void);
 extern void chkp_expand_bounds_reset_for_mem (tree mem, tree ptr);
 extern tree chkp_insert_retbnd_call (tree bndval, tree retval,
 				     gimple_stmt_iterator *gsi);
Index: gcc/tree-ssa-uninit.c
===================================================================
--- gcc/tree-ssa-uninit.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/tree-ssa-uninit.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1310,7 +1310,8 @@
     return false;
 
   c1 = x1.cond_code;
-  if (x1.invert != x2.invert)
+  if (x1.invert != x2.invert
+      && TREE_CODE_CLASS (x2.cond_code) == tcc_comparison)
     c2 = invert_tree_comparison (x2.cond_code, false);
   else
     c2 = x2.cond_code;
Index: gcc/c-family/ChangeLog
===================================================================
--- gcc/c-family/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/c-family/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,13 @@
+2015-08-11  Marek Polacek  <polacek@redhat.com>
+
+	Backported from mainline
+	2015-08-03  Marek Polacek  <polacek@redhat.com>
+
+	PR sanitizer/66908
+	* c-ubsan.c: Include gimplify.h.
+	(ubsan_instrument_division): Unshare OP0 and OP1.
+	(ubsan_instrument_shift): Likewise.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: gcc/c-family/c-common.c
===================================================================
--- gcc/c-family/c-common.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/c-family/c-common.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -10741,7 +10741,7 @@
       if (TREE_CODE (p) == INTEGER_CST)
         {
 	  int i = tree_to_uhwi (p);
-	  if (i < 0 || (i & MEMMODEL_MASK) >= MEMMODEL_LAST)
+	  if (i < 0 || (memmodel_base (i) >= MEMMODEL_LAST))
 	    {
 	      warning_at (loc, OPT_Winvalid_memory_model,
 			  "invalid memory model argument %d of %qE", x + 1,
Index: gcc/c-family/c-ubsan.c
===================================================================
--- gcc/c-family/c-ubsan.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/c-family/c-ubsan.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -55,6 +55,7 @@
 #include "internal-fn.h"
 #include "stor-layout.h"
 #include "builtins.h"
+#include "gimplify.h"
 
 /* Instrument division by zero and INT_MIN / -1.  If not instrumenting,
    return NULL_TREE.  */
@@ -71,6 +72,9 @@
   gcc_assert (TYPE_MAIN_VARIANT (TREE_TYPE (op0))
 	      == TYPE_MAIN_VARIANT (TREE_TYPE (op1)));
 
+  op0 = unshare_expr (op0);
+  op1 = unshare_expr (op1);
+
   if (TREE_CODE (type) == INTEGER_TYPE
       && (flag_sanitize & SANITIZE_DIVIDE))
     t = fold_build2 (EQ_EXPR, boolean_type_node,
@@ -151,6 +155,9 @@
   HOST_WIDE_INT op0_prec = TYPE_PRECISION (type0);
   tree uprecm1 = build_int_cst (op1_utype, op0_prec - 1);
 
+  op0 = unshare_expr (op0);
+  op1 = unshare_expr (op1);
+
   t = fold_convert_loc (loc, op1_utype, op1);
   t = fold_build2 (GT_EXPR, boolean_type_node, t, uprecm1);
 
Index: gcc/c/ChangeLog
===================================================================
--- gcc/c/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/c/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,28 @@
+2015-09-10  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/67502
+	* c-parser.c (c_parser_omp_for_loop): Emit DECL_EXPR stmts
+	into OMP_FOR_PRE_BODY rather than before the loop.
+
+2015-09-09  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/67501
+	* c-parser.c (c_parser_oacc_all_clauses,
+	c_parser_omp_all_clauses): Remove invalid clause from
+	list of clauses even if parser->error is set.
+
+	PR c/67500
+	* c-parser.c (c_parser_omp_clause_aligned,
+	c_parser_omp_clause_safelen, c_parser_omp_clause_simdlen): Fix up
+	test for errors.
+	* c-decl.c (temp_pop_parm_decls): Allow b->decl equal to
+	error_mark_node.
+
+	PR c/67495
+	* c-parser.c (c_parser_omp_atomic): Use c_parser_cast_expression
+	instead of c_parser_unary_expression.  If the result is !lvalue_p,
+	wrap the result of c_fully_fold into NON_LVALUE_EXPR.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: gcc/c/c-parser.c
===================================================================
--- gcc/c/c-parser.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/c/c-parser.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -11185,9 +11185,9 @@
       tree alignment = c_parser_expr_no_commas (parser, NULL).value;
       mark_exp_read (alignment);
       alignment = c_fully_fold (alignment, false, NULL);
-      if (!INTEGRAL_TYPE_P (TREE_TYPE (alignment))
-	  && TREE_CODE (alignment) != INTEGER_CST
-	  && tree_int_cst_sgn (alignment) != 1)
+      if (TREE_CODE (alignment) != INTEGER_CST
+	  || !INTEGRAL_TYPE_P (TREE_TYPE (alignment))
+	  || tree_int_cst_sgn (alignment) != 1)
 	{
 	  error_at (clause_loc, "%<aligned%> clause alignment expression must "
 				"be positive constant integer expression");
@@ -11264,9 +11264,9 @@
   t = c_parser_expr_no_commas (parser, NULL).value;
   mark_exp_read (t);
   t = c_fully_fold (t, false, NULL);
-  if (!INTEGRAL_TYPE_P (TREE_TYPE (t))
-      && TREE_CODE (t) != INTEGER_CST
-      && tree_int_cst_sgn (t) != 1)
+  if (TREE_CODE (t) != INTEGER_CST
+      || !INTEGRAL_TYPE_P (TREE_TYPE (t))
+      || tree_int_cst_sgn (t) != 1)
     {
       error_at (clause_loc, "%<safelen%> clause expression must "
 			    "be positive constant integer expression");
@@ -11300,9 +11300,9 @@
   t = c_parser_expr_no_commas (parser, NULL).value;
   mark_exp_read (t);
   t = c_fully_fold (t, false, NULL);
-  if (!INTEGRAL_TYPE_P (TREE_TYPE (t))
-      && TREE_CODE (t) != INTEGER_CST
-      && tree_int_cst_sgn (t) != 1)
+  if (TREE_CODE (t) != INTEGER_CST
+      || !INTEGRAL_TYPE_P (TREE_TYPE (t))
+      || tree_int_cst_sgn (t) != 1)
     {
       error_at (clause_loc, "%<simdlen%> clause expression must "
 			    "be positive constant integer expression");
@@ -11706,7 +11706,7 @@
 
       first = false;
 
-      if (((mask >> c_kind) & 1) == 0 && !parser->error)
+      if (((mask >> c_kind) & 1) == 0)
 	{
 	  /* Remove the invalid clause(s) from the list to avoid
 	     confusing the rest of the compiler.  */
@@ -11935,7 +11935,7 @@
 
       first = false;
 
-      if (((mask >> c_kind) & 1) == 0 && !parser->error)
+      if (((mask >> c_kind) & 1) == 0)
 	{
 	  /* Remove the invalid clause(s) from the list to avoid
 	     confusing the rest of the compiler.  */
@@ -12379,6 +12379,7 @@
   bool structured_block = false;
   bool swapped = false;
   bool seq_cst = false;
+  bool non_lvalue_p;
 
   if (c_parser_next_token_is (parser, CPP_NAME))
     {
@@ -12432,20 +12433,33 @@
     {
     case OMP_ATOMIC_READ:
     case NOP_EXPR: /* atomic write */
-      v = c_parser_unary_expression (parser).value;
+      v = c_parser_cast_expression (parser, NULL).value;
+      non_lvalue_p = !lvalue_p (v);
       v = c_fully_fold (v, false, NULL);
       if (v == error_mark_node)
 	goto saw_error;
+      if (non_lvalue_p)
+	v = non_lvalue (v);
       loc = c_parser_peek_token (parser)->location;
       if (!c_parser_require (parser, CPP_EQ, "expected %<=%>"))
 	goto saw_error;
       if (code == NOP_EXPR)
-	lhs = c_parser_expression (parser).value;
+	{
+	  lhs = c_parser_expression (parser).value;
+	  lhs = c_fully_fold (lhs, false, NULL);
+	  if (lhs == error_mark_node)
+	    goto saw_error;
+	}
       else
-	lhs = c_parser_unary_expression (parser).value;
-      lhs = c_fully_fold (lhs, false, NULL);
-      if (lhs == error_mark_node)
-	goto saw_error;
+	{
+	  lhs = c_parser_cast_expression (parser, NULL).value;
+	  non_lvalue_p = !lvalue_p (lhs);
+	  lhs = c_fully_fold (lhs, false, NULL);
+	  if (lhs == error_mark_node)
+	    goto saw_error;
+	  if (non_lvalue_p)
+	    lhs = non_lvalue (lhs);
+	}
       if (code == NOP_EXPR)
 	{
 	  /* atomic write is represented by OMP_ATOMIC with NOP_EXPR
@@ -12464,10 +12478,13 @@
 	}
       else
 	{
-	  v = c_parser_unary_expression (parser).value;
+	  v = c_parser_cast_expression (parser, NULL).value;
+	  non_lvalue_p = !lvalue_p (v);
 	  v = c_fully_fold (v, false, NULL);
 	  if (v == error_mark_node)
 	    goto saw_error;
+	  if (non_lvalue_p)
+	    v = non_lvalue (v);
 	  if (!c_parser_require (parser, CPP_EQ, "expected %<=%>"))
 	    goto saw_error;
 	}
@@ -12480,7 +12497,7 @@
      old or new x should be captured.  */
 restart:
   eloc = c_parser_peek_token (parser)->location;
-  expr = c_parser_unary_expression (parser);
+  expr = c_parser_cast_expression (parser, NULL);
   lhs = expr.value;
   expr = default_function_array_conversion (eloc, expr);
   unfolded_lhs = expr.value;
@@ -12573,6 +12590,8 @@
 	}
       /* FALLTHRU */
     default:
+      if (!lvalue_p (unfolded_lhs))
+	lhs = non_lvalue (lhs);
       switch (c_parser_peek_token (parser)->type)
 	{
 	case CPP_MULT_EQ:
@@ -12687,14 +12706,17 @@
     {
       if (!c_parser_require (parser, CPP_SEMICOLON, "expected %<;%>"))
 	goto saw_error;
-      v = c_parser_unary_expression (parser).value;
+      v = c_parser_cast_expression (parser, NULL).value;
+      non_lvalue_p = !lvalue_p (v);
       v = c_fully_fold (v, false, NULL);
       if (v == error_mark_node)
 	goto saw_error;
+      if (non_lvalue_p)
+	v = non_lvalue (v);
       if (!c_parser_require (parser, CPP_EQ, "expected %<=%>"))
 	goto saw_error;
       eloc = c_parser_peek_token (parser)->location;
-      expr = c_parser_unary_expression (parser);
+      expr = c_parser_cast_expression (parser, NULL);
       lhs1 = expr.value;
       expr = default_function_array_read_conversion (eloc, expr);
       unfolded_lhs1 = expr.value;
@@ -12701,6 +12723,8 @@
       lhs1 = c_fully_fold (lhs1, false, NULL);
       if (lhs1 == error_mark_node)
 	goto saw_error;
+      if (!lvalue_p (unfolded_lhs1))
+	lhs1 = non_lvalue (lhs1);
     }
   if (structured_block)
     {
@@ -12802,7 +12826,8 @@
 		       tree clauses, tree *cclauses)
 {
   tree decl, cond, incr, save_break, save_cont, body, init, stmt, cl;
-  tree declv, condv, incrv, initv, ret = NULL;
+  tree declv, condv, incrv, initv, ret = NULL_TREE;
+  tree pre_body = NULL_TREE, this_pre_body;
   bool fail = false, open_brace_parsed = false;
   int i, collapse = 1, nbraces = 0;
   location_t for_loc;
@@ -12846,8 +12871,23 @@
 	{
 	  if (i > 0)
 	    vec_safe_push (for_block, c_begin_compound_stmt (true));
+	  this_pre_body = push_stmt_list ();
 	  c_parser_declaration_or_fndef (parser, true, true, true, true, true,
 					 NULL, vNULL);
+	  if (this_pre_body)
+	    {
+	      this_pre_body = pop_stmt_list (this_pre_body);
+	      if (pre_body)
+		{
+		  tree t = pre_body;   
+		  pre_body = push_stmt_list ();
+		  add_stmt (t);
+		  add_stmt (this_pre_body);
+		  pre_body = pop_stmt_list (pre_body);
+		}
+	      else
+		pre_body = this_pre_body;
+	    }
 	  decl = check_for_loop_decls (for_loc, flag_isoc99);
 	  if (decl == NULL)
 	    goto error_init;
@@ -13042,7 +13082,7 @@
   if (!fail)
     {
       stmt = c_finish_omp_for (loc, code, declv, initv, condv,
-			       incrv, body, NULL);
+			       incrv, body, pre_body);
       if (stmt)
 	{
 	  if (cclauses != NULL
Index: gcc/c/c-decl.c
===================================================================
--- gcc/c/c-decl.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/c/c-decl.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -8883,7 +8883,8 @@
   current_scope->bindings = NULL;
   for (; b; b = free_binding_and_advance (b))
     {
-      gcc_assert (TREE_CODE (b->decl) == PARM_DECL);
+      gcc_assert (TREE_CODE (b->decl) == PARM_DECL
+		  || b->decl == error_mark_node);
       gcc_assert (I_SYMBOL_BINDING (b->id) == b);
       I_SYMBOL_BINDING (b->id) = b->shadowed;
       if (b->shadowed && b->shadowed->u.type)
Index: gcc/lra-int.h
===================================================================
--- gcc/lra-int.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/lra-int.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -314,8 +314,8 @@
 extern void lra_process_new_insns (rtx_insn *, rtx_insn *, rtx_insn *,
 				   const char *);
 
-extern bool lra_substitute_pseudo (rtx *, int, rtx);
-extern bool lra_substitute_pseudo_within_insn (rtx_insn *, int, rtx);
+extern bool lra_substitute_pseudo (rtx *, int, rtx, bool);
+extern bool lra_substitute_pseudo_within_insn (rtx_insn *, int, rtx, bool);
 
 extern lra_insn_recog_data_t lra_set_insn_recog_data (rtx_insn *);
 extern lra_insn_recog_data_t lra_update_insn_recog_data (rtx_insn *);
Index: gcc/optabs.c
===================================================================
--- gcc/optabs.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/optabs.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -7178,7 +7178,7 @@
   success = NULL_RTX;
   oldval = cmp_reg;
   if (!expand_atomic_compare_and_swap (&success, &oldval, mem, old_reg,
-				       new_reg, false, MEMMODEL_SEQ_CST,
+				       new_reg, false, MEMMODEL_SYNC_SEQ_CST,
 				       MEMMODEL_RELAXED))
     return false;
 
@@ -7239,9 +7239,7 @@
      exists, and the memory model is stronger than acquire, add a release 
      barrier before the instruction.  */
 
-  if ((model & MEMMODEL_MASK) == MEMMODEL_SEQ_CST
-      || (model & MEMMODEL_MASK) == MEMMODEL_RELEASE
-      || (model & MEMMODEL_MASK) == MEMMODEL_ACQ_REL)
+  if (is_mm_seq_cst (model) || is_mm_release (model) || is_mm_acq_rel (model))
     expand_mem_thread_fence (model);
 
   if (icode != CODE_FOR_nothing)
@@ -7348,11 +7346,12 @@
   rtx ret;
 
   /* Try an atomic_exchange first.  */
-  ret = maybe_emit_atomic_exchange (target, mem, val, MEMMODEL_ACQUIRE);
+  ret = maybe_emit_atomic_exchange (target, mem, val, MEMMODEL_SYNC_ACQUIRE);
   if (ret)
     return ret;
 
-  ret = maybe_emit_sync_lock_test_and_set (target, mem, val, MEMMODEL_ACQUIRE);
+  ret = maybe_emit_sync_lock_test_and_set (target, mem, val,
+					   MEMMODEL_SYNC_ACQUIRE);
   if (ret)
     return ret;
 
@@ -7363,7 +7362,7 @@
   /* If there are no other options, try atomic_test_and_set if the value
      being stored is 1.  */
   if (val == const1_rtx)
-    ret = maybe_emit_atomic_test_and_set (target, mem, MEMMODEL_ACQUIRE);
+    ret = maybe_emit_atomic_test_and_set (target, mem, MEMMODEL_SYNC_ACQUIRE);
 
   return ret;
 }
@@ -7620,7 +7619,7 @@
 {
   if (HAVE_mem_thread_fence)
     emit_insn (gen_mem_thread_fence (GEN_INT (model)));
-  else if ((model & MEMMODEL_MASK) != MEMMODEL_RELAXED)
+  else if (!is_mm_relaxed (model))
     {
       if (HAVE_memory_barrier)
 	emit_insn (gen_memory_barrier ());
@@ -7644,7 +7643,7 @@
 {
   if (HAVE_mem_signal_fence)
     emit_insn (gen_mem_signal_fence (GEN_INT (model)));
-  else if ((model & MEMMODEL_MASK) != MEMMODEL_RELAXED)
+  else if (!is_mm_relaxed (model))
     {
       /* By default targets are coherent between a thread and the signal
 	 handler running on the same thread.  Thus this really becomes a
@@ -7699,7 +7698,7 @@
     target = gen_reg_rtx (mode);
 
   /* For SEQ_CST, emit a barrier before the load.  */
-  if ((model & MEMMODEL_MASK) == MEMMODEL_SEQ_CST)
+  if (is_mm_seq_cst (model))
     expand_mem_thread_fence (model);
 
   emit_move_insn (target, mem);
@@ -7745,7 +7744,7 @@
 	  if (maybe_expand_insn (icode, 2, ops))
 	    {
 	      /* lock_release is only a release barrier.  */
-	      if ((model & MEMMODEL_MASK) == MEMMODEL_SEQ_CST)
+	      if (is_mm_seq_cst (model))
 		expand_mem_thread_fence (model);
 	      return const0_rtx;
 	    }
@@ -7772,7 +7771,7 @@
   emit_move_insn (mem, val);
 
   /* For SEQ_CST, also emit a barrier after the store.  */
-  if ((model & MEMMODEL_MASK) == MEMMODEL_SEQ_CST)
+  if (is_mm_seq_cst (model))
     expand_mem_thread_fence (model);
 
   return const0_rtx;
Index: gcc/DATESTAMP
===================================================================
--- gcc/DATESTAMP	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/DATESTAMP	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1 +1 @@
-20150716
+20150918
Index: gcc/postreload.c
===================================================================
--- gcc/postreload.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/postreload.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -2164,6 +2164,8 @@
 	 unknown values.  */
       if (CALL_P (insn))
 	{
+	  rtx link;
+
 	  for (i = FIRST_PSEUDO_REGISTER - 1; i >= 0; i--)
 	    {
 	      if (call_used_regs[i])
@@ -2170,6 +2172,21 @@
 		/* Reset the information about this register.  */
 		reg_mode[i] = VOIDmode;
 	    }
+
+	  for (link = CALL_INSN_FUNCTION_USAGE (insn); link;
+	       link = XEXP (link, 1))
+	    {
+	      rtx setuse = XEXP (link, 0);
+	      rtx usage_rtx = XEXP (setuse, 0);
+	      if (GET_CODE (setuse) == CLOBBER
+		  && REG_P (usage_rtx))
+	        {
+		  unsigned int end_regno = END_REGNO (usage_rtx);
+		  for (unsigned int r = REGNO (usage_rtx); r < end_regno; ++r)
+		    /* Reset the information about this register.  */
+		    reg_mode[r] = VOIDmode;
+		}
+	    }
 	}
     }
   return changed;
Index: gcc/lra.c
===================================================================
--- gcc/lra.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/lra.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1818,9 +1818,10 @@
 
 
 /* Replace all references to register OLD_REGNO in *LOC with pseudo
-   register NEW_REG.  Return true if any change was made.  */
+   register NEW_REG.  Try to simplify subreg of constant if SUBREG_P.
+   Return true if any change was made.  */
 bool
-lra_substitute_pseudo (rtx *loc, int old_regno, rtx new_reg)
+lra_substitute_pseudo (rtx *loc, int old_regno, rtx new_reg, bool subreg_p)
 {
   rtx x = *loc;
   bool result = false;
@@ -1832,9 +1833,25 @@
     return false;
 
   code = GET_CODE (x);
-  if (code == REG && (int) REGNO (x) == old_regno)
+  if (code == SUBREG && subreg_p)
     {
-      machine_mode mode = GET_MODE (*loc);
+      rtx subst, inner = SUBREG_REG (x);
+      /* Transform subreg of constant while we still have inner mode
+	 of the subreg.  The subreg internal should not be an insn
+	 operand.  */
+      if (REG_P (inner) && (int) REGNO (inner) == old_regno
+	  && CONSTANT_P (new_reg)
+	  && (subst = simplify_subreg (GET_MODE (x), new_reg, GET_MODE (inner),
+				       SUBREG_BYTE (x))) != NULL_RTX)
+	{
+	  *loc = subst;
+	  return true;
+	}
+      
+    }
+  else if (code == REG && (int) REGNO (x) == old_regno)
+    {
+      machine_mode mode = GET_MODE (x);
       machine_mode inner_mode = GET_MODE (new_reg);
 
       if (mode != inner_mode
@@ -1856,13 +1873,15 @@
     {
       if (fmt[i] == 'e')
 	{
-	  if (lra_substitute_pseudo (&XEXP (x, i), old_regno, new_reg))
+	  if (lra_substitute_pseudo (&XEXP (x, i), old_regno,
+				     new_reg, subreg_p))
 	    result = true;
 	}
       else if (fmt[i] == 'E')
 	{
 	  for (j = XVECLEN (x, i) - 1; j >= 0; j--)
-	    if (lra_substitute_pseudo (&XVECEXP (x, i, j), old_regno, new_reg))
+	    if (lra_substitute_pseudo (&XVECEXP (x, i, j), old_regno,
+				       new_reg, subreg_p))
 	      result = true;
 	}
     }
@@ -1869,13 +1888,15 @@
   return result;
 }
 
-/* Call lra_substitute_pseudo within an insn.  This won't update the insn ptr,
-   just the contents of the insn.  */
+/* Call lra_substitute_pseudo within an insn.  Try to simplify subreg
+   of constant if SUBREG_P.  This won't update the insn ptr, just the
+   contents of the insn.  */
 bool
-lra_substitute_pseudo_within_insn (rtx_insn *insn, int old_regno, rtx new_reg)
+lra_substitute_pseudo_within_insn (rtx_insn *insn, int old_regno,
+				   rtx new_reg, bool subreg_p)
 {
   rtx loc = insn;
-  return lra_substitute_pseudo (&loc, old_regno, new_reg);
+  return lra_substitute_pseudo (&loc, old_regno, new_reg, subreg_p);
 }
 
 
Index: gcc/tree.h
===================================================================
--- gcc/tree.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/tree.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -4381,6 +4381,69 @@
 extern void warn_deprecated_use (tree, tree);
 extern void cache_integer_cst (tree);
 
+/* Return the memory model from a host integer.  */
+static inline enum memmodel
+memmodel_from_int (unsigned HOST_WIDE_INT val)
+{
+  return (enum memmodel) (val & MEMMODEL_MASK);
+}
+
+/* Return the base memory model from a host integer.  */
+static inline enum memmodel
+memmodel_base (unsigned HOST_WIDE_INT val)
+{
+  return (enum memmodel) (val & MEMMODEL_BASE_MASK);
+}
+
+/* Return TRUE if the memory model is RELAXED.  */
+static inline bool
+is_mm_relaxed (enum memmodel model)
+{
+  return (model & MEMMODEL_BASE_MASK) == MEMMODEL_RELAXED;
+}
+
+/* Return TRUE if the memory model is CONSUME.  */
+static inline bool
+is_mm_consume (enum memmodel model)
+{
+  return (model & MEMMODEL_BASE_MASK) == MEMMODEL_CONSUME;
+}
+
+/* Return TRUE if the memory model is ACQUIRE.  */
+static inline bool
+is_mm_acquire (enum memmodel model)
+{
+  return (model & MEMMODEL_BASE_MASK) == MEMMODEL_ACQUIRE;
+}
+
+/* Return TRUE if the memory model is RELEASE.  */
+static inline bool
+is_mm_release (enum memmodel model)
+{
+  return (model & MEMMODEL_BASE_MASK) == MEMMODEL_RELEASE;
+}
+
+/* Return TRUE if the memory model is ACQ_REL.  */
+static inline bool
+is_mm_acq_rel (enum memmodel model)
+{
+  return (model & MEMMODEL_BASE_MASK) == MEMMODEL_ACQ_REL;
+}
+
+/* Return TRUE if the memory model is SEQ_CST.  */
+static inline bool
+is_mm_seq_cst (enum memmodel model)
+{
+  return (model & MEMMODEL_BASE_MASK) == MEMMODEL_SEQ_CST;
+}
+
+/* Return TRUE if the memory model is a SYNC variant.  */
+static inline bool
+is_mm_sync (enum memmodel model)
+{
+  return (model & MEMMODEL_SYNC);
+}
+
 /* Compare and hash for any structure which begins with a canonical
    pointer.  Assumes all pointers are interchangeable, which is sort
    of already assumed by gcc elsewhere IIRC.  */
Index: gcc/builtins.c
===================================================================
--- gcc/builtins.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/builtins.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -5271,7 +5271,7 @@
   mem = get_builtin_sync_mem (CALL_EXPR_ARG (exp, 0), mode);
   val = expand_expr_force_mode (CALL_EXPR_ARG (exp, 1), mode);
 
-  return expand_atomic_fetch_op (target, mem, val, code, MEMMODEL_SEQ_CST,
+  return expand_atomic_fetch_op (target, mem, val, code, MEMMODEL_SYNC_SEQ_CST,
 				 after);
 }
 
@@ -5301,8 +5301,8 @@
 	poval = &target;
     }
   if (!expand_atomic_compare_and_swap (pbool, poval, mem, old_val, new_val,
-				       false, MEMMODEL_SEQ_CST,
-				       MEMMODEL_SEQ_CST))
+				       false, MEMMODEL_SYNC_SEQ_CST,
+				       MEMMODEL_SYNC_SEQ_CST))
     return NULL_RTX;
 
   return target;
@@ -5337,7 +5337,7 @@
   /* Expand the operands.  */
   mem = get_builtin_sync_mem (CALL_EXPR_ARG (exp, 0), mode);
 
-  expand_atomic_store (mem, const0_rtx, MEMMODEL_RELEASE, true);
+  expand_atomic_store (mem, const0_rtx, MEMMODEL_SYNC_RELEASE, true);
 }
 
 /* Given an integer representing an ``enum memmodel'', verify its
@@ -5366,7 +5366,8 @@
       return MEMMODEL_SEQ_CST;
     }
 
-  if ((INTVAL (op) & MEMMODEL_MASK) >= MEMMODEL_LAST)
+  /* Should never see a user explicit SYNC memodel model, so >= LAST works. */
+  if (memmodel_base (val) >= MEMMODEL_LAST)
     {
       warning (OPT_Winvalid_memory_model,
 	       "invalid memory model argument to builtin");
@@ -5433,8 +5434,7 @@
       success = MEMMODEL_SEQ_CST;
     }
  
-  if ((failure & MEMMODEL_MASK) == MEMMODEL_RELEASE
-      || (failure & MEMMODEL_MASK) == MEMMODEL_ACQ_REL)
+  if (is_mm_release (failure) || is_mm_acq_rel (failure))
     {
       warning (OPT_Winvalid_memory_model,
 	       "invalid failure memory model for "
@@ -5496,8 +5496,7 @@
   enum memmodel model;
 
   model = get_memmodel (CALL_EXPR_ARG (exp, 1));
-  if ((model & MEMMODEL_MASK) == MEMMODEL_RELEASE
-      || (model & MEMMODEL_MASK) == MEMMODEL_ACQ_REL)
+  if (is_mm_release (model) || is_mm_acq_rel (model))
     {
       warning (OPT_Winvalid_memory_model,
 	       "invalid memory model for %<__atomic_load%>");
@@ -5526,9 +5525,8 @@
   enum memmodel model;
 
   model = get_memmodel (CALL_EXPR_ARG (exp, 2));
-  if ((model & MEMMODEL_MASK) != MEMMODEL_RELAXED
-      && (model & MEMMODEL_MASK) != MEMMODEL_SEQ_CST
-      && (model & MEMMODEL_MASK) != MEMMODEL_RELEASE)
+  if (!(is_mm_relaxed (model) || is_mm_seq_cst (model)
+	|| is_mm_release (model)))
     {
       warning (OPT_Winvalid_memory_model,
 	       "invalid memory model for %<__atomic_store%>");
@@ -5635,9 +5633,7 @@
   mem = get_builtin_sync_mem (CALL_EXPR_ARG (exp, 0), mode);
   model = get_memmodel (CALL_EXPR_ARG (exp, 1));
 
-  if ((model & MEMMODEL_MASK) == MEMMODEL_CONSUME
-      || (model & MEMMODEL_MASK) == MEMMODEL_ACQUIRE
-      || (model & MEMMODEL_MASK) == MEMMODEL_ACQ_REL)
+  if (is_mm_consume (model) || is_mm_acquire (model) || is_mm_acq_rel (model))
     {
       warning (OPT_Winvalid_memory_model,
 	       "invalid memory model for %<__atomic_store%>");
@@ -5833,7 +5829,7 @@
 static void
 expand_builtin_sync_synchronize (void)
 {
-  expand_mem_thread_fence (MEMMODEL_SEQ_CST);
+  expand_mem_thread_fence (MEMMODEL_SYNC_SEQ_CST);
 }
 
 static rtx
Index: gcc/jit/ChangeLog
===================================================================
--- gcc/jit/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/jit/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,32 @@
+2015-08-13  David Malcolm  <dmalcolm@redhat.com>
+
+	Backport from mainline r226882
+	2015-08-13  David Malcolm  <dmalcolm@redhat.com>
+
+	* jit-playback.c (invoke_driver): On OS X, add
+	"-Wl,-undefined,dynamic_lookup" to the driver arguments.
+
+2015-07-23  David Malcolm  <dmalcolm@redhat.com>
+
+	Backport from mainline r226126
+	2015-07-23  David Malcolm  <dmalcolm@redhat.com>
+
+	* jit-playback.c (invoke_driver): Convert local "argvec"
+	to an auto_argvec, so that it owns copies of the strings,
+	rather than borrows them, updating ADD_ARG to use xstrdup
+	and special-casing the NULL terminator to avoid
+	xstrdup (NULL).  Call add_multilib_driver_arguments at the front
+	of the arguments.
+	(MULTILIB_DEFAULTS): Provide a default definition.
+	(multilib_defaults_raw): New constant array.
+	(gcc::jit::playback::context::add_multilib_driver_arguments): New
+	method.
+	* jit-playback.h
+	(gcc::jit::playback::context::add_multilib_driver_arguments): New
+	method.
+	* docs/internals/test-hello-world.exe.log.txt: Update.
+	* docs/_build/texinfo/libgccjit.texi: Regenerate.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: gcc/jit/docs/internals/test-hello-world.exe.log.txt
===================================================================
--- gcc/jit/docs/internals/test-hello-world.exe.log.txt	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/jit/docs/internals/test-hello-world.exe.log.txt	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,4 +1,4 @@
-JIT: libgccjit (GCC) version 5.0.0 20150123 (experimental) (x86_64-unknown-linux-gnu)
+JIT: libgccjit (GCC) version 5.2.1 20150723 (x86_64-unknown-linux-gnu)
 JIT:	compiled by GNU C version 4.8.3 20140911 (Red Hat 4.8.3-7), GMP version 5.1.2, MPFR version 3.1.2, MPC version 1.0.1
 JIT: entering: gcc_jit_context_set_str_option
 JIT:  GCC_JIT_STR_OPTION_PROGNAME: "./test-hello-world.c.exe"
@@ -64,6 +64,7 @@
 JIT:   GCC_JIT_BOOL_OPTION_DUMP_EVERYTHING: false
 JIT:   GCC_JIT_BOOL_OPTION_SELFCHECK_GC: true
 JIT:   GCC_JIT_BOOL_OPTION_KEEP_INTERMEDIATES: false
+JIT:   gcc_jit_context_set_bool_allow_unreachable_blocks: false
 JIT:   entering: void gcc::jit::recording::context::validate()
 JIT:   exiting: void gcc::jit::recording::context::validate()
 JIT:   entering: gcc::jit::playback::context::context(gcc::jit::recording::context*)
@@ -129,13 +130,16 @@
 JIT:    entering: virtual void gcc::jit::playback::compile_to_memory::postprocess(const char*)
 JIT:     entering: void gcc::jit::playback::context::convert_to_dso(const char*)
 JIT:      entering: void gcc::jit::playback::context::invoke_driver(const char*, const char*, const char*, timevar_id_t, bool, bool)
-JIT:       argv[0]: x86_64-unknown-linux-gnu-gcc-5.0.0
-JIT:       argv[1]: -shared
-JIT:       argv[2]: /tmp/libgccjit-CKq1M9/fake.s
-JIT:       argv[3]: -o
-JIT:       argv[4]: /tmp/libgccjit-CKq1M9/fake.so
-JIT:       argv[5]: -fno-use-linker-plugin
-JIT:       argv[6]: (null)
+JIT:       entering: void gcc::jit::playback::context::add_multilib_driver_arguments(vec<char*>*)
+JIT:       exiting: void gcc::jit::playback::context::add_multilib_driver_arguments(vec<char*>*)
+JIT:       argv[0]: x86_64-unknown-linux-gnu-gcc-5.2.1
+JIT:       argv[1]: -m64
+JIT:       argv[2]: -shared
+JIT:       argv[3]: /tmp/libgccjit-CKq1M9/fake.s
+JIT:       argv[4]: -o
+JIT:       argv[5]: /tmp/libgccjit-CKq1M9/fake.so
+JIT:       argv[6]: -fno-use-linker-plugin
+JIT:       argv[7]: (null)
 JIT:      exiting: void gcc::jit::playback::context::invoke_driver(const char*, const char*, const char*, timevar_id_t, bool, bool)
 JIT:     exiting: void gcc::jit::playback::context::convert_to_dso(const char*)
 JIT:     entering: gcc::jit::result* gcc::jit::playback::context::dlopen_built_dso()
Index: gcc/jit/docs/_build/texinfo/libgccjit.texi
===================================================================
--- gcc/jit/docs/_build/texinfo/libgccjit.texi	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/jit/docs/_build/texinfo/libgccjit.texi	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -19,7 +19,7 @@
 
 @copying
 @quotation
-libgccjit 5.1.1 ( 20150701), July 01, 2015
+libgccjit 5.2.1 ( 20150723), July 23, 2015
 
 David Malcolm
 
@@ -14675,7 +14675,7 @@
 generated via this call:
 
 @example
-JIT: libgccjit (GCC) version 5.0.0 20150123 (experimental) (x86_64-unknown-linux-gnu)
+JIT: libgccjit (GCC) version 5.2.1 20150723 (x86_64-unknown-linux-gnu)
 JIT:	compiled by GNU C version 4.8.3 20140911 (Red Hat 4.8.3-7), GMP version 5.1.2, MPFR version 3.1.2, MPC version 1.0.1
 JIT: entering: gcc_jit_context_set_str_option
 JIT:  GCC_JIT_STR_OPTION_PROGNAME: "./test-hello-world.c.exe"
@@ -14741,6 +14741,7 @@
 JIT:   GCC_JIT_BOOL_OPTION_DUMP_EVERYTHING: false
 JIT:   GCC_JIT_BOOL_OPTION_SELFCHECK_GC: true
 JIT:   GCC_JIT_BOOL_OPTION_KEEP_INTERMEDIATES: false
+JIT:   gcc_jit_context_set_bool_allow_unreachable_blocks: false
 JIT:   entering: void gcc::jit::recording::context::validate()
 JIT:   exiting: void gcc::jit::recording::context::validate()
 JIT:   entering: gcc::jit::playback::context::context(gcc::jit::recording::context*)
@@ -14806,13 +14807,16 @@
 JIT:    entering: virtual void gcc::jit::playback::compile_to_memory::postprocess(const char*)
 JIT:     entering: void gcc::jit::playback::context::convert_to_dso(const char*)
 JIT:      entering: void gcc::jit::playback::context::invoke_driver(const char*, const char*, const char*, timevar_id_t, bool, bool)
-JIT:       argv[0]: x86_64-unknown-linux-gnu-gcc-5.0.0
-JIT:       argv[1]: -shared
-JIT:       argv[2]: /tmp/libgccjit-CKq1M9/fake.s
-JIT:       argv[3]: -o
-JIT:       argv[4]: /tmp/libgccjit-CKq1M9/fake.so
-JIT:       argv[5]: -fno-use-linker-plugin
-JIT:       argv[6]: (null)
+JIT:       entering: void gcc::jit::playback::context::add_multilib_driver_arguments(vec<char*>*)
+JIT:       exiting: void gcc::jit::playback::context::add_multilib_driver_arguments(vec<char*>*)
+JIT:       argv[0]: x86_64-unknown-linux-gnu-gcc-5.2.1
+JIT:       argv[1]: -m64
+JIT:       argv[2]: -shared
+JIT:       argv[3]: /tmp/libgccjit-CKq1M9/fake.s
+JIT:       argv[4]: -o
+JIT:       argv[5]: /tmp/libgccjit-CKq1M9/fake.so
+JIT:       argv[6]: -fno-use-linker-plugin
+JIT:       argv[7]: (null)
 JIT:      exiting: void gcc::jit::playback::context::invoke_driver(const char*, const char*, const char*, timevar_id_t, bool, bool)
 JIT:     exiting: void gcc::jit::playback::context::convert_to_dso(const char*)
 JIT:     entering: gcc::jit::result* gcc::jit::playback::context::dlopen_built_dso()
Index: gcc/jit/jit-playback.c
===================================================================
--- gcc/jit/jit-playback.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/jit/jit-playback.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -2432,8 +2432,8 @@
      TV_ASSEMBLE.  */
   auto_timevar assemble_timevar (tv_id);
   const char *errmsg;
-  auto_vec <const char *> argvec;
-#define ADD_ARG(arg) argvec.safe_push (arg)
+  auto_argvec argvec;
+#define ADD_ARG(arg) argvec.safe_push (xstrdup (arg))
   int exit_status = 0;
   int err = 0;
   const char *gcc_driver_name = GCC_DRIVER_NAME;
@@ -2440,6 +2440,8 @@
 
   ADD_ARG (gcc_driver_name);
 
+  add_multilib_driver_arguments (&argvec);
+
   if (shared)
     ADD_ARG ("-shared");
 
@@ -2459,8 +2461,17 @@
      time.  */
   ADD_ARG ("-fno-use-linker-plugin");
 
+#if defined (DARWIN_X86) || defined (DARWIN_PPC)
+  /* OS X's linker defaults to treating undefined symbols as errors.
+     If the context has any imported functions or globals they will be
+     undefined until the .so is dynamically-linked into the process.
+     Ensure that the driver passes in "-undefined dynamic_lookup" to the
+     linker.  */
+  ADD_ARG ("-Wl,-undefined,dynamic_lookup");
+#endif
+
   /* pex argv arrays are NULL-terminated.  */
-  ADD_ARG (NULL);
+  argvec.safe_push (NULL);
 
   /* pex_one's error-handling requires pname to be non-NULL.  */
   gcc_assert (ctxt_progname);
@@ -2501,6 +2512,36 @@
 #undef ADD_ARG
 }
 
+/* Extract the target-specific MULTILIB_DEFAULTS to
+   multilib_defaults_raw for use by
+   playback::context::add_multilib_driver_arguments ().  */
+
+#ifndef MULTILIB_DEFAULTS
+#define MULTILIB_DEFAULTS { "" }
+#endif
+
+static const char *const multilib_defaults_raw[] = MULTILIB_DEFAULTS;
+
+/* Helper function for playback::context::invoke_driver ().
+
+   32-bit and 64-bit multilib peer builds of libgccjit.so may share
+   a driver binary.  We need to pass in options to the shared driver
+   to get the appropriate assembler/linker options for this multilib
+   peer.  */
+
+void
+playback::context::
+add_multilib_driver_arguments (vec <char *> *argvec)
+{
+  JIT_LOG_SCOPE (get_logger ());
+
+  /* Add copies of the arguments in multilib_defaults_raw to argvec,
+     prepending each with a "-".  */
+  for (size_t i = 0; i < ARRAY_SIZE (multilib_defaults_raw); i++)
+    if (multilib_defaults_raw[i][0])
+      argvec->safe_push (concat ("-", multilib_defaults_raw[i], NULL));
+}
+
 /* Dynamically-link the built DSO file into this process, using dlopen.
    Wrap it up within a jit::result *, and return that.
    Return NULL if any errors occur, reporting them on this context.  */
Index: gcc/jit/jit-playback.h
===================================================================
--- gcc/jit/jit-playback.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/jit/jit-playback.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -276,6 +276,9 @@
 		 bool shared,
 		 bool run_linker);
 
+  void
+  add_multilib_driver_arguments (vec <char *> *argvec);
+
   result *
   dlopen_built_dso ();
 
Index: gcc/ChangeLog
===================================================================
--- gcc/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,697 @@
+2015-09-17  Eric Botcazou  <ebotcazou@adacore.com>
+
+	PR rtl-optimization/66790
+	* df-problems.c (LIVE): Amend documentation.
+
+2015-09-17  Marek Polacek  <polacek@redhat.com>
+
+	Backport from mainline:
+	2015-08-18  Marek Polacek  <polacek@redhat.com>
+
+	PR middle-end/67222
+	* gimple-low.c (lower_stmt): Don't lower BUILT_IN_POSIX_MEMALIGN
+	if the call isn't valid.
+	* tree-ssa-alias.c (ref_maybe_used_by_call_p_1): Check builtins using
+	gimple_call_builtin_p.
+	(call_may_clobber_ref_p_1): Likewise.
+	(stmt_kills_ref_p): Likewise.
+
+2015-09-12  John David Anglin  <danglin@gcc.gnu.org>
+
+	* config/pa/pa.c (pa_output_move_double): Enhance to handle HIGH
+	CONSTANT_P operands.
+
+2015-09-10  Oleg Endo  <olegendo@gcc.gnu.org>
+
+	Backport from mainline
+	2015-09-10  Oleg Endo  <olegendo@gcc.gnu.org>
+
+	PR target/67506
+	* config/sh/sh.c (sh_extending_set_of_reg::use_as_extended_reg): Add
+	missing simplify_gen_subreg.
+
+2015-09-10  Rainer Orth  <ro@CeBiTec.Uni-Bielefeld.DE>
+
+	Backport from mainline
+	2015-08-27  Rainer Orth  <ro@CeBiTec.Uni-Bielefeld.DE>
+
+	* config.gcc (*-*-solaris2*): Enable default_use_cxa_atexit on
+	Solaris 12+.
+
+2015-09-10  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/67523
+	* gimplify.c (gimplify_omp_for): If inner stmt is not found
+	for combined loop, assert seen_error () and return GS_ERROR.
+
+	PR middle-end/67521
+	* gimplify.c (gimplify_omp_for): Don't call omp_add_variable
+	if decl is already in outer->variables.
+
+	PR middle-end/67517
+	* gimplify.c (gimplify_scan_omp_clauses): Instead of
+	asserting that decl is not specified in octx->variables,
+	break out of the loop if it is.
+
+	PR c++/67514
+	* gimplify.c (gimplify_omp_for): For loop SIMD construct, if
+	iterator is not explicitly determined, but is defined inside
+	of the combined workshare region, handle it like if it has
+	DECL_EXPR in OMP_FOR_PRE_BODY.
+
+2015-09-09  Marek Polacek  <polacek@redhat.com>
+
+	Backport from mainline:
+	2015-09-09  Marek Polacek  <polacek@redhat.com>
+
+	PR middle-end/67512
+	* tree-ssa-uninit.c (pred_equal_p): Only call invert_tree_comparison
+	for comparisons.
+
+2015-09-09  Alan Modra  <amodra@gmail.com>
+
+	PR target/67378
+	* config/rs6000/rs6000.c (rs6000_secondary_reload_gpr): Find
+	reload replacement for PRE_MODIFY address reg.
+
+2015-09-07  Ilya Verbin  <ilya.verbin@intel.com>
+
+	* config/i386/intelmic-mkoffload.c (prepare_target_image): Handle all
+	non-alphanumeric characters in the symbol name.
+
+2015-09-04  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/67452
+	* tree-ssa-live.c: Include cfgloop.h.
+	(remove_unused_locals): Clear loop->simduid if simduid is about
+	to be removed from cfun->local_decls.
+
+2015-09-03  Richard Biener  <rguenther@suse.de>
+
+	PR ipa/66705
+	* tree-ssa-structalias.c (ctor_for_analysis): New function.
+	(create_variable_info_for_1): Use ctor_for_analysis instead
+	of get_constructor.
+	(create_variable_info_for): Likewise.
+
+2015-09-02  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline:
+	2015-08-27  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/67317
+	* config/i386/i386.md (*add<mode>3_cc): Remove insn pattern.
+	(addqi3_cc): Ditto.
+	(UNSPEC_ADD_CARRY): Remove.
+	(addqi3_cconly_overflow): New expander.
+	(*add<dwi>3_doubleword): Split to add<mode>3_cconly_overflow.
+	Adjust for changed add<mode>3_carry.
+	(*neg<dwi>2_doubleword): Adjust for changed add<mode>3_carry.
+	(*sub<dwi>3_doubleword): Adjust for changed sub<mode>3_carry.
+	(<plusminus_insn><mode>3_carry): Remove expander.
+	(*<plusminus_insn><mode>3_carry): Split insn pattern to
+	add<mode>3_carry and sub<mode>3_carry.
+	(plusminus_carry_mnemonic): Remove code attribute.
+	(add<mode>3_carry): Canonicalize insn pattern.
+	(*addsi3_carry_zext): Ditto.
+	(sub<mode>3_carry): Ditto.
+	(*subsi3_carry_zext): Ditto.
+	(adcx<mode>3): Remove insn pattern.
+	(addcarry<mode>): New insn pattern.
+	(subborrow<mode>): Ditto.
+	* config/i386/i386.c (ix86_expand_strlensi_unroll_1): Use
+	gen_addqi3_cconly_overflow instead of gen_addqi3_cc.
+	(ix86_expand_builtin) <case IX86_BUILTIN_SBB32,
+	case IX86_BUILTIN_SBB64, case IX86_BUILTIN_ADDCARRY32,
+	case IX86_BUILTIN_ADDCARRY64>: Use CODE_FOR_subborrowsi,
+	CODE_FOR_subborrowdi, CODE_FOR_addcarrysi and CODE_FOR_addcarrydi.
+	Rewrite expander to not clobber carry flag chains.
+
+2015-09-02  Alan Modra  <amodra@gmail.com>
+
+	PR target/67417
+	* config/rs6000/predicates.md (current_file_function_operand): Don't
+	return true for weak symbols.
+	* config/rs6000/rs6000.c (rs6000_function_ok_for_sibcall): Likewise.
+
+2015-08-31  Marek Polacek  <polacek@redhat.com>
+
+	Backport from mainline
+	2015-08-27  Marek Polacek  <polacek@redhat.com>
+
+	PR middle-end/67005
+	* tree-ssa-dce.c (remove_dead_stmt): Also schedule fixup if removing
+	an entry into an irreducible region.
+
+2015-08-27  Pat Haugen  <pthaugen@us.ibm.com>
+
+	Backport from mainline:
+	2015-08-27  Pat Haugen  <pthaugen@us.ibm.com>
+
+	* config/rs6000/vector.md (vec_shr_<mode>): Fix to do a shift
+	instead of a rotate.
+
+2015-08-26  Renlin Li  <renlin.li@arm.com>
+
+	Backport from mainline
+	2015-08-24  Renlin Li  <renlin.li@arm.com>
+
+	* config/arm/arm-protos.h (arm_valid_symbolic_address_p): Declare.
+	* config/arm/arm.c (arm_valid_symbolic_address_p): Define.
+	* config/arm/arm.md (arm_movt): Use arm_valid_symbolic_address_p.
+	* config/arm/constraints.md ("j"): Add check for high code.
+
+2015-08-25  Dominik Vogt  <vogt@linux.vnet.ibm.com>
+
+	Backport from mainline
+	2015-08-21  Dominik Vogt  <vogt@linux.vnet.ibm.com>
+
+    	* config/s390/s390-builtins.def: Fix value range of vec_load_bndry.
+
+2015-08-24  Michael Meissner  <meissner@linux.vnet.ibm.com>
+
+	Back port from mainline:
+	2015-08-24  Michael Meissner  <meissner@linux.vnet.ibm.com>
+
+	PR target/67211
+	* config/rs6000/rs6000-cpus.def (ISA_2_7_MASKS_SERVER): Set
+	-mefficient-unaligned-vsx on ISA 2.7.
+
+	* config/rs6000/rs6000.opt (-mefficient-unaligned-vsx): Convert
+	option to a masked option.
+
+	* config/rs6000/rs6000.c (rs6000_option_override_internal): Rework
+	logic for -mefficient-unaligned-vsx so that it is set via an arch
+	ISA option, instead of being set if -mtune=power8 is set. Move
+	-mefficient-unaligned-vsx and -mallow-movmisalign handling to be
+	near other default option handling.
+
+2015-08-20  Georg-Johann Lay  <avr@gjlay.de>
+
+	* config/avr/avr.c (avr_insert_attributes): In diagnostic essage:
+	Multiply argument avr_n_flash by 64 to match unit of "KiB".
+	(avr_pgm_check_var_decl): Same.
+
+2015-08-18  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	Backport from mainline:
+	2015-08-08  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	PR rtl-optimization/67028
+	* combine.c (simplify_comparison): Fix comment.  Rearrange code.
+	Add test to see if a const_int fits in the new mode.
+
+2015-08-17  Jason Merrill  <jason@redhat.com>
+
+	PR c++/65734
+	* stor-layout.c (layout_type): Layout the TYPE_MAIN_VARIANT.
+	(finalize_type_size): Respect TYPE_USER_ALIGN.
+	(layout_type) [ARRAY_TYPE]: Likewise.
+
+2015-08-17  Yvan Roux  <yvan.roux@linaro.org>
+
+	Backport from mainline:
+	2015-08-12  Yvan Roux  <yvan.roux@linaro.org>
+
+	PR target/67127
+	* config/arm/arm.md (movdi): Restrict illegitimate ldrd/strd checking
+	to ARM core registers.
+
+2015-08-16  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline:
+	2015-07-25  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/66648
+	* config/i386/i386.c (ix86_expand_set_or_movmem): Emit main loop
+	execution guard when min_size is less than size_needed.
+
+2015-08-11  Thomas Preud'homme  <thomas.preudhomme@arm.com>
+
+	Backport from mainline
+	2015-07-28  Thomas Preud'homme  <thomas.preudhomme@arm.com>
+
+	PR tree-optimization/66828
+	* tree-ssa-math-opts.c (perform_symbolic_merge): Change type of inc
+	from int64_t to uint64_t.
+
+2015-08-07  Kaz Kojima  <kkojima@gcc.gnu.org>
+
+	Backport from mainline
+	2015-08-07  Kaz Kojima  <kkojima@gcc.gnu.org>
+
+	PR target/67002
+	* config/sh/sh.c (sh_recog_treg_set_expr): Return false when
+	currently_expanding_to_rtl is set.
+
+2015-08-07  Kirill Yukhin  <kirill.yukhin@intel.com>
+
+	* config/i386/i386.md (define_attr "isa"): Addd avx512vl and
+	noavx512vl.
+	(define_attr "enabled"): Handle avx521vl and noavx512vl.
+	* config/i386/sse.md (define_insn "vec_dupv2df<mask_name>"): Split
+	AVX-512 alternative out of SSE.
+	(define_insn "*vec_concatv2df"): Ditto.
+
+2015-08-05  Matthew Wahab  <matthew.wahab@arm.com>
+
+	Backport from trunk:
+	2015-06-29  Matthew Wahab  <matthew.wahab@arm.com>
+
+	PR target/65697
+	* config/arm/arm.c (arm_split_compare_and_swap): For ARMv8,
+	replace an initial acquire barrier with final barrier.
+
+2015-08-05  Matthew Wahab  <matthew.wahab@arm.com>
+
+	Backport from trunk:
+	2015-06-29  Matthew Wahab  <matthew.wahab@arm.com>
+
+	PR target/65697
+	* config/arm/arm.c (arm_split_atomic_op): For ARMv8, replace an
+	initial acquire barrier with final barrier.
+
+2015-08-05  Matthew Wahab  <matthew.wahab@arm.com>
+
+	Backport from trunk.
+	2015-06-01  Matthew Wahab  <matthew.wahab@arm.com>
+
+	PR target/65697
+	* config/aarch64/aarch64.c (aarch64_split_compare_and_swap): Check
+	for __sync memory models, emit initial loads and final barriers as
+	appropriate.
+
+2015-08-05  Matthew Wahab  <matthew.wahab@arm.com>
+
+	Backport from trunk.
+	2015-06-01  Matthew Wahab  <matthew.wahab@arm.com>
+
+	PR target/65697
+	* config/aarch64/aarch64.c (aarch64_emit_post_barrier): New.
+	(aarch64_split_atomic_op): Check for __sync memory models, emit
+	appropriate initial loads and final barriers.
+
+2015-08-05  Matthew Wahab  <matthew.wahab@arm.com>
+
+	Backport from trunk
+	2015-05-12  Andrew MacLeod  <amacleod@redhat.com>
+
+	PR target/65697
+	* coretypes.h (MEMMODEL_SYNC, MEMMODEL_BASE_MASK): New macros.
+	(enum memmodel): Add SYNC_{ACQUIRE,RELEASE,SEQ_CST}.
+	* tree.h (memmodel_from_int, memmodel_base, is_mm_relaxed)
+	(is_mm_consume,is_mm_acquire, is_mm_release, is_mm_acq_rel)
+	(is_mm_seq_cst, is_mm_sync): New accessor functions.
+	* builtins.c (expand_builtin_sync_operation)
+	(expand_builtin_compare_and_swap): Use MEMMODEL_SYNC_SEQ_CST.
+	(expand_builtin_sync_lock_release): Use MEMMODEL_SYNC_RELEASE.
+	(get_memmodel,  expand_builtin_atomic_compare_exchange)
+	(expand_builtin_atomic_load, expand_builtin_atomic_store)
+	(expand_builtin_atomic_clear): Use new accessor routines.
+	(expand_builtin_sync_synchronize): Use MEMMODEL_SYNC_SEQ_CST.
+	* optabs.c (expand_compare_and_swap_loop): Use MEMMODEL_SYNC_SEQ_CST.
+	(maybe_emit_sync_lock_test_and_set): Use new accessors and
+	MEMMODEL_SYNC_ACQUIRE.
+	(expand_sync_lock_test_and_set): Use MEMMODEL_SYNC_ACQUIRE.
+	(expand_mem_thread_fence, expand_mem_signal_fence, expand_atomic_load)
+	(expand_atomic_store): Use new accessors.
+	* emit-rtl.c (need_atomic_barrier_p): Add additional enum cases.
+	* tsan.c (instrument_builtin_call): Update check for memory model beyond
+	final enum to use MEMMODEL_LAST.
+	* c-family/c-common.c: Use new accessor for memmodel_base.
+	* config/aarch64/aarch64.c (aarch64_expand_compare_and_swap): Use new
+	accessors.
+	* config/aarch64/atomics.md (atomic_load<mode>,atomic_store<mode>)
+	(arch64_load_exclusive<mode>, aarch64_store_exclusive<mode>)
+	(mem_thread_fence, *dmb): Likewise.
+	* config/alpha/alpha.c (alpha_split_compare_and_swap)
+	(alpha_split_compare_and_swap_12): Likewise.
+	* config/arm/arm.c (arm_expand_compare_and_swap)
+	(arm_split_compare_and_swap, arm_split_atomic_op): Likewise.
+	* config/arm/sync.md (atomic_load<mode>, atomic_store<mode>)
+	(atomic_loaddi): Likewise.
+	* config/i386/i386.c (ix86_destroy_cost_data, ix86_memmodel_check):
+	Likewise.
+	* config/i386/sync.md (mem_thread_fence, atomic_store<mode>): Likewise.
+	* config/ia64/ia64.c (ia64_expand_atomic_op): Add new memmodel cases and
+	use new accessors.
+	* config/ia64/sync.md (mem_thread_fence, atomic_load<mode>)
+	(atomic_store<mode>, atomic_compare_and_swap<mode>)
+	(atomic_exchange<mode>): Use new accessors.
+	* config/mips/mips.c (mips_process_sync_loop): Likewise.
+	* config/pa/pa.md (atomic_loaddi, atomic_storedi): Likewise.
+	* config/rs6000/rs6000.c (rs6000_pre_atomic_barrier)
+	(rs6000_post_atomic_barrier): Add new cases.
+	(rs6000_expand_atomic_compare_and_swap): Use new accessors.
+	* config/rs6000/sync.md (mem_thread_fence): Add new cases.
+	(atomic_load<mode>): Add new cases and use new accessors.
+	(store_quadpti): Add new cases.
+	* config/s390/s390.md (mem_thread_fence, atomic_store<mode>): Use new
+	accessors.
+	* config/sparc/sparc.c (sparc_emit_membar_for_model): Use new accessors.
+	* doc/extend.texi: Update docs to indicate 16 bits are used for memory
+	model, not 8.
+
+2015-08-04  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	Backport from mainline:
+	2015-08-04  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	PR target/66731
+	* config/aarch64/aarch64.c (aarch64_rtx_costs): Fix NEG cost for FNMUL.
+	(aarch64_rtx_mult_cost): Fix MULT cost with -frounding-math.
+
+	2015-07-06  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	PR target/66731
+	* config/aarch64/aarch64.md (fnmul<mode>3): Handle -frounding-math.
+
+2015-08-03  Peter Bergner  <bergner@vnet.ibm.com>
+
+	Backport from mainline:
+	2015-08-03  Peter Bergner  <bergner@vnet.ibm.com>
+
+	* config/rs6000/htm.md (tabort.): Restrict the source operand to
+	using a base register.
+
+2015-08-03  John David Anglin  <danglin@gcc.gnu.org>
+
+	PR target/67060
+	* config/pa/pa.md (call_reg_64bit): Remove reg:DI 1 clobber.
+	Adjust splits to match new pattern.
+
+2015-08-03  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	Backport form mainline r226496.
+	2015-08-03  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	PR target/66731
+	* config/arm/vfp.md (negmuldf3_vfp): Add new pattern.
+	(negmulsf3_vfp): Likewise.
+	(muldf3negdf_vfp): Disable for -frounding-math.
+	(mulsf3negsf_vfp): Likewise.
+	* config/arm/arm.c (arm_new_rtx_costs): Fix NEG cost for VNMUL,
+	fix MULT cost with -frounding-math.
+
+2015-07-31  Kaz Kojima  <kkojima@gcc.gnu.org>
+
+	Backport form mainline
+	2015-07-31  Kaz Kojima  <kkojima@gcc.gnu.org>
+
+	PR target/67049
+	* config/sh/sh.md (GOTaddr2picreg): Fix typo.
+
+2015-07-31  Vladimir Makarov  <vmakarov@redhat.com>
+
+	PR debug/66691
+	* lra-int.h (lra_substitute_pseudo): Add a parameter.
+	(lra_substitute_pseudo_within_insn): Ditto.
+	* lra.c (lra_substitute_pseudo): Add a parameter.  Simplify subreg
+	of constant.
+	(lra_substitute_pseudo_within_insn): Add a parameter.  Transfer it
+	to lra_substitute_pseudo.
+	* lra-lives.c (process_bb_lives): Add an argument to
+	lra_substitute_pseudo_within_insn call.
+	* lra-constraints.c (inherit_reload_reg, split_reg): Add an
+	argument to lra_substitute_pseudo and
+	lra_substitute_pseudo_within_insn calls.
+	(remove_inheritance_pseudos, undo_optional_reloads): Ditto.
+
+2015-07-27  Marek Polacek  <polacek@redhat.com>
+
+	Backport from mainline
+	2015-07-27  Marek Polacek  <polacek@redhat.com>
+
+	* ipa-devirt.c (types_same_for_odr): Fix typo.
+
+2015-07-25  Oleg Endo  <olegendo@gcc.gnu.org>
+
+	Backport from mainline
+	2015-07-25  Oleg Endo  <olegendo@gcc.gnu.org>
+
+	PR target/66930
+	* config/sh/sh.c (sh_split_movrt_negc_to_movt_xor): Add missing
+	T bit register modified_between_p check.
+
+2015-07-25  Tom de Vries  <tom@codesourcery.com>
+
+	backport from trunk:
+	2015-07-24  Tom de Vries  <tom@codesourcery.com>
+
+	* graphite-sese-to-poly.c (is_reduction_operation_p): Limit
+	flag_associative_math to FLOAT_TYPE_P.  Honour
+	TYPE_OVERFLOW_WRAPS for INTEGRAL_TYPE_P. Don't allow any other types.
+
+2015-07-25  Kaz Kojima  <kkojima@gcc.gnu.org>
+
+	Backport from mainline
+	2015-07-16  Kaz Kojima  <kkojima@gcc.gnu.org>
+
+	PR target/65249
+	* config/sh/sh.md (movdi): Split simple reg move to two movsi
+	when the destination is R0.
+
+2015-07-24  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	Backport from mainline r226159.
+	2015-07-24  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	* config/aarch64/aarch64-elf-raw.h (LINK_SPEC): Handle -h, -static,
+	-shared, -symbolic, -rdynamic.
+
+2015-07-24  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	Backport from mainline r226158.
+	2015-07-24  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	PR target/65711
+	* config/aarch64/aarch64-linux.h (LINUX_TARGET_LINK_SPEC): Move
+	-dynamic-linker within %{!static %{!shared, and -rdynamic within
+	%{!static.
+
+2015-07-24  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	Backport from mainline r226155.
+	2015-07-24  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	PR ipa/66566
+	* ipa-inline-analysis.c (estimate_calls_size_and_time): Check
+	edge summary is available.
+
+2015-07-23  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline:
+	2015-07-17  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR rtl-optimization/66891
+	* calls.c (expand_call): Wrap precompute_register_parameters with
+	NO_DEFER_POP/OK_DEFER_POP to prevent deferred pops.
+
+	2015-07-15  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/58066
+	* config/i386/i386.md (*tls_global_dynamic_64_<mode>): Depend on SP_REG.
+	(*tls_local_dynamic_base_64_<mode>): Ditto.
+	(*tls_local_dynamic_base_64_largepic): Ditto.
+	(tls_global_dynamic_64_<mode>): Update expander pattern.
+	(tls_local_dynamic_base_64_<mode>): Ditto.
+
+	2015-07-15  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR rtl-optimization/58066
+	* calls.c (expand_call): Precompute register parameters before stack
+	alignment is performed.
+
+2015-07-23  Martin Jambor  <mjambor@suse.cz>
+
+	Backport from mainline r225867.
+	2015-07-16  Martin Jambor  <mjambor@suse.cz>
+
+	* ipa-prop.h (param_aa_status): Rename to ipa_param_aa_status.  Adjust
+	all uses.  Fix two typos in its general comment.
+	(func_body_info): Rename to ipa_func_body_info.  Adjust all uses.
+
+2015-07-23  Martin Jambor  <mjambor@suse.cz>
+
+	Backport from mainline r225838.
+	2015-07-15  Paolo Bonzini  <bonzini@gnu.org>
+	    	    Martin Jambor  <mjambor@suse.cz>
+
+	PR ipa/66760
+	* ipa-inline-analysis.c (unmodified_parm_or_parm_agg_item): Accept
+	struct func_body_info* instead of struct ipa_node_params*, expecting
+	fbi->info to be filled in.  Replace throughout.  Adjust call to
+	ipa_load_from_parm_agg.
+	(set_cond_stmt_execution_predicate): Accept struct func_body_info*
+	instead of struct ipa_node_params*.  Adjust calls to other functions
+	so that they pass either fbi or fbi->info.
+	(set_switch_stmt_execution_predicate): Likewise.
+	(will_be_nonconstant_predicate): Likewise.
+	(compute_bb_predicates): Likewise.
+	(estimate_function_body_sizes): Move asserts earlier.  Fill in
+	struct func_body_info, replace parms_info with fbi.info.  Adjust
+	calls to functions that now accept struct func_body_info.
+	* ipa-prop.c (param_aa_status, struct ipa_bb_info): Move to ipa-prop.h.
+	(struct func_body_info): Likewise.
+	(ipa_load_from_parm_agg_1): Rename to ipa_load_from_parm_agg,
+	remove static.  Adjust callers.
+	(ipa_load_from_parm_agg): Remove.
+	* ipa-prop.h (param_aa_status, ipa_bb_info): Move from ipa-prop.c.
+	(func_body_info): Likewise.
+	(ipa_load_from_parm_agg): Adjust prototype.
+
+2015-07-23  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	Backport from mainline r224643.
+	2015-06-19  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	PR middle-end/pr66581
+	* tree-chkp.c (chkp_compute_bounds_for_assignment): Don't
+	reuse bounds created for abnormal ssa names.
+
+2015-07-23  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	Backport from mainline r224602.
+	2015-06-18  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	PR target/66569
+	* function.c (assign_bounds): Add arguments assign_regs,
+	assign_special, assign_bt.
+	(assign_parms): For vararg functions handle bounds in BT
+	and special slots after incoming vararg bounds.
+
+2015-07-23  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	Backport from mainline r224601.
+	2015-06-18  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	PR middle-end/66568
+	* cfgexpand.c (expand_return): Handle missing bounds.
+	(expand_gimple_stmt_1): Likewise.
+	* tree-chkp.c (chkp_expand_zero_bounds): New.
+	* tree-chkp.h (chkp_expand_zero_bounds): New.
+
+2015-07-23  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	Backport from mainline r224600.
+	2015-06-18  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	PR middle-end/66567
+	* ipa-chkp.c (chkp_maybe_create_clone): Require
+	functions to be instrumentable.
+	* tree-chkp.c (chkp_replace_function_pointer): Use
+	chkp_instrumentable_p instead of attribute check.
+
+2015-07-23  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	Backport from mainline r223215.
+	2015-05-15  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	PR middle-end/66134
+	* tree-chkp.c (chkp_get_orginal_bounds_for_abnormal_copy): New.
+	(chkp_maybe_copy_and_register_bounds): Don't copy abnormal copy.
+
+2015-07-23  Ilya Enkovich  <ilya.enkovich@intel.com>
+
+	Backport from mainline r223114.
+	2015-05-13  Ilya Enkovich  <ilya.enkovich@intel.com>
+
+	PR target/66048
+	* function.c (diddle_return_value_1): Process bounds first.
+	* config/i38/i386.c (ix86_function_value_regno_p): Add bnd1
+	register.
+
+2015-07-23  Ilya Enkovich  <ilya.enkovich@intel.com>
+
+	Backport from mainline r223216.
+	2015-05-15  Ilya Enkovich  <ilya.enkovich@intel.com>
+
+	* ipa-chkp.h (chkp_wrap_function): New.
+	* ipa-chkp.c (chkp_wrap_function): Remove 'static'.
+	(chkp_wrap_function_name): New.
+	(chkp_build_instrumented_fndecl): Use chkp_wrap_function_name
+	to get wrapper name.
+	* lto-cgraph.c: Include ipa-chkp.h.
+	(input_cgraph_1): Avoid alias chain for wrappers.
+
+2015-07-23  Ilya Enkovich  <ilya.enkovich@intel.com>
+
+	Backport from mainline r224074.
+	2015-06-03  Ilya Enkovich  <ilya.enkovich@intel.com>
+
+	* ipa-chkp.c (chkp_maybe_create_clone): Create alias
+	reference when cloning alias node.
+
+2015-07-21  Georg-Johann Lay  <avr@gjlay.de>
+
+	Backport from 2015-07-21 trunk r226046.
+
+	PR target/66956
+	* config/avr/avr-dimode.md (<extend_u>mulsidi3_insn)
+	(<extend_u>mulsidi3): Don't use if !AVR_HAVE_MUL.
+
+2015-07-21  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/66948
+	* genmatch.c (capture_info::walk_match): Also recurse to
+	captures.  Properly compute expr state from captures of
+	captures.
+
+2015-07-18  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/66922
+	* config/i386/i386.c (ix86_expand_pinsr): Reject insertions
+	to misaligned positions.
+
+2015-07-17  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/66866
+	* config/i386/i386.c (ix86_expand_pinsr): Reject non-lowpart
+	source subregs.
+
+2015-07-17  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline:
+	2015-07-10  Uros Bizjak  <ubizjak@gmail.com>
+
+	* config/i386/sse.md (movdi_to_sse): Use gen_lowpart
+	and gen_higpart instead of gen_rtx_SUBREG.
+	* config/i386/i386.md
+	(floatdi<X87MODEF:mode>2_i387_with_xmm splitter): Ditto.
+	(read-modify peephole2): Use gen_lowpart instead of
+	gen_rtx_SUBREG for operand 5.
+
+2015-07-17  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline:
+	2015-07-08  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/66814
+	* config/i386/predicates.md (nonimmediate_gr_operand): New predicate.
+	* config/i386/i386.md (not peephole2): Use nonimmediate_gr_operand.
+	(varous peephole2s): Use {GENERAL,SSE,MMX}_REGNO_P instead of
+	{GENERAL,SSE,MMX}_REG_P where appropriate.
+
+2015-07-17  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline:
+	2015-07-15  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR rtl-optimization/66838
+	* postreload.c (reload_cse_move2add): Also process
+	CALL_INSN_FUNCTION_USAGE when resetting information of
+	call-clobbered registers.
+
+2015-07-16  Martin Liska  <mliska@suse.cz>
+
+	PR ipa/66896
+	* ipa-prop.c (update_jump_functions_after_inlining): Create properly
+	dst_ctx if it does not exist.
+
+2015-07-16  Richard Biener  <rguenther@suse.de>
+
+	* BASE-VER: Set to 5.2.1.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
@@ -119,8 +813,8 @@
 2015-07-09  Iain Sandoe  <iain@codesourcery.com>
 
 	PR target/66523
-	* config/darwin.c (darwin_mark_decl_preserved): Exclude 'L' label names from
-	preservation.
+	* config/darwin.c (darwin_mark_decl_preserved): Exclude 'L' label
+	names from preservation.
 
 2015-07-06  Alan Lawrence  <alan.lawrence@arm.com>
 
Index: gcc/testsuite/jit.dg/test-benchmark.c
===================================================================
--- gcc/testsuite/jit.dg/test-benchmark.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/jit.dg/test-benchmark.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -209,6 +209,7 @@
 {
   int opt_level;
   int num_iterations = 100;
+  double elapsed_time[4];
 
   ticks_to_msec = TICKS_TO_MSEC;
 
@@ -215,7 +216,7 @@
   for (opt_level = 0; opt_level < 4; opt_level++)
     {
       int i;
-      double start_time, end_time, elapsed_time;
+      double start_time, end_time;
       start_time = get_wallclock_time ();
       for (i = 1; i <= num_iterations; i++)
 	{
@@ -226,15 +227,26 @@
 	  test_jit (argv[0], opt_level);
 	}
       end_time = get_wallclock_time ();
-      elapsed_time = end_time - start_time;
+      elapsed_time[opt_level] = end_time - start_time;
       pass ("%s: survived %i iterations at optlevel %i",
 	    argv[0], num_iterations, opt_level);
       note (("%s: %i iterations at optlevel %i"
 	     " took a total of %.3fs (%.3fs per iteration)"),
 	    argv[0], num_iterations, opt_level,
-	    elapsed_time, elapsed_time / num_iterations);
+	    elapsed_time[opt_level],
+	    elapsed_time[opt_level] / num_iterations);
     }
+
   totals ();
 
+  /* Print a summary.  */
+  printf ("%s: %i iterations: time taken (lower is better)\n",
+	  argv[0], num_iterations);
+  for (opt_level = 0; opt_level < 4; opt_level++)
+    printf ("optlevel %i: %.3fs (%.3fs per iteration)\n",
+	    opt_level,
+	    elapsed_time[opt_level],
+	    elapsed_time[opt_level] / num_iterations);
+
   return 0;
 }
Index: gcc/testsuite/gcc.target/powerpc/htm-tabort-no-r0.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/htm-tabort-no-r0.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/htm-tabort-no-r0.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,12 @@
+/* { dg-do compile { target { powerpc*-*-* } } } */
+/* { dg-skip-if "" { powerpc*-*-darwin* } { "*" } { "" } } */
+/* { dg-require-effective-target powerpc_htm_ok } */
+/* { dg-options "-O2 -mhtm -ffixed-r3 -ffixed-r4 -ffixed-r5 -ffixed-r6 -ffixed-r7 -ffixed-r8 -ffixed-r9 -ffixed-r10 -ffixed-r11 -ffixed-r12" } */
+
+/* { dg-final { scan-assembler-not "tabort\\.\[ \t\]0" } } */
+
+int
+foo (void)
+{
+  return __builtin_tabort (10);
+}
Index: gcc/testsuite/gcc.target/powerpc/vec-shr.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/vec-shr.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/vec-shr.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,34 @@
+/* { dg-do run } */
+/* { dg-options "-O3 -fno-inline" } */
+
+#include <stdlib.h>
+
+typedef struct { double r, i; } complex;
+#define LEN 30
+complex c[LEN];
+double d[LEN];
+
+void
+foo (complex *c, double *d, int len1)
+{
+  int i;
+  for (i = 0; i < len1; i++)
+    {
+      c[i].r = d[i];
+      c[i].i = 0.0;
+    }
+}
+
+int
+main (void)
+{
+  int i;
+  for (i = 0; i < LEN; i++)
+    d[i] = (double) i;
+  foo (c, d, LEN);
+  for (i=0;i<LEN;i++)
+    if ((c[i].r != (double) i) || (c[i].i != 0.0))
+      abort ();
+  return 0;
+}
+
Index: gcc/testsuite/gcc.target/arm/thumb1-far-jump-2.c
===================================================================
--- gcc/testsuite/gcc.target/arm/thumb1-far-jump-2.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.target/arm/thumb1-far-jump-2.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -5,7 +5,7 @@
 /* { dg-options "-Os" } */
 /* { dg-skip-if "" { ! { arm_thumb1 } } } */
 
-volatile register r4 asm("r4");
+volatile register int r4 asm ("r4");
 void f3(int i)
 {
 #define GO(n) \
Index: gcc/testsuite/gcc.target/arm/armv8-sync-comp-swap.c
===================================================================
--- gcc/testsuite/gcc.target/arm/armv8-sync-comp-swap.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/arm/armv8-sync-comp-swap.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,10 @@
+/* { dg-do compile } */
+/* { dg-require-effective-target arm_arch_v8a_ok } */
+/* { dg-options "-O2" } */
+/* { dg-add-options arm_arch_v8a } */
+
+#include "../aarch64/sync-comp-swap.x"
+
+/* { dg-final { scan-assembler-times "ldrex" 2 } } */
+/* { dg-final { scan-assembler-times "stlex" 2 } } */
+/* { dg-final { scan-assembler-times "dmb" 2 } } */
Index: gcc/testsuite/gcc.target/arm/thumb-ltu.c
===================================================================
--- gcc/testsuite/gcc.target/arm/thumb-ltu.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.target/arm/thumb-ltu.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -2,6 +2,9 @@
 /* { dg-require-effective-target arm_thumb1_ok } */
 /* { dg-options "-mcpu=arm1136jf-s -mthumb -O2" } */
 
+extern int foo ();
+extern int bar ();
+
 void f(unsigned a, unsigned b, unsigned c, unsigned d)
 {
   if (a <= b || c > d)
Index: gcc/testsuite/gcc.target/arm/vnmul-1.c
===================================================================
--- gcc/testsuite/gcc.target/arm/vnmul-1.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/arm/vnmul-1.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,18 @@
+/* { dg-do compile } */
+/* { dg-require-effective-target arm_vfp_ok } */
+/* { dg-skip-if "need fp instructions" { *-*-* } { "-mfloat-abi=soft" } { "" } } */
+/* { dg-options "-O2 -fno-rounding-math -mfpu=vfp -mfloat-abi=hard" } */
+
+double
+foo_d (double a, double b)
+{
+  /* { dg-final { scan-assembler "vnmul\\.f64" } } */
+  return -a * b;
+}
+
+float
+foo_s (float a, float b)
+{
+  /* { dg-final { scan-assembler "vnmul\\.f32" } } */
+  return -a * b;
+}
Index: gcc/testsuite/gcc.target/arm/vnmul-2.c
===================================================================
--- gcc/testsuite/gcc.target/arm/vnmul-2.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/arm/vnmul-2.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,18 @@
+/* { dg-do compile } */
+/* { dg-require-effective-target arm_vfp_ok } */
+/* { dg-skip-if "need fp instructions" { *-*-* } { "-mfloat-abi=soft" } { "" } } */
+/* { dg-options "-O2 -frounding-math -mfpu=vfp -mfloat-abi=hard" } */
+
+double
+foo_d (double a, double b)
+{
+  /* { dg-final { scan-assembler-not "vnmul\\.f64" } } */
+  return -a * b;
+}
+
+float
+foo_s (float a, float b)
+{
+  /* { dg-final { scan-assembler-not "vnmul\\.f32" } } */
+  return -a * b;
+}
Index: gcc/testsuite/gcc.target/arm/vnmul-3.c
===================================================================
--- gcc/testsuite/gcc.target/arm/vnmul-3.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/arm/vnmul-3.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,18 @@
+/* { dg-do compile } */
+/* { dg-require-effective-target arm_vfp_ok } */
+/* { dg-skip-if "need fp instructions" { *-*-* } { "-mfloat-abi=soft" } { "" } } */
+/* { dg-options "-O2 -fno-rounding-math -mfpu=vfp -mfloat-abi=hard" } */
+
+double
+foo_d (double a, double b)
+{
+  /* { dg-final { scan-assembler "vnmul\\.f64" } } */
+  return -(a * b);
+}
+
+float
+foo_s (float a, float b)
+{
+  /* { dg-final { scan-assembler "vnmul\\.f32" } } */
+  return -(a * b);
+}
Index: gcc/testsuite/gcc.target/arm/armv8-sync-op-acquire.c
===================================================================
--- gcc/testsuite/gcc.target/arm/armv8-sync-op-acquire.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/arm/armv8-sync-op-acquire.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,10 @@
+/* { dg-do compile } */
+/* { dg-require-effective-target arm_arch_v8a_ok } */
+/* { dg-options "-O2" } */
+/* { dg-add-options arm_arch_v8a } */
+
+#include "../aarch64/sync-op-acquire.x"
+
+/* { dg-final { scan-assembler-times "ldrex" 1 } } */
+/* { dg-final { scan-assembler-times "strex" 1 } } */
+/* { dg-final { scan-assembler-times "dmb" 1 } } */
Index: gcc/testsuite/gcc.target/arm/macro_defs0.c
===================================================================
--- gcc/testsuite/gcc.target/arm/macro_defs0.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.target/arm/macro_defs0.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,6 +1,7 @@
 /* { dg-do compile } */
 /* { dg-skip-if "avoid conflicting multilib options" { *-*-* } { "-march=*" } { "-march=armv7-m" } } */
 /* { dg-skip-if "avoid conflicting multilib options" { *-*-* } { "-mfloat-abi=*" } { "-mfloat-abi=soft" } } */
+/* { dg-skip-if "avoid conflicting multilib options" { *-*-* } { "-marm" } { "" } } */
 /* { dg-options "-march=armv7-m -mcpu=cortex-m3 -mfloat-abi=soft -mthumb" } */
 
 #ifdef __ARM_FP
Index: gcc/testsuite/gcc.target/arm/armv8-sync-op-full.c
===================================================================
--- gcc/testsuite/gcc.target/arm/armv8-sync-op-full.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/arm/armv8-sync-op-full.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,10 @@
+/* { dg-do compile } */
+/* { dg-require-effective-target arm_arch_v8a_ok } */
+/* { dg-options "-O2" } */
+/* { dg-add-options arm_arch_v8a } */
+
+#include "../aarch64/sync-op-full.x"
+
+/* { dg-final { scan-assembler-times "ldrex" 12 } } */
+/* { dg-final { scan-assembler-times "stlex" 12 } } */
+/* { dg-final { scan-assembler-times "dmb" 12 } } */
Index: gcc/testsuite/gcc.target/arm/vnmul-4.c
===================================================================
--- gcc/testsuite/gcc.target/arm/vnmul-4.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/arm/vnmul-4.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,18 @@
+/* { dg-do compile } */
+/* { dg-require-effective-target arm_vfp_ok } */
+/* { dg-skip-if "need fp instructions" { *-*-* } { "-mfloat-abi=soft" } { "" } } */
+/* { dg-options "-O2 -frounding-math -mfpu=vfp -mfloat-abi=hard" } */
+
+double
+foo_d (double a, double b)
+{
+  /* { dg-final { scan-assembler "vnmul\\.f64" } } */
+  return -(a * b);
+}
+
+float
+foo_s (float a, float b)
+{
+  /* { dg-final { scan-assembler "vnmul\\.f32" } } */
+  return -(a * b);
+}
Index: gcc/testsuite/gcc.target/arm/macro_defs1.c
===================================================================
--- gcc/testsuite/gcc.target/arm/macro_defs1.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.target/arm/macro_defs1.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,5 +1,6 @@
 /* { dg-do compile } */
 /* { dg-skip-if "avoid conflicting multilib options" { *-*-* } { "-march=*" } { "-march=armv6-m" } } */
+/* { dg-skip-if "avoid conflicting multilib options" { *-*-* } { "-marm" } { "" } } */
 /* { dg-options "-march=armv6-m -mthumb" } */
 
 #ifdef __ARM_NEON_FP
Index: gcc/testsuite/gcc.target/arm/thumb-bitfld1.c
===================================================================
--- gcc/testsuite/gcc.target/arm/thumb-bitfld1.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.target/arm/thumb-bitfld1.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -10,6 +10,8 @@
   unsigned b28 : 1;
   unsigned rest : 28;
 };
+
+unsigned
 foo(a)
      struct foo a;
 {
Index: gcc/testsuite/gcc.target/arm/split-live-ranges-for-shrink-wrap.c
===================================================================
--- gcc/testsuite/gcc.target/arm/split-live-ranges-for-shrink-wrap.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.target/arm/split-live-ranges-for-shrink-wrap.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,6 +1,8 @@
 /* { dg-do assemble } */
 /* { dg-options "-mthumb -Os -fdump-rtl-ira " }  */
 /* { dg-require-effective-target arm_thumb1_ok } */
+/* { dg-skip-if "do not test on armv4t" { *-*-* } { "-march=armv4t" } } */
+/* { dg-additional-options "-march=armv5t" {target arm_arch_v5t_ok} } */
 
 int foo (char *, char *, int);
 int test (int d, char * out, char *in, int len)
Index: gcc/testsuite/gcc.target/arm/armv8-sync-op-release.c
===================================================================
--- gcc/testsuite/gcc.target/arm/armv8-sync-op-release.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/arm/armv8-sync-op-release.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,8 @@
+/* { dg-do compile } */
+/* { dg-require-effective-target arm_arch_v8a_ok } */
+/* { dg-options "-O2" } */
+/* { dg-add-options arm_arch_v8a } */
+
+#include "../aarch64/sync-op-release.x"
+
+/* { dg-final { scan-assembler-times "stl" 1 } } */
Index: gcc/testsuite/gcc.target/arm/pr63210.c
===================================================================
--- gcc/testsuite/gcc.target/arm/pr63210.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.target/arm/pr63210.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,6 +1,8 @@
 /* { dg-do assemble } */
 /* { dg-options "-mthumb -Os " }  */
 /* { dg-require-effective-target arm_thumb1_ok } */
+/* { dg-skip-if "do not test on armv4t" { *-*-* } { "-march=armv4t" } } */
+/* { dg-additional-options "-march=armv5t" {target arm_arch_v5t_ok} } */
 
 int foo1 (int c);
 int foo2 (int c);
Index: gcc/testsuite/gcc.target/aarch64/sync-op-release.c
===================================================================
--- gcc/testsuite/gcc.target/aarch64/sync-op-release.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/sync-op-release.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,6 @@
+/* { dg-do compile } */
+/* { dg-options "-O2" } */
+
+#include "sync-op-release.x"
+
+/* { dg-final { scan-assembler-times "stlr" 1 } } */
Index: gcc/testsuite/gcc.target/aarch64/sync-op-release.x
===================================================================
--- gcc/testsuite/gcc.target/aarch64/sync-op-release.x	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/sync-op-release.x	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,7 @@
+int v;
+
+void
+sync_lock_release (void)
+{
+  __sync_lock_release (&v);
+}
Index: gcc/testsuite/gcc.target/aarch64/fnmul-1.c
===================================================================
--- gcc/testsuite/gcc.target/aarch64/fnmul-1.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/fnmul-1.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,16 @@
+/* { dg-do compile } */
+/* { dg-options "-O2" } */
+
+double
+foo_d (double a, double b)
+{
+  /* { dg-final { scan-assembler "fnmul\\td\[0-9\]+, d\[0-9\]+, d\[0-9\]+" } } */
+  return -a * b;
+}
+
+float
+foo_s (float a, float b)
+{
+  /* { dg-final { scan-assembler "fnmul\\ts\[0-9\]+, s\[0-9\]+, s\[0-9\]+" } } */
+  return -a * b;
+}
Index: gcc/testsuite/gcc.target/aarch64/sync-op-acquire.c
===================================================================
--- gcc/testsuite/gcc.target/aarch64/sync-op-acquire.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/sync-op-acquire.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,8 @@
+/* { dg-do compile } */
+/* { dg-options "-O2" } */
+
+#include "sync-op-acquire.x"
+
+/* { dg-final { scan-assembler-times "ldxr\tw\[0-9\]+, \\\[x\[0-9\]+\\\]" 1 } } */
+/* { dg-final { scan-assembler-times "stxr\tw\[0-9\]+, w\[0-9\]+, \\\[x\[0-9\]+\\\]" 1 } } */
+/* { dg-final { scan-assembler-times "dmb\tish" 1 } } */
Index: gcc/testsuite/gcc.target/aarch64/sync-op-acquire.x
===================================================================
--- gcc/testsuite/gcc.target/aarch64/sync-op-acquire.x	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/sync-op-acquire.x	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,7 @@
+int v;
+
+int
+sync_lock_test_and_set (int a)
+{
+  return __sync_lock_test_and_set (&v, a);
+}
Index: gcc/testsuite/gcc.target/aarch64/fnmul-2.c
===================================================================
--- gcc/testsuite/gcc.target/aarch64/fnmul-2.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/fnmul-2.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,18 @@
+/* { dg-do compile } */
+/* { dg-options "-O2 -frounding-math" } */
+
+double
+foo_d (double a, double b)
+{
+  /* { dg-final { scan-assembler "fneg\\td\[0-9\]+, d\[0-9\]+" } } */
+  /* { dg-final { scan-assembler "fmul\\td\[0-9\]+, d\[0-9\]+, d\[0-9\]+" } } */
+  return -a * b;
+}
+
+float
+foo_s (float a, float b)
+{
+  /* { dg-final { scan-assembler "fneg\\ts\[0-9\]+, s\[0-9\]+" } } */
+  /* { dg-final { scan-assembler "fmul\\ts\[0-9\]+, s\[0-9\]+, s\[0-9\]+" } } */
+  return -a * b;
+}
Index: gcc/testsuite/gcc.target/aarch64/sync-comp-swap.c
===================================================================
--- gcc/testsuite/gcc.target/aarch64/sync-comp-swap.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/sync-comp-swap.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,8 @@
+/* { dg-do compile } */
+/* { dg-options "-O2 -fno-ipa-icf" } */
+
+#include "sync-comp-swap.x"
+
+/* { dg-final { scan-assembler-times "ldxr\tw\[0-9\]+, \\\[x\[0-9\]+\\\]" 2 } } */
+/* { dg-final { scan-assembler-times "stlxr\tw\[0-9\]+, w\[0-9\]+, \\\[x\[0-9\]+\\\]" 2 } } */
+/* { dg-final { scan-assembler-times "dmb\tish" 2 } } */
Index: gcc/testsuite/gcc.target/aarch64/sync-op-full.c
===================================================================
--- gcc/testsuite/gcc.target/aarch64/sync-op-full.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/sync-op-full.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,8 @@
+/* { dg-do compile } */
+/* { dg-options "-O2" } */
+
+#include "sync-op-full.x"
+
+/* { dg-final { scan-assembler-times "ldxr\tw\[0-9\]+, \\\[x\[0-9\]+\\\]" 12 } } */
+/* { dg-final { scan-assembler-times "stlxr\tw\[0-9\]+, w\[0-9\]+, \\\[x\[0-9\]+\\\]" 12 } } */
+/* { dg-final { scan-assembler-times "dmb\tish" 12 } } */
Index: gcc/testsuite/gcc.target/aarch64/sync-comp-swap.x
===================================================================
--- gcc/testsuite/gcc.target/aarch64/sync-comp-swap.x	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/sync-comp-swap.x	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,13 @@
+int v = 0;
+
+int
+sync_bool_compare_swap (int a, int b)
+{
+  return __sync_bool_compare_and_swap (&v, &a, &b);
+}
+
+int
+sync_val_compare_swap (int a, int b)
+{
+  return __sync_val_compare_and_swap (&v, &a, &b);
+}
Index: gcc/testsuite/gcc.target/aarch64/sync-op-full.x
===================================================================
--- gcc/testsuite/gcc.target/aarch64/sync-op-full.x	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/sync-op-full.x	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,73 @@
+int v = 0;
+
+int
+sync_fetch_and_add (int a)
+{
+  return __sync_fetch_and_add (&v, a);
+}
+
+int
+sync_fetch_and_sub (int a)
+{
+  return __sync_fetch_and_sub (&v, a);
+}
+
+int
+sync_fetch_and_and (int a)
+{
+  return __sync_fetch_and_and (&v, a);
+}
+
+int
+sync_fetch_and_nand (int a)
+{
+  return __sync_fetch_and_nand (&v, a);
+}
+
+int
+sync_fetch_and_xor (int a)
+{
+  return __sync_fetch_and_xor (&v, a);
+}
+
+int
+sync_fetch_and_or (int a)
+{
+  return __sync_fetch_and_or (&v, a);
+}
+
+int
+sync_add_and_fetch (int a)
+{
+  return __sync_add_and_fetch (&v, a);
+}
+
+int
+sync_sub_and_fetch (int a)
+{
+  return __sync_sub_and_fetch (&v, a);
+}
+
+int
+sync_and_and_fetch (int a)
+{
+  return __sync_and_and_fetch (&v, a);
+}
+
+int
+sync_nand_and_fetch (int a)
+{
+  return __sync_nand_and_fetch (&v, a);
+}
+
+int
+sync_xor_and_fetch (int a)
+{
+  return __sync_xor_and_fetch (&v, a);
+}
+
+int
+sync_or_and_fetch (int a)
+{
+  return __sync_or_and_fetch (&v, a);
+}
Index: gcc/testsuite/gcc.target/aarch64/fnmul-3.c
===================================================================
--- gcc/testsuite/gcc.target/aarch64/fnmul-3.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/fnmul-3.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,16 @@
+/* { dg-do compile } */
+/* { dg-options "-O2" } */
+
+double
+foo_d (double a, double b)
+{
+  /* { dg-final { scan-assembler "fnmul\\td\[0-9\]+, d\[0-9\]+, d\[0-9\]+" } } */
+  return -(a * b);
+}
+
+float
+foo_s (float a, float b)
+{
+  /* { dg-final { scan-assembler "fnmul\\ts\[0-9\]+, s\[0-9\]+, s\[0-9\]+" } } */
+  return -(a * b);
+}
Index: gcc/testsuite/gcc.target/aarch64/fnmul-4.c
===================================================================
--- gcc/testsuite/gcc.target/aarch64/fnmul-4.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/fnmul-4.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,16 @@
+/* { dg-do compile } */
+/* { dg-options "-O2 -frounding-math" } */
+
+double
+foo_d (double a, double b)
+{
+  /* { dg-final { scan-assembler "fnmul\\td\[0-9\]+, d\[0-9\]+, d\[0-9\]+" } } */
+  return -(a * b);
+}
+
+float
+foo_s (float a, float b)
+{
+  /* { dg-final { scan-assembler "fnmul\\ts\[0-9\]+, s\[0-9\]+, s\[0-9\]+" } } */
+  return -(a * b);
+}
Index: gcc/testsuite/gcc.target/i386/adx-addcarryx64-1.c
===================================================================
--- gcc/testsuite/gcc.target/i386/adx-addcarryx64-1.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.target/i386/adx-addcarryx64-1.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,6 +1,6 @@
 /* { dg-do compile { target { ! ia32 } } } */
 /* { dg-options "-madx -O2" } */
-/* { dg-final { scan-assembler-times "adcx" 2 } } */
+/* { dg-final { scan-assembler-times "adc\[xq\]" 2 } } */
 /* { dg-final { scan-assembler-times "sbbq" 1 } } */
 
 #include <x86intrin.h>
Index: gcc/testsuite/gcc.target/i386/pr66648.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr66648.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr66648.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,33 @@
+/* { dg-do run } */
+/* { dg-options "-O2 -mstringop-strategy=unrolled_loop -mtune=nocona" } */
+
+#define PATTERN 0xdeadbeef
+#define SIZE    32
+
+struct S { int i; char str[SIZE]; int j; };
+
+void __attribute__((noclone, noinline))
+my_memcpy (char *, const char *, unsigned int);
+
+void
+my_memcpy (char *dst, const char *src, unsigned int len)
+{
+  if (len < 8)
+    __builtin_abort ();
+
+  __builtin_memcpy (dst, src, len);
+}
+
+int
+main (void)
+{
+  const char str[SIZE]= "1234567890123456789012345678901";
+  struct S *s = __builtin_malloc (sizeof (struct S));
+
+  s->j = PATTERN;
+  my_memcpy (s->str, str, SIZE);
+  if (s->j != PATTERN)
+    __builtin_abort ();
+
+  return 0;
+}
Index: gcc/testsuite/gcc.target/i386/pr66691.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr66691.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr66691.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,64 @@
+/* PR debug/66691 */
+/* { dg-do compile } */
+/* { dg-require-effective-target ia32 } */
+/* { dg-options "-O3 -g -mtune=generic -march=i686" } */
+
+unsigned int a;
+int b[2], c, d, e, f, g, h, i, k[8], l, m, s, t, w;
+static int j;
+
+void
+fn1 (long long p)
+{
+  int t = p;
+  c = c ^ b[c ^ (t & 1)];
+}
+
+static void
+fn2 (long long p)
+{
+  c = c ^ b[1 ^ (d & 1)];
+  fn1 (p >> 1 & 1);
+  fn1 (p >> 2);
+}
+
+static void
+fn3 ()
+{
+  unsigned char p;
+  f = g = 0;
+  for (h = 0; h < 6; h++)
+    {
+      for (s = 0; s < 7; s++)
+	if (k[s+1])
+	  g = 0;
+	else
+	  for (j = 0; j < 2; j++)
+	    ;
+      t = j > 2 ? 0 : 1 >> j;
+    }
+  if (l)
+    {
+      short q[2];
+      q[0] = q[1] = 0;
+      if (m)
+	for (i = 0; i < 2; i++)
+	  {
+	    unsigned char r = q[i];
+	    p = f ? r % f : r;
+	    e = ((p > 0) <= (q[i] ^ 1)) + a;
+	    if (k[1])
+	      for (e = 0; e != 18; ++e)
+		k[0] = 0;
+	  }
+    }
+}
+
+int
+main ()
+{
+  fn3 ();
+  fn2 (w);
+  fn2 (j);
+  return 0;
+}
Index: gcc/testsuite/gcc.target/i386/pr66838.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr66838.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr66838.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,36 @@
+/* { dg-do run { target lp64 } } */
+/* { dg-options "-O2" } */
+
+void abort (void);
+
+char global;
+
+__attribute__((sysv_abi, noinline, noclone))
+void sysv_abi_func(char const *desc, void *local)
+{
+  register int esi asm ("esi");
+  register int edi asm ("edi");
+  
+  if (local != &global)
+    abort ();
+
+  /* Clobber some of the extra SYSV ABI registers.  */
+  asm volatile ("movl\t%2, %0\n\tmovl\t%2, %1"
+		: "=r" (esi), "=r" (edi)
+		: "i" (0xdeadbeef));
+}
+
+__attribute__((ms_abi, noinline, noclone))
+void ms_abi_func ()
+{
+  sysv_abi_func ("1st call", &global);
+  sysv_abi_func ("2nd call", &global);
+  sysv_abi_func ("3rd call", &global);
+}
+
+int
+main(void)
+{
+  ms_abi_func();
+  return 0;
+}
Index: gcc/testsuite/gcc.target/i386/pr67317-1.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr67317-1.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr67317-1.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,18 @@
+/* PR target/67317 */
+/* { dg-do compile } */
+/* { dg-options "-O2" } */
+
+typedef unsigned int u32;
+
+u32 testcarry_u32 (u32 a, u32 b, u32 c, u32 d)
+{
+  u32 result0, result1;
+
+  __builtin_ia32_addcarryx_u32
+    (__builtin_ia32_addcarryx_u32 (0, a, c, &result0), b, d, &result1);
+
+  return result0 ^ result1;
+}
+
+/* { dg-final { scan-assembler-not "addb" } } */
+/* { dg-final { scan-assembler-not "setn?c" } } */
Index: gcc/testsuite/gcc.target/i386/pr67317-2.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr67317-2.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr67317-2.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,18 @@
+/* PR target/67317 */
+/* { dg-do compile { target { ! ia32 } } } */
+/* { dg-options "-O2" } */
+
+typedef unsigned long long u64;
+
+u64 testcarry_u64 (u64 a, u64 b, u64 c, u64 d)
+{
+  u64 result0, result1;
+
+  __builtin_ia32_addcarryx_u64
+    (__builtin_ia32_addcarryx_u64 (0, a, c, &result0), b, d, &result1);
+
+  return result0 ^ result1;
+}
+
+/* { dg-final { scan-assembler-not "addb" } } */
+/* { dg-final { scan-assembler-not "setn?c" } } */
Index: gcc/testsuite/gcc.target/i386/pr67317-3.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr67317-3.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr67317-3.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,18 @@
+/* PR target/67317 */
+/* { dg-do compile } */
+/* { dg-options "-O2" } */
+
+typedef unsigned int u32;
+
+u32 testcarry_u32 (u32 a, u32 b, u32 c, u32 d)
+{
+  u32 result0, result1;
+
+  __builtin_ia32_sbb_u32
+    (__builtin_ia32_sbb_u32 (0, a, c, &result0), b, d, &result1);
+
+  return result0 ^ result1;
+}
+
+/* { dg-final { scan-assembler-not "addb" } } */
+/* { dg-final { scan-assembler-not "setn?c" } } */
Index: gcc/testsuite/gcc.target/i386/readeflags-1.c
===================================================================
--- gcc/testsuite/gcc.target/i386/readeflags-1.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.target/i386/readeflags-1.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -9,10 +9,11 @@
 #define EFLAGS_TYPE unsigned int
 #endif
 
-static EFLAGS_TYPE
+__attribute__((noinline, noclone))
+EFLAGS_TYPE
 readeflags_test (unsigned int a, unsigned int b)
 {
-  unsigned x = (a == b);
+  volatile char x = (a == b);
   return __readeflags ();
 }
 
Index: gcc/testsuite/gcc.target/i386/pr66891.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr66891.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr66891.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,16 @@
+/* { dg-do compile { target ia32 } } */
+/* { dg-options "-O2" } */
+
+__attribute__((__stdcall__)) void fn1();
+
+int a;
+
+static void fn2() {
+  for (;;)
+    ;
+}
+
+void fn3() {
+  fn1(0);
+  fn2(a == 0);
+}
Index: gcc/testsuite/gcc.target/i386/pr66703.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr66703.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr66703.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,4 @@
+/* { dg-do run { target { ia32 } } } */
+/* { dg-options "-O0 -mtune=pentium" } */
+
+#include "readeflags-1.c"
Index: gcc/testsuite/gcc.target/i386/pr67317-4.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr67317-4.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr67317-4.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,18 @@
+/* PR target/67317 */
+/* { dg-do compile { target { ! ia32 } } } */
+/* { dg-options "-O2" } */
+
+typedef unsigned long long u64;
+
+u64 testcarry_u64 (u64 a, u64 b, u64 c, u64 d)
+{
+  u64 result0, result1;
+
+  __builtin_ia32_sbb_u64
+    (__builtin_ia32_sbb_u64 (0, a, c, &result0), b, d, &result1);
+
+  return result0 ^ result1;
+}
+
+/* { dg-final { scan-assembler-not "addb" } } */
+/* { dg-final { scan-assembler-not "setn?c" } } */
Index: gcc/testsuite/gcc.target/i386/adx-addcarryx32-1.c
===================================================================
--- gcc/testsuite/gcc.target/i386/adx-addcarryx32-1.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.target/i386/adx-addcarryx32-1.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,6 +1,6 @@
 /* { dg-do compile } */
 /* { dg-options "-madx -O2" } */
-/* { dg-final { scan-assembler-times "adcx" 2 } } */
+/* { dg-final { scan-assembler-times "adc\[xl\]" 2 } } */
 /* { dg-final { scan-assembler-times "sbbl" 1 } } */
 
 #include <x86intrin.h>
Index: gcc/testsuite/gcc.target/i386/pr66922.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr66922.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr66922.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,23 @@
+/* { dg-do run } */
+/* { dg-options "-O1 -msse2" } */
+/* { dg-require-effective-target sse2 } */
+
+#include "sse2-check.h"
+
+struct S 
+{
+  int:31;
+  int:2;
+  int f0:16;
+  int f1;
+  int f2;
+};
+
+static void 
+sse2_test (void)
+{
+  struct S a = { 1, 0, 0 };
+
+  if (a.f0 != 1)
+    __builtin_abort(); 
+}
Index: gcc/testsuite/gcc.target/i386/pr66814.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr66814.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr66814.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,4 @@
+/* { dg-do compile { target { ia32 } } } */
+/* { dg-options "-march=i586 -mavx512f -O2" } */
+
+#include "avx512f-klogic-2.c"
Index: gcc/testsuite/gcc.target/i386/mpx/pr66566.c
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/pr66566.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/mpx/pr66566.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,12 @@
+/* { dg-do compile } */
+/* { dg-options "-O2 -fcheck-pointer-bounds -mmpx" } */
+
+union jsval_layout
+{
+  void *asPtr;
+};
+union jsval_layout a;
+union jsval_layout b;
+union jsval_layout __inline__ fn1() { return b; }
+
+void fn2() { a = fn1(); }
Index: gcc/testsuite/gcc.target/i386/mpx/pr66567.c
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/pr66567.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/mpx/pr66567.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,16 @@
+/* { dg-do compile } */
+/* { dg-options "-fcheck-pointer-bounds -mmpx" } */
+
+void  (*b) ();
+
+void fn1 (const int *p1)
+{
+  static void *a = &&conv_1234_123C;
+ conv_1234_123C:
+  ;
+}
+
+void fn2 ()
+{
+  b = fn1;
+}
Index: gcc/testsuite/gcc.target/i386/mpx/pr66134.c
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/pr66134.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/mpx/pr66134.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,17 @@
+/* { dg-do compile } */
+/* { dg-options "-O2 -fcheck-pointer-bounds -mmpx -fno-tree-ccp" } */
+
+extern int vfork (void) __attribute__ ((__nothrow__ , __leaf__));
+void test1 (void);
+void test2 (void);
+void test3 (int *);
+
+void test (int *p)
+{
+ test1 ();
+ p++;
+ test2 ();
+ p++;
+ vfork ();
+ test3 (p);
+}
Index: gcc/testsuite/gcc.target/i386/mpx/pr66568.c
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/pr66568.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/mpx/pr66568.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,11 @@
+/* { dg-do compile } */
+/* { dg-require-effective-target fpic } */
+/* { dg-options "-O2 -fcheck-pointer-bounds -mmpx -O2 -fPIC" } */
+
+extern void exit (int);
+int a, b, c;
+void *set_test () {
+  if (b)
+    a ? exit (0) : exit (1);
+  b = c;
+}
Index: gcc/testsuite/gcc.target/i386/mpx/pr66569.c
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/pr66569.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/mpx/pr66569.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,14 @@
+/* { dg-do compile } */
+/* { dg-options "-fcheck-pointer-bounds -mmpx" } */
+
+struct s1 {
+  int *p;
+  int i;
+};
+
+struct s2 {
+  struct s1 s;
+  int i;
+};
+
+int test (struct s2 s, ...) { }
Index: gcc/testsuite/gcc.target/i386/mpx/pr66048.cc
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/pr66048.cc	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/mpx/pr66048.cc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,16 @@
+/* { dg-do compile } */
+/* { dg-options "-O2 -fcheck-pointer-bounds -mmpx -march=corei7-avx" } */
+
+struct c1
+{
+  c1 (const c1 &other) : p (other.p) { };
+  int *p;
+};
+
+struct c2 : public c1 { };
+
+c1
+test (c2 a)
+{
+  return a;
+}
Index: gcc/testsuite/gcc.target/i386/mpx/pr66581.c
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/pr66581.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/mpx/pr66581.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,18 @@
+/* { dg-do compile } */
+/* { dg-options "-fcheck-pointer-bounds -mmpx" } */
+
+void *a;
+int b;
+
+void
+fn1 (void)
+{
+  void *c = &&l_nop;
+l_nop:
+    for (; b;)
+    ;
+  int *d = c;
+  c = fn1;
+  *d = 1;
+  goto *a;
+}
Index: gcc/testsuite/gcc.target/s390/zvector/vec-load_bndry-1.c
===================================================================
--- gcc/testsuite/gcc.target/s390/zvector/vec-load_bndry-1.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/s390/zvector/vec-load_bndry-1.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,80 @@
+/* { dg-do compile { target { s390*-*-* } } } */
+/* { dg-options "-O0 -mzarch -march=z13 -mzvector" } */
+
+#include <vecintrin.h>
+
+signed char
+foo64 (signed char *p)
+{
+  return vec_load_bndry (p, 64)[0];
+  /* { dg-final { scan-assembler-times "\tvlbb\t%v..?,0\\(%r..?\\),0" 1 } } */
+}
+
+signed char
+foo128 (signed char *p)
+{
+  return
+    vec_load_bndry (p, 128)[0]
+    + vec_load_bndry (p + 16, 128)[0];
+  /* { dg-final { scan-assembler-times "\tvlbb\t%v..?,0\\(%r..?\\),1" 2 } } */
+}
+
+signed char
+foo256 (signed char *p)
+{
+  return
+    vec_load_bndry (p, 256)[0]
+    + vec_load_bndry (p + 16, 256)[0]
+    + vec_load_bndry (p + 32, 256)[0];
+  /* { dg-final { scan-assembler-times "\tvlbb\t%v..?,0\\(%r..?\\),2" 3 } } */
+}
+
+signed char
+foo512 (signed char *p)
+{
+  return
+    vec_load_bndry (p, 512)[0]
+    + vec_load_bndry (p + 16, 512)[0]
+    + vec_load_bndry (p + 32, 512)[0]
+    + vec_load_bndry (p + 48, 512)[0];
+  /* { dg-final { scan-assembler-times "\tvlbb\t%v..?,0\\(%r..?\\),3" 4 } } */
+}
+
+signed char
+foo1024 (signed char *p)
+{
+  return
+    vec_load_bndry (p, 1024)[0]
+    + vec_load_bndry (p + 16, 1024)[0]
+    + vec_load_bndry (p + 32, 1024)[0]
+    + vec_load_bndry (p + 48, 1024)[0]
+    + vec_load_bndry (p + 64, 1024)[0];
+  /* { dg-final { scan-assembler-times "\tvlbb\t%v..?,0\\(%r..?\\),4" 5 } } */
+}
+
+signed char
+foo2048 (signed char *p)
+{
+  return
+    vec_load_bndry (p, 2048)[0]
+    + vec_load_bndry (p + 16, 2048)[0]
+    + vec_load_bndry (p + 32, 2048)[0]
+    + vec_load_bndry (p + 48, 2048)[0]
+    + vec_load_bndry (p + 64, 2048)[0]
+    + vec_load_bndry (p + 80, 2048)[0];
+  /* { dg-final { scan-assembler-times "\tvlbb\t%v..?,0\\(%r..?\\),5" 6 } } */
+}
+
+signed char
+foo4096 (signed char *p)
+{
+  return
+    vec_load_bndry (p, 4096)[0]
+    + vec_load_bndry (p + 16, 4096)[0]
+    + vec_load_bndry (p + 32, 4096)[0]
+    + vec_load_bndry (p + 48, 4096)[0]
+    + vec_load_bndry (p + 64, 4096)[0]
+    + vec_load_bndry (p + 80, 4096)[0]
+    + vec_load_bndry (p + 96, 4096)[0];
+  /* { dg-final { scan-assembler-times "\tvlbb\t%v..?,0\\(%r..?\\),6" 7 } } */
+}
Index: gcc/testsuite/gfortran.dg/pr67526.f90
===================================================================
--- gcc/testsuite/gfortran.dg/pr67526.f90	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/pr67526.f90	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,9 @@
+! { dg-do compile }
+! Original code from gerhard dot steinmetz dot fortran at t-online dot de
+! PR fortran/67526
+program p
+   character :: c1 = 'abc'(:     ! { dg-error "error in SUBSTRING" }
+   character :: c2 = 'abc'(3:    ! { dg-error "error in SUBSTRING" }
+   character :: c3 = 'abc'(:1    ! { dg-error "error in SUBSTRING" }
+   character :: c4 = 'abc'(2:2   ! { dg-error "error in SUBSTRING" }
+end
Index: gcc/testsuite/gfortran.dg/pr66864.f90
===================================================================
--- gcc/testsuite/gfortran.dg/pr66864.f90	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/pr66864.f90	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,16 @@
+! { dg-do run }
+! PR fortran/66864
+!
+program t
+   implicit none
+   real(8) x
+   x = 2.0d0**26.5d0
+   if (floor(x) /= 94906265) call abort
+   if (floor(2.0d0**26.5d0)/= 94906265) call abort
+   x = 777666555.6d0
+   if (floor(x) /= 777666555) call abort
+   if (floor(777666555.6d0) /= 777666555) call abort
+   x = 2000111222.6d0
+   if (floor(x) /= 2000111222) call abort
+   if (floor(2000111222.6d0) /= 2000111222) call abort
+end program t
Index: gcc/testsuite/gfortran.dg/pr66545_1.f90
===================================================================
--- gcc/testsuite/gfortran.dg/pr66545_1.f90	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/pr66545_1.f90	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,17 @@
+! { dg-do compile }
+! { dg-options "-Wall" }
+! PR fortran/66545
+!
+subroutine p
+   complex, parameter :: c1 = (c1) ! { dg-error "before its definition" }
+   complex, parameter :: c2 = c2   ! { dg-error "before its definition" }
+   complex :: c3 = (c3)            ! { dg-error "has not been declared or is a variable" }
+   complex :: c4 = c4              ! { dg-error "has not been declared or is a variable" }
+end subroutine p
+
+subroutine q
+   real, parameter :: r1 = (r1)  ! { dg-error "before its definition" }
+   real, parameter :: r2 = r2    ! { dg-error "before its definition" }
+   real :: r3 = (r3)             ! { dg-error "has not been declared or is a variable" }
+   real :: r4 = r4               ! { dg-error "has not been declared or is a variable" }
+end subroutine q
Index: gcc/testsuite/gfortran.dg/iomsg_2.f90
===================================================================
--- gcc/testsuite/gfortran.dg/iomsg_2.f90	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/iomsg_2.f90	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,44 @@
+! { dg-do compile }
+subroutine foo1
+   implicit none
+   integer i
+   open(1, iomsg=666)      ! { dg-error "IOMSG must be" }
+   open(1, iomsg='sgk')    ! { dg-error "IOMSG must be" }
+   open(1, iomsg=i)        ! { dg-error "IOMSG must be" }
+   close(1, iomsg=666)     ! { dg-error "IOMSG must be" }
+   close(1, iomsg='sgk')   ! { dg-error "IOMSG must be" }
+   close(1, iomsg=i)       ! { dg-error "IOMSG must be" }
+end subroutine foo1
+
+subroutine foo
+   implicit none
+   integer i
+   real :: x = 1
+   write(1, *, iomsg='sgk') x   ! { dg-error "IOMSG must be" }
+   write(1, *, iomsg=i)     x   ! { dg-error "IOMSG must be" }
+   read(1,  *, iomsg='sgk') x   ! { dg-error "IOMSG must be" }
+   read(1,  *, iomsg=i)     x   ! { dg-error "IOMSG must be" }
+   flush(1,    iomsg='sgk')     ! { dg-error "IOMSG must be" }
+   flush(1,    iomsg=i)         ! { dg-error "IOMSG must be" }
+   rewind(1,   iomsg='sgk')     ! { dg-error "IOMSG must be" }
+   rewind(1,   iomsg=i)         ! { dg-error "IOMSG must be" }
+   backspace(1,iomsg='sgk')     ! { dg-error "IOMSG must be" }
+   backspace(1,iomsg=i)         ! { dg-error "IOMSG must be" }
+   wait(1,     iomsg='sgk')     ! { dg-error "IOMSG must be" }
+   wait(1,     iomsg=i)         ! { dg-error "IOMSG must be" }
+end subroutine foo
+
+subroutine bar
+   implicit none
+   integer i
+   real :: x = 1
+   character(len=20) s(2)
+   open(1, iomsg=s)         ! { dg-error "must be scalar" }
+   close(1, iomsg=s)        ! { dg-error "must be scalar" }
+   write(1, *, iomsg=s) x   ! { dg-error "must be scalar" }
+   read(1,  *, iomsg=s) x   ! { dg-error "must be scalar" }
+   flush(1,    iomsg=s)     ! { dg-error "must be scalar" }
+   rewind(1,   iomsg=s)     ! { dg-error "must be scalar" }
+   backspace(1,iomsg=s)     ! { dg-error "must be scalar" }
+   wait(1,     iomsg=s)     ! { dg-error "must be scalar" }
+end subroutine bar
Index: gcc/testsuite/gfortran.dg/co_reduce_1.f90
===================================================================
--- gcc/testsuite/gfortran.dg/co_reduce_1.f90	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/co_reduce_1.f90	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,33 @@
+! { dg-do compile }
+! { dg-additional-options "-fdump-tree-original -fcoarray=lib" }
+!
+! Check that we don't take twice the address of procedure simple_reduction
+! in the generated code.
+!
+! Contributed by Alessandro Fanfarillo <fanfarillo.gcc@gmail.com>
+
+program simple_reduce
+  implicit none
+
+  integer :: me
+
+  me = this_image()
+
+  sync all
+
+  call co_reduce(me,simple_reduction)
+
+  write(*,*) this_image(),me
+
+contains
+  
+  pure function simple_reduction(a,b)
+    integer,intent(in) :: a,b
+    integer :: simple_reduction
+
+    simple_reduction = a * b
+  end function simple_reduction
+
+end program simple_reduce
+
+! { dg-final { scan-tree-dump "_gfortran_caf_co_reduce \\(&desc\\.\\d+,\\s*simple_reduction," "original" } }
Index: gcc/testsuite/gfortran.dg/generic_31.f90
===================================================================
--- gcc/testsuite/gfortran.dg/generic_31.f90	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/generic_31.f90	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,35 @@
+! { dg-do run }
+!
+! PR fortran/66929
+! Check that the specific FIRST symbol is used for the call to FOO,
+! so that the J argument is not assumed to be present
+
+module m
+  interface foo
+    module procedure first
+  end interface foo
+contains
+  elemental function bar(j) result(r)
+    integer, intent(in), optional :: j
+    integer :: r, s(2)
+    ! We used to have NULL dereference here, in case of a missing J argument
+    s = foo(j, [3, 7])
+    r = sum(s)
+  end function bar
+  elemental function first(i, j) result(r)
+    integer, intent(in), optional :: i
+    integer, intent(in) :: j
+    integer :: r
+    if (present(i)) then
+      r = i
+    else
+      r = -5
+    end if
+  end function first
+end module m
+program p
+  use m
+  integer :: i
+  i = bar()
+  if (i /= -10) call abort
+end program p
Index: gcc/testsuite/gfortran.dg/pr56520.f90
===================================================================
--- gcc/testsuite/gfortran.dg/pr56520.f90	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/pr56520.f90	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,13 @@
+! { dg-do compile }
+! PR fortran/56520
+!
+program misleading
+    implicit none
+    real a, c
+    a = 1.0
+    c = exp(+a) )    ! { dg-error "Unclassifiable statement" }
+    c = exp(-a) )    ! { dg-error "Unclassifiable statement" }
+    c = exp((a)) )   ! { dg-error "Unclassifiable statement" }
+    c = exp(a) )     ! { dg-error "Unclassifiable statement" }
+    c = exp(a)
+end program misleading
Index: gcc/testsuite/gfortran.dg/coarray_collectives_16.f90
===================================================================
--- gcc/testsuite/gfortran.dg/coarray_collectives_16.f90	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gfortran.dg/coarray_collectives_16.f90	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -33,7 +33,7 @@
   end function hc
 end program test
 
-! { dg-final { scan-tree-dump-times "_gfortran_caf_co_reduce \\(&desc.., &fr, 4, _gfortran_caf_num_images \\(0, -1\\), &stat1, errmesg1, 0, 6\\);" 1 "original" } }
-! { dg-final { scan-tree-dump-times "_gfortran_caf_co_reduce \\(&val2, &gz, 0, 4, &stat2, errmesg2, 0, 7\\);" 1 "original" } }
-! { dg-final { scan-tree-dump-times "_gfortran_caf_co_reduce \\(&desc.., &hc, 1, res, &stat3, errmesg3, 99, 8\\);" 1 "original" } }
+! { dg-final { scan-tree-dump-times "_gfortran_caf_co_reduce \\(&desc.., fr, 4, _gfortran_caf_num_images \\(0, -1\\), &stat1, errmesg1, 0, 6\\);" 1 "original" } }
+! { dg-final { scan-tree-dump-times "_gfortran_caf_co_reduce \\(&val2, gz, 0, 4, &stat2, errmesg2, 0, 7\\);" 1 "original" } }
+! { dg-final { scan-tree-dump-times "_gfortran_caf_co_reduce \\(&desc.., hc, 1, res, &stat3, errmesg3, 99, 8\\);" 1 "original" } }
 ! { dg-final { cleanup-tree-dump "original" } }
Index: gcc/testsuite/gfortran.dg/class_allocate_20.f90
===================================================================
--- gcc/testsuite/gfortran.dg/class_allocate_20.f90	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/class_allocate_20.f90	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,32 @@
+! { dg-do run }
+!
+! PR fortran/64921
+! Test that the finalization wrapper procedure get the always_explicit
+! attribute so that the array is not passed without descriptor from 
+! T3's finalization wrapper procedure to T2's one.
+!
+! Contributed by Mat Cross  <mathewc@nag.co.uk>
+
+Program test
+  Implicit None
+  Type :: t1
+    Integer, Allocatable :: i
+  End Type
+  Type :: t2
+    Integer, Allocatable :: i
+  End Type
+  Type, Extends (t1) :: t3
+    Type (t2) :: j
+  End Type
+  Type, Extends (t3) :: t4
+    Integer, Allocatable :: k
+  End Type
+  Call s
+  Print *, 'ok'
+Contains
+  Subroutine s
+    Class (t1), Allocatable :: x
+    Allocate (t4 :: x)
+  End Subroutine
+End Program
+! { dg-output "ok" }
Index: gcc/testsuite/gfortran.dg/pr66545_2.f90
===================================================================
--- gcc/testsuite/gfortran.dg/pr66545_2.f90	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/pr66545_2.f90	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,23 @@
+! { dg-do compile }
+! { dg-options "-Wuninitialized" }
+! PR fortran/66545
+!
+program foo
+   implicit none
+   call p1
+   call q1
+end program foo
+
+subroutine p1
+   complex :: c5
+   complex :: c6
+   c5 = (c5)      ! { dg-warning "used uninitialized in this" }
+   c6 = c6        ! { dg-warning "used uninitialized in this" }
+end subroutine p1
+
+subroutine q1
+   real :: r5
+   real :: r6
+   r5 = (r5)   ! { dg-warning "used uninitialized in this" }
+   r6 = r6     ! { dg-warning "used uninitialized in this" }
+end subroutine q1
Index: gcc/testsuite/gfortran.dg/pr66725.f90
===================================================================
--- gcc/testsuite/gfortran.dg/pr66725.f90	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/pr66725.f90	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,31 @@
+! { dg-do compile }
+! PR fortran/66725
+!
+program foo
+
+   open(unit=1,access = 999)        ! { dg-error "ACCESS requires" }
+   open(unit=1,action = 999)        ! { dg-error "ACTION requires" }
+   open(unit=1,asynchronous = 999)  ! { dg-error "ASYNCHRONOUS requires" }
+   open(unit=1,blank = 999)         ! { dg-error "BLANK requires" }
+   open(unit=1,decimal = 999)       ! { dg-error "DECIMAL requires" }
+   open(unit=1,delim = 999)         ! { dg-error "DELIM requires" }
+   open(unit=1,encoding = 999)      ! { dg-error "ENCODING requires" }
+   open(unit=1,form = 999)          ! { dg-error "FORM requires" }
+   open(unit=1,pad = 999)           ! { dg-error "PAD requires" }
+   open(unit=1,position = 999)      ! { dg-error "POSITION requires" }
+   open(unit=1,round = 999)         ! { dg-error "ROUND requires" }
+   open(unit=1,sign = 999)          ! { dg-error "SIGN requires" }
+   open(unit=1,status = 999)        ! { dg-error "STATUS requires" }
+
+   close(unit=1, status=999)        ! { dg-error "STATUS requires" }
+
+   write (unit=1, asynchronous=257) ! { dg-error "ASYNCHRONOUS requires" }
+   write (unit=1, delim=257)        ! { dg-error "DELIM requires" }
+   write (unit=1, decimal=257)      ! { dg-error "DECIMAL requires" }
+   write (unit=1, round=257)        ! { dg-error "ROUND requires" }
+   write (unit=1, sign=257)         ! { dg-error "SIGN requires" }
+
+   write (unit=1, blank=257)        ! { dg-error "BLANK requires" }
+   write (unit=1, pad=257)          ! { dg-error "PAD requires" }
+
+end program foo
Index: gcc/testsuite/gfortran.dg/generic_30.f90
===================================================================
--- gcc/testsuite/gfortran.dg/generic_30.f90	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/generic_30.f90	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,41 @@
+! { dg-do compile }
+!
+! PR fortran/66929
+! Generic procedures as actual argument used to lead to
+! a NULL pointer dereference in gfc_get_proc_ifc_for_expr
+! because the generic symbol was used as procedure symbol,
+! instead of the specific one.
+
+module iso_varying_string
+  type, public :: varying_string
+     character(LEN=1), dimension(:), allocatable :: chars
+  end type varying_string
+  interface operator(/=)
+     module procedure op_ne_VS_CH
+  end interface operator (/=)
+  interface trim
+     module procedure trim_
+  end interface
+contains
+  elemental function op_ne_VS_CH (string_a, string_b) result (op_ne)
+    type(varying_string), intent(in) :: string_a
+    character(LEN=*), intent(in)     :: string_b
+    logical                          :: op_ne
+    op_ne = .true.
+  end function op_ne_VS_CH
+  elemental function trim_ (string) result (trim_string)
+    type(varying_string), intent(in) :: string
+    type(varying_string)             :: trim_string
+    trim_string = varying_string(["t", "r", "i", "m", "m", "e", "d"])
+  end function trim_
+end module iso_varying_string
+module syntax_rules
+  use iso_varying_string, string_t => varying_string
+contains
+  subroutine set_rule_type_and_key
+    type(string_t) :: key
+    if (trim (key) /= "") then
+      print *, "non-empty"
+    end if
+  end subroutine set_rule_type_and_key
+end module syntax_rules
Index: gcc/testsuite/gfortran.dg/structure_constructor_13.f03
===================================================================
--- gcc/testsuite/gfortran.dg/structure_constructor_13.f03	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/structure_constructor_13.f03	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,28 @@
+! { dg-do run }
+!
+! Contributed by Melven Roehrig-Zoellner  <Melven.Roehrig-Zoellner@DLR.de>
+! PR fortran/66035
+
+program test_pr66035
+  type t
+  end type t
+  type w
+    class(t), allocatable :: c
+  end type w
+
+  type(t) :: o
+
+  call test(o)
+contains
+  subroutine test(o)
+    class(t), intent(inout) :: o
+    type(w), dimension(:), allocatable :: list
+
+    select type (o)
+      class is (t)
+        list = [w(o)] ! This caused an ICE
+      class default
+        call abort()
+    end select
+  end subroutine
+end program
Index: gcc/testsuite/gcc.c-torture/compile/pr67506.c
===================================================================
--- gcc/testsuite/gcc.c-torture/compile/pr67506.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.c-torture/compile/pr67506.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,53 @@
+extern struct _IO_FILE *stderr;
+typedef long integer;
+typedef unsigned char byte;
+short nl;
+byte * tfmfilearray;
+integer charbase, ligkernbase;
+unsigned char charsonline;
+short c;
+unsigned short r;
+struct {
+  short cc;
+  integer rr;
+} labeltable[259];
+short sortptr;
+unsigned char activity[(32510) + 1];
+integer ai, acti;
+extern void _IO_putc (char, struct _IO_FILE *);
+
+void
+mainbody (void)
+{
+  register integer for_end;
+  if (c <= for_end)
+    do {
+      if (((tfmfilearray + 1001)[4 * (charbase + c) + 2] % 4) == 1)
+	{
+	  if ( r < nl )
+	    ;
+	  else
+	    {
+	      while (labeltable[sortptr ].rr > r)
+		labeltable[sortptr + 1 ]= labeltable[sortptr];
+	    }
+	}
+    } while (c++ < for_end);
+
+  if (ai <= for_end)
+    do {
+      if (activity[ai]== 2)
+	{
+	  r = (tfmfilearray + 1001)[4 * (ligkernbase + (ai))];
+	  if (r < 128)
+	    {
+	      r = r + ai + 1 ;
+	      if (r >= nl)
+		{
+		  if (charsonline > 0)
+		    _IO_putc ('\n', stderr);
+		}
+	    }
+	}
+    } while (ai++ < for_end);
+}
Index: gcc/testsuite/gcc.dg/gomp/pr67500.c
===================================================================
--- gcc/testsuite/gcc.dg/gomp/pr67500.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/gomp/pr67500.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,42 @@
+/* PR c/67500 */
+/* { dg-do compile } */
+/* { dg-options "-fopenmp" } */
+
+#pragma omp declare simd simdlen(d)	/* { dg-error "clause expression must be positive constant integer expression" } */
+void f1 (int);				/* { dg-error "undeclared here" "" { target *-*-* } 5 } */
+#pragma omp declare simd simdlen(0.5)	/* { dg-error "clause expression must be positive constant integer expression" } */
+void f2 (int);
+#pragma omp declare simd simdlen(-2)	/* { dg-error "clause expression must be positive constant integer expression" } */
+void f3 (int);
+#pragma omp declare simd simdlen(0)	/* { dg-error "clause expression must be positive constant integer expression" } */
+void f4 (int);
+
+void
+foo (int *p)
+{
+  int i;
+  #pragma omp simd safelen(d)		/* { dg-error "must be positive constant integer expression" } */
+  for (i = 0; i < 16; ++i)		/* { dg-error "undeclared" "" { target *-*-* } 18 } */
+    ;
+  #pragma omp simd safelen(0.5)		/* { dg-error "must be positive constant integer expression" } */
+  for (i = 0; i < 16; ++i)
+    ;
+  #pragma omp simd safelen(-2)		/* { dg-error "must be positive constant integer expression" } */
+  for (i = 0; i < 16; ++i)
+    ;
+  #pragma omp simd safelen(0)		/* { dg-error "must be positive constant integer expression" } */
+  for (i = 0; i < 16; ++i)
+    ;
+  #pragma omp simd aligned(p:d)		/* { dg-error "must be positive constant integer expression" } */
+  for (i = 0; i < 16; ++i)
+    ;
+  #pragma omp simd aligned(p:0.5)	/* { dg-error "must be positive constant integer expression" } */
+  for (i = 0; i < 16; ++i)
+    ;
+  #pragma omp simd aligned(p:-2)	/* { dg-error "must be positive constant integer expression" } */
+  for (i = 0; i < 16; ++i)
+    ;
+  #pragma omp simd aligned(p:0)		/* { dg-error "must be positive constant integer expression" } */
+  for (i = 0; i < 16; ++i)
+    ;
+}
Index: gcc/testsuite/gcc.dg/gomp/pr67495.c
===================================================================
--- gcc/testsuite/gcc.dg/gomp/pr67495.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/gomp/pr67495.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,38 @@
+/* PR c/67495 */
+/* { dg-do compile } */
+/* { dg-options "-fopenmp" } */
+
+int a, b, c;
+
+void
+foo (void)
+{
+#pragma omp atomic capture
+  a = (float)a + b;	/* { dg-error "invalid operator" } */
+#pragma omp atomic read
+  (float) a = b;	/* { dg-error "lvalue required" } */
+#pragma omp atomic write
+  (float) a = b;	/* { dg-error "lvalue required" } */
+#pragma omp atomic read
+  a = (float) b;	/* { dg-error "lvalue required" } */
+#pragma omp atomic capture
+  (float) a = b += c;	/* { dg-error "lvalue required" } */
+#pragma omp atomic capture
+  { a += b; (float) c = a; }	/* { dg-error "lvalue required" } */
+#pragma omp atomic capture
+  { a += b; c = (float) a; }	/* { dg-error "uses two different expressions for memory" } */
+#pragma omp atomic capture
+  a = (int)a + b;	/* { dg-error "invalid operator" } */
+#pragma omp atomic read
+  (int) a = b;		/* { dg-error "lvalue required" } */
+#pragma omp atomic write
+  (int) a = b;		/* { dg-error "lvalue required" } */
+#pragma omp atomic read
+  a = (int) b;		/* { dg-error "lvalue required" } */
+#pragma omp atomic capture
+  (int) a = b += c;	/* { dg-error "lvalue required" } */
+#pragma omp atomic capture
+  { a += b; (int) c = a; }	/* { dg-error "lvalue required" } */
+#pragma omp atomic capture
+  { a += b; c = (int) a; }	/* { dg-error "lvalue required" } */
+}
Index: gcc/testsuite/gcc.dg/pie-link.c
===================================================================
--- gcc/testsuite/gcc.dg/pie-link.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.dg/pie-link.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,5 +1,5 @@
 /* { dg-do link { target pie } } */
-/* { dg-options "-fpie" } */
+/* { dg-options "-fpie -pie" } */
 
 int main(void)
 {
Index: gcc/testsuite/gcc.dg/pr67512.c
===================================================================
--- gcc/testsuite/gcc.dg/pr67512.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/pr67512.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,15 @@
+/* PR middle-end/67512 */
+/* { dg-do compile }  */
+/* { dg-options "-O -Wuninitialized" } */
+
+extern int fn2 (void);
+extern int fn3 (int);
+void
+fn1 (void)
+{
+  int z, m;
+  if (1 & m) /* { dg-warning "is used uninitialized" } */
+    z = fn2 ();
+  z = 1 == m ? z : 2 == m;
+  fn3 (z);
+}
Index: gcc/testsuite/gcc.dg/graphite/interchange-15.c
===================================================================
--- gcc/testsuite/gcc.dg/graphite/interchange-15.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.dg/graphite/interchange-15.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -49,6 +49,6 @@
 }
 
 /* PRE destroys the perfect nest and we can't cope with that yet.  */
-/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" } } */
+/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" { xfail *-*-* } } } */
 /* { dg-final { cleanup-tree-dump "graphite" } } */
 
Index: gcc/testsuite/gcc.dg/graphite/uns-interchange-14.c
===================================================================
--- gcc/testsuite/gcc.dg/graphite/uns-interchange-14.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/graphite/uns-interchange-14.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,60 @@
+/* { dg-require-effective-target size32plus } */
+
+#define DEBUG 0
+#if DEBUG
+#include <stdio.h>
+#endif
+
+#define N 200
+
+unsigned int A[N][N], B[N][N], C[N][N];
+
+static void __attribute__((noinline))
+matmult (void)
+{
+  int i, j, k;
+
+  for (i = 0; i < N; i++)
+    for (j = 0; j < N; j++)
+      A[i][j] = 0;
+
+  /* Loops J and K should be interchanged.  */
+  for (i = 0; i < N; i++)
+    for (j = 0; j < N; j++)
+      for (k = 0; k < N; k++)
+	A[i][j] += B[i][k] * C[k][j];
+}
+
+extern void abort ();
+
+int
+main (void)
+{
+  int i, j;
+  unsigned res = 0;
+
+  for (i = 0; i < N; i++)
+    for (j = 0; j < N; j++)
+      {
+	B[i][j] = j;
+	C[i][j] = i;
+      }
+
+  matmult ();
+
+  for (i = 0; i < N; i++)
+    res += A[i][i];
+
+#if DEBUG
+  fprintf (stderr, "res = %d \n", res);
+#endif
+
+  if (res != 529340000)
+    abort ();
+
+  return 0;
+}
+
+/* PRE destroys the perfect nest and we can't cope with that yet.  */
+/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" } } */
+/* { dg-final { cleanup-tree-dump "graphite" } } */
Index: gcc/testsuite/gcc.dg/graphite/interchange-12.c
===================================================================
--- gcc/testsuite/gcc.dg/graphite/interchange-12.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.dg/graphite/interchange-12.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -53,5 +53,5 @@
   return 0;
 }
 
-/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" } } */
+/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" { xfail *-*-* } } } */
 /* { dg-final { cleanup-tree-dump "graphite" } } */
Index: gcc/testsuite/gcc.dg/graphite/uns-interchange-15.c
===================================================================
--- gcc/testsuite/gcc.dg/graphite/uns-interchange-15.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/graphite/uns-interchange-15.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,55 @@
+/* { dg-require-effective-target size32plus } */
+
+#define DEBUG 0
+#if DEBUG
+#include <stdio.h>
+#endif
+
+#define NMAX 2000
+
+static unsigned int x[NMAX], a[NMAX][NMAX];
+
+static unsigned int __attribute__((noinline))
+mvt (long N)
+{
+  int i,j;
+
+  /* These two loops should be interchanged.  */
+  for (i = 0; i < N; i++)
+    for (j = 0; j < N; j++)
+      x[i] += a[j][i];
+
+  return x[1];
+}
+
+extern void abort ();
+
+int
+main (void)
+{
+  int i, j;
+  unsigned int res;
+
+  for (i = 0; i < NMAX; i++)
+    for (j = 0; j < NMAX; j++)
+      a[i][j] = j;
+
+  for (i = 0; i < NMAX; i++)
+    x[i] = i;
+
+  res = mvt (NMAX);
+
+#if DEBUG
+  fprintf (stderr, "res = %d \n", res);
+#endif
+
+  if (res != 2001)
+    abort ();
+
+  return 0;
+}
+
+/* PRE destroys the perfect nest and we can't cope with that yet.  */
+/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" } } */
+/* { dg-final { cleanup-tree-dump "graphite" } } */
+
Index: gcc/testsuite/gcc.dg/graphite/graphite.exp
===================================================================
--- gcc/testsuite/gcc.dg/graphite/graphite.exp	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.dg/graphite/graphite.exp	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -41,8 +41,10 @@
 set scop_files        [lsort [glob -nocomplain $srcdir/$subdir/scop-*.c ] ]
 set id_files          [lsort [glob -nocomplain $srcdir/$subdir/id-*.c ] ]
 set run_id_files      [lsort [glob -nocomplain $srcdir/$subdir/run-id-*.c ] ]
-set interchange_files [lsort [glob -nocomplain $srcdir/$subdir/interchange-*.c ] ]
-set block_files       [lsort [glob -nocomplain $srcdir/$subdir/block-*.c ] ]
+set interchange_files [lsort [glob -nocomplain $srcdir/$subdir/interchange-*.c \
+			      $srcdir/$subdir/uns-interchange-*.c ] ]
+set block_files       [lsort [glob -nocomplain $srcdir/$subdir/block-*.c \
+			      $srcdir/$subdir/uns-block-*.c ] ]
 set vect_files        [lsort [glob -nocomplain $srcdir/$subdir/vect-*.c ] ]
 
 # Tests to be compiled.
Index: gcc/testsuite/gcc.dg/graphite/uns-interchange-mvt.c
===================================================================
--- gcc/testsuite/gcc.dg/graphite/uns-interchange-mvt.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/graphite/uns-interchange-mvt.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,65 @@
+/* { dg-require-effective-target size32plus } */
+
+#define DEBUG 0
+#if DEBUG
+#include <stdio.h>
+#endif
+
+#define NMAX 2000
+
+static unsigned int x1[NMAX], x2[NMAX], a[NMAX][NMAX], y1[NMAX], y2[NMAX];
+
+static unsigned int __attribute__((noinline))
+mvt (long N)
+{
+
+  int i,j;
+
+  for (i = 0; i < N; i++)
+    for (j = 0; j < N; j++)
+      x1[i] = x1[i] + a[i][j] * y1[j];
+
+  /* These two loops should be interchanged.  */
+  for (i = 0; i < N; i++)
+    for (j = 0; j < N; j++)
+      x2[i] = x2[i] + a[j][i] * y2[j];
+
+  return x1[0] + x2[0];
+}
+
+extern void abort ();
+
+int
+main (void)
+{
+  int i, j;
+  unsigned int res;
+
+  for (i = 0; i < NMAX; i++)
+    for (j = 0; j < NMAX; j++)
+      a[i][j] = i + j;
+
+  for (i = 0; i < NMAX; i++)
+    {
+      x1[i] = 0;
+      x2[i] = 2*i;
+      y1[i] = 100 - i;
+      y2[i] = i;
+    }
+
+  res = mvt (NMAX);
+
+#if DEBUG
+  fprintf (stderr, "res = %d \n", res);
+#endif
+
+  if (res != 199900000)
+    abort ();
+
+  return 0;
+}
+
+/* PRE destroys the perfect nest and we can't cope with that yet.  */
+/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" } } */
+/* { dg-final { cleanup-tree-dump "graphite" } } */
+
Index: gcc/testsuite/gcc.dg/graphite/uns-interchange-12.c
===================================================================
--- gcc/testsuite/gcc.dg/graphite/uns-interchange-12.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/graphite/uns-interchange-12.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,58 @@
+/* { dg-require-effective-target size32plus } */
+
+#define DEBUG 0
+#if DEBUG
+#include <stdio.h>
+#endif
+
+#define N 200
+
+unsigned int A[N][N], B[N][N], C[N][N];
+
+static unsigned int __attribute__((noinline))
+matmult (void)
+{
+  int i, j, k;
+
+  /* Loops J and K should be interchanged.  */
+  for (i = 0; i < N; i++)
+    for (j = 0; j < N; j++)
+      {
+	A[i][j] = 0;
+	for (k = 0; k < N; k++)
+	  A[i][j] += B[i][k] * C[k][j];
+      }
+
+  return A[0][0] + A[N-1][N-1];
+}
+
+extern void abort ();
+
+int
+main (void)
+{
+  int i, j;
+  unsigned int res;
+
+  for (i = 0; i < N; i++)
+    for (j = 0; j < N; j++)
+      {
+	A[i][j] = 0;
+	B[i][j] = i - j;
+	C[i][j] = i + j;
+      }
+
+  res = matmult ();
+
+#if DEBUG
+  fprintf (stderr, "res = %d \n", res);
+#endif
+
+  if (res != 2626800)
+    abort ();
+
+  return 0;
+}
+
+/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" } } */
+/* { dg-final { cleanup-tree-dump "graphite" } } */
Index: gcc/testsuite/gcc.dg/graphite/uns-block-1.c
===================================================================
--- gcc/testsuite/gcc.dg/graphite/uns-block-1.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/graphite/uns-block-1.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,49 @@
+/* { dg-require-effective-target size32plus } */
+
+#define DEBUG 0
+#if DEBUG
+#include <stdio.h>
+#endif
+
+#define MAX 100
+
+extern void abort ();
+
+int
+main (void)
+{
+  int i, j;
+  unsigned int sum = 0;
+  unsigned int A[MAX * MAX];
+  unsigned int B[MAX * MAX];
+
+  /* These loops should be loop blocked.  */
+  for (i = 0; i < MAX; i++)
+    for (j = 0; j < MAX; j++)
+      {
+	A[i*MAX + j] = j;
+	B[i*MAX + j] = j;
+      }
+
+  /* These loops should be loop blocked.  */
+  for (i = 0; i < MAX; i++)
+    for (j = 0; j < MAX; j++)
+      A[i*MAX + j] += B[j*MAX + i];
+
+  /* These loops should be loop blocked.  */
+  for (i = 0; i < MAX; i++)
+    for (j = 0; j < MAX; j++)
+      sum += A[i*MAX + j];
+
+#if DEBUG
+  fprintf (stderr, "sum = %d \n", sum);
+#endif
+
+  if (sum != 990000)
+    abort ();
+
+  return 0;
+}
+
+/* { dg-final { scan-tree-dump-times "will be loop blocked" 3 "graphite" } } */
+/* { dg-final { cleanup-tree-dump "graphite" } } */
Index: gcc/testsuite/gcc.dg/graphite/interchange-mvt.c
===================================================================
--- gcc/testsuite/gcc.dg/graphite/interchange-mvt.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.dg/graphite/interchange-mvt.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -59,6 +59,6 @@
 }
 
 /* PRE destroys the perfect nest and we can't cope with that yet.  */
-/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" } } */
+/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" { xfail *-*-* } } } */
 /* { dg-final { cleanup-tree-dump "graphite" } } */
 
Index: gcc/testsuite/gcc.dg/graphite/uns-interchange-9.c
===================================================================
--- gcc/testsuite/gcc.dg/graphite/uns-interchange-9.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/graphite/uns-interchange-9.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,49 @@
+/* { dg-require-effective-target size32plus } */
+
+#define DEBUG 0
+#if DEBUG
+#include <stdio.h>
+#endif
+
+#define N 111
+#define M 111
+
+static unsigned int __attribute__((noinline))
+foo (unsigned int *x)
+{
+  int i, j;
+  unsigned int sum = 0;
+
+  for (j = 0; j < M; ++j)
+    for (i = 0;  i < N; ++i)
+      sum += x[M * i + j];
+
+  return sum;
+}
+
+extern void abort ();
+
+int
+main (void)
+{
+  unsigned int A[N*M];
+  int i;
+  unsigned int res;
+
+  for (i = 0; i < N*M; i++)
+    A[i] = 2;
+
+  res = foo (A);
+
+#if DEBUG
+  fprintf (stderr, "res = %d \n", res);
+#endif
+
+  if (res != 24642)
+    abort ();
+
+  return 0;
+}
+
+/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" } } */
+/* { dg-final { cleanup-tree-dump "graphite" } } */
Index: gcc/testsuite/gcc.dg/graphite/interchange-14.c
===================================================================
--- gcc/testsuite/gcc.dg/graphite/interchange-14.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.dg/graphite/interchange-14.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -55,5 +55,5 @@
 }
 
 /* PRE destroys the perfect nest and we can't cope with that yet.  */
-/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" } } */
+/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" { xfail *-*-* } } } */
 /* { dg-final { cleanup-tree-dump "graphite" } } */
Index: gcc/testsuite/gcc.dg/graphite/interchange-9.c
===================================================================
--- gcc/testsuite/gcc.dg/graphite/interchange-9.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.dg/graphite/interchange-9.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -44,5 +44,5 @@
   return 0;
 }
 
-/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" } } */
+/* { dg-final { scan-tree-dump-times "will be interchanged" 1 "graphite" { xfail *-*-* } } } */
 /* { dg-final { cleanup-tree-dump "graphite" } } */
Index: gcc/testsuite/gcc.dg/graphite/block-1.c
===================================================================
--- gcc/testsuite/gcc.dg/graphite/block-1.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/gcc.dg/graphite/block-1.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -45,5 +45,5 @@
   return 0;
 }
 
-/* { dg-final { scan-tree-dump-times "will be loop blocked" 3 "graphite" } } */
+/* { dg-final { scan-tree-dump-times "will be loop blocked" 3 "graphite" { xfail *-*-* } } } */
 /* { dg-final { cleanup-tree-dump "graphite" } } */
Index: gcc/testsuite/gcc.dg/lto/chkp-wrap-asm-name_0.c
===================================================================
--- gcc/testsuite/gcc.dg/lto/chkp-wrap-asm-name_0.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/lto/chkp-wrap-asm-name_0.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,20 @@
+/* { dg-lto-do link } */
+/* { dg-require-effective-target mpx } */
+/* { dg-lto-options { { -O2 -flto -fcheck-pointer-bounds -mmpx } } } */
+
+typedef long unsigned int size_t;
+
+extern size_t strlen (const char *);
+extern __typeof (strlen) strlen __asm__ ("" "__hidden_strlen") __attribute__ ((visibility ("hidden")));
+
+size_t
+test1 (const char *p) { return strlen (p); }
+
+size_t
+test2 (const char *p) { return __builtin_strlen (p); }
+
+int
+main (int argc, const char **argv)
+{
+  return test1 (argv[0]) - test2 (argv[0]);
+}
Index: gcc/testsuite/gcc.dg/lto/chkp-removed-alias_0.c
===================================================================
--- gcc/testsuite/gcc.dg/lto/chkp-removed-alias_0.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/lto/chkp-removed-alias_0.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,28 @@
+/* { dg-lto-do link } */
+/* { dg-require-effective-target mpx } */
+/* { dg-lto-options { { -O2 -flto -flto-partition=max -fcheck-pointer-bounds -mmpx } } } */
+
+int test1 (const char *c)
+{
+  return c[0] * 2;
+}
+
+int test2 (const char *c)
+{
+  return c[1] * 3;
+}
+
+int test1_alias (const char *c) __attribute__ ((alias ("test1")));
+int test2_alias (const char *c) __attribute__ ((alias ("test2")));
+
+struct S
+{
+  int (*fnptr[2]) (const char *);
+} S;
+
+struct S s = {test1_alias, test2_alias};
+
+int main (int argc, const char **argv)
+{
+  return s.fnptr[argc] (argv[0]);
+}
Index: gcc/testsuite/gcc.dg/lto/pr67452_0.c
===================================================================
--- gcc/testsuite/gcc.dg/lto/pr67452_0.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/lto/pr67452_0.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,23 @@
+/* { dg-lto-do link } */
+/* { dg-lto-options { { -O2 -flto -fopenmp-simd } } } */
+
+float b[3][3];
+
+__attribute__((used, noinline)) void
+foo ()
+{
+  int v1, v2;
+#pragma omp simd collapse(2)
+  for (v1 = 0; v1 < 3; v1++)
+    for (v2 = 0; v2 < 3; v2++)
+      b[v1][v2] = 2.5;
+}
+
+int
+main ()
+{
+  asm volatile ("" : : "g" (b) : "memory");
+  foo ();
+  asm volatile ("" : : "g" (b) : "memory");
+  return 0;
+}
Index: gcc/testsuite/gcc.dg/torture/pr67005.c
===================================================================
--- gcc/testsuite/gcc.dg/torture/pr67005.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/torture/pr67005.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,15 @@
+/* { dg-do compile } */
+
+int a;
+void
+f (void)
+{
+  if (!a);
+  else
+  lbl:
+    a = a;
+
+  if (a)
+    a = 8;
+  goto lbl;
+}
Index: gcc/testsuite/gcc.dg/torture/pr67222.c
===================================================================
--- gcc/testsuite/gcc.dg/torture/pr67222.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/torture/pr67222.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,19 @@
+/* PR middle-end/67222 */
+/* { dg-do compile } */
+
+void
+foo (void **p)
+{
+  posix_memalign (); /* { dg-warning "implicit declaration" } */
+  posix_memalign (p);
+  posix_memalign (0);
+  posix_memalign (p, 1);
+  posix_memalign (p, "foo");
+  posix_memalign ("gnu", "gcc");
+  posix_memalign (1, p);
+  posix_memalign (1, 2);
+  posix_memalign (1, 2, 3);
+  posix_memalign (p, p, p);
+  posix_memalign (p, "qui", 3);
+  posix_memalign (p, 1, 2);
+}
Index: gcc/testsuite/gcc.dg/pr67028.c
===================================================================
--- gcc/testsuite/gcc.dg/pr67028.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/pr67028.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,21 @@
+/* { dg-do run } */
+/* { dg-options "-O3" } */
+
+short c = 0;
+
+int __attribute__ ((noinline)) f(void)
+{
+	int d = 5;
+	signed char e = (c != 1) * -2;
+	int a = (unsigned short)e > d;
+
+	return a;
+}
+
+int main(void)
+{
+	if (!f())
+		__builtin_abort();
+
+	return 0;
+}
Index: gcc/testsuite/ChangeLog
===================================================================
--- gcc/testsuite/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,494 @@
+2015-09-17  Marek Polacek  <polacek@redhat.com>
+
+	Backport from mainline:
+	2015-08-18  Marek Polacek  <polacek@redhat.com>
+
+	PR middle-end/67222
+	* gcc.dg/torture/pr67222.c: New test.
+
+2015-09-11  Rainer Orth  <ro@CeBiTec.Uni-Bielefeld.DE>
+
+	* gcc.dg/pie-link.c: Add -pie to dg-options.
+
+2015-09-11  Alex Velenko  <Alex.Velenko@arm.com>
+
+	Backport from mainline
+	* gcc.target/arm/pr63210.c (dg-skip-if): Skip armv4t.
+	(dg-additional-options): Add -march=armv5t if arm_arch_v5t_ok.
+
+2015-09-10  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/67526
+	* gfortran.dg/pr67526.f90: New test.
+
+2015-09-10  Oleg Endo  <olegendo@gcc.gnu.org>
+
+	Backport from mainline
+	PR target/67506
+	* gcc.c-torture/compile/pr67506.c: New test.
+
+2015-09-10  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/67523
+	* g++.dg/gomp/pr67523.C: New test.
+
+	PR c++/67522
+	* g++.dg/gomp/pr67522.C: New test.
+
+	PR middle-end/67521
+	* c-c++-common/gomp/pr67521.c: New test.
+
+	PR middle-end/67517
+	* c-c++-common/gomp/pr67517.c: New test.
+
+	PR c++/67514
+	* g++.dg/gomp/pr67514.C: New test.
+
+	PR c++/67511
+	* g++.dg/gomp/pr67511.C: New test.
+
+	PR c/67502
+	* c-c++-common/gomp/pr67502.c: New test.
+
+2015-09-09  Marek Polacek  <polacek@redhat.com>
+
+	Backport from mainline:
+	2015-09-09  Marek Polacek  <polacek@redhat.com>
+
+	PR middle-end/67512
+	* gcc.dg/pr67512.c: New test.
+
+2015-09-09  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/67504
+	* g++.dg/gomp/pr67504.C: New test.
+
+	PR c/67501
+	* c-c++-common/gomp/pr67501.c: New test.
+
+	PR c/67500
+	* gcc.dg/gomp/pr67500.c: New test.
+
+	PR c/67495
+	* gcc.dg/gomp/pr67495.c: New test.
+
+2015-09-08  Paolo Carlini  <paolo.carlini@oracle.com>
+
+	PR c++/67369
+	* g++.dg/cpp1y/lambda-generic-ice4.C: New.
+
+2015-09-04  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/67452
+	* gcc.dg/lto/pr67452_0.c: New test.
+
+2015-09-03  Richard Biener  <rguenther@suse.de>
+
+	PR ipa/66705
+	* g++.dg/lto/pr66705_0.C: New testcase.
+
+2015-09-02  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline:
+	2015-08-27  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/67317
+	* gcc.target/i386/pr67317-1.c: New test.
+	* gcc.target/i386/pr67317-2.c: Ditto.
+	* gcc.target/i386/pr67317-3.c: Ditto.
+	* gcc.target/i386/pr67317-4.c: Ditto.
+	* gcc.target/i386/adx-addcarryx32-1.c: Also scan for adcl.
+	* gcc.target/i386/adx-addcarryx32-2.c: Also scan for adcq.
+
+2015-08-31  Marek Polacek  <polacek@redhat.com>
+
+	Backport from mainline
+	2015-08-27  Marek Polacek  <polacek@redhat.com>
+
+	PR middle-end/67005
+	* gcc.dg/torture/pr67005.c: New test.
+
+2015-08-27  Pat Haugen  <pthaugen@us.ibm.com>
+
+	Backport from mainline:
+	2015-08-27  Pat Haugen  <pthaugen@us.ibm.com>
+
+	* gcc.target/powerpc/vec-shr.c: New.
+
+2015-08-25  Dominik Vogt  <vogt@linux.vnet.ibm.com>
+
+	Backport from mainline
+	2015-08-21  Dominik Vogt  <vogt@linux.vnet.ibm.com>
+
+    	* gcc.target/s390/zvector/vec-load_bndry-1.c: New test.
+
+2015-08-24  Michael Meissner  <meissner@linux.vnet.ibm.com>
+
+	Backport from mainline:
+	2015-08-24  Michael Meissner  <meissner@linux.vnet.ibm.com>
+
+	PR target/67211
+	* g++.dg/pr67211.C: New test.
+
+2015-08-18  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	Backport from mainline:
+	2015-08-08  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	PR rtl-optimization/67028
+	* gcc.dg/pr67028.c: New testcase.
+
+2015-08-16  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline:
+	2015-07-25  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/66648
+	* gcc.target/i386/pr66648.c: New test.
+
+2015-08-11  Marek Polacek  <polacek@redhat.com>
+
+	Backported from mainline
+	2015-08-03  Marek Polacek  <polacek@redhat.com>
+
+	PR sanitizer/66908
+	* c-c++-common/ubsan/pr66908.c: New test.
+
+2015-08-07  Mikael Morin  <mikael@gcc.gnu.org>
+
+	PR fortran/66929
+	* gfortran.dg/generic_30.f90: New.
+	* gfortran.dg/generic_31.f90: New.
+
+2015-08-06  David Malcolm  <dmalcolm@redhat.com>
+
+	Backport from trunk r226697:
+	2015-08-06  David Malcolm  <dmalcolm@redhat.com>
+
+	* jit.dg/test-benchmark.c (main): Record all elapsed times at each
+	optimization level, and print a summary at the end.
+
+2015-08-05  Mikael Morin  <mikael@gcc.gnu.org>
+
+	PR fortran/64921
+	* gfortran.dg/class_allocate_20.f90: New.
+
+2015-08-05  Matthew Wahab  <matthew.wahab@arm.com>
+
+	Backport from trunk:
+	2015-07-01  Matthew Wahab  <matthew.wahab@arm.com>
+
+	* gcc.target/arm/armv8-sync-comp-swap.c: Replace
+	'do-require-effective-target' with 'dg-require-effective-target'.
+	* gcc.target/arm/armv8-sync-op-full.c: Likewise.
+	* gcc.target/arm/armv8-sync-op-release.c: Likewise.
+	* gcc.target/arm/armv8-sync-op-acquire.c: Likewise.  Also, replace
+	'stlex' with 'strex' as the expected output.
+
+2015-08-05  Matthew Wahab  <matthew.wahab@arm.com>
+
+	Backport from trunk:
+	2015-06-29  Matthew Wahab  <matthew.wahab@arm.com>
+
+	PR target/65697
+	* gcc.target/arm/armv-sync-comp-swap.c: New.
+	* gcc.target/arm/armv-sync-op-acquire.c: New.
+	* gcc.target/arm/armv-sync-op-full.c: New.
+	* gcc.target/arm/armv-sync-op-release.c: New.
+
+2015-08-05  Matthew Wahab  <matthew.wahab@arm.com>
+
+	Backport from trunk
+	2015-06-01  Matthew Wahab  <matthew.wahab@arm.com>
+
+	PR target/65697
+	* gcc.target/aarch64/sync-comp-swap.c: New.
+	* gcc.target/aarch64/sync-comp-swap.x: New.
+	* gcc.target/aarch64/sync-op-acquire.c: New.
+	* gcc.target/aarch64/sync-op-acquire.x: New.
+	* gcc.target/aarch64/sync-op-full.c: New.
+	* gcc.target/aarch64/sync-op-full.x: New.
+	* gcc.target/aarch64/sync-op-release.c: New.
+	* gcc.target/aarch64/sync-op-release.x: New.
+
+2015-08-04  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	* gcc.target/aarch64/fnmul-1.c: Fix whitespace.
+	* gcc.target/aarch64/fnmul-2.c: Likewise.
+	* gcc.target/aarch64/fnmul-3.c: Likewise.
+	* gcc.target/aarch64/fnmul-4.c: Likewise.
+
+2015-08-04  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	Backport from mainline r225450:
+	2015-07-06  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	PR target/66731
+	* gcc.target/aarch64/fnmul-1.c: New.
+	* gcc.target/aarch64/fnmul-2.c: New.
+	* gcc.target/aarch64/fnmul-3.c: New.
+	* gcc.target/aarch64/fnmul-4.c: New.
+
+2015-08-03  Peter Bergner  <bergner@vnet.ibm.com>
+
+	Backport from mainline:
+	2015-08-03  Peter Bergner  <bergner@vnet.ibm.com>
+
+	* gcc.target/powerpc/htm-tabort-no-r0.c: New test.
+
+2015-08-03  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	Backport form mainline r226496.
+	2015-08-03  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	PR target/66731
+	* gcc.target/arm/vnmul-1.c: New.
+	* gcc.target/arm/vnmul-2.c: New.
+	* gcc.target/arm/vnmul-3.c: New.
+	* gcc.target/arm/vnmul-4.c: New.
+
+2015-07-31  Vladimir Makarov  <vmakarov@redhat.com>
+
+	PR debug/66691
+	* gcc.target/i386/pr66691.c: New.
+
+2015-07-28  Alex Velenko  <Alex.Velenko@arm.com>
+
+	backport from trunk:
+	2015-07-21  Alex Velenko  <Alex.Velenko@arm.com>
+
+        * gcc.target/arm/split-live-ranges-for-shrink-wrap.c (dg-skip-if):
+	Skip -march=armv4t.
+        (dg-additional-options): Set armv5t flag.
+
+2015-07-25  Tom de Vries  <tom@codesourcery.com>
+
+	backport from trunk:
+	2015-07-25  Tom de Vries  <tom@codesourcery.com>
+
+	* gcc.dg/graphite/graphite.exp: Include uns-*.c files in
+	interchange_files and block_files variables.
+	* gcc.dg/graphite/uns-block-1.c (main): Change signed into unsigned
+	arithmetic.
+	* gcc.dg/graphite/uns-interchange-12.c: Same.
+	* gcc.dg/graphite/uns-interchange-14.c: Same.
+	* gcc.dg/graphite/uns-interchange-15.c: Same.
+	* gcc.dg/graphite/uns-interchange-9.c (foo): Same.
+	* gcc.dg/graphite/uns-interchange-mvt.c: Same.
+
+	2015-07-24  Tom de Vries  <tom@codesourcery.com>
+
+	* gcc.dg/graphite/block-1.c: Xfail scan.
+	* gcc.dg/graphite/interchange-12.c: Same.
+	* gcc.dg/graphite/interchange-14.c: Same.
+	* gcc.dg/graphite/interchange-15.c: Same.
+	* gcc.dg/graphite/interchange-9.c: Same.
+	* gcc.dg/graphite/interchange-mvt.c: Same.
+	* gcc.dg/graphite/uns-block-1.c: New test.
+	* gcc.dg/graphite/uns-interchange-12.c: New test.
+	* gcc.dg/graphite/uns-interchange-14.c: New test.
+	* gcc.dg/graphite/uns-interchange-15.c: New test.
+	* gcc.dg/graphite/uns-interchange-9.c: New test.
+	* gcc.dg/graphite/uns-interchange-mvt.c: New test.
+
+2015-07-24  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	Backport from mainline r226155.
+	2015-07-24  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	PR ipa/66566
+	* gcc.target/i386/mpx/pr66566.c: New test.
+
+2015-07-23  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline:
+	2015-07-17  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/66891
+	* gcc.target/i386/pr66891.c: New test.
+
+2015-07-23  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	Backport from mainline r224643.
+	2015-06-19  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	PR middle-end/pr66581
+	* gcc.target/i386/mpx/pr66581.c: New test.
+
+2015-07-23  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	Backport from mainline r224602.
+	2015-06-18  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	PR target/66569
+	* gcc.target/i386/mpx/chkp-vararg.c: New test.
+
+2015-07-23  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	Backport from mainline r224601.
+	2015-06-18  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	PR middle-end/66568
+	* gcc.target/i386/mpx/pr66568.c: New test.
+
+	Backport from mainline r225296.
+	2015-07-01  H.J. Lu  <hongjiu.lu@intel.com>
+
+	* gcc.target/i386/mpx/pr66568.c (exit): New prototype.
+2015-07-23  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	Backport from mainline r224600.
+	2015-06-18  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	PR middle-end/66567
+	* gcc.target/i386/mpx/pr66567.c: New test.
+
+2015-07-23  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	Backport from mainline r223215.
+	2015-05-15  Ilya Enkovich  <enkovich.gnu@gmail.com>
+
+	PR middle-end/66134
+	* gcc.target/i386/mpx/pr66134.c: New test.
+
+2015-07-23  Ilya Enkovich  <ilya.enkovich@intel.com>
+
+	Backport from mainline r223114.
+	2015-05-13  Ilya Enkovich  <ilya.enkovich@intel.com>
+
+	PR target/66048
+	* gcc.target/i386/mpx/pr66048.cc: New.
+
+2015-07-23  Ilya Enkovich  <ilya.enkovich@intel.com>
+
+	Backport from mainline r223216.
+	2015-05-15  Ilya Enkovich  <ilya.enkovich@intel.com>
+
+	* gcc.dg/lto/chkp-wrap-asm-name_0.c: New.
+
+2015-07-23  Ilya Enkovich  <ilya.enkovich@intel.com>
+
+	Backport from mainline r224074.
+	2015-06-03  Ilya Enkovich  <ilya.enkovich@intel.com>
+
+	* gcc.dg/lto/chkp-removed-alias_0.c: New.
+
+2015-07-21  Alex Velenko  <Alex.Velenko@arm.com>
+
+	Backport from mainline:
+	2015-07-21  Alex Velenko  <Alex.Velenko@arm.com>
+
+	* gcc.target/arm/thumb-bitfld1.c (foo): Add explicit return type.
+
+2015-07-21  Andre Vehreschild  <vehre@gcc.gnu.org>
+
+	PR fortran/66035
+	* gfortran.dg/structure_constructor_13.f03: New test.
+
+2015-07-21  Alex Velenko  <Alex.Velenko@arm.com>
+
+	Backport from mainline:
+	2015-05-20  Alex Velenko  <Alex.Velenko@arm.com>
+
+	* gcc.target/arm/thumb1-far-jump-2.c (r4): Added int in definition.
+
+2015-07-21  Alex Velenko  <Alex.Velenko@arm.com>
+
+	Backport from mainline:
+	2015-06-01  Alex Velenko  <Alex.Velenko@arm.com>
+
+	* gcc.target/arm/thumb-ltu.c (foo): Predefined.
+	(bar): Predefined.
+
+2015-07-21  Mantas Mikaitis  <mantas.mikaitis@arm.com>
+
+	* gcc.target/arm/macro_defs0.c: Add directive to skip
+	test if -marm is present.
+	* gcc.target/arm/macro_defs1.c: Likewise.
+
+2015-07-18  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/66922
+	* gcc.target/i386/pr66922.c: New test.
+
+2015-07-17  Mikael Morin  <mikael@gcc.gnu.org>
+
+	* gfortran.dg/coarray_collectives_16.f90: Fix patterns
+	as follow-up to r225932.
+
+2015-07-17  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/66866
+	* g++.dg/pr66866.C: New test.
+
+2015-07-17  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline:
+	2015-07-10  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/66703
+	* gcc.target/i386/readeflags-1.c (readeflags_test): Declare with
+	__attribute__((noinline, noclone)).  Change "x" to "volatile char"
+	type to prevent possible flag-clobbering zero-extensions.
+	* gcc.target/i386/pr66703.c: New test.
+
+2015-07-17  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline:
+	2015-07-09  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/66814
+	* gcc.target/i386/pr66814.c: New test.
+
+2015-07-17  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline:
+	2015-07-15  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR rtl-optimization/66838
+	* gcc.target/i386/pr66838.c: New test.
+
+2015-07-17  Alessandro Fanfarillo  <fanfarillo.gcc@gmail.com>
+
+	* gfortran.dg/co_reduce_1.f90: New file.
+
+2015-07-16  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/66864
+	* gfortran.dg/pr66864.f90: New test.
+
+2015-07-16  Steven G. Kargl   <kargl@gcc.gnu.org>
+
+	PR fortran/66545
+	* gfortran.dg/pr66545_1.f90: New test.
+	* gfortran.dg/pr66545_2.f90: New test.
+
+2015-07-16  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/56520
+	* gfortran.dg/pr56520.f90: New test.
+
+2015-07-16  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	* gfortran.dg/iomsg_2.f90: New test.
+
+2015-07-16  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/66725
+	* gfortran.dg/pr66725.f90: New test.
+
+2015-07-16  Martin Liska  <mliska@suse.cz>
+
+	* g++.dg/ipa/pr66896.c: New test.
+
+2015-07-16  Marek Polacek  <polacek@redhat.com>
+
+	Backported from mainline
+	2015-07-08  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/66748
+	* g++.dg/abi/abi-tag15.C: New test.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
@@ -792,7 +1283,7 @@
 	Add missing ChangeLog entry for r222341.
 
 	Backport from trunk r222273
-        2015-04-21  Andreas Tobler  <andreast@gcc.gnu.org>
+	2015-04-21  Andreas Tobler  <andreast@gcc.gnu.org>
 	* gcc.target/i386/avx512bw-vpermi2w-2.c: Fix includes to use actual
 	headers.
 	* gcc.target/i386/avx512bw-vpermt2w-2.c: Likewise.
Index: gcc/testsuite/g++.dg/ubsan/vptr-10.C
===================================================================
--- gcc/testsuite/g++.dg/ubsan/vptr-10.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/ubsan/vptr-10.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,15 @@
+// { dg-do run }
+// { dg-options "-fsanitize=vptr -fno-sanitize-recover=vptr" }
+
+struct A
+{
+    virtual ~A() {}
+};
+struct B : virtual A {};
+struct C : virtual A {};
+struct D : B, virtual C {};
+
+int main()
+{
+    D d;
+}
Index: gcc/testsuite/g++.dg/pr67211.C
===================================================================
--- gcc/testsuite/g++.dg/pr67211.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/pr67211.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,50 @@
+/* { dg-do compile { target { powerpc*-*-* && lp64 } } } */
+/* { dg-skip-if "" { powerpc*-*-darwin* } { "*" } { "" } } */
+/* { dg-require-effective-target powerpc_p8vector_ok } */
+/* { dg-skip-if "do not override -mcpu" { powerpc*-*-* } { "-mcpu=*" } { "-mcpu=power7" } } */
+/* { dg-options "-mcpu=power7 -mtune=power8 -O3 -w" } */
+
+/* target/67211, compiler got a 'insn does not satisfy its constraints' error.  */
+
+template <typename _InputIterator, typename _ForwardIterator>
+void find_first_of(_InputIterator, _InputIterator, _ForwardIterator p3,
+                   _ForwardIterator p4) {
+  for (; p3 != p4; ++p3)
+    ;
+}
+
+template <typename, typename, typename> struct A {
+  int _S_buffer_size;
+  int *_M_cur;
+  int *_M_first;
+  int *_M_last;
+  int **_M_node;
+  void operator++() {
+    if (_M_cur == _M_last)
+      m_fn1(_M_node + 1);
+  }
+  void m_fn1(int **p1) {
+    _M_node = p1;
+    _M_first = *p1;
+    _M_last = _M_first + _S_buffer_size;
+  }
+};
+
+template <typename _Tp, typename _Ref, typename _Ptr>
+bool operator==(A<_Tp, _Ref, _Ptr>, A<_Tp, _Ref, _Ptr>);
+template <typename _Tp, typename _Ref, typename _Ptr>
+bool operator!=(A<_Tp, _Ref, _Ptr> p1, A<_Tp, _Ref, _Ptr> p2) {
+  return p1 == p2;
+}
+
+class B {
+public:
+  A<int, int, int> m_fn2();
+};
+struct {
+  B j;
+} a;
+void Linked() {
+  A<int, int, int> b, c, d;
+  find_first_of(d, c, b, a.j.m_fn2());
+}
Index: gcc/testsuite/g++.dg/cpp0x/alignas1.C
===================================================================
--- gcc/testsuite/g++.dg/cpp0x/alignas1.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp0x/alignas1.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,16 @@
+// PR c++/65734
+// { dg-do compile { target c++11 } }
+
+template <class T> struct A
+{
+  T t;
+};
+
+typedef A<int> T[4] alignas (2 * alignof (int));
+A<int> a[4];
+
+typedef A<char> T2[4] alignas (2 * alignof (int));
+
+#define SA(X) static_assert((X),#X)
+SA(alignof (T) == 2 * alignof(int));
+SA(alignof (T2) == 2 * alignof(int));
Index: gcc/testsuite/g++.dg/cpp0x/lambda/lambda-nested5.C
===================================================================
--- gcc/testsuite/g++.dg/cpp0x/lambda/lambda-nested5.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp0x/lambda/lambda-nested5.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,29 @@
+// PR c++/67244
+// { dg-do compile { target c++11 } }
+
+class A {
+public:
+  int operator*();
+};
+template <typename T, typename Predicate>
+void searchGen(int, int, T, Predicate p4) {
+  p4(0);
+}
+template <typename...> struct B;
+template <typename MetaFunction, typename Type, typename... Types>
+struct B<MetaFunction, Type, Types...> {
+  static void exec() { MetaFunction::template exec<Type>; }
+};
+template <typename MetaFunction, typename... Types> void forEachType() {
+  B<MetaFunction, Types...>::exec;
+}
+namespace {
+struct C {
+  template <typename T> void exec() {
+    A __trans_tmp_1;
+    const auto target = *__trans_tmp_1;
+    searchGen(0, 0, 0, [=](T) { [=] { target; }; });
+  }
+};
+}
+void ____C_A_T_C_H____T_E_S_T____75() { forEachType<C, int>; }
Index: gcc/testsuite/g++.dg/cpp0x/alias-decl-52.C
===================================================================
--- gcc/testsuite/g++.dg/cpp0x/alias-decl-52.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp0x/alias-decl-52.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,24 @@
+// PR c++/67021
+// { dg-do compile { target c++11 } }
+
+template<typename> struct Dummy;
+template<> struct Dummy<int> {};
+
+template <class...>
+struct all_same { static constexpr bool value = true; };
+template <class T, class...Rest>
+struct all_same<T, T, Rest...> : all_same<T, Rest...> {};
+template <class T, class U, class...Rest>
+struct all_same<T, U, Rest...> { static constexpr bool value = false; };
+
+template <class R>
+using ValueType = int;
+
+template <class I>
+constexpr bool A(I i) {
+  return all_same<ValueType<I>, ValueType<decltype(i++)>>::value;
+}
+
+int main() {
+  static_assert(A(42), "");
+}
Index: gcc/testsuite/g++.dg/cpp0x/alignas2.C
===================================================================
--- gcc/testsuite/g++.dg/cpp0x/alignas2.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp0x/alignas2.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,20 @@
+// PR c++/65734
+// { dg-do compile { target c++11 } }
+
+template <typename T>
+struct BVector
+{
+  T t;
+};
+BVector<int> m;
+
+template <template <class> class T>
+struct BV2
+{
+  typedef T<float> value_type alignas (16);
+  value_type v;
+};
+BV2<BVector> m2;
+
+#define SA(X) static_assert((X),#X)
+SA(alignof (BV2<BVector>::value_type) == 16);
Index: gcc/testsuite/g++.dg/cpp1y/var-templ43.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/var-templ43.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/var-templ43.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,35 @@
+// PR c++/67130
+// { dg-do compile { target c++14 } }
+
+namespace std {
+template <typename> struct __success_type;
+template <typename> void declval();
+template <typename> class decay {
+public:
+  typedef int type;
+};
+template <typename...> struct common_type;
+struct A {
+  template <typename, typename _Up>
+  static __success_type<typename decay<decltype(declval<_Up>)>::type> _S_test;
+};
+template <typename _Tp, typename _Up> struct __common_type_impl : A {
+  typedef decltype(_S_test<_Tp, _Up>) type;
+};
+template <typename _Tp, typename _Up>
+struct common_type<_Tp, _Up> : __common_type_impl<_Tp, _Up> {};
+}
+template <typename> struct B { struct _; };
+template <typename T> typename B<T>::_ type;
+template <template <typename...> class> struct C;
+template <template <typename...> class f> C<f> metafunction;
+template <typename T> struct B<T>::_ {};
+namespace detail {
+template <typename> struct _decltype;
+}
+template <template <typename...> class F> struct C {
+  template <typename... T>
+  auto operator()(T...)
+      -> decltype(type<typename F<detail::_decltype<T>...>::type>);
+};
+auto common_type = metafunction<std::common_type>(0, 0);
Index: gcc/testsuite/g++.dg/cpp1y/var-templ35.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/var-templ35.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/var-templ35.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,5 @@
+// PR c++/66595
+// { dg-do compile { target c++14 } }
+
+template<typename T> int typeID{42};
+template<typename T> double typeID<double>{10.10}; // { dg-error "primary template|redeclaration|not deducible" }
Index: gcc/testsuite/g++.dg/cpp1y/var-templ39.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/var-templ39.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/var-templ39.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,16 @@
+// PR c++/66260
+// { dg-do compile { target c++14 } }
+
+template <class>
+constexpr bool foo = false;
+template <>
+constexpr bool foo<int> = true;
+template <class T, int N>
+constexpr bool foo<T[N]> = foo<T>;
+
+static_assert(foo<int>, "");
+static_assert(!foo<double>, "");
+static_assert(foo<int[3]>, "");
+static_assert(!foo<double[3]>, "");
+static_assert(foo<int[2][5][3]>, "");
+static_assert(!foo<double[2][5][3]>, "");
Index: gcc/testsuite/g++.dg/cpp1y/var-templ40.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/var-templ40.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/var-templ40.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,9 @@
+// PR c++/66619
+// { dg-do compile { target c++14 } }
+
+int y;
+template<class T> T val1 = y;
+auto&& x1 = val1<int&>;
+
+template<class T> T val2 = 0;
+auto&& x2 = val2<int&&>;
Index: gcc/testsuite/g++.dg/cpp1y/var-templ44.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/var-templ44.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/var-templ44.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,29 @@
+// PR c++/67161
+// { dg-do compile { target c++14 } }
+
+template <typename _Tp> struct integral_constant {
+  static constexpr _Tp value = 0;
+};
+template <bool, typename, typename> struct conditional;
+template <typename...> struct __or_;
+template <typename _B1, typename _B2>
+struct __or_<_B1, _B2> : conditional<1, _B1, _B2>::type {};
+template <typename...> struct __and_;
+template <typename> struct __not_ : integral_constant<bool> {};
+template <typename> struct __is_void_helper : integral_constant<bool> {};
+template <typename> struct is_void : __is_void_helper<int> {};
+template <bool, typename _Iftrue, typename> struct conditional {
+  typedef _Iftrue type;
+};
+template <bool _Cond, typename _Iftrue, typename _Iffalse>
+using conditional_t = typename conditional<_Cond, _Iftrue, _Iffalse>::type;
+template <typename...> using common_type_t = int;
+template <typename, int> struct array {};
+template <typename _Tp> constexpr int is_void_v = is_void<_Tp>::value;
+template <typename _Dest = void, typename... _Types>
+constexpr auto make_array()
+    -> array<conditional_t<is_void_v<_Dest>, common_type_t<>, _Dest>,
+             sizeof...(_Types)> {
+  static_assert(__or_<__not_<is_void<_Dest>>, __and_<>>::value, ""); // { dg-error "static assert" }
+}
+auto d = make_array();
Index: gcc/testsuite/g++.dg/cpp1y/auto-fn27.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/auto-fn27.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/auto-fn27.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,42 @@
+// PR c++/66919
+// { dg-do compile { target c++14 } }
+
+template <int>
+struct A {
+  template <typename F, typename R, typename T>
+    static auto run (F fn, R, T) { auto r =  fn (); } // { dg-error "" }
+};
+template <typename F, typename T>
+auto foo (F fn, T)
+{
+  A <0>::run (fn, 0, 0);
+}
+struct B;
+struct C {
+  typedef B D;
+};
+struct E {
+  virtual void bar (const int &);
+};
+template <typename C>
+struct F : E {
+  typedef typename C::D::G G;
+  void bar (const G &);
+  typename C::D::H I;
+};
+struct J { struct K {}; };
+template <typename T>
+void
+F<T>::bar (const G &)
+{
+  auto s = I;
+  typedef decltype (s) L;
+  auto u =[&](L) { auto t = foo (J::K (), 0); }; // { dg-error "" }
+}
+struct B {
+  typedef int G;
+  typedef int H;
+};
+struct M : F <C> {
+  M () {}
+};
Index: gcc/testsuite/g++.dg/cpp1y/lambda-generic-ice3.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/lambda-generic-ice3.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/lambda-generic-ice3.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,3 @@
+// PR c++/66533
+// { dg-do compile { target c++14 } }
+auto a([](auto) -> decltype((void)0) {});
Index: gcc/testsuite/g++.dg/cpp1y/var-templ32.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/var-templ32.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/var-templ32.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,7 @@
+// { dg-do compile { target c++14 } }
+
+template<typename T>
+bool V1 = true;
+
+template<typename T>
+bool V1<int> = false; // { dg-error "primary template|not deducible" }
Index: gcc/testsuite/g++.dg/cpp1y/var-templ36.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/var-templ36.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/var-templ36.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,15 @@
+// { dg-do compile { target c++14 } }
+
+template <class T>
+constexpr T v = T();
+
+template <class T>
+constexpr T v<T*> = T();
+
+template <class T>
+struct A {
+  static constexpr decltype (v<T>) v = ::v<T>;
+};
+
+double d1 = v<double*>;
+double d2 = A<double*>::v;
Index: gcc/testsuite/g++.dg/cpp1y/constexpr-array1.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/constexpr-array1.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/constexpr-array1.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,20 @@
+// PR c++/67104
+// { dg-do compile { target c++14 } }
+
+template <typename T, int N> struct array
+{
+  constexpr T &operator[](int index) { return data[index]; }
+  constexpr T operator[](int index) const { return data[index]; }
+  T data[N];
+};
+
+constexpr array<long unsigned, 1001>
+make_bottle_count ()
+{
+  array<long unsigned, 1001> a{};
+  a[65] = 1;
+  return a;
+}
+
+constexpr auto bottle_count = make_bottle_count ();
+static_assert (bottle_count[65], "");
Index: gcc/testsuite/g++.dg/cpp1y/lambda-generic-ice4.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/lambda-generic-ice4.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/lambda-generic-ice4.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,10 @@
+// PR c++/67369
+// { dg-do compile { target c++14 } }
+
+int main() {
+  unsigned const nsz = 0;
+  auto repeat_conditional = [&](auto) {
+    auto new_sz = nsz;
+  };
+  repeat_conditional(1);
+}
Index: gcc/testsuite/g++.dg/cpp1y/var-templ33.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/var-templ33.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/var-templ33.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,20 @@
+// Test for variable templates in pack expansion
+// { dg-do compile { target c++14 } }
+
+template <int I> const int Val = I;
+
+constexpr int f () { return 0; }
+template <class T, class ...Ts>
+constexpr int f(T t, Ts... ts)
+{
+  return t + f(ts...);
+}
+
+template <int... Is>
+constexpr int g()
+{
+  return f(Val<Is>...);
+}
+
+#define SA(X) static_assert((X),#X)
+SA((g<1,2,3,4>() == 1+2+3+4));
Index: gcc/testsuite/g++.dg/cpp1y/var-templ37.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/var-templ37.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/var-templ37.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,23 @@
+// PR c++/65195
+// { dg-do compile { target c++14 } }
+
+template<typename T>
+T constant {};
+
+template<typename T>
+struct foo {
+    int operator()() const
+    { return 3; }
+};
+
+template<typename T>
+auto& f = constant<foo<T>>;
+
+int main()
+{
+    // fine
+    auto& ref = f<int>; ref();
+
+    // error: f<int> cannot be used as a function
+    f<int>();
+}
Index: gcc/testsuite/g++.dg/cpp1y/var-templ42.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/var-templ42.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/var-templ42.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,17 @@
+// PR c++/67131
+// { dg-do compile { target c++14 } }
+
+template <typename T> typename T::_ type;
+template <template <typename...> class> struct A;
+template <template <typename> class f> A<f> metafunction;
+namespace detail {
+template <typename> struct _decltype;
+}
+template <template <typename...> class F> struct A {
+  template <typename... T>
+  auto operator()() -> decltype(type<F<detail::_decltype<T>...>>);
+};
+template <typename F> auto valid_call(F f) -> decltype(f());
+constexpr auto valid_call(...) { return 0; }
+template <typename> struct no_type;
+static_assert(!valid_call(metafunction<no_type>),""); // { dg-error "" }
Index: gcc/testsuite/g++.dg/cpp1y/var-templ38.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/var-templ38.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/var-templ38.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,9 @@
+// PR c++/66596
+// { dg-do compile { target c++14 } }
+
+struct U { void f() {} };
+struct V { void f() {} };
+template<class T> U t;
+template<> V t<int>;
+template<class T> void g() { t<T>.f(); }
+int main() { g<int>(); }
Index: gcc/testsuite/g++.dg/abi/abi-tag15.C
===================================================================
--- gcc/testsuite/g++.dg/abi/abi-tag15.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/abi/abi-tag15.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,3 @@
+// PR c++/66748
+
+enum __attribute__((abi_tag("foo"))) E {}; // { dg-error "redeclaration of" }
Index: gcc/testsuite/g++.dg/gomp/pr67504.C
===================================================================
--- gcc/testsuite/g++.dg/gomp/pr67504.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/gomp/pr67504.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,15 @@
+// PR c++/67504
+// { dg-do compile }
+// { dg-options "-fopenmp" }
+
+int bar (int);
+double bar (double);
+
+template <typename T>
+void
+foo (T x)
+{
+  #pragma omp for collapse (x + 1) // { dg-error "collapse argument needs positive constant integer expression" }
+  for (int i = 0; i < 10; i++)
+    ;
+}
Index: gcc/testsuite/g++.dg/gomp/pr67522.C
===================================================================
--- gcc/testsuite/g++.dg/gomp/pr67522.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/gomp/pr67522.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,26 @@
+// PR c++/67522
+// { dg-do compile }
+// { dg-options "-fopenmp" }
+
+struct S;
+
+template <int N>
+void
+foo (void)
+{
+  #pragma omp simd linear (S)			// { dg-error "is not a variable in clause" }
+  for (int i = 0; i < 16; i++)
+    ;
+
+  #pragma omp target map (S[0:10])		// { dg-error "is not a variable in" }
+  ;
+
+  #pragma omp task depend (inout: S[0:10])	// { dg-error "is not a variable in" }
+  ;
+}
+
+void
+bar ()
+{
+  foo <0> ();
+}
Index: gcc/testsuite/g++.dg/gomp/pr67514.C
===================================================================
--- gcc/testsuite/g++.dg/gomp/pr67514.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/gomp/pr67514.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,30 @@
+// PR c++/67514
+// { dg-do compile }
+// { dg-options "-fopenmp" }
+
+template <class T>
+void
+foo (T x, T y)
+{
+  #pragma omp parallel
+  #pragma omp for simd
+  for (T i = x; i < y; ++i)
+    ;
+  #pragma omp parallel
+  #pragma omp for simd collapse (2)
+  for (T i = x; i < y; ++i)
+    for (T j = x; j < y; j++)
+      ;
+}
+
+void
+bar (int *x, int *y)
+{
+  foo (x, y);
+}
+
+void
+baz (int x, int y)
+{
+  foo (x, y);
+}
Index: gcc/testsuite/g++.dg/gomp/pr67523.C
===================================================================
--- gcc/testsuite/g++.dg/gomp/pr67523.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/gomp/pr67523.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,29 @@
+// PR c++/67523
+// { dg-do compile }
+// { dg-options "-fopenmp" }
+
+struct S { int s; };
+
+template <typename T>
+void foo (T &x, T &y)
+{
+#pragma omp for simd
+  for (T i = x; i < y; i++)	// { dg-error "used with class iteration variable" }
+    ;
+#pragma omp parallel for simd
+  for (T i = x; i < y; i++)	// { dg-error "used with class iteration variable" }
+    ;
+#pragma omp target teams distribute parallel for simd
+  for (T i = x; i < y; i++)	// { dg-error "used with class iteration variable" }
+    ;
+#pragma omp target teams distribute simd
+  for (T i = x; i < y; i++)	// { dg-error "used with class iteration variable" }
+    ;
+}
+
+void
+bar ()
+{
+  S x, y;
+  foo <S> (x, y);
+}
Index: gcc/testsuite/g++.dg/gomp/pr67511.C
===================================================================
--- gcc/testsuite/g++.dg/gomp/pr67511.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/gomp/pr67511.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,20 @@
+// PR c++/67511
+// { dg-do compile }
+// { dg-options "-fopenmp" }
+
+struct I
+{
+  I ();
+  I (const I &);
+  I &operator++ ();
+  bool operator< (const I &) const;
+};
+__PTRDIFF_TYPE__ operator- (const I &, const I &);
+
+void
+foo (I &x, I &y)
+{
+#pragma omp for
+  for (I i = x; i < y; ++i)	// { dg-error "no match for" }
+    ;
+}
Index: gcc/testsuite/g++.dg/init/pr66857.C
===================================================================
--- gcc/testsuite/g++.dg/init/pr66857.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/init/pr66857.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,19 @@
+// PR c++/66857
+// { dg-do run }
+
+const int i = 0;
+
+struct Test
+{
+  Test (const int &rhs)
+  {
+    if (&rhs != &i)
+      __builtin_abort ();
+  }
+};
+
+int
+main (void)
+{
+  Test test = i;
+}
Index: gcc/testsuite/g++.dg/conversion/access1.C
===================================================================
--- gcc/testsuite/g++.dg/conversion/access1.C	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/testsuite/g++.dg/conversion/access1.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -15,7 +15,7 @@
 struct C : public P
 {
   // C can access P's copy ctor, but can't convert b to const P&.
-  C(const B& b) : P(b) {}	// { dg-error "inaccessible base" }
+  C(const B& b) : P(b) {}	// { dg-error "inaccessible base" "" { xfail *-*-* } }
 };
 
 void foo()
Index: gcc/testsuite/g++.dg/lto/pr66705_0.C
===================================================================
--- gcc/testsuite/g++.dg/lto/pr66705_0.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/lto/pr66705_0.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,15 @@
+// { dg-lto-do link }
+// { dg-lto-options { { -O2 -flto -flto-partition=max -fipa-pta } } }
+// { dg-extra-ld-options "-r -nostdlib" }
+
+class A {
+public:
+    A();
+};
+int a = 0;
+void foo() {
+    a = 0;
+    A b;
+    for (; a;)
+      ;
+}
Index: gcc/testsuite/g++.dg/warn/deprecated-9.C
===================================================================
--- gcc/testsuite/g++.dg/warn/deprecated-9.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/warn/deprecated-9.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,16 @@
+// PR c++/65974
+// { dg-options "-Wdeprecated" }
+
+struct S {
+    void bar();
+
+    __attribute__((deprecated("use bar() instead.")))
+    virtual void foo();
+};
+
+void S::foo() { bar(); }
+
+int main()
+{
+    return 0;
+}
Index: gcc/testsuite/g++.dg/pr66866.C
===================================================================
--- gcc/testsuite/g++.dg/pr66866.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/pr66866.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,29 @@
+// { dg-do run { target i?86-*-* x86_64-*-* } }
+// { dg-require-effective-target sse2_runtime }
+// { dg-options "-O -msse2" }
+
+extern "C" void abort (void);
+
+typedef long long __m128i __attribute__ ((__vector_size__ (16), __may_alias__));
+typedef short A __attribute__((__may_alias__));
+
+__m128i __attribute__((noinline))
+shuf(const __m128i v)
+{
+  __m128i r;
+
+  reinterpret_cast<A *>(&r)[5] = reinterpret_cast<const A *>(&v)[4];
+  return r;
+}
+
+int main()
+{
+  __attribute__((aligned(16))) short mem[8] = { 0, 1, 2, 3, 4, 5, 6, 7 };
+
+  *reinterpret_cast<__m128i *>(mem) = shuf (*reinterpret_cast<__m128i *>(mem));
+
+  if (mem[5] != 4)
+    abort ();
+
+  return 0;
+}
Index: gcc/testsuite/g++.dg/inherit/access9.C
===================================================================
--- gcc/testsuite/g++.dg/inherit/access9.C	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/inherit/access9.C	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,14 @@
+// PR c++/66957
+
+class BaseClass {
+protected:
+  static int x;
+};
+
+struct DerivedA : BaseClass { };
+
+struct DerivedB : BaseClass {
+  DerivedB() {
+    (void) DerivedA::x;
+  }
+};
Index: gcc/testsuite/c-c++-common/ubsan/pr66908.c
===================================================================
--- gcc/testsuite/c-c++-common/ubsan/pr66908.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/c-c++-common/ubsan/pr66908.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,15 @@
+/* PR sanitizer/66908 */
+/* { dg-do compile } */
+/* { dg-options "-fsanitize=shift,bounds -O2 -Werror=maybe-uninitialized" } */
+/* { dg-additional-options "-std=gnu90" { target c } } */
+
+struct S { int a[22]; };
+static int const e[22] = { };
+
+void
+foo (struct S const *s, unsigned int m, unsigned int *res)
+{
+  unsigned int i;
+  for (i = 0; i < 22; ++i)
+    res[i] = ((s->a[i] + e[i]) << m);
+}
Index: gcc/testsuite/c-c++-common/gomp/pr67501.c
===================================================================
--- gcc/testsuite/c-c++-common/gomp/pr67501.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/c-c++-common/gomp/pr67501.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,12 @@
+/* PR c/67501 */
+/* { dg-do compile } */
+/* { dg-options "-fopenmp" } */
+
+void
+foo (void)
+{
+  int i, j;
+  #pragma omp for simd copyprivate(j	/* { dg-error "before end of line" } */
+  for (i = 0; i < 16; ++i)		/* { dg-error "is not valid for" "" { target *-*-* } 9 } */
+    ;
+}
Index: gcc/testsuite/c-c++-common/gomp/pr67502.c
===================================================================
--- gcc/testsuite/c-c++-common/gomp/pr67502.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/c-c++-common/gomp/pr67502.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,16 @@
+/* PR c/67502 */
+/* { dg-do compile } */
+/* { dg-options "-fopenmp" } */
+/* { dg-additional-options "-std=c99" { target c } } */
+
+void bar (int, int);
+
+void
+foo (void)
+{
+#pragma omp parallel
+#pragma omp for simd collapse(2)
+  for (int i = 0; i < 16; ++i)
+    for (int j = 0; j < 16; ++j)
+      bar (i, j);
+}
Index: gcc/testsuite/c-c++-common/gomp/pr67521.c
===================================================================
--- gcc/testsuite/c-c++-common/gomp/pr67521.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/c-c++-common/gomp/pr67521.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,20 @@
+/* PR middle-end/67521 */
+/* { dg-do compile } */
+/* { dg-options "-fopenmp" } */
+
+void
+foo (int x)
+{
+  int i = 0;
+  #pragma omp parallel for simd
+  for (i = (i & x); i < 10; i = i + 2)
+    ;
+  i = 0;
+  #pragma omp parallel for simd
+  for (i = 0; i < (i & x) + 10; i = i + 2)
+    ;
+  i = 0;
+  #pragma omp parallel for simd
+  for (i = 0; i < 10; i = i + ((i & x) + 2))
+    ;
+}
Index: gcc/testsuite/c-c++-common/gomp/pr67517.c
===================================================================
--- gcc/testsuite/c-c++-common/gomp/pr67517.c	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/testsuite/c-c++-common/gomp/pr67517.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,13 @@
+/* PR middle-end/67517 */
+/* { dg-do compile } */
+/* { dg-options "-fopenmp" } */
+
+int
+foo (int x, int y, int z)
+{
+  int i;
+  #pragma omp parallel for simd linear (y : x & 15) linear (x : 16) linear (z : x & 15)
+  for (i = 0; i < 256; ++i)
+    x += 16, y += x & 15, z += x & 15;
+  return x + y + z;
+}
Index: gcc/cp/class.c
===================================================================
--- gcc/cp/class.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cp/class.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1989,6 +1989,10 @@
   if (!t)
     return;
 
+  tree attrs = TYPE_ATTRIBUTES (t);
+  unsigned align = TYPE_ALIGN (t);
+  bool user_align = TYPE_USER_ALIGN (t);
+
   for (variants = TYPE_NEXT_VARIANT (t);
        variants;
        variants = TYPE_NEXT_VARIANT (variants))
@@ -1995,8 +1999,13 @@
     {
       /* These are the two fields that check_qualified_type looks at and
 	 are affected by attributes.  */
-      TYPE_ATTRIBUTES (variants) = TYPE_ATTRIBUTES (t);
-      TYPE_ALIGN (variants) = TYPE_ALIGN (t);
+      TYPE_ATTRIBUTES (variants) = attrs;
+      unsigned valign = align;
+      if (TYPE_USER_ALIGN (variants))
+	valign = MAX (valign, TYPE_ALIGN (variants));
+      else
+	TYPE_USER_ALIGN (variants) = user_align;
+      TYPE_ALIGN (variants) = valign;
     }
 }
 
Index: gcc/cp/constexpr.c
===================================================================
--- gcc/cp/constexpr.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cp/constexpr.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1750,8 +1750,39 @@
       VERIFY_CONSTANT (ary);
       gcc_unreachable ();
     }
-  if (compare_tree_int (index, len) >= 0)
+
+  i = tree_to_shwi (index);
+  bool found = true;
+  if (TREE_CODE (ary) == CONSTRUCTOR && len
+      && (TREE_CODE (CONSTRUCTOR_ELT (ary, len-1)->index) == RANGE_EXPR
+	  || compare_tree_int (CONSTRUCTOR_ELT (ary, len-1)->index, len-1)))
     {
+      /* The last element doesn't match its position in the array; this must be
+	 a sparse array from cxx_eval_store_expression.  So iterate.  */
+      found = false;
+      vec<constructor_elt, va_gc> *v = CONSTRUCTOR_ELTS (ary);
+      constructor_elt *e;
+      for (unsigned ix = 0; vec_safe_iterate (v, ix, &e); ++ix)
+	{
+	  if (TREE_CODE (e->index) == RANGE_EXPR)
+	    {
+	      tree lo = TREE_OPERAND (e->index, 0);
+	      tree hi = TREE_OPERAND (e->index, 1);
+	      if (tree_int_cst_le (lo, index) && tree_int_cst_le (index, hi))
+		found = true;
+	    }
+	  else if (tree_int_cst_equal (e->index, index))
+	    found = true;
+	  if (found)
+	    {
+	      i = ix;
+	      break;
+	    }
+	}
+    }
+
+  if (i >= len || !found)
+    {
       if (tree_int_cst_lt (index, array_type_nelts_top (TREE_TYPE (ary))))
 	{
 	  /* If it's within the array bounds but doesn't have an explicit
@@ -1767,7 +1798,7 @@
       *non_constant_p = true;
       return t;
     }
-  else if (tree_int_cst_lt (index, integer_zero_node))
+  else if (i < 0)
     {
       if (!ctx->quiet)
 	error ("negative array subscript");
@@ -1774,7 +1805,7 @@
       *non_constant_p = true;
       return t;
     }
-  i = tree_to_shwi (index);
+
   if (TREE_CODE (ary) == CONSTRUCTOR)
     return (*CONSTRUCTOR_ELTS (ary))[i].value;
   else if (elem_nchars == 1)
Index: gcc/cp/error.c
===================================================================
--- gcc/cp/error.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cp/error.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1230,7 +1230,8 @@
 	if (args == error_mark_node)
 	  pp_string (pp, M_("<template arguments error>"));
 	else if (args)
-	  dump_template_argument_list (pp, args, flags);
+	  dump_template_argument_list
+	    (pp, args, flags|TFF_NO_OMIT_DEFAULT_TEMPLATE_ARGUMENTS);
       	pp_cxx_end_template_argument_list (pp);
       }
       break;
Index: gcc/cp/tree.c
===================================================================
--- gcc/cp/tree.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cp/tree.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -3602,13 +3602,15 @@
 		 name, *node);
 	  goto fail;
 	}
-      else if (CLASSTYPE_TEMPLATE_INSTANTIATION (*node))
+      else if (CLASS_TYPE_P (*node)
+	       && CLASSTYPE_TEMPLATE_INSTANTIATION (*node))
 	{
 	  warning (OPT_Wattributes, "ignoring %qE attribute applied to "
 		   "template instantiation %qT", name, *node);
 	  goto fail;
 	}
-      else if (CLASSTYPE_TEMPLATE_SPECIALIZATION (*node))
+      else if (CLASS_TYPE_P (*node)
+	       && CLASSTYPE_TEMPLATE_SPECIALIZATION (*node))
 	{
 	  warning (OPT_Wattributes, "ignoring %qE attribute applied to "
 		   "template specialization %qT", name, *node);
Index: gcc/cp/ChangeLog
===================================================================
--- gcc/cp/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cp/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,119 @@
+2015-09-10  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/67522
+	* semantics.c (handle_omp_array_sections_1): Only run
+	type_dependent_expression_p on VAR_DECL/PARM_DECLs.
+	(finish_omp_clauses) <case OMP_CLAUSE_LINEAR>: Likewise.
+	Don't adjust OMP_CLAUSE_LINEAR_STEP if OMP_CLAUSE_DECL
+	is not a VAR_DECL/PARM_DECL.
+
+	PR c++/67511
+	* semantics.c (handle_omp_for_class_iterator): Don't wrap
+	error_mark_node into a NOP_EXPR to void_type_node.
+
+2015-09-09  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/67504
+	* parser.c (cp_parser_omp_clause_collapse): Test tree_fits_shwi_p
+	before INTEGRAL_TYPE_P test.
+
+2015-09-08  Paolo Carlini  <paolo.carlini@oracle.com>
+
+	PR c++/67369
+	* pt.c (tsubst_copy, [case FUNCTION_DECL]): Do not call tsubst
+	if the first argument isn't a template.
+
+2015-08-17  Jason Merrill  <jason@redhat.com>
+
+	PR c++/66957
+	* search.c (protected_accessible_p): Revert fix for 38579.
+
+2015-08-17  Paolo Carlini  <paolo.carlini@oracle.com>
+
+	PR c++/66919
+	* pt.c (tsubst_copy): Pass complain to mark_used, check return value.
+
+2015-08-17  Jason Merrill  <jason@redhat.com>
+
+	PR c++/67244
+	* pt.c (tsubst_copy_and_build): Call insert_pending_capture_proxies.
+
+	PR c++/65734
+	* class.c (fixup_attribute_variants): Respect TYPE_USER_ALIGN.
+
+	PR c++/67104
+	* constexpr.c (cxx_eval_array_reference): Handle sparse
+	CONSTRUCTORs.
+
+2015-08-14  Jason Merrill  <jason@redhat.com>
+
+	PR c++/65974
+	* decl2.c (mark_vtable_entries): Suppress -Wdeprecated.
+
+2015-08-14  Patrick Palka  <ppalka@gcc.gnu.org>
+
+	PR c++/66857
+	* cvt.c (ocp_convert): Don't call scalar_constant_value when
+	converting to a class type.
+
+2015-08-12  Jason Merrill  <jason@redhat.com>
+
+	PR c++/67161
+	* error.c (dump_decl) [TEMPLATE_ID_EXPR]: Pass
+	TFF_NO_OMIT_DEFAULT_TEMPLATE_ARGUMENTS.
+
+2015-08-06  Jason Merrill  <jason@redhat.com>
+
+	PR c++/66533
+	* parser.c (cp_parser_primary_expression): Don't skip to the end
+	of the statement if we're parsing tentatively.
+
+	PR c++/67130
+	PR c++/67131
+	PR c++/66260
+	* mangle.c (write_expression) [TEMPLATE_ID_EXPR]: Handle variable
+	templates.
+	* pt.c (tsubst_copy_and_build): Check for argument substitution
+	failure.
+
+2015-08-05  Jason Merrill  <jason@redhat.com>
+
+	PR c++/66260
+	PR c++/66596
+	PR c++/66649
+	PR c++/66923
+	* pt.c (lookup_template_variable): Use NULL_TREE for type.
+	(instantiate_template_1): Also set DECL_TI_ARGS based on
+	the immediate parent.
+	(tsubst_copy_and_build) [TEMPLATE_ID_EXPR]: Handle variable templates.
+	(finish_template_variable): Add complain parm.
+	* cp-tree.h: Adjust.
+
+	PR c++/65195
+	PR c++/66619
+	* semantics.c (finish_id_expression): Call convert_from_reference
+	for variable template.
+
+	PR c++/66336
+	* pt.c (find_parameter_packs_r): Handle variable templates.
+	(variable_template_specialization_p): New.
+	* cp-tree.h: Declare it.
+
+2015-07-30  Jason Merrill  <jason@redhat.com>
+
+	DR 1558
+	PR c++/67021
+	* pt.c (tsubst_decl) [TYPE_DECL]: Clear TYPE_DEPENDENT_P_VALID.
+
+2015-07-16  Marek Polacek  <polacek@redhat.com>
+
+	Backported from mainline
+	2015-07-08  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/66748
+	* tree.c (handle_abi_tag_attribute): Check for CLASS_TYPE_P before
+	accessing TYPE_LANG_SPECIFIC node.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: gcc/cp/pt.c
===================================================================
--- gcc/cp/pt.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cp/pt.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -3222,6 +3222,13 @@
 			ppd, ppd->visited);
 	  *walk_subtrees = 0;
 	}
+      else if (variable_template_specialization_p (t))
+	{
+	  cp_walk_tree (&DECL_TI_ARGS (t),
+			find_parameter_packs_r,
+			ppd, ppd->visited);
+	  *walk_subtrees = 0;
+	}
       break;
 
     case BASES:
@@ -5323,6 +5330,17 @@
   return instantiate_non_dependent_expr_sfinae (expr, tf_error);
 }
 
+/* True iff T is a specialization of a variable template.  */
+
+bool
+variable_template_specialization_p (tree t)
+{
+  if (!VAR_P (t) || !DECL_LANG_SPECIFIC (t) || !DECL_TEMPLATE_INFO (t))
+    return false;
+  tree tmpl = DECL_TI_TEMPLATE (t);
+  return variable_template_p (tmpl);
+}
+
 /* Return TRUE iff T is a type alias, a TEMPLATE_DECL for an alias
    template declaration, or a TYPE_DECL for an alias declaration.  */
 
@@ -8161,7 +8179,7 @@
 tree
 lookup_template_variable (tree templ, tree arglist)
 {
-  tree type = unknown_type_node;
+  tree type = NULL_TREE;
   return build2 (TEMPLATE_ID_EXPR, type, templ, arglist);
 }
 
@@ -8168,7 +8186,7 @@
 /* Instantiate a variable declaration from a TEMPLATE_ID_EXPR for use. */
 
 tree
-finish_template_variable (tree var)
+finish_template_variable (tree var, tsubst_flags_t complain)
 {
   tree templ = TREE_OPERAND (var, 0);
 
@@ -8177,7 +8195,6 @@
   arglist = add_outermost_template_args (tmpl_args, arglist);
 
   tree parms = DECL_TEMPLATE_PARMS (templ);
-  tsubst_flags_t complain = tf_warning_or_error;
   arglist = coerce_innermost_template_parms (parms, arglist, templ, complain,
 					     /*req_all*/true,
 					     /*use_default*/true);
@@ -11547,6 +11564,10 @@
 	  {
 	    DECL_ORIGINAL_TYPE (r) = NULL_TREE;
 	    set_underlying_type (r);
+	    if (TYPE_DECL_ALIAS_P (r) && type != error_mark_node)
+	      /* An alias template specialization can be dependent
+		 even if its underlying type is not.  */
+	      TYPE_DEPENDENT_P_VALID (TREE_TYPE (r)) = false;
 	  }
 
 	layout_decl (r, 0);
@@ -13089,8 +13110,9 @@
 	      if (r)
 		{
 		  /* Make sure that the one we found is the one we want.  */
-		  tree ctx = tsubst (DECL_CONTEXT (t), args,
-				     complain, in_decl);
+		  tree ctx = DECL_CONTEXT (t);
+		  if (DECL_LANG_SPECIFIC (ctx) && DECL_TEMPLATE_INFO (ctx))
+		    ctx = tsubst (ctx, args, complain, in_decl);
 		  if (ctx != DECL_CONTEXT (r))
 		    r = NULL_TREE;
 		}
@@ -13138,7 +13160,8 @@
 	}
       else
 	r = t;
-      mark_used (r);
+      if (!mark_used (r, complain) && !(complain & tf_error))
+	return error_mark_node;
       return r;
 
     case NAMESPACE_DECL:
@@ -14714,7 +14737,20 @@
 
 	if (targs)
 	  targs = tsubst_template_args (targs, args, complain, in_decl);
+	if (targs == error_mark_node)
+	  return error_mark_node;
 
+	if (variable_template_p (templ))
+	  {
+	    templ = lookup_template_variable (templ, targs);
+	    if (!any_dependent_template_arguments_p (targs))
+	      {
+		templ = finish_template_variable (templ, complain);
+		mark_used (templ);
+	      }
+	    RETURN (convert_from_reference (templ));
+	  }
+
 	if (TREE_CODE (templ) == COMPONENT_REF)
 	  {
 	    object = TREE_OPERAND (templ, 0);
@@ -15826,6 +15862,8 @@
 
 	LAMBDA_EXPR_THIS_CAPTURE (r) = NULL_TREE;
 
+	insert_pending_capture_proxies ();
+
 	RETURN (build_lambda_object (r));
       }
 
@@ -16112,6 +16150,8 @@
   /* The DECL_TI_TEMPLATE should always be the immediate parent
      template, not the most general template.  */
   DECL_TI_TEMPLATE (fndecl) = tmpl;
+  if (VAR_P (fndecl))
+    DECL_TI_ARGS (fndecl) = targ_ptr;
 
   /* Now we know the specialization, compute access previously
      deferred.  */
Index: gcc/cp/semantics.c
===================================================================
--- gcc/cp/semantics.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cp/semantics.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -3580,6 +3580,7 @@
 	{
 	  decl = finish_template_variable (decl);
 	  mark_used (decl);
+	  decl = convert_from_reference (decl);
 	}
       else if (scope)
 	{
@@ -4294,8 +4295,6 @@
     {
       if (error_operand_p (t))
 	return error_mark_node;
-      if (type_dependent_expression_p (t))
-	return NULL_TREE;
       if (TREE_CODE (t) != VAR_DECL && TREE_CODE (t) != PARM_DECL)
 	{
 	  if (processing_template_decl)
@@ -4318,6 +4317,8 @@
 		    omp_clause_code_name[OMP_CLAUSE_CODE (c)]);
 	  return error_mark_node;
 	}
+      if (type_dependent_expression_p (t))
+	return NULL_TREE;
       t = convert_from_reference (t);
       return t;
     }
@@ -5332,7 +5333,8 @@
 	  goto check_dup_generic;
 	case OMP_CLAUSE_LINEAR:
 	  t = OMP_CLAUSE_DECL (c);
-	  if (!type_dependent_expression_p (t)
+	  if ((VAR_P (t) || TREE_CODE (t) == PARM_DECL)
+	      && !type_dependent_expression_p (t)
 	      && !INTEGRAL_TYPE_P (TREE_TYPE (t))
 	      && TREE_CODE (TREE_TYPE (t)) != POINTER_TYPE)
 	    {
@@ -5359,7 +5361,9 @@
 	  else
 	    {
 	      t = mark_rvalue_use (t);
-	      if (!processing_template_decl)
+	      if (!processing_template_decl
+		  && (VAR_P (OMP_CLAUSE_DECL (c))
+		      || TREE_CODE (OMP_CLAUSE_DECL (c)) == PARM_DECL))
 		{
 		  if (TREE_CODE (OMP_CLAUSE_DECL (c)) == PARM_DECL)
 		    t = maybe_constant_value (t);
@@ -6452,7 +6456,8 @@
   iter_init = build_x_modify_expr (elocus,
 				   iter, PLUS_EXPR, iter_init,
 				   tf_warning_or_error);
-  iter_init = build1 (NOP_EXPR, void_type_node, iter_init);
+  if (iter_init != error_mark_node)
+    iter_init = build1 (NOP_EXPR, void_type_node, iter_init);
   finish_expr_stmt (iter_init);
   finish_expr_stmt (build_x_modify_expr (elocus,
 					 last, NOP_EXPR, decl,
Index: gcc/cp/decl2.c
===================================================================
--- gcc/cp/decl2.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cp/decl2.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1742,6 +1742,9 @@
   tree fnaddr;
   unsigned HOST_WIDE_INT idx;
 
+  /* It's OK for the vtable to refer to deprecated virtual functions.  */
+  warning_sentinel w(warn_deprecated_decl);
+
   FOR_EACH_CONSTRUCTOR_VALUE (CONSTRUCTOR_ELTS (DECL_INITIAL (decl)),
 			      idx, fnaddr)
     {
Index: gcc/cp/parser.c
===================================================================
--- gcc/cp/parser.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cp/parser.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -4432,7 +4432,8 @@
 	parser->greater_than_is_operator_p
 	  = saved_greater_than_is_operator_p;
 	/* Consume the `)'.  */
-	if (!cp_parser_require (parser, CPP_CLOSE_PAREN, RT_CLOSE_PAREN))
+	if (!cp_parser_require (parser, CPP_CLOSE_PAREN, RT_CLOSE_PAREN)
+	    && !cp_parser_uncommitted_to_tentative_parse_p (parser))
 	  cp_parser_skip_to_end_of_statement (parser);
 
 	return expr;
@@ -28181,8 +28182,8 @@
   if (num == error_mark_node)
     return list;
   num = fold_non_dependent_expr (num);
-  if (!INTEGRAL_TYPE_P (TREE_TYPE (num))
-      || !tree_fits_shwi_p (num)
+  if (!tree_fits_shwi_p (num)
+      || !INTEGRAL_TYPE_P (TREE_TYPE (num))
       || (n = tree_to_shwi (num)) <= 0
       || (int) n != n)
     {
Index: gcc/cp/cvt.c
===================================================================
--- gcc/cp/cvt.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cp/cvt.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -695,7 +695,8 @@
     }
 
   /* FIXME remove when moving to c_fully_fold model.  */
-  e = scalar_constant_value (e);
+  if (!CLASS_TYPE_P (type))
+    e = scalar_constant_value (e);
   if (error_operand_p (e))
     return error_mark_node;
 
Index: gcc/cp/mangle.c
===================================================================
--- gcc/cp/mangle.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cp/mangle.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -2771,7 +2771,9 @@
     {
       tree fn = TREE_OPERAND (expr, 0);
       if (is_overloaded_fn (fn))
-	fn = DECL_NAME (get_first_fn (fn));
+	fn = get_first_fn (fn);
+      if (DECL_P (fn))
+	fn = DECL_NAME (fn);
       if (IDENTIFIER_OPNAME_P (fn))
 	write_string ("on");
       write_unqualified_id (fn);
Index: gcc/cp/cp-tree.h
===================================================================
--- gcc/cp/cp-tree.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cp/cp-tree.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -5762,6 +5762,7 @@
 extern tree instantiate_non_dependent_expr	(tree);
 extern tree instantiate_non_dependent_expr_sfinae (tree, tsubst_flags_t);
 extern tree instantiate_non_dependent_expr_internal (tree, tsubst_flags_t);
+extern bool variable_template_specialization_p  (tree);
 extern bool alias_type_or_template_p            (tree);
 extern bool alias_template_specialization_p     (const_tree);
 extern bool dependent_alias_template_spec_p     (const_tree);
@@ -5944,7 +5945,7 @@
 						 tsubst_flags_t);
 extern tree finish_call_expr			(tree, vec<tree, va_gc> **, bool,
 						 bool, tsubst_flags_t);
-extern tree finish_template_variable	(tree);
+extern tree finish_template_variable		(tree, tsubst_flags_t = tf_warning_or_error);
 extern tree finish_increment_expr		(tree, enum tree_code);
 extern tree finish_this_expr			(void);
 extern tree finish_pseudo_destructor_expr       (tree, tree, tree, location_t);
Index: gcc/cp/search.c
===================================================================
--- gcc/cp/search.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cp/search.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -736,7 +736,7 @@
     Here DERIVED is a possible P, DECL is m and BINFO_TYPE (binfo) is N.  */
 
   /* If DERIVED isn't derived from N, then it can't be a P.  */
-  if (!DERIVED_FROM_P (BINFO_TYPE (binfo), derived))
+  if (!DERIVED_FROM_P (context_for_name_lookup (decl), derived))
     return 0;
 
   access = access_in_type (derived, decl);
Index: gcc/lto-cgraph.c
===================================================================
--- gcc/lto-cgraph.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/lto-cgraph.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -80,6 +80,7 @@
 #include "pass_manager.h"
 #include "ipa-utils.h"
 #include "omp-low.h"
+#include "ipa-chkp.h"
 
 /* True when asm nodes has been output.  */
 bool asm_nodes_output = false;
@@ -1641,10 +1642,13 @@
 		    cnode->instrumented_version->instrumented_version = cnode;
 		}
 
-	      /* Restore decl names reference.  */
-	      IDENTIFIER_TRANSPARENT_ALIAS (DECL_ASSEMBLER_NAME (cnode->decl)) = 1;
-	      TREE_CHAIN (DECL_ASSEMBLER_NAME (cnode->decl))
-		  = DECL_ASSEMBLER_NAME (cnode->orig_decl);
+	      /* Restore decl names reference except for wrapper functions.  */
+	      if (!chkp_wrap_function (cnode->orig_decl))
+		{
+		  tree name = DECL_ASSEMBLER_NAME (cnode->decl);
+		  IDENTIFIER_TRANSPARENT_ALIAS (name) = 1;
+		  TREE_CHAIN (name) = DECL_ASSEMBLER_NAME (cnode->orig_decl);
+		}
 	    }
 	}
 
Index: gcc/tree-ssa-math-opts.c
===================================================================
--- gcc/tree-ssa-math-opts.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/tree-ssa-math-opts.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1856,7 +1856,7 @@
      the same base (array, structure, ...).  */
   if (gimple_assign_rhs1 (source_stmt1) != gimple_assign_rhs1 (source_stmt2))
     {
-      int64_t inc;
+      uint64_t inc;
       HOST_WIDE_INT start_sub, end_sub, end1, end2, end;
       struct symbolic_number *toinc_n_ptr, *n_end;
 
Index: gcc/tree-ssa-alias.c
===================================================================
--- gcc/tree-ssa-alias.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/tree-ssa-alias.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1570,7 +1570,7 @@
      escape points.  See tree-ssa-structalias.c:find_func_aliases
      for the list of builtins we might need to handle here.  */
   if (callee != NULL_TREE
-      && DECL_BUILT_IN_CLASS (callee) == BUILT_IN_NORMAL)
+      && gimple_call_builtin_p (call, BUILT_IN_NORMAL))
     switch (DECL_FUNCTION_CODE (callee))
       {
 	/* All the following functions read memory pointed to by
@@ -1976,7 +1976,7 @@
      escape points.  See tree-ssa-structalias.c:find_func_aliases
      for the list of builtins we might need to handle here.  */
   if (callee != NULL_TREE
-      && DECL_BUILT_IN_CLASS (callee) == BUILT_IN_NORMAL)
+      && gimple_call_builtin_p (call, BUILT_IN_NORMAL))
     switch (DECL_FUNCTION_CODE (callee))
       {
 	/* All the following functions clobber memory pointed to by
@@ -2376,7 +2376,7 @@
     {
       tree callee = gimple_call_fndecl (stmt);
       if (callee != NULL_TREE
-	  && DECL_BUILT_IN_CLASS (callee) == BUILT_IN_NORMAL)
+	  && gimple_call_builtin_p (stmt, BUILT_IN_NORMAL))
 	switch (DECL_FUNCTION_CODE (callee))
 	  {
 	  case BUILT_IN_FREE:
Index: gcc/gimple-low.c
===================================================================
--- gcc/gimple-low.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/gimple-low.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -361,7 +361,8 @@
 		return;
 	      }
 	    else if (DECL_FUNCTION_CODE (decl) == BUILT_IN_POSIX_MEMALIGN
-		     && flag_tree_bit_ccp)
+		     && flag_tree_bit_ccp
+		     && gimple_builtin_call_types_compatible_p (stmt, decl))
 	      {
 		lower_builtin_posix_memalign (gsi);
 		return;
Index: gcc/lra-lives.c
===================================================================
--- gcc/lra-lives.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/lra-lives.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -759,7 +759,7 @@
 		    {
 		      insn = lra_insn_recog_data[uid]->insn;
 		      lra_substitute_pseudo_within_insn (insn, dst_regno,
-							 SET_SRC (set));
+							 SET_SRC (set), true);
 		      lra_update_insn_regno_info (insn);
 		    }
 		}
Index: gcc/tsan.c
===================================================================
--- gcc/tsan.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/tsan.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -535,7 +535,7 @@
 	  case fetch_op:
 	    last_arg = gimple_call_arg (stmt, num - 1);
 	    if (!tree_fits_uhwi_p (last_arg)
-		|| tree_to_uhwi (last_arg) > MEMMODEL_SEQ_CST)
+		|| memmodel_base (tree_to_uhwi (last_arg)) >= MEMMODEL_LAST)
 	      return;
 	    gimple_call_set_fndecl (stmt, decl);
 	    update_stmt (stmt);
@@ -600,10 +600,10 @@
 	    for (j = 0; j < 6; j++)
 	      args[j] = gimple_call_arg (stmt, j);
 	    if (!tree_fits_uhwi_p (args[4])
-		|| tree_to_uhwi (args[4]) > MEMMODEL_SEQ_CST)
+		|| memmodel_base (tree_to_uhwi (args[4])) >= MEMMODEL_LAST)
 	      return;
 	    if (!tree_fits_uhwi_p (args[5])
-		|| tree_to_uhwi (args[5]) > MEMMODEL_SEQ_CST)
+		|| memmodel_base (tree_to_uhwi (args[5])) >= MEMMODEL_LAST)
 	      return;
 	    update_gimple_call (gsi, decl, 5, args[0], args[1], args[2],
 				args[4], args[5]);
Index: gcc/fortran/trans-expr.c
===================================================================
--- gcc/fortran/trans-expr.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/fortran/trans-expr.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -5698,18 +5698,18 @@
   vec_safe_reserve (retargs, arglen);
 
   /* Add the return arguments.  */
-  retargs->splice (arglist);
+  vec_safe_splice (retargs, arglist);
 
   /* Add the hidden present status for optional+value to the arguments.  */
-  retargs->splice (optionalargs);
+  vec_safe_splice (retargs, optionalargs);
 
   /* Add the hidden string length parameters to the arguments.  */
-  retargs->splice (stringargs);
+  vec_safe_splice (retargs, stringargs);
 
   /* We may want to append extra arguments here.  This is used e.g. for
      calls to libgfortran_matmul_??, which need extra information.  */
-  if (!vec_safe_is_empty (append_args))
-    retargs->splice (append_args);
+  vec_safe_splice (retargs, append_args);
+
   arglist = retargs;
 
   /* Generate the actual call.  */
@@ -6732,6 +6732,29 @@
 				       TREE_TYPE (tmp), tmp,
 				       fold_convert (TREE_TYPE (tmp), size));
     }
+  else if (cm->ts.type == BT_CLASS)
+    {
+      gcc_assert (expr2->ts.type == BT_CLASS || expr2->ts.type == BT_DERIVED);
+      if (expr2->ts.type == BT_DERIVED)
+	{
+	  tmp = gfc_get_symbol_decl (expr2->ts.u.derived);
+	  size = TYPE_SIZE_UNIT (tmp);
+	}
+      else
+	{
+	  gfc_expr *e2vtab;
+	  gfc_se se;
+	  e2vtab = gfc_find_and_cut_at_last_class_ref (expr2);
+	  gfc_add_vptr_component (e2vtab);
+	  gfc_add_size_component (e2vtab);
+	  gfc_init_se (&se, NULL);
+	  gfc_conv_expr (&se, e2vtab);
+	  gfc_add_block_to_block (block, &se.pre);
+	  size = fold_convert (size_type_node, se.expr);
+	  gfc_free_expr (e2vtab);
+	}
+      size_in_bytes = size;
+    }
   else
     {
       /* Otherwise use the length in bytes of the rhs.  */
@@ -6859,7 +6882,8 @@
       gfc_add_expr_to_block (&block, tmp);
     }
   else if (init && (cm->attr.allocatable
-	   || (cm->ts.type == BT_CLASS && CLASS_DATA (cm)->attr.allocatable)))
+	   || (cm->ts.type == BT_CLASS && CLASS_DATA (cm)->attr.allocatable
+	       && expr->ts.type != BT_CLASS)))
     {
       /* Take care about non-array allocatable components here.  The alloc_*
 	 routine below is motivated by the alloc_scalar_allocatable_for_
@@ -8984,7 +9008,7 @@
   if (scalar_to_array && dealloc)
     {
       tmp = gfc_deallocate_alloc_comp_no_caf (expr2->ts.u.derived, rse.expr, 0);
-      gfc_add_expr_to_block (&loop.post, tmp);
+      gfc_prepend_expr_to_block (&loop.post, tmp);
     }
 
   /* When assigning a character function result to a deferred-length variable,
Index: gcc/fortran/trans-array.c
===================================================================
--- gcc/fortran/trans-array.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/fortran/trans-array.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -8972,7 +8972,11 @@
     return NULL;
 
   /* Normal procedure case.  */
-  sym = procedure_ref->symtree->n.sym;
+  if (procedure_ref->expr_type == EXPR_FUNCTION
+      && procedure_ref->value.function.esym)
+    sym = procedure_ref->value.function.esym;
+  else
+    sym = procedure_ref->symtree->n.sym;
 
   /* Typebound procedure case.  */
   for (ref = procedure_ref->ref; ref; ref = ref->next)
Index: gcc/fortran/class.c
===================================================================
--- gcc/fortran/class.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/fortran/class.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1599,6 +1599,7 @@
   final->ts.type = BT_INTEGER;
   final->ts.kind = 4;
   final->attr.artificial = 1;
+  final->attr.always_explicit = 1;
   final->attr.if_source = expr_null_wrapper ? IFSRC_IFBODY : IFSRC_DECL;
   if (ns->proc_name->attr.flavor == FL_MODULE)
     final->module = ns->proc_name->name;
Index: gcc/fortran/error.c
===================================================================
--- gcc/fortran/error.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/fortran/error.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -804,6 +804,9 @@
   pp->buffer = this_buffer;
   pp_clear_output_area (pp);
   pp->buffer = tmp_buffer;
+  /* We need to reset last_location, otherwise we may skip caret lines
+     when we actually give a diagnostic.  */
+  global_dc->last_location = UNKNOWN_LOCATION;
 }
 
 
Index: gcc/fortran/ChangeLog
===================================================================
--- gcc/fortran/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/fortran/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,90 @@
+2015-09-10  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/67526
+	* expr.c (gfc_check_init_expr): Do not dereference a NULL pointer.
+
+2015-09-04  Manuel López-Ibáñez  <manu@gcc.gnu.org>
+
+	PR fortran/67429
+	* error.c (gfc_clear_pp_buffer): Reset last_location, otherwise
+	caret lines might be skipped when actually giving a diagnostic.
+
+2015-08-07  Mikael Morin  <mikael@gcc.gnu.org>
+
+	PR fortran/66929
+	* trans-array.c (gfc_get_proc_ifc_for_expr): Use esym as procedure
+	symbol if available.
+
+2015-08-05  Mikael Morin  <mikael@gcc.gnu.org>
+
+	PR fortran/64921
+	* class.c (generate_finalization_wrapper): Set finalization
+	procedure symbol's always_explicit attribute.
+
+2015-08-03  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/66942
+	* trans-expr.c (gfc_conv_procedure_call): Avoid NULL pointer reference
+
+2015-07-25  Mikael Morin  <mikael@gcc.gnu.org>
+
+	PR fortran/64986
+	* trans-expr.c (gfc_trans_assignment_1): Put component deallocation
+	code at the beginning of the block.
+
+2015-07-21  Andre Vehreschild  <vehre@gcc.gnu.org>
+
+	PR fortran/66035
+	* trans-expr.c (alloc_scalar_allocatable_for_subcomponent_assignment):
+	Compute the size to allocate for class and derived type objects
+	correclty.
+	(gfc_trans_subcomponent_assign): Only allocate memory for a
+	component when the object to assign is not an allocatable class
+	object (the memory is already present for allocatable class objects).
+	Furthermore use copy_class_to_class for assigning the rhs to the
+	component (may happen for dummy class objects on the rhs).
+
+2015-07-17  Alessandro Fanfarillo  <fanfarillo.gcc@gmail.com>
+
+	* trans-intrinsic.c (conv_co_collective): Remove redundant address
+	operator in the generated code.
+
+2015-07-16  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/66724
+	PR fortran/66724
+	* io.c (is_char_type): Call gfc_resolve_expr ().
+	(match_open_element, match_dt_element, match_inquire_element): Fix
+	ASYNCHRONOUS case.
+
+2015-07-16  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/66864
+	* simplify.c (gfc_simplify_floor): Set precision of temporary to
+	that of arg.
+
+2015-07-16  Steven G. Kargl   <kargl@gcc.gnu.org>
+
+	PR fortran/66545
+	* primary.c (match_sym_complex_part): Do not dereference NULL pointer.
+
+2015-07-16  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/56520
+	* match.c (gfc_match_name): Special case unary minus and plus.
+
+2015-07-16  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	* io.c (check_char_variable): New function.
+	(match_open_element, match_close_element, match_file_element,
+	match_dt_element, match_inquire_element, match_wait_element): Use it.
+
+2015-07-16  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/66725
+	* io.c (is_char_type): New function to test for BT_CHARACTER
+	(gfc_match_open, gfc_match_close, match_dt_element): Use it.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
@@ -94,7 +181,7 @@
 2015-05-19  Steven G. Kargl  <kargl@gcc.gnu.org>
 
 	PR fortran/66052
-	* decl.c(gfc_match_protected): Prevent dereference of NULL pointer. 
+	* decl.c(gfc_match_protected): Prevent dereference of NULL pointer.
 
 2015-05-19  Steven G. Kargl  <kargl@gcc.gnu.org>
 
@@ -106,7 +193,7 @@
 
 	PR fortran/66044
 	* decl.c(gfc_match_entry):  Change a gfc_internal_error() into
-	a gfc_error() 
+	a gfc_error()
 
 2015-05-19  Steven G. Kargl  <kargl@gcc.gnu.org>
 
Index: gcc/fortran/expr.c
===================================================================
--- gcc/fortran/expr.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/fortran/expr.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -2599,14 +2599,18 @@
       break;
 
     case EXPR_SUBSTRING:
-      t = gfc_check_init_expr (e->ref->u.ss.start);
-      if (!t)
-	break;
+      if (e->ref)
+	{
+	  t = gfc_check_init_expr (e->ref->u.ss.start);
+	  if (!t)
+	    break;
 
-      t = gfc_check_init_expr (e->ref->u.ss.end);
-      if (t)
-	t = gfc_simplify_expr (e, 0);
-
+	  t = gfc_check_init_expr (e->ref->u.ss.end);
+	  if (t)
+	    t = gfc_simplify_expr (e, 0);
+	}
+      else
+	t = false;
       break;
 
     case EXPR_STRUCTURE:
Index: gcc/fortran/io.c
===================================================================
--- gcc/fortran/io.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/fortran/io.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1181,7 +1181,7 @@
 }
 
 
-/************ Fortran 95 I/O statement matchers *************/
+/************ Fortran I/O statement matchers *************/
 
 /* Match a FORMAT statement.  This amounts to actually parsing the
    format descriptors in order to correctly locate the end of the
@@ -1242,6 +1242,36 @@
 }
 
 
+/* Check for a CHARACTER variable.  The check for scalar is done in
+   resolve_tag.  */
+
+static bool
+check_char_variable (gfc_expr *e)
+{
+  if (e->expr_type != EXPR_VARIABLE || e->ts.type != BT_CHARACTER)
+    {
+      gfc_error("IOMSG must be a scalar-default-char-variable at %L", &e->where);
+      return false;
+    }
+  return true;
+}
+
+
+static bool
+is_char_type (const char *name, gfc_expr *e)
+{
+  gfc_resolve_expr (e);
+
+  if (e->ts.type != BT_CHARACTER)
+    {
+      gfc_error ("%s requires a scalar-default-char-expr at %L",
+		   name, &e->where);
+      return false;
+    }
+  return true;
+}
+
+
 /* Match an expression I/O tag of some sort.  */
 
 static match
@@ -1552,12 +1582,16 @@
   match m;
 
   m = match_etag (&tag_e_async, &open->asynchronous);
+  if (m == MATCH_YES && !is_char_type ("ASYNCHRONOUS", open->asynchronous))
+    return MATCH_ERROR;
   if (m != MATCH_NO)
     return m;
   m = match_etag (&tag_unit, &open->unit);
   if (m != MATCH_NO)
     return m;
-  m = match_out_tag (&tag_iomsg, &open->iomsg);
+  m = match_etag (&tag_iomsg, &open->iomsg);
+  if (m == MATCH_YES && !check_char_variable (open->iomsg))
+    return MATCH_ERROR;
   if (m != MATCH_NO)
     return m;
   m = match_out_tag (&tag_iostat, &open->iostat);
@@ -1870,6 +1904,9 @@
       static const char *access_f2003[] = { "STREAM", NULL };
       static const char *access_gnu[] = { "APPEND", NULL };
 
+      if (!is_char_type ("ACCESS", open->access))
+	goto cleanup;
+
       if (!compare_to_allowed_values ("ACCESS", access_f95, access_f2003,
 				      access_gnu,
 				      open->access->value.character.string,
@@ -1882,6 +1919,9 @@
     {
       static const char *action[] = { "READ", "WRITE", "READWRITE", NULL };
 
+      if (!is_char_type ("ACTION", open->action))
+	goto cleanup;
+
       if (!compare_to_allowed_values ("ACTION", action, NULL, NULL,
 				      open->action->value.character.string,
 				      "OPEN", warn))
@@ -1895,6 +1935,9 @@
 			   "not allowed in Fortran 95"))
 	goto cleanup;
 
+      if (!is_char_type ("ASYNCHRONOUS", open->asynchronous))
+	goto cleanup;
+
       if (open->asynchronous->expr_type == EXPR_CONSTANT)
 	{
 	  static const char * asynchronous[] = { "YES", "NO", NULL };
@@ -1913,6 +1956,9 @@
 			   "not allowed in Fortran 95"))
 	goto cleanup;
 
+      if (!is_char_type ("BLANK", open->blank))
+	goto cleanup;
+
       if (open->blank->expr_type == EXPR_CONSTANT)
 	{
 	  static const char *blank[] = { "ZERO", "NULL", NULL };
@@ -1931,6 +1977,9 @@
 			   "not allowed in Fortran 95"))
 	goto cleanup;
 
+      if (!is_char_type ("DECIMAL", open->decimal))
+	goto cleanup;
+
       if (open->decimal->expr_type == EXPR_CONSTANT)
 	{
 	  static const char * decimal[] = { "COMMA", "POINT", NULL };
@@ -1949,6 +1998,9 @@
 	{
 	  static const char *delim[] = { "APOSTROPHE", "QUOTE", "NONE", NULL };
 
+	if (!is_char_type ("DELIM", open->delim))
+	  goto cleanup;
+
 	  if (!compare_to_allowed_values ("DELIM", delim, NULL, NULL,
 					  open->delim->value.character.string,
 					  "OPEN", warn))
@@ -1962,7 +2014,10 @@
       if (!gfc_notify_std (GFC_STD_F2003, "ENCODING= at %C "
 			   "not allowed in Fortran 95"))
 	goto cleanup;
-    
+
+      if (!is_char_type ("ENCODING", open->encoding))
+	goto cleanup;
+
       if (open->encoding->expr_type == EXPR_CONSTANT)
 	{
 	  static const char * encoding[] = { "DEFAULT", "UTF-8", NULL };
@@ -1979,6 +2034,9 @@
     {
       static const char *form[] = { "FORMATTED", "UNFORMATTED", NULL };
 
+      if (!is_char_type ("FORM", open->form))
+	goto cleanup;
+
       if (!compare_to_allowed_values ("FORM", form, NULL, NULL,
 				      open->form->value.character.string,
 				      "OPEN", warn))
@@ -1990,6 +2048,9 @@
     {
       static const char *pad[] = { "YES", "NO", NULL };
 
+      if (!is_char_type ("PAD", open->pad))
+	goto cleanup;
+
       if (!compare_to_allowed_values ("PAD", pad, NULL, NULL,
 				      open->pad->value.character.string,
 				      "OPEN", warn))
@@ -2001,6 +2062,9 @@
     {
       static const char *position[] = { "ASIS", "REWIND", "APPEND", NULL };
 
+      if (!is_char_type ("POSITION", open->position))
+	goto cleanup;
+
       if (!compare_to_allowed_values ("POSITION", position, NULL, NULL,
 				      open->position->value.character.string,
 				      "OPEN", warn))
@@ -2014,6 +2078,9 @@
 			   "not allowed in Fortran 95"))
       goto cleanup;
 
+      if (!is_char_type ("ROUND", open->round))
+	goto cleanup;
+
       if (open->round->expr_type == EXPR_CONSTANT)
 	{
 	  static const char * round[] = { "UP", "DOWN", "ZERO", "NEAREST",
@@ -2034,6 +2101,9 @@
 			   "not allowed in Fortran 95"))
 	goto cleanup;
 
+      if (!is_char_type ("SIGN", open->sign))
+	goto cleanup;
+
       if (open->sign->expr_type == EXPR_CONSTANT)
 	{
 	  static const char * sign[] = { "PLUS", "SUPPRESS", "PROCESSOR_DEFINED",
@@ -2071,6 +2141,9 @@
       static const char *status[] = { "OLD", "NEW", "SCRATCH",
 	"REPLACE", "UNKNOWN", NULL };
 
+      if (!is_char_type ("STATUS", open->status))
+	goto cleanup;
+
       if (!compare_to_allowed_values ("STATUS", status, NULL, NULL,
 				      open->status->value.character.string,
 				      "OPEN", warn))
@@ -2182,7 +2255,9 @@
   m = match_etag (&tag_status, &close->status);
   if (m != MATCH_NO)
     return m;
-  m = match_out_tag (&tag_iomsg, &close->iomsg);
+  m = match_etag (&tag_iomsg, &close->iomsg);
+  if (m == MATCH_YES && !check_char_variable (close->iomsg))
+    return MATCH_ERROR;
   if (m != MATCH_NO)
     return m;
   m = match_out_tag (&tag_iostat, &close->iostat);
@@ -2256,6 +2331,9 @@
     {
       static const char *status[] = { "KEEP", "DELETE", NULL };
 
+      if (!is_char_type ("STATUS", close->status))
+	goto cleanup;
+
       if (!compare_to_allowed_values ("STATUS", status, NULL, NULL,
 				      close->status->value.character.string,
 				      "CLOSE", warn))
@@ -2340,7 +2418,9 @@
   m = match_etag (&tag_unit, &fp->unit);
   if (m != MATCH_NO)
     return m;
-  m = match_out_tag (&tag_iomsg, &fp->iomsg);
+  m = match_etag (&tag_iomsg, &fp->iomsg);
+  if (m == MATCH_YES && !check_char_variable (fp->iomsg))
+    return MATCH_ERROR;
   if (m != MATCH_NO)
     return m;
   m = match_out_tag (&tag_iostat, &fp->iostat);
@@ -2676,6 +2756,8 @@
     }
 
   m = match_etag (&tag_e_async, &dt->asynchronous);
+  if (m == MATCH_YES && !is_char_type ("ASYNCHRONOUS", dt->asynchronous))
+    return MATCH_ERROR;
   if (m != MATCH_NO)
     return m;
   m = match_etag (&tag_e_blank, &dt->blank);
@@ -2705,9 +2787,12 @@
   m = match_etag (&tag_spos, &dt->pos);
   if (m != MATCH_NO)
     return m;
-  m = match_out_tag (&tag_iomsg, &dt->iomsg);
+  m = match_etag (&tag_iomsg, &dt->iomsg);
+  if (m == MATCH_YES && !check_char_variable (dt->iomsg))
+    return MATCH_ERROR;
   if (m != MATCH_NO)
     return m;
+
   m = match_out_tag (&tag_iostat, &dt->iostat);
   if (m != MATCH_NO)
     return m;
@@ -3305,6 +3390,9 @@
 	  return MATCH_ERROR;
 	}
 
+      if (!is_char_type ("ASYNCHRONOUS", dt->asynchronous))
+	return MATCH_ERROR;
+
       if (!compare_to_allowed_values
 		("ASYNCHRONOUS", asynchronous, NULL, NULL,
 		 dt->asynchronous->value.character.string,
@@ -3334,6 +3422,9 @@
 	{
 	  static const char * decimal[] = { "COMMA", "POINT", NULL };
 
+      if (!is_char_type ("DECIMAL", dt->decimal))
+	return MATCH_ERROR;
+
 	  if (!compare_to_allowed_values ("DECIMAL", decimal, NULL, NULL,
 					  dt->decimal->value.character.string,
 					  io_kind_name (k), warn))
@@ -3351,10 +3442,14 @@
 			   "not allowed in Fortran 95"))
 	return MATCH_ERROR;
 
+      if (!is_char_type ("BLANK", dt->blank))
+	return MATCH_ERROR;
+
       if (dt->blank->expr_type == EXPR_CONSTANT)
 	{
 	  static const char * blank[] = { "NULL", "ZERO", NULL };
 
+
 	  if (!compare_to_allowed_values ("BLANK", blank, NULL, NULL,
 					  dt->blank->value.character.string,
 					  io_kind_name (k), warn))
@@ -3372,6 +3467,9 @@
 			   "not allowed in Fortran 95"))
 	return MATCH_ERROR;
 
+      if (!is_char_type ("PAD", dt->pad))
+	return MATCH_ERROR;
+
       if (dt->pad->expr_type == EXPR_CONSTANT)
 	{
 	  static const char * pad[] = { "YES", "NO", NULL };
@@ -3393,6 +3491,9 @@
 			   "not allowed in Fortran 95"))
 	return MATCH_ERROR;
 
+      if (!is_char_type ("ROUND", dt->round))
+	return MATCH_ERROR;
+
       if (dt->round->expr_type == EXPR_CONSTANT)
 	{
 	  static const char * round[] = { "UP", "DOWN", "ZERO", "NEAREST",
@@ -3412,6 +3513,10 @@
       if (gfc_notify_std (GFC_STD_F2003, "SIGN= at %C "
 	  "not allowed in Fortran 95") == false)
 	return MATCH_ERROR;  */
+
+      if (!is_char_type ("SIGN", dt->sign))
+	return MATCH_ERROR;
+
       if (dt->sign->expr_type == EXPR_CONSTANT)
 	{
 	  static const char * sign[] = { "PLUS", "SUPPRESS", "PROCESSOR_DEFINED",
@@ -3438,6 +3543,9 @@
 			   "not allowed in Fortran 95"))
 	return MATCH_ERROR;
 
+      if (!is_char_type ("DELIM", dt->delim))
+	return MATCH_ERROR;
+
       if (dt->delim->expr_type == EXPR_CONSTANT)
 	{
 	  static const char *delim[] = { "APOSTROPHE", "QUOTE", "NONE", NULL };
@@ -3860,7 +3968,9 @@
   m = match_etag (&tag_unit, &inquire->unit);
   RETM m = match_etag (&tag_file, &inquire->file);
   RETM m = match_ltag (&tag_err, &inquire->err);
-  RETM m = match_out_tag (&tag_iomsg, &inquire->iomsg);
+  RETM m = match_etag (&tag_iomsg, &inquire->iomsg);
+  if (m == MATCH_YES && !check_char_variable (inquire->iomsg))
+    return MATCH_ERROR;
   RETM m = match_out_tag (&tag_iostat, &inquire->iostat);
   RETM m = match_vtag (&tag_exist, &inquire->exist);
   RETM m = match_vtag (&tag_opened, &inquire->opened);
@@ -3882,6 +3992,8 @@
   RETM m = match_vtag (&tag_write, &inquire->write);
   RETM m = match_vtag (&tag_readwrite, &inquire->readwrite);
   RETM m = match_vtag (&tag_s_async, &inquire->asynchronous);
+  if (m == MATCH_YES && !is_char_type ("ASYNCHRONOUS", inquire->asynchronous))
+    return MATCH_ERROR;
   RETM m = match_vtag (&tag_s_delim, &inquire->delim);
   RETM m = match_vtag (&tag_s_decimal, &inquire->decimal);
   RETM m = match_out_tag (&tag_size, &inquire->size);
@@ -4143,7 +4255,9 @@
   RETM m = match_ltag (&tag_err, &wait->err);
   RETM m = match_ltag (&tag_end, &wait->eor);
   RETM m = match_ltag (&tag_eor, &wait->end);
-  RETM m = match_out_tag (&tag_iomsg, &wait->iomsg);
+  RETM m = match_etag (&tag_iomsg, &wait->iomsg);
+  if (m == MATCH_YES && !check_char_variable (wait->iomsg))
+    return MATCH_ERROR;
   RETM m = match_out_tag (&tag_iostat, &wait->iostat);
   RETM m = match_etag (&tag_id, &wait->id);
   RETM return MATCH_NO;
Index: gcc/fortran/match.c
===================================================================
--- gcc/fortran/match.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/fortran/match.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -544,7 +544,10 @@
   c = gfc_next_ascii_char ();
   if (!(ISALPHA (c) || (c == '_' && flag_allow_leading_underscore)))
     {
-      if (!gfc_error_flag_test () && c != '(')
+      /* Special cases for unary minus and plus, which allows for a sensible
+	 error message for code of the form 'c = exp(-a*b) )' where an
+	 extra ')' appears at the end of statement.  */
+      if (!gfc_error_flag_test () && c != '(' && c != '-' && c != '+')
 	gfc_error ("Invalid character in name at %C");
       gfc_current_locus = old_loc;
       return MATCH_NO;
Index: gcc/fortran/primary.c
===================================================================
--- gcc/fortran/primary.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/fortran/primary.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1202,6 +1202,9 @@
       return MATCH_ERROR;
     }
 
+  if (!sym->value)
+    goto error;
+
   if (!gfc_numeric_ts (&sym->value->ts))
     {
       gfc_error ("Numeric PARAMETER required in complex constant at %C");
Index: gcc/fortran/trans-intrinsic.c
===================================================================
--- gcc/fortran/trans-intrinsic.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/fortran/trans-intrinsic.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -8801,7 +8801,7 @@
 	}
       opr_flags = build_int_cst (integer_type_node, opr_flag_int);
       gfc_conv_expr (&argse, opr_expr);
-      opr = gfc_build_addr_expr (NULL_TREE, argse.expr);
+      opr = argse.expr;
       fndecl = build_call_expr_loc (input_location, fndecl, 8, array, opr, opr_flags,
 				    image_index, stat, errmsg, strlen, errmsg_len);
     }
Index: gcc/fortran/simplify.c
===================================================================
--- gcc/fortran/simplify.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/fortran/simplify.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -2352,9 +2352,7 @@
   if (e->expr_type != EXPR_CONSTANT)
     return NULL;
 
-  gfc_set_model_kind (kind);
-
-  mpfr_init (floor);
+  mpfr_init2 (floor, mpfr_get_prec (e->value.real));
   mpfr_floor (floor, e->value.real);
 
   result = gfc_get_constant_expr (BT_INTEGER, kind, &e->where);
Index: gcc/ipa-devirt.c
===================================================================
--- gcc/ipa-devirt.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/ipa-devirt.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -483,7 +483,7 @@
 	return false;
       if (TREE_CODE (type1) == RECORD_TYPE
 	  && (TYPE_BINFO (type1) == NULL_TREE)
-	      != (TYPE_BINFO (type1) == NULL_TREE))
+	      != (TYPE_BINFO (type2) == NULL_TREE))
 	return false;
       if (TREE_CODE (type1) == RECORD_TYPE && TYPE_BINFO (type1)
 	  && (BINFO_VTABLE (TYPE_BINFO (type1)) == NULL_TREE)
Index: gcc/BASE-VER
===================================================================
--- gcc/BASE-VER	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/BASE-VER	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1 +1 @@
-5.2.0
+5.2.1
Index: gcc/function.c
===================================================================
--- gcc/function.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/function.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -3500,9 +3500,11 @@
 
 static void
 assign_bounds (vec<bounds_parm_data> &bndargs,
-	       struct assign_parm_data_all &all)
+	       struct assign_parm_data_all &all,
+	       bool assign_regs, bool assign_special,
+	       bool assign_bt)
 {
-  unsigned i, pass, handled = 0;
+  unsigned i, pass;
   bounds_parm_data *pbdata;
 
   if (!bndargs.exists ())
@@ -3516,17 +3518,20 @@
       {
 	/* Pass 0 => regs only.  */
 	if (pass == 0
-	    && (!pbdata->parm_data.entry_parm
-		|| GET_CODE (pbdata->parm_data.entry_parm) != REG))
+	    && (!assign_regs
+		||(!pbdata->parm_data.entry_parm
+		   || GET_CODE (pbdata->parm_data.entry_parm) != REG)))
 	  continue;
 	/* Pass 1 => slots only.  */
 	else if (pass == 1
-		 && (!pbdata->parm_data.entry_parm
-		     || GET_CODE (pbdata->parm_data.entry_parm) == REG))
+		 && (!assign_special
+		     || (!pbdata->parm_data.entry_parm
+			 || GET_CODE (pbdata->parm_data.entry_parm) == REG)))
 	  continue;
 	/* Pass 2 => BT only.  */
 	else if (pass == 2
-		 && pbdata->parm_data.entry_parm)
+		 && (!assign_bt
+		     || pbdata->parm_data.entry_parm))
 	  continue;
 
 	if (!pbdata->parm_data.entry_parm
@@ -3547,14 +3552,7 @@
 	else
 	  assign_parm_setup_stack (&all, pbdata->bounds_parm,
 				   &pbdata->parm_data);
-
-	/* Count handled bounds to make sure we miss nothing.  */
-	handled++;
       }
-
-  gcc_assert (handled == bndargs.length ());
-
-  bndargs.release ();
 }
 
 /* Assign RTL expressions to the function's parameters.  This may involve
@@ -3679,12 +3677,14 @@
 	      /* We expect this is the last parm.  Otherwise it is wrong
 		 to assign bounds right now.  */
 	      gcc_assert (i == (fnargs.length () - 1));
-	      assign_bounds (bndargs, all);
+	      assign_bounds (bndargs, all, true, false, false);
 	      targetm.calls.setup_incoming_vararg_bounds (all.args_so_far,
 							  data.promoted_mode,
 							  data.passed_type,
 							  &pretend_bytes,
 							  false);
+	      assign_bounds (bndargs, all, false, true, true);
+	      bndargs.release ();
 	    }
 	}
 
@@ -3696,7 +3696,8 @@
 	bound_no++;
     }
 
-  assign_bounds (bndargs, all);
+  assign_bounds (bndargs, all, true, true, true);
+  bndargs.release ();
 
   if (targetm.calls.split_complex_arg)
     assign_parms_unsplit_complex (&all, fnargs);
@@ -5193,8 +5194,8 @@
 void
 diddle_return_value (void (*doit) (rtx, void *), void *arg)
 {
+  diddle_return_value_1 (doit, arg, crtl->return_bnd);
   diddle_return_value_1 (doit, arg, crtl->return_rtx);
-  diddle_return_value_1 (doit, arg, crtl->return_bnd);
 }
 
 static void
Index: gcc/stor-layout.c
===================================================================
--- gcc/stor-layout.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/stor-layout.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1831,9 +1831,13 @@
 	{
 	  TYPE_SIZE (variant) = size;
 	  TYPE_SIZE_UNIT (variant) = size_unit;
-	  TYPE_ALIGN (variant) = align;
+	  unsigned valign = align;
+	  if (TYPE_USER_ALIGN (variant))
+	    valign = MAX (valign, TYPE_ALIGN (variant));
+	  else
+	    TYPE_USER_ALIGN (variant) = user_align;
+	  TYPE_ALIGN (variant) = valign;
 	  TYPE_PRECISION (variant) = precision;
-	  TYPE_USER_ALIGN (variant) = user_align;
 	  SET_TYPE_MODE (variant, mode);
 	}
     }
@@ -2154,6 +2158,10 @@
   if (type == error_mark_node)
     return;
 
+  /* We don't want finalize_type_size to copy an alignment attribute to
+     variants that don't have it.  */
+  type = TYPE_MAIN_VARIANT (type);
+
   /* Do nothing if type has been laid out before.  */
   if (TYPE_SIZE (type))
     return;
@@ -2350,13 +2358,17 @@
 	/* Now round the alignment and size,
 	   using machine-dependent criteria if any.  */
 
+	unsigned align = TYPE_ALIGN (element);
+	if (TYPE_USER_ALIGN (type))
+	  align = MAX (align, TYPE_ALIGN (type));
+	else
+	  TYPE_USER_ALIGN (type) = TYPE_USER_ALIGN (element);
 #ifdef ROUND_TYPE_ALIGN
-	TYPE_ALIGN (type)
-	  = ROUND_TYPE_ALIGN (type, TYPE_ALIGN (element), BITS_PER_UNIT);
+	align = ROUND_TYPE_ALIGN (type, align, BITS_PER_UNIT);
 #else
-	TYPE_ALIGN (type) = MAX (TYPE_ALIGN (element), BITS_PER_UNIT);
+	align = MAX (align, BITS_PER_UNIT);
 #endif
-	TYPE_USER_ALIGN (type) = TYPE_USER_ALIGN (element);
+	TYPE_ALIGN (type) = align;
 	SET_TYPE_MODE (type, BLKmode);
 	if (TYPE_SIZE (type) != 0
 	    && ! targetm.member_type_forces_blk (type, VOIDmode)
Index: gcc/genmatch.c
===================================================================
--- gcc/genmatch.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/genmatch.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1515,16 +1515,25 @@
 {
   if (capture *c = dyn_cast <capture *> (o))
     {
-      info[c->where].toplevel_msk |= 1 << toplevel_arg;
-      info[c->where].force_no_side_effects_p |= conditional_p;
-      info[c->where].cond_expr_cond_p |= cond_expr_cond_p;
-      /* Mark expr (non-leaf) captures and recurse.  */
+      unsigned where = c->where;
+      info[where].toplevel_msk |= 1 << toplevel_arg;
+      info[where].force_no_side_effects_p |= conditional_p;
+      info[where].cond_expr_cond_p |= cond_expr_cond_p;
+      if (!c->what)
+	return;
+      /* Recurse to exprs and captures.  */
+      if (is_a <capture *> (c->what)
+	  || is_a <expr *> (c->what))
+	walk_match (c->what, toplevel_arg, conditional_p, false);
+      /* We need to look past multiple captures to find a captured
+	 expression as with conditional converts two captures
+	 can be collapsed onto the same expression.  */
+      while (c->what && is_a <capture *> (c->what))
+	c = as_a <capture *> (c->what);
+      /* Mark expr (non-leaf) captures.  */
       if (c->what
 	  && is_a <expr *> (c->what))
-	{
-	  info[c->where].expr_p = true;
-	  walk_match (c->what, toplevel_arg, conditional_p, false);
-	}
+	info[where].expr_p = true;
     }
   else if (expr *e = dyn_cast <expr *> (o))
     {
Index: gcc/ipa-inline-analysis.c
===================================================================
--- gcc/ipa-inline-analysis.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/ipa-inline-analysis.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1602,7 +1602,7 @@
    loaded.  */
 
 static bool
-unmodified_parm_or_parm_agg_item (struct ipa_node_params *info,
+unmodified_parm_or_parm_agg_item (struct ipa_func_body_info *fbi,
 				  gimple stmt, tree op, int *index_p,
 				  struct agg_position_info *aggpos)
 {
@@ -1611,7 +1611,7 @@
   gcc_checking_assert (aggpos);
   if (res)
     {
-      *index_p = ipa_get_param_decl_index (info, res);
+      *index_p = ipa_get_param_decl_index (fbi->info, res);
       if (*index_p < 0)
 	return false;
       aggpos->agg_contents = false;
@@ -1627,13 +1627,14 @@
       stmt = SSA_NAME_DEF_STMT (op);
       op = gimple_assign_rhs1 (stmt);
       if (!REFERENCE_CLASS_P (op))
-	return unmodified_parm_or_parm_agg_item (info, stmt, op, index_p,
+	return unmodified_parm_or_parm_agg_item (fbi, stmt, op, index_p,
 						 aggpos);
     }
 
   aggpos->agg_contents = true;
-  return ipa_load_from_parm_agg (info, stmt, op, index_p, &aggpos->offset,
-				 &aggpos->by_ref);
+  return ipa_load_from_parm_agg (fbi, fbi->info->descriptors,
+				 stmt, op, index_p, &aggpos->offset,
+				 NULL, &aggpos->by_ref);
 }
 
 /* See if statement might disappear after inlining.
@@ -1772,7 +1773,7 @@
    predicates to the CFG edges.   */
 
 static void
-set_cond_stmt_execution_predicate (struct ipa_node_params *info,
+set_cond_stmt_execution_predicate (struct ipa_func_body_info *fbi,
 				   struct inline_summary *summary,
 				   basic_block bb)
 {
@@ -1795,7 +1796,7 @@
   /* TODO: handle conditionals like
      var = op0 < 4;
      if (var != 0).  */
-  if (unmodified_parm_or_parm_agg_item (info, last, op, &index, &aggpos))
+  if (unmodified_parm_or_parm_agg_item (fbi, last, op, &index, &aggpos))
     {
       code = gimple_cond_code (last);
       inverted_code = invert_tree_comparison (code, HONOR_NANS (op));
@@ -1838,8 +1839,7 @@
       || gimple_call_num_args (set_stmt) != 1)
     return;
   op2 = gimple_call_arg (set_stmt, 0);
-  if (!unmodified_parm_or_parm_agg_item
-      (info, set_stmt, op2, &index, &aggpos))
+  if (!unmodified_parm_or_parm_agg_item (fbi, set_stmt, op2, &index, &aggpos))
     return;
   FOR_EACH_EDGE (e, ei, bb->succs) if (e->flags & EDGE_FALSE_VALUE)
     {
@@ -1855,7 +1855,7 @@
    predicates to the CFG edges.   */
 
 static void
-set_switch_stmt_execution_predicate (struct ipa_node_params *info,
+set_switch_stmt_execution_predicate (struct ipa_func_body_info *fbi,
 				     struct inline_summary *summary,
 				     basic_block bb)
 {
@@ -1873,7 +1873,7 @@
     return;
   gswitch *last = as_a <gswitch *> (lastg);
   op = gimple_switch_index (last);
-  if (!unmodified_parm_or_parm_agg_item (info, last, op, &index, &aggpos))
+  if (!unmodified_parm_or_parm_agg_item (fbi, last, op, &index, &aggpos))
     return;
 
   FOR_EACH_EDGE (e, ei, bb->succs)
@@ -1916,8 +1916,8 @@
    which it is executable.  */
 
 static void
-compute_bb_predicates (struct cgraph_node *node,
-		       struct ipa_node_params *parms_info,
+compute_bb_predicates (struct ipa_func_body_info *fbi,
+		       struct cgraph_node *node,
 		       struct inline_summary *summary)
 {
   struct function *my_function = DECL_STRUCT_FUNCTION (node->decl);
@@ -1926,8 +1926,8 @@
 
   FOR_EACH_BB_FN (bb, my_function)
     {
-      set_cond_stmt_execution_predicate (parms_info, summary, bb);
-      set_switch_stmt_execution_predicate (parms_info, summary, bb);
+      set_cond_stmt_execution_predicate (fbi, summary, bb);
+      set_switch_stmt_execution_predicate (fbi, summary, bb);
     }
 
   /* Entry block is always executable.  */
@@ -2059,7 +2059,7 @@
    a compile time constant.  */
 
 static struct predicate
-will_be_nonconstant_predicate (struct ipa_node_params *info,
+will_be_nonconstant_predicate (struct ipa_func_body_info *fbi,
 			       struct inline_summary *summary,
 			       gimple stmt,
 			       vec<predicate_t> nonconstant_names)
@@ -2093,7 +2093,7 @@
       tree op;
       gcc_assert (gimple_assign_single_p (stmt));
       op = gimple_assign_rhs1 (stmt);
-      if (!unmodified_parm_or_parm_agg_item (info, stmt, op, &base_index,
+      if (!unmodified_parm_or_parm_agg_item (fbi, stmt, op, &base_index,
 					     &aggpos))
 	return p;
     }
@@ -2106,7 +2106,7 @@
     {
       tree parm = unmodified_parm (stmt, use);
       /* For arguments we can build a condition.  */
-      if (parm && ipa_get_param_decl_index (info, parm) >= 0)
+      if (parm && ipa_get_param_decl_index (fbi->info, parm) >= 0)
 	continue;
       if (TREE_CODE (use) != SSA_NAME)
 	return p;
@@ -2127,7 +2127,7 @@
       tree parm = unmodified_parm (stmt, use);
       int index;
 
-      if (parm && (index = ipa_get_param_decl_index (info, parm)) >= 0)
+      if (parm && (index = ipa_get_param_decl_index (fbi->info, parm)) >= 0)
 	{
 	  if (index != base_index)
 	    p = add_condition (summary, index, NULL, CHANGED, NULL_TREE);
@@ -2509,7 +2509,7 @@
   int freq;
   struct inline_summary *info = inline_summaries->get (node);
   struct predicate bb_predicate;
-  struct ipa_node_params *parms_info = NULL;
+  struct ipa_func_body_info fbi;
   vec<predicate_t> nonconstant_names = vNULL;
   int nblocks, n;
   int *order;
@@ -2516,6 +2516,10 @@
   predicate array_index = true_predicate ();
   gimple fix_builtin_expect_stmt;
 
+  gcc_assert (my_function && my_function->cfg);
+  gcc_assert (cfun == my_function);
+
+  memset(&fbi, 0, sizeof(fbi));
   info->conds = NULL;
   info->entry = NULL;
 
@@ -2538,7 +2542,11 @@
 
       if (ipa_node_params_sum)
 	{
-	  parms_info = IPA_NODE_REF (node);
+	  fbi.node = node;
+	  fbi.info = IPA_NODE_REF (node);
+	  fbi.bb_infos = vNULL;
+	  fbi.bb_infos.safe_grow_cleared (last_basic_block_for_fn (cfun));
+	  fbi.param_count = count_formal_params(node->decl);
 	  nonconstant_names.safe_grow_cleared
 	    (SSANAMES (my_function)->length ());
 	}
@@ -2556,10 +2564,8 @@
   bb_predicate = not_inlined_predicate ();
   account_size_time (info, 2 * INLINE_SIZE_SCALE, 0, &bb_predicate);
 
-  gcc_assert (my_function && my_function->cfg);
-  if (parms_info)
-    compute_bb_predicates (node, parms_info, info);
-  gcc_assert (cfun == my_function);
+  if (fbi.info)
+    compute_bb_predicates (&fbi, node, info);
   order = XNEWVEC (int, n_basic_blocks_for_fn (cfun));
   nblocks = pre_and_rev_post_order_compute (NULL, order, false);
   for (n = 0; n < nblocks; n++)
@@ -2576,7 +2582,7 @@
 	}
 
       /* TODO: Obviously predicates can be propagated down across CFG.  */
-      if (parms_info)
+      if (fbi.info)
 	{
 	  if (bb->aux)
 	    bb_predicate = *(struct predicate *) bb->aux;
@@ -2592,7 +2598,7 @@
 	  dump_predicate (dump_file, info->conds, &bb_predicate);
 	}
 
-      if (parms_info && nonconstant_names.exists ())
+      if (fbi.info && nonconstant_names.exists ())
 	{
 	  struct predicate phi_predicate;
 	  bool first_phi = true;
@@ -2601,7 +2607,7 @@
 	       gsi_next (&bsi))
 	    {
 	      if (first_phi
-		  && !phi_result_unknown_predicate (parms_info, info, bb,
+		  && !phi_result_unknown_predicate (fbi.info, info, bb,
 						    &phi_predicate,
 						    nonconstant_names))
 		break;
@@ -2710,9 +2716,9 @@
 	  /* TODO: When conditional jump or swithc is known to be constant, but
 	     we did not translate it into the predicates, we really can account
 	     just maximum of the possible paths.  */
-	  if (parms_info)
+	  if (fbi.info)
 	    will_be_nonconstant
-	      = will_be_nonconstant_predicate (parms_info, info,
+	      = will_be_nonconstant_predicate (&fbi, info,
 					       stmt, nonconstant_names);
 	  if (this_time || this_size)
 	    {
@@ -2727,7 +2733,7 @@
 	      if (prob == 2 && dump_file && (dump_flags & TDF_DETAILS))
 		fprintf (dump_file, "\t\tWill be eliminated by inlining\n");
 
-	      if (parms_info)
+	      if (fbi.info)
 		p = and_predicates (info->conds, &bb_predicate,
 				    &will_be_nonconstant);
 	      else
@@ -2795,7 +2801,7 @@
 		&& !is_gimple_min_invariant (niter_desc.niter))
 	    {
 	      predicate will_be_nonconstant
-		= will_be_nonconstant_expr_predicate (parms_info, info,
+		= will_be_nonconstant_expr_predicate (fbi.info, info,
 						      niter_desc.niter,
 						      nonconstant_names);
 	      if (!true_predicate_p (&will_be_nonconstant))
@@ -2833,7 +2839,7 @@
 			|| is_gimple_min_invariant (iv.step))
 		      continue;
 		    will_be_nonconstant
-		      = will_be_nonconstant_expr_predicate (parms_info, info,
+		      = will_be_nonconstant_expr_predicate (fbi.info, info,
 							    iv.step,
 							    nonconstant_names);
 		    if (!true_predicate_p (&will_be_nonconstant))
@@ -3133,6 +3139,9 @@
   struct cgraph_edge *e;
   for (e = node->callees; e; e = e->next_callee)
     {
+      if (inline_edge_summary_vec.length () <= (unsigned) e->uid)
+	continue;
+
       struct inline_edge_summary *es = inline_edge_summary (e);
 
       /* Do not care about zero sized builtins.  */
@@ -3164,6 +3173,9 @@
     }
   for (e = node->indirect_calls; e; e = e->next_callee)
     {
+      if (inline_edge_summary_vec.length () <= (unsigned) e->uid)
+	continue;
+
       struct inline_edge_summary *es = inline_edge_summary (e);
       if (!es->predicate
 	  || evaluate_predicate (es->predicate, possible_truths))
Index: gcc/gimplify.c
===================================================================
--- gcc/gimplify.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/gimplify.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -6195,9 +6195,12 @@
 		    }
 		  else
 		    break;
-		  gcc_checking_assert (splay_tree_lookup (octx->variables,
-							  (splay_tree_key)
-							  decl) == NULL);
+		  if (splay_tree_lookup (octx->variables,
+					 (splay_tree_key) decl) != NULL)
+		    {
+		      octx = NULL;
+		      break;
+		    }
 		  flags = GOVD_SEEN;
 		  if (!OMP_CLAUSE_LINEAR_NO_COPYIN (c))
 		    flags |= GOVD_FIRSTPRIVATE;
@@ -6979,7 +6982,7 @@
 static enum gimplify_status
 gimplify_omp_for (tree *expr_p, gimple_seq *pre_p)
 {
-  tree for_stmt, orig_for_stmt, decl, var, t;
+  tree for_stmt, orig_for_stmt, inner_for_stmt = NULL_TREE, decl, var, t;
   enum gimplify_status ret = GS_ALL_DONE;
   enum gimplify_status tret;
   gomp_for *gfor;
@@ -7022,6 +7025,19 @@
 	  }
     }
 
+  if (OMP_FOR_INIT (for_stmt) == NULL_TREE)
+    {
+      gcc_assert (TREE_CODE (for_stmt) != OACC_LOOP);
+      inner_for_stmt = walk_tree (&OMP_FOR_BODY (for_stmt),
+				  find_combined_omp_for, NULL, NULL);
+      if (inner_for_stmt == NULL_TREE)
+	{
+	  gcc_assert (seen_error ());
+	  *expr_p = NULL_TREE;
+	  return GS_ERROR;
+	}
+    }
+
   gimplify_scan_omp_clauses (&OMP_FOR_CLAUSES (for_stmt), pre_p,
 			     simd ? ORT_SIMD : ORT_WORKSHARE);
   if (TREE_CODE (for_stmt) == OMP_DISTRIBUTE)
@@ -7057,10 +7073,7 @@
 
   if (OMP_FOR_INIT (for_stmt) == NULL_TREE)
     {
-      gcc_assert (TREE_CODE (for_stmt) != OACC_LOOP);
-      for_stmt = walk_tree (&OMP_FOR_BODY (for_stmt), find_combined_omp_for,
-			    NULL, NULL);
-      gcc_assert (for_stmt != NULL_TREE);
+      for_stmt = inner_for_stmt;
       gimplify_omp_ctxp->combined_loop = true;
     }
 
@@ -7104,13 +7117,27 @@
 		  OMP_CLAUSE_LINEAR_NO_COPYOUT (c) = 1;
 		  flags |= GOVD_LINEAR_LASTPRIVATE_NO_OUTER;
 		}
+	      struct gimplify_omp_ctx *outer
+		= gimplify_omp_ctxp->outer_context;
+	      if (outer && !OMP_CLAUSE_LINEAR_NO_COPYOUT (c))
+		{
+		  if (outer->region_type == ORT_WORKSHARE
+		      && outer->combined_loop)
+		    {
+		      n = splay_tree_lookup (outer->variables,
+					     (splay_tree_key)decl);
+		      if (n != NULL && (n->value & GOVD_LOCAL) != 0)
+			{
+			  OMP_CLAUSE_LINEAR_NO_COPYOUT (c) = 1;
+			  flags |= GOVD_LINEAR_LASTPRIVATE_NO_OUTER;
+			}
+		    }
+		}
+
 	      OMP_CLAUSE_DECL (c) = decl;
 	      OMP_CLAUSE_CHAIN (c) = OMP_FOR_CLAUSES (for_stmt);
 	      OMP_FOR_CLAUSES (for_stmt) = c;
-	      
 	      omp_add_variable (gimplify_omp_ctxp, decl, flags);
-	      struct gimplify_omp_ctx *outer
-		= gimplify_omp_ctxp->outer_context;
 	      if (outer && !OMP_CLAUSE_LINEAR_NO_COPYOUT (c))
 		{
 		  if (outer->region_type == ORT_WORKSHARE
@@ -7127,10 +7154,16 @@
 		    outer = NULL;
 		  if (outer)
 		    {
-		      omp_add_variable (outer, decl,
-					GOVD_LASTPRIVATE | GOVD_SEEN);
-		      if (outer->outer_context)
-			omp_notice_variable (outer->outer_context, decl, true);
+		      n = splay_tree_lookup (outer->variables,
+					     (splay_tree_key)decl);
+		      if (n == NULL || (n->value & GOVD_DATA_SHARE_CLASS) == 0)
+			{
+			  omp_add_variable (outer, decl,
+					    GOVD_LASTPRIVATE | GOVD_SEEN);
+			  if (outer->outer_context)
+			    omp_notice_variable (outer->outer_context, decl,
+						 true);
+			}
 		    }
 		}
 	    }
@@ -7147,9 +7180,16 @@
 		  if (outer->region_type == ORT_WORKSHARE
 		      && outer->combined_loop)
 		    {
-		      if (outer->outer_context
-			  && (outer->outer_context->region_type
-			      == ORT_COMBINED_PARALLEL))
+		      n = splay_tree_lookup (outer->variables,
+					     (splay_tree_key)decl);
+		      if (n != NULL && (n->value & GOVD_LOCAL) != 0)
+			{
+			  lastprivate = false;
+			  outer = NULL;
+			}
+		      else if (outer->outer_context
+			       && (outer->outer_context->region_type
+				   == ORT_COMBINED_PARALLEL))
 			outer = outer->outer_context;
 		      else if (omp_check_private (outer, decl, false))
 			outer = NULL;
@@ -7158,10 +7198,16 @@
 		    outer = NULL;
 		  if (outer)
 		    {
-		      omp_add_variable (outer, decl,
-					GOVD_LASTPRIVATE | GOVD_SEEN);
-		      if (outer->outer_context)
-			omp_notice_variable (outer->outer_context, decl, true);
+		      n = splay_tree_lookup (outer->variables,
+					     (splay_tree_key)decl);
+		      if (n == NULL || (n->value & GOVD_DATA_SHARE_CLASS) == 0)
+			{
+			  omp_add_variable (outer, decl,
+					    GOVD_LASTPRIVATE | GOVD_SEEN);
+			  if (outer->outer_context)
+			    omp_notice_variable (outer->outer_context, decl,
+						 true);
+			}
 		    }
 		}
 
Index: gcc/coretypes.h
===================================================================
--- gcc/coretypes.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/coretypes.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -263,6 +263,18 @@
   function_c11_misc
 };
 
+/* Suppose that higher bits are target dependent. */
+#define MEMMODEL_MASK ((1<<16)-1)
+
+/* Legacy sync operations set this upper flag in the memory model.  This allows
+   targets that need to do something stronger for sync operations to
+   differentiate with their target patterns and issue a more appropriate insn
+   sequence.  See bugzilla 65697 for background.  */
+#define MEMMODEL_SYNC (1<<15)
+
+/* Memory model without SYNC bit for targets/operations that do not care.  */
+#define MEMMODEL_BASE_MASK (MEMMODEL_SYNC-1)
+
 /* Memory model types for the __atomic* builtins. 
    This must match the order in libstdc++-v3/include/bits/atomic_base.h.  */
 enum memmodel
@@ -273,12 +285,12 @@
   MEMMODEL_RELEASE = 3,
   MEMMODEL_ACQ_REL = 4,
   MEMMODEL_SEQ_CST = 5,
-  MEMMODEL_LAST = 6
+  MEMMODEL_LAST = 6,
+  MEMMODEL_SYNC_ACQUIRE = MEMMODEL_ACQUIRE | MEMMODEL_SYNC,
+  MEMMODEL_SYNC_RELEASE = MEMMODEL_RELEASE | MEMMODEL_SYNC,
+  MEMMODEL_SYNC_SEQ_CST = MEMMODEL_SEQ_CST | MEMMODEL_SYNC
 };
 
-/* Suppose that higher bits are target dependent. */
-#define MEMMODEL_MASK ((1<<16)-1)
-
 /* Support for user-provided GGC and PCH markers.  The first parameter
    is a pointer to a pointer, the second a cookie.  */
 typedef void (*gt_pointer_operator) (void *, void *);
Index: gcc/lra-constraints.c
===================================================================
--- gcc/lra-constraints.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/lra-constraints.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -4729,7 +4729,7 @@
 	}
       return false;
     }
-  lra_substitute_pseudo_within_insn (insn, original_regno, new_reg);
+  lra_substitute_pseudo_within_insn (insn, original_regno, new_reg, false);
   lra_update_insn_regno_info (insn);
   if (! def_p)
     /* We now have a new usage insn for original regno.  */
@@ -4761,7 +4761,7 @@
 	  lra_assert (DEBUG_INSN_P (usage_insn));
 	  next_usage_insns = XEXP (next_usage_insns, 1);
 	}
-      lra_substitute_pseudo (&usage_insn, original_regno, new_reg);
+      lra_substitute_pseudo (&usage_insn, original_regno, new_reg, false);
       lra_update_insn_regno_info (as_a <rtx_insn *> (usage_insn));
       if (lra_dump_file != NULL)
 	{
@@ -5023,7 +5023,7 @@
       usage_insn = XEXP (next_usage_insns, 0);
       lra_assert (DEBUG_INSN_P (usage_insn));
       next_usage_insns = XEXP (next_usage_insns, 1);
-      lra_substitute_pseudo (&usage_insn, original_regno, new_reg);
+      lra_substitute_pseudo (&usage_insn, original_regno, new_reg, false);
       lra_update_insn_regno_info (as_a <rtx_insn *> (usage_insn));
       if (lra_dump_file != NULL)
 	{
@@ -5955,8 +5955,9 @@
 		    {
 		      if (change_p && bitmap_bit_p (remove_pseudos, regno))
 			{
-			  lra_substitute_pseudo_within_insn (
-			    curr_insn, regno, regno_reg_rtx[restore_regno]);
+			  lra_substitute_pseudo_within_insn
+			    (curr_insn, regno, regno_reg_rtx[restore_regno],
+			     false);
 			  restored_regs_p = true;
 			}
 		      else
@@ -6079,9 +6080,9 @@
 		 we remove the inheritance pseudo and the optional
 		 reload.  */
 	    }
-	  lra_substitute_pseudo_within_insn (
-	    insn, regno,
-	    regno_reg_rtx[lra_reg_info[regno].restore_regno]);
+	  lra_substitute_pseudo_within_insn
+	    (insn, regno, regno_reg_rtx[lra_reg_info[regno].restore_regno],
+	     false);
 	  lra_update_insn_regno_info (insn);
 	  if (lra_dump_file != NULL)
 	    {
Index: gcc/calls.c
===================================================================
--- gcc/calls.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/calls.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -3115,6 +3115,19 @@
 
       compute_argument_addresses (args, argblock, num_actuals);
 
+      /* Stack is properly aligned, pops can't safely be deferred during
+	 the evaluation of the arguments.  */
+      NO_DEFER_POP;
+
+      /* Precompute all register parameters.  It isn't safe to compute
+	 anything once we have started filling any specific hard regs.
+	 TLS symbols sometimes need a call to resolve.  Precompute
+	 register parameters before any stack pointer manipulation
+	 to avoid unaligned stack in the called function.  */
+      precompute_register_parameters (num_actuals, args, &reg_parm_seen);
+
+      OK_DEFER_POP;
+
       /* Perform stack alignment before the first push (the last arg).  */
       if (argblock == 0
           && adjusted_args_size.constant > reg_parm_stack_space
@@ -3155,10 +3168,6 @@
 
       funexp = rtx_for_function_call (fndecl, addr);
 
-      /* Precompute all register parameters.  It isn't safe to compute anything
-	 once we have started filling any specific hard regs.  */
-      precompute_register_parameters (num_actuals, args, &reg_parm_seen);
-
       if (CALL_EXPR_STATIC_CHAIN (exp))
 	static_chain_value = expand_normal (CALL_EXPR_STATIC_CHAIN (exp));
       else
Index: gcc/emit-rtl.c
===================================================================
--- gcc/emit-rtl.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/emit-rtl.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -6323,11 +6323,14 @@
     case MEMMODEL_CONSUME:
       return false;
     case MEMMODEL_RELEASE:
+    case MEMMODEL_SYNC_RELEASE:
       return pre;
     case MEMMODEL_ACQUIRE:
+    case MEMMODEL_SYNC_ACQUIRE:
       return !pre;
     case MEMMODEL_ACQ_REL:
     case MEMMODEL_SEQ_CST:
+    case MEMMODEL_SYNC_SEQ_CST:
       return true;
     default:
       gcc_unreachable ();
Index: gcc/cfgexpand.c
===================================================================
--- gcc/cfgexpand.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/cfgexpand.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -3219,9 +3219,10 @@
   bounds_rtl = DECL_BOUNDS_RTL (DECL_RESULT (current_function_decl));
   if (bounds_rtl)
     {
-      rtx addr, bnd;
+      rtx addr = NULL;
+      rtx bnd = NULL;
 
-      if (bounds)
+      if (bounds && bounds != error_mark_node)
 	{
 	  bnd = expand_normal (bounds);
 	  targetm.calls.store_returned_bounds (bounds_rtl, bnd);
@@ -3228,9 +3229,15 @@
 	}
       else if (REG_P (bounds_rtl))
 	{
-	  addr = expand_normal (build_fold_addr_expr (retval_rhs));
-	  addr = gen_rtx_MEM (Pmode, addr);
-	  bnd = targetm.calls.load_bounds_for_arg (addr, NULL, NULL);
+	  if (bounds)
+	    bnd = chkp_expand_zero_bounds ();
+	  else
+	    {
+	      addr = expand_normal (build_fold_addr_expr (retval_rhs));
+	      addr = gen_rtx_MEM (Pmode, addr);
+	      bnd = targetm.calls.load_bounds_for_arg (addr, NULL, NULL);
+	    }
+
 	  targetm.calls.store_returned_bounds (bounds_rtl, bnd);
 	}
       else
@@ -3239,15 +3246,23 @@
 
 	  gcc_assert (GET_CODE (bounds_rtl) == PARALLEL);
 
-	  addr = expand_normal (build_fold_addr_expr (retval_rhs));
-	  addr = gen_rtx_MEM (Pmode, addr);
+	  if (bounds)
+	    bnd = chkp_expand_zero_bounds ();
+	  else
+	    {
+	      addr = expand_normal (build_fold_addr_expr (retval_rhs));
+	      addr = gen_rtx_MEM (Pmode, addr);
+	    }
 
 	  for (n = 0; n < XVECLEN (bounds_rtl, 0); n++)
 	    {
-	      rtx offs = XEXP (XVECEXP (bounds_rtl, 0, n), 1);
 	      rtx slot = XEXP (XVECEXP (bounds_rtl, 0, n), 0);
-	      rtx from = adjust_address (addr, Pmode, INTVAL (offs));
-	      rtx bnd = targetm.calls.load_bounds_for_arg (from, NULL, NULL);
+	      if (!bounds)
+		{
+		  rtx offs = XEXP (XVECEXP (bounds_rtl, 0, n), 1);
+		  rtx from = adjust_address (addr, Pmode, INTVAL (offs));
+		  bnd = targetm.calls.load_bounds_for_arg (from, NULL, NULL);
+		}
 	      targetm.calls.store_returned_bounds (slot, bnd);
 	    }
 	}
@@ -3344,33 +3359,40 @@
       break;
 
     case GIMPLE_RETURN:
-      op0 = gimple_return_retval (as_a <greturn *> (stmt));
+      {
+	tree bnd = gimple_return_retbnd (as_a <greturn *> (stmt));
+	op0 = gimple_return_retval (as_a <greturn *> (stmt));
 
-      if (op0 && op0 != error_mark_node)
-	{
-	  tree result = DECL_RESULT (current_function_decl);
+	if (op0 && op0 != error_mark_node)
+	  {
+	    tree result = DECL_RESULT (current_function_decl);
 
-	  /* If we are not returning the current function's RESULT_DECL,
-	     build an assignment to it.  */
-	  if (op0 != result)
-	    {
-	      /* I believe that a function's RESULT_DECL is unique.  */
-	      gcc_assert (TREE_CODE (op0) != RESULT_DECL);
+	    /* If we are not returning the current function's RESULT_DECL,
+	       build an assignment to it.  */
+	    if (op0 != result)
+	      {
+		/* I believe that a function's RESULT_DECL is unique.  */
+		gcc_assert (TREE_CODE (op0) != RESULT_DECL);
 
-	      /* ??? We'd like to use simply expand_assignment here,
-	         but this fails if the value is of BLKmode but the return
-		 decl is a register.  expand_return has special handling
-		 for this combination, which eventually should move
-		 to common code.  See comments there.  Until then, let's
-		 build a modify expression :-/  */
-	      op0 = build2 (MODIFY_EXPR, TREE_TYPE (result),
-			    result, op0);
-	    }
-	}
-      if (!op0)
-	expand_null_return ();
-      else
-	expand_return (op0, gimple_return_retbnd (stmt));
+		/* ??? We'd like to use simply expand_assignment here,
+		   but this fails if the value is of BLKmode but the return
+		   decl is a register.  expand_return has special handling
+		   for this combination, which eventually should move
+		   to common code.  See comments there.  Until then, let's
+		   build a modify expression :-/  */
+		op0 = build2 (MODIFY_EXPR, TREE_TYPE (result),
+			      result, op0);
+	      }
+	    /* Mark we have return statement with missing bounds.  */
+	    if (!bnd && chkp_function_instrumented_p (cfun->decl))
+	      bnd = error_mark_node;
+	  }
+
+	if (!op0)
+	  expand_null_return ();
+	else
+	  expand_return (op0, bnd);
+      }
       break;
 
     case GIMPLE_ASSIGN:
Index: gcc/tree-ssa-live.c
===================================================================
--- gcc/tree-ssa-live.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/tree-ssa-live.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -80,6 +80,7 @@
 #include "ipa-ref.h"
 #include "cgraph.h"
 #include "ipa-utils.h"
+#include "cfgloop.h"
 
 #ifdef ENABLE_CHECKING
 static void  verify_live_on_entry (tree_live_info_p);
@@ -941,6 +942,14 @@
 	  }
       }
 
+  if (cfun->has_simduid_loops)
+    {
+      struct loop *loop;
+      FOR_EACH_LOOP (loop, 0)
+	if (loop->simduid && !is_used_p (loop->simduid))
+	  loop->simduid = NULL_TREE;
+    }
+
   cfun->has_local_explicit_reg_vars = false;
 
   /* Remove unmarked local and global vars from local_decls.  */
Index: gcc/ipa-prop.c
===================================================================
--- gcc/ipa-prop.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/ipa-prop.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -99,57 +99,6 @@
 #include "domwalk.h"
 #include "builtins.h"
 
-/* Intermediate information that we get from alias analysis about a particular
-   parameter in a particular basic_block.  When a parameter or the memory it
-   references is marked modified, we use that information in all dominatd
-   blocks without cosulting alias analysis oracle.  */
-
-struct param_aa_status
-{
-  /* Set when this structure contains meaningful information.  If not, the
-     structure describing a dominating BB should be used instead.  */
-  bool valid;
-
-  /* Whether we have seen something which might have modified the data in
-     question.  PARM is for the parameter itself, REF is for data it points to
-     but using the alias type of individual accesses and PT is the same thing
-     but for computing aggregate pass-through functions using a very inclusive
-     ao_ref.  */
-  bool parm_modified, ref_modified, pt_modified;
-};
-
-/* Information related to a given BB that used only when looking at function
-   body.  */
-
-struct ipa_bb_info
-{
-  /* Call graph edges going out of this BB.  */
-  vec<cgraph_edge *> cg_edges;
-  /* Alias analysis statuses of each formal parameter at this bb.  */
-  vec<param_aa_status> param_aa_statuses;
-};
-
-/* Structure with global information that is only used when looking at function
-   body. */
-
-struct func_body_info
-{
-  /* The node that is being analyzed.  */
-  cgraph_node *node;
-
-  /* Its info.  */
-  struct ipa_node_params *info;
-
-  /* Information about individual BBs. */
-  vec<ipa_bb_info> bb_infos;
-
-  /* Number of parameters.  */
-  int param_count;
-
-  /* Number of statements already walked by when analyzing this function.  */
-  unsigned int aa_walked;
-};
-
 /* Function summary where the parameter infos are actually stored. */
 ipa_node_params_t *ipa_node_params_sum = NULL;
 /* Vector of IPA-CP transformation data for each clone.  */
@@ -563,7 +512,7 @@
    of this function body.  */
 
 static struct ipa_bb_info *
-ipa_get_bb_info (struct func_body_info *fbi, basic_block bb)
+ipa_get_bb_info (struct ipa_func_body_info *fbi, basic_block bb)
 {
   gcc_checking_assert (fbi);
   return &fbi->bb_infos[bb->index];
@@ -838,7 +787,7 @@
    should really just start giving up.  */
 
 static bool
-aa_overwalked (struct func_body_info *fbi)
+aa_overwalked (struct ipa_func_body_info *fbi)
 {
   gcc_checking_assert (fbi);
   return fbi->aa_walked > (unsigned) PARAM_VALUE (PARAM_IPA_MAX_AA_STEPS);
@@ -847,8 +796,8 @@
 /* Find the nearest valid aa status for parameter specified by INDEX that
    dominates BB.  */
 
-static struct param_aa_status *
-find_dominating_aa_status (struct func_body_info *fbi, basic_block bb,
+static struct ipa_param_aa_status *
+find_dominating_aa_status (struct ipa_func_body_info *fbi, basic_block bb,
 			   int index)
 {
   while (true)
@@ -867,8 +816,8 @@
    structures and/or intialize the result with a dominating description as
    necessary.  */
 
-static struct param_aa_status *
-parm_bb_aa_status_for_bb (struct func_body_info *fbi, basic_block bb,
+static struct ipa_param_aa_status *
+parm_bb_aa_status_for_bb (struct ipa_func_body_info *fbi, basic_block bb,
 			  int index)
 {
   gcc_checking_assert (fbi);
@@ -875,13 +824,13 @@
   struct ipa_bb_info *bi = ipa_get_bb_info (fbi, bb);
   if (bi->param_aa_statuses.is_empty ())
     bi->param_aa_statuses.safe_grow_cleared (fbi->param_count);
-  struct param_aa_status *paa = &bi->param_aa_statuses[index];
+  struct ipa_param_aa_status *paa = &bi->param_aa_statuses[index];
   if (!paa->valid)
     {
       gcc_checking_assert (!paa->parm_modified
 			   && !paa->ref_modified
 			   && !paa->pt_modified);
-      struct param_aa_status *dom_paa;
+      struct ipa_param_aa_status *dom_paa;
       dom_paa = find_dominating_aa_status (fbi, bb, index);
       if (dom_paa)
 	*paa = *dom_paa;
@@ -898,10 +847,10 @@
    gathered but do not survive the summary building stage.  */
 
 static bool
-parm_preserved_before_stmt_p (struct func_body_info *fbi, int index,
+parm_preserved_before_stmt_p (struct ipa_func_body_info *fbi, int index,
 			      gimple stmt, tree parm_load)
 {
-  struct param_aa_status *paa;
+  struct ipa_param_aa_status *paa;
   bool modified = false;
   ao_ref refd;
 
@@ -937,7 +886,7 @@
    modified.  Otherwise return -1.  */
 
 static int
-load_from_unmodified_param (struct func_body_info *fbi,
+load_from_unmodified_param (struct ipa_func_body_info *fbi,
 			    vec<ipa_param_descriptor> descriptors,
 			    gimple stmt)
 {
@@ -964,10 +913,10 @@
    before reaching statement STMT.  */
 
 static bool
-parm_ref_data_preserved_p (struct func_body_info *fbi,
+parm_ref_data_preserved_p (struct ipa_func_body_info *fbi,
 			   int index, gimple stmt, tree ref)
 {
-  struct param_aa_status *paa;
+  struct ipa_param_aa_status *paa;
   bool modified = false;
   ao_ref refd;
 
@@ -1003,7 +952,7 @@
    CALL into which it is passed.  FBI describes the function body.  */
 
 static bool
-parm_ref_data_pass_through_p (struct func_body_info *fbi, int index,
+parm_ref_data_pass_through_p (struct ipa_func_body_info *fbi, int index,
 			      gimple call, tree parm)
 {
   bool modified = false;
@@ -1017,8 +966,9 @@
       || aa_overwalked (fbi))
     return false;
 
-  struct param_aa_status *paa = parm_bb_aa_status_for_bb (fbi, gimple_bb (call),
-							  index);
+  struct ipa_param_aa_status *paa = parm_bb_aa_status_for_bb (fbi,
+							      gimple_bb (call),
+							      index);
   if (paa->pt_modified)
     return false;
 
@@ -1041,12 +991,12 @@
    within the aggregate and whether it is a load from a value passed by
    reference respectively.  */
 
-static bool
-ipa_load_from_parm_agg_1 (struct func_body_info *fbi,
-			  vec<ipa_param_descriptor> descriptors,
-			  gimple stmt, tree op, int *index_p,
-			  HOST_WIDE_INT *offset_p, HOST_WIDE_INT *size_p,
-			  bool *by_ref_p)
+bool
+ipa_load_from_parm_agg (struct ipa_func_body_info *fbi,
+			vec<ipa_param_descriptor> descriptors,
+			gimple stmt, tree op, int *index_p,
+			HOST_WIDE_INT *offset_p, HOST_WIDE_INT *size_p,
+			bool *by_ref_p)
 {
   int index;
   HOST_WIDE_INT size, max_size;
@@ -1113,18 +1063,6 @@
   return false;
 }
 
-/* Just like the previous function, just without the param_analysis_info
-   pointer, for users outside of this file.  */
-
-bool
-ipa_load_from_parm_agg (struct ipa_node_params *info, gimple stmt,
-			tree op, int *index_p, HOST_WIDE_INT *offset_p,
-			bool *by_ref_p)
-{
-  return ipa_load_from_parm_agg_1 (NULL, info->descriptors, stmt, op, index_p,
-				   offset_p, NULL, by_ref_p);
-}
-
 /* Given that an actual argument is an SSA_NAME (given in NAME) and is a result
    of an assignment statement STMT, try to determine whether we are actually
    handling any of the following cases and construct an appropriate jump
@@ -1179,7 +1117,7 @@
    only needed for intraprocedural analysis.  */
 
 static void
-compute_complex_assign_jump_func (struct func_body_info *fbi,
+compute_complex_assign_jump_func (struct ipa_func_body_info *fbi,
 				  struct ipa_node_params *info,
 				  struct ipa_jump_func *jfunc,
 				  gcall *call, gimple stmt, tree name,
@@ -1321,7 +1259,7 @@
      return D.1879_6;  */
 
 static void
-compute_complex_ancestor_jump_func (struct func_body_info *fbi,
+compute_complex_ancestor_jump_func (struct ipa_func_body_info *fbi,
 				    struct ipa_node_params *info,
 				    struct ipa_jump_func *jfunc,
 				    gcall *call, gphi *phi)
@@ -1703,7 +1641,7 @@
    to this callsite.  */
 
 static void
-ipa_compute_jump_functions_for_edge (struct func_body_info *fbi,
+ipa_compute_jump_functions_for_edge (struct ipa_func_body_info *fbi,
 				     struct cgraph_edge *cs)
 {
   struct ipa_node_params *info = IPA_NODE_REF (cs->caller);
@@ -1826,7 +1764,7 @@
    from BB.  */
 
 static void
-ipa_compute_jump_functions_for_bb (struct func_body_info *fbi, basic_block bb)
+ipa_compute_jump_functions_for_bb (struct ipa_func_body_info *fbi, basic_block bb)
 {
   struct ipa_bb_info *bi = ipa_get_bb_info (fbi, bb);
   int i;
@@ -1989,7 +1927,7 @@
    passed by value or reference.  */
 
 static void
-ipa_analyze_indirect_call_uses (struct func_body_info *fbi, gcall *call,
+ipa_analyze_indirect_call_uses (struct ipa_func_body_info *fbi, gcall *call,
 				tree target)
 {
   struct ipa_node_params *info = fbi->info;
@@ -2008,9 +1946,9 @@
   int index;
   gimple def = SSA_NAME_DEF_STMT (target);
   if (gimple_assign_single_p (def)
-      && ipa_load_from_parm_agg_1 (fbi, info->descriptors, def,
-				   gimple_assign_rhs1 (def), &index, &offset,
-				   NULL, &by_ref))
+      && ipa_load_from_parm_agg (fbi, info->descriptors, def,
+				 gimple_assign_rhs1 (def), &index, &offset,
+				 NULL, &by_ref))
     {
       struct cgraph_edge *cs = ipa_note_param_call (fbi->node, index, call);
       cs->indirect_info->offset = offset;
@@ -2127,7 +2065,7 @@
    statement.  */
 
 static void
-ipa_analyze_virtual_call_uses (struct func_body_info *fbi,
+ipa_analyze_virtual_call_uses (struct ipa_func_body_info *fbi,
 			       gcall *call, tree target)
 {
   tree obj = OBJ_TYPE_REF_OBJECT (target);
@@ -2184,7 +2122,7 @@
    containing intermediate information about each formal parameter.  */
 
 static void
-ipa_analyze_call_uses (struct func_body_info *fbi, gcall *call)
+ipa_analyze_call_uses (struct ipa_func_body_info *fbi, gcall *call)
 {
   tree target = gimple_call_fn (call);
 
@@ -2230,7 +2168,7 @@
    formal parameters are called.  */
 
 static void
-ipa_analyze_stmt_uses (struct func_body_info *fbi, gimple stmt)
+ipa_analyze_stmt_uses (struct ipa_func_body_info *fbi, gimple stmt)
 {
   if (is_gimple_call (stmt))
     ipa_analyze_call_uses (fbi, as_a <gcall *> (stmt));
@@ -2263,7 +2201,7 @@
    the function being analyzed.  */
 
 static void
-ipa_analyze_params_uses_in_bb (struct func_body_info *fbi, basic_block bb)
+ipa_analyze_params_uses_in_bb (struct ipa_func_body_info *fbi, basic_block bb)
 {
   gimple_stmt_iterator gsi;
   for (gsi = gsi_start_bb (bb); !gsi_end_p (gsi); gsi_next (&gsi))
@@ -2345,13 +2283,13 @@
 class analysis_dom_walker : public dom_walker
 {
 public:
-  analysis_dom_walker (struct func_body_info *fbi)
+  analysis_dom_walker (struct ipa_func_body_info *fbi)
     : dom_walker (CDI_DOMINATORS), m_fbi (fbi) {}
 
   virtual void before_dom_children (basic_block);
 
 private:
-  struct func_body_info *m_fbi;
+  struct ipa_func_body_info *m_fbi;
 };
 
 void
@@ -2368,7 +2306,7 @@
 void
 ipa_analyze_node (struct cgraph_node *node)
 {
-  struct func_body_info fbi;
+  struct ipa_func_body_info fbi;
   struct ipa_node_params *info;
 
   ipa_check_create_node_params ();
@@ -2472,11 +2410,15 @@
 	      ctx.offset_by (dst->value.ancestor.offset);
 	      if (!ctx.useless_p ())
 		{
-		  vec_safe_grow_cleared (args->polymorphic_call_contexts,
-					 count);
-		  dst_ctx = ipa_get_ith_polymorhic_call_context (args, i);
+		  if (!dst_ctx)
+		    {
+		      vec_safe_grow_cleared (args->polymorphic_call_contexts,
+					     count);
+		      dst_ctx = ipa_get_ith_polymorhic_call_context (args, i);
+		    }
+
+		  dst_ctx->combine_with (ctx);
 		}
-	      dst_ctx->combine_with (ctx);
 	    }
 
 	  if (src->agg.items
@@ -5183,7 +5125,7 @@
 class ipcp_modif_dom_walker : public dom_walker
 {
 public:
-  ipcp_modif_dom_walker (struct func_body_info *fbi,
+  ipcp_modif_dom_walker (struct ipa_func_body_info *fbi,
 			 vec<ipa_param_descriptor> descs,
 			 struct ipa_agg_replacement_value *av,
 			 bool *sc, bool *cc)
@@ -5193,7 +5135,7 @@
   virtual void before_dom_children (basic_block);
 
 private:
-  struct func_body_info *m_fbi;
+  struct ipa_func_body_info *m_fbi;
   vec<ipa_param_descriptor> m_descriptors;
   struct ipa_agg_replacement_value *m_aggval;
   bool *m_something_changed, *m_cfg_changed;
@@ -5234,8 +5176,8 @@
       if (vce)
 	continue;
 
-      if (!ipa_load_from_parm_agg_1 (m_fbi, m_descriptors, stmt, rhs, &index,
-				     &offset, &size, &by_ref))
+      if (!ipa_load_from_parm_agg (m_fbi, m_descriptors, stmt, rhs, &index,
+				   &offset, &size, &by_ref))
 	continue;
       for (v = m_aggval; v; v = v->next)
 	if (v->index == index
@@ -5351,7 +5293,7 @@
 ipcp_transform_function (struct cgraph_node *node)
 {
   vec<ipa_param_descriptor> descriptors = vNULL;
-  struct func_body_info fbi;
+  struct ipa_func_body_info fbi;
   struct ipa_agg_replacement_value *aggval;
   int param_count;
   bool cfg_changed = false, something_changed = false;
Index: gcc/ipa-prop.h
===================================================================
--- gcc/ipa-prop.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/ipa-prop.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -336,6 +336,57 @@
   unsigned node_calling_single_call : 1;
 };
 
+/* Intermediate information that we get from alias analysis about a particular
+   parameter in a particular basic_block.  When a parameter or the memory it
+   references is marked modified, we use that information in all dominated
+   blocks without consulting alias analysis oracle.  */
+
+struct ipa_param_aa_status
+{
+  /* Set when this structure contains meaningful information.  If not, the
+     structure describing a dominating BB should be used instead.  */
+  bool valid;
+
+  /* Whether we have seen something which might have modified the data in
+     question.  PARM is for the parameter itself, REF is for data it points to
+     but using the alias type of individual accesses and PT is the same thing
+     but for computing aggregate pass-through functions using a very inclusive
+     ao_ref.  */
+  bool parm_modified, ref_modified, pt_modified;
+};
+
+/* Information related to a given BB that used only when looking at function
+   body.  */
+
+struct ipa_bb_info
+{
+  /* Call graph edges going out of this BB.  */
+  vec<cgraph_edge *> cg_edges;
+  /* Alias analysis statuses of each formal parameter at this bb.  */
+  vec<ipa_param_aa_status> param_aa_statuses;
+};
+
+/* Structure with global information that is only used when looking at function
+   body. */
+
+struct ipa_func_body_info
+{
+  /* The node that is being analyzed.  */
+  cgraph_node *node;
+
+  /* Its info.  */
+  struct ipa_node_params *info;
+
+  /* Information about individual BBs. */
+  vec<ipa_bb_info> bb_infos;
+
+  /* Number of parameters.  */
+  int param_count;
+
+  /* Number of statements already walked by when analyzing this function.  */
+  unsigned int aa_walked;
+};
+
 /* ipa_node_params access functions.  Please use these to access fields that
    are or will be shared among various passes.  */
 
@@ -585,8 +636,9 @@
 /* Aggregate jump function related functions.  */
 tree ipa_find_agg_cst_for_param (struct ipa_agg_jump_function *, HOST_WIDE_INT,
 				 bool);
-bool ipa_load_from_parm_agg (struct ipa_node_params *, gimple, tree, int *,
-			     HOST_WIDE_INT *, bool *);
+bool ipa_load_from_parm_agg (struct ipa_func_body_info *,
+			     vec<ipa_param_descriptor>, gimple, tree, int *,
+			     HOST_WIDE_INT *, HOST_WIDE_INT *, bool *);
 
 /* Debugging interface.  */
 void ipa_print_node_params (FILE *, struct cgraph_node *node);
Index: gcc/po/es.po
===================================================================
--- gcc/po/es.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/es.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.7.2\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2012-09-24 13:50-0500\n"
 "Last-Translator: Cristian Othón Martínez Vera <cfuga@cfuga.mx>\n"
 "Language-Team: Spanish <es@li.org>\n"
@@ -202,13 +202,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "constante de coma flotante mal usada"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1420,7 +1420,7 @@
 msgid "options enabled: "
 msgstr "opciones activadas: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2645,97 +2645,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "código de operando '%c' inválido"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "se usó '%%&' sin ninguna referencia TLS dinámica local"
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "valor %%H inválido"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "valor %%J inválido"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "valor %%r inválido"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "valor %%R inválido"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "valor %%N inválido"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "valor %%P inválido"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "valor %%h inválido"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "valor %%L inválido"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "valor %%m inválido"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "valor %%M inválido"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "valor %%U inválido"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "valor %%s inválido"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "valor %%C inválido"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "valor %%E inválido"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "reubicación unspec desconocida"
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "código %%xn inválido"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid operand address"
@@ -2788,7 +2788,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "operando inválido en el código de salida"
@@ -2946,8 +2946,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3167,67 +3167,67 @@
 msgid "bad output_condmove_single operand"
 msgstr "operando output_condmove_single erróneo"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC inválido como operando"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "tamaño de operando inválido para el código de operando '%c'"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "tamaño de operando inválido para el código de operando '%c'"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, fuzzy, c-format
 #| msgid "invalid operand type used with operand code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "se usó un tipo de operando inválido con el código de operando '%c'"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "tamaño de operando inválido para el código de operando '%c'"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "el operando no es un código de condición, código de operando 'Y' inválido"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "el operando no es un código de condición, código de operando 'D' inválido"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "el operando no es un código de condición, código de operando 'D' inválido"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "el operando no es una referencia de memoria desplazable, código de operando 'H' inválido"
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "código de operando '%c' inválido"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "restricciones inválidas para el operando"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "modo insn desconocido"
 
@@ -3267,7 +3267,7 @@
 msgid "invalid %%P operand"
 msgstr "operando %%P inválido"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "valor %%p inválido"
@@ -3331,7 +3331,7 @@
 msgstr "la dirección de post-incremento no es un registro"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "dirección errónea"
 
@@ -3499,102 +3499,102 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "Genera código en modo little endian"
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 msgid "bad move"
 msgstr "move erróneo"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "valor %%H inválido"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "valor %%f inválido"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "valor %%F inválido"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "valor %%G inválido"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "código %%j inválido"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "código %%J inválido"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "valor %%k inválido"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "valor %%K inválido"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "valor %%O inválido"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "valor %%q inválido"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "valor %%S inválido"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "valor %%T inválido"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "valor %%u inválido"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "valor %%v inválido"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "valor %%x inválido"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valor %%y inválido, pruebe usando la restricción 'Z'"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Se pasó un argumento Altivec a una función sin prototipo"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 #| msgid "Do not generate code for a Sun FPA"
 msgid "Could not generate addis value for fusion"
 msgstr "No generar código para un FPA de Sun"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load offset for fusion"
@@ -3690,60 +3690,60 @@
 msgid "invalid operand to %%S"
 msgstr "operando inválido para %%S"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr "creado y usado con diferentes arquitecturas / ABIs"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr "creado y usado con diferentes ABIs"
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr "creado y usado con diferente orden de bits"
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "operando %%Y inválido"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "operando %%A inválido"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "operando %%B inválido"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, c-format
 msgid "invalid %%C operand"
 msgstr "operando %%C inválido"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, c-format
 msgid "invalid %%D operand"
 msgstr "operando %%D inválido"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "operando %%f inválido"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "operando %%s inválido"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "la constante long long no es un operando inmediato válido"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "la constante de coma flotante no es un operando inmediato válido"
@@ -3956,7 +3956,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "se esperaba %<;%>"
@@ -3972,15 +3972,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "se esperaba %<(%>"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "se esperaba %<,%>"
@@ -4002,8 +4002,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "se esperaba %<)%>"
@@ -4010,8 +4010,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "se esperaba %<]%>"
@@ -4020,13 +4020,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "se esperaba %<}%>"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "se esperaba %<{%>"
@@ -4033,8 +4033,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "se esperaba %<:%>"
@@ -4057,7 +4057,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "se esperaba %<while%>"
@@ -4074,34 +4074,34 @@
 msgid "expected %<.%>"
 msgstr "se esperaba %<.%>"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "se esperaba %<@end%>"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "se esperaba %<>%>"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "se esperaba %<,%> o %<)%>"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "se esperaba %<=%>"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "se esperaba %<#pragma omp section%> o %<}%>"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "se esperaba %<[%>"
@@ -4110,11 +4110,11 @@
 msgid "(anonymous)"
 msgstr "(anónimo)"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "candidato 1:"
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "candidato 2:"
 
@@ -4344,11 +4344,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%s:%d:   en la expansión de la expresión constante de %qs"
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "los candidatos son:"
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "el candidato es:"
@@ -4394,48 +4394,48 @@
 msgid "source type is not polymorphic"
 msgstr "el tipo fuente no es polimórfico"
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "argumento de tipo erróneo para el decremento unario"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "argumento de tipo erróneo para el incremento unario"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "argumento de tipo erróneo para complemento de bits"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "argumento de tipo erróneo para abs"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "argumento de tipo erróneo para la conjugación"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 msgid "in argument to unary !"
 msgstr "en el argumento para el ! unario"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 msgid "no pre-increment operator for type"
 msgstr "no hay operador de pre-incremento para el tipo"
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr "no hay operador de post-incremento para el tipo"
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 msgid "no pre-decrement operator for type"
 msgstr "no hay operador de pre-decremento para el tipo"
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr "no hay operador de post-decremento para el tipo"
 
@@ -4536,7 +4536,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "Valor entero demasiado grande en la expresión en %C"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 msgid "array assignment"
 msgstr "asignación de matriz"
 
@@ -4560,7 +4560,7 @@
 msgid "Driving:"
 msgstr "Conduciendo:"
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "argumento actual de INTENT = OUT/INOUT"
 
@@ -4630,13 +4630,13 @@
 msgid "%s tag"
 msgstr "etiqueta %s"
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr "unidad interna en WRITE"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "etiqueta %s con INQUIRE"
@@ -4714,7 +4714,7 @@
 msgid "Bad type in constant expression"
 msgstr "Tipo erróneo en la expresión constante"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 msgid "Unexpected end of module"
 msgstr "Fin de módulo inesperado"
 
@@ -4742,11 +4742,11 @@
 msgid "implied END DO"
 msgstr "END DO implícito"
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr "asignación"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 msgid "pointer assignment"
 msgstr "asignación de puntero"
 
@@ -4762,221 +4762,221 @@
 msgid "internal function"
 msgstr "función interna"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 msgid "elemental procedure"
 msgstr "procedimiento elemental"
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "argumento de tipo inválido"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 #| msgid "not enough arguments"
 msgid "asynchronous argument"
 msgstr "faltan argumentos"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 #| msgid "invalid PHI argument"
 msgid "optional argument"
 msgstr "argumento PHI inválido"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "asignación de puntero"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 #| msgid "too many arguments"
 msgid "target argument"
 msgstr "demasiados argumentos"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "argumento de tipo inválido"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "sin argumentos"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-shape argument"
 msgstr "no coinciden los argumentos"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-rank argument"
 msgstr "no coinciden los argumentos"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 #| msgid "array assignment"
 msgid "coarray argument"
 msgstr "asignación de matriz"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 #, fuzzy
 #| msgid "parameterized structures not implemented"
 msgid "parametrized derived type argument"
 msgstr "no se han implementado las estructuras parametrizadas"
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "sin argumentos"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "argumento de tipo inválido"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 #, fuzzy
 #| msgid "Coindexed allocatable object at %L"
 msgid "pointer or allocatable result"
 msgstr "Objeto alojable coindizado en %L"
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 #, fuzzy
 #| msgid "bit array slice with non-constant length"
 msgid "result with non-constant character length"
 msgstr "rebanada de la matriz de bits con longitud no constante"
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 #, fuzzy
 #| msgid "module procedure"
 msgid "bind(c) procedure"
 msgstr "procedimiento módulo"
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Contexto inválido para el puntero NULL() en %%L"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr "El operando del operador numérico unario '%s' en %%L es %s"
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr "Los operandos del operador binario numérico '%s' en %%L son %s/%s"
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Los operandos del operador de concatenación de cadenas en %%L son %s/%s"
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr "Los operandos del operador lógico '%s' en %%L son %s/%s"
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "El operando del operador .not. en %%L es %s"
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Las cantidades COMPLEX no se pueden comparar en %L"
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Los lógicos en %%L se deben comparar con %s en lugar de %s"
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr "Los operandos del operador de comparación '%s' en %%L son %s/%s"
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr "Operador '%s' desconocido en %%L"
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr "El operando del operador de usuario '%s' en %%L es %s"
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr "Los operandos del operador de usuario '%s' en %%L son %s/%s"
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Rangos inconsistentes para el operador en %%L y %%L"
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr "Variable de ciclo"
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 msgid "iterator variable"
 msgstr "variable de iterador"
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 msgid "Start expression in DO loop"
 msgstr "Expresión de inicio en el bucle DO"
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 msgid "End expression in DO loop"
 msgstr "Expresión de fin en el bucle DO"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 msgid "Step expression in DO loop"
 msgstr "Expresión de paso en el bucle DO"
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 msgid "DEALLOCATE object"
 msgstr "objeto DEALLOCATE"
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 msgid "ALLOCATE object"
 msgstr "objeto ALLOCATE"
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr "variable STAT"
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr "elemento en READ"
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
@@ -5396,16 +5396,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr "el cpu rx200 no tiene FPU de hardware"
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr "considere usar '-pg' en lugar de '-p' con gprof(1)"
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr "considere usar `-pg' en lugar de `-p' con gprof(1)"
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr "no se admite multilib"
@@ -5418,6 +5408,10 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "-Xbind-now y -Xbind-lazy son incompatibles"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+msgid "profiling not supported with -mg"
+msgstr "el análisis de perfil no se admite con -mg"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "no se admite -mhard-float"
@@ -5426,10 +5420,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "no se pueden especificar -msingle-float y -msoft-float al mismo tiempo"
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr "el m210 no admite little endian"
-
 #: config/cris/cris.h:184
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "no especifique -march=... y -mcpu=... al mismo tiempo"
@@ -5460,6 +5450,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr "considere usar '-pg' en lugar de '-p' con gprof(1)"
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5466,6 +5462,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr "no se pueden usar -m32 y -m64 al mismo tiempo"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr "considere usar `-pg' en lugar de `-p' con gprof(1)"
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr "static no se admite en TPF-OS"
@@ -5478,6 +5478,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "no se pueden usar juntos -mbig-endian y -mlittle-endian"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr "el m210 no admite little endian"
+
 #: config/avr/specs.h:68
 #, fuzzy
 #| msgid "-fpic is not supported"
@@ -5507,17 +5511,19 @@
 msgid "no processor type specified for linking"
 msgstr "no existe el tipo de procesador especificado para enlazar"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr "aviso: considere enlazar con '-static' como bibliotecas de sistema con"
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr " soporte a análisis de perfil sólo se proveen en formato de archivo"
 
@@ -5553,10 +5559,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "la opción -shared no se admite actualmente en ELF de VAX"
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-msgid "profiling not supported with -mg"
-msgstr "el análisis de perfil no se admite con -mg"
-
 #: fortran/lang.opt:146
 msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgstr "-J<directorio>\tColoca los ficheros MODULE en el 'directorio'"
@@ -5746,9 +5748,9 @@
 msgstr "Permite signos de dólar en nombres de entidades"
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "No hace nada. Preservado por compatibilidad hacia atrás."
 
@@ -5960,10 +5962,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "No hace nada.  Se preserva por compatibilidad hacia atrás."
 
@@ -6009,7 +6011,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr "falta un nombre de fichero después de %qs"
@@ -7934,52 +7936,56 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr "Asume que el CPU destino está configurado como little endian"
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 #, fuzzy
 #| msgid "Select code model"
 msgid "Specify the code model"
 msgstr "Selecciona el modelo de código"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr "No asume que los accesos sin alinear son manejados por el sistema"
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr "Omite el marco de referencia para las funciones hojas"
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 #, fuzzy
 #| msgid "-mcpu=CPU\tUse features of and schedule code for given CPU"
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr "-mcpu=CPU\tUsa las características y el código de calendarizador para el CPU dado"
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 #, fuzzy
 #| msgid "-mcpu=CPU\tUse features of and schedule code for given CPU"
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr "-mcpu=CPU\tUsa las características y el código de calendarizador para el CPU dado"
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 #, fuzzy
 #| msgid "-mabi=ABI\tGenerate code that conforms to the given ABI"
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr "-mabi=ABI\tGenera código que cumpla con la ABI dada"
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 #, fuzzy
 #| msgid "Known ARM ABIs (for use with the -mabi= option):"
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
@@ -9108,11 +9114,17 @@
 
 #: config/i386/i386.opt:864
 #, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "Admite funciones internas y generación de código MMX y SSE"
+
+#: config/i386/i386.opt:868
+#, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use given stack-protector guard"
 msgstr "Usa propolice como un método de protección de pila"
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 #, fuzzy
 #| msgid "Known ARM architectures (for use with the -march= option):"
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
@@ -9487,7 +9499,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -9636,7 +9648,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr "Establece los costos de ramificación para las instrucciones de ramificación condicional.  Razonable"
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
@@ -9769,7 +9781,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr "Permite la calendarización de un secuencia de los prólogos de función"
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr "No carga el registro PIC en los prólogos de función"
 
@@ -10096,311 +10108,309 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "Usa instrucciones (VSX) vector/escalar"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr "No genera load/store con instrucciones de actualización"
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr "Genera load/store con instrucciones de actualización"
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr "Evita la generación de instrucciones indizadas load/store cuando sea posible"
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "Marca las llamadas __tls_get_addr con información de argumentos"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr "Calendariza el inicio y el final del procedimiento"
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr "Devuelve todas las estructuras en memoria (por defecto en AIX)"
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr "Devuelve las estructuras pequeñas en registros (por defecto en SVR4)"
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr "Conforma más cerca a la semántica XLC de IBM"
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr "Genera división recíproca y raíz cuadrada de software para mejor salida."
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr "Asume que las instrucciones estimadas recíprocas proveen más exactitud."
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr "No coloca las constantes de coma flotante en TOC"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr "Coloca las constantes de coma flotante en TOC"
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "No coloca las constantes símbolo+desplazamiento en TOC"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr "Coloca las constantes símbolo+desplazamiento en TOC"
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr "Usa sólo una entrada TOC por procedimiento"
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr "Coloca todo en la TOC normal"
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr "Genera instrucciones VRSAVE cuando se genere código AltiVec"
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr "Opción obsoleta.  Use en su lugar -mno-vrsave"
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr "Opción obsoleta.  Use en su lugar -mvrsave"
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr "Especifica cúantos bytes se debe mover en inclusión en línea antes de llamar a memcp/memmove"
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 msgid "Generate isel instructions"
 msgstr "Genera instrucciones isel"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr "Opción obsoleta.  Use en su lugar -mno-isel"
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 msgid "Deprecated option.  Use -misel instead"
 msgstr "Opción obsoleta.  Use en su lugar -misel"
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr "Genera instrucciones SPE SIMD en E500"
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "Genera instrucciones par-sencillo PPC750CL"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr "Opción obsoleta.  Use en su lugar -mno-spe"
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 msgid "Deprecated option.  Use -mspe instead"
 msgstr "Opción obsoleta.  Use en su lugar -mspe"
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 msgid "-mdebug=\tEnable debug output"
 msgstr "-mdebug=\tActiva la salida de depuración"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 msgid "Use the AltiVec ABI extensions"
 msgstr "Usa las extensiones de ABI AltiVec"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "No usa las extensiones de ABI AltiVec"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 msgid "Use the SPE ABI extensions"
 msgstr "Usa las extensiones de ABI SPE"
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 msgid "Do not use the SPE ABI extensions"
 msgstr "No usa las extensiones de ABI SPE"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv1 ABI"
 msgstr "Usa EABI"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv2 ABI"
 msgstr "Usa EABI"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 msgid "using darwin64 ABI"
 msgstr "se usa ABI darwin64"
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 msgid "using old darwin ABI"
 msgstr "se usa ABI de darwin antiguo"
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr "se usa long double de precisión extendida de IEEE"
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr "se usa long double de precisión extendida de IBM"
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr "-mcpu=\tUsa las características y el código de calendarizador para el CPU dado"
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "-mtune=\tCódigo de calendarizador para el CPU dado"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr "-mtraceback=\tSelecciona la tabla full, part, ó sin traceback"
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr "Evita todos los límites de rango en las instrucciones de llamadas"
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 msgid "Generate Cell microcode"
 msgstr "Genera microcódigo Cell"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "Avisa cuando se emite una instrucción microcodificada Cell"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr "Avisa sobre el uso del tipo AltiVec obsoleto 'vector long ...'"
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr "-mfloat-gprs=\tSelecciona el método de coma flotante GPR"
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Argumentos válidos para -mfloat-gprs:"
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr "-mlong-double-<n>\tEspecifica el tamaño de long double (64 ó 128 bits)"
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr "Determina cuáles dependencias entre insns se consideran costosas"
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr "Especifica cuál esquema de inserción de nop post calendarizados se debe aplicar"
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr "Especifica la alineación de los campos de estructuras default/natural"
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 msgid "Valid arguments to -malign-:"
 msgstr "Argumentos válidos para -malign-:"
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr "Especifica la prioridad de calendarización para despachar insns restringidos por ranuras"
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 msgid "Single-precision floating point unit"
 msgstr "Unidad de coma flotante de precisión simple"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 msgid "Double-precision floating point unit"
 msgstr "Unidad de coma flotante de precisión doble"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 msgid "Floating point unit does not support divide & sqrt"
 msgstr "La unidad de coma flotante no admite divide & sqrt"
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr "-mfpu=\tEspecifica FP (sp, dp, sp-lite, dp-lite) (implica -mxilinx-fpu)"
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 msgid "Specify Xilinx FPU."
 msgstr "Especifica la FPU de Xilinx."
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr "Usa/no usa r11 para preservar el enlace estático en llamadas a funciones a través de punteros."
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr "Controla si se guarda la TOC en el prólogo para llamadas indirectas o genera el save en línea"
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 #, fuzzy
 #| msgid "Align destination of the string operations"
 msgid "Allow sign extension in fusion operations"
 msgstr "Alínea el destino de las operaciones de cadenas"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
-#, fuzzy
-#| msgid "Use SmartMIPS instructions"
-msgid "Use ISA 2.07 crypto instructions"
-msgstr "Usa instrucciones SmartMIPS"
+#: config/rs6000/rs6000.opt:566
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr ""
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 #, fuzzy
 #| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr "Usa instrucciones (VSX) vector/escalar"
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Genera múltiples instrucciones load/store"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -13470,1619 +13480,1619 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr "-dumpdir <dir>\tEstablece el nombre del directorio a usar para los volcados"
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "Alínea el inicio de las funciones"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr "Alínea las etiquetas que solamente se alcanzan saltando"
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr "Alínea todas las etiquetas"
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "Alínea el inicio de los bucles"
 
-#: common.opt:894
+#: common.opt:897
 #, fuzzy
 #| msgid "Select the runtime"
 msgid "Select what to sanitize"
 msgstr "Selecciona el tiempo de ejecución"
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr "Esta opción es obsoleta; utilice en su lugar -Wextra"
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr "Genera tablas de desenredo que sean exactas en cada límite de instrucción"
 
-#: common.opt:918
+#: common.opt:921
 msgid "Generate auto-inc/dec instructions"
 msgstr "Genera instrucciones auto-inc/dec"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr "Usa la información de análisis de perfil para las probabilidades de ramificación"
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "Genera código para revisar los límites antes de indizar matrices"
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr "Reemplaza add, compare, branch con branch en la cuenta de registros"
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr "Usa la información de análisis de perfil para las probabilidades de ramificación"
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr "Realiza optimización de carga de ramificación objetivo antes del hilo prólogo / epílogo"
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr "Realiza optimización de carga de ramificación objetivo después del hilo prólogo / epílogo"
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr "Restringe que la migración de carga de objetivos no reuse registros en ningún bloque básico"
 
-#: common.opt:960
+#: common.opt:963
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr "-fcall-saved-<registro>\tMarca el <registro> como preservado entre funciones"
 
-#: common.opt:964
+#: common.opt:967
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr "-fcall-used-<registro>\tMarca el <registro> como corrupto por llamadas de función"
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr "Guarda registros alrededor de llamadas de función"
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr "Compara los resultados de varios analizadores de dependencia de datos."
 
-#: common.opt:979
+#: common.opt:982
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++"
 msgstr "Revisa el valor de devolución de new"
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "Busca oportunidades para reducir los ajustes de pila y las referencias de pila."
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr "No pone globales sin inicializar en la sección común"
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr "-fcompare-debug[=<opts>]\tCompila con y sin p.e. -gtoggle, y compara el volcado de insns finales"
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr "Ejecuta sólo la segunda compilación de -fcompare-debug"
 
-#: common.opt:1003
+#: common.opt:1006
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr "Realiza la eliminación de comparaciones después de terminar el alojamiento de registros"
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr "No realizar optimizaciones que incrementan notablemente el uso de la pila"
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr "Realiza el paso de optimización de copia-propagación de registros"
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr "Realiza optimizaciones de saltos cruzados"
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr "Cuando se esté ejecutando CSE, sigue los saltos a sus objetivos"
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr "Omite el paso de reducción de rango al realizar divisiones complejas"
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr "La multiplicación y la división complejas siguen las reglas Fortran"
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr "Coloca los elementos de datos en su propia sección"
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Enumera todos los contadores de depuración disponibles con sus límites y cuentas."
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr "-fdbg-cnt=<contador>:<límite>[,<contador>:<límite>,...]\tEstablece el límite del contador de depuración."
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr "Mapea un nombre de directorio a otro en la información de depuración"
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "Muestra la sección .debug_types al usar la información de depuración DWARF v4."
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr "Posterga la extracción de argumentos de funciones de la pila hasta más tarde"
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr "Intenta rellenar las ranuras de retraso de las instrucciones de ramificación"
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr "Borra las revisiones de punteros nulos sin uso"
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization"
 msgstr "Realiza la formación de superbloques a través de la duplicación de colas"
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr "Trata de convertir las llamadas virtuales a llamadas directas."
 
-#: common.opt:1085
+#: common.opt:1088
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr "-fdiagnostics-show-location=[once|every-line]\tIndica que tan seguido se debe emitir la ubicación del código al inicio de los diagnósticos con corte de línea"
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr "Asocia adecuadamente los mensajes de diagnóstico con la opción de línea de orden que los controla"
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr "-fdisable-[tree|rtl|ipa]-<paso>=rango1+rango2 desactiva un paso de optimización"
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr "-fenable-[tree|rtl|ipa]-<paso>=rango1+rango2 activa un paso de optimización"
 
-#: common.opt:1142
+#: common.opt:1145
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr "-fdump-<tipo>\tVuelca varios internos del compilador a un fichero"
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr "-fdump-final-insns=fichero\tVuelca al fichero las insns al final de la traducción"
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr "-fdump-go-spec=fichero\tEscribe todas las declaraciones al fichero como código Go"
 
-#: common.opt:1157
+#: common.opt:1160
 msgid "Suppress output of addresses in debugging dumps"
 msgstr "Suprime la salida de direcciones en los volcados de depuración"
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 msgid "Dump optimization passes"
 msgstr "Vuelca pasadas de optimización"
 
-#: common.opt:1170
+#: common.opt:1173
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr "Suprime la salida de números de instrucción, notas de números de linea y direcciones en los volcados de depuración"
 
-#: common.opt:1174
+#: common.opt:1177
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr "Suprime la salida de los números insn previos y siguientes en los volcados de depuración"
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Activa las tablas CFI a través de directivas del ensamblador GAS."
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr "Realiza la inclusión en línea temprana"
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr "Realiza la eliminación de duplicados DWARF2"
 
-#: common.opt:1190
+#: common.opt:1193
 msgid "Perform interprocedural reduction of aggregates"
 msgstr "Realiza la reducción interprocedural de los agregados"
 
-#: common.opt:1194
+#: common.opt:1197
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info"
 msgstr "Realiza la eliminación de tipos sin uso en la información de depuración"
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr "Realiza la eliminación de tipos sin uso en la información de depuración"
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr "No suprime la información de depuración de clases C++."
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "Activa el manejo de excepciones"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr "Realiza un número de optimizaciones menores y costosas"
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr "-fexcess-precision=[fast|standard]\tEspecifica el manejo del exceso de precisión de coma flotante"
 
-#: common.opt:1217
+#: common.opt:1220
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr "estilo de exceso de precisión %qs desconocido"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "Muestra los objetos lto que contienen tanto el lenguaje intermedio como la salida binaria."
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr "Asume que no se generan NaNs o infinitos"
 
-#: common.opt:1238
+#: common.opt:1241
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr "-ffixed-<registro>\tMarca el <registro> como no disponible para el compilador"
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr "No aloja floats y doubles en registros de precisión extendida"
 
-#: common.opt:1250
+#: common.opt:1253
 msgid "Perform a forward propagation pass on RTL"
 msgstr "Realiza el paso de la propagación hacia adelante en RTL"
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr "-ffp-contract=[off|on|fast] Realiza contracción de expresión de coma flotante."
 
-#: common.opt:1257
+#: common.opt:1260
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "estilo de contracción de coma flotante %qs desconocido"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr "Permite que las direcciones de las funciones se conservern en registros"
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr "Coloca cada función en su propia sección"
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr "Realiza la eliminación de subexpresiones comunes globales"
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr "Realiza el movimiento de la carga mejorada durante la eliminación de subexpresiones comunes globales"
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr "Realiza el movimiento de guardado después de la eliminación de subexpresiones comunes globales"
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr "Realiza la carga redundante después de la eliminación de almacenamiento en las subexpresiones comunes globales"
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr "Realiza la eliminación de subexpresiones comunes globales después del alojamiento de registros"
 
-#: common.opt:1305
+#: common.opt:1308
 msgid "Enable in and out of Graphite representation"
 msgstr "Activa in y out de la representación Graphite"
 
-#: common.opt:1309
+#: common.opt:1312
 msgid "Enable Graphite Identity transformation"
 msgstr "Activa la transformación Graphite Identity"
 
-#: common.opt:1313
+#: common.opt:1316
 #, fuzzy
 #| msgid "Enable hoisting loads from conditional pointers."
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr "Activa las cargas de elevación de punteros condicionales."
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr "Marca todos los bucles como paralelos"
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr "Activa la transformación Loop Strip Mining"
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr "Activa la transformación Loop Interchange"
 
-#: common.opt:1330
+#: common.opt:1333
 msgid "Enable Loop Blocking transformation"
 msgstr "Activa la transformación Loop Blocking"
 
-#: common.opt:1334
+#: common.opt:1337
 #, fuzzy
 #| msgid "Enable Loop Interchange transformation"
 msgid "Enable Loop Unroll Jam transformation"
 msgstr "Activa la transformación Loop Interchange"
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr "Activa el soporte para la memoria transaccional de GNU"
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr "Fuerza que los accesos de campos de bit coincidan con su anchura de tipo"
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr "Activa la predicción de probabilidades de ramificación"
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr "Procesa directivas #ident"
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr "Realiza la conversión de saltos condicionales a equivalentes sin ramificación"
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr "Realiza la conversión de saltos condicionales a ejecución condicional"
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, fuzzy, c-format
 #| msgid "unknown architecture %qs"
 msgid "unknown Stack Reuse Level %qs"
 msgstr "arquitectura %qs desconocida"
 
-#: common.opt:1394
+#: common.opt:1397
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr "Convierte saltos condicionales en los bucles más internos a equivalentes sin ramificación"
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr "También convierte los saltos condicionales if que contienen escrituras a memoria"
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr "No genera directivas .size"
 
-#: common.opt:1410
+#: common.opt:1413
 msgid "Perform indirect inlining"
 msgstr "Realiza la inclusión en línea indirecta"
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr "Activa la inclusión en línea de la la función declarada \"inline\", y desactiva todas las demás inclusiones en línea"
 
-#: common.opt:1420
+#: common.opt:1423
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "Integra las funciones en sus invocadores cuando se sabe que el tamaño del código no crece"
 
-#: common.opt:1424
+#: common.opt:1427
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "Integra las funciones que no se declaran \"inline\" en sus invocadores cuando es rentable"
 
-#: common.opt:1428
+#: common.opt:1431
 msgid "Integrate functions only required by their single caller"
 msgstr "Integra las funciones sólo requeridas por su invocador único"
 
-#: common.opt:1435
+#: common.opt:1438
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr "-finline-limit=<número>\tLimita el tamaño de las funciones incluídas en línea a <número>"
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "Coloca en línea las operaciones __atomic cuando una secuencia de instrucciones lock free está disponible"
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr "Instrumenta funciones de entrada y salida con llamadas de análisis de perfil"
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr "-finstrument-functions-exclude-functions-list=nombre,... No instrumenta las funciones enlistadas"
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr "-finstrument-functions-exclude-file-list=fichero,... No instrumenta las funciones enlistadas en ficheros"
 
-#: common.opt:1455
+#: common.opt:1458
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation"
 msgstr "Realiza la propagación interprocedural de las constantes"
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr "Realiza la clonación para hacer la propagación constante Interprocedural más fuerte"
 
-#: common.opt:1463
+#: common.opt:1466
 #, fuzzy
 #| msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr "Realiza la clonación para hacer la propagación constante Interprocedural más fuerte"
 
-#: common.opt:1467
+#: common.opt:1470
 msgid "Perform interprocedural profile propagation"
 msgstr "Realiza la propagación de perfil interprocedural"
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr "Realiza el análisis interprocedural de puntero-a"
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr "Descubre funciones pure y const"
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables"
 msgstr "Realiza el desenrollamiento del bucle para todos los bucles"
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr "Descubre variables estáticas de sólo lectura y no direccionables"
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr "-fira-algorithm=[CB|priority] Establece el algoritmo IRA a usar"
 
-#: common.opt:1506
+#: common.opt:1509
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "algoritmo IRA %qs desconocido"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr "-fira-region=[one|all|mixed] Establece las regiones para IRA"
 
-#: common.opt:1519
+#: common.opt:1522
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr "región IRA %qs desconocida"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr "Usa el cálculo de presión de registros basado en IRA"
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr "Comparte ranuras para ahorrar registros hard diferentes."
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Comparte ranuras de pila para pseudo-registros derramados."
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<número>\tControla el nivel de mensajes de diagnóstico de IRA."
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr "Optimiza la inducción de variables en los árboles"
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "Usa tablas de salto para las declaraciones switch suficientemente grandes"
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr "Genera código para las funciones aún si están completamente incluídas en línea"
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr "Emite variables static const aún si no se usan"
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr "Da a los símbolos externos un subrayado inicial"
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 msgid "Enable link-time optimization."
 msgstr "Activa las optimizaciones de tiempo de enlace."
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Optimización en tiempo de enlace con el número de trabajos paralelos o el servidor de trabajos."
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "modelo TLS %qs desconocido"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr "-flto-compression-level=<número>\tUsa el nivel de compresión de zlib <número> para IL"
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 msgid "Report various link-time optimization statistics"
 msgstr "Reporta varias estadísticas de optimización de tiempo de enlace"
 
-#: common.opt:1625
+#: common.opt:1628
 #, fuzzy
 #| msgid "Report various link-time optimization statistics"
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr "Reporta varias estadísticas de optimización de tiempo de enlace"
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr "Establece errno después de las funciones matemáticas internas"
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr "-fmax-errors=<número>\tNúmero máximo de errores a reportar"
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr "Reporta el alojamiento en memoria permanente"
 
-#: common.opt:1641
+#: common.opt:1644
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only"
 msgstr "Reporta el alojamiento en memoria permanente"
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr "Intenta mezclar constantes idénticas y variables constantes"
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr "Intenta mezclar constantes idénticas a través de las unidades de compilación"
 
-#: common.opt:1656
+#: common.opt:1659
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr "Intenta mezclar cadenas de depuración idénticas a través de las unidades de compilación"
 
-#: common.opt:1660
+#: common.opt:1663
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr "-fmessage-length=<número>\tLimita los diagnósticos a <número> caracteres por línea.  0 suprime el corte de línea"
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr "Realiza la calendarización SMS basada en módulo antes del primer paso de calendarización"
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr "Realiza la calendarización módulo basada en SMS con movimientos permitidos de registros"
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr "Mueve las computaciones invariantes de bucles fuera de los bucles"
 
-#: common.opt:1676
+#: common.opt:1679
 msgid "Use the RTL dead code elimination pass"
 msgstr "Usa el paso de eliminación de código muerto de RTL"
 
-#: common.opt:1680
+#: common.opt:1683
 msgid "Use the RTL dead store elimination pass"
 msgstr "Usa la eliminación de almacenamiento muerto de RTL"
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr "Activa/Desactiva la calendarización tradicional en bucles que ya pasaron la calendarización módulo"
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr "Permite las excepciones síncronas que no son llamadas"
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 #| msgid "target missing after %s"
 msgid "options or targets missing after %qs"
 msgstr "falta el objetivo después de %s"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown offload ABI %qs"
 msgstr "modelo TLS %qs desconocido"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr "Cuando sea posible no genera marcos de pila"
 
-#: common.opt:1713
+#: common.opt:1716
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable all optimization info dumps on stderr"
 msgstr "Activa las optimizaciones de bucles a nivel de árbol"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr "Optimiza las llamadas recursivas hermanadas y de extremo"
 
-#: common.opt:1729
+#: common.opt:1732
 msgid "Perform partial inlining"
 msgstr "Realiza la inclusión en línea parcial"
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr "Reporta la ubicación de memoria antes de la optimización interprocedural"
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr "Empaqueta juntos a los miembros de la estructura sin agujeros"
 
-#: common.opt:1745
+#: common.opt:1748
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr "-fpack-struct=<número>\tEstablece la alineación inicial máxima de estructuras miembro"
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr "Devuelve los agregados small en memoria, no en registros"
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr "Realiza el pelado de bucles"
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr "Activa las optimizaciones de mirilla específicas de la máquina"
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr "Activa un paso de mirilla RTL antes de sched2"
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr "Genera código independiente de posición si es posible (modo large)"
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr "Genera código independiente de posición para ejecutables si es posible (modo large)"
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr "Genera código independiente de posición si es posible (modo small)"
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr "Genera código independiente de posición para ejecutables si es posible (modo small)"
 
-#: common.opt:1781
+#: common.opt:1784
 msgid "Specify a plugin to load"
 msgstr "Especifica un plugin a cargar"
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr "-fplugin-arg-<nom>-<clave>[=<valor>]\tEspecifica el argumento <clave>=<valor> para el plugin <nom>bre"
 
-#: common.opt:1789
+#: common.opt:1792
 msgid "Run predictive commoning optimization."
 msgstr "Ejecuta la optimización comunizadora predictiva."
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr "Genera instrucciones de precargado, si están disponibles, para matrices en bucles"
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr "Activa el código básico de análisis de perfil del programa"
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr "Inserta el código de análisis de perfil de programa basado en arc"
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr "Establece el directorio de nivel principal para almacenar los datos de perfilado."
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr "Activa la corrección de datos de entrada de perfilado inconsistente de flujo"
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr "Activa las opciones comunes para generar información de análisis de perfil para optimizaciones dirigidas por retroalimentación de perfil"
 
-#: common.opt:1818
+#: common.opt:1821
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Activa las opciones comunes para generar información de análisis de perfil para optimizaciones dirigidas por retroalimentación de perfili, y establece -fprofile-dir="
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr "Activa las opciones comunes para realizar optimizaciones dirigidas por retroalimentación de perfil"
 
-#: common.opt:1826
+#: common.opt:1829
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Activa las opciones comunes para realizar optimizaciones dirigidas por retroalimentación de perfil, y establece -fprofile-dir="
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr "Inserta el código para perfilar valores de expresiones"
 
-#: common.opt:1834
+#: common.opt:1837
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Report on consistency of profile"
 msgstr "falla interna de consistencia"
 
-#: common.opt:1838
+#: common.opt:1841
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement"
 msgstr "Reordena las funciones para mejorar la ubicación del código"
 
-#: common.opt:1845
+#: common.opt:1848
 #, fuzzy
 #| msgid "-frandom-seed=<string>\tMake compile reproducible using <string>"
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr "-frandom-seed=<cadena>\tHace que se pueda reproducir la compilación utilizando la <cadena>"
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr "Guarda las opciones de la línea de órdenes de gcc en el fichero objeto."
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr "Devuelve agregados small en registros"
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 #, fuzzy
 #| msgid "Enable register pressure sensitive insn scheduling"
 msgid "Relief of register pressure through live range shrinkage"
 msgstr "Activa la calendarización de insn sensible a la presión de registros"
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr "Realiza el paso de optimización de renombrado de registros"
 
-#: common.opt:1880
+#: common.opt:1883
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr "Realiza el paso de optimización de renombrado de registros"
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr "Reordena los bloques básicos para mejorar la ubicación del código"
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr "Reordena los bloques básicos y particionar en secciones caliente y fría"
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr "Reordena las funciones para mejorar la ubicación del código"
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr "Ejecuta un paso de eliminación de subexpresión común después de las optimizaciones de bucles"
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr "Desactiva las optimizaciones que asumen la conducta de un FP que redondea por defecto"
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr "Activa la calendarización entre bloques básicos"
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr "Activa la calendarización de insn sensible a la presión de registros"
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr "Permite el movimiento especulativo de insn que no son load"
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr "Permite el movimiento especulativo de algunas loads"
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr "Permite el movimiento especulativo de más loads"
 
-#: common.opt:1928
+#: common.opt:1931
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr "-fsched-verbose=<número>\tEstablece el nivel de detalle del calendarizador"
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr "Si se calendariza después de la recarga, hace la calendarización de superbloque"
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr "Recalendariza las instrucciones antes del alojamiento de registros"
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr "Recalendariza las instrucciones después del alojamiento de registros"
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr "Calendariza instrucciones usando el algoritmo de calendarización selectivo"
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr "Ejecuta la calendarización selectiva después de recargar"
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr "Realiza el `pipelining' de software de los bucles internos durante la calendarización selectiva"
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr "Realiza el `pipelining' de software de los bucles externos durante la calendarización selectiva"
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr "Recalendariza las regiones `pipelined' sin `pipelining'"
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr "Permite la calendarización prematura de insns encoladas"
 
-#: common.opt:1981
+#: common.opt:1984
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr "-fsched-stalled-insns=<número>\tEstablece el número de insns encoladas que se pueden calendarizar prematuramente"
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr "Establece la revisión de distancia de dependencias en la calendarización prematura de insns encoladas"
 
-#: common.opt:1993
+#: common.opt:1996
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr "-fsched-stalled-insns-dep=<número>\tEstablece la revisión de distancia de dependencias en la calendarización prematura de insns encoladas"
 
-#: common.opt:1997
+#: common.opt:2000
 msgid "Enable the group heuristic in the scheduler"
 msgstr "Activa la heurística de grupo en el calendarizador"
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr "Activa la heurística de ruta crítica en el calendarizador"
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr "Activa la heurística de instrucción especulativa en el calendarizador"
 
-#: common.opt:2009
+#: common.opt:2012
 msgid "Enable the rank heuristic in the scheduler"
 msgstr "Activa la heurística de rango en el calendarizador"
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr "Activa la heurística de última instrucción en el calendarizador"
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr "Activa la heurística de cuenta dependiente en el calendarizador"
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr "Accede datos en la misma sección que los puntos de anclaje compartidos"
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "Activa el paso de Eliminación de Extensiones Redundantes."
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr "Muestra los números de columna en los diagnósticos, cuando estén disponible.  Activado por defecto"
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr "Emite prólogos de función sólo después de que las partes de la función que los necesitan,"
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr "Desactiva las optimizaciones observables con IEEE señalando NaNs"
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr "Desactiva las optimizaciones de coma flotante que ignoran el signo de IEEE para cero"
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr "Convierte las constantes de coma flotante a constantes de precisión simple"
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr "Divide los tiempos de vida de las variables de inducción cuando se desenrollen los bucles"
 
-#: common.opt:2062
+#: common.opt:2065
 msgid "Generate discontiguous stack frames"
 msgstr "Genera marcos de pila discontiguos"
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr "Divide los tipos anchos en registros independientes"
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 #, fuzzy
 #| msgid "fixed register %s used to pass parameter to function"
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr "se usó el registro fijo %s para pasar un parámetro a la función"
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr "Aplica la expansión de variables cuando se desenrollan los bucles"
 
-#: common.opt:2082
+#: common.opt:2085
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "-fstack-check=[no|generic|specific]\tInserta código de revisión de la pila en el programa"
 
-#: common.opt:2086
+#: common.opt:2089
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "Inserta código de revisión de la pila en el programai.  Igual que -fstach-check=specific"
 
-#: common.opt:2093
+#: common.opt:2096
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr "-fstack-limit-register=<register>\tCaptura si la pila pasa del <registro>"
 
-#: common.opt:2097
+#: common.opt:2100
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr "-fstack-limit-symbol=<nombre>\tCaptura si la pila pasa del símbolo <nombre>"
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr "Usa propolice como un método de protección de pila"
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr "Usa un método de protección de pila para cada función"
 
-#: common.opt:2109
+#: common.opt:2112
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions"
 msgstr "Usa un método de protección de pila para cada función"
 
-#: common.opt:2113
+#: common.opt:2116
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr "Usa un método de protección de pila para cada función"
 
-#: common.opt:2117
+#: common.opt:2120
 msgid "Output stack usage information on a per-function basis"
 msgstr "Información de uso de pila de salida basada por función"
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr "Asume que se aplican las reglas estrictas de alias"
 
-#: common.opt:2133
+#: common.opt:2136
 msgid "Treat signed overflow as undefined"
 msgstr "Trata el desbordamiento de signo como indefinido"
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr "Busca errores de sintaxis, y termina"
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr "Crea ficheros de datos necesarios para \"gcov\""
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr "Realiza optimizaciones de hilado de saltos"
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr "Reporta el tiempo tomado por cada paso del compilador"
 
-#: common.opt:2157
+#: common.opt:2160
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tEstablece el modelo de generación de código por defecto para almacenamiento thread-local"
 
-#: common.opt:2160
+#: common.opt:2163
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "modelo TLS %qs desconocido"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr "Reordena las funciones de nivel superior, variables y asms"
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr "Realiza la formación de superbloques a través de la duplicación de colas"
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr "Asume que las operaciones de coma flotante pueden atrapar"
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr "Atrapar desbordamientos signed en adición, sustracción y multiplicación"
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr "Activa la optimización SSA-CCP en árboles"
 
-#: common.opt:2199
+#: common.opt:2202
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr "Activa la optimización SSA-BIT-CCP en árboles"
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr "Activa la copia de encabezado de bucles en árboles"
 
-#: common.opt:2211
+#: common.opt:2214
 #, fuzzy
 #| msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr "Realiza el seguimiento de variables y también marca las variables que no se inicializaron"
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr "Reemplaza temporales SSA con mejores nombres en las copias"
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr "Activa la propagación de copia en árboles"
 
-#: common.opt:2231
+#: common.opt:2234
 msgid "Transform condition stores into unconditional ones"
 msgstr "Transforma los almacenamientos condicionales a incondicionales"
 
-#: common.opt:2235
+#: common.opt:2238
 msgid "Perform conversions of switch initializations."
 msgstr "Realiza la conversión de las inicializaciones de switch."
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr "Activa la optimización de eliminación de código muerto SSA en árboles"
 
-#: common.opt:2243
+#: common.opt:2246
 msgid "Enable dominator optimizations"
 msgstr "Activa las optimizaciones dominadoras"
 
-#: common.opt:2247
+#: common.opt:2250
 msgid "Enable tail merging on trees"
 msgstr "Activa la mezcla de colas en árboles"
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr "Activa la eliminación de almacenamiento muerto"
 
-#: common.opt:2255
+#: common.opt:2258
 msgid "Enable forward propagation on trees"
 msgstr "Activa la propagación hacia adelante en árboles"
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr "Activa la Eliminación de Redundancia Completa en árboles"
 
-#: common.opt:2263
+#: common.opt:2266
 msgid "Enable string length optimizations on trees"
 msgstr "Activa la optimizaciones de longitud de cadenas en árboles"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 msgid "Enable loop distribution on trees"
 msgstr "Activa la distribución de bucles en árboles"
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr "Activa la distribución de bucles por patrones transformados en una llamada a biblioteca"
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr "Permite el movimiento invariante de bucles en árboles"
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr "Activa las transformaciones de intercambio de bucle.  Igual que -floop-interchange"
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr "Crea variables de inducción canónica en los bucles"
 
-#: common.opt:2300
+#: common.opt:2303
 msgid "Enable loop optimizations on tree level"
 msgstr "Activa las optimizaciones de bucles a nivel de árbol"
 
-#: common.opt:2304
+#: common.opt:2307
 msgid "Enable automatic parallelization of loops"
 msgstr "Activa la paralelización automática de bucles"
 
-#: common.opt:2308
+#: common.opt:2311
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Activa las cargas de elevación de punteros condicionales."
 
-#: common.opt:2312
+#: common.opt:2315
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "Activa las optimizaciones SSA-PRE en árboles"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Realiza el análisis puntero-a función-local en árboles."
 
-#: common.opt:2324
+#: common.opt:2327
 msgid "Enable reassociation on tree level"
 msgstr "Activa la reasociación a nivel de árbol"
 
-#: common.opt:2332
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
 msgstr "Activa el hundimiento de código SSA en árboles"
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr ""
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr "Realiza el reemplazo escalar de agregados"
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr "Reemplaza expresiones temporales en el paso SSA->normal"
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr "Realizar la división de rango vivo durante el paso SSA->normal"
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr "Realiza la Propagación de Rango Valor en árboles"
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr "Compila la unidad de compilación completa a la vez"
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr "Realiza el desenrollamiento del bucle cuando se conoce la cuenta de iteración"
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr "Realiza el desenrollamiento del bucle para todos los bucles"
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr "Permite que las optimizaciones de bucle asuman que los bucles se comportan normalmente"
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr "Permite la optimización para la aritmética de coma flotante la cual puede cambiar"
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Igual que -fassociative-math para las expresiones que incluyen división."
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr "Permite optimizaciones matemáticas que pueden violar los estándares IEEE ó ISO"
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr "Realiza la eliminación de opciones de bucle"
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr "Sólo genera tablas de desenredo para manejo de excepciones"
 
-#: common.opt:2400
+#: common.opt:2403
 #, fuzzy
 #| msgid "Use the hardware barrel shifter instead of emulation"
 msgid "Use the bfd linker instead of the default linker"
 msgstr "Usa el corredor de barril de hardware en lugar de la emulación"
 
-#: common.opt:2404
+#: common.opt:2407
 #, fuzzy
 #| msgid "Use the hardware barrel shifter instead of emulation"
 msgid "Use the gold linker instead of the default linker"
 msgstr "Usa el corredor de barril de hardware en lugar de la emulación"
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr "Realiza seguimiento de variables"
 
-#: common.opt:2424
+#: common.opt:2427
 msgid "Perform variable tracking by annotating assignments"
 msgstr "Realiza seguimiento de variables con asignación de anotaciones"
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr "Cambia -fvar-tracking-assignments"
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr "Realiza el seguimiento de variables y también marca las variables que no se inicializaron"
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees"
 msgstr "Activa la vectorización de bucles en árboles"
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr "Activa la vectorización de bucles en árboles"
 
-#: common.opt:2454
+#: common.opt:2457
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr "Activa la vectorización de bloque básico (SLP) en árboles"
 
-#: common.opt:2458
+#: common.opt:2461
 #, fuzzy
 #| msgid "Enable use of cost model in vectorization"
 msgid "Specifies the cost model for vectorization"
 msgstr "Activa el uso del modelo costo en la vectorización"
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "modelo TLS %qs desconocido"
 
-#: common.opt:2478
+#: common.opt:2481
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "No hace nada.  Se preserva por compatibilidad hacia atrás."
 
-#: common.opt:2482
+#: common.opt:2485
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr "No hace nada.  Se preserva por compatibilidad hacia atrás."
 
-#: common.opt:2490
+#: common.opt:2493
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Activa la propagación de copia de la información escalar-evolución."
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr "Agrega comentarios extra a la salida de ensamblador"
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr "-fvisibility=[default|internal|hidden|protected]\tEstablece la visibilidad de símbolos por defecto"
 
-#: common.opt:2507
+#: common.opt:2510
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "no se reconoce el valor de visibilidad %qs"
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(cerca de la inicialización de %qs)"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr "Usa perfiles de valor de expresión en las optimizaciones"
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr "Construye redes y divide usos no relacionados de una sola variable"
 
-#: common.opt:2555
+#: common.opt:2558
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr "Activa la eliminación de código muerto condicional para llamadas internas"
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr "Realiza optimizaciones del programa completo"
 
 # wraps around? No entiendo bien. cfuga
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr "Asume que el desbordamiento aritmético con signo se envuelve"
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr "Pone los datos inicializados a cero en la sección bss"
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr "Genera información de depuración en el formato por defecto"
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr "Genera información de depuración en el formato COFF"
 
-#: common.opt:2579
+#: common.opt:2582
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format"
 msgstr "Genera información de depuración en el formato por defecto"
 
-#: common.opt:2583
+#: common.opt:2586
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr "Genera información de depuración en el formato DWARF v2 (o posterior)"
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr "Genera información de depuración en el formato extendido por defecto"
 
-#: common.opt:2591
+#: common.opt:2594
 #, fuzzy
 #| msgid "Don't generate fused multiply/add instructions"
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "No genera instrucciones multiply/add de corto circuito"
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr "No guarda las opciones de la línea de órdenes de gcc en DW_AT_producer de DWARF."
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Guarda las opciones de la línea de órdenes de gcc en DW_AT_producer de DWARF."
 
-#: common.opt:2611
+#: common.opt:2614
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Don't generate debug information in separate .dwo files"
 msgstr "Genera información de depuración en el formato por defecto"
 
-#: common.opt:2615
+#: common.opt:2618
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files"
 msgstr "Genera información de depuración en el formato por defecto"
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr "Genera información de depuración en el formato STABS"
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr "Genera información de depuración en el formato STABS extendido"
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr "Emite adiciones DWARF más allá de la versión seleccionada"
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr "No emite adiciones DWARF más allá de la versión seleccionada"
 
-#: common.opt:2635
+#: common.opt:2638
 msgid "Toggle debug information generation"
 msgstr "Cambia la generación de información de depuración"
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr "Genera información de depuración en el formato VMS"
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr "Genera información de depuración en el formato XCOFF"
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr "Genera información de depuración en el formato XCOFF extendido"
 
-#: common.opt:2665
+#: common.opt:2668
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections"
 msgstr "Genera instrucciones isel"
 
-#: common.opt:2669
+#: common.opt:2672
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr "Genera información de depuración en el formato por defecto"
 
-#: common.opt:2676
+#: common.opt:2679
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr "-iplugindir=<dir>\tDefine <dir> como el directorio de plugins por defecto"
 
-#: common.opt:2680
+#: common.opt:2683
 #, fuzzy
 #| msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr "-imultilib <dir>\tDefine <dir> como el subdirectorio de inclusión de multilib"
 
-#: common.opt:2702
+#: common.opt:2705
 msgid "-o <file>\tPlace output into <file>"
 msgstr "-o <fichero>\tColoca la salida en el <fichero>"
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr "Activa el análisis de perfil de las funciones"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr "Como -pedantic pero los muestra como errores"
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr "No muestra las funciones compiladas o el tiempo transcurrido"
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr "Activa la salida detallada"
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr "Muestra la versión del compilador"
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "Suprime avisos"
 
-#: common.opt:2806
+#: common.opt:2809
 msgid "Create a shared library"
 msgstr "Crea una biblioteca compartida"
 
-#: common.opt:2851
+#: common.opt:2854
 msgid "Create a position independent executable"
 msgstr "Genera un ejecutable independiente de posición"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "no se usa el valor calculado"
@@ -15112,233 +15122,233 @@
 msgid "expected integer or boolean type"
 msgstr "se esperaba un tipo entero o booleano"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 #, fuzzy
 #| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of nil with nil"
 msgstr "código de comparación inválido en la condición gimple"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 msgid "incompatible types in binary expression"
 msgstr "tipos incompatibles en la expresión binaria"
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 #| msgid "division by zero"
 msgid "integer division by zero"
 msgstr "división por cero"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 msgid "shift of non-integer operand"
 msgstr "desplazamiento de un operando que no es entero"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 msgid "shift count not unsigned integer"
 msgstr "la cuenta de desplazamiento no es un entero sin signo"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 msgid "negative shift count"
 msgstr "cuenta de desplazamiento negativa"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 msgid "object is not a method"
 msgstr "el objeto no es un método"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 msgid "method type does not match object type"
 msgstr "el tipo de método no coincide con el tipo de objeto"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 msgid "invalid use of %<...%> with builtin function"
 msgstr "uso inválido de %<..%> con la función interna"
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 #, fuzzy
 #| msgid "invalid use of template-name %qE without an argument list"
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "uso inválido del nombre-de-plantilla %qE sin una lista de argumentos"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 msgid "not enough arguments"
 msgstr "faltan argumentos"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 msgid "too many arguments"
 msgstr "demasiados argumentos"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 msgid "argument 1 must be a map"
 msgstr "el argumento 1 debe ser un mapa"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 msgid "invalid type for make function"
 msgstr "tipo inválido para la función make"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr "se requiere longitud al alojar una rebanada"
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 msgid "too many arguments to make"
 msgstr "demasiados argumentos para make"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 msgid "argument must be array or slice or channel"
 msgstr "el argumento debe ser matriz o rebanada o canal"
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr "el argumento debe ser cadena o matriz o rebanada o mapa o canal"
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 msgid "unsupported argument type to builtin function"
 msgstr "no se admite el tipo de argumento para la función interna"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 msgid "argument must be channel"
 msgstr "el argumento debe ser canal"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr "no se puede cerrar un canal de sólo recepción"
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 msgid "argument must be a field reference"
 msgstr "el argumento debe ser una referencia de campo"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 msgid "left argument must be a slice"
 msgstr "el argumento izquierdo debe ser una rebanada"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr "los tipos de elemento deben ser el mismo"
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 msgid "first argument must be []byte"
 msgstr "el primer argumento debe ser []byte"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 msgid "second argument must be slice or string"
 msgstr "el segundo argumento debe ser una rebanada o una cadena"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 msgid "argument 2 has invalid type"
 msgstr "el argumento 2 es de tipo inválido"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 msgid "argument must have complex type"
 msgstr "el argumento debe tener tipo complejo"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 msgid "complex arguments must have identical types"
 msgstr "los argumentos complejos deben tener tipos idénticos"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 msgid "complex arguments must have floating-point type"
 msgstr "los argumentos complejos deben tener tipo de coma flotante"
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 msgid "expected function"
 msgstr "se esperaba función"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 #, fuzzy
 #| msgid "multiple value function call in single value context"
 msgid "multiple-value argument in single-value context"
 msgstr "llamada a función de valor múltiple en un contexto de un solo valor"
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 msgid "invalid use of %<...%> with non-slice"
 msgstr "uso inválido de %<...%> con algo que no es rebanada"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 #, fuzzy
 #| msgid "Function return value not set"
 msgid "function result count mismatch"
 msgstr "La función devuelve un valor no establecido"
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 msgid "incompatible type for receiver"
 msgstr "tipo incompatible para el receptor"
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "uso inválido de %<...%> en la llamada a la función que no es variadic"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 msgid "number of results does not match number of values"
 msgstr "el número de resultados no coincide con el número de valores"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 msgid "index must be integer"
 msgstr "el índice debe ser entero"
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 msgid "slice end must be integer"
 msgstr "el final de la rebanada debe ser entero"
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 #| msgid "slice end must be integer"
 msgid "slice capacity must be integer"
 msgstr "el final de la rebanada debe ser entero"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr "rebanada con valor que no es direccionable"
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 msgid "incompatible type for map index"
 msgstr "tipo incompatibles para el índice de mapa"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr "se esperaba interfaz o puntero a interfaz"
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 msgid "too many expressions for struct"
 msgstr "demasiadas expresiones para struct"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 msgid "too few expressions for struct"
 msgstr "faltan expresiones para struct"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 msgid "type assertion only valid for interface types"
 msgstr "la aserción de tipo sólo es válida para los tipos de interfaz"
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr "aserción de tipo imposible: el tipo no implementa interfaz"
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 msgid "expected channel"
 msgstr "se esperaba canal"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr "recepción inválida en canal de sólo envío"
 
@@ -15452,72 +15462,72 @@
 msgid "cannot use type %s as type %s"
 msgstr "no se puede usar el tipo %s como tipo %s"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 msgid "different receiver types"
 msgstr "tipos de receptor diferentes"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 msgid "different number of parameters"
 msgstr "número diferente de parámetros"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 msgid "different parameter types"
 msgstr "tipos de parámetro diferentes"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr "varargs diferentes"
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr "número diferente de resultados"
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 msgid "different result types"
 msgstr "tipos de resultado diferentes"
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "se necesita conversión explícita; falta el método %s%s%s"
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "tipo incompatible para el método %s%s%s"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "tipo incompatible para el método %s%s%s (%s)"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr "el puntero a tipo de interfaz no tiene métodos"
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 msgid "type has no methods"
 msgstr "el tipo no tiene métodos"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "método ambiguo %s%s%s"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "falta el método %s%s%s"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, fuzzy, c-format
 #| msgid "method %s%s%s requires a pointer"
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "el método %s%s%s requiere un puntero"
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, fuzzy, c-format
 #| msgid "method %s%s%s requires a pointer"
 msgid "method %s%s%s is marked go:nointerface"
@@ -15645,7 +15655,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "el tercer argumento para %<__builtin_prefetch%> es inválido; se usa cero"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "faltan argumentos para la función %<va_start%>"
@@ -15829,12 +15839,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kse intenta liberar un objeto que no es de pila"
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "la llamada a la función tiene valor agregado"
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT for argument %P to %qD"
 msgid "passing too large argument on stack"
@@ -16413,256 +16423,261 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "el número de notas bb en la cadena insn (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr "la cuenta de borde llamador es negativa"
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr "la frecuencia de borde llamador es negativa"
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr "la frecuencia de borde llamador es demasiado grande"
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "campo aux establecido para el borde %s->%s"
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, gcc-internal-format
 msgid "execution count is negative"
 msgstr "la cuenta de ejecución es negativa"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, fuzzy, gcc-internal-format
 #| msgid "node is alone in a comdat group"
 msgid "inline clone in same comdat group list"
 msgstr "el nodo está solo en un grupo comdat"
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Asume que los símbolos pueden ser inválidos"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "clon incluído en línea visible externamente"
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "clon incluído en línea con dirección tomada"
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, fuzzy, gcc-internal-format
 #| msgid "inline clone is needed"
 msgid "inline clone is forced to output"
 msgstr "se necesita un clon incluído en línea"
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "se define el campo aux para el borde indirecto desde %s"
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Un borde indirecto de %s no está marcado como indirecto o tiene indirect_info asociado, la declaración correspondiente es: "
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "el puntero inlined_to está mal"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "múltiples llamantes inline"
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "se estableció el puntero inlined_to para llamantes no-inline"
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr "la frecuencia de borde llamador %i no coincide con la frecuencia BB %i"
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "caller edge frequency %i does not match BB frequency %i"
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr "la frecuencia de borde llamador %i no coincide con la frecuencia BB %i"
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "se estableció el puntero inlined_to, pero no se encontraron predecesores"
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "el puntero inlined_to se refiere a sí mismo"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, fuzzy, gcc-internal-format
 #| msgid "node has wrong clone_of"
 msgid "cgraph_node has wrong clone_of"
 msgstr "el nodo tiene un clone_of erróneo"
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, fuzzy, gcc-internal-format
 #| msgid "node has wrong clone list"
 msgid "cgraph_node has wrong clone list"
 msgstr "el nodo tiene una lista de clones errónea"
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "node is in clone list but it is not clone"
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "el nodo está en la lista de clones pero no es clon"
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, fuzzy, gcc-internal-format
 #| msgid "node has wrong prev_clone pointer"
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "el nodo tiene un puntero prev_clone erróneo"
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "lista de clones doblemente ligada corrrupta"
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Alias tiene bordes de llamada"
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Alias tiene una referencia que no es alias"
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Alias tiene más de una referencia alias"
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "El alias analizado no tiene referencia"
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "la alineación de %qD es más grande que la declaración original"
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "Instrumented node has wrong original declaration"
 msgstr "la alineación de %qD es más grande que la declaración original"
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, fuzzy, gcc-internal-format
 #| msgid "Alias has more than one alias reference"
 msgid "Node has more than one chkp reference"
 msgstr "Alias tiene más de una referencia alias"
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare references to references"
 msgid "Wrong node is referenced with chkp reference"
 msgstr "no se pueden declarar referencias a referencias"
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, fuzzy, gcc-internal-format
 #| msgid "Analyzed alias has no reference"
 msgid "Analyzed node has no reference to instrumented version"
 msgstr "El alias analizado no tiene referencia"
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "No hay un borde fuera de un nodo thunk"
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Más de un borde fuera de un nodo thunk"
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "No se supone que thunk tenga cuerpo"
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "call_stmt compartida:"
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "puntos de borde para una declaración errónea:"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "un borde indirecto con un llamante desconocido que corresponde a call_stmt con una declaración conocida:"
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "falta el borde de callgraph para la llamada stmt:"
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "se esperaba una declaración"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "el borde %s->%s no tiene un call_stmt correspondiente"
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "un borde indirecto desde %s no tiene un call_stmt correspondiente"
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "falló verify_cgraph_node"
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "%s: falta la sección %s"
@@ -16794,7 +16809,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "se debe definir COLLECT_LTO_WRAPPER"
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, gcc-internal-format
 msgid "atexit failed"
@@ -17037,17 +17052,17 @@
 msgid "          %s"
 msgstr "          %s"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr "la información de depuración de símbolos comunes no está estructurada como símbolo+desplazamiento"
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "no se admiten los destructores globales en este objetivo"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "no se admiten constructores globales en este objetivo"
@@ -17093,12 +17108,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "sólo se admiten múltiples personalidades EH con ensambladores que admiten la directiva cfi.personality"
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "se encontró UNSPEC %s (%d) que no está delegitimado la ubicación de variable"
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -17295,7 +17310,7 @@
 msgid "total size of local objects too large"
 msgstr "el tamaño total de los objetos locales es demasiado grande"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "restricción imposible en %<asm%>"
@@ -17752,9 +17767,9 @@
 msgstr "no se puede escribir el fichero PCH"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, gcc-internal-format
 msgid "declared here"
 msgstr "se declara aquí"
@@ -17769,164 +17784,158 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr "revisión gimple: se esperaba %s(%s), se tiene %s(%s) en %s, en %s:%d"
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "se usa el resultado de una función que devuelve %<void%>"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "l-valor inválido en la salida asm %d"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "la entrada que no es de memoria %d debe permanecer en memoria"
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "la entrada de memoria %d no es directamente direccionable"
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, fuzzy, gcc-internal-format
 #| msgid "threadprivate variable %qE used in untied task"
 msgid "threadprivate variable %qE used in target region"
 msgstr "se usó la variable threadprivate %qE en una tarea sin atar"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing task"
 msgid "enclosing target region"
 msgstr "tarea contenedora"
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "se usó la variable threadprivate %qE en una tarea sin atar"
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "tarea contenedora"
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr "no se especificó %qE en el paralelo que lo contiene"
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr "paralelo contenedor"
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, fuzzy, gcc-internal-format
 #| msgid "%qE not specified in enclosing parallel"
 msgid "%qE not specified in enclosing task"
 msgstr "no se especificó %qE en el paralelo que lo contiene"
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, fuzzy, gcc-internal-format
 #| msgid "%qE not specified in enclosing parallel"
 msgid "%qE not specified in enclosing teams construct"
 msgstr "no se especificó %qE en el paralelo que lo contiene"
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing task"
 msgid "enclosing teams construct"
 msgstr "tarea contenedora"
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 #| msgid "%Hiteration variable %qE is unsigned"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%Hla variable de iteración %qE no tiene signo"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "la variable de iteración %qE debe ser private"
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "la variable de iteración %qE no debe ser firstprivate"
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "la variable de iteración %qE no debe ser reduction"
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qE should not be firstprivate"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "la variable de iteración %qE no debe ser firstprivate"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qE should be private"
 msgid "iteration variable %qE should not be private"
 msgstr "la variable de iteración %qE debe ser private"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qE is private in outer context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "la variable %s %qE es private en el contexto externo"
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "la variable %s %qE es private en el contexto externo"
 
-#: gimplify.c:7001
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, fuzzy, gcc-internal-format
-#| msgid "%s variable %qE is private in outer context"
-msgid "lastprivate variable %qE is private in outer context"
-msgstr "la variable %s %qE es private en el contexto externo"
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
-#, fuzzy, gcc-internal-format
 #| msgid "Finalization at %L is not yet implemented"
 msgid "directive not yet implemented"
 msgstr "Aún no se admite la finalización en %L"
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "se esperaba %<}%> antes de %<else%>"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "falló la gimplificación"
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "el primer argumento para %<va_arg%> no es del tipo %<va_list%>"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT se promueve a %qT cuando pasa a través de %<...%>"
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(así que debe pasar %qT y no %qT a %<va_arg%>)"
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "si se alcanza este código, el programa abortará"
@@ -18360,48 +18369,48 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "bytecode stream: found multiple instances of cgraph node %d"
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "flujo de bytecode: se encontraron instancias múltiples del nodo cgraph %d"
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "flujo de bytecode: no se encontró un llamante al leer el borde"
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "flujo de bytecode: no se encontró un llamado al leer el borde"
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "flujo de bytecode: se encontró un nodo cgraph vacío"
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "Por lo menos se admiten %i corridas de perfil. ¿Tal vez se corrompió el perfil?"
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "La información de análisis de perfil en %s está corrupta"
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "no se puede encontrar cgraph de LTO en %s"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "no se pueden encontrar las referencias de sección LTO en %s"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -18489,49 +18498,49 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "COLLECT_GCC_OPTIONS malformado"
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "no hay ficheros de entrada"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing output file '%s'\n"
 msgid "writing output file"
 msgstr "Error al escribir el fichero de salida '%s'\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "se debe establecer la variable de ambiente COLLECT_GCC"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "se debe establecer la variable de ambiente COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s: %m"
 msgid "fopen: %s: %m"
@@ -18674,13 +18683,13 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid exit from OpenMP structured block"
 msgid "invalid exit from %s structured block"
 msgstr "salida inválida de un bloque estructurado OpenMP"
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid entry to OpenMP structured block"
 msgid "invalid entry to %s structured block"
@@ -18687,19 +18696,19 @@
 msgstr "entrada inválida a un bloque estructurado OpenMP"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid branch to/from an OpenMP structured block"
 msgid "invalid branch to/from %s structured block"
 msgstr "ramificación inválida desde/para un bloque estructurado OpenMP"
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring pragma: %s"
 msgid "ignoring large linear step"
 msgstr "ignorando el pragma: %s"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -19236,8 +19245,8 @@
 msgstr "no se puede usar %qs como un registro fijo"
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "nombre de registro desconocido: %s"
@@ -19690,7 +19699,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld devolvió el estado de salida %d"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "se usa %q+F pero nunca se define"
@@ -20687,42 +20696,42 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr ""
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -21108,47 +21117,47 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, gcc-internal-format
 msgid "array subscript is outside array bounds"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, gcc-internal-format
 msgid "array subscript is above array bounds"
 msgstr "el subíndice de la matriz está por arriba de los límites de la matriz"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, gcc-internal-format
 msgid "array subscript is below array bounds"
 msgstr "el subíndice de la matriz está por debajo de los límites de la matriz"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr "se asume que el desbordamiento con signo no sucede al simplificar el condicional a constante"
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr "se asume que el desbordamiento con signo no sucede al simplificar el condicional"
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr "la comparación siempre es falsa debido al rango limitado del tipo de datos"
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr "la comparación siempre es verdadera debido al rango limitado del tipo de datos"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr "se asume que el desbordamiento con signo no sucede al simplificar %</%> o %<%%%> a %<>>%> o %<&%>"
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr "se asume que el desbordamiento con signo no sucede al simplificar %<abs (X)%> a %<X%> o %<-X%>"
@@ -21192,9 +21201,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21431,7 +21440,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "la alineación solicitada para %q+D es mayor que la alineación implementada de %wu"
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "no se conoce el tamaño de almacenamiento de %q+D"
@@ -21588,27 +21597,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "la longitud de la cadena %qd es mayor que la longitud %qd, la máxima que los compiladores ISO C%d deben admitir"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "la cuenta de desplazamiento a la izquierda es negativa"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "la cuenta de desplazamiento a la derecha es negativa"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "cuenta de desplazamiento a la izquierda >= anchura del tipo"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "cuenta de desplazamiento a la derecha >= anchura del tipo"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "desbordamiento en la expresión constante"
@@ -21946,12 +21955,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "la dirección de %qD siempre se evaluará como %<true%>"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "se sugieren paréntesis alrededor de la asignación usada como valor verdadero"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "uso inválido de %<restrict%>"
@@ -22409,12 +22418,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "tipo de vector inválido para el atributo %qE"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "el tamaño del vector no es un múltiplo integral del tamaño del componente"
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "vector de tamaño cero"
@@ -22424,22 +22433,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr "el número de componentes del vector no es una potencia de dos"
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "un atributo que no es nulo sin argumento es un atributo que no es prototipo"
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "un argumento que no es nulo tiene un número de operando inválido (argumento %lu)"
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "un argumento que no es nulo con número de operando fuera de rango (argumento %lu, operando %lu)"
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "un argumento que no es nulo hace referencia a un operando que no es puntero (argumento %lu, operando %lu)"
@@ -22479,12 +22488,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "el atributo %qE se aplica solamente a funciones variadic"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "la posición solicitada no es una constante entera"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "la posición solicitada es menor a cero"
@@ -22568,7 +22577,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "no se puede aplicar %<offsetof%> a una dirección que no es constante"
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "se intentó tomar la dirección del miembro de la estructura de campos de bits %qD"
@@ -22987,7 +22996,7 @@
 msgstr "el valor del índice está fuera del límite"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of scalar to vector involves truncation"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -23444,7 +23453,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> usa dos variables diferentes para la memoria"
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipo inválido para la variable de iteración %qE"
@@ -23454,22 +23463,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE no está inicializado"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "falta el predicado controlador"
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predicado controlador inválido"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "falta la expresión de incremento"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "expresión de incremento inválida"
@@ -24014,6 +24023,12 @@
 msgid "too many input files"
 msgstr "demasiados ficheros de entrada"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+#| msgid "INIT string too large for mode"
+msgid "-mcpu string too large"
+msgstr "la cadena INIT es demasiado grande para el modo"
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -24040,47 +24055,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s tiene una versión de silicio inválida"
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops es obsoleto, use -falign-loops"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d no está entre 0 y %d"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps es obsoleto, use -falign-jumps"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d no está entre 0 y %d"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions es obsoleto, use -falign-functions"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d no está entre 0 y %d"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d no está entre 0 y 5"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "sólo se admite %<-fsplit-stack%> en GNU/Linux"
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> requiere soporte del ensamblador para las directivas CFI"
@@ -24478,63 +24493,63 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr "número de línea fuera de rango"
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "valor %qs erróneo para el interruptor -mtrap-precision"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "valor %qs erróneo para el interruptor -mfp-rounding-mode"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "valor %qs erróneo para el interruptor -mfp-trap-mode"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr "valor %qs erróneo para el interruptor -mcpu"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, gcc-internal-format
 msgid "bad value %qs for -mtune switch"
 msgstr "valor erróneo %qs para la opción -mtune"
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr "el completado por software de fp requiere una opción -mtrap-precision=i"
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "el modo de redondeo no se admite para floats de VAX"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "el modo de captura no se admite para valores de coma flotante VAX"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr "los long double de 128 bits no se admiten para valores de coma flotante VAX"
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr "latencia de caché L%d desconocida para %s"
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr "valor %qs erróneo para -mmemory-latency"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -25019,14 +25034,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, gcc-internal-format
 msgid "%qE attribute only applies to functions"
@@ -25698,391 +25713,409 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "no se puede establecer la posición en el fichero PCH: %m"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-Werror=%s: no option -%s"
 msgid "wrong arg %s to option %s"
 msgstr "-Werror=%s: no existe la opción -%s"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "no se especifica un nombre de registro para %q+D"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr "no se admite -mstringop-stategy=rep_8byte para código de 32-bit"
+
+#: config/i386/i386.c:3012
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "alignment specified for function %qE"
 msgid "unknown alignment %s specified for option %s"
 msgstr "se especificó la alineación para la función %qE"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid range %s in option %s"
 msgid "too many size ranges specified in option %s"
 msgstr "Rango %s inválido en la opción %s"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown argument list function at %L"
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "Lista de argumentos de función desconocida en %L"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr "%stune=x86-64%s es obsoleto; use en su lugar %stune=k8%s o %stune=generic%s como sea adecuado"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "no se admite -mstringop-stategy=rep_8byte para código de 32-bit"
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "el modelo de código %qs no se admite en el modo de bit %s"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "el modelo de código %qs no se admite en el modo de bit %s"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "el modelo de código %qs no se admite en modo x32"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "el modelo de código %s no admite el modo PIC"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "no se admite -masm=intel en esta configuración"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "no está compilado el modo bit-%i"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "el CPU que seleccionó no admite el conjunto de instrucciones x86-64"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support APCS-26"
 msgid "Intel MPX does not support x32"
 msgstr "el CPU objetivo no tiene soporte para APCS-26"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr "el CPU generic sólo se puede usar para %stune=%s %s"
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr "el CPU generic sólo se puede usar para %stune=%s %s"
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "valor erróneo (%s) para %sarch=%s %s"
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "valor erróneo (%s) para %stune=%s %s"
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "se descarta -mregparm en modo de 64-bit"
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d no está entre 0 y %d"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr "se descarta %srtd%s en el modo de 64bit"
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "no se admite -mpreferred-stack-boundary en este objetivo"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d no está entre %d y %d"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d no está entre %d y 12"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mno-fentry no es compatible con SEH"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "no se han implementado las optimizaciones intermódulos para C++"
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr "se usó %ssseregparm%s sin SSE activado"
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "el conjunto de instrucciones SSE está desactivado, usando la aritmética 387"
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "el conjunto de instrucciones 387 está desactivado, usando la aritmética SSE"
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr "actualmente la prueba de pila requiere un puntero de marco o %saccumulate-outgoing-args%s para ser correctas"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry no se admite para 32-bit en combinación con -fpic"
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry no es compatible con SEH"
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "opción desconocida para -mrecip=%s"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %qE argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "el argumento del atributo %qE no es una cadena"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "se desconoce attribute(target(\"%s\"))"
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "ya se había especificado option(\"%s\")"
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "los atributos fastcall y regparm no son compatibles"
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "los atributos regparam y thiscall no son compatibles"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "el atributo %qE requiere un argumento constante entero"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "el argumento para el atributo %qE es más grande que %d"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "los atributos fastcall y cdecl no son compatibles"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "los atributos fastcall y stdcall no son compatibles"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "los atributos fastcall y thiscall no son compatibles"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "los atributos stdcall y cdecl no son compatibles"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "los atributos stdcall y fastcall no son compatibles"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "los atributos stdcall y thiscall no son compatibles"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "los atributos cdecl y thiscall no son compatibles"
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "se usó el atributo %qE para clases-métodos none"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "se llama a %qD con el atributo sseregparm sin activar SSE/SSE2"
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "se llama a %qT con el atributo sseregparm sin activar SSE/SSE2"
 
-#: config/i386/i386.c:5923
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
-#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr "se llama a %qD con el atributo sseregparm sin activar SSE/SSE2"
-
-#: config/i386/i386.c:6210
-#, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "no se admite multilib"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue no es compatible con la función anidada"
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "el argumento de vector AVX sin AVX activado cambia la ABI"
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "el argumento de vector AVX sin AVX activado cambia la ABI"
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "el argumento de vector AVX sin AVX activado cambia la ABI"
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "el argumento de vector AVX sin AVX activado cambia la ABI"
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "el argumento de vector SSE sin SSE activado cambia la ABI"
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "la devolución de vector SSE sin SSE activado cambia la ABI"
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "el argumento de vector MMX sin MMX activado cambia la ABI"
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "la devolución de vector MMX sin MMX activado cambia la ABI"
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "la ABI para pasar un struct con un miembro de matriz flexible cambió en GCC 4.4"
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "la ABI para pasar un union con long double cambió en GCC 4.4"
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "la ABI para pasar una estructura con un miembro de coma flotante compleja cambió en GCC 4.4"
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "se devuelve el registro SSE con SSE desactivado"
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argumento de registro SSE con SSE desactivado"
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "se devuelve el registro x87 con x87 desactivado"
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, fuzzy, gcc-internal-format
+#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr "se llama a %qD con el atributo sseregparm sin activar SSE/SSE2"
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "La ABI para pasar parámetros con alineación de %d-bytes cambió en GCC 4.6"
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
+#, fuzzy, gcc-internal-format
+#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr "se llama a %qD con el atributo sseregparm sin activar SSE/SSE2"
+
+#: config/i386/i386.c:11378
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "el atributo ms_hook_prologue no es compatible con -mfentry para 32-bit"
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack no admite fastcall con funciones anidadas"
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 2 register  parameters for a nested function"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -26090,273 +26123,273 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack no admite 3 parámetros de registro"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "los registros extendidos no tiene mitades superiores"
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "no se admite el tamaño de operando para el registro extendido"
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, fuzzy, gcc-internal-format
 #| msgid "non-integer operand used with operand code '%c'"
 msgid "non-integer operand used with operand code 'z'"
 msgstr "se usó un operando que no es entero con el código de operando '%c'"
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "No dispatcher found for %s"
 msgstr "No se encontró una definición de etiqueta para %qs"
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, fuzzy, gcc-internal-format
 #| msgid "static linking is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "no se admite enlace estático"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %D"
 msgstr "declaración previa de %q+D"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "no se admiten funciones anidadas en este objetivo"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "el argumento para %qs debe ser una literal sin signo de 2-bit"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "El argumento para -ffpe-trap no es válido: %s"
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 2-bit"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "el quinto argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 1-bit"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 32-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 32-bit"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 4-bit"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 1-bit"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 5-bit"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "el penúltimo argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "el argumento debe ser una constante"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "insn incorrecta:"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "compartición incorrecta de nodos de árbol"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 4-bit"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 5-bit"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 32-bit"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "el selector debe ser una constante entera en el rango 0..%wi"
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE necesita la opción isa desconocida"
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE necesita la opción isa %s"
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "el último argumento debe ser un inmediato"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be scale 1, 2, 4, 8"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "el argumento izquierdo debe ser un escalar 1, 2, 4, 8"
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be scale 1, 2, 4, 8"
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "el argumento izquierdo debe ser un escalar 1, 2, 4, 8"
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "insn incorrecta:"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "el atributo %qE solamente está disponible para 64-bit"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "el argumento del atributo %qE no es cero ni uno"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "los atributos ms_abi y sysv_abi no son compatibles"
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "se descarta el atributo incompatible %qE"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, fuzzy, gcc-internal-format
 #| msgid "unknown architecture %qs"
 msgid "Unknown architecture specific memory model"
 msgstr "arquitectura %qs desconocida"
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %d"
 msgstr "versión sin soporte"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "no se admite el tipo de argumento para la función interna"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -26452,13 +26485,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "el atributo %qE requiere una constante entera como argumento"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr "el valor de -mfixed-range debe ser de la forma REG1-REG2"
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -26530,7 +26563,7 @@
 msgstr "no se admite el atributo %qE para el objetivo R8C"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, gcc-internal-format
 msgid "%qE attribute argument not an integer constant"
 msgstr "el argumento del atributo %qE no es una constante entera"
@@ -26591,7 +26624,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread sólo está disponible en fido"
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "no se admite la expresión del límite de la pila"
@@ -27481,16 +27514,11 @@
 msgid "-g option disabled"
 msgstr "opción -g desactivada"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "la alineación (%u) para %s excede la alineación máxima para los datos comunes globales.  Se usará %u"
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr "se requiere la opción -munix=98 para las características C89 Enmienda 1.\n"
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, fuzzy, gcc-internal-format
@@ -27759,325 +27787,331 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "el atributo o pragma target cambia la coma flotante de precisión doble"
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "La ABI para pasar parámetros con alineación de %d-bytes cambió en GCC 4.6"
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "Se devolvió un vector GCC por referencia: extensión de ABI no estándar sin garantía de compatibilidad"
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "no se puede devolver un valor en el registro vector porque las instrucciones altivec están desactivadas, use -maltivec para activarlas"
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "La ABI para pasar parámetros con alineación de %d-bytes cambió en GCC 4.6"
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "no se puede pasar argumentos en el registro vector porque las instrucciones altivec están desactivadas, use -maltivec para activarlas"
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "la ABI para pasar una estructura con un miembro de coma flotante compleja cambió en GCC 4.4"
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vector GCC pasado por referencia: extensión ABI que no es estándar sin garantía de compatibilidad"
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "error interno: la función interna %s ya se procesó"
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "el argumento 1 debe ser una literal con signo de 5-bit"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "el argumento 1 debe ser una literal con signo de 5-bit"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "el argumento 2 debe ser una literal sin signo de 5-bit"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "el argumento 1 de __builtin_altivec_predicate debe ser una constante"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "el argumento 1 de __builtin_altivec_predicate está fuera de rango"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "%srtd%s is ignored in 64bit mode"
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr "se descarta %srtd%s en el modo de 64bit"
+
+#: config/rs6000/rs6000.c:12763
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "el argumento 2 debe ser una literal sin signo de 5-bit"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "el argumento 1 de __builtin_spe_predicate está fuera de rango"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 4-bit"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 2-bit"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 1-bit"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a map"
 msgid "argument 1 must be 0 or 2"
 msgstr "el argumento 1 debe ser un mapa"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 1-bit"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "el argumento 2 debe ser una literal sin signo de 5-bit"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "el número debe ser 0 ó 1"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument 3 must be in the range 0..15"
 msgstr "el argumento %d de %qE debe estar dentro del rango %d...%d"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "el argumento para %qs debe ser una literal sin signo de 2-bit"
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "sobrecarga sin resolver para el interno Altivec %qF"
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "el argumento para dss debe ser una literal sin signo de 2-bit"
 
 # continuar aqui
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "el argumento 1 de __builtin_paired_predicate debe ser una constante"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "el argumento 1 de __builtin_paired_predicate está fuera de rango"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "el argumento 1 de __builtin_spe_predicate debe ser una constante"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "el argumento 1 de __builtin_spe_predicate está fuera de rango"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "La función interna %s sólo es válida para el procesador cell"
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "La función interna %s requiere la opción -mvsx"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "La función interna %s requiere la opción -mvsx"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "La función interna %s requiere la opción -maltivec"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "La función interna %s requiere la opción -mpaired"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "La función interna %s requiere la opción -mspe"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mpaired option"
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "La función interna %s requiere la opción -mpaired"
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mpaired option"
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "La función interna %s requiere la opción -mpaired"
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mspe option"
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "La función interna %s requiere la opción -mspe"
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -maltivec option"
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "La función interna %s requiere la opción -maltivec"
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mpaired option"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "La función interna %s requiere la opción -mpaired"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "La función interna %s no se admite con las opciones actuales"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had no type"
 msgstr "error interno: la función interna %s no tiene tipo"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "error interno: la función interna %s tiene un tipo de devolución inesperado %s"
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "error interno: función interna %s, el argumento %d tiene el tipo de argumento inesperado %s"
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "marco de pila demasiado grande"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "no hay análisis de perfil del código de 64-bit para esta ABI"
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "No se puede tomar la dirección de una función anindada si se usa la opción -mno-pointers-to-nested-functions."
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "el uso de %<long double%> en tipos AltiVec es inválido"
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "el uso de tipos booleanos en tipos AltiVec es inválido"
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "el uso de %<complex%> en tipos AltiVec es inválido"
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "el uso de tipos de coma flotante decimal en tipos AltiVec es inválido"
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "el uso de %<long%> en tipos AltiVec es inválido para código de 64 bit sin -mvsx"
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "el uso de %<long%> en tipos AltiVec es obsoleto; use %<int%>"
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "el uso de %<long long%> en tipos AltiVec es inválido sin -mvsx"
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "el uso de %<double%> en tipos AltiVec es inválido sin -mvsx"
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "se emite el insn de microcódigo %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "se emite el insn de microcódigo condicional %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "cpu \"%s\" inválido para %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s\"%s\"%s no está definido"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s\"%s\"%s es inválido"
@@ -28333,90 +28367,90 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "el tamaño total de las variables locales excede el límite de la arquitectura"
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "el tamaño de marco de la función %qs de %wd bytes excede el límite de pila definido por el usuario de %d bytes.  Se agrega una trampa incondicional."
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "el tamaño de marco de la función %qs de %wd bytes es mayor que la mitad del tamaño de la pila. La revisión dinámica no será confiable. No se emitirá revisión para esta función."
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "el tamaño de marco de %qs es de %wd bytes"
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs utiliza alojamiento dinámico de pila"
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "el argumento para %qs debe ser un entero no negativo"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "el argumento para el atributo %qE es más grande que %d"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "no se admite el modo z/Architecture en %s"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "no se admite la ABI de 64-bit en el modo ESA/390"
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "las instrucciones de coma flotante decimal de hardware no están disponibles en %s"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "las instrucciones de coma flotante decimal de hardware no están disponibles en el modo ESA/390"
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp no se puede usar en conjunción con -msoft-float"
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "no se admiten -mbackchain -mpacked-stack -mhard-float en combinación"
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "el tamaño de la pila debe ser mayor que el valor de la guardia de pila"
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "el tamaño de la pila no debe ser mayor a 64k"
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard implica el uso de -mstack-size"
@@ -28431,53 +28465,53 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr "actualmente las tablas de desenredo requieren un puntero de marco o -maccumulate-outgoing-args para ser correctas"
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "no se admite __builtin_saveregs en este subobjetivo"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, gcc-internal-format
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "el atributo %qE se aplica solamente a funciones de interrupción"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, gcc-internal-format
 msgid "%qE attribute is supported only for SH2A"
 msgstr "el atributo %qE solo se admite para SH2A"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr "el atributo interrupt_handler no es compatible con -m5-compact"
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, gcc-internal-format
 msgid "%qE attribute only applies to SH2A"
 msgstr "el atributo %qE solo se aplica a SH2A"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, gcc-internal-format
 msgid "%qE attribute argument should be between 0 to 255"
 msgstr "el argumento del atributo %qE debe estar entre 0 y 255"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, gcc-internal-format
 msgid "%qE attribute argument not a string constant"
 msgstr "el argumento del atributo %qE no es una constante de cadena"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr "r0 necesita estar disponible como un registro sobreescrito por llamada"
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, gcc-internal-format
 msgid "need a second call-clobbered general purpose register"
 msgstr "se necesita un segundo registro de propósito general sobreescrito por llamada"
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr "se necesita un registro objetivo sobreescrito por llamada"
@@ -28858,44 +28892,44 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "tipo de elemento inválido para el atributo %qs"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "el número de componentes del vector no es una potencia de dos"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "se descarta el atributo %qs"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "el atributo %qs requiere prototipos con argumentos nombrados"
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "el atributo %qs se aplica solamente a funciones variadic"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "el atributo %qE no tiene efecto"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "el atributo %qs solamente se aplica a tipos de matriz"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
@@ -28959,7 +28993,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "no se descarta el valor void como debería de ser"
@@ -28989,62 +29023,62 @@
 msgid "GCC supports only %u nested scopes"
 msgstr "GCC sólo admite %u ámbitos anidados"
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "se usa la etiqueta %q+D pero no está definida"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "se declara la función anidada %q+D pero nunca se define"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr "se declara la función inline %q+D pero nunca se define"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "variable %q+D sin usar"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, gcc-internal-format
 msgid "variable %qD set but not used"
 msgstr "se define la variable %qD pero no se usa"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "el tipo de la matriz %q+D se completó de forma incompatible con la inicialización implícita"
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "se definió originalmente aquí"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr "una lista de parámetros con una elipsis no puede coincidir con una declaración de nombre de lista de parámetros vacía."
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr "un tipo de argumento que tiene una promoción por defecto no puede coincidir con una declaración de nombre de lista de parámetros vacía."
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "el prototipo para %q+D declara más argumentos que la definición anterior de estilo antiguo"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "el prototipo para %q+D declara menos argumentos que la definición anterior de estilo antiguo"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr "el prototipo para %q+D declara el argumento %d con un tipo incompatible"
@@ -29051,42 +29085,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "prototipo para %q+D después de una definición que no es prototipo"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "la definición previa de %q+D estaba aquí"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "la declaración implícita previa de %q+D estaba aquí"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "la declaración previa de %q+D estaba aquí"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "%q+D redeclarado como un tipo diferente de símbolo"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "la función interna %q+D no se declara como función"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "la declaración de %q+D oscurece una función interna"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "redeclaración del enumerador %q+D"
@@ -29094,342 +29128,342 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "tipos en conflicto para la función interna %q+D"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "tipos en conflicto para %q+D"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr "se especificaron espacios de direcciones nombrados en conflicto (generic vs %s) para %q+D"
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr "se especificaron espacios de direcciones nombrados en conflicto (%s vs generic) para %q+D"
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr "se especificaron espacios de direcciones nombrados en conflicto (%s vs %s) para %q+D"
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "calificadores de tipos en conflicto para %q+D"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
 msgstr "redefinición de la definición de tipo %q+D con un tipo diferente"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "redefinición de la definición de tipo %q+D con un tipo modificado variablemente"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "redefinición de la definición de tipo %q+D"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "redefinición de %q+D"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "declaración static de %q+D después de una declaración que no es static"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "declaración que no es static de %q+D después de una declaración static"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr "atributo %<gnu_inline%> presente en %q+D"
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, gcc-internal-format
 msgid "but not here"
 msgstr "pero no aquí"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "declaración thread-local de %q+D después de una declaración que no es thread-local"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "declaración que no es thread-local de %q+D después de una declaración thread-local"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "declaración extern de %q+D después de una declaración sin enlace"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "declaración de %q+D sin enlace después de una declaración extern"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "redeclaración de %q+D sin enlace"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr "redeclaración de %q+D con visibilidad diferente (se preserva la visibilidad anterior)"
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "declaración inline de %qD después de una declaración con atributo noinline"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "declaración de %q+D con atributo noinline después de la declaración inline "
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "declaración de %q+D con atributo noinline después de la declaración inline "
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "redefinición del parámetro %q+D"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "redeclaración redundante de %q+D"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "la declaración de %q+D oscurece a una declaración previa que no es variable"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr "la declaración de %q+D oscurece un parámetro"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "la declaración de %qD oscurece a una declaración global"
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "la declaración de %q+D oscurece a una declaración local previa"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "aquí está la declaración oscurecida"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "declaración externa anidada de %qD"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "declaración implícita de la función %qE"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "declaración implícita incompatible de la función interna %qD"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "redeclaración inválida de %q+D"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "declaración implícita incompatible de la función %qD"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE no se declaró aquí (no en una función)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE no se declaró aquí (primer uso en esta función)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "cada identificador sin declarar se reporta sólo una vez para cada función en el que aparece"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "la etiqueta %qE es referenciada fuera de cualquier función"
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "salto al ámbito de un identificador con tipo modificado variablemente"
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "el salto evita la inicialización de la variable"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "la etiqueta %qD se define aquí"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD se declara aquí"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "salto a una expresión de declaración"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "declaración duplicada de la etiqueta %qE"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "etiqueta %qD duplicada"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "C tradicional carece de un espacio de nombres separado para etiquetas, el identificador %qE genera un conflicto con"
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "el switch salta sobre la inicialización de la variable"
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "switch inicia aquí"
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "switch salta dentro de una expresión de declaración"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE definido como un tipo erróneo de etiqueta"
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "struct/union sin nombre que no define ninguna instancia"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "una declaración vacía con especificadores de clase de almacenamiento no redeclara la etiqueta"
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "una declaración vacía con calificador de tipo no redeclara la etiqueta"
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "una declaración vacía con %<_Alignas%> no redeclara la etiqueta"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "nombre de tipo sin uso en una declaración vacía"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> en una declaración vacía"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<_Noreturn%> en una declaración vacía"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> en una declaración vacía en ámbito de fichero"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> en una declaración vacía en ámbito de fichero"
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "especificador de clase de almacenamiento sin uso en una declaración vacía"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "useless %<_Alignas%> in empty declaration"
 msgid "useless %qs in empty declaration"
 msgstr "%<_Alignas%> sin uso en la declaración vacía"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "calificador de tipo sin uso en una declaración vacía"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "%<_Alignas%> sin uso en la declaración vacía"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "declaración vacía"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 no admite %<static%> o calificadores de tipo en los declaradores de parámetros de matrices"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 no admite declaradores de matriz %<[*]%>"
@@ -29437,38 +29471,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "no se permite %<[*]%> en otro lugar que no sea el ámbido de prototipo de función"
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D generalmente es una función"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "typedef %qD está inicializado (utilice __typeof__ en su lugar)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "la función %qD está inicializada como una variable"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "el parámetro %qD está inicializado"
@@ -29477,259 +29511,259 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "un objeto de tamaño variable puede no ser inicializado"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "la variable %qD tiene inicializador pero de tipo de dato incompleto"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "se le dió a la función incluída en línea %q+D un atributo noinline"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "el miembro const sin inicializar en %qT es inválido en C++"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD se debe inicializar"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "el inicializador no puede determinar el tamaño de %q+D"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "falta el tamaño de la matriz en %q+D"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "matriz %q+D de tamaño cero o negativo"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "el tamaño de almacenamiento de %q+D no es constante"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "se descarta el especificador asm para la variable local que no es estática %q+D"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "no se puede poner un objeto con un campo volatile en register"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, gcc-internal-format
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "const %qD sin inicializar es inválida en C++"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C prohíbe declaraciones adelantadas de parámetros"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "definir un tipo en una literal compuesta es inválido en C++"
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "la anchura del campo de bits %qs no es una constante entera"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "la anchura del campo de bits %qs no es una expresión constante entera"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "anchura negativa en el campo de bit %qs"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "anchura cero para el campo de bits %qs"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "el campo de bits %qs tiene un tipo inválido"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "el tipo de campo de bits %qs es una extensión de GCC"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "la anchura de %qs excede su tipo"
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs es más estrecho que los valores de su tipo"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 prohíbe la matriz %qE cuyo tamaño no se puede evaluar"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 prohíbe la matriz cuyo tamaño no se puede evaluar"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 prohíbe la matriz de longitud variable"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "%qE variablemente modificado en el ámbito del fichero"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "campo variablemente modificado en el ámbito del fichero"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "el tipo de dato por defecto es %<int%> en la declaración de %qE"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "el tipo de dato por defecto es %<int%> en el nombre de tipo"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "%<const%> duplicado"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "%<restrict%> duplicado"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "%<volatile%> duplicado"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "%<restrict%> duplicado"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "espacios de direcciones nombrados generan un conflicto (%s vs %s)"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "la definición de la función se declaró como %<auto%>"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "la definición de la función se declaró como %<register%>"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "la definición de la función se declaró como %<typedef%>"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "la definición de la función se declaró como %<auto%>"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "se especificó una clase de almacenamiento para el campo de la estructura %qE"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "se especificó una clase de almacenamiento para el campo de la estructura"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "se especificó una clase de almacenamiento para el parámetro %qE"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "se especificó una clase de almacenamiento para un parámetro sin nombre"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "se especificó una clase de almacenamiento para el nombre de tipo"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE se inicializó y declaró como %<extern%>"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE tiene %<extern%> e inicializador al mismo tiempo"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "la declaración del ámbito de fichero de %qE especifica %<auto%>"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "la declaración del ámbito de fichero de %qE especifica %<register%>"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "la función anidada %qE se declaró %<extern%>"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope %qE implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -29738,688 +29772,688 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static o calificadores de tipo en un declarador de matriz que no es parámetro"
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "la declaración de %qE como una matriz de voids"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "declaración de nombre de tipo como una matriz de voids"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "declaración de %qE como una matriz de funciones"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "declaración de nombre de tipo como una matriz de funciones"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "uso inválido de una estructura con un miembro de matriz flexible"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "el tamaño de la matriz %qE es de un tipo no entero"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "el tamaño de la matriz sin nombre es de un tipo no entero"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C prohíbe la matriz %qE de tamaño cero"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C prohíbe matrices de tamaño cero"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "el tamaño de la matriz %qE es negativo"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "el tamaño de la matriz sin nombre es negativo"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "el tamaño de la matriz %qE es demasiado grande"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "el tamaño de la matriz sin nombre es demasiado grande"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> fuera de una declaración"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "el tipo matriz tiene tipo de elemento incompleto"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE que se declaró como función devuelve una función"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "el nombre de tipo que se declaró como función devuelve una función"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE que se declaró como función devuelve una matriz"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "el nombre de tipo que se declaró como función devuelve una matriz"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "la definición de la función tiene un tipo de devolución void calificado"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C prohíbe los tipos de función calificados"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C prohíbe los tipos de función calificados"
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs combinado con el calificador %<auto%> para %qE"
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs combinado con el calificador %<register%> para %qE"
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "se especificó %qs para la variable auto %qE"
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "se especificó %qs para el parámetro %qE"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "se especificó %qs para el parámetro sin nombre"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "se especificó %qs para el campo de estructura %qE"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "se especificó %qs para el campo de estructura"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "el campo de bits %qs tiene un tipo inválido"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "el campo de bits %qs tiene un tipo inválido"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "se especificó la alineación para la definición de tipo %qE"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "se especificó la alineación para el objeto %<register%> %qE"
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "se especificó la alineación para el parámetro %qE"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "se especificó la alineación para el parámetro sin nombre"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "se especificó la alineación para el campo de bits %qE"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "se especificó la alineación para el campo de bits sin nombre"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "se especificó la alineación para la función %qE"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "los especificadores %<_Alignas%> no pueden reducir la alineación de %qE"
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "los especificadores %<_Alignas%> no pueden reducir la alineación del campo sin nombre"
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "la definición de tipo %q+D se declaró como %<inline%>"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "la definición de tipo %q+D se declaró como %<_Noreturn%>"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C prohíbe los tipos de función const o volatile"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "un miembro de una estructura o union no puede tener un tipo modificado variablemente"
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "se declaró la variable o campo %qE como void"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "se descartan los atributos en los declaradores de parámetros de matriz"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "el parámetro %q+D se declaró %<inline%>"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "el parámetro %q+D se declaró %<_Noreturn%>"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "el campo %qE se declaró como una función"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "el campo %qE tiene tipo de dato incompleto"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "el campo sin nombre tiene tipo de dato incompleto"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "clase de almacenamiento inválida para la función %qE"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "no se puede incluir en línea la función %<main%>"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> se declaró como %<_Noreturn%>"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 no admite %<_Noreturn%>"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 no admite %<_Noreturn%>"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "una variable previamente declarada como %<static%> se redeclara como %<extern%>"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "la variable %q+D se declaró como %<inline%>"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "la variable %q+D se declaró como %<_Noreturn%>"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "función no anidada con tipo modificado variablemente"
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "un objeto con tipo modificado variablemente no debe tener enlace"
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "la declaración de la función no es un prototipo"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "nombres de parámetros (sin tipos) en la declaración de la función"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "el parámetro %u (%q+D) tiene tipo incompleto"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "el parámetro %u tiene tipo incompleto"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "el parámetro %u (%q+D) tiene tipo void"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "el parámetro %u tiene tipo void"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "no se puede calificar %<void%> si es el único parámetro"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> debe ser el único parámetro"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "el parámetro %q+D sólo tiene una declaración posterior"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "se declaró %<%s %E%> dentro de la lista de parámetros"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "el %s anónimo se declaró dentro de una lista de parámetros"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "su ámbito es solamente esta definición o declaración, lo cual probablemente no es lo que desea"
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "se definió el tipo enum aquí"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "se definió struct aquí"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "se definió union aquí"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "redefinición de %<union %E%>"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "redefinición de %<struct %E%>"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "redefinición anidada de %<union %E%>"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "redefinición anidada de %<struct %E%>"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "la definición de tipo en %qs es inválida en C++"
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "la declaración no declara nada"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 no admite structs/unions sin nombre"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 no admite structs/unions sin nombre"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "miembro %q+D duplicado"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union no tiene miembros nombrados"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union no tiene miembros"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct no tiene miembros nombrados"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct no tiene miembros"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "miembro de matriz flexible en union"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr "el miembro de matriz flexible sería de otra manera un struct vacío"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "type %qT is too large"
 msgstr "%s es demasiado grande"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union no se puede hacer transparente"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "redefinición anidada de %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "redeclaración de %<enum %E%>"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "los valores de enumeración exceden el rango del entero más grande"
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "el modo especificado es demasiado pequeño para valores enumerados"
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "el valor de enumerador para %qE no es una constante entera"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "el valor de enumerador para %qE no es una expresión constante entera"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "desbordamiento en valores de enumeración"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C restringe los valores de enumeración al rango de %<int%>"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "se le dió a la función incluída en línea %qD un atributo noinline"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "el tipo de devolución es un tipo de dato incompleto"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "el tipo de devolución por defecto es %<int%>"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "no hay un prototipo previo para %qD"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "se usó %qD sin prototipo antes de su definición"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "no hay declaración previa para %qD"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "se usó %qD sin declaración antes de su definición"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "el tipo de devolución de %qD no es %<int%>"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD generalmente es una función que no es static"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "declaraciones de parámetros de estilo antiguo en la definición de una función prototipo"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "C tradicional rechaza la definición de funciones de estilo ISO C"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "se omitió el nombre del parámetro"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "definición de función de estilo antiguo"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "falta el nombre del parámetro de la lista de parámetros"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD se declaró como un no-parámetro"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "múltiples parámetros nombrados %qD"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "el parámetro %qD se declaró con tipo void"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "el tipo de %qD es %<int%> por defecto"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "el parámetro %qD tiene tipo incompleto"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "existe la declaración para el parámetro %qD pero no hay tal parámetro"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "el número de argumentos no coinciden con el prototipo interno"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "el número de argumentos no coinciden con el prototipo"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "declaración de prototipo"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "el argumento promovido %qD no coincide con el prototipo interno"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "el argumento promovido %qD no coincide con el prototipo"
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "el argumento %qD no coincide con el prototipo interno"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "el argumento %qD no coincide con el prototipo"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "se definió el parámetro %qD pero no se usa"
@@ -30427,206 +30461,206 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "sólo se permiten las declaraciones iniciales del bucle %<for%> en modo C99"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99 or -std=gnu99 to compile your code"
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "use la opción -std=c99 o -std=gnu99 para compilar su código"
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de la variable static %qD en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de la variable %<extern%> %qD en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de %qD que no es variable en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "calificadores de espacio de direcciones incompatibles %qs y %qs"
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE duplicado"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "dos o más tipos de datos en los especificadores de la declaración"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> es demasiado largo para GCC"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 no admite %<long long%>"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 no admite tipos complejos"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C no admite tipos saturantes"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int128%> type"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C no admite el tipo %<__int128%>"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported for this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "no se admite %<__int128%> para este objetivo"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 no admite tipos complejos"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C no admite coma flotante decimal"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "no se admiten tipos de coma fija para este objetivo"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C no admite tipos de coma fija"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "la búsqueda en C++ de %qD devolvería un campo, no un tipo"
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE falla al ser un typedef o un tipo interno del compilador"
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE no está al inicio de la declaración"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "se usó %<__thread%> con %<auto%>"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "se usó %<__thread%> con %<register%>"
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "se usó %<__thread%> con %<typedef%>"
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 no admite %qE"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 no admite %qE"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> antes de %<extern%>"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> antes de %<static%>"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "múltiples clases de almacenamiento en los especificadores de declaración"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs used with %qE"
 msgstr "%qs se debe usar con %qs"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "se usó %<_Sat%> sin %<_Fract%> o %<_Accum%>"
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C no admite %<complex%> simples que significan %<double complex%>"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C no admite tipos enteros complejos"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -30636,7 +30670,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr "el identificador %qE causa conflictos con la palabra clave de C++"
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "se esperaba fin de línea"
@@ -30656,8 +30690,8 @@
 msgid "unknown type name %qE"
 msgstr "nombre de tipo %qE desconocido"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "se esperaban especificadores de declaración"
@@ -30673,7 +30707,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "se esperaba %<;>, identificador o %<(%>"
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "se descartan los atributos de prefijo para los métodos"
@@ -30753,7 +30787,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 no admite %<_Static_assert%>"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "se esperaba una cadena literal"
@@ -30813,14 +30847,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "se esperaba un identificador"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "coma al final de la lista de enumeradores"
@@ -31283,32 +31317,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr "ninguna clase de almacenamiento o tipo se puede especificar aquí,"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "atributo de propiedad desconocido"
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "falta un %<=%> (después del atributo %<getter%>)"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "falta un %<=%> (después del atributo %<setter%>)"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "el atributo %<setter%> sólo se puede especificar una vez"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "el nombre del setter debe terminar con %<:%>"
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "el atributo %<getter%> sólo se puede especificar una vez"
@@ -31319,50 +31353,50 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr "%<#pragma omp taskyield%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr "%<#pragma omp taskyield%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> sólo se puede usar en construcciones %<#pragma omp sections%>"
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "se esperaba una declaración for"
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> debe ser primero"
@@ -31378,12 +31412,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -31395,29 +31429,29 @@
 msgid "expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not const"
 msgid "%qD is not a constant"
 msgstr "%q#D no es const"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD no es una variable"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD no es una variable"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "se esperaba %<none%> o %<shared%>"
@@ -31451,17 +31485,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> o %<max%>"
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "el calendarizador %<runtime%> no toma un parámetro %<chunk_size%>"
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "el calendarizador %<auto%> no toma un parámetro %<chunk_size%>"
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "género de calendarizador inválido"
@@ -31484,13 +31518,13 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "using parameters for %<linear%> step is not supported yet"
@@ -31514,19 +31548,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "género de calendarizador inválido"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "máscara inválida"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -31538,61 +31572,61 @@
 msgid "invalid proc_bind kind"
 msgstr "género de calendarizador inválido"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs no es válido para %qs"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs se debe usar con %qs"
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr "se esperaba una cadena después de %<#pragma message%>"
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid pragma"
 msgstr "#pragma %s inválido"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "forma inválida de %<#pragma omp atomic%>"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operador inválido para %<#pragma omp atomic%>"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
@@ -31603,18 +31637,18 @@
 msgid "expected %<(%> or end of line"
 msgstr "se esperaba %<(%> o fin de línea"
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "se esperaba una declaración for"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "_Cilk_for statement expected"
 msgstr "se esperaba una declaración for"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "se esperaba una declaración de iteración o una inicialización"
@@ -31624,259 +31658,259 @@
 msgid "not enough perfectly nested loops"
 msgstr "no hay suficientes bucles perfectamente anidados"
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "los bucles colapsados no están perfectamente anidados"
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable de iteración %qD no debe ser firstprivate"
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
 msgstr "se esperaba %<operator%>"
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<using%>"
 msgid "expected %<point%>"
 msgstr "se esperaba %<using%>"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> debe aparecer antes de la declaración de %D, se descarta"
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<try%>"
 msgid "expected %<target%>"
 msgstr "se esperaba %<try%>"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "se esperaba %<decltype%>"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma GCC pop_options%> sin un %<#pragma GCC push_options%> correspondiente"
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, fuzzy, gcc-internal-format
 #| msgid "a template declaration cannot appear at block scope"
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "una declaración de plantilla no puede aparecer en el ámbito de bloque"
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> o %<max%>"
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration"
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "declaración previa"
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<omp_priv%> or function-name"
 msgstr "se esperaba %<(%> o fin de línea"
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 #| msgid "expected function"
 msgid "expected function-name %<(%>"
 msgstr "se esperaba función"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "se esperaba %<#pragma omp section%> o %<}%>"
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE se declaró %<threadprivate%> después del primer uso"
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "la variable automática %qE no puede ser %<threadprivate%>"
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE tiene tipo incompleto"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "pragma simd must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, fuzzy, gcc-internal-format
 #| msgid "end bit in POS must be an integer constant"
 msgid "vectorlength must be an integer constant"
 msgstr "el bit final en POS debe ser una constante entera"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 #| msgid "text length must be greater than 0"
 msgid "vectorlength must be a power of 2"
 msgstr "la longitud de texto debe ser más grande que 0"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "el selector debe ser una constante entera en el rango 0..%wi"
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma simd%> clause"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma%> no se permite aquí"
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> sin activar el soporte para memoria transaccional"
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> dentro de un %<__transaction_relaxed%>"
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> más externo no está dentro del %<__transaction_atomic%> más externo"
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  o una función %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> no está dentro de %<__transaction_atomic%>"
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "base of array section must be pointer or array type"
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<:%> or numeral"
 msgstr "se esperaba %<:%> o %<::%>"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "array notations cannot be used with function type"
 msgstr "new no se puede aplicar a un tipo de función"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 #| msgid "expected boolean expression"
 msgid "expected array notation expression"
@@ -31887,7 +31921,7 @@
 msgid "%qD has an incomplete type"
 msgstr "%qD tiene un tipo de dato incompleto"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "uso inválido de la expresión void"
@@ -31996,7 +32030,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "el valor del subíndice no es ni matriz ni puntero ni vector"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "el subíndice de la matriz no es un entero"
@@ -32122,7 +32156,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "se pasa el argumento %d de %qE como signed debido al prototipo"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "conversión implícita de %qT a %qT al pasar el argumento a la función"
@@ -32152,7 +32186,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmética en puntero a un tipo de dato incompleto"
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -32240,7 +32274,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "matriz no-lvaluada en la expresión condicional"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "conversión implícita de %qT a %qT para coincidir con otro resultado del condicional"
@@ -32276,7 +32310,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "los tipos de datos punteros/enteros no coinciden en la expresión condicional"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, fuzzy, gcc-internal-format
 #| msgid "a function call cannot appear in a constant-expression"
 msgid "spawned function call cannot be part of a comma expression"
@@ -32363,7 +32397,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "conversión desde una llamada a función de tipo %qT al tipo %qT que no coincide"
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "conversión a puntero desde un entero de tamaño diferente"
@@ -32517,7 +32551,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la inicialización puede ser un candidato para un atributo de formato"
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "el tipo de devolución puede ser un candidato para un atributo de formato"
@@ -32654,7 +32688,7 @@
 msgid "initialization of a flexible array member"
 msgstr "inicialización de un miembro de matriz flexible"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "matriz de tipo char inicializada con una cadena ancha"
@@ -32700,7 +32734,7 @@
 msgid "invalid initializer"
 msgstr "inicializador inválido"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "no se pueden inicializar los tipos de vector opacos"
@@ -32846,7 +32880,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C prohíbe %<goto *expr;%>"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "la función declarada %<noreturn%> tiene una declaración %<return%>"
@@ -32857,7 +32891,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "se usó una expresión coma para inicializar el valor de devolución"
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
@@ -32967,17 +33001,17 @@
 msgid "expression statement has incomplete type"
 msgstr "la declaración de la expresión tiene tipo de dato incompleto"
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "se comparan vectores con tipos de elemento diferentes"
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "se comparan vectores con números de elementos diferentes"
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "no es segura la comparacion de coma flotante con == o !="
@@ -33028,12 +33062,12 @@
 msgstr "comparación ordenada de puntero con un puntero nulo"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "comparación ordenada de puntero con el entero cero"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "conversión implícita de %qT a %qT para coincidir con otro operando de la expresión binaria"
@@ -33058,93 +33092,93 @@
 msgid "used vector type where scalar is required"
 msgstr "se usa un tipo vector cuando se requiere un escalar"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "se usó la matriz de longitud variable"
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, fuzzy, gcc-internal-format
 #| msgid "for increment expression has no effect"
 msgid "for pointer type length expression must be specified"
 msgstr "la expresión de incremento for no tiene efecto"
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Copia las secciones de matriz en un bloque contiguo en la entrada de procedimiento"
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qE does not have pointer or array type"
@@ -33155,18 +33189,18 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE tiene tipo inválido para %<reduction(%s)%>"
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "user defined reduction not found for %qD"
 msgstr "No se encontró una definición de etiqueta para %qs"
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE debe ser %<threadprivate%> para %<copin%>"
@@ -33176,7 +33210,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE no es una variable en la cláusula %qs"
@@ -33186,17 +33220,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE no es una variable en la cláusula %<firstprivate%>"
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE no es una variable en la cláusula %<lastprivate%>"
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -33214,54 +33248,54 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, fuzzy, gcc-internal-format
 #| msgid "Array section not permitted in '%s' call at %L"
 msgid "array section does not have mappable type in %qs clause"
 msgstr "No se permite una sección de matriz en la llamada '%s' en %L"
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE está predeterminado como %qs para %qs"
@@ -33272,18 +33306,18 @@
 msgstr "C++ requiere un tipo promovido, no un tipo enum, en %<va_arg%>"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "pasar %qT como el argumento %<this%> de %q#D descarta a los calificadores"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr "  no hay una conversión conocida para el parámetro %<this%> implícito de %qT a %qT"
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  no known conversion for argument %d from %qT to %qT"
 msgid "  conversion of argument %d would be ill-formed:"
@@ -33290,18 +33324,18 @@
 msgstr "  no hay una conversión conocida para el argumento %d de %qT a %qT"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion from %qT to %qT"
 msgstr "  para la conversión de %qT a %qT"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, gcc-internal-format
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "  no hay una conversión conocida para el argumento %d de %qT a %qT"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -33308,83 +33342,83 @@
 msgstr[0] "  el candidato espera %d argumento, se proporcionaron %d"
 msgstr[1] "  el candidato espera %d argumentos, se proporcionaron %d"
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, gcc-internal-format
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr "%s%D(%T, %T, %T) <interno>"
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, gcc-internal-format
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "%s%D(%T, %T) <interno>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, gcc-internal-format
 msgid "%s%D(%T) <built-in>"
 msgstr "%s%D(%T) <interno>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, gcc-internal-format
 msgid "%s%T <conversion>"
 msgstr "%s%T <conversión>"
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr "%s%#D <coincidencia cercana>"
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr "%s%#D <borrado>"
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr "%s%#D"
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr " el tipo de devolución %qT de la función de conversiń explícita no se puede convertir a %qT con una conversión de calificación"
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr " la conversión del tipo de devolución %qT de la especialización de función de conversión de plantilla a %qT no es una coincidencia exacta"
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr " la sustitución de los argumentos de plantilla deducidos resultó en errores vistos con anterioridad"
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr "  un constructor que toma un solo argumento de su propio tipo de clase es inválido"
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "la conversión de %qT a %qT es ambigua"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, gcc-internal-format
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr "no se consideró la conversión de %qT a %qT para el argumento de plantilla que no es tipo"
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "no hay una función coincidente para la llamada a %<%D(%A)%>"
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "la llamada del %<%D(%A)%> sobrecargado es ambigua"
@@ -33391,485 +33425,485 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr "la función puntero-a-miembro %E no se puede llamar dentro de un objeto; considere utilizar .* o ->*"
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "no hay coincidencia para la llamada a %<(%T) (%A)%>"
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "la llamada de %<(%T) (%A)%> es ambigua"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous overload for %qs in %<%s %E%>"
 msgid "ambiguous overload for "
 msgstr "sobrecarga ambigua para %qs en %<%s %E%>"
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %qs in %<%s %E%>"
 msgid "no match for "
 msgstr "no hay coincidencia para %qs en %<%s %E%>"
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "operandos inválidos para el binario %s (se tiene %qT y %qT)"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT and %qT)"
 msgstr "operandos inválidos para el binario %s (se tiene %qT y %qT)"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, fuzzy, gcc-internal-format
 #| msgid "operand is r0"
 msgid " (operand type is %qT)"
 msgstr "el operando es r0"
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "ternary %<operator?:%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, fuzzy, gcc-internal-format
 #| msgid "no match for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "no hay coincidencia para el %<operator?:%> terniario en %<%E ? %E : %E%>"
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "%<operator%s%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "no hay coincidencia para %<operator%s%> en %<%E%s%>"
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "%<operator[]%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "no hay coincidencia para el %<operador[]%> en %<%E[%E]%>"
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "no hay coincidencia para %qs en %<%s %E%>"
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "no hay coincidencia para %<operator%s%> en %<%E %s %E%>"
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "no hay coincidencia para %<operador%s%> en %<%s%E%>"
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ prohíbe la omisión del término medio de una expresión ?:"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "no coincide el enumeral en la expresión condicional: %qT vs %qT"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "el segundo operando del operador condicional es del tipo %<void%>, pero el tercer operando no es una expresión throw ni del tipo %<void%>"
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "el tercer operando del operador condicional es del tipo %<void%>, pero el segundo operando no es una expresión throw ni del tipo %<void%>"
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "los operandos de ?: tienen tipos diferentes %qT y %qT"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, fuzzy, gcc-internal-format
 #| msgid "methods cannot be converted to function pointers"
 msgid "  and each type can be converted to the other"
 msgstr "los métodos no pueden ser convertidos a apuntadores a funciones"
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "no coincide el enumeral en la expresión condicional: %qT vs %qT"
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "tipos enumeral y no enumeral en la expresión condicional"
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "no se declaró %<%D(int)%> para el %qs postfijo, intentando en su lugar el operador prefijo"
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "no se declaró %<%D(int)%> para el %qs postfijo"
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "comparación entre %q#T y %q#T"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, gcc-internal-format
 msgid "non-placement deallocation function %q+D"
 msgstr "función de desalojo %q+D sin ubicación"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr "seleccionada para borrado de ubicación"
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "no existe una función de desalojo correspondiente para %qD"
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "no hay un %<operator %s%> adecuado para %qT"
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr "%q+#D es privado"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr "%q+#D está protegido"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr "%q+#D es inaccesible"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr "desde este contexto"
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "se pasó NULL al argumento %P de %qD que no es puntero"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "se convierte al tipo %qT que no es puntero desde NULL"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "se convierte %<false%> a tipo puntero para el argumento %P de %qD"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "se convierte %<false%> al tipo puntero %qT"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "demasiadas llaves alrededor del inicializador para %qT"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr "no se puede convertir %qT a %qT en la inicialización"
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, gcc-internal-format
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "conversión definida por el usuario inválida de %qT a %qT"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  argumento de inicialización %P de %qD"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "conversión inválida de %qT a %qT"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "la conversión a %qT desde la lista del inicializador usaría el constructor explícito %qD"
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, gcc-internal-format
 msgid "  initializing argument %P of %q+D"
 msgstr "  se inicializa el argumento %P de %q+D"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, gcc-internal-format
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "no se puede unir el l-valor %qT a %qT"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "inicialización inválida de una referencia que no es constante de tipo %qT desde un r-valor de tipo %qT"
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "pasar %qT como el argumento %<this%> de %q#D descarta a los calificadores"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "no se puede unir el campo de bits %qE a %qT"
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "no se unir el campo packed %qE a %qT"
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "no se puede unir el r-valor %qE a %qT"
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-trivially-copyable type %q#T through %<...%>"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "no se puede pasar objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "no se puede recibir objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "no se puede recibir objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "evaluación recursiva del argumento por defecto para %q#D"
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "la llamada a %qD usa el argumento por defecto para el parámetro %P, el cual no se ha definido aún"
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "el argumento de la llamada a función puede ser un candidato para un atributo de formato"
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted function %q+D with default argument"
 msgid "use of multiversioned function without a default"
 msgstr "función definida por defecto %q+D con argumento por defecto"
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "pasar %qT como el argumento %<this%> de %q#D descarta a los calificadores"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  en la llamada a %qD"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT no es una base inaccesible de %qT"
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "se deduce %qT como %qT"
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, gcc-internal-format
 msgid "  in call to %q+D"
 msgstr "  en la llamada a %q+D"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (puede desactivar esto con -fno-deduce-init-list)"
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr "no se puede encontrar un campo class$ en el tipo de interfaz java %qT"
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, fuzzy, gcc-internal-format
 #| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "la constante se refiere a sí misma"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "llamada a %qD que no es función"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "no se puede llamar directamente al constructor %<%T::%D%>"
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, fuzzy, gcc-internal-format
 #| msgid "  for a function-style cast, remove the redundant %<::%D%>"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  para una conversión de estilo de función, borre el %<::%D%> redundante"
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "no se encontró una función coincidente para la llamada a %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr "no se encontró una función coincidente para la llamada a %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "no hay una función coincidente para la llamada a %<%D(%A)%>"
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "la llamada del %<%s(%A)%> sobrecargado es ambigua"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "los inicializadores de los datos miembro no son estáticos"
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "no se puede llamar a la función miembro %qD sin un objeto"
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "al pasar %qT se escoge %qT sobre %qT"
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "se escoge %qD sobre %qD"
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  para la conversión de %qT a %qT"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  porque la secuencia de conversión para el argumento es mejor"
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "no coincide el argumento por defecto en la resolución de sobrecarga"
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr " candidato 1: %q+#F"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr " candidato 2: %q+#F"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ dice que estos son ambiguos, aún cuando la peor conversión para el primero es mejor que la peor conversión para el segundo:"
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "no se puede convertir %qE de %qT a %qT"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "un enlace temporal a %qD sólo persiste hasta que el constructor termina"
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "inicialización inválida de la referencia de tipo %qT desde una expresión de tipo %qT"
@@ -34036,7 +34070,7 @@
 msgid "  by %q+D"
 msgstr "  por %q+D"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D inválido; un union anónimo sólo puede tener miembros con datos no estáticos"
@@ -34046,7 +34080,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D inválido; un struct anónimo sólo puede tener miembros con datos no estáticos"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr "miembro privado %q+#D en union anónima"
@@ -34056,7 +34090,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "miembro privado %q+#D en struct anónimo"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr "miembro protegido %q+#D en union anónima"
@@ -34190,69 +34224,80 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  pero no se impone a %<operator=(const %T&)%>"
 
-#: cp/class.c:4538
+#: cp/class.c:4300
 #, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, fuzzy, gcc-internal-format
+#| msgid "alignment of %qD is bigger than original declaration"
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr "la alineación de %qD es más grande que la declaración original"
+
+#: cp/class.c:4557
+#, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "se especificó un inicializador para el método %q+D que no es virtual"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "el método anula tanto %<transaction_pure%> como los métodos %qE"
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "el método declarado como %qE anula el método %qE"
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "la clase envolvente de la función miembro que no es estática constexpr %q+#D no es un tipo literal"
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T no es literal porque:"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T tiene un destructor que no es trivial"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr "  %q+T no es un agregado, no tiene un constructor trivial por defecto y no tiene un constructor constexpr que no es un constructor copy o move"
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  la clase base %qT de %q+T no es literal"
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, gcc-internal-format
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "  el dato miembro que no es estático %q+D tiene un tipo que no es literal"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %q+D has non-literal type"
 msgid "  non-static data member %q+D has volatile type"
 msgstr "  el dato miembro que no es estático %q+D tiene un tipo que no es literal"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "la clase base %q#T tiene un destructor no virtual"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr "referencia %q+#D que no es static en una clase sin un constructor"
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr "miembro const %q+#D que no es static en una clase sin un constructor"
@@ -34259,104 +34304,104 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "se declaró %q+D para tomar referencia const, pero la declaración implícita tomaría algo que no es const"
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "base directa %qT inaccesible en %qT debido a ambigüedad"
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "base virtual %qT inaccesible en %qT debido a ambigüedad"
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr "el desplazamiento de %q+D no cumple con la ABI y puede cambiar en una versión futura de GCC"
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinición de %q#T"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T tiene funciones virtuales y destructor no virtual accesible"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, fuzzy, gcc-internal-format
 #| msgid "type transparent class %qT does not have any fields"
 msgid "type transparent %q#T does not have any fields"
 msgstr "la clase transparente tipo %qT no tiene ningún campo"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "la clase transparente tipo %qT tiene clases base"
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "la clase transparente tipo %qT tiene funciones virtuales"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "se trató de terminar struct, pero fue sacado debido a errores previos de decodificación"
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "no se reconoce la cadena de lenguaje %<\"%E\"%>"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "no se puede resolver la función sobrecargada %qD basándose en la conversión al tipo %qT"
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "no hay coincidencias al convertir la función %qD al tipo %q#T"
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "la conversión de la función sobrecargada %qD al tipo %q#T es ambigua"
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "asumiendo el puntero a miembro %qD"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(un puntero a miembro solamente se puede formar con %<&%E%>)"
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "no hay suficiente información de tipo"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "no se puede convertir %qE desde el tipo %qT al tipo %qT"
@@ -34366,12 +34411,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "la declaración de %q#D"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr "cambia el significado de %qD a partir de %q+#D"
@@ -34413,267 +34458,267 @@
 msgid "constexpr constructor does not have empty body"
 msgstr "el constructor constexpr no tiene cuerpo vacío"
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "el constructor %<constexpr%> para union %qT debe inicializar exactamente un dato miembro que no es static"
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "el cuerpo de la función constexpr %qD no es una declaración de devolución"
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr "%q+D no se puede usar como una función constexpr porque:"
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
 msgid "call to internal function"
 msgstr "función interna"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "la expresión %qE no designa una función constexpr"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "llamada a la función %qD que no es constexpr"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "se llamó %qD en una expresión constante"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "se usó %qD antes de su definición"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "la llamada tiene una dependencia circular"
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "la profundidad de evaluación de constexpr excede el máximo de %d (use -fconstexpr-depth= para incrementar el máximo)"
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, fuzzy, gcc-internal-format
 #| msgid "Warn on calls to these functions"
 msgid "constexpr call flows off the end of the function"
 msgstr "Avisa en las llamadas a estas funciones"
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E no es una expresión constante"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "la cuenta de desplazamiento a la derecha es negativa"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "el operador del lado izquierdo de la expresión coma no tiene efecto"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "la expresión integral %qE no es una constante"
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "array subscript out of bound"
 msgstr "el subíndice de la matriz está fuera de los límites"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "negative array subscript"
 msgstr "Se esperaba un subíndice de matriz en %C"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD mutable no se puede usar en una expresión constante"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "se accede al miembro %qD  en lugar del miembro inicializado %qD en la expresión constante"
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "se accede al valor de %qE a través de glvalue %qT en una expresión constante"
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "el valor de %qD no se puede usar en una expresión constante"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "se usó %qD en su propio inicializador"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D no es const"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q+#D es volatile"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD no se inicializó con una expresion constante"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD no se declaró %<constexpr%>"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "modification of %qE is not a constant-expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast inválido del tipo `%T' al tipo `%T'"
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant-expression"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "expresión %qE inesperada de género %s"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr "conversión del tipo puntero %qT al tipo aritmético %qT en una expresión constante"
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "la expresión %qE tiene efectos colaterales"
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "la dirección de un objeto %qE con hilo local o almacenamiento automático no es una expresión constante"
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, gcc-internal-format
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "la diferencia de dos expresiones puntero no es una expresión constante"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr "la expresión de comparación de punteros no es una expresión constante"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, gcc-internal-format
 msgid "division by zero is not a constant-expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "inicialización de una matriz que no es constante"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "AST inesperado de género %s"
@@ -34748,7 +34793,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr "No se permite una declaración %s dentro de BLOCK en %C"
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr "%qE se determina implícitamente ya que %<firstprivate%> tiene tipo de referencia"
@@ -34788,7 +34833,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "la conversión de %qT a %qT descarta los calificadores"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "la conversión de %qT a %qT no dereferencía a los punteros"
@@ -34798,294 +34843,294 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "no se puede convertir el tipo %qT al tipo %qT"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "conversión de %q#T a %q#T"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "el resultado de la conversión no está especificado porque %qE está fuera del rango del tipo %qT"
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "se usó %q#T donde se esperaba un %qT"
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE from %qT to %qT"
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "no se puede convertir %qE de %qT a %qT"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "se usó %q#T donde se esperaba un valor de coma flotante"
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "se solicitó la conversión desde %qT al tipo no escalar %qT"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "no se llamó al seudo-destructor"
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "la conversión a void no accederá al objeto de tipo incompleto %qT"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en el segundo operando de la expresión condicional"
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en el tercer operando de la expresión condicional"
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en el operando derecho del operador coma"
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en el operando izquierdo del operador coma"
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "la indirección no accederá a un objeto de tipo incompleto %qT en la declaración"
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en la expresión de incremento for"
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "la conversión a void no accederá al objeto de tipo %qT"
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en el segundo operando de la expresión condicional"
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en el tercer operando de la expresión condicional"
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en el operando derecho del operador coma"
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en el operando izquierdo del operador coma"
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en la declaración"
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en la expresión de incremento for"
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "la conversión a void no accederá al objeto de tipo no-copiable-trivialmente %qT"
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en el segundo operando de la expresión condicional"
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en el tercer operando de la expresión condicional"
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en el operando derecho del operador coma"
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en el operando izquierdo del operador coma"
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en la declaración"
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en la expresión de incremento for"
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "la conversión a void no accederá al objeto %qE de tipo incompleto %qT"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en el segundo operando de la expresión condicional"
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en el tercer operando de la expresión condicional"
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en el operando derecho del operador coma"
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en el operando izquierdo del operador coma"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en la declaración"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en la expresión de incremento for"
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "la conversión a void no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "el segundo operando de la expresión condicional no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "el tercer operando de la expresión condicional no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "el operando derecho del operador coma no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "el operador izquierdo del operador coma no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "la declaración no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "la expresión de incremento for no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "el segundo operando de la expresión condicional es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "el tercer operando de la expresión condicional es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "el operando derecho del operador coma es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "el operando izquierdo del operador coma es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "la declaración es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "la expresión de incremento for es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "el segundo operando de la expresión condicional no tiene efecto"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "el tercer operando de la expresión condicional no tiene efecto"
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "el operando derecho del operador coma no tiene efecto"
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "el operando izquierdo del operador coma no tiene efecto"
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "la declaración no tiene efecto"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "la expresión de incremento for no tiene efecto"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "se convierte NULL a un tipo que no es puntero"
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 #| msgid "  couldn't deduce template parameter %qD"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "  no se puede deducir el parámetro de plantilla %qD"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "conversión de tipo por defecto ambigua desde %qT"
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  las conversiones candidatas incluyen %qD y %qD"
@@ -35520,246 +35565,246 @@
 msgid "template parameters do not match template %qD"
 msgstr "los parámetros de la plantilla no coinciden con la plantilla"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr "un struct anónimo no puede tener funciones miembro"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr "un union anónimo no puede tener funciones miembro"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con constructor en un agregado anónimo"
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con destructor en un agregado anónimo"
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con operador de asignación de copia en un agregado anónimo"
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "se descarta el atributo en la declaración de %q#T"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "el atributo para %q#T debe estar a continuación de la palabra clave %qs"
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "tipos múltiples en una declaración"
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redeclaración del tipo interno de C++ %qT"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> sólo se puede especificar para variables o declaraciones de función"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "falta el nombre del tipo en la declaración typedef"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ prohíbe structs anónimos"
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr "%qs sólo se puede especificar para funciones"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> sólo se puede especificar dentro de una clase"
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> sólo se puede especificar para constructores"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "una clase de almacenamiento sólo se puede especificar para objetos y funciones"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "se descartó %<typedef%> en esta declaración"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%> no se puede usar en declaraciones de tipo"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "se descartan los atributos en la instanciación de una plantilla"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "se descartan los atributos aplicados al tipo de clase %qT fuera de la definición"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "se descartan los atributos aplicados al tipo dependiente %qT sin una declaración asociada"
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD está inicializado (utilice decltype en su lugar)"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "la declaración de %q#D tiene %<extern%> y está inicializada"
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "la definición de %q#D se marca como %<dllimport%>"
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D no es un dato miembro no static de %qT"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "declaración plantilla de %q#D"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "declaración de la plantilla miembro %qD inválida"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ no permite que %<%T::%D%> se defina como %<%T::%D%>"
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "inicialización duplicada de %qD"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr "%qD se declaró %<constexpr%> fuera de su clase"
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "la declaración de %q#D fuera de la clase no es una definición"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qE no se declaró aquí (no en una función)"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "la variable %q#D tiene inicializador pero de tipo de dato incompleto"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementos de la matriz %q#D con tipo de dato incompleto"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "la declaración de %q#D no tiene inicializadores"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "el agregado %q#D tiene un tipo incompleto y no se puede definir"
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD declarado como referencia pero no se inicializa"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "se usó un nombre en un inicializador designado de estilo GNU para una matriz"
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "el nombre %qD se utiliza en un inicializador designado en estilo GNU para una matriz"
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "no se admiten los inicializadores designados como no triviales"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "el inicializador no puede determinar el tamaño de %qD"
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "falta el tamaño de la matriz en %qD"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "matriz %qD de tamaño cero"
@@ -35767,842 +35812,842 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "no se conoce el tamaño de almacenamiento de %qD"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "el tamaño de almacenamiento de %qD no es constante"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "perdón: la semántica de los datos static de la función inline %q+#D es errónea (terminará con múltiples copias)"
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, fuzzy, gcc-internal-format
 #| msgid "  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "  puede evitar esto eliminando el inicializador"
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "const %qD sin inicializar"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T no tiene constructor por defecto proporcionado por el usuario"
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "el constructor no es proporcionado por el usuario porque está marcado explícitamente por defecto en el cuerpo de la clase"
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr "y el constructor implícitamente definido no inicializa %q+#D"
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "tipo %qT inválido como inicializador para un vector de tipo %qT"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "el inicializador para %qT debe estar encerrado entre llaves"
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "se usa %<[%E] =%> en un inicializador designado en estilo GNU para la clase %qT"
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT no tiene un dato miembro que no es static llamado %qD"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for array member %q#D"
 msgid "invalid initializer for %q#D"
 msgstr "inicializador inválido para la matriz miembro %q#D"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "asignador C99 %qE fuera del inicializador agregado"
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "demasiados inicializadores para %qT"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "llaves alrededor del inicializador escalar para el tipo %qT"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "faltan llaves alrededor del inicializador para %qT"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementos de la matriz %q#T tienen tipo de dato incompleto"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "literal compuesta de tamaño variable"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D tiene un tipo incompleto"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "el objeto escalar %qD requiere un elemento en el inicializador"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "en C++98 %qD debe ser inicializado por un constructor, no por %<{...}%>"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "matriz %qD inicializada con una constante de cadena entre paréntesis %qE"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "inicializador inválido para el miembro static con constructor"
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "inicialización en clase que no es constante inválida para el miembro static %qD"
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(se requiere una inicialización fuera de la clase)"
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is initialized with itself"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD se inicializa con sí mismo"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "se oscurece la declaración de tipo previa de %q#D"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr "El objeto Java %qD no se aloja con %<new%>"
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr "el dato miembro que no es estático %qD tiene un tipo de clase Java"
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "la función %q#D se inicializa como una variable"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T tiene un destructor que no es trivial"
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "el inicializador no puede determinar el tamaño de %qT"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "falta el tamaño de la matriz en %qT"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "matriz %qT de tamaño cero"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "el destructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "el constructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD se declaró como una variable %<virtual%>"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> variable"
 msgstr "%qD se declaró como una variable %<inline%>"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son inválidos en la declaración de variable"
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD se declaró como un parámetro %<virtual%>"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD se declaró como un parámetro %<inline%>"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son inválidos en la declaración de parámetro"
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD se declaró como un tipo %<virtual%>"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD se declaró como un tipo %<inline%>"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son inválidos en la declaración de tipo"
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD se declaró como un campo %<virtual%>"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD se declaró como un campo %<inline%>"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son inválidos en la declaración de campo"
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D se declaró con una especificación de excepción"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "la definición de %qD no está en un espacio de nombres que contenga a %qT"
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "la función miembro static %q#D se declara con calificadores de tipo"
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definiendo la especialización explícita %qD en la declaración friend"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "uso inválido del id de plantilla %qD en la declaración de la plantilla primaria"
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "no se permiten los argumentos por defecto en la declaración de la especialización friend de la plantilla %qD"
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "no se permite %<inline%> en la declaración de la especialización friend de la plantilla %qD"
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr "no se permite %<inline%> en la declaración de la especialización friend de la plantilla %qD"
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "no se puede declarar %<::main%> como plantilla"
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "no se puede declarar %<::main%> como inline"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "no se puede declarar %<::main%> como inline"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "no se puede declarar %<::main%> como static"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "operador literal con enlace C"
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD tien una lista de argumentos inválida"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr "se oscurece el sufijo entero %<%s%> por la implementación"
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr "se oscurece el sufijo de coma flotante %<%s%> por la implementación"
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD debe ser una función que no sea miembro"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> debe devolver %<int%>"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "la definición de %qD declarado implícitamente"
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "la definición de %qD explícitamente por defecto"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, gcc-internal-format
 msgid "%q+#D explicitly defaulted here"
 msgstr "%q+#D explícitamente por defecto aquí"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "no hay una función miembro %q#D declarada en la clase %qT"
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "inicialización en la clase del miembro de datos static %q#D de tipo incompleto"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "se necesita %<constexpr%> para la inicialización en la clase inválida del miembro de datos static %q#D de tipo que no es integral"
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "inicialización en la clase del miembro de datos static %q#D de tipo que no es literal"
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "inicialización en la clase inválida para el miembro de datos static de tipo %qT que no es integral"
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ prohíbe la inicialización en la clase del miembro static %qD que no es constante"
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ prohíbe la inicialización de la constante miembro %qD del tipo %qT que no es entero"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "el tamaño de la matriz %qD tiene un tipo %qT que no es integral"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "el tamaño de la matriz tiene un tipo %qT que no es integral"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "el tamaño de la matriz %qD es negativo"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "el tamaño de la matriz es negativo"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ prohíbe la matriz %qD de tamaño cero"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ prohíbe matrices de tamaño cero"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ prohíbe la matriz %qD de longitud variable"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ prohíbe las matrices de longitud variable"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "se usa la matriz de longitud variable %qD"
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "se usó la matriz de longitud variable"
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "desbordamiento en la dimensión de la matriz"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "la declaración de %qD como una matriz de voids"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "se crea la matriz de voids"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "la declaración de %qD como una matriz de funciones"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "se crea la matriz de funciones"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "la declaración de %qD como una matriz de referencias"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "se crea la matriz de referencias"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "la declaración de %qD como una matriz de miembros de función"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "se crea la matriz de miembros de función"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la declaración de %qD como una matriz multidimensional debe tener límites para todas las dimensiones excepto la primera"
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "una matriz multidimensional debe tener límites para todas las dimensiones excepto para la primera"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "la especificación del tipo de devolución para el constructor es inválida"
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "la especificación del tipo de devolución para el destructor es inválida"
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "se especificó un tipo de devolución para %<operator %T%>"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "se declaró la variable o campo sin nombre como void"
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "se declaró la variable o campo como void"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "uso inválido del nombre calificado %<::%D%>"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "uso inválido del nombre calificado %<%T::%D%>"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "uso inválido del nombre calificado %<%D::%D%>"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T no es una clase o un espacio de nombres"
 
 #  FIXME traducción
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "la declaración de %qD como algo que no es función"
 
 #  FIXME traducción
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "declaración de %qD como algo que no es miembro"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "falta el id del declarador; se utiliza la palabra reservada %qD"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "la definición de la función no declara parámetros"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "declaración de %qD como %<typedef%>"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "la declaración de %qD como parámetro"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> no puede aparecer en una declaración typedef"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "dos o más tipos de datos en la declaración de %qs"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C no admite %<complex%> simples que significan %<double complex%>"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ prohíbe la declaración de %qs sin tipo"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "no se admite %<__int128%> en este objetivo"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ no admite %<__int128%> para %qs"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> o %<unsigned%> inválido para %qs"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> y %<unsigned%> se especificaron juntos para %qs"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> inválido para %qs"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> inválido para %qs"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> inválido para %qs"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> o %<short%> inválidos para %qs"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%>, o %<char%> inválido para %qs"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "se especificó %<long%> o %<short%> con char para %qs"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> y %<short%>  se especificaron juntos para %qs"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> o %<long%> inválidos para %qs"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "uso inválido de long, short, signed ó unsigned para %qs"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex inválido para %qs"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr "el miembro %qD no se puede declarar como virtual y static al mismo tiempo"
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "declaración typedef inválida en la declaración de parámetros"
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "se especificó una clase de almacenamiento para el parámetro de plantilla %qs"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "especificadores de clase de almacenamiento inválidos en las declaraciones de parámetros"
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "declaración de clase fuera de %<virtual%>"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "múltiples clases de almacenamiento en la declaración de %qs"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "se especificó una clase de almacenamiento para %qs"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "se especificó una clase de almacenamiento para el parámetro %qs"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "la función anidada %qs se declaró %<extern%>"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "la declaración del nivel superior de %qs especifica %<auto%>"
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "el ámbito de la función %qs es implícitamente auto y declarado %<__thread%>"
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "especificadores de clase de almacenamiento inválidos en las declaraciones de funciones friend"
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs que se declaró como función devuelve una función"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs que se declaró como función devuelve una matriz"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "la función %qs usa el especificador de tipo %<auto%> sin un tipo de devolución trailing"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "la función %qs con tipo de devolución trailing tiene %qT como su tipo en lugar de un simple %<auto%>"
@@ -36609,481 +36654,481 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "no se declaró la función %qs con tipo de devolución trailing con el especificador de tipo %<auto%>"
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "el destructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "los constructores tal vez no sean cv-calificados"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr "los constructores no se pueden declarar virtual"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "la declaración friend no está en una definición de clase"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "no se puede definir la función friend %qs en una definición de clase local"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "los destructores no pueden tener parámetros"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "no se puede declarar el puntero a %q#T"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "no se puede declarar la referencia a %q#T"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "no se puede declarar el puntero al miembro %q#T"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "no se puede declarar la referencia a %q#T, el cual no es una definición de tipo o un argumento de tipo de plantilla"
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "el id de plantilla %qD se usa como un declarador"
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "las funciones miembros son implícitamente friends de su clase"
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "calificación extra %<%T::%> en el miembro %qs"
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "no se puede definir la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "no se puede declarar la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "no se puede declarar el miembro %<%T::%s%> dentro de %qT"
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "%qs que no es parámetro no puede ser un paquete de parámetro"
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "el tamaño de la matriz %qs es demasiado grande"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "los datos miembro pueden no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "el parámetro puede no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "declaración de clase fuera de %<virtual%>"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> en una declaración vacía"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "solamente las declaraciones de constructores pueden ser %<explicit%>"
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "el miembro que no es objeto %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "static %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "la referencia %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "la definición de tipo se declaró %<auto%>"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "el nombre del typedef puede no ser un especificador-de-nombre-anidado"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ prohíbe el tipo anidado %qD con el mismo nombre que la clase que lo contiene"
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr "se especificaron calificadores de tipo para la declaración de clase friend"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "se especificó %<inline%> para la declaración de clase friend"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "los parámetros de la plantilla no pueden ser friends"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "la declaración friend requere una llave de clase, p.e. %<friend class %T::%D%>"
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "la declaración friend requiere una llave de clase, p.e. %<friend %#T%>"
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "se intenta hacer que la clase %qT sea un friend de ámbito global"
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "calificadores inválidos en el tipo de función que no es miembro"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "el declarador abstracto %qT se usó como declaración"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "no se puede usar %<::%>  en la declaración de parámetros"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "no se puede usar %<this%> en este contexto"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "el parámetro se declaró %<auto%>"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, gcc-internal-format
 msgid "non-static data member declared %<auto%>"
 msgstr "se declaró el miembro dato que no es static como %<auto%>"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "uso inválido de %<::%>"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "declaración de la función %qD en un contexto inválido"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "la función %qD se declaró virtual dentro de un union"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr "%qD no se puede declarar virtual, ya que siempre es static"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el destructor %qD"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el constructor %qD"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD redeclared as function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "la variable %qD se redeclaró como función"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 #| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "el tipo original se definió aquí"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "el campo %qD tiene tipo de dato incompleto"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "el nombre %qT tiene tipo de dato incompleto"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE no es ni función ni función miembro; no se puede declarar friend"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr "el miembro dato static constexpr %qD debe tener un inicializador"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<auto%> es inválida para la función %qs"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<register%> es inválida para la función %qs"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es inválida para la función %qs"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es inválida para la función %qs"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "no se permiten los especificadores-virt en %qs fuera de una definición de clase"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr "el especificador %<static%> es inválido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "el especificador %<inline%> es inválido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "función virtual %qs que no es clase"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "se definió %qs en un ámbito que no es una clase"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "se declaró %qs en un ámbito que no es una clase"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "no se puede declarar que la función miembro %qD tenga enlace estático"
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "no se puede declarar una función static dentro de otra función"
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> puede no ser utilizado cuando se define (opuesto a la declaración) un dato miembro static"
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "se declaró el miembro static %qD como %<register%>"
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "no se puede declarar explícitamente que el miembro %q#D tenga un enlace externo"
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, gcc-internal-format
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "la declaración de la variable constexpr %qD no es una definición"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs inicializado y declarado como %<extern%>"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs tiene %<extern%> e inicializador al mismo tiempo"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "el argumento por defecto %qE usa %qD"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "el argumento por defecto %qE usa la variable local %qD"
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "uso inválido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "uso inválido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "el parámetro %qD tiene tipo de clase Java"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "el parámetro %qD se declaró inválidamente como tipo de método"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye un puntero a matriz %qT de límite desconocido"
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye una referencia a matriz %qT de límite desconocido"
@@ -37103,98 +37148,98 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructor inválido; tal vez quiso decir %<%T (const %T&)%>"
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD no se puede declarar dentro de un espacio de nombres"
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD no se puede declarar como static"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD debe ser una función miembro que no sea static"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD debe ser una función miembro que no sea static o una función que no sea miembro"
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD debe tener un argumento de tipo clase o enumerado"
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "la conversión a una referencia a void nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "la conversión a void nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "la conversión a una referencia al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "la conversión al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "la conversión a una referencia a una clase base nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "la conversión a una clase base nunca usará un operador de conversión de tipo"
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ prohíbe la sobrecarga del operador ?:"
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD no debe tener un número variable de argumentos"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su argumento"
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su segundo argumento"
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr "%qD debe tomar cero o un argumentos"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr "%qD debe tomar uno o dos argumentos"
@@ -37201,77 +37246,77 @@
 
 #  En esta traducción se emplea 'devolver' por 'return'. Si embargo, aquí
 #  se cambió por cacofonía: no es agradable escuchar 'debe devolver'. cfuga
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "el prefijo %qD debe regresar %qT"
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "el postfijo %qD debe regresar %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr "%qD debe tomar %<void%>"
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr "%qD debe tomar un argumento exactamente"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "%qD debe tomar dos argumentos exactamente"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "el %qD definido por el usuario siempre evalúa ambos argumentos"
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD debe devolver por valor"
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD no puede tener argumentos por defecto"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "usando el parámetro de tipo plantilla %qT después de %qs"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "se usa especialización de plantilla %qT alias después de %qs"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "se usó el nombre de definición de tipo %qD después de %qs"
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD tiene una declaración previa aquí"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "se refirió a %qT como %qs"
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "%q+T tiene una declaración previa aquí"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "se refirió a %qT como un enum"
@@ -37283,48 +37328,48 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "se requiere un argumento de plantilla para %<%s %T%>"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD tiene el mismo nombre que la clase en la cual se declaró"
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "uso del enum %q#D sin declaración previa"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeclaración de %qT como algo que no es plantilla"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "declaración previa de %q+D"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union derivada %qT inválida"
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr "la clase Java %qT no puede tener bases múltiples"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr "la clase Java %qT no puede tener bases virtuales"
@@ -37331,42 +37376,42 @@
 
 #  No me gusta mucho esta traducción. Creo que es mejor
 #  "el tipo base %qT no es de tipo struct o clase". cfuga
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "el tipo base %qT falla en ser un tipo struct o clase"
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipo recursivo %qT sin definir"
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "tipo base duplicado %qT inválido"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "no coinciden scoped/unscoped en el enum %q#T"
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "la definición previa está aquí"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "no coincide el tipo subyacente en el enum %q#T"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "tipos subyacentes diferentes en el enum %q#T"
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr "el tipo subyacente %<%T%> de %<%T%> debe ser un tipo integral"
@@ -37375,90 +37420,90 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ningún tipo integral puede representar todos los valores de enumerador de %qT"
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "el valor de enumerador para %qD no es una constante entera"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "el valor del enumerador incrementado es demasiado grande para %<unsigned long%>"
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "desbordamiento en valores de enumeración en %qD"
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr "el valor de enumerador %E es demasiado grande para el tipo subyacente %<%T%>"
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr "el tipo de devolución tiene tipo de clase Java %q#T"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> debe devolver una referencia a %<*this%>"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "no hay declaración previa para %q+D"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "declaración de función inválida"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "el parámetro %qD se declaró void"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "los tipos de devolución de función no son compatibles debido a %<volatile%>"
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, gcc-internal-format
 msgid "parameter %q+D set but not used"
 msgstr "se define el parámetro %q+D pero no se usa"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "declaración de la función miembro inválida"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ya se definió en la clase %qT"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD defaults to %<int%>"
 msgid "use of %qD before deduction of %<auto%>"
@@ -37500,7 +37545,7 @@
 msgid "deleting %qT is undefined"
 msgstr "el borrado de %qT está indefinido"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "declaración plantilla de %q#D"
@@ -37523,7 +37568,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "se declaró el destructor %qD como una plantilla miembro"
@@ -37616,28 +37661,28 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "la anchura del campo de bits %qD es del tipo %qT que no integral"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a static data member of a class template"
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD no es un dato miembro static de una plantilla de clase"
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "struct anónimo no está dentro de un tipo nombrado"
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "los agregados anónimos de alcance de espacio de nombres deben ser static"
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "union anónima sin miembros"
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> debe devolver el tipo %qT"
@@ -37646,47 +37691,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "el primer parámetro de %<operator new%> no puede tener un argumento por defecto"
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> toma el tipo %<size_t%> (%qT) como primer argumento"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> debe devolver el tipo %qT"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> toma el tipo %qT como primer argumento"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT se declaró con mayor visibilidad que el tipo de su campo %qD"
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT se declaró con mayor visibilidad que su base %qT"
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using anonymous type, is used but never defined"
 msgid "%q#D, declared using anonymous type, is used but never defined"
@@ -37696,49 +37741,49 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr "se usó un tipo anónimo sin enlace para declarar la variable %q#D sin enlace"
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr "se usó un tipo anónimo sin enlace para declarar la función %q#D con enlace"
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D no se refiere al tipo sin calificar, así que no se usa para el enlace"
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using local type %qT, is used but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D, declarada usando el tipo local %qT, se usa pero nunca se define"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "se usó el tipo %qT sin enlace para declarar la variable %q#D con enlace"
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "se usó el tipo %qT sin enlace para declarar la función %q#D con enlace"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "se usa la función inline %q+D pero nunca se define"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "falta el argumento por defecto para el parámetro %P de %q+#D"
@@ -37745,12 +37790,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr "se convierte lambda la cual usa %<...%> a un puntero de función"
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "se usó la función borrada %q+D"
@@ -38346,42 +38391,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "no se llamará ni al destructor ni al operador delete específico de la clase, aún si se declaran cuando se defina la clase"
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "el inicializador termina prematuramente"
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr "no se pueden inicializar matrices multidimensionales con el inicializador"
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "tamaño de matriz desconocida en delete"
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "se detectó un posible problema en la invocación del operador delete:"
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "no se llamará ni al destructor ni al operador delete específico de la clase, aún si se declaran cuando se defina la clase"
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr "si borra un objeto de tipo de clase abstracta %qT que tiene un destructor que no es virtual, puede causar conducta indefinida"
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr "si borra un objeto de tipo de clase polimórfica %qT que tiene un destructor que no es virtual, puede causar conducta indefinida"
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
@@ -38513,19 +38558,19 @@
 msgid "string literal in function template signature"
 msgstr "literal de cadena en la firma de plantilla de función"
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, fuzzy, gcc-internal-format
 #| msgid "-fabi-version=6 (or =0) avoids this error with a change in mangling"
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=6 (o =0) evita este error con un cambio en la decodificación"
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
@@ -38946,7 +38991,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr "el identificador %qE es una palabra clave en C++11"
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -38971,7 +39016,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "solicitud por el miembro %qE en el tipo %qT que no es clase"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> no se ha declarado"
@@ -39036,7 +39081,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(tal vez falta un punto y coma después de la definición de %qT)"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT no es una plantilla"
@@ -39062,7 +39107,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "una literal de coma flotante no puede aparecer en una expresión constante"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "una conversión a un tipo diferente de un tipo integral o de enumeración no puede aparecer en una expresión constante"
@@ -39338,7 +39383,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "los sufijos de operador literal que no están precedidos por %<_%> están reservados para estandarización futura"
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "se esperaba un id sin calificar"
@@ -39519,7 +39564,7 @@
 msgid "capture of non-variable %qD "
 msgstr "captura de %qD que no es variable "
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, gcc-internal-format
 msgid "%q+#D declared here"
 msgstr "%q+#D se declaró aquí"
@@ -39581,7 +39626,7 @@
 msgid "compound-statement in constexpr function"
 msgstr "declaración compuesta en una función constexpr"
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "se esperaba una declaración de selección"
@@ -39611,7 +39656,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "tipos begin/end inconsistentes para la declaración %<for%> basada en rango: %qT y %qT"
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "se esperaba una declaración de iteración"
@@ -39646,12 +39691,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ prohíbe los gotos calculados"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "se esperaba una declaración de salto"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "<;%> extra"
@@ -39700,7 +39745,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "la definición de clase no se puede declarar como friend"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "las plantillas no pueden ser %<virtual%>"
@@ -39795,12 +39840,12 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "no se admite la palabra clave %<export%>, y se descartará"
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "el paquete de parámetros plantilla %qD no puede tener un argumento por defecto"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "el paquete de parámetros plantilla no puede tener un argumento por defecto"
@@ -39815,7 +39860,7 @@
 msgid "expected template-id"
 msgstr "se esperaba un id de plantilla"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "se esperaba %<<%>"
@@ -39893,214 +39938,214 @@
 msgid "expected type specifier"
 msgstr "se esperaba un specificador de tipo"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C prohíbe declaraciones adelantadas de parámetros"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "se esperaba un id de plantilla para el tipo"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "se esperaba un nombre de tipo"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr "el especificador de tipo elaborado para un ámbito enumerado no debe usar la palabra clave %<%D%>"
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "la declaración %qD no declara nada"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "se descartan los atributos en el tipo sin instanciar"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "se descartan los atributos en la instanciación de una plantilla"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "se descartan los atributos en un especificador de tipo elaborado que no es una declaración adelantada"
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD es una plantilla de enumeración"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, gcc-internal-format
 msgid "%qD is not an enumerator-name"
 msgstr "%qD no es un nombre-de-enumerador"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "se esperaba %<;%> o %<{%>"
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "no se puede agregar una lista de enumerador a una instanciación de plantilla"
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "la declaración de %qD en el espacio de nombres %qD el cual no incluye a %qD"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "la declaración de %qD en %qD la cual no incluye a %qD"
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "definición múltiple de %q#T"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C++ prohíbe incrementar un enum"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "especificador enumerador opaco sin nombre"
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "el especificador enumerador opaco debe usar un identificador simple"
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD no es un nombre-de-espacio-de-nombres"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "se esperaba un nombre de espacio"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "la definición %<namespace%> no se permite aquí"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "un id-de-plantilla no puede aparecer en una declaración-using"
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "las declaraciones access son obsoletas en favor de las declaraciones using: sugerencia: use la palabra clave %<using%>"
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "no se pueden definir tipos en declaraciones de plantilla alias"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "declaración compuesta en una función constexpr"
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "una definición de función no se permite aquí"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "no se permite una especificación-asm en una definición-de-función"
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "no se permiten atributos en una definición-de-función"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "se esperaba un constructor, un destructor, o una conversión de tipo"
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "se esperaba un inicializador"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "se proporcionó un inicializador para la función"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "se descartan los atributos después del inicializador entre paréntesis"
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "se redeclara la función %q+D como inline"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "el límite de la matriz no es una constante entera"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "no se puede definir el miembro de la definición de tipo dependiente %qT"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> no es un tipo"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "uso inválido del constructor como una plantilla"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "use %<%T::%D%> en lugar de %<%T::%D%> para nombrar el constructor en un nombre calificado"
@@ -40109,7 +40154,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "declarador inválido"
@@ -40116,299 +40161,299 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type in declaration"
 msgid "qualified-id in declaration"
 msgstr "tipo inválido en la declaración"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "se esperaba un declarador"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD es un espacio de nombres"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "no se puede formar un puntero al miembro de %q#T que no es clase"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "se esperaba un operador puntero"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "calificador-cv duplicado"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple ref-qualifiers"
 msgstr "especificadores `virtual' múltiples"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "especificador-virt duplicado"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, gcc-internal-format
 msgid "invalid use of %<auto%>"
 msgstr "uso inválido de %<auto%>"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "no se pueden definir tipos en argumentos de plantilla"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "uso inválido de '%E' como un argumento de plantilla que no es tipo"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "se esperaba un especificador de tipo"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "se esperaba %<,%> o %<...%>"
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "no se pueden definir tipos en tipos de parámetro"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr "uso obsoleto del argumento por defecto para el parámetro de una no función"
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "los argumentos por defecto sólo se permiten para parámetros de función"
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "el paquete de parámetros %qD no puede tener un argumento por defecto"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "el paquete de parámetros no puede tener un argumento por defecto"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ no permite inicializadores designados de C99"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "se esperaba un nombre de clase"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "se esperaba %<;%> después de la definición de clase"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "se esperaba %<;%> después de la definición de struct"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "se esperaba %<;%> después de la definición de union"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "se esperaba %<{%> o %<:%>"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "no se puede especificar %<override%> para una clase"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "la calificación global del nombre de clase es inválida"
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "el nombre calificado no nombra una clase"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "nombre de clase inválido en la declaración de %qD"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "no se permite la calificación extra"
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "una especialización explícita se debe preceder con %<template <>%>"
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "la plantilla de función %qD se redeclaró commo una plantilla de clase"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "no se puede resolver el tipo typename"
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr "definición previa de %q+#T"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "se esperaba una llave de clase"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "en C++03 se debe usar una llave-clase cuando se declara un friend"
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "la declaración friend no nombra una clase o función"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "especificador-pure en la definición-de-función"
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "se esperaba %<;%> al final de la declaración miembro"
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "se esperaba %<;%> al final de la declaración miembro"
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "especificador pure inválido (sólo se permite %<= 0%>)"
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "un inicializador dentro de llaves no se permite aquí"
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr "se especificó %<virtual%> más de una vez en la base especificada"
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr "más de un especificador de acceso en la base especificada"
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "no se permite la palabra clave %<typename%> en este contexto (la clase base es implícitamente un tipo)"
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "no se pueden definir tipos en una especificación de excepción"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr "las especificaciones de excepción dinámicas son obsoletas en C++0x; utilice %<noexcept%> en su lugar"
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not %<constexpr%>"
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%qD no es %<constexpr%>"
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "no se pueden definir tipos en declaraciones de excepción"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "se esperaba un identificador o %<(%>"
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "el miembro especializado %<%T::%E%> requiere sintaxis %<template<>%>"
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "declaración inválida de %<%T::%E%>"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "faltan listas-de-parámetros-de-plantilla"
@@ -40417,554 +40462,554 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "demasiadas listas-de-parámetros-de-plantilla"
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "ya no se admiten los valores de devolución nombrados"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "declaración inválida de plantilla miembro en la clase local"
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "plantilla con enlace C"
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "especialización explícita inválida"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, fuzzy, gcc-internal-format
 #| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros inválida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros inválida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "declaración plantilla de %<typedef%>"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "la especialización de plantilla explícita no puede tener una clase de almacenamiento"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> debe ser %<> >%> dentro de una lista de argumentos de plantilla anidada"
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%<>>%> sobrante, use %<>%> para terminar una lista de argumentos de plantilla"
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "uso inválido de %qD en la especificación de enlace"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> antes de %qD"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 no admite %<long long%>"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "se usaron al mismo tiempo %<_Sat%> y %<char%> en los especificadores de declaración"
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE duplicado"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs duplicado"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "se esperaba %<new%>"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "se esperaba %<delete%>"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "se esperaba %<return%>"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "se esperaba %<extern%>"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "se esperaba %<static_assert%>"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "se esperaba %<decltype%>"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "se esperaba %<class%>"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "se esperaba %<template%>"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "se esperaba %<namespace%>"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "se esperaba %<using%>"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "se esperaba %<asm%>"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "se esperaba %<try%>"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "se esperaba %<catch%>"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "se esperaba %<throw%>"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "se esperaba %<__label__%>"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "se esperaba %<@try%>"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "se esperaba %<@synchronized%>"
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "se esperaba %<@throw%>"
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "se esperaba %<__transaction_atomic%>"
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "se esperaba %<__transaction_relaxed%>"
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "se esperaba %<::%>"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "se esperaba %<...%>"
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "se esperaba %<*%>"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "se esperaba %<~%>"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "se esperaba %<:%> o %<::%>"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "se usó la etiqueta %qs al nombrar a %q#T"
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T se declaró previamente aquí"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD se redeclaró con acceso diferente"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (como desambiguador) sólo se permite dentro de plantillas"
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "el fichero termina en el argumento por defecto"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "construct Objective-C++ %<@%D%> mal ubicado"
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c++ message argument(s) are expected"
 msgid "objective-c++ message receiver expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> debe especificar un tipo como un argumento"
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "nombre de selector Objective-C++ inválido"
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "se esperaba una declaración de método de objective-c++"
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "los atributos de método se deben especificar al final"
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "%qs sobrante después de los métodos Objective-C++"
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "tipo inválido para la variable de de instancia"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "se esperaba un identificador después de %<@protocol%>"
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "los atributos no se pueden especificar antes de la palabra clave de Objective-C++ %<@%D%>"
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "se descartan los atributos de prefijo antes de %<@%D%>"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "tipo inválido para la propiedad"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected positive integer expression"
 msgstr "se esperaba una expresión entera"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "inicializador inválido"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "no se permite la inicialización entre paréntesis para el bucle %<for%> en OpenMP"
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "no se permite la inicialización entre paréntesis para el bucle %<for%> en OpenMP"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable de iteración %qD no debe ser reduction"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, gcc-internal-format
 msgid "not enough collapsed for loops"
 msgstr "no se colapsó lo suficiente para los bucles"
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "no se permiten atributos en una definición-de-función"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "inicializador inválido"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 #| msgid "expected id-expression"
 msgid "expected id-expression (arguments)"
 msgstr "se esperaba una expresión id"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> o %<max%>"
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "no se pueden definir tipos nuevos en un tipo de devolución"
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "basura al final de %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "restricciones inválidas para el operando"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "no se han implementado las optimizaciones intermódulos para C++"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "se esperaba un nombre variable en %C"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "se esperaba %<,%> o %<)%>"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "las plantillas no pueden ser %<virtual%>"
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "el dato miembro %qD no puede ser una plantilla miembro"
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "declaración de la plantilla miembro %qD inválida"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "especialización explícita en el ámbito %qD que no es espacio de nombres"
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "las plantillas de clase contenedoras no son explícitamente especializadas"
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "especialización de %qD en un espacio de nombres diferente"
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr " de la definición de %q+#D"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "instanciación explícita de %qD en el espacio de nombres %qD (el cual no incluye el espacio de nombres %qD)"
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "el nombre de la clase oscurece la plantilla de parámetro de plantilla %qD"
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "specialization of alias template %qD"
 msgstr "especialización parcial de la plantilla alias %qD"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "especialización de %qT después de la instanciación"
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "se especializó %q#T en un espacio de nombres diferente"
@@ -40971,72 +41016,72 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "especialización de %qT después de la instanciación %qT"
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "no se permite la especialización de plantilla de %qD por ISO C++"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "especialización de %qD después de la instanciación"
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid "candidate is: %#D"
 msgstr "el candidato es: %+#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
 msgstr "%s %+#D"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD no es una plantilla de función"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD no es una variable"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "el id-de-plantilla %qD para %q+D no coincide con ninguna declaración de plantilla"
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "se encontró %d %<template<>%>, se necesita %d para especializar una plantilla de función miembro"
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "especialización de plantilla %qD ambigua para %q+D"
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %D (should be %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -41043,59 +41088,59 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "id de plantilla %qD en la declaración de la plantilla primaria"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "no se usan la plantilla de lista de parámetros en la instanciación explícita"
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "se proporcionó una definición para la instanciación explícita"
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "demasiadas listas de parámetros de plantilla en la declaración de %qD"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "faltan listas de parámetros de plantilla en la declaración de %qD"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "la especialización explícita de %qD se debe preceder con %<template <>%>"
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "no se permite la especialización parcial de la función de plantilla %qD"
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "no se permite la especialización parcial de la función de plantilla %qD"
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "se especificó un argumento por defecto en la especialización explícita"
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD no es una función plantilla"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "%qD no se declaró en %qD"
@@ -41108,95 +41153,95 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "especialización de la función miembro especial declarada implícitamente"
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "la función no miembro %qD se declaró en %qT"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr "la expansión del inicializador base %<%T%> no contiene paquetes de parámetro"
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr "el patrón de expansión %<%T%> no contiene paquetes de argumento"
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr "el patrón de expansión %<%E%> no contiene paquetes de argumento"
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "no se expanden los paquetes de parámetro con %<...%>"
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anónimo>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "la declaración de %q+#D"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr " oscurece el parámetro de plantilla %q+#D"
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "no se usan los parámetros de plantilla en la especialización parcial:"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template here"
 msgstr "se declaró previamente aquí"
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "el argumento de paquete de parámetro %qE debe estar al final de la lista de argumentos de plantilla"
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "el argumento de paquete de parámetro %qT debe estar al final de la lista de argumentos de plantilla"
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "el argumento de plantilla %qE involucra a el(los) parámetro(s) de plantilla"
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -41203,13 +41248,13 @@
 msgstr[0] "el tipo %qT del argumento de plantilla %qE depende de un parámetro de plantilla"
 msgstr[1] "el tipo %qT del argumento de plantilla %qE depende de parámetros de plantilla"
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of %qT after instantiation of %qT"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "especialización parcial de %qT después de la instanciación %qT"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "no hay un argumento por defecto para %qD"
@@ -41217,43 +41262,43 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "el parámetro de paquete %qE debe estar al final de la lista de parámetros de plantilla"
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en la re-declaración friend de la plantilla de función"
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en las declaraciones friend de la plantilla de función"
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "los argumentos de plantilla por defecto no se pueden usar en las plantillas de función sin -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en las especializaciones parciales"
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "clase de plantilla sin nombre"
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -41264,57 +41309,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "declaración de la plantilla de %qD inválida"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "definición de plantilla de %q#D que no es plantilla"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "se esperaban %d niveles de parámetros de plantilla para %q#D, se obtuvieron %d"
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "se obtuvieron %d parámetros de plantilla para %q#D"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "se obtuvieron %d parámetros de plantilla para %q#T"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  pero se requieren %d"
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "los argumentos de plantilla para %qD no coinciden con la plantilla original %qD"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr "utilice template<> para una especialización explícita"
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT no es un tipo plantilla"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "no se especificaron los especificadores de plantilla en la declaración de %qD"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -41321,7 +41366,7 @@
 msgstr[0] "se redeclaró con %d parámetro de plantilla"
 msgstr[1] "se redeclaró con %d parámetros de plantilla"
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, gcc-internal-format
 msgid "previous declaration %q+D used %d template parameter"
 msgid_plural "previous declaration %q+D used %d template parameters"
@@ -41328,12 +41373,12 @@
 msgstr[0] "la declaración previa de %q+#D usó %d parámetro de plantilla"
 msgstr[1] "la declaración previa de %q+#D usó %d parámetros de plantilla"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "parámetro de plantilla %q+#D"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redeclarado aquí como %q#D"
@@ -41342,103 +41387,103 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redefinición del argumento por defecto para %q#D"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "la definición original apareció aquí"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "debe ser la dirección de una función con enlace externo"
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "debe ser la dirección de una función con enlace externo"
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque %qD no tiene enlace"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "debe ser un puntero-a-miembro de la forma %<&X::Y%>"
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "  no se puede deducir el parámetro de plantilla %qD"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  los tipos %qT y %qT tiene calificadores-cv incompatibles"
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  no coinciden los tipos %qT y %qT"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  el parámetro de plantilla %qD no es un paquete de parámetro, pero el argumento %qD sí"
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  el argumento de plantilla %qE no coincide con la constante puntero-a-miembro %qE"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE no es equivalente a %qE"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  deducción de paquete de parámetros inconsistente con %qT y %qT"
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  se deducen tipos en conflicto para el parámetro %qT (%qT y %qT)"
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  se deducen valores en conflicto para el parámetro %qE que no es tipo (%qE y %qE)"
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  el tipo de función miembro %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -41447,173 +41492,173 @@
 msgstr[0] "  el candidato espera %d argumento, se proporcionaron %d"
 msgstr[1] "  el candidato espera %d argumentos, se proporcionaron %d"
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  no se puede convertir %qE (tipo %qT) al tipo %qT"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT es una clase base ambigua de %qT"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT no es derivado de %qT"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  los parámetros de plantilla de un argumento de plantilla plantilla son inconsistentes con otros argumentos de plantilla deducidos"
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "  no se puede deducir una plantilla para %qT del tipo %qT que no es plantilla"
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qD"
 msgstr "  el argumento de plantilla %qE no coincide con %qD"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, gcc-internal-format
 msgid "  could not resolve address from overloaded function %qE"
 msgstr "  no se puede resolver la dirección de la función sobrecargada %qE"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque las literales de cadena nunca se pueden usar en este contexto"
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, gcc-internal-format
 msgid "in template argument for type %qT "
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD no es un argumento válido de plantilla porque %qD es una variable, no la dirección de una variable"
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD no es un argumento válido de plantilla porque %qD es una variable, no la dirección de una variable"
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qE no es una variable"
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace"
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT debido a conflictos en la calificación cv"
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque no es un l-valor"
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D no es un argumento válido de plantilla para el tipo %qT porque una referencia variable no tiene una dirección constante"
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque no es un objeto con enlace externo"
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque el objeto %qD no tiene enlace externo"
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es un puntero"
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "intente utilizar %qE en su lugar"
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es de tipo %qT"
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "no se permiten las conversiones estándar en este contexto"
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "se usó el nombre-de-clase-inyectada %qD como un argumento de plantilla plantilla"
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "uso inválido del destructor %qE como un tipo"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "para hacer referencia a un tipo miembro de un parámetro de plantilla, use %<typename %E%>"
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "no coincide el tipo/valor en el argumento %d en la lista de parámetros de plantilla para %qD"
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  se esperaba una constante de tipo %qT, se obtuvo %qT"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qE"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  se esperaba un tipo, se obtuvo %qE"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  se esperaba un tipo, se obtuvo %qT"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  se esperaba una plantilla de tipo %qD, se obtuvo %qT"
@@ -41620,80 +41665,80 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "los tipos no coinciden en el parámetro pack que no es de tipo"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr "no se puede convertir el argumento de plantilla %qE a %qT"
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "el argumento de plantilla %d es inválido"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "provisto por %q+D"
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D no es una plantilla de función"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "se usa el tipo %qT que no es plantilla como una plantilla"
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "para la declaración de plantilla %q+D"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum) substituting %qS"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d (use -ftemplate-depth= para incrementar el máximo) al sustituir %qS"
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%T%>"
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%E%>"
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %D"
@@ -41712,272 +41757,272 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "la variable %qD tiene tipo de función"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipo de parámetro %qT inválido"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "en la declaración %q+D"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "la función devuelve una matriz"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "la función devuelve una función"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "se crea un puntero a función miembro del tipo %qT que no es clase"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "se forma la referencia a void"
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "se forma un puntero para referenciar al tipo %qT"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "se forma una referencia para referenciar al tipo %qT"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "se crea un puntero al miembro de referencia de tipo %qT"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "se crea un puntero al miembro de tipo void"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "se crea la matriz de %qT"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT no es de tipo clase, struct o union"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo enumerado"
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo de clase"
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificador %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "el nombre dependiente %qE se decodifica como un no tipo, pero la instanciación genera un tipo"
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "escriba %<typename %E%> si quiere un tipo"
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "se usa el campo inválido %qD"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "uso inválido de la expresión de expansión de paquete"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "use %<...%> para expandir el paquete de argumentos"
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD no se declaró en este ámbito, y no se encontraron declaraciones en la búsqueda dependiente de argumentos en el punto de la instanciación"
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "no se encontraron declaraciones en la base dependiente %qT pur la búsqueda no calificada"
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "use %<this->%D%> en su lugar"
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "use %<%T::%D%> en su lugar"
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, gcc-internal-format
 msgid "%q+D declared here, later in the translation unit"
 msgstr "%q+D se declaró aquí, después en la unidad de translación"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT no es una clase o un espacio de nombres"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD no es una clase o un espacio de nombres"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr "%qT es/usa un tipo anónimo"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "el argumento de plantilla para %qD usa el tipo local %qT"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT es un tipo modificado variablemente"
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "la expresión integral %qE no es una constante"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  se trata de instanciar %qD"
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciación explícita de %q#D que no es plantilla"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD no es un dato miembro static de una plantilla de clase"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "el tipo %qT para la instanciación explícita %qD no coincide con el tipo declarado %qT"
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciación explícita de %q#D"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciación explícita duplicada de %q#D"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 prohíbe el uso de %<extern%> en instanciaciones explícitas"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "clase de almacenamiento %qD aplicada a la instanciación de una plantilla"
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciación explícita de la plantilla %qD que no es clase"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciación explícita del tipo %qT que no es plantilla"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciación explícita de %q#T antes de la definición de la plantilla"
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ prohíbe el uso de %qE en las instanciaciones explícitas"
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciación explícita duplicada de %q#T"
@@ -41989,63 +42034,63 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciación explícita de %qD pero no hay una definición disponible"
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d al instanciar %q+D, posiblemente de la generación de tabla virtual (use -ftemplate-depth= para incrementar el máximo)"
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "parámetro que no es tipo plantilla inválido"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T no es un tipo válido para un parámetro que no es tipo plantilla"
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "se deducen los tipos inconsistentes %qT y %qT para el tipo de devolución lambda"
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "deducción inconsistente para %qT: %qT y después %qT"
@@ -42285,255 +42330,255 @@
 msgid "invalid base-class specification"
 msgstr "especificación de clase base inválida"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "miembro protegido %q+#D en union anónima"
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD no se capturó"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "uso de la variable %<auto%> desde la función contenedora"
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "uso de parámetro desde la función contenedora"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "no se permite el parámetro de plantilla %qD de tipo %qT en una expresión integral constante porque no es de tipo integral o de enumeración"
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "uso del espacio de nombres %qD como expresión"
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "uso de la plantilla de clase %qT como expresión"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "la petición por el miembro %qD es ambigua en la red de herencia múltiple"
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD no puede aparecer en una expresion constante"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "el tipo de %qE es desconocido"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT no es un tipo de enumeración"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Los paquetes de parámetros __bases sólo son válidos en la declaración de plantilla"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "no se puede aplicar %<offsetof%> al destructor %<~%T%>"
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "%qE tiene tipo inválido para %<reduction%>"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD no es una variable en la cláusula %<firstprivate%>"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD no es una variable en la cláusula %<lastprivate%>"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_teams%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<device%> id must be integral"
 msgstr "el final de la rebanada debe ser entero"
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr "%qE tiene tipo de referencia para %qs"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD no es un fichero, espacio de nombres o variable de ámbito de bloque"
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "la directiva %<threadprivate%> %qE no está en la definición %qT"
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "la diferencia entre %qE y %qD no tiene tipo entero"
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
@@ -42540,22 +42585,22 @@
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "falló la aserción estática: %s"
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "condición que no es constante para una aserción estática"
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "el argumento para decltype debe ser una expresión"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "el tipo de declaración no puede resolver la dirección de la función sobrecargada"
@@ -42571,130 +42616,130 @@
 msgid "lambda-expression in a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clases Java"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr "%qE es obsoleto; las vtables de g++ ahora son compatibles con COM por defecto"
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "la init_priority solicitada no es una constante entera"
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "solo se puede usar el atributo %qE en definiciones de rango de fichero de objetos de tipo class"
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "la init_priority solicitada está fuera de rango"
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "la init_priority solicitada está reservada para uso interno"
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "el atributo %qE no se admite en esta plataforma"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
 msgstr "declaración previa de %q+#D aquí"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "el atributo %qD requiere un solo argumento NTBS"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "el argumento del atributo %qE no es una cadena constante"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "el argumento del atributo %qE no es una cadena constante"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, fuzzy, gcc-internal-format
 #| msgid "%.*s is not a valid universal character"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%.*s no es un carácter universal válido"
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> no es un declarador válido"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "se descarta el atributo %qE en tipos que no son clases"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "el atributo %qE se aplica solamente a funciones, no a %s"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute applied to %s %s at %L"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "El atributo %s se aplica a %s %s en %L"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "cero como constante de puntero nulo"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "revisión lang_*: falló en %s, en %s:%d"
@@ -42888,572 +42933,567 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr "la alineación de los elementos de la matriz es mayor que el tamaño de los elementos"
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr "ISO C++ prohíbe el subíndice de una matriz que no sea l-valuada"
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "se declaró el subíndice de la matriz como %<register%>"
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "el valor indicado por el subíndice no es ni matriz ni puntero"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "falta un objeto en el uso de %qE"
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ prohíbe la llamada %<::main%> dentro del mismo programa"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "se debe usar %<.*%> o %<->*%> en la llamada a la función puntero-a-miembro en %<%E (...)%>, p.e. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "demasiados argumentos para el constructor %q#D"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "faltan argumentos para el constructor %q#D"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "demasiados argumentos para la función miembro %q#D"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "faltan argumentos para la función miembro %q#D"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "demasiados argumentos para la función %q#D"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "faltan argumentos para la función %q#D"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "demasiados argumentos para el método %q#D"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "faltan argumentos para el método %q#D"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "demasiados argumentos para la función"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "faltan argumentos para la función"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "el parámetro %P de %qD tiene el tipo incompleto %qT"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "el parámetro %P tiene el tipo incompleto %qT"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "se asume la conversión al tipo %qT desde la función sobrecargada"
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "se usó NULL en la aritmética"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "la cuenta de rotación izquierda es negativa"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "la cuenta de rotación derecha es negativa"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "la cuenta de rotación izquierda >= anchura del tipo"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "la cuenta de rotación derecha >= anchura del tipo"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr "la comparación con una literal de cadena resulta en una conducta no especificada"
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "la dirección de %qD nunca debe ser NULL"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ prohíbe la comparación entre puntero y entero"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "operand types are %qT and %qT"
 msgstr "no hay un tipo llamado %q#T en %q#T"
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, fuzzy, gcc-internal-format
 #| msgid "could not find interface for class %qE"
 msgid "could not find an integer type of the same size as %qT"
 msgstr "no se puede encontrar la interfaz para la clase %qE"
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "comparación sin orden en el argumento de coma no flotante"
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "operadores inválidos de tipos %qT y %qT para el binario %qO"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero de tipo %<void *%> en la sustracción"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero a una función en la sustracción"
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero a un método en la sustracción"
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "uso inválido de un puntero a un tipo incompleto en aritmética de punteros"
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, gcc-internal-format
 msgid "taking address of constructor %qE"
 msgstr "se toma la dirección del constructor %qE"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, gcc-internal-format
 msgid "taking address of destructor %qE"
 msgstr "se toma la dirección del destructor %qE"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "uso inválido de %qE para formar una función puntero a miembro"
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  se requiere un id calificado"
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "no se pueden usar paréntesis alrededor de %qE para formar una función-puntero-a-miembro"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ prohíbe tomar la dirección de una función miembro no estática sin calificar o entre paréntesis para formar un puntero a la función miembro.  Como %<&%T::%D%>"
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ prohíbe tomar la dirección de una función miembro limitada para formar un puntero a la función miembro.  Como %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "se toma la dirección del temporal"
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "se toma la dirección de xvalue (referencia rvalue)"
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ prohíbe tomar la dirección de la función %<::main%>"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr "ISO C++ prohíbe tomar la dirección de una conversión a una expresión no l-valuada"
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "no se puede crear un puntero al miembro referencia %qD"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ prohíbe incrementar un enum"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ prohíbe decrementar un enum"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "no se puede incrementar un puntero a un tipo incompleto %qT"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "no se puede decrementar un puntero a un tipo incompleto %qT"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ prohíbe incrementar un puntero de tipo %qT"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ prohíbe decrementar un puntero de tipo %qT"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "uso inválido de una expresión Booleana como operando para %<operator--%>"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "no se puede tomar la dirección de %<this%> que es una expresión r-valuada"
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "se solicitó la dirección de la variable register explícita %qD"
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "se solicitó la dirección de %qD, la cual se declaró como %<register%>"
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "el inicializador de lista para el tipo que no es clase no debe estar entre paréntesis"
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "se trata la lista de expresiones como una expresión compuesta en en inicializador"
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "se trata la lista de expresiones como una expresión compuesta en el inicializador de memoria"
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "se trata la lista de expresiones como una expresión compuesta en la conversión funcional"
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "se trata la lista de expresiones como una expresión compuesta %s"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "no hay contexto para resolver el tipo de %qE"
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "la conversión del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, fuzzy, gcc-internal-format
 #| msgid "%qT uses local type %qT"
 msgid "useless cast to type %qT"
 msgstr "%qT usa el tipo local %qT"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "static_cast inválido del tipo %qT al tipo %qT"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "se convierte de %qT a %qT"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "conversión inválida de una expresión r-valuada de tipo %qT al tipo %qT"
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr "la conversión de %qT a %qT pierde precisión"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "la conversión de %qT a %qT incrementa la alineación requerida del tipo del destino"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ prohíbe la conversión entre puntero a función y puntero a objeto"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "conversión inválida del tipo %qT al tipo %qT"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "uso inválido de const_cast con tipo %qT, que no es puntero, referencia, ni un tipo puntero-a-datos-miembro"
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "uso inválido de const_cast con tipo %qT, el cual es un puntero o referencia a un tipo de función"
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "const_cast inválido de un valor-r de tipo %qT al tipo %qT"
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "const_cast inválido del tipo %qT al tipo %qT"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ prohíbe la conversión a un tipo de matriz %qT"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "conversión inválida al tipo de función %qT"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  en la evaluación de %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "se asigna a una matriz desde una lista de inicializador"
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "tipos incompatible en la asignación de %qT a %qT"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "se usó una matriz como inicializador"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "asignación de matriz inválida"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   en la conversión del puntero a función miembro"
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "puntero a la conversión miembro a través de la base virtual %qT"
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   en la conversión del puntero a miembro"
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "conversión inválida del tipo %qT a partir del tipo %qT"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "no se puede convertir %qT a %qT para el argumento %qP para %qD"
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "no se puede convertir %qT a %qT en el argumento por defecto"
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "no se puede convertir %qT a %qT en el paso de argumentos"
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "no se puede convertir %qT a %qT"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "no se puede convertir %qT a %qT en la inicialización"
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "no se puede convertir %qT a %qT en la devolución"
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "no se puede convertir %qT a %qT en la asignación"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "el parámetro %qP de %qD puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "el parámetro puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "el objetivo de conversión puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "el objetivo de inicialización puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la asignación puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "al pasar el argumento %P de %q+D"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "se devuelve la referencia al temporal"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "se devolvió una referencia a un valor que no es l-valor"
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr "se devolvió una referencia a la variable local %q+D"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %q+D returned"
 msgstr "se devolvió la dirección de la variable local %q+D"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr "se devolvió la dirección de la variable local %q+D"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "se devuelve un valor de un destructor"
@@ -43460,46 +43500,46 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "no se puede regresar de un manejador de una función-intenta-bloque de un constructor"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "se devuelve un valor de un constructor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "declaración return sin valores, en una función que devuelve %qT"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 #| msgid "<brace-enclosed initializer list>"
 msgid "returning initializer list"
 msgstr "<lista inicializador dentro de llaves>"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "declaración return con un valor, en una función que devuelve 'void'"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> no debe regresar NULL a menos que se declare %<throw()%> (o -fcheck-new esté en efecto)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "se usa el temporal como l-valor"
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "se usa xvalue (referencia a r-valor) como l-valor"
@@ -43735,125 +43775,125 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr "la conversión estrechadora de %qE desde %qT a %qT dentro de { } está mal formada en C++11"
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "conversión estrechadora de %qE desde %qT a %qT dentro de { }"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "matriz de enteros inicializada con una cadena que no es ancha"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "matriz de enteros inicializada con una cadena ancha incompatible"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "la cadena del inicializador para la matriz de caracteres es demasiado larga"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "no se puede inicializar el agregado del tipo %qT con una literal compuesta"
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "la matriz se debe inicializar con un inicializador dentro de llaves"
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "no existe el campo %qD en la union que se está inicializando"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valor de índice en lugar del nombre del campo en el inicializador de union"
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "se detectó una delegación de puntero circular"
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "el operando base de %<->%> tiene el tipo %qT que no es puntero"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "el resultado de %<operator->()%> produce un resultado que no es puntero"
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "el operando base de %<->%> no es un puntero"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "no se puede usar %qE como un puntero miembro, porque es de tipo %qT"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "no se puede aplicar el puntero a miembro %qE a %qE, el cual es del tipo %qT que no es clase"
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "el tipo de puntero a miembro %qT es incompatible con el tipo objeto %qT"
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "conversión funcional al tipo de matriz %qT"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "inicialización por valor inválida del tipo de referencia"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "llamada a la función %qD la cual arroja el tipo incompleto %q#T"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "llamada a una función la cual arroja el tipo incompleto %q#T"
@@ -44040,8 +44080,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, fuzzy, gcc-internal-format
 #| msgid "Coarrays disabled at %C, use -fcoarray= to enable"
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
@@ -44187,7 +44227,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr "Fortran 2003: Los constructores de matriz incluyen especificación de tipo en %C"
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "La especificación de tipo en %L no puede tener un parámetro de tipo diferido"
@@ -44313,7 +44353,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser INTEGER o PROCEDURE"
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -44991,13 +45031,13 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "El argumento 'source' del intrínseco 'shape' en %L no debe ser una matriz de tamaño asumido"
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L may not be a procedure"
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no puede ser un procedimiento"
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
@@ -45296,6 +45336,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser INTEGER o LOGICAL"
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -45303,7 +45348,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, fuzzy, gcc-internal-format
 #| msgid "Maximum extension level reached with type '%s' at %L"
 msgid "Maximum extension level reached with type %qs at %L"
@@ -45547,81 +45592,81 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "La variable '%s' en %C con un inicializador ya aparecía en una declaración DATA"
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "No se puede inicializar la matriz de tamaño implícito en %L con un escalar"
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "El límite inferior no es constante en la declaración de forma implícita en %L"
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "El componente en %C debe tener el atributo POINTER"
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "El componente de matriz de la estructura en %C debe tener una forma explícita o diferida"
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "El componente de matriz de puntero de la estructura en %C debe tener una forma diferida"
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "El componente allocatable de la estructura en %C debe tener una forma diferida"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "El componente de matriz de la estructura en %C debe tener una forma explícita"
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "La inicialización NULL() en %C es ambigua"
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NULL() initialization at %C is ambiguous"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "La inicialización NULL() en %C es ambigua"
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "No se permite la inicialización de un puntero en %C en un procedimiento PURE"
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Error en la inicialización de puntero en %C"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: non-NULL pointer initialization at %C"
 msgid "non-NULL pointer initialization at %C"
 msgstr "Fortran 2008: inicialización de puntero que no es NULL en %C"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "Function name %qs not allowed at %C"
 msgstr "No se permite el nombre de función '%s' en %C"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, fuzzy, gcc-internal-format
 #| msgid "Non-PARAMETER symbol '%s' at %L can't be implied-shape"
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr "El símbolo '%s' que no es PARAMETER en %L no puede ser de forma implícita"
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: Implied-shape array at %L"
 msgid "Implied-shape array at %L"
@@ -45632,352 +45677,352 @@
 # como `apuntado'. cfuga
 # Referencia: http://gcc.gnu.org/onlinedocs/gfortran/Cray-pointers.html
 #
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Especificación de matriz duplicada para el apuntado Cray en %C"
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Extensión: Inicialización de estilo antiguo en %C"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid value-initialization of reference type"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "inicialización por valor inválida del tipo de referencia"
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "La inicialización en %C no es para una variable puntero"
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "La inicialización de puntero en %C requiere '=>', no '='"
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Se esperaba una expresión de inicialización en %C"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "No se permite la inicialización de una variable en %C en un procedimiento PURE"
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "No se permite la inicialización del componente allocatable en %C"
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "No se admite la declaración de tipo de estilo antiguo %s*%d en %C"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Declaración de tipo %s*%d no estándar en %C"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Falta el paréntesis derecho en %C"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Se esperaba una expresión de inicialización en %C"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Se esperaba una expresión de inicialización escalar en %C"
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "No se admite el género %d para el tipo %s en %C"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "El parámetro de tipo de género C es para el tipo %s, pero el tipo en %L es %s"
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Falta el paréntesis derecho o una coma en %C"
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "No se admite el género %d para CHARACTER en %C"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Error sintáctico en la declaración CHARACTER en %C"
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Extensión: tipo BYTE en %C"
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "El tipo BYTE usado en %C no está disponible en la máquina objetivo"
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "El argumento por valor en %L no se permite en este contexto"
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: TYPE with intrinsic-type-spec at %C"
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "Fortran 2008: TYPE con especificación de tipo intrínseco en %C"
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: DOUBLE COMPLEX at %C"
 msgid "DOUBLE COMPLEX at %C"
 msgstr "Extensión: DOUBLE COMPLEX en %C"
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: CLASS statement at %C"
 msgid "CLASS statement at %C"
 msgstr "Fortran 2003: Declaración CLASS en %C"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "El nombre de tipo '%s' en %C es ambiguo"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "El nombre de tipo '%s' en %C tiene conflictos con la entidad declarada previamente en %L, la cual tiene el mismo nombre"
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Declaración IMPLICIT NONE duplicada en %C"
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Falta el rango de carácter en IMPLICIT en %C"
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Las letras debe estar en orden alfabético en la declaración IMPLICIT en %C"
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "Declaración SAVE en %C después de una declaración SAVE incondicional"
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "La declaración IMPORT en %C sólo se permite en un cuerpo INTERFACE"
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Se espera la lista de entidades nombradas %C"
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot IMPORT '%s' from host scoping unit at %C - does not exist."
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "No se puede IMPORTar '%s' desde la unidad de ámbito del anfitrión en %C - no existe."
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is already IMPORTed from host scoping unit at %C."
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "'%s' ya se IMPORTó desde la unidad de ámbito del anfitrión en %C."
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Error sintáctico en la declaración IMPORT en %C"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Falta la especificación de codimensión en %C"
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Falta la especificación de dimensión en %C"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Atributo %s duplicado en %L"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atributo ALLOCATABLE en %C en una definición TYPE"
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "No se permite el atributo %L en una definición TYPE"
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003: Atributo %s en %L en una definición TYPE"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "No se permite el atributo %s en %L fuera de la parte de especificación de un módulo"
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASYNCHRONOUS attribute at %C"
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Fortran 2003: Atributo ASYNCHRONOUS en %C"
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTIGUOUS attribute at %C"
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Fortran 2008: Atributo CONTIGUOUS en %C"
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "Sólo se permite PROTECTED en %C en la parte de especificación de un módulo"
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED attribute at %C"
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003: Atributo PROTECTED en %C"
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE attribute at %C"
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003: Atributo VALUE en %C"
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE attribute at %C"
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003: Atributo VOLATILE en %C"
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Se proveen múltiples identificadores con un sólo especificador NAME= en %C"
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly declared BIND(C) function '%s' at %L may not be C interoperable"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "La función implícitamente declarada BIND(C) '%s' en %L no puede ser interoperable con C"
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L may not be a C interoperable kind though common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "La variable '%s' en el bloque común '%s' en %L no puede ser un género interoperable con C ya que el bloque común '%s' es BIND(C)"
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, fuzzy, gcc-internal-format
 #| msgid "Type declaration '%s' at %L is not C interoperable but it is BIND(C)"
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "La declaración de tipo '%s' en %L no es interoperable con C pero es BIND(C)"
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L may not be a C interoperable kind but it is bind(c)"
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "La variable '%s' en %L no es de un género interoperable con C pero es BIND(C)"
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L cannot be declared with BIND(C) since it is not a global"
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "La variable '%s' en el bloque común '%s' en %L no se puede declarar con BIND(C) porque no es un global"
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "El tipo de devolución de la función BIND(C) '%s' en %L no puede ser una matriz"
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -45985,296 +46030,296 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is marked PRIVATE but has been given the binding label '%s'"
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "El símbolo '%s' en %L se marcó PRIVATE pero se le dio la etiqueta de asignación '%s'"
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Se necesita una entidad o un nombre de bloque común para la declaración de especificación de atributo en %C"
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Falta la entidad o el nombre de bloque común para la declaración de especificación de atributo en %C"
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "Missing name"
 msgid "Missing symbol"
 msgstr "Falta el nombre"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "El tipo derivado en %C no se definió previamente y no puede aparecer en una definición de tipo derivado"
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Error sintáctico en la declaración de datos en %C"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: IMPURE procedure at %C"
 msgid "IMPURE procedure at %C"
 msgstr "Fortran 2008: Procedimiento IMPURE en %C"
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "No deben aparecer PURE con IMPURE en %C"
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Se esperaba la etiqueta de devolución alterna en %C"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "El nombre '%s' en %C es el nombre del procedimiento"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Basura inesperada en la lista de argumentos formales en %C"
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Símbolo '%s' duplicado en la lista de argumentos formales en %C"
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "La variable RESULT en %C debe ser diferente que el nombre de la función"
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Basura inesperada después de la declaración de la función en %C"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BIND(C) attribute at %L may not be specified for an internal procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008: El atributo BIND(C) en %L no se puede especificar para un procedimiento internal"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "El atributo BIND(C) en %C requiere una interfaz con BIND(C)"
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "El procedimiento BIND(C) con NAME no debe tener atributo POINTER en %C"
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "El procedimiento dummy en %C no puede tener atributo BIND(C) con NAME"
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "El procedimiento '%s' en %L ya tenía el tipo básico de %s"
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Error sintáctico en la declaración PROCEDURE en %C"
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Se esperaba '::' después de los atributos de enlazado en %C"
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Procedure pointer component at %C"
 msgid "Procedure pointer component at %C"
 msgstr "Fortran 2003: Procedimiento de componente puntero en %C"
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Error sintáctico en el procedimiento de componente puntero en %C"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE en %C debe estar en una interfaz genérica"
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: double colon in MODULE PROCEDURE statement at %L"
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Fortran 2008: dos puntos dobles en la declaración MODULE PROCEDURE en %L"
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROCEDURE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003: Declaración PROCEDURE en %C"
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Se esperaba una lista de argumentos formales en la definición de la función en %C"
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "El atributo BIND(C) en %L sólo se puede usar para variables o bloques comunes"
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un PROGRAM"
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un MODULE"
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un BLOCK DATA"
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un INTERFACE"
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque DERIVED TYPE"
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque IF-THEN"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque DO"
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque SELECT"
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque FORALL"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque WHERE"
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un subprograma contenido"
 
-#: fortran/decl.c:5597
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
-msgid "gfc_match_entry(): Bad state"
-msgstr "gfc_trans_code(): Código de declaración erróneo"
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Unexpected END statement at %C"
+msgid "Unexpected ENTRY statement at %C"
+msgstr "Declaración END inesperada en %C"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un procedimiento contenido"
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Faltan los paréntesis requeridos antes de BIND(C) en %C"
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid C name in NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Nombre C inválido en el especificador NAME= en %C"
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Error sintáctico en el especificador NAME= para la etiqueta de asignación %C"
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "El especificador ASYNCHRONOUS= en %L debe ser una expresión de inicialización"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Falta el paréntesis que cierra en la etiqueta de asignación en %C"
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "No se permite un nombre de enlazado en BIND(C) en %C"
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Para el procedimiento dummy %s, no se permite un nombre de enlazado en BIND(C) en %C"
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "No se permite NAME en BIND(C) para ABSTRACT INTERFACE en %C"
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Declaración END inesperada en %C"
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: END statement instead of %s statement at %L"
 msgid "END statement instead of %s statement at %L"
@@ -46281,553 +46326,559 @@
 msgstr "Fortran 2008: Declaración END en lugar de una declaración %s en %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "Se esperaba %s en la declaración en %L"
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Se esperaba la declaración %s en %C"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Se esperaba el nombre de bloque de '%s' en la declaración %s en %C"
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Se esperaba un nombre terminal en %C"
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Se esperaba la etiqueta '%s' para la declaración %s en %C"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Falta la especificación de matriz en %L en la declaración DIMENSION"
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr "Se especificarion dimensiones para %s en %L después de su inicialización"
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Falta la especificación de matriz en %L en la declaración CODIMENSION"
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "La especificación de matriz se debe diferir en %L"
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Carácter inesperado en la lista de variables en %C"
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Se esperaba '(' en %C"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "se esperaba un nombre variable en %C"
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "El puntero Cray en %C debe ser un entero"
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "El puntero Cray en %C tiene %d bytes de precisión; las direcciones de memoria requieren %d bytes"
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Se esperaba \",\" en %C"
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Se esperaba \")\" en %C"
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Se esperaba \",\" o el final de la declaración en %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "No se permite INTENT dentro de BLOCK en %C"
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "No se permite OPTIONAL dentro de BLOCK en %C"
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "La declaración de punteros Cray en %C requiere la opción -fcray-pointer"
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTIGUOUS statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Fortran 2008: Declaración CONTIGUOUS en %C"
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "La especificación de acceso del operador %s en %C ya se había especificado"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "La especificación de acceso del operador .%s. en %C ya se había especificado"
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003: Declaración PROTECTED en %C"
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Error sintáctico en la declaración PROTECTED en %C"
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "Sólo se permite la declaración PRIVATE en %C en la parte de especificación de un módulo"
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "Sólo se permite la declaración PRIVATE en %C en la parte de especificación de un módulo"
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Se esperaba un nombre de variable en %C en la declaración PARAMETER"
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Se esperaba un signo = en la declaración PARAMETER en %C"
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Se esperaba una expresión en %C en la declaración PARAMETER"
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Se inicializa una variable ya inicializada en %C"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Caracteres inesperados en la declaración PARAMETER en %C"
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Declaración SAVE incondicional en %C después de una declaración SAVE previa"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "Declaración SAVE en %C después de una declaración SAVE incondicional"
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Error sintáctico en la declaración SAVE en %C"
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "No se permite VALUE dentro de BLOCK en %C"
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003: Declaración VALUE en %C"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Error sintáctico en la declaración VALUE en %C"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003: Declaración VOLATILE en %C"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, fuzzy, gcc-internal-format
 #| msgid "Specifying VOLATILE for coarray variable '%s' at %C, which is use-/host-associated"
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "Se especifica VOLATILE para la variable de comatriz '%s' en %C, la cual es asociada a uso/anfitrión"
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Error sintáctico en la declaración VOLATILE en %C"
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASYNCHRONOUS statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Fortran 2003: Declaración ASYNCHRONOUS en %C"
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Error sintáctico en la declaración ASYNCHRONOUS en %C"
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE en %C debe estar en una interfaz genérica de módulo"
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "El procedimiento intrínseco en %L no puede ser un MODULE PROCEDURE"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Símbolo ambiguo en la definición TYPE en %C"
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "El símbolo '%s' en %C ya se había asociado con el anfitrión"
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in EXTENDS expression at %C is not a derived type"
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "'%s' en la expresión EXTENDS en %C no es un tipo derivado"
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is BIND(C)"
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "'%s' no se puede extender en %C porque es BIND(C)"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is a SEQUENCE type"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "'%s' no se puede extender en %C porque es un tipo SEQUENCE"
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "El tipo derivado en %C sólo puede ser PRIVATE en la parte de especificación de un módulo"
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "El tipo derivado en %C sólo puede ser PUBLIC en la parte de especificación de un módulo"
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ABSTRACT type '%s' used at %L"
 msgid "ABSTRACT type at %C"
 msgstr "El tipo ABSTRACT '%s' se usa en %L"
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Se esperaba :: en la definición TYPE en %C"
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "El nombre de tipo '%s' en %C no puede ser el mismo que un tipo intrínseco"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "El nombre de tipo derivado '%s' en %C ya tiene un tipo básico de %s"
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "La definición del tipo derivado de '%s' en %C ya se había definido"
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "El Apuntado Cray en %C no puede ser una matriz de forma asumida"
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ENUM and ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003: ENUM y ENUMERATOR en %C"
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "El enumerador excede el tipo entero de C en %C"
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L no se inicializó con una expresión entera"
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Se esperaba una declaración de definición ENUM antes de %C"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Error sintáctico en la definición ENUMERATOR en %C"
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Especificador de acceso duplicado en %C"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Los atributos de enlace ya especifican paso, NOPASS ilegal en %C"
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Los atributos de enlace ya especifican paso, PASS ilegal en %C"
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Atributo POINTER duplicado en %C"
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "NON_OVERRIDABLE duplicado en %C"
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "DEFERRED duplicado en %C"
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Se esperaba un especificador de acceso en %C"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Se esperaba un atributo de enlace en %C"
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "No pueden aparecer NON_OVERRIDABLE y DEFERRED al mismo tiempo en %C"
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "Se requiere el atributo POINTER para el procedimiento de componente puntero en %C"
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, fuzzy, gcc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Se esperaba un nombre de interfaz después de '(' en %C"
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected at %C"
 msgid "%<)%> expected at %C"
 msgstr "Se esperaba ')' en %C"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Se debe especificar una interfaz para el enlace DEFERRED en %C"
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) en %C se debe declarar DEFERRED"
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Se esperaba un nombre de enlace en %C"
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: PROCEDURE list at %C"
 msgid "PROCEDURE list at %C"
 msgstr "Fortran 2008: Lista PROCEDURE en %C"
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format
 #| msgid "'=> target' is invalid for DEFERRED binding at %C"
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "'=> objetivo' es inválido para el enlace DEFERRED en %C"
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, fuzzy, gcc-internal-format
 #| msgid "'::' needed in PROCEDURE binding with explicit target at %C"
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "Se necesita '::' en el enlace PROCEDURE con objetivo explícito en %C"
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Se esperaba un objetivo de enlace después de '=>' en %C"
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' containing DEFERRED binding at %C is not ABSTRACT"
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "El tipo '%s' que contiene el enlace DEFERRED en %C no es ABSTRACT"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, fuzzy, gcc-internal-format
 #| msgid "There is already a procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Ya existe un procedimiento con nombre de enlazado '%s' para el tipo derivado '%s' en %C"
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC en %C debe estar dentro de un tipo derivado CONTAINS"
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Se esperaba '::' en %C"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Se esperaba un nombre genérico o un descriptor de operador en %C"
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Invalid form of PROGRAM statement at %C"
+msgid "Malformed GENERIC statement at %C"
+msgstr "Forma inválida de la declaración PROGRAM en %C"
+
+#: fortran/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '=>' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Se esperaba '=>' en %C"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a non-generic procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Ya existe un procedimiento que no es genérico con el nombre de enlace '%s' para el tipo derivado '%s' en %C"
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, fuzzy, gcc-internal-format
 #| msgid "Binding at %C must have the same access as already defined binding '%s'"
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "El enlace en %C debe tener el mismo acceso que el enlace '%s' que ya está definido"
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Se esperaba un nombre de enlace específico en %C"
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' already defined as specific binding for the generic '%s' at %C"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "Ya se definió '%s' como un enlace específico para el genérico '%s' en %C"
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Basura después del enlace GENERIC en %C"
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "La declaración FINAL en %C debe estar dentro de una sección de tipo derivado CONTAINS"
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "La declaración de tipo derivado con FINAL en %C debe estar en la parte de especificación de un MODULE"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "FINAL vacío en %C"
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Se esperaba un nombre de procedimiento de módulo en %C"
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Se esperaba \",\" en %C"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "Nombre de procedimiento \"%s\" desconocido en %C"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is already defined as FINAL procedure!"
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "¡'%s' en %C ya se había definido como un procedimiento FINAL!"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Atributo desconocido en la declaración !GCC$ ATTRIBUTES en %C"
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Error sintáctico en la declaración !GCC$ ATTRIBUTES en %C"
@@ -47133,377 +47184,377 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "Forma diferente para %s en %L en la dimensión %d (%d y %d)"
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a VALUE"
 msgid "%qs at %L is not a VALUE"
 msgstr "'%s' en %L no es un VALUE"
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Rangos %d y %d incompatibles en la asignación en %L"
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "El tipo de la variable es UNKNOWN en la asignación en %L"
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "NULL aparece en el lado derecho de una asignación en %L"
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "POINTER valued function appears on right-hand side of assignment at %L"
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "Una función valuada como POINTER aparece en el lado derecho de la asignación en %L"
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: BOZ literal at %L used to initialize non-integer variable '%s'"
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "Extensión: se usa la literal BOZ en %L para inicializar la variable '%s' que no es entera"
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "Extensión: la literal BOZ en %L está fuera de una declaración DATA y fuera de INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, fuzzy, gcc-internal-format
 #| msgid "BOZ literal at %L is bitwise transferred non-integer symbol '%s'"
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "La literal BOZ en %L se transfiere por bits al símbolo '%s' que no es entero"
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Desborde aritmético por debajo del BOZ transferido por bits en %L. Esta revisión se puede desactivar con la opción -fno-range-check"
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Desborde aritmético del BOZ transferido por bits en %L. Esta revisión se puede desactivar con la opción -fno-range-check"
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "NaN aritmético del BOZ transferido por bits en %L. Esta revisión se puede desactivar con la opción -fno-range-check"
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from  %s to %s at %L"
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "Cambio de valor en la conversión de %s a %s en %L"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 #| msgid "Possible change of value in conversion from %s to %s at %L"
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "Posible cambio de valor en la conversión de %s a %s en %L"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Conversion from %qs to %qs at %L"
 msgstr "Conversión de %s a %s en %L"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Tipos incompatible en la declaración DATA en %L; se intentó la conversión de %s a %s"
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "El objetivo de asignación de puntero no es un POINTER en %L"
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "'%s' en la asignación de puntero en %L no puede ser un l-valor ya que es un procedimiento"
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "Expected bounds specification for '%s' at %L"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Se esperaba una especificación de límites para '%s' en %L"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Bounds specification for '%s' in pointer assignment at %L"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Fortran 2003: Especificación de límites para '%s' en una asignación de puntero en %L"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr "El límite inferior debe estar presente en %L"
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "El tranco no debe ser estar presente en %L"
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr "Se deben especificar todos o ninguno de los límites superiores en %L"
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "El objeto puntero en %L no debe tener un coíndice"
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Asignación de puntero de procedimiento inválida en %L"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "La función de declaración '%s' es inválida en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "La interfaz abstracta '%s' es inválida en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "La función de declaración '%s' es inválida en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "El procedimiento interno '%s' es inválido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "El procedimiento interno '%s' es inválido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, fuzzy, gcc-internal-format
 #| msgid "Nonintrinsic elemental procedure '%s' is invalid in procedure pointer assigment at %L"
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "El procedimiento elemental que no es intrínseco '%s' es inválido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "No hay coincidencia en la asignación de puntero a procedimiento en %L: no hay coincidencia en la convención a llamada"
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, fuzzy, gcc-internal-format
 #| msgid "NOPASS or explicit interface required at %C"
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "No coincide la interfaz en la asignación de puntero a procedimiento en %L: %s"
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Tipos diferentes en la asignación de puntero en %L; se intentó la asignación de %s a %s"
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Parámetros de tipo de género diferentes en la asignación de puntero en %L"
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Rangos diferentes en la asignación de puntero en %L"
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "El objetivo de remapeo de rango es menor que el tamaño del puntero (%ld < %ld) en %L"
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "El objetivo de remapeo de rango de debe ser de rango 1 o simplemente contiguo en %L"
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: Rank remapping target is not rank 1 at %L"
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Fortran 2008: El objetivo de remapeo de rango no es rango 1 en %L"
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero"
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "El objetivo de asignación de puntero no es TARGET ni POINTER en %L"
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Objetivo erróneo en la asignación de puntero en el procedimiento PURE en %L"
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Asignación de puntero con subíndice vectorial del lado derecho en %L"
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "El objetivo de asignación de puntero tiene atributo PROTECTED en %L"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "El objetivo de datos en %L no puede tener un coíndice"
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero"
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization target at %L must not be ALLOCATABLE "
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "El objetivo de inicialización de puntero en %L no debe ser ALLOCATABLE"
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization target at %C must have the TARGET attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "El objetivo de inicialización de puntero en %C debe tener el atributo TARGET"
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "El objetivo de inicialización de puntero en %L debe tener el atributo SAVE"
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "El objetivo de inicialización de puntero a procedimiento en %L tal vez no es un puntero a procedimiento"
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Funciones puntero en un contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Expresión que no es variable en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' in variable definition context (%s) at %L"
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Constante nombrada '%s' en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in variable definition context (%s) at %L is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "'%s' en el contexto de definición variable (%s) en %L no es una variable"
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Uno que no es POINTER en el contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in pointer association context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Argumento dummy '%s' con INTENT(IN) en el contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in variable definition context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Argumento dummy '%s' con INTENT(IN) en el contexto de definición de variable (%s) en %L"
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "La variable '%s' es PROTECTED y no puede aparecer en un contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "La variable '%s' es PROTECTED y no puede aparecer en un contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "La variable '%s' no puede aparecer en un contexto de definición variable (%s) en %L en el procedimiento PURE"
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "No se puede usar '%s' en %L asociado al objetivo con índice vectorial en un contexto de definición variable (%s)"
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "No se puede usar '%s' en %L asociado a una expresión en un contexto de definición variable (%s)"
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "El nombre asociado '%s' no puede aparecer en un contexto de definición variable (%s) en %L porque su obtetivo en %L tampoco puede aparecer"
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "No se puede usar '%s' en %L asociado a una expresión en un contexto de definición variable (%s)"
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "no se puede abrir el fichero de entrada: %s"
@@ -47526,31 +47577,31 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Se elimina la llamada a la función '%s' en %L"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "illegal OP in optimize_comparison"
 msgstr "operandos inválidos en la comparación gimple"
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
@@ -47609,678 +47660,684 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr "Se esperaba 'END INTERFACE ASSIGNMENT (=)' en %C"
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, fuzzy, gcc-internal-format
+#| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr "Se esperaba 'END INTERFACE OPERATOR (.%s.)' en %C"
+
+#: fortran/interface.c:353
+#, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (%s)' at %C, but got %s"
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr "Se esperaba 'END INTERFACE OPERATOR (%s)' en %C, pero se obtuvo %s"
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr "Se esperaba 'END INTERFACE OPERATOR (.%s.)' en %C"
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE %s' at %C"
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr "Se esperaba 'END INTERFACE %s' en %C"
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr "No puede aparecer una devolución alternativa en la interfaz de operador en %L"
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr "La interfaz de operador de asignación en %L debe tener dos argumentos"
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr "La interfaz de operador en %L tiene el número erróneo de argumentos"
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr "La interfaz de operador de asignación en %L debe ser SUBROUTINE"
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr "La interfaz de operador de asignación en %L no debe redefinir una asignación de tipo INTRINSIC"
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr "La interfaz de operador intrínseco en %L debe ser FUNCTION"
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr "El primer argumento de la asignación definida en %L debe ser INTENT(OUT) o INTENT(INOUT)"
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la asignación definida en %L debe ser INTENT(IN)"
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "El primer argumento de la interfaz de operador en %L debe ser INTENT(IN)"
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la interfaz de operador en %L debe ser INTENT(IN)"
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr "La interfaz de operador en %L genera un conflicto con la interfaz intrínseca"
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr "El procedimiento '%s' en %s en %L no tiene una interfaz explícita"
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr "El procedimiento '%s' en %s en %L no es ni función ni subrutina"
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr "En %s en %L los procedimientos deben ser o todos SUBROUTINE o todos FUNCTION"
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr "En %s en %L los procedimientos deben ser puras FUNCTIONs ya que el nombre genérico es también el nombre de un tipo derivado"
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Internal procedure '%s' in %s at %L"
 msgid "Internal procedure %qs in %s at %L"
 msgstr "Fortran 2008: Procedimiento interno '%s' en %s en %L"
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, fuzzy, gcc-internal-format
 #| msgid "Ambiguous interfaces '%s' and '%s' in %s at %L"
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr "Las interfaces '%s' y '%s' son ambiguas en %s en %L"
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, fuzzy, gcc-internal-format
 #| msgid "Although not referenced, '%s' has ambiguous interfaces at %L"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "Aunque no esté referenciado, '%s' tiene interfaces ambiguas en %L"
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a module procedure"
 msgid "%qs at %L is not a module procedure"
 msgstr "'%s' en %L no es un procedimiento de módulo"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (scalar and rank-%d)"
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "No coincide el rango en el argumento '%s' en %L (escalar y rango %d)"
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (rank-%d and scalar)"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "No coincide el rango en el argumento '%s' en %L (rango %d y escalar)"
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (rank-%d and rank-%d)"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "No coincide el rango en el argumento '%s' en %L (rango %d y rango %d)"
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Argumento de procedimiento inválido en %L"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in dummy procedure '%s' at %L: %s"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento dummy '%s' en %L: %s"
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to contiguous pointer dummy '%s' at %L must be simply contigous"
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "El argumento actual para el puntero dummy contiguo '%s' en %L debe ser simplemente contiguo"
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, fuzzy, gcc-internal-format
 #| msgid "Type mismatch in argument '%s' at %L; passed %s to %s"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "No coincide el tipo en el argumento '%s' en %L; se pasa %s a %s"
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "El argumento actual de forma asumida en %L es incompatible con el argumento dummy de forma no asumida '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be polymorphic"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "El argumento actual para '%s' en %L debe ser polimórfico"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must have the same declared type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "El argumento actual para '%s' en %L debe tener el mismo tipo declarado"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, fuzzy, gcc-internal-format
 #| msgid "Corank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "No coincide el corango en el argumento '%s' en %L (%d y %d)"
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be simply contiguous"
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "El argumento actual para '%s' en %L debe ser simplemente contiguo"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to non-INTENT(INOUT) dummy '%s' at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Argumento actual para el dummy que no es INTENT(OUT) '%s' en %L, el cual es LOCK_TYPE o tiene un componente LOCK_TYPE"
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' has to be a pointer or assumed-shape array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "El argumento dummy '%s' tiene que ser un puntero o una matriz de tamaño asumida sin atributo CONTIGUOUS - porque el argumento actual en %L no es simplemente contiguo y ambos son ASYNCHRONOUS o VOLATILE"
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, fuzzy, gcc-internal-format
 #| msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument '%s'"
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Se pasa una comatriz en %L al argumento dummy INTENT(OUT) '%s', que no es comatriz, alojable"
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, fuzzy, gcc-internal-format
 #| msgid "Passing coarray at %L to allocatable, noncoarray dummy argument '%s', which is invalid if the allocation status is modified"
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Se pasa una comatriz en %L al argumento dummy '%s' que no es comatriz, el cual es inválido si se modifica el estado de alojamiento"
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, fuzzy, gcc-internal-format
 #| msgid "Polymorphic scalar passed to array dummy argument '%s' at %L"
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Se pasó un escalar polimórfico al argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument '%s' at %L"
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr "Se pasó un elemento de forma asumida o puntero a matriz al argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Extensión: Argumento actual CHARACTER de género diferente a C_CHAR, sin género por defecto escalar con argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Argumento actual CHARACTER escalar con argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "El argumento de palabra clave '%s' en %L no está en el procedimiento"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "El argumento de palabra clave '%s' en %L ya está asociado con otro argumento actual"
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Más argumentos actuales que formales en la llamada a procedimento en %L"
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Falta la especificación de devolución alternativa en la llamada a subrutina en %L"
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr "Especificación de devolución alternativa inesperada en la llamada a subrutina en %L"
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Intrínseco NULL inesperado en %L para el dummy '%s'"
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Null pointer at %L to non-pointer dummy '%s'"
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Puntero nulo en %L a un dummy '%s' que no es puntero"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "No coincide la longitud de carácter (%ld/%ld) entre el argumento actual y el argumento dummy puntero o alojable '%s' en %L"
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "No coincide la longitud de carácter (%ld/%ld) entre el argumento actual y el argumento dummy de forma asumida '%s' en %L"
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument at %L to allocatable or pointer dummy argument '%s' must have a deferred length type parameter if and only if the dummy has one"
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "El argumento actual en %L para el argumento alojable o dummy puntero '%s' debe tener un parámetro de tipo de longitud diferido si y sólo si el dummy tiene uno"
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of actual argument shorter than of dummy argument '%s' (%lu/%lu) at %L"
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "La longitud del carácter del argumento actual es más corta que la del argumento dummy '%s' (%lu/%lu) en %L"
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "El argumento actual contiene muy pocos elementos para el argumento dummy '%s' (%lu/%lu) en %L"
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure pointer for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Se esperaba un puntero procedimiento para el argumento '%s' en %L"
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Falta un procedimiento para el argumento '%s' en %L"
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "El argumento actual para '%s' no puede ser una matriz de tamaño asumido en %L"
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "El argumento actual para '%s' debe ser un puntero en %L"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy '%s'"
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: El argumento actual que no es puntero en %L para el puntero dummy '%s'"
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L to pointer dummy '%s'"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Argumento actual coindizado en %L para el puntero dummy '%s'"
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L to allocatable dummy '%s' requires INTENT(IN)"
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "El argumento actual coindizado en %L para el dummy alojable '%s' requiere INTENT(IN)"
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy '%s' has neither ASYNCHRONOUS nor VOLATILE"
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "El argumento actual coindizado ASYNCHRONOUS o VOLATILE en %L requiere que el dummy '%s' no tenga ASYNCHRONOUS ni VOLATILE"
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy '%s' requires either VALUE or INTENT(IN)"
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "El argumento actual coindizado en %L con componente último alojable para el dummy '%s' requiere uno de VALUE o INTENT(IN)"
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, fuzzy, gcc-internal-format
 #| msgid "Actual CLASS array argument for '%s' must be a full array at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "El argumento de la matriz CLASS actual para '%s' debe ser una matriz completa en %L"
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "El argumento actual para '%s' debe ser ALLOCATABLE en %L"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument '%s'"
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "El argumento actual de sección de matriz con subíndices vectoriales en %L es incompatible con el atributo INTENT(OUT), INTENT(INOUT), VOLATILE o ASYNCHRONOUS del argumento dummy '%s'"
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "El argumento actual de forma asumida en %L es incompatible con el argumento dummy de forma no asumida '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "El argumento actual de sección de matriz en %L es incompatible con el argumento dummy de forma no asumida '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument '%s' due to VOLATILE attribute"
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "El argumento actual de matriz de puntero en %L requiere un argumento dummy de forma asumida o matriz de puntero '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Falta el argumento actual para el argumento '%s' en %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "El mismo argumento actual está asociado con el argumento INTENT(%s) '%s' y el argumento INTENT(%s) '%s' en %L"
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "El argumento del procedimiento en %L es local a un procedimiento PURE y tiene el atributo POINTER"
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "El argumento coindizado en %L en un procedimiento PURE se pasa a un argumento INTENT(%s)"
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "El argumento actual coindizado en %L es un procedimiento PURE se pasa a un argumento dummy POINTER"
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument '%s'"
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "El argumento actual polimórfico coindizado en %L se pasa al argumento dummy polimórfico '%s'"
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called at %L is not explicitly declared"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "El procedimiento '%s' que se llama en %L no tiene una interfaz explícita"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Se llamó al procedimiento '%s' con una interfaz implícita en %L"
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer object '%s' at %L must have an explicit function interface or be declared as array"
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "El objeto puntero '%s' en %L debe tener una interfaz de función explícita o declrararse como matriz"
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "The allocatable object '%s' at %L must have an explicit function interface or be declared as array"
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "El objeto allocatable '%s' en %L debe tener una interfaz de función explícita o declararse como matriz"
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable function '%s' at %L must have an explicit function interface"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "La función allocatable '%s' en %L debe tener una interfaz de función explícita"
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "El argumento de palabra clave requiere una interfaz explícita para el procedimiento '%s' en %L"
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "El símbolo '%s' en %L ya tenía una interfaz explícita"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure '%s'"
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "El argumento actual de LOCK_TYPE o con componente LOCK_TYPE en %L requiere una interfaz explícita para el procedimiento '%s'"
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "se requiere el argumento MOLD para NULL en %L"
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "El argumento de palabra clave requiere una interfaz explícita para el procedimiento '%s' en %L"
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Se llamó al procedimiento de componente puntero '%s' con una interfaz implícita en %L"
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure pointer component '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "El argumento de palabra clave requiere una interfaz explícita para el procedimiento de componente puntero '%s' en %L"
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "Se require MOLD= en un argumento NULL en %L: Ambigüedad entre las funciones específicas %s y %s "
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qE"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D es un alias del símbolo sin definir %qE"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "La entidad '%s' en %C ya está presente en la interfaz"
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - too many interface type"
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "error interno - demasiados tipos de interfaz"
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC '%s' at %L"
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr "No se puede sobreescribir el GENERIC '%s' en %L"
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "'%s' en %L sobreescribe un enlace de procedimiento declarad como NON_OVERRIDABLE"
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "'%s' en %L no debe ser DEFERRED porque sobreescribe un enlazado que no es DEFERRED"
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PURE procedure and must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "'%s' en %L sobreescribe un procedimiento PURE y también debe ser PURE"
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "'%s' en %L sobreescribe un procedimiento ELEMENTAL y también debe ser ELEMENTAL"
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "'%s' en %L sobreeescribe un procedimiento que no es ELEMENTAL y tampoco debe ser ELEMENTAL"
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "'%s' en %L sobreescribe una SUBROUTINE y también debe ser una SUBROUTINE"
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a FUNCTION and must also be a FUNCTION"
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "'%s' en %L sobreescribe una FUNCTION y también debe ser una FUNCTION"
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, fuzzy, gcc-internal-format
 #| msgid "Argument mismatch for the overriding procedure '%s' at %L: %s"
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento '%s' que sobreescribe en %L: %s"
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "'%s' en %L sobreescribe un procedimiento PUBLIC y no debe ser PRIVATE"
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' of '%s' at %L should be named '%s' as to match the corresponding argument of the overridden procedure"
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "El argumento dummy '%s' de '%s' en %L se debe llamar '%s' para que coincida con el argumento correspondiente al procedimiento sobreescrito"
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, fuzzy, gcc-internal-format
 #| msgid "Argument mismatch for the overriding procedure '%s' at %L: %s"
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento '%s' que sobreescribe en %L: %s"
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have the same number of formal arguments as the overridden procedure"
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "'%s' en %L debe tener el mismo nombre de argumentos formales que el procedimiento sobreeescrito"
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a NOPASS binding and must also be NOPASS"
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "'%s' en %L sobreescribe un enlace NOPASS y también debe ser NOPASS"
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a binding with PASS and must also be PASS"
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "'%s' en %L sobreescribe un enlace con PASS y también debe ser PASS"
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
@@ -48733,13 +48790,13 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite ASYNCHRONOUS= en %C en Fortran 95"
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: BLANK= at %C not allowed in Fortran 95"
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite BLANK= en %C en Fortran 95"
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DECIMAL= at %C not allowed in Fortran 95"
 msgid "DECIMAL= at %C not allowed in Fortran 95"
@@ -48751,7 +48808,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite ENCODING= en %C en Fortran 95"
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ROUND= at %C not allowed in Fortran 95"
 msgid "ROUND= at %C not allowed in Fortran 95"
@@ -48778,828 +48835,828 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "El número UNIT en la declaración CLOSE en %L debe ser no negativo"
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "No se permite una declaración %s en el procedimiento PURE en %C"
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "El número UNIT en la declaración en %L debe ser no negativo"
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: FLUSH statement at %C"
 msgid "FLUSH statement at %C"
 msgstr "Fortran 2003: Declaración FLUSH en %C"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "Especificación UNIT duplicada en %C"
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Especificación de formato duplicada en %C"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "El símbolo '%s' en la lista de nombres '%s' es INTENT(IN) en %C"
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Especificación NML duplicada en %C"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C must be a NAMELIST group name"
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "El símbolo '%s' en %C debe ser un nombre de grupo NAMELIST"
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "No se permite la etiqueta END en %C en la declaración de salida"
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "No se especificó UNIT en %L"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "La especificación UNIT en %L debe ser una expresión INTEGER o una variable CHARACTER"
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "Forma inválida de la declaración WRITE en %L, se requiere UNIT"
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "Unidad interna con subíndice vectorial en %L"
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "Un IO UNIT externo no puede ser una matriz en %L"
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST '%s' in READ statement at %L contains the symbol '%s' which may not appear in a variable definition context"
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr "NAMELIST '%s' en la declaración READ en %L contiene el símbolo '%s' el cual puede no aparecer en un contexto de definición de variable"
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Comma before i/o item list at %L"
 msgid "Comma before i/o item list at %L"
 msgstr "Extensión: Una coma antes de una lista de elementos de e/s en %L"
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "La etiqueta ERR %d en %L no está definida"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "La etiqueta END %d en %L no está definida"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "La etiqueta EOR %d en %L no está definida"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "La etiqueta FORMAT %d en %L no está definida"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Error sintáctico en el iterador de E/S en %C"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Se esperaba una variable en la declaración READ en %C"
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Se esperaba una expresión en la declaración %s en %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Error sintáctico en la declaración %s en %C"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Internal file at %L with namelist"
 msgid "Internal file at %L with namelist"
 msgstr "Fortran 2003: Fichero interno en %L con lista de nombres"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "El especificador ASYNCHRONOUS= en %L debe ser una expresión de inicialización"
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PAD= at %C not allowed in Fortran 95"
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: No se permite PAD= en %C en Fortran 95"
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DELIM= at %C not allowed in Fortran 95"
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite DELIM= en %C en Fortran 95"
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "La lista de nombres PRINT en %C es una extensión"
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Se esperaba una coma en la lista E/S en %C"
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "No se permite la declaración PRINT en %C dentro un procedimiento PURE"
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "No se permite la declaración INQUIRE en el procedimiento PURE en %C"
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "La etiqueta IOLENGHT es inválida en la declaración INQUIRE en %C"
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "La declaración INQUIRE en %L no puede contener especificadores FILE y UNIT al mismo tiempo"
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "La declaración INQUIRE en %L requiere un especificador FILE o UNIT"
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT number in statement at %L must be non-negative"
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr "El número UNIT en la declaración en %L debe ser no negativo"
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "La declaración INQUIRE en %L requiere un especificador PENDING= con el especificador ID="
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: WAIT at %C not allowed in Fortran 95"
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: No se permite WAIT en %C en Fortran 95"
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "No se permite una declaración WAIT en un procedimiento PURE en %C"
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_op2string(): Bad code"
 msgstr "gfc_trans_code(): Código de declaración erróneo"
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 #| msgid "Missing ')' in statement at or before %L"
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "Falta un ')' en la declaración en o antes de %L"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 #| msgid "Missing '(' in statement at or before %L"
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "Falta un '(' en la declaración en o antes de %L"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr "Entero demasiado grande en %C"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "Demasiados dígitos en la declaración de etiqueta en %C"
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr "La etiqueta de declaración en %C es cero"
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 #| msgid "Label name '%s' at %C is ambiguous"
 msgid "Label name %qs at %C is ambiguous"
 msgstr "El nombre de etiqueta '%s' en %C es ambigua"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Duplicate construct label %qs at %C"
 msgstr "Etiqueta construct '%s' duplicada en %C"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr "Carácter inválido en el nombre en %C"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr "El nombre en %C es demasiado largo"
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid character '$' at %C. Use -fdollar-ok to allow it as an extension"
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr "Carácter '$' inválido en %C. Use -fdollar-ok para permitirlo como una extensión"
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr "La variable de bucle en %C no puede ser una comatriz"
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr "La variable de bucle en %C no puede ser un subcomponente"
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr "Se esperaba un valor de paso en el iterador en %C"
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr "Error sintáctico en el iterador en %C"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_match(): Bad match code %c"
 msgstr "gfc_trans_code(): Código de declaración erróneo"
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr "Forma inválida de la declaración PROGRAM en %C"
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolescent feature: Arithmetic IF statement at %C"
 msgid "Arithmetic IF statement at %C"
 msgstr "Característica obsoleta: Declaración IF aritmética en %C"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr "Error sintáctico en la expresión IF en %C"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr "La etiqueta de bloque no es apropiada para la declaración IF aritmética en %C"
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr "La etiqueta de bloque no es apropiada para la declaración IF en %C"
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr "No se puede asignar a una constante nombrada en %C"
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr "Declaración inclasificable en la cláusula IF en %C"
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr "Error sintáctico en la cláusula IF en %C"
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr "Basura inesperada después de la declaración ELSE en %C"
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match IF label '%s'"
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "La etiqueta '%s' en %C no coincide con la etiqueta IF '%s'"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr "Basura inesperada después de la declaración ELSE IF en %C"
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr "Declaración de control de imagen CRITICAL en %C en un procedimiento PURE"
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr "Declaración de control de imagen CRITICAL en %C en un bloque DO CONCURRENT"
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CRITICAL statement at %C"
 msgid "CRITICAL statement at %C"
 msgstr "Fortran 2008: Declaración CRITICAL en %C"
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr "Bloque CRITICAL anidado en %C"
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr "Se esperaba una lista lista de asociación en %C"
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr "Se esperaba una asociación en %C"
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate name '%s' in association at %C"
 msgid "Duplicate name %qs in association at %C"
 msgstr "Nombre '%s' duplicado en la asociación en %C"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, fuzzy, gcc-internal-format
 #| msgid "Expected ')' or ',' at %C"
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "Se esperaba ')' o ',' en %C"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr "Basura después de la declaración ASSOCIATE en %C"
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L may not be ABSTRACT"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "El tipo derivado '%s' en %L no debe ser ABSTRACT"
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "Especificación de tipo inválida en %C"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "Error sintáctico en el iterador FORALL en %C"
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: DO CONCURRENT construct at %C"
 msgid "DO CONCURRENT construct at %C"
 msgstr "Fortran 2008: Constructor DO CONCURRENT en %C"
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is unknown"
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "Se desconoce el nombre '%s' en la declaración %s en %C"
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a construct name"
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "El nombre '%s' en la declaración %s en %C no es un nombre de constructor"
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "La declaración %s en %C deja una construcción CRITICAL"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "La declaración %s en %C deja una construcción DO CONCURRENT"
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "La declaración %s en %C no está dentro de una construcción"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within construct '%s'"
 msgid "%s statement at %C is not within construct %qs"
 msgstr "La declaración %s en %C no está dentro de la construcción '%s'"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, fuzzy, gcc-internal-format
 #| msgid "CYCLE statement at %C is not applicable to non-loop construct '%s'"
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "La declaración CYCLE en %C no se aplica a la construcción '%s' que no es bucle"
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: EXIT statement with no do-construct-name at %C"
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "Fortran 2008: Declaración EXIT sin nombre de constructor do en %C"
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not applicable to construct '%s'"
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "La declaración %s en %C no se aplica a la construcción '%s'"
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "La declaración %s en %C deja un bloque estructurado OpenMP"
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "La declaración EXIT en %C termina el bucle !$OMP DO"
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "La declaración CYCLE en %C para el bucle !$OMP DO colapsado que no es el más interno"
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "La declaración EXIT en %C termina el bucle !$OMP DO"
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "La declaración CYCLE en %C para el bucle !$OMP DO colapsado que no es el más interno"
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Image control statement %s at %C in PURE procedure"
 msgid "%s statement at %C in PURE procedure"
 msgstr "Declaración de control de imagen %s en %C en un procedimiento PURE"
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr "Declaración de control de imagen STOP en %C en el bloque CRITICAL"
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "Declaración de control de imagen STOP en %C en el bloque DO CONCURRENT"
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "El código STOP en %L debe ser de tipo INTEGER o CHARACTER"
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "El código STOP en %L debe ser escalar"
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr "El código STOP en %L debe ser un carácter por defecto KIND=%d"
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "El código STOP en %L debe ser un entero por defecto KIND=%d"
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "PAUSE statement at %C"
 msgstr "Declaración CASE inesperada en %C"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: ERROR STOP statement at %C"
 msgid "ERROR STOP statement at %C"
 msgstr "Fortran 2008: Declaración ERROR STOP en %C"
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "Declaración de control de imagen %s en %C en un procedimiento PURE"
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "Declaración de control de imagen %s en %C en el bloque CRITICAL"
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "Declaración de control de imagen %s en %C en el bloque DO CONCURRENT"
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr "Se encontró una etiqueta STAT redundante en %L "
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr "Se encontró una etiqueta ERRMSG redundante en %L "
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr "Se encontró una etiqueta ACQUIRED_LOCK redundante en %L "
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: LOCK statement at %C"
 msgid "LOCK statement at %C"
 msgstr "Fortran 2008: Declaración LOCK en %C"
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: UNLOCK statement at %C"
 msgid "UNLOCK statement at %C"
 msgstr "Fortran 2008: Declaración UNLOCK en %C"
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "Declaración de control de imagen SYNC en %C en un procedimiento PURE"
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: SYNC statement at %C"
 msgid "SYNC statement at %C"
 msgstr "Fortran 2008: Declaración SYNC en %C"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr "Declaración de control de imagen SYNC en %C en un bloque CRITICAL"
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "Declaración de control de imagen SYNC en %C en un bloque DO CONCURRENT"
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: ASSIGN statement at %C"
 msgid "ASSIGN statement at %C"
 msgstr "Característica eliminada: declaración ASSIGN en %C"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: Assigned GOTO statement at %C"
 msgid "Assigned GOTO statement at %C"
 msgstr "Característica eliminada: declaración GOTO asignada en %C"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "La lista de etiquetas de declaración en GOTO en %C no puede estar vacía"
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolescent feature: Computed GOTO at %C"
 msgid "Computed GOTO at %C"
 msgstr "Característica obsoleta: GOTO computado en %C"
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "Error en la especificación de tipo en %L"
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: typespec in ALLOCATE at %L"
 msgid "typespec in ALLOCATE at %L"
 msgstr "Fortran 2003: Especificación de tipo en ALLOCATE en %L"
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "Objeto de alojamiento erróneo en %C para un procedimiento PURE"
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "ALLOCATE de comatriz en %C en el bloque DO CONCURRENT"
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr "ALLOCATE de comatriz en %C en el bloque CRITICAL"
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocate-object at %L is not a nonprocedure pointer or an allocatable variable"
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "El objeto de alojamiento en %L no es un puntero que no es procedimiento o una variable de alojamiento"
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "El tipo de entidad en %L es de tipo incompatible con la especificación de tipo"
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr "El parámetro de tipo de género para la entidad en %L difiere del parámetro de tipo de género de la especificación de tipo"
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "Especificación de forma para el escalar asignable en %C"
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ERRMSG tag at %L"
 msgid "ERRMSG tag at %L"
 msgstr "Fortran 2003: Etiqueta ERRMSG en %L"
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: SOURCE tag at %L"
 msgid "SOURCE tag at %L"
 msgstr "Fortran 2003: Etiqueta SOURCE en %L"
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr "Se encontró una etiqueta SOURCE redundante en %L "
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr "La etiqueta SOURCE en %L tiene conflictos con la especificación de tipo en %L"
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: SOURCE tag at %L with more than a single allocate object"
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr "Fortran 2008: Etiqueta SOURCE en %L con más de un objeto de alojamiento sencillo"
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: MOLD tag at %L"
 msgid "MOLD tag at %L"
 msgstr "Fortran 2008: Etiqueta MOLD en %L"
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr "Se encontró una etiqueta MOLD redundante en %L "
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la especificación de tipo en %L"
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la etiqueta SOURCE en %L"
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "El objeto de alojamiento en %L con un parámetro de tipo diferido requiere una especificación de tipo o una etiqueta SOURCE o una etiqueta MOLD"
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "El objeto de alojamiento en %L con un parámetro de tipo diferido requiere una especificación de tipo o una etiqueta SOURCE o una etiqueta MOLD"
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "El objeto puntero en %C no debe tener un coíndice"
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "Objeto de alojamiento ilegal en %C para un procedimiento PURE"
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "DEALLOCATE de comatriz en %C en el bloque DO CONCURRENT"
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr "DEALLOCATE de comatriz en %C en el bloque CRITICAL"
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocate-object at %C is not a nonprocedure pointer or an allocatable variable"
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "El objeto de alojamiento en %C no es un puntero que no es procedimiento o una variable de alojamiento"
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ERRMSG at %L"
 msgid "ERRMSG at %L"
 msgstr "Fortran 2003: ERRMSG en %L"
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr "Declaración de control de imagen RETURN en %C en un bloque CRITICAL"
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "Declaración de control de imagen RETURN en %C en un bloque DO CRITICAL"
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "La declaración RETURN alternativa en %C sólo se permite dentro de una SUBROUTINE"
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: RETURN statement in main program at %C"
 msgid "RETURN statement in main program at %C"
 msgstr "Extensión: declaración RETURN en el programa principal en %C"
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Se esperaba una referencia de componente en %C"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "Basura después de CALL en %C"
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Se esperaba un procedimiento enlazado a tipo o un procedimiento de componente puntero en %C"
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "Error sintáctico en el nombre de bloque común en %C"
@@ -49607,159 +49664,159 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr "La variable '%s' en %L en el bloque común '%s' en %C se debe declarar con género interoperable con C porque el bloque común '%s' es bind(c)"
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %C can not be bind(c) since it is not global"
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr "La variable '%s' en el bloque común '%s' en %C no puede ser bind(c) porque no es global"
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "El símbolo '%s' en %C ya está en un bloque COMMON"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, fuzzy, gcc-internal-format
 #| msgid "Initialized symbol '%s' at %C can only be COMMON in BLOCK DATA"
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "El símbolo inicializado '%s' en %C sólo puede ser COMMON en BLOCK DATA"
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "Array specification for symbol '%s' in COMMON at %C must be explicit"
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "La especificación de matriz para el símbolo '%s' en COMMON en %C debe ser explícita"
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in COMMON at %C cannot be a POINTER array"
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "El símbolo '%s' en COMMON en %C no puede ser una matriz POINTER"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s', in COMMON block '%s' at %C is being indirectly equivalenced to another COMMON block '%s'"
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "El símbolo '%s', en el bloque COMMON '%s' en %C está siendo indirectamente equivalente a otro bloque COMMON '%s'"
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already has a basic type of %s"
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "El nombre de grupo de lista de nombres '%s' en %C ya tiene un tipo básico de %s"
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already is USE associated and cannot be respecified."
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "El nombre de grupo de lista de nombres '%s' en %C ya está asociado con USE y no se puede reespecificar."
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "No se permite la matriz de tamaño asumido '%s' en la lista de nombres '%s' en %C"
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "El componente de tipo derivado %C no es un miembro EQUIVALENCE permitido"
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "La referencia a matriz en EQUIVALENCE en %C no puede ser una sección de matriz"
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "El EQUIVALENCE en %C requiere dos o más objetos"
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Se intentó sobreescribir indirectamente los bloques COMMON %s y %s con EQUIVALENCE en %C"
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Se esperaba una coma en EQUIVALENCE en %C"
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "La función de declaración en %L es recursiva"
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In statement function"
 msgid "Statement function at %C"
 msgstr "En la declaración de la función"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Se esperaba la inicialización de la expresión en CASE en %C"
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name '%s' of SELECT construct at %C"
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Se esperaba el nombre de bloque '%s' de la construcción SELECT en %C"
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROTECTED statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Error sintáctico en la declaración PROTECTED en %C"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "El selector en SELECT TYPE en %C no es una variable nombrada; use nombre-asociado =>"
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Declaración CASE inesperada en %C"
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Error sintáctico en la especificación CASE en %C"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Declaración TYPE IS inesperada en %C"
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Error sintáctico en la especificación TYPE IS en %C"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Error sintáctico en la especificación CLASS IS en %C"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "La declaración ELSEWHERE en %C no está dentro de un bloque WHERE"
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -49916,51 +49973,51 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s"
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' of module '%s', imported at %C, is also the name of the current program unit"
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "'%s' del módulo '%s', importado en %C, es también el nombre de la unidad de programa actual"
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "El símbolo '%s' referenciado en %L no se encontró en el módulo '%s'"
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, fuzzy, gcc-internal-format
 #| msgid "User operator '%s' referenced at %L not found in module '%s'"
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "El operador de usuario '%s' referenciado en %L no se encontró en el módulo '%s'"
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "El operador intrínseco '%s' referenciado en %L no se encontró en el módulo '%s'"
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
@@ -49967,141 +50024,141 @@
 msgstr "No se puede abrir el fichero de módulo '%s' para escritura en %C: %s"
 
 # El mensaje de error seguramente está mal redactado. cfuga
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Error al escribir al fichero de módulo '%s' para escritura: %s"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file '%s': %s"
 msgid "Can't delete module file %qs: %s"
 msgstr "No se puede borrar el fichero de módulo '%s': %s"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "Can't rename module file '%s' to '%s': %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "No se puede renombrar el fichero de módulo '%s' a '%s': %s"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete temporary module file '%s': %s"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "No se puede borrar el fichero de módulo temporal '%s': %s"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs already declared"
 msgstr "El símbolo '%s' ya se había declarado"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "The symbol '%s', referenced at %L, is not in the selected standard"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "El símbolo '%s' referenciado en %L, no está en el módulo estándar"
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "El símbolo '%s' referenciado en %L no se encontró en el módulo intrínseco ISO_C_BINDING"
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, fuzzy, gcc-internal-format
 #| msgid "Use of intrinsic module '%s' at %C conflicts with non-intrinsic module name used previously"
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "El uso del módulo intrínseco '%s' en %C tiene conflictos con un nombre de módulo no intrínseco usado previamente"
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %s"
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "El uso de la constante nombrada NUMERIC_STORAGE_SIZE del módulo intrínseco ISO_FORTRAN_ENV en %L es incompatible con la opción %s"
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "El uso de la constante nombrada NUMERIC_STORAGE_SIZE del módulo intrínseco ISO_FORTRAN_ENV en %C es incompatible con la opción %s"
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "El símbolo '%s' referenciado en %L no se encontró en el módulo intrínseco ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CLOSE statement at %L requires a UNIT number"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "La declaración CLOSE en %L requiere un número UNIT"
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_FORTRAN_ENV intrinsic module at %C"
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003: Módulo intrínseco ISO_FORTRAN_ENV en %C"
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_C_BINDING module at %C"
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003: Módulo ISO_C_BINDING en %C"
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, fuzzy, gcc-internal-format
 #| msgid "Can't find an intrinsic module named '%s' at %C"
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "No se puede encontrar un módulo intrínseco llamado '%s' en %C"
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "No se puede abrir el fichero de módulo '%s' para lectura en %C: %s"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, fuzzy, gcc-internal-format
 #| msgid "Use of non-intrinsic module '%s' at %C conflicts with intrinsic module name used previously"
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "El uso del módulo '%s' que no es intrínseco en %C tiene conflictos con el nombre del módulo intrínseco usado previamente"
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GFORTRAN module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "El fichero '%s' abierto en %C no es un fichero de módulo GFORTRAN"
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
 # No se puede hacer el mismo juego de palabras que en inglés. cfuga
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr "¡No se puede hacer USE del mismo módulo que estamos construyendo!"
@@ -50427,7 +50484,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula IF en %L requiere una expresión LOGICAL escalar"
@@ -51200,393 +51257,387 @@
 msgid "Unexpected %s statement at %C"
 msgstr "Declaración %s inesperada en %C"
 
-#: fortran/parse.c:2428
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected %s statement in MODULE at %C"
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr "Declaración %s inesperada en MODULE en %C"
-
-#: fortran/parse.c:2439
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "La declaración %s en %C no puede ir después de la declaración %s en %L"
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "Fin de fichero inesperado en '%s'"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with SEQUENCE must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "El tipo derivado '%s' con SEQUENCE no debe tener una sección CONTAINS en %C"
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with BIND(C) must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "El tipo derivado '%s' con BIND(C) no debe tener una sección CONTAINS en %C"
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "Los componentes en TYPE en %C deben preceder a CONTAINS"
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  Type-bound procedure at %C"
 msgid "Type-bound procedure at %C"
 msgstr "Fortran 2003: Procedimiento enlazado a tipo en %C"
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after GENERIC binding at %C"
 msgid "GENERIC binding at %C"
 msgstr "Basura después del enlace GENERIC en %C"
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  FINAL procedure declaration at %C"
 msgid "FINAL procedure declaration at %C"
 msgstr "Fortran 2003: Declaración de procedimiento FINAL en %C"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: Derived type definition at %C with empty CONTAINS section"
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Fortran 2003: La definición de tipo derivado en %C tiene una sección CONTAINS vacía"
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "La declaración PRIVATE en TYPE en %C debe estar dentro de un MODULE"
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "La declaración PRIVATE en %C debe preceder a los enlaces de procedimiento"
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Declaración PRIVATE duplicada en %C"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "La declaración SEQUENCE en %C debe preceder a CONTAINS"
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "Ya está dentro de un bloque CONTAINS en %C"
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "La declaración FINAL en %C debe estar dentro de CONTAINS"
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Derived type definition at %C without components"
 msgid "Derived type definition at %C without components"
 msgstr "Fortran 2003: La definición de tipo derivado en %C no tiene componentes"
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "La declaración PRIVATE en %C debe preceder a los componentes de la estructura"
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "La declaración SEQUENCE en %C debe preceder a los componentes de la estructura"
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "El atributo SEQUENCE en %C ya se especificó en la declaración TYPE"
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Declaración SEQUENCE duplicada en %C"
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  CONTAINS block in derived type definition at %C"
 msgid "CONTAINS block in derived type definition at %C"
 msgstr "Fortran 2003: Bloque CONTAINS en una definición de tipo derivado en %C"
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "El componente %s en %L de tipo LOCK_TYPE debe tener una codimensión o ser un subcomponente de una comatriz, lo cua no es posible ya que el componente tiene el atributo puntero"
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "El componenten puntero %s en %L tiene un subcomponenten que no es comatriz de tipo LOCK_TYPE, el cual debe tener una codimensión o ser un subcomponente de una comatriz"
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "El componente allocatable %s en %L de tipo LOCK_TYPE debe tener una codimensión"
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr "El componente allocatable %s en %L debe tener una codimensión ya que tiene un subcomponente que no es comatriz de tipo LOCK_TYPE"
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "El componente %s que no es comatriz en %L de tipo LOCK_TYPE o con subcomponente de tipo LOCK_TYPE debe tener una codimensión o ser un subcomponente de una comatriz. (Las variables de tipo %s pueden no tener una codimensión si ya existe un subcomponente comatriz)"
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "El componente %s que no es comatriz en %L de tipo LOCK_TYPE o con subcomponente de tipo LOCK_TYPE debe tener una codimensión o ser un subcomponente de una comatriz. (Las variables de tipo %s pueden no tener una codimiensión ya que %s en %L tiene una codimensión o un componente submatriz)"
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "La declaración ENUM en %C no tiene ENUMERATORS"
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Declaración %s inesperada en el bloque INTERFACE en %C"
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "El nombre '%s' de ABSTRACT INTERFACE en %C no puede ser el mismo que un tipo intrínseco"
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Declaración %s inesperada en %C en el cuerpo de INTERFACE"
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "El procedimiento INTERFACE '%s' en %L tiene el mismo nombre que el procedimiento que lo incluye"
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "No se permite una declaración %s dentro de BLOCK en %C"
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement is not allowed inside of BLOCK at %C"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "No se permite una declaración %s dentro de BLOCK en %C"
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "La declaración %s debe aparecer en un MODULE"
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "La declaración %s en %C después de otra especificación de accesibilidad"
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "Bad kind expression for function '%s' at %L"
 msgid "Bad kind expression for function %qs at %L"
 msgstr "Expresión de género errónea para la función '%s' en %L"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, fuzzy, gcc-internal-format
 #| msgid "The type for function '%s' at %L is not accessible"
 msgid "The type for function %qs at %L is not accessible"
 msgstr "El tipo para la función '%s' en %L no es accesible"
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "Declaración ELSEWHERE en %C después de un ELSEWHERE desenmascarado previo"
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Declaración %s inesperada en el bloque WHERE en %C"
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Declaración %s inesperada en el bloque FORALL en %C"
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "La declaración ELSE IF en %C no puede ir después de una declaración ELSE en %L"
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Declaraciones ELSE duplicadas en %L y %C"
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "Se esperaba una declaración CASE o END SELECT después de un SELECT CASE en %C"
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "Se esperaba una declaración TYPE IS, CLASS IS o END SELECT después de un SELECT TYPE en %C"
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "El final de la declaración DO que no es bloque en %C está dentro de otro bloque"
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "El final de la declaración DO que no es bloque en %C está entrelazado con otro bucle DO"
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement label in END CRITICAL at %C does not match CRITIAL label"
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "La etiqueta de declaración en END CRITICAL en %C no coincide con la etiqueta CRITICAL"
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BLOCK construct at %C"
 msgid "BLOCK construct at %C"
 msgstr "Fortran 2008: Constructor BLOCK en %C"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASSOCIATE construct at %C"
 msgid "ASSOCIATE construct at %C"
 msgstr "Fortran 2003: Constructor ASSOCIATE en %C"
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "La etiqueta de declaración en ENDDO en %C no coincide con la etiqueta DO"
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "El bloque DO nombrado en %L requiere un nombre ENDDO coincidente"
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr "Falta !$OMP END ATOMIC después de !$OMP ATOMIC CAPTURE en %C"
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Nested CRITICAL block at %C"
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr "Bloque CRITICAL anidado en %C"
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s at %C"
 msgstr "Se esperaba la declaración %s en %C"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "Se esperaba '(' en %C"
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr "Se encontró una etiqueta ACQUIRED_LOCK redundante en %L "
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "Los nombres después de !$omp critical y !$omp end critical no coinciden en %C"
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "La declaración %s en %C no puede terminar un bucle DO que no es bloque"
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORMAT statement at %L does not have a statement label"
 msgid "DATA statement at %C after the first executable statement"
 msgstr "La declaración FORMAT en %L no tiene una etiqueta de declaración"
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %C is already ambiguous"
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "El procedimiento contenido '%s' en %C ya es ambiguo"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Declaración %s inesperada en la sección CONTAINS en %C"
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr "Fortran 2008: Declaración CONTAINS sin una declaración FUNCTION o SUBROUTINE en %C"
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "La declaración CONTAINS en %C ya está contenida en una unidad de programa"
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr "El nombre global '%s' en %L ya se está usando como un %s en %L"
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr "El nombre global '%s' en %L ya se está usando como un %s en %L"
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "BLOCK DATA en blanco en %C genera un conflicto con un BLOCK DATA previo en %L"
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Declaración %s inesperada en BLOCK DATA en %C"
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Declaración %s inesperada en MODULE en %C"
@@ -51594,7 +51645,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "Dos PROGRAMas principales en %L y %C"
@@ -52374,7 +52425,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "El procedimiento que no es RECURSIVE '%s' en %L posiblemente se está llamando a sí mismo recursivamente. Declárelo RECURSIVE o utilice -frecursive"
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "La etiqueta %d referenciada en %L nunca se define"
@@ -52435,96 +52486,96 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "No se permite el paso del procedimiento interno en %L por ubicación"
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "El procedimiento ELEMENTAL que no es INTRINSIC '%s' no se permite como un argumento actual en %L"
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Argumento actual coindizado en %L con componente puntero último"
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "'%s' en %L es una matriz y OPTIONAL; SI FALTA, no puede ser el argumento actual de un procedimiento ELEMENTAL a menos que exista un argumento que no sea opcional con el mismo rango (12.4.1.5)"
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument at %L for INTENT(%s) dummy '%s' of ELEMENTAL subroutine '%s' is a scalar, but another actual argument is an array"
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "El argumento actual en %L para el dummy INTENT(%s) '%s' de la subrutina ELEMENTAL '%s' es un escalar, pero otro argumento actual es una matriz"
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, fuzzy, gcc-internal-format
 #| msgid "Return type mismatch of function '%s' at %L (%s/%s)"
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "No coincide el tiop de devolución de la función '%s' en %L (%s/%s)"
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in dummy procedure '%s' at %L: %s"
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr "La interfaz no coincide en el procedimiento dummy '%s' en %L: %s"
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "No hay una función específica para el genérico '%s' en %L"
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "La función genérica '%s' en %L no es consistente con una interfaz intrínseca específica"
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "La función '%s' en %L es INTRINSIC pero no es compatible con un intrínseco"
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "No se puede resolver la función específica '%s' en %L"
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "La función '%s' en %L no es de tipo IMPLICIT"
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, fuzzy, gcc-internal-format
 #| msgid "Reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "La referencia a la función '%s' que no es PURE en %L está dentro de un FORALL %s"
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, fuzzy, gcc-internal-format
 #| msgid "Reference to non-PURE function '%s' at %L inside a DO CONCURRENT %s"
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "La referencia a la función '%s' que no es PURE en %L está dentro de un DO CONCURRENT %s"
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, fuzzy, gcc-internal-format
 #| msgid "Reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "La referencia a la función '%s' que no es PURE en %L está dentro de un FORALL %s"
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a function"
 msgid "%qs at %L is not a function"
 msgstr "'%s' en %L no es una función"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "ABSTRACT INTERFACE '%s' must not be referenced at %L"
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
@@ -52531,300 +52582,300 @@
 msgstr "La ABSTRACT INTERFACE '%s' no se debe referenciar en %L"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "La función '%s' se declara CHARACTER(*) y no se puede usar en %L ya que no es un argumento de prueba"
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_function(): bad function type"
 msgstr "<tipo de función sobrecargada sin resolver>"
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "User defined non-ELEMENTAL function '%s' at %L not allowed in WORKSHARE construct"
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "La función definida por el usuario '%s' que no es ELEMENTAL en %L no se permite en la construcción WORKSHARE"
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as function '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "ENTRY '%s' en %L no se puede llamar recursivamente, porque la función '%s' no es RECURSIVE"
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "La función '%s' en %L no se puede llamar recursivamente, porque no es RECURSIVE"
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "La llamada a subrutina a '%s' en el bloque FORALL en %L no es PURE"
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in DO CONCURRENT block at %L is not PURE"
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "La llamada a subrutina a '%s' en el bloque DO CONCURRENT en %L no es PURE"
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "La llamada a subrutina a '%s' en %L no es PURE"
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific subroutine for the generic '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "No hay una subrutina específica para el genérico '%s' en %L"
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "La subrutina genérica '%s' en %L no es consistente con una interfaz de subrutina intrínseca"
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "La subrutina '%s' en %L es INTRINSIC pero no es compatible con un intrínseco"
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "No se puede resolver la subrutina específica '%s' en %L"
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr "'%s' en %L tiene un tipo, el cual no es consistente con CALL en %L"
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as subroutine '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "ENTRY '%s' en %L no se puede llamar recursivamente, porque la subrutina '%s' no es RECURSIVE"
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE '%s' en %L no se puede llamar recursivamente, porque no es RECURSIVE"
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_subroutine(): bad function type"
 msgstr "<tipo de función sobrecargada sin resolver>"
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Las formas para los operandos en %L y %L no son conformables"
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld < %ld) en la codimensión %d"
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld > %ld) en la codimensión %d"
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Tranco ilegal de cero en %L"
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz inferior en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz inferior en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz superior en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz superior en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "falta el subíndice en la referencia de la matriz"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "No se especificó el límite superior a la derecha de la sección de matriz de tamaño asumido en %L"
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "El rango no coincide en la referencia de matriz en %L (%d/%d)"
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "El rango de coíndice no coincide en la referencia de matriz en %L (%d/%d)"
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "El coíndice en la codimensión %d debe ser un escalar en %L"
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "El índice de matriz en %L debe ser escalar"
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "El índice de matriz en %L debe ser de tipo INTEGER, se encontró %s"
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Extensión: índice de matriz REAL en %L"
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "El argumento dim en %L debe ser escalar"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "El argumento dim en %L debe ser de tipo entero"
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "El índice de matriz en %L es una matriz de rango %d"
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "El índice de inicio de la subcadena en %L debe ser de tipo INTEGER"
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "El índice de inicio de la subcadena en %L debe ser escalar"
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "El índice de inicio de la subcadena en %L es menor a uno"
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "El índice de final de la subcadena en %L debe ser de tipo INTEGER"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "El índice de final de la subcadena en %L debe ser escalar"
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "El índice de final de la subcadena en %L excede la longitud de la cadena"
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "El índice de final de la subcadena en %L es demasiado grande"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Referencia de matriz errónea en %L"
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "El componente a la derecha de una referencia de parte con rango que no es cero no debe tener el atributo POINTER en %L"
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "El componente a la derecha de una referencia de parte con rango que no es cero no debe tener el atributo ALLOCATABLE en %L"
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "No se deben especificar dos o más referencias de parte con rango que no es cero en %L"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -52834,12 +52885,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -52849,262 +52900,262 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure '%s' at %L with BIND(C) attribute must have an explicit interface"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "El procedimiento '%s' en %L con atributo BIND(C) debe tener una interfaz explícita"
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable '%s', usada en una expresión de especificación, se referencía en %L antes de la declaración ENTRY en la cual es un parámetro"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable '%s' se usa en %L antes de la declaración ENTRY en la cual es un parámetro"
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Subobjecto polimórfico de un objeto coindizado en %L"
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Objeto coindizado con subcomponente alojable polimórfico en %L"
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "El objeto pasado en %L debe ser escalar"
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type '%s'"
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a componente procedimiento-puntero en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for type-bound procedure call at %L is of ABSTRACT type '%s'"
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo NOPASS en %L debe ser escalar"
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "No se encontró un enlace específico coincidente para la llamada al GENERIC '%s' en %L"
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' en %L debe ser una SUBROUTINE"
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' en %L debe ser una FUNCTION"
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Se esperaba un tipo de expresión"
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s en %L debe ser un escalar"
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "%s at %L must be integer"
 msgstr "'%s' en %L debe ser no negativo"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s en %L debe ser INTEGER"
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "La expresión de paso en el bucle DO en %L no puede ser cero"
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "El bucle DO en %L se ejecutará cero veces"
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "El nombre de índice FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "La expresión de inicio FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "La expresión de fin FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "La expresión de tranco FORALL en %L debe ser un %s escalar"
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "La expresión de tranco FORALL en %L no puede ser cero"
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "El índice FORALL '%s' no puede aparecer en la especificación triplet en %L"
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "El objeto de alojamiento en %L debe ser ALLOCATABLE o un POINTER"
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Objeto alojable coindizado en %L"
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "La expresión fuente en %L debe ser escalar o tener el mismo rango que el objeto de alojamiento en %L"
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "La expresión fuente en %L y el objeto de alojamiento en %L deben tener la misma forma"
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "El tipo de entidad en %L es de tipo incompatible con la expresión fuente en %L"
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "El objeto de alojamiento en %L y la expresión fuente en %L deben tener el mismo parámetro de tipo de género"
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "La expresión fuente en %L no puede ser de tipo LOCK_TYPE ni tener un componente LOCK_TYPE si el objeto-alojado en %L es una comatriz"
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "El alojamiento %s del tipo de base ABSTRACT en %L requiere una especificación de tipo o una expresión source"
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Alojar %s en %L con especificación de tipo requiere el mismo parámetro de longitud de carácter que el de la declaración"
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de matriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Especificación de matriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' no debe aparecer en la especificación de matriz en %L en la misma declaración ALLOCATE donde se aloja a sí misma"
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Se esperaba '*' en la especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Especificación de comatriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "La variable stat en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable stat en %L no no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG en %L es inútil sin una etiqueta STAT"
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "La variable errmsg en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable errmsg en %L no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "El objeto de alojamiento en %L también aparece en %L"
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "El objeto de alojamiento en %L es un subobjeto del objeto en %L"
@@ -53113,123 +53164,123 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "La etiqueta CASE en %L se encima con la etiqueta CASE en %L"
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "La expresión en la declaración CASE en %L debe ser de tipo %s"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "La expresión en la declaración CASE en %L debe ser de género %d"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "La expresión en la declaración CASE en %L debe ser escalar"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "La expresión de selección en una declaración GOTO computada en %L debe ser una expresión entera escalar"
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "El argumento de la declaración SELECT en %L no puede ser %s"
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "El argumento de la declaración SELECT en %L debe ser una expresión escalar"
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "La expresión en la declaración CASE en %L no está en el rango de %s"
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "El DEFAULT CASE en %L no puede tener después un segundo DEFAULT CASE en %L"
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "No se permite un rango lógico en una declaración CASE en %L"
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Se repite un valor lógico constante en una declaración CASE en %L"
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "La especificación de rango en %L nunca puede coincidir"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "El bloque SELECT CASE lógico en %L tiene más de dos cases"
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' at %L is used as array"
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Se usa el nombre asociado '%s' en %L como una matriz"
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "El selector debe ser polimórfico en la declaración SELECT TYPE en %L"
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L must not be coindexed"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "El tipo derivado '%s' en %L debe ser extensible"
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be an extension of '%s'"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "El tipo derivado '%s' en %L debe ser una extensión de '%s'"
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Intrínseco NULL inesperado en %L para el dummy '%s'"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "La especificación de tipo en %L no puede tener un parámetro de tipo diferido"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Bloque CLASS IS doble en la declaración SELECT TYPE  en %L"
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
@@ -53236,72 +53287,72 @@
 msgstr "Contexto inválido para el puntero NULL() en %%L"
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede ser polimórfico a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes POINTER a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes de puntero a procedimiento"
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes ALLOCATABLE a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes PRIVATE"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "El elemento de transferencia de datos en %L no puede ser una referencia completa a una matriz de tamaño asumido"
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "La variable lock en %L debe ser un escalar de tipo LOCK_TYPE"
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "El argumento STAT= en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "El argumento ERRMSG= en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "El argumento ACQUIRED_LOCK= en %L debe ser una variable LOGICAL escalar"
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "El argumento de conjunto de imagen en %L debe estar entre 1 y num_images()"
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "La declaración en %L no es una declaración de objetivo de ramificación válida para la declaración de ramificación en %L"
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "La ramificación en %L puede resultar en un bucle infinito"
@@ -53308,12 +53359,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción CRITICAL por la etiqueta en %L"
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción DO CONCURRENT por la etiqueta en %L"
@@ -53321,166 +53372,166 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "La etiqueta en %L no está en el mismo bloque que la declaración GOTO en %L"
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "La máscara WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "El objetivo de asignación WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Asignación definida por el usuario de un no-ELEMENTAL en WHERE en %L"
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Declaración sin soporte dentro de WHERE en %L"
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "No se usa el FORALL con índice '%s' en el lado izquierdo de la asignación en %L y podría causar múltiples asignaciones a este objeto"
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Una construcción FORALL externa ya tiene un índice con este nombre %L"
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "la cláusula WHERE/ELSEWHERE en %L requiere una matriz LOGICAL"
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr "Se truncará la expresión CHARACTER en la asignación (%d/%d) en %L"
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "La expresión con coíndice en %L se asigna a una variable de tipo derivado con un componente POINTER en un procedimiento PURE"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "La variable impura en %L se asigna a una variable de tipo derivado con un componente POINTER en un procedimiento PURE (12.6)"
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Asignación a una variable coindizada en %L en un procedimiento PURE"
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Polymorphic array at %C not yet supported"
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Aún no se admite la matriz polimórfica en %C"
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Polymorphic array at %C not yet supported"
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr "Aún no se admite la matriz polimórfica en %C"
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "La variable no debe ser polimórfica en la asignación intrínseca en %L - revise que hay una subrutina específica coincidente para el operador '='"
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coindexed variable must not be have an allocatable ultimate component in assignment at %L"
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "La variable coindizada no debe tener un componente último alojable en la asignación en %L"
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "La declaración ASSIGNED GOTO en %L requiere una variable INTEGER"
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "La variable '%s' no se ha asignado a una etiqueta objetivo en %L"
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "La declaración RETURN alternativa en %L requiere de un especificador de devolución SCALAR-INTEGER"
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "La declaración de ASSIGN en %L requiere una variable INTEGER escalar por defecto"
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr "La declaración IF aritmética en %L requiere una expresión numérica"
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "La condición de salida del bucle DO WHILE en %L debe ser una expresión LOGICAL escalar"
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula de máscara FORALL en %L requiere una expresión LOGICAL escalar"
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Código de declaración erróneo"
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
@@ -53488,7 +53539,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -53496,64 +53547,64 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en %L"
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr "La variable CHARACTER en %L tiene longitud negativa %d, la longitud se estableció a cero"
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "La longitud de la cadena en %L es demasiado grande"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz allocatable '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "El objeto escalar '%s' en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz de puntero '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "La matriz '%s' en %L no puede tener una forma diferida"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' of CLASS variable '%s' at %L is not extensible"
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "El tipo '%s' de la variable CLASS '%s' en %L no es extensible"
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable '%s' at %L must be dummy, allocatable or pointer"
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "La variable CLASS '%s' en %L debe ser dummy, allocatable o pointer"
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "El tipo '%s' no se puede asociar al anfitrión en %L porque está bloqueado por un objeto incompatible del mismo nombre declarado en %L"
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Implied SAVE for module variable '%s' at %L, needed due to the default initialization"
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
@@ -53561,493 +53612,493 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr "El módulo o la matriz del programa principal '%s' en %L deben tener una forma constante"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el atributo pointer o allocatable"
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "La entidad con longitud de carácter asumida en %L debe ser un argumento de prueba o un PARAMETER"
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr "'%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "La variable COMMON '%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "El allocatable '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "El external '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "El dummy '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "El intrinsic '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "El resultado de la función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "La matriz automática '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "La función de declaración valuada con carácter '%s' en %L debe tener longitud constante"
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' es de un tipo PRIVATE y no puede ser un argumento dummy de '%s', el cual es PUBLIC en %L"
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: El procedimiento '%s' en la interfaz PUBLIC '%s' en %L toma argumentos dummy de '%s' el cual es PRIVATE"
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "La función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "El objeto external '%s' en %L puede no tener un inicializador"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "La función ELEMENTAL '%s' en %L debe tener un resultado escalar"
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L may not have pointer or allocatable attribute"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "La función de declaración '%s' en %L no debe tener atributo puntero o alojable"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser matriz-valuada"
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser puntero-valuada"
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser recursiva"
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "El procedimiento '%s' en %s en %L no tiene una interfaz explícita"
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "El procedimiento dummy '%s' en %C no puede tener una interfaz genérica"
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo SAVE en '%s' en %L"
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo INTENT en '%s' en %L"
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo RESULT en '%s' en %L"
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, fuzzy, gcc-internal-format
 #| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "El atributo EXTERNAL genera un conflicto con el atributo FUNCTION en '%s' en %L"
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer result '%s' at %L is missing the pointer attribute"
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Al resultado del puntero de procedimiento '%s' en %L le falta el atributo puntero"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "El procedimiento FINAL '%s' en %L no debe ser una SUBROUTINE"
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "El procedimiento FINAL en %L debe tener exactamente un argumento"
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "El argumento del procedimiento FINAL en %L debe ser de tipo '%s'"
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser un POINTER"
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "El argumento del procedimiento final en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser OPTIONAL"
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser INTENT(OUT)"
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "El procedimiento FINAL que no es escalar en %L debe tener un argumento sharp asumido"
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "El procedimiento FINAL '%s' declarado en %L tiene el mismo rango (%d) que '%s'"
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Sólo se declaran procedimientos FINAL de matriz para el tipo derivado '%s' definido en %L, se sugiere también uno escalar"
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' y '%s' no pueden ser FUNCTION/SUBROUTINE mezcladas para el GENERIC '%s' en %L"
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' y '%s' para el GENERIC '%s' en %L son ambiguos"
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "El enlace específico '%s' no está definido como objetivo del GENERIC '%s' en %L"
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "El GENERIC '%s' en %L debe apuntar a un enlace específico, '%s' es GENERIC también"
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "El GENERIC '%s' en %L no puede sobreescribir el enlace específico con el mismo nombre"
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "El operador enlazado a tipo en %L no puede ser NOPASS"
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' debe ser un procedimiento de módulo o un procedimiento externo con una interfaz explícita en %L"
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 #| msgid "Non-polymorphic passed-object dummy argument of '%s' at %L"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Argumento dummy pasado como objeto no polimórfico de '%s' en %L"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L debe ser escalar"
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser POINTER"
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente de '%s'"
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente heredado de '%s'"
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' declared at %L must be ABSTRACT because '%s' is DEFERRED and not overridden"
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "El tipo derivado '%s' declarado en %L debe ser ABSTRACT porque '%s' es DEFERRED y no se sobreescribió"
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, fuzzy, gcc-internal-format
 #| msgid "As extending type '%s' at %L has a coarray component, parent type '%s' shall also have one"
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Como al extender el tipo '%s' en %L tiene un componente de comatriz, el tipo padre '%s' también debe tener uno"
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "El tipo derivado '%s' que no es extensible en %L no debe ser ABSTRACT"
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray component '%s' at %L must be allocatable with deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "El componente de comatriz '%s' en %L debe sel alojable con forma diferida"
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "El componente '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "El componenten '%s' en %L con componente comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "El componente '%s' en %L tiene el atributo CONTIGUOUS porque no es un puntero de matriz"
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento de componente puntero '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento de componente puntero '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser escalar"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede tener el atributo POINTER"
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "El componente '%s' de '%s' en %L tiene el mismo nombre que un procedimiento enlazado a tipo heredado"
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "La longitud de carácter del componente '%s' necesita ser una expresión de especificación constante en %L"
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, fuzzy, gcc-internal-format
 #| msgid "Character component '%s' of '%s' at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "El componente de carácter '%s' de '%s' en %L con longitud diferida debe ser POINTER o ALLOCATABLE"
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: el componente '%s' es un tipo PRIVATE y no puede ser un componente de '%s' el cual es PUBLIC en %L"
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "El componente polimórfico %s en %L en SEQUENCE o de tipo BIND(C) %s"
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "El componente %s del tipo SEQUENCE declarado en %L no tiene el atributo SEQUENCE"
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "El componente puntero '%s' de '%s' en %L es de un tipo que no se ha declarado"
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr "El componente '%s' con CLASS en %L debe ser allocatable o pointer"
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr "Fortran 2003: El nombre genérico '%s' de la función '%s' en %L tiene el mismo nombre que el tipo derivado en %L"
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %L is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "No se permite la matriz de tamaño asumido '%s' en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003: Objeto de matriz NAMELIST '%s' con forma asumida en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with nonconstant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con forma que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' with nonconstant character length in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con longitud de carácter que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' in namelist '%s' at %L is polymorphic and requires a defined input/output procedure"
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "El objeto NAMELIST '%s' en la lista de nombres '%s' en %L es polimórfico y requiere un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -54055,448 +54106,448 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' in namelist '%s' at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr "El objeto NAMELIST '%s' en la lista de nombres '%s' en %L tiene componentes ALLOCATABLE o POINTER y por lo tanto requere un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' se declaró PRIVATE y no puede ser miembro de una lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE asociados a uso y no puede ser miembro de la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE y no puede ser un miembro de la lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo NAMELIST en '%s' en %L"
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "La matriz de parámetro '%s' en %L no puede ser automática ni de forma diferida"
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "El PARAMETER de tipo implícito '%s' en %L no coincide con un tipo IMPLICIT posterior"
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipo derivado incompatible en PARAMETER en %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "El atributo PROTECTED genera un conflicto con el atributo EXTERNAL en %L"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo PROTECTED en %L"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "La matriz de tamaño asumido en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "El símbolo en %L no es una variable DUMMY"
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' en %L no puede tener el atributo VALUE porque no es un argumento dummy"
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable dummy de carácter '%s' en %L con atributo VALUE debe tener longitud constante"
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable dummy de carácter interoperable con C '%s' en %L con atributo VALUE debe ser de longitud uno"
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "El tipo derivado '%s' en %L es de tipo '%s', el cual no se ha definido"
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "No se permite la matriz de forma asumida '%s' en %L en una expresión de inicialización"
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de bucle en %C no puede ser una comatriz"
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable '%s' en %L no puede ser BIND(C) porque no es un bloque COMMON ni se declaró en el ámbito de nivel de módulo"
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: La función PUBLIC %s '%s' en %L es de tipo derivado PRIVATE '%s'"
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "El argumento dummy INTENT(OUT) '%s' en %L es ASSUMED SIZE y por lo tanto no puede tener un inicializador por defecto"
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L shall not be a coarray or have a coarray component"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "El resultado de la función '%s' en %L no puede ser una comatriz o tener un componente comatriz"
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable '%s' en %L con componente de comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable '%s' en %L es una comatriz y no es ALLOCATABLE, SAVE ni un argumento dummy"
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable coarray variable '%s' at %L must have deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable comatriz allocatable '%s' en %L debe tener forma diferida"
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable '%s' en %L es INTENT(OUT) y por lo tanto no puede ser una comatriz allocatable o tener componentes comatriz"
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "No se guarda (SAVE) el threadprivate en %L"
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "El elemento BLOCK DATA '%s' en %L debe estar en COMMON"
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "La matriz DATA '%s' en %L se debe especificar en una declaración previa"
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L cannot have a coindex"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "El elemento DATA '%s' en %L no puede tener un coíndice"
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L is a pointer and so must be a full array"
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "El elemento DATA '%s' en %L es un puntero y entonces debe ser una matriz completa"
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Sección de matriz no constante en %L en la declaración DATA"
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "La declaración DATA en %L tiene más variables que valores"
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el inicio del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el final del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el paso del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "La declaración DATA en %L tiene más valores que variables"
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Se define la etiqueta %d en %L pero no se usa"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Se define la etiqueta %d en %L pero no se puede usar"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L debe tener el atributo SEQUENCE para ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L no puede tener componentes ALLOCATABLE que sean un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de tipo derivado '%s' en %L con inicializadores por defecto no puede ser un objeto EQUIVALENCE con una variable en COMMON"
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L con componente(s) de puntero no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Error sintáctico en la declaración EQUIVALENCE en %L"
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Todos o ninguno de los objetos en el conjunto EQUIVALENCE en %L deben tener el atributo PROTECTED"
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "El miembro de bloque común '%s' en %L no puede ser un objeto EQUIVALENCE en el procedimiento puro '%s'"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nombrada '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "La matriz '%s' en %L con límites que no son constantes no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "El componente de estructura '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La subcadena en %L tiene longitud cero"
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "La función PUBLIC '%s' en %L no puede ser del tipo PRIVATE '%s'"
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY '%s' en %L no tiene tipo IMPLICIT"
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe ser FUNCTION"
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "El procedimiento de operador de usuario '%s' en %L no puede ser de longitud de carácter asumido"
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "El primer argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "El segundo argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "La interfaz de operador en %L debe tener, cuando mucho, dos argumentos"
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -54531,49 +54582,49 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr "!$OMP en %C inicia una línea comentada y no está seguido de un espacio ni es una continuación de línea"
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr "Se truncó la línea en %L"
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr "Se excedió el límite de %d continuaciones en la declaración en %C"
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "Missing '&' in continued character constant at %C"
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "Falta un '&' en la constante de carácter continuado en %C"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr "Carácter de tabulación que no es conforme en %C"
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "'&' not allowed by itself in line %d"
 msgid "%<&%> not allowed by itself in line %d"
 msgstr "no se permite '&' por sí solo en la línea %d"
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr "Carácter de tabulador que no es conformante en la columna %d de la línea %d"
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr "%s:%d: se dejó el fichero %s pero no se entró"
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr "%s:%d: Directiva de preprocesamiento ilegal"
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open file '%s'"
 msgid "Can't open file %qs"
@@ -54842,55 +54893,55 @@
 msgid "Reshaped array too large at %C"
 msgstr "Entero demasiado grande en %C"
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "El resultado de SCALE desborda su género en %L"
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Tipo erróneo en la expresión constante"
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "El argumento de SQRT en %L tiene un valor negativo"
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid second argument of IBSET at %L"
 msgid "invalid argument of SQRT at %L"
 msgstr "Segundo argumento de IBSET inválido en %L"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr "Fuera de límites en IMAGE_INDEX en %L para la dimensión %d, SUB tiene %ld y el límite inferior de COARRAY  es %ld)"
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr "Fuera de límites en IMAGE_INDEX en %L para la dimensión %d, SUB tiene %ld y el límite superior de COARRAY es %ld)"
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_conv_constant_to_tree(): invalid type: %s"
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): tipo inválido: %s"
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, fuzzy, gcc-internal-format
 #| msgid "Character '%s' in string at %L cannot be converted into character kind %d"
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
@@ -54976,272 +55027,278 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "El nombre de grupo de lista de nombres en %L no puede tener el atributo SAVE"
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "User operator procedure '%s' at %L must have at least one argument"
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "El procedimiento de operador de usuario '%s' en %L debe tener al menos un argumento"
+
+#: fortran/symbol.c:489
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Procedure pointer at %C"
 msgid "Procedure pointer at %C"
 msgstr "Fortran 2003: Procedimiento puntero en %C"
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "El atributo %s se aplica a %s %s en %L"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "Se aplicó BIND(C) a %s %s en %L"
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "El atributo %s genera un conflicto con el atributo %s en %L"
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr "El atributo %s genera un conflicto con el atributo %s en '%s' en %L"
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute with %s attribute at %L"
 msgstr "El atributo %s genera un conflicto con el atributo %s en %L"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr "El atributo %s genera un conflicto con el atributo %s en '%s' en %L"
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "No se pueden cambiar los atributos de un símbolo asociado con USE en %L"
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "No se pueden cambiar los atributos del símbolo asociado con USE %s en %L"
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Se especificó un atributo %s duplicado en %L"
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "Se especificó ALLOCATABLE fuera de un cuerpo INTERFACE en %L"
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, fuzzy, gcc-internal-format
 #| msgid "CODIMENSION specified for '%s' outside its INTERFACE body at %L"
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "Se especificó CODIMENSION para '%s' fuera de su cuerpo INTERFACE en %L"
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, fuzzy, gcc-internal-format
 #| msgid "DIMENSION specified for '%s' outside its INTERFACE body at %L"
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "Se especificó DIMENSION para '%s' fuera de su cuerpo INTERFACE en %L"
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "El Apuntado Cray en %L aparece en varias declaraciones pointer()"
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Se especificó un atributo PROTECTED duplicado en %L"
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "El atributo SAVE en %L no se puede especificar en un procedimiento PURE"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "Se especificó un atributo SAVE duplicado en %L"
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Se especificó un atributo VALUE duplicado en %L"
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Se especificó un atributo VOLATILE duplicado en %L"
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Se especificó un atributo ASYNCHRONOUS duplicado en %L"
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "El atributo %s de '%s' genera un conflicto con el atributo %s en %L"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "El procedimiento %s en %L ya se había declarado como un procedimiento %s"
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) genera un conflicto con INTENT(%s) en %L"
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "La especificación ACCESS en %L ya se había especificado"
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Se especificó un atributo BIND duplicado en %L"
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid " BIND(C)"
 msgid "BIND(C) at %L"
 msgstr " BIND(C)"
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Se especificó un atributo EXTENDS duplicado en %L"
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: EXTENDS at %L"
 msgid "EXTENDS at %L"
 msgstr "Fortran 2003: EXTENDS en %L"
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "El símbolo '%s' en %L ya tenía una interfaz explícita"
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has attributes specified outside its INTERFACE body"
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "'%s' en %L tiene atributos especificados fuera de su cuerpo INTERFACE"
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr "El símbolo '%s' en %L genera conflictos con el símbolo del módulo '%s' asociado a uso en %L"
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "El símbolo '%s' en %L ya tenía el tipo básico de %s"
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "El procedimiento '%s' en %L no puede tener el tipo básico de %s"
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "El símbolo '%s' en %L no puede tener un tipo"
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr "El componente '%s' en %C ya se había declarado en %L"
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr "El componente '%s' en %C ya estaba en el tipo padre en %L"
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "El símbolo '%s' en %C es ambiguo"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "El tipo derivado '%s' en %C se está usando antes de ser definido"
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "El componente '%s' en %C es un componente PRIVATE de '%s'"
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%s' en %C no es un miembro de la estructura '%s'"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Declaración de etiqueta %d duplicada en %L y %L"
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "La etiqueta %d en %C ya se referenció como objetivo de ramificación"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "La etiqueta %d en %C ya se referenció como etiqueta de formato"
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "La etiqueta %d en %C se utilizó previamente como una etiqueta FORMAT"
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "La etiqueta %d en %C se utilizó previamente como objetivo de ramificación"
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "Se esperaba un nombre terminal en %C"
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "El nombre '%s' en %C es una referencia ambigua a '%s' del módulo '%s'"
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
@@ -55248,69 +55305,69 @@
 msgstr "El nombre '%s' en %C es una referencia ambigua a '%s' de la unidad de programa actual"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "El símbolo '%s' en %C ya se había asociado con el anfitrión"
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' declared at %L must have the BIND attribute to be C interoperable"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "El tipo derivado '%s' declarado en %L debe tener el atributo BIND para ser interoperable con C"
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "El tipo derivado '%s' con atributo BIND(C) en %L está vacío, y puede ser inaccesible para el procesador acompañante de C"
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr "El componente '%s' en %L no puede tener el atributo POINTER porque es un miembro del tipo derivado BIND(C) '%s' en %L"
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr "El procedimiento de componente puntero '%s' en %L no puede ser un miembro del tipo derivado BIND(C) '%s' en %L"
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr "El componente '%s' en %L no puede tener el atributo ALLOCATABLE porque es un miembro del tipo derivado BIND(C) '%s' en %L"
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable, even though derived type '%s' is BIND(C)"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "El componente '%s' en el tipo derivado '%s' en %L tal vez no es interoperable con C, aún cuando el tipo derivado '%s' es BIND(C)"
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "El componente '%s' en el tipo derivado '%s' en %L tal vez no es interoperable con C"
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "El tipo derivado '%s' en %L no se puede declarar con atributos PRIVATE y BIND(C) al mismo tiempo"
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "El tipo derivado '%s' en %L no puede tener el atributo SEQUENCE porque es BIND(C)"
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' is used before it is typed at %L"
 msgid "Symbol %qs is used before it is typed at %L"
@@ -55596,7 +55653,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr "Tipo base ES erróneo (%d)"
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr "gfc_trans_omp_workshare(): Código de declaración erróneo"
@@ -57729,6 +57786,9 @@
 #~ msgid "%q+D causes a section type conflict"
 #~ msgstr "%q+D causa un conflicto de tipo de sección"
 
+#~ msgid "-munix=98 option required for C89 Amendment 1 features.\n"
+#~ msgstr "se requiere la opción -munix=98 para las características C89 Enmienda 1.\n"
+
 #~ msgid "invalid AE type specified (%s)"
 #~ msgstr "se especificó un tipo AE inválido (%s)"
 
@@ -57999,6 +58059,9 @@
 #~ msgid "%qD has no member named %qE"
 #~ msgstr "%qD no tiene un miembro llamado %qE"
 
+#~ msgid "ISO C++ forbids subscripting non-lvalue array"
+#~ msgstr "ISO C++ prohíbe el subíndice de una matriz que no sea l-valuada"
+
 #~ msgid "  since type %qT has pure virtual functions"
 #~ msgstr "  ya que el tipo %qT tiene funciones virtuales pure"
 
@@ -68880,9 +68943,6 @@
 #~ msgid "SYN value outside range of its mode"
 #~ msgstr "valor SYN fuera del rango de su modo"
 
-#~ msgid "INIT string too large for mode"
-#~ msgstr "la cadena INIT es demasiado grande para el modo"
-
 #~ msgid "mode with non-value property in signal definition"
 #~ msgstr "modo sin propiedad que no es valor en la definición de la señal"
 
Index: gcc/po/fr.po
===================================================================
--- gcc/po/fr.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/fr.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -124,7 +124,7 @@
 msgstr ""
 "Project-Id-Version: gcc 5.1.0\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2015-04-29 12:25+0200\n"
 "Last-Translator: Stéphane Aulery <lkppo@free.fr>\n"
 "Language-Team: French <traduc@traduc.org>\n"
@@ -312,13 +312,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "constante flottante mal utilisée"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1536,7 +1536,7 @@
 msgid "options enabled: "
 msgstr "options autorisées: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2822,97 +2822,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "préfixe d'opérande invalide « %%%c »"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "valeur %%H invalide"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "valeur %%J invalide"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "valeur %%r invalide"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "valeur %%R invalide"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "valeur %%N invalide"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "valeur %%P invalide"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "valeur %%h invalide"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "valeur %%L invalide"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "valeur %%m invalide"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "valeur %%M invalide"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "valeur %%U invalide"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "valeur %%s invalide"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "valeur %%C invalide"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "valeur %%E invalide"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "relocalisation unspec inconnue"
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "valeur %%xn invalide"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, c-format
 msgid "invalid operand address"
 msgstr "adresse d'opérande invalide"
@@ -2960,7 +2960,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "opérande invalide pour le code de sortie"
@@ -3132,8 +3132,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3391,63 +3391,63 @@
 msgid "bad output_condmove_single operand"
 msgstr "opérande output_condmove_single erronée"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC invalide comme opérande"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "taille d'opérande invalide pour le code d'opérande « 0 »"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "taille d'opérande invalide pour le code d'opérande « z »"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "type opérande invalide utilisé avec le code d'opérande « Z »"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "taille opérande invalide pour le code d'opérande « Z »"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande invalide « Y »"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande invalide « D »"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande invalide « %c »"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "l'opérande n'est ni une constante ni du code de condition, code d'opérande invalide « c »"
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "opérande invalide pour « %c »"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "contrainte invalide pour l'opérande"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "mode insn inconnu"
 
@@ -3487,7 +3487,7 @@
 msgid "invalid %%P operand"
 msgstr "opérande %%P invalide"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "valeur %%p invalide"
@@ -3551,7 +3551,7 @@
 msgstr "post-incrément d'adresse n'est pas un registre"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "adresse erronée"
 
@@ -3713,104 +3713,104 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 msgid "bad move"
 msgstr "mauvais mouvement"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, c-format
 msgid "invalid %%e value"
 msgstr "valeur %%e invalide"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "valeur %%f invalide"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "valeur %%F invalide"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "valeur %%G invalide"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "valeur %%j invalide"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "valeur %%J invalide"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "valeur %%k invalide"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "valeur %%K invalide"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "valeur %%O invalide"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "valeur %%q invalide"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "valeur %%S invalide"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "valeur %%T invalide"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "valeur %%u invalide"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "valeur %%v invalide"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "valeur %%x invalide"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, fuzzy, c-format
 #| msgid "invalid punctuation `%c' in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ponctuation invalide « %c » dans la contrainte"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "trop peu d'arguments pour la fonction"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 #| msgid "Do not generate code for a Sun FPA"
 msgid "Could not generate addis value for fusion"
 msgstr "Ne pas générer le code pour un Sun FPA"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load offset for fusion"
@@ -3906,66 +3906,66 @@
 msgid "invalid operand to %%S"
 msgstr "opérande invalide pour %%S"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different architectures / ABIs"
 msgstr "créé et utilisé avec des configurations différentes de -fpic"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different ABIs"
 msgstr "créé et utilisé avec des configurations différentes de -fpic"
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different endianness"
 msgstr "créé et utilisé avec des configurations différentes de -fpic"
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "opérande %%Y invalide"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "opérande %%A invalide"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "Opérande %%B invalide"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, c-format
 msgid "invalid %%C operand"
 msgstr "opérande %%C invalide"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, c-format
 msgid "invalid %%D operand"
 msgstr "opérande %%D invalide"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "opérande %%f invalide"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "opérande %%s invalide"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "constante long long n'est pas une opérande immédiate valide"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "constante en virgule flottante n'est pas une opérande immédiate valide"
@@ -4170,7 +4170,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> attendu"
@@ -4186,15 +4186,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> attendu"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> attendu"
@@ -4216,8 +4216,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> attendu"
@@ -4224,8 +4224,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> attendu"
@@ -4234,13 +4234,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "%<;%>, %<,%> or %<)%> attendu"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> attendu"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> attendu"
@@ -4247,8 +4247,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> attendu"
@@ -4269,7 +4269,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> attendu"
@@ -4286,34 +4286,34 @@
 msgid "expected %<.%>"
 msgstr "%<.%> attendu"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> attendu"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> attendu"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> or %<)%> attendu"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> attendu"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> or %<}%> attendu"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> attendu"
@@ -4322,11 +4322,11 @@
 msgid "(anonymous)"
 msgstr "(anonyme)"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "candidat 1 :"
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "candidat 2 :"
 
@@ -4544,11 +4544,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "candidats sont :"
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "candidat est :"
@@ -4610,48 +4610,48 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "type d'argument erroné pour le moins unaire"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "type d'argument erroné pour le plus unaire"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "type d'argument erroné pour un complément de bit"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "type d'argument erroné pour abs"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "type d'argument erroné pour la conjugaison"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4754,7 +4754,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "débordement d'entier dans l'expression"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 msgid "array assignment"
 msgstr "affectation de tableau"
 
@@ -4784,7 +4784,7 @@
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4868,13 +4868,13 @@
 msgid "%s tag"
 msgstr "tag %s"
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4958,7 +4958,7 @@
 msgid "Bad type in constant expression"
 msgstr "débordement dans l'expression de la constante"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 msgid "Unexpected end of module"
 msgstr "Fin de module inattendue"
 
@@ -4986,11 +4986,11 @@
 msgid "implied END DO"
 msgstr "implique END DO"
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr "affectation"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 msgid "pointer assignment"
 msgstr "affectation de pointeur"
 
@@ -5006,217 +5006,217 @@
 msgid "internal function"
 msgstr "fonction interne"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 #, fuzzy
 #| msgid "too few arguments to procedure"
 msgid "elemental procedure"
 msgstr "trop peu d'arguments pour la procédure"
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "type d'argument invalide"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "pas d'argument"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "pas d'argument"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 #| msgid "no arguments"
 msgid "pointer argument"
 msgstr "pas d'argument"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 msgid "target argument"
 msgstr "argument cible"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 msgid "value argument"
 msgstr "argument valeur"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 msgid "volatile argument"
 msgstr "argument volatile"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-shape argument"
 msgstr "type d'argument invalide"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "pas d'argument"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 msgid "coarray argument"
 msgstr "argument co-tableau"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 #, fuzzy
 #| msgid "parameterized structures not implemented"
 msgid "parametrized derived type argument"
 msgstr "structure paramétrisée ne sont pas implantées"
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 msgid "polymorphic argument"
 msgstr "argument polymorphique"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 msgid "assumed-type argument"
 msgstr "argument assumed-type"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 #, fuzzy
 #| msgid "bit array slice with non-constant length"
 msgid "result with non-constant character length"
 msgstr "découpage de tableau de bits avec une longueur non constante"
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, fuzzy, c-format
 #| msgid "Invalid continuation line at %0"
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "ligne de continuation invalide à %0"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, fuzzy, c-format
 #| msgid "Invalid operand at %1 for concatenation operator at %0"
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Opérande invalide à %1 pour l'opérateur de concaténation à %0"
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 #, fuzzy
 #| msgid "`%V' qualifiers cannot be applied to `%T'"
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "qualificateur « %V » ne peut pas être appliqué à « %T »"
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr "Opérateur inconnu « %s » à %%L"
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr "Variable de boucle"
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 msgid "iterator variable"
 msgstr "Variable d'itérateur"
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 #, fuzzy
 #| msgid "SET expression not a location"
 msgid "Start expression in DO loop"
 msgstr "expression de l'ENSEMBLE n'est pas une localisation"
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 #, fuzzy
 #| msgid "SET expression not a location"
 msgid "End expression in DO loop"
 msgstr "expression de l'ENSEMBLE n'est pas une localisation"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 #, fuzzy
 #| msgid "SET expression not a location"
 msgid "Step expression in DO loop"
 msgstr "expression de l'ENSEMBLE n'est pas une localisation"
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 msgid "DEALLOCATE object"
 msgstr "objet DEALLOCATE"
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 msgid "ALLOCATE object"
 msgstr "object ALLOCATE"
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr "object STAT"
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr "élément dans READ"
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
@@ -5625,16 +5625,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr "le processeur rx200 n'a pas de d'unité matérielle FPU"
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr ""
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr ""
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr "ne supporte pas multilib"
@@ -5647,6 +5637,10 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "-Xbind-now et -Xbind-lazy sont incompatibles"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+msgid "profiling not supported with -mg"
+msgstr "profilage n'est pas supporté avec -mg"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "-mhard-float n'est pas supporté"
@@ -5657,10 +5651,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "-msingle-float et -msoft-float ne peuvent être spécifiés ensembles"
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr "Le m210 ne supporte pas le code pour système à octets de poids faible"
-
 #: config/cris/cris.h:184
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "ne peut spécifier à la fois -march=… et -mcpu=…"
@@ -5689,6 +5679,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr ""
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5695,6 +5691,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr "ne peut utiliser ensemble -m32 et -m64"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr ""
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr "static n'est pas supporté sur TPF-OS"
@@ -5707,6 +5707,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian et -mlittle-endian ne peuvent être utilisés ensemble"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr "Le m210 ne supporte pas le code pour système à octets de poids faible"
+
 #: config/avr/specs.h:68
 msgid "shared is not supported"
 msgstr "shared n'est pas supporté"
@@ -5734,17 +5738,19 @@
 msgid "no processor type specified for linking"
 msgstr "fichier de specs n'a pas de spécification pour l'édition de liens"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr ""
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr ""
 
@@ -5784,10 +5790,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "L'option -shared n'est pas couramment supportée pour VAS ELF."
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-msgid "profiling not supported with -mg"
-msgstr "profilage n'est pas supporté avec -mg"
-
 #: fortran/lang.opt:146
 msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgstr ""
@@ -5997,9 +5999,9 @@
 msgstr ""
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -6213,10 +6215,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -6262,7 +6264,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr "nom de fichier manquant après %qs"
@@ -8292,48 +8294,52 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr "Présumer que le processeur cible est un système à octets de poids faible"
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 #, fuzzy
 #| msgid "Specify the MCU name"
 msgid "Specify the code model"
 msgstr "Spécifier le nom du MCU"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr "Ne pas présumer que les accès non alignées sont traités par le système"
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr "Omettre le pointeur de trame dans les fonctions feuilles"
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr "Utiliser les options et ordonnancer le code pour le processeur donné"
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -9545,10 +9551,16 @@
 msgstr "Non supporté; affecte la génération de code des tableaux"
 
 #: config/i386/i386.opt:864
+#, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "Supporte les fonctions internes MMX et SSE et la génération de code"
+
+#: config/i386/i386.opt:868
 msgid "Use given stack-protector guard"
 msgstr ""
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr ""
 
@@ -9943,7 +9955,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -10102,7 +10114,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
@@ -10241,7 +10253,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr "Utiliser des stubs pour les prologues de fonction"
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr "Ne pas charger le registre PIC dans les prologue de fonction"
 
@@ -10594,339 +10606,341 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "Utiliser les instructions AltiVec"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr "Ne pas générer les instructions de mise à jour de chargement/stockage"
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr "Générer les instructions de mise à jour de chargement/stockage"
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 #, fuzzy
 #| msgid "Do not generate load/store multiple instructions"
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr "Ne pas générer les instructions multiples de chargement/stockage"
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 #, fuzzy
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "« __builtin_next_arg » appelé sans argument"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 #, fuzzy
 #| msgid "Do not schedule the start and end of the procedure"
 msgid "Schedule the start and end of the procedure"
 msgstr "Ne pas ordonnancer le début et la fin de la procédure"
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr "Retourner toutes les structures en mémoire (par défaut sur AIX)"
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr "Retourner les petites structures par les registres (par défaut sur SVR4)"
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 #, fuzzy
 #| msgid "Generate inline square root, optimize for throughput"
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr "Générer la racine carrée enligne, optimiser pour le débit"
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr "Ne pas placer les constantes en virgule flottante dans le TOC"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr "Placer les constantes en virgule flottante dans le TOC"
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "Ne pas placer les constantes symboles+décalages dans le TOC"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr "Placer les constantes symboles+décalages dans le TOC"
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr "Place tout dans le TOC régulier"
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 #, fuzzy
 #| msgid "Specify yes/no if VRSAVE instructions should be generated for AltiVec"
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr "Spécifier yes (pour oui)/ no (pour non) si les instruction VRSAVE doivent être générés pour ALtiVec"
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate isel instructions"
 msgstr "Générer des instructions « char »"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 msgid "Deprecated option.  Use -misel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate SPE SIMD instructions on E500"
 msgstr "Générer des instructions « char »"
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "Générer des instructions « char »"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 msgid "Deprecated option.  Use -mspe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "-mdebug=\tEnable debug output"
 msgstr "Autoriser la sortie lors de la mise au point"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 #, fuzzy
 #| msgid "Use AltiVec instructions"
 msgid "Use the AltiVec ABI extensions"
 msgstr "Utiliser les instructions AltiVec"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 #, fuzzy
 #| msgid "Do not use AltiVec instructions"
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "Ne pas utiliser les instructions AltiVec"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 msgid "Use the SPE ABI extensions"
 msgstr "Utiliser les extensions de l'ABI SPE"
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 msgid "Do not use the SPE ABI extensions"
 msgstr "Ne pas utiliser les extensions de l'ABI SPE"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 msgid "Use the ELFv1 ABI"
 msgstr "Utiliser l'ABI ELFv1"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 msgid "Use the ELFv2 ABI"
 msgstr "Utiliser l'ABI ELFv2"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 msgid "using darwin64 ABI"
 msgstr "utilisation de l'ABI darwin64"
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 msgid "using old darwin ABI"
 msgstr "utilisation de l'ancienne ABI darwin"
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr "Utiliser les options et ordonnancer le code pour le processeur donné"
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 #, fuzzy
 #| msgid "Schedule code for given CPU"
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "Ordonnancer le code pour le processeur donné"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 #, fuzzy
 #| msgid "Select full, part, or no traceback table"
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr "Sélectionner « full », « part » ou « none »"
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr "Éviter toutes les limites sur les instructions d'appel"
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 #, fuzzy
 #| msgid "Generate CA code"
 msgid "Generate Cell microcode"
 msgstr "Générer du code CA"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 #, fuzzy
 #| msgid "Warn when all constructors and destructors are private"
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "Avertir lorsque tous les constructeurs et destructeurs sont privés"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr "Avertir à propos de l'usage obsolète des types AltiVec 'vector long ...' "
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr "-mlong-double-<n>\tSpécifier la taille des long double (64 ou 128 bits)"
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr "Déterminer laquelle des dépendances entre les insns qui sont considérées coûteuses"
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr "Spécifier lequel schème de post ordonnancement d'insertion de NOP doit être appliqué"
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr "Spécifier l'alignement des champs de structure par défaut/naturel"
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 msgid "Valid arguments to -malign-:"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr "Spécifier la priorité d'ordonnancement pour la répartition de fentes insns restreintes"
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 #, fuzzy
 #| msgid "Quadruple-precision floating-point unsupported"
 msgid "Single-precision floating point unit"
 msgstr "virgule flottante en quadruple précision non supporté"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 #, fuzzy
 #| msgid "Quadruple-precision floating-point unsupported"
 msgid "Double-precision floating point unit"
 msgstr "virgule flottante en quadruple précision non supporté"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 msgid "Floating point unit does not support divide & sqrt"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 msgid "Specify Xilinx FPU."
 msgstr "Spécifier un FPU Xilinx."
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 #, fuzzy
 #| msgid "Align destination of the string operations"
 msgid "Allow sign extension in fusion operations"
 msgstr "Aligner la destination des opérations sur les chaînes"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
-msgid "Use ISA 2.07 crypto instructions"
+#: config/rs6000/rs6000.opt:566
+#, fuzzy
+#| msgid "Use ISA 2.07 crypto instructions"
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
 msgstr "Utiliser les instructions cryptographiques ISA 2.07"
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Générer des instructions « char »"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -14119,1743 +14133,1743 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr "-dumpdir <fichier>\tfixer le nom de base du fichier à utiliser pour les vidanges"
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "Aligner le début des fonctions"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr "Aligner les étiquettes qui sont seulement atteintes par sauts"
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr "Aligner toutes les étiquettes"
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "Aligner le début des boucles"
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr ""
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr "Cette option est obsolète; utiliser -Wextra à la place"
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr "Générer des tables étendues qui soient exactes pour chaque borne d'instruction"
 
-#: common.opt:918
+#: common.opt:921
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate auto-inc/dec instructions"
 msgstr "Générer des instructions « char »"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr "Utiliser les informations de profilage pour les probabilités de branchements"
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "Générer du code pour vérifier les bornes avant d'indexer les tableaux"
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr "Remplacer add,compare,branch avec des branchements utilisant un compteur registre"
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr "Utiliser les informations de profilage pour les probabilités de branchements"
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr "Effectuer l'optimisation du chargement du branchement cible avant le thread prologue / epilogue"
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr "Effectuer l'optimisation du chargement du branchement cible après le thread prologue / epilogue"
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr ""
 
-#: common.opt:960
+#: common.opt:963
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr "-fcall-saved-<registre>\tmarquer le <registre> comme étant préservé à travers les fonctions"
 
-#: common.opt:964
+#: common.opt:967
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr "-fcall-used-<registre>\tmarquer le <registre> comme étant corrompu par les appels de fonctions"
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr "Sauvegarder les registres autour des appels de fonction"
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr ""
 
-#: common.opt:979
+#: common.opt:982
 msgid "Check the return value of new in C++"
 msgstr "Vérifier la valeur retournée de new in C++"
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr "Ne pas placer de globaux non initialisés dans la section commune"
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr ""
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr ""
 
-#: common.opt:1003
+#: common.opt:1006
 #, fuzzy
 #| msgid "Reschedule instructions after register allocation"
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr "Réordonnancer les instructions après l'allocation de registres"
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr ""
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr "Effectuer la passe d'optimisation de la propagation-de-copie par registre"
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr "Exécuter des optimisations de sauts croisés"
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr "Lorsque CSE s'exécute, suivre les sauts vers leurs cibles"
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr ""
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr ""
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr "placer les items des données dans leur propre section"
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr ""
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr ""
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr "Déférer le dépilage des arguments de fonction de la pile plus tard"
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr "Tented de remplir de délais les fentes des instructions de branchement"
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr "Détruire les vérifications de pointeurs nul inutiles"
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization"
 msgstr "Exécuter la formation du super bloc via la duplication de la queue"
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1085
+#: common.opt:1088
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr "-fdiagnostics-show-location=[once|every-line]\tindiquer combien de fois les informations de localisation des sources doivent être produites au début d'un diagnostique lorsque les lignes doivent s'enrouler"
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1145
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr "-fdump-<type>\tvidander les divers internes du compilateur dans un fichier"
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr ""
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr ""
 
-#: common.opt:1157
+#: common.opt:1160
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps"
 msgstr "Supprimer dans la sortie les numéros d'instructions et de notes de lignes dans les vidanges de mises au point"
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 #, fuzzy
 #| msgid "Perform loop optimizations"
 msgid "Dump optimization passes"
 msgstr "Exécuter l'optimisation des boucles"
 
-#: common.opt:1170
+#: common.opt:1173
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr "Supprimer dans la sortie les numéros d'instructions et de notes de lignes dans les vidanges de mises au point"
 
-#: common.opt:1174
+#: common.opt:1177
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr "Supprimer dans la sortie les numéros d'instructions et de notes de lignes dans les vidanges de mises au point"
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1185
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform early inlining"
 msgstr "Exécuter des réductions de boucles"
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr "Exécuter une élimination DAWRF2 des doublons"
 
-#: common.opt:1190
+#: common.opt:1193
 msgid "Perform interprocedural reduction of aggregates"
 msgstr ""
 
-#: common.opt:1194
+#: common.opt:1197
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info"
 msgstr "Effectuer l'élimination des types non utilisés dans l'information de mise au point"
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr "Effectuer l'élimination des types non utilisés dans l'information de mise au point"
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "Autoriser le traitement des exceptions"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr "Effectuer un nombre mineur d'optimisations coûteuses"
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr ""
 
-#: common.opt:1217
+#: common.opt:1220
 #, fuzzy, c-format
 #| msgid "unknown string token %s\n"
 msgid "unknown excess precision style %qs"
 msgstr "élément lexical %s inconnu\n"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr "Assumer qu'aucun NaNs ou infinités ne soit généré"
 
-#: common.opt:1238
+#: common.opt:1241
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr "-ffixed-<registre>\tmarquer le <registre> comme n'étant plus disponible pour le compilateur"
 
-#: common.opt:1242
+#: common.opt:1245
 #, fuzzy
 #| msgid "Control allocation order of integer registers"
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr "Contrôle l'ordre d'allocation des registres entier"
 
-#: common.opt:1250
+#: common.opt:1253
 #, fuzzy
 #| msgid "Perform a register copy-propagation optimization pass"
 msgid "Perform a forward propagation pass on RTL"
 msgstr "Effectuer la passe d'optimisation de la propagation-de-copie par registre"
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, fuzzy, c-format
 #| msgid "Use hardware floating point instructions"
 msgid "unknown floating point contraction style %qs"
 msgstr "Utiliser les instructions matérielles en virgule flottante"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr "Autoriser le maintien des adresses de fonction dans les registres"
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr "placer chaque fonction dans sa propre section"
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr "Exécuter l'élimination de sous-expression commune globale"
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr "Exécuter un chargement amélioré lors de l'élimination de sous-expression commune globale"
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr "Exécuter un stockage après l'élimination de sous-expression commune globale"
 
-#: common.opt:1294
+#: common.opt:1297
 #, fuzzy
 #| msgid "Perform redundant load after store elimination in global common subexpression elimination"
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr "Exécuter un stockage redondant après l'élimination de sous-expression commune globale"
 
-#: common.opt:1299
+#: common.opt:1302
 #, fuzzy
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr "Exécuter l'élimination de sous-expression commune globale"
 
-#: common.opt:1305
+#: common.opt:1308
 #, fuzzy
 #| msgid "Enable automatic template instantiation"
 msgid "Enable in and out of Graphite representation"
 msgstr "Autoriser l'instantiation automatique de patron"
 
-#: common.opt:1309
+#: common.opt:1312
 #, fuzzy
 #| msgid "Emit call graph information"
 msgid "Enable Graphite Identity transformation"
 msgstr "Produire les informations du graphe d'appel"
 
-#: common.opt:1313
+#: common.opt:1316
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr ""
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr ""
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr ""
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr ""
 
-#: common.opt:1330
+#: common.opt:1333
 #, fuzzy
 #| msgid "Enable linker relaxation"
 msgid "Enable Loop Blocking transformation"
 msgstr "Autoriser la relâche par l'éditeur de liens"
 
-#: common.opt:1334
+#: common.opt:1337
 msgid "Enable Loop Unroll Jam transformation"
 msgstr ""
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr "Autoriser l'estimation des probabilités de branchement"
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr "Traiter les directive #ident"
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr "Exécuter la conversion des sauts conditionels à des équivalents sans branchements"
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr "Exécuter la conversion des sauts conditionnels à une exécution conditionnel"
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1394
+#: common.opt:1397
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr "Exécuter la conversion des sauts conditionels à des équivalents sans branchements"
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr ""
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr "Ne pas générer de directives .size"
 
-#: common.opt:1410
+#: common.opt:1413
 #, fuzzy
 #| msgid "recursive inlining"
 msgid "Perform indirect inlining"
 msgstr "enlignage récursif"
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 #, fuzzy
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "Intégrer les fonctions simples à l'intérieur des appelants"
 
-#: common.opt:1424
+#: common.opt:1427
 #, fuzzy
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "Intégrer les fonctions simples à l'intérieur des appelants"
 
-#: common.opt:1428
+#: common.opt:1431
 #, fuzzy
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions only required by their single caller"
 msgstr "Intégrer les fonctions simples à l'intérieur des appelants"
 
-#: common.opt:1435
+#: common.opt:1438
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr "-finline-limit=<nombre>\tlimiter la taille des fonction enligne à <nombre>"
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr "Traiter les entrées et les sorties des fonctions avec appels de profilage"
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1458
 #, fuzzy
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Perform interprocedural constant propagation"
 msgstr "Autoriser la propagation SSA de constante conditionnelle"
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1466
 #, fuzzy
 #| msgid "how much can given compilation unit grow because of the inlining (in percent)"
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr "quelle croissance d'une unité de compilation peut être tolérée en raison de l'enlignage (en pourcentage)"
 
-#: common.opt:1467
+#: common.opt:1470
 msgid "Perform interprocedural profile propagation"
 msgstr ""
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1478
 #, fuzzy
 #| msgid "Discard unused virtual functions"
 msgid "Discover pure and const functions"
 msgstr "Écarter les fonctions virtuelles non utilisées"
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables"
 msgstr "Exécuter la boucle par désenroulement de toutes les boucles"
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr ""
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr ""
 
-#: common.opt:1506
+#: common.opt:1509
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA algorithm %qs"
 msgstr "nom de registre inconnu: %s"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr ""
 
-#: common.opt:1519
+#: common.opt:1522
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA region %qs"
 msgstr "nom de registre inconnu: %s"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1545
 #, fuzzy
 #| msgid "Store locals in argument registers"
 msgid "Share slots for saving different hard registers."
 msgstr "Stocker les var. locales dans redistres d'arguments"
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1561
 #, fuzzy
 #| msgid "case label not within a switch statement"
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "étiquette de « case » en dehors de tout switch"
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr "Générer le code pour les fonctions même si elles sont complètement enligne"
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr "Produire des variables constantes statiques même si elles ne sont pas utilisées"
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr "Afficher les symboles externes préfixés d'un caractère de soulignement"
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable link-time optimization."
 msgstr "Activer les optimisations par l'éditeur de liens"
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown LTO partitioning model %qs"
 msgstr "mode machine « %s » inconnu"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr ""
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Report various link-time optimization statistics"
 msgstr "Effectuer une changement de nom de registres après une passe d'optimisation"
 
-#: common.opt:1625
+#: common.opt:1628
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr "Initialiser errno après les fonctions internes mathématiques"
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr "Rapporter l'allocation de mémoire permanente"
 
-#: common.opt:1641
+#: common.opt:1644
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only"
 msgstr "Rapporter l'allocation de mémoire permanente"
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr "Tentative de fusion de constantes identique et des variables constantes"
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr "Tentative de fusion de constantes identiques à travers des unités de compilation"
 
-#: common.opt:1656
+#: common.opt:1659
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr "Tentative de fusion de constantes identiques à travers des unités de compilation"
 
-#: common.opt:1660
+#: common.opt:1663
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr "-fmessage-length=<nombre>\tlimiter la longueur des diagnotiques à <nombre> de caractères par ligne.  0 supprime l'enroulement de ligne"
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1675
 #, fuzzy
 #| msgid "Force all loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops"
 msgstr "Forcer pour toutes les boucles des calculs invariants en dehors des boucles"
 
-#: common.opt:1676
+#: common.opt:1679
 #, fuzzy
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Use the RTL dead code elimination pass"
 msgstr "Autoriser l'élimination agressive SSA du code mort"
 
-#: common.opt:1680
+#: common.opt:1683
 #, fuzzy
 #| msgid "Do the full register move optimization pass"
 msgid "Use the RTL dead store elimination pass"
 msgstr "Effectuer la passe d'optimisation complète des déplacements par les registres"
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr "Supporter les exceptions synchrones des non appels"
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 #| msgid "target missing after %s"
 msgid "options or targets missing after %qs"
 msgstr "cible manquante après %s"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 #| msgid "unknown tls-model \"%s\""
 msgid "unknown offload ABI %qs"
 msgstr "tls-model  \"%s\" inconnu"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr "Lorsque c'est possible ne pas générer des trames de pile"
 
-#: common.opt:1713
+#: common.opt:1716
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable all optimization info dumps on stderr"
 msgstr "Activer les optimisations par l'éditeur de liens"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr "Optimiser sur mesure les appels enfants et récursif"
 
-#: common.opt:1729
+#: common.opt:1732
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform partial inlining"
 msgstr "Exécuter des réductions de boucles"
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr ""
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr "Empaqueter les membres des structures ensembles sans trous"
 
-#: common.opt:1745
+#: common.opt:1748
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr ""
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr "Retourner les petits agrégats en mémoire, pas dans les registres"
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr "Exécuter des réductions de boucles"
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr "Autoriser les optimisations des trous spécifiques à une machine"
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr "Autoriser l'exécution de la passe RTL avant sched2"
 
-#: common.opt:1765
+#: common.opt:1768
 #, fuzzy
 #| msgid "Generate position-independent code if possible"
 msgid "Generate position-independent code if possible (large mode)"
 msgstr "Générer du code indépendant de la position si possible"
 
-#: common.opt:1769
+#: common.opt:1772
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible"
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr "Générer du code indépendant de la position pour les exécutables si possible"
 
-#: common.opt:1773
+#: common.opt:1776
 #, fuzzy
 #| msgid "Generate position-independent code if possible"
 msgid "Generate position-independent code if possible (small mode)"
 msgstr "Générer du code indépendant de la position si possible"
 
-#: common.opt:1777
+#: common.opt:1780
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible"
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr "Générer du code indépendant de la position pour les exécutables si possible"
 
-#: common.opt:1781
+#: common.opt:1784
 msgid "Specify a plugin to load"
 msgstr ""
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr ""
 
-#: common.opt:1789
+#: common.opt:1792
 #, fuzzy
 #| msgid "Enables a register move optimization"
 msgid "Run predictive commoning optimization."
 msgstr "Autoriser l'optimisation des déplacements par registre"
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr "Générer des instructions prérecherchées, si disponible, pour les tableaux dans les boucles"
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr "Autoriser le code de profilage de base du programme"
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr "Insérer le code de profilage du programme de arc-based"
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1813
 #, fuzzy
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr "Autoriser la propagation SSA de constante conditionnelle"
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr "Autoriser les options communes pour la génération d'information de profile pour le feedback d'optimisation direct de profile"
 
-#: common.opt:1818
+#: common.opt:1821
 #, fuzzy
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Autoriser les options communes pour la génération d'information de profile pour le feedback d'optimisation direct de profile"
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr "Autoriser les options communes pour effectuer le feedback d'optimisation direct de profile"
 
-#: common.opt:1826
+#: common.opt:1829
 #, fuzzy
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Autoriser les options communes pour effectuer le feedback d'optimisation direct de profile"
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr "Insérer le code pour profile les expressions de valeurs"
 
-#: common.opt:1834
+#: common.opt:1837
 msgid "Report on consistency of profile"
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1841
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement"
 msgstr "Ré-ordonner les fonctions pour améliorer l'emplacement de code"
 
-#: common.opt:1845
+#: common.opt:1848
 #, fuzzy
 #| msgid "-frandom-seed=<string>\tMake compile reproducible using <string>"
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr "-frandom-seed=<chaîne>\tfaire une compilation reproduisible en utilisant <chaîne>"
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr "Retourner les petits agrégats dans les registres"
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr ""
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr "Effectuer une changement de nom de registres après une passe d'optimisation"
 
-#: common.opt:1880
+#: common.opt:1883
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr "Effectuer une changement de nom de registres après une passe d'optimisation"
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr "Ré-ordonner les blocs de base pour améliorer l'emplacement de code"
 
-#: common.opt:1888
+#: common.opt:1891
 #, fuzzy
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr "Ré-ordonner les blocs de base pour améliorer l'emplacement de code"
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr "Ré-ordonner les fonctions pour améliorer l'emplacement de code"
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr "Ajouter une passe d'élimination d'une sous-expression commune après les optimisations de boucle"
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr "Interdire les optimisation qui assument un comportement d'arrondissement FP par défaut"
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr "Autoriser l'ordonnancement à travers les blocs de base"
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr "Autoriser le mouvement spéculatif de non chargements"
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr "Autoriser le mouvement spéculatif de quelques chargements"
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr "Autoriser le mouvement spéculatif de plusieurs chargements"
 
-#: common.opt:1928
+#: common.opt:1931
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr "-fsched-verbose=<numéro>\tnitialiser le niveau de verbosité de l'ordonnanceur"
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr "Si l'ordonnancement fait une post recharge, faire un ordonnancement de super bloc"
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr "Réordonnancer les instructions avant l'allocation de registres"
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr "Réordonnancer les instructions après l'allocation de registres"
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr ""
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr ""
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr ""
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr "Autoriser l'ordonnancement prématuré de queues insns"
 
-#: common.opt:1981
+#: common.opt:1984
 #, fuzzy
 #| msgid "-fsched-stalled-insns=<number>       Set number of queued insns that can be prematurely scheduled"
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr "-fsched-stalled-insns=<nombre>       fixer le nombre d'insns en queu qui peuvent être prématurément ordonnancés"
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr "Fixer la distance de vérification de dépendance dans l'ordonnancement prématuré d'insns en queue"
 
-#: common.opt:1993
+#: common.opt:1996
 #, fuzzy
 #| msgid "-fsched-stalled-insns-dep=<number>   Set dependence distance checking in premature scheduling of queued insns"
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr "-fsched-stalled-insns-dep=<nombre>   fixer la distance de vérification de dépendance dans l'ordonnancement d'insnsn en queue"
 
-#: common.opt:1997
+#: common.opt:2000
 msgid "Enable the group heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2009
+#: common.opt:2012
 msgid "Enable the rank heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr ""
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr ""
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr "Désactiver les optimisations observable par le signalement NaNs IEEE"
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr ""
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr "Convertir les constantes en virgules flottantes en constantes de simple précision"
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr ""
 
-#: common.opt:2062
+#: common.opt:2065
 #, fuzzy
 #| msgid "Generate APCS conformant stack frames"
 msgid "Generate discontiguous stack frames"
 msgstr "Générer des trames de pile conformes à APCS"
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr ""
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 #, fuzzy
 #| msgid "Number of registers used to pass integer arguments"
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr "Nombre de registres utilisés pour passer les arguments entiers"
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr ""
 
-#: common.opt:2082
+#: common.opt:2085
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "Insérer du code de vérificaion de la pile dans le programme"
 
-#: common.opt:2086
+#: common.opt:2089
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "Insérer du code de vérificaion de la pile dans le programme"
 
-#: common.opt:2093
+#: common.opt:2096
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr "-fstack-limit-register=<registre>\tfaire un déroutement si la pile va au delà du <registre>"
 
-#: common.opt:2097
+#: common.opt:2100
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr "-fstack-limit-symbol=<nom>\tfaire un déroutement si la pile va au delà du symbole <nom>"
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr ""
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr ""
 
-#: common.opt:2109
+#: common.opt:2112
 msgid "Use a smart stack protection method for certain functions"
 msgstr ""
 
-#: common.opt:2113
+#: common.opt:2116
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr ""
 
-#: common.opt:2117
+#: common.opt:2120
 #, fuzzy
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output stack usage information on a per-function basis"
 msgstr "Ré-utiliser R30 sur une base par fonction"
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr "Présumer que des règles stricts d'alias s'appliquent"
 
-#: common.opt:2133
+#: common.opt:2136
 #, fuzzy
 #| msgid "Treat missing header files as generated files"
 msgid "Treat signed overflow as undefined"
 msgstr "Traiter les en-têtes manquantes de fichiers comme des fichiers générés"
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr "Vérifier les erreurs de syntaxes et puis stopper"
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr "Créer les fichiers de données nécessaires à \"gcov\""
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr "Exécuter des optimisations de sauts de thread"
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr "Rapporter le temps pris par chaque passe de compilation"
 
-#: common.opt:2157
+#: common.opt:2160
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tinitialiser le modèle de génération de code par défaut de thread local"
 
-#: common.opt:2160
+#: common.opt:2163
 #, fuzzy, c-format
 #| msgid "unknown tls-model \"%s\""
 msgid "unknown TLS model %qs"
 msgstr "tls-model  \"%s\" inconnu"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr "Exécuter la formation du super bloc via la duplication de la queue"
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr "On assume que les opérations en virgule flottante peuvent être attrappées"
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr "Attrapper les débordements de signe dans l'addition, la soustraction et la multiplication"
 
-#: common.opt:2195
+#: common.opt:2198
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-CCP optimization on trees"
 msgstr "Autoriser les optimisations SSA"
 
-#: common.opt:2199
+#: common.opt:2202
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr "Autoriser les optimisations SSA"
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr ""
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr ""
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr ""
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr ""
 
-#: common.opt:2231
+#: common.opt:2234
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Transform condition stores into unconditional ones"
 msgstr "Exécuter la conversion des sauts conditionnels à une exécution conditionnel"
 
-#: common.opt:2235
+#: common.opt:2238
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversions of switch initializations."
 msgstr "Exécuter la conversion des sauts conditionnels à une exécution conditionnel"
 
-#: common.opt:2239
+#: common.opt:2242
 #, fuzzy
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr "Autoriser l'élimination agressive SSA du code mort"
 
-#: common.opt:2243
+#: common.opt:2246
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable dominator optimizations"
 msgstr "Activer les optimisations par l'éditeur de liens"
 
-#: common.opt:2247
+#: common.opt:2250
 #, fuzzy
 #| msgid "Enable most warning messages"
 msgid "Enable tail merging on trees"
 msgstr "Autoriser la plupart des messages d'avertissement"
 
-#: common.opt:2251
+#: common.opt:2254
 #, fuzzy
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Enable dead store elimination"
 msgstr "Autoriser l'élimination agressive SSA du code mort"
 
-#: common.opt:2255
+#: common.opt:2258
 msgid "Enable forward propagation on trees"
 msgstr ""
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr ""
 
-#: common.opt:2263
+#: common.opt:2266
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable string length optimizations on trees"
 msgstr "Activer les optimisations par l'éditeur de liens"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 #, fuzzy
 #| msgid "Enable parallel instructions"
 msgid "Enable loop distribution on trees"
 msgstr "Autoriser les instructions parallèles"
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr ""
 
-#: common.opt:2288
+#: common.opt:2291
 #, fuzzy
 #| msgid "Force all loop invariant computations out of loops"
 msgid "Enable loop invariant motion on trees"
 msgstr "Forcer pour toutes les boucles des calculs invariants en dehors des boucles"
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr ""
 
-#: common.opt:2296
+#: common.opt:2299
 #, fuzzy
 #| msgid "Strength reduce all loop general induction variables"
 msgid "Create canonical induction variables in loops"
 msgstr "Renforcer la réduction de toutes les boucles par induction des variables"
 
-#: common.opt:2300
+#: common.opt:2303
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable loop optimizations on tree level"
 msgstr "Activer les optimisations par l'éditeur de liens"
 
-#: common.opt:2304
+#: common.opt:2307
 #, fuzzy
 #| msgid "Enable automatic template instantiation"
 msgid "Enable automatic parallelization of loops"
 msgstr "Autoriser l'instantiation automatique de patron"
 
-#: common.opt:2308
+#: common.opt:2311
 #, fuzzy
 #| msgid "Enable use of conditional move instructions"
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Autoriser l'utilisation des instructions conditionnelles move"
 
-#: common.opt:2312
+#: common.opt:2315
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "Autoriser les optimisations SSA"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2324
+#: common.opt:2327
 msgid "Enable reassociation on tree level"
 msgstr ""
 
-#: common.opt:2332
+#: common.opt:2335
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA code sinking on trees"
 msgstr "Autoriser les optimisations SSA"
 
-#: common.opt:2336
+#: common.opt:2339
 #, fuzzy
 #| msgid "Perform strength reduction optimizations"
 msgid "Perform straight-line strength reduction"
 msgstr "Exécuter un réduction en force des optimisations"
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr ""
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2352
+#: common.opt:2355
 #, fuzzy
 #| msgid "Perform a register copy-propagation optimization pass"
 msgid "Perform Value Range Propagation on trees"
 msgstr "Effectuer la passe d'optimisation de la propagation-de-copie par registre"
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr "Compiler complètement à la fois une unité de compilation"
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr "Exécuter un dé-roulement des boucles lorsque le compteur d'itération est connu"
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr "Exécuter la boucle par désenroulement de toutes les boucles"
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr ""
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr "Permettre les optimisations mathématiques qui peuvent violer les standards IEEE ou ISO"
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr "Exécuter des boucles sans branchement"
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr "Générer simplement des tables étendues pour le traitement des exceptions"
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2416
+#: common.opt:2419
 #, fuzzy
 #| msgid "Perform tail call optimization"
 msgid "Perform variable tracking"
 msgstr "Effectuer une optimisation sur mesure des appels"
 
-#: common.opt:2424
+#: common.opt:2427
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform variable tracking by annotating assignments"
 msgstr "Effectuer une changement de nom de registres après une passe d'optimisation"
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr ""
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr ""
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 #| msgid "Enable traditional preprocessing"
 msgid "Enable vectorization on trees"
 msgstr "Autoriser le traitement traditionnel"
 
-#: common.opt:2450
+#: common.opt:2453
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable loop vectorization on trees"
 msgstr "Activer les optimisations par l'éditeur de liens"
 
-#: common.opt:2454
+#: common.opt:2457
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr ""
 
-#: common.opt:2458
+#: common.opt:2461
 #, fuzzy
 #| msgid "Specify alternate name for bss section"
 msgid "Specifies the cost model for vectorization"
 msgstr "Spécifier un nom alternatif pour la section bss"
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown vectorizer cost model %qs"
 msgstr "mode machine « %s » inconnu"
 
-#: common.opt:2478
+#: common.opt:2481
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2485
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2493
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr "Ajouter des commentaires additionnels à la sortie de l'assembleur"
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr ""
 
-#: common.opt:2507
+#: common.opt:2510
 #, fuzzy, c-format
 #| msgid "unrecognized register name \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "nom de registre non reconnue \"%s\""
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 #| msgid "(near initialization for `%s')"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(près de l'initialisation de « %s »)"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr "Utiliser le profile de la valeur d'expression dans l'optimisation"
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr "Construire une toile et séparer les utilisations de variables simples"
 
-#: common.opt:2555
+#: common.opt:2558
 #, fuzzy
 #| msgid "Enable use of conditional move instructions"
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr "Autoriser l'utilisation des instructions conditionnelles move"
 
-#: common.opt:2559
+#: common.opt:2562
 #, fuzzy
 #| msgid "Perform loop optimizations"
 msgid "Perform whole program optimizations"
 msgstr "Exécuter l'optimisation des boucles"
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr "Assumer un débordement arithmétique signé enroulé"
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr "Placer des données initialisées de zéros dans la section bss"
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr "Générer les informations de mise au point dans le format par défaut"
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr "Générer les informations de mise au point dans le format COFF"
 
-#: common.opt:2579
+#: common.opt:2582
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format"
 msgstr "Générer les informations de mise au point dans le format par défaut"
 
-#: common.opt:2583
+#: common.opt:2586
 #, fuzzy
 #| msgid "Generate debug information in DWARF v2 format"
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr "Générer les informations de mise au point dans le format DWARF v2"
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr "Générer les informations de mise au point dans le format étendu par défaut"
 
-#: common.opt:2591
+#: common.opt:2594
 #, fuzzy
 #| msgid "Don't generate fused multiply/add instructions"
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Ne pas générer des instructions fusionnés de multiplication/addition"
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2614
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Don't generate debug information in separate .dwo files"
 msgstr "Générer les informations de mise au point dans le format par défaut"
 
-#: common.opt:2615
+#: common.opt:2618
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files"
 msgstr "Générer les informations de mise au point dans le format par défaut"
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr "Générer les informations de mise au point dans le format STABS"
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr "Générer les informations de mise au point dans le format étendu STABS"
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2638
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation"
 msgstr "Générer les informations de mise au point dans le format VMS"
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr "Générer les informations de mise au point dans le format VMS"
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr "Générer les information de mise au point dans le format XCOFF"
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr "Générer les informations de mise au point dans le format étendu XCOFF"
 
-#: common.opt:2665
+#: common.opt:2668
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate compressed debug sections"
 msgstr "Générer des instructions « char »"
 
-#: common.opt:2669
+#: common.opt:2672
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr "Générer les informations de mise au point dans le format par défaut"
 
-#: common.opt:2676
+#: common.opt:2679
 #, fuzzy
 #| msgid "-isysroot <dir>\tSet <dir> to be the system root directory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr "-isysroot <répertoire>\tsélectionner le <répertoire> comme répertoire racine du système"
 
-#: common.opt:2680
+#: common.opt:2683
 #, fuzzy
 #| msgid "-isysroot <dir>\tSet <dir> to be the system root directory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr "-isysroot <répertoire>\tsélectionner le <répertoire> comme répertoire racine du système"
 
-#: common.opt:2702
+#: common.opt:2705
 msgid "-o <file>\tPlace output into <file>"
 msgstr "-o <fichier>\tproduire la sortie dans le <fichier>"
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr "Autoriser le profilage de fonction"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr "Identique à -pedantic mais les marque comme des erreurs"
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr "Ne pas afficher les fonctions compilées ou le temps écoulé"
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr "Autoriser le mode bavard sur la sortie"
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr "Afficher la version du compilateur"
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "Supprimer les avertissements"
 
-#: common.opt:2806
+#: common.opt:2809
 #, fuzzy
 #| msgid "Enable ID based shared library"
 msgid "Create a shared library"
 msgstr "Autoriser les identificateurs de librairies partagées de base"
 
-#: common.opt:2851
+#: common.opt:2854
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible"
 msgid "Create a position independent executable"
 msgstr "Générer du code indépendant de la position pour les exécutables si possible"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, fuzzy, gcc-internal-format
 #| msgid "%Hvalue computed is not used"
 msgid "value computed is not used"
@@ -15896,301 +15910,301 @@
 msgid "expected integer or boolean type"
 msgstr "attendait une autre clause de changement de nom"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 #, fuzzy
 #| msgid "comparison of promoted ~unsigned with unsigned"
 msgid "invalid comparison of nil with nil"
 msgstr "comparaison entre élément promu ~unsigned et un élément non signé"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 #, fuzzy
 #| msgid "incompatible modes in concat expression"
 msgid "incompatible types in binary expression"
 msgstr "modes incompatibles dans l'expression de concaténation"
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 #| msgid "division by zero"
 msgid "integer division by zero"
 msgstr "division par zéro"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 msgid "shift of non-integer operand"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 #, fuzzy
 #| msgid "switch quantity not an integer"
 msgid "shift count not unsigned integer"
 msgstr "quantité du switch n'est pas un entier"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 #, fuzzy
 #| msgid "negative string length"
 msgid "negative shift count"
 msgstr "longueur négative de chaîne"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 #, fuzzy
 #| msgid "called object is not a function"
 msgid "object is not a method"
 msgstr "l'objet appelé n'est pas une fonction"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 #, fuzzy
 #| msgid "cast does not match function type"
 msgid "method type does not match object type"
 msgstr "le transtypage ne concorde pas avec le type de la fonction"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 #, fuzzy
 #| msgid "invalid use of `this' in non-member function"
 msgid "invalid use of %<...%> with builtin function"
 msgstr "utilisation invalide de « ceci » dans un non membre de fonction"
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 #, fuzzy
 #| msgid "invalid type argument of `%s'"
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "type d'argument invalide pour « %s »"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 #, fuzzy
 #| msgid "no arguments"
 msgid "not enough arguments"
 msgstr "pas d'argument"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 #, fuzzy
 #| msgid "too many arguments for format"
 msgid "too many arguments"
 msgstr "trop d'arguments pour le format"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 #, fuzzy
 #| msgid "argument %d must be referable"
 msgid "argument 1 must be a map"
 msgstr "argument %d doit pouvoir être référencé"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 #, fuzzy
 #| msgid "invalid return type for member function `%#D'"
 msgid "invalid type for make function"
 msgstr "type retourné invalide pour le membre de la fonction « %#D »"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 #, fuzzy
 #| msgid "too many arguments to process"
 msgid "too many arguments to make"
 msgstr "trop d'arguments à traiter"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 #, fuzzy
 #| msgid "UPPER argument must be string, array, mode or integer"
 msgid "argument must be array or slice or channel"
 msgstr "argument du HAUT doit être une chaîne, un tableau, un mode ou un entier"
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 #, fuzzy
 #| msgid "UPPER argument must be string, array, mode or integer"
 msgid "argument must be string or array or slice or map or channel"
 msgstr "argument du HAUT doit être une chaîne, un tableau, un mode ou un entier"
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 #, fuzzy
 #| msgid "unimplemented built-in function `%s'"
 msgid "unsupported argument type to builtin function"
 msgstr "fonction interne non implantée « %s »"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 #, fuzzy
 #| msgid "argument %d must be referable"
 msgid "argument must be channel"
 msgstr "argument %d doit pouvoir être référencé"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 #, fuzzy
 #| msgid "argument %d must be referable"
 msgid "argument must be a field reference"
 msgstr "argument %d doit pouvoir être référencé"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 #, fuzzy
 #| msgid "first argument to `%s' must be a mode"
 msgid "left argument must be a slice"
 msgstr "premier argument de « %s » doit être un mode"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 #, fuzzy
 #| msgid "first argument to `%s' must be a mode"
 msgid "first argument must be []byte"
 msgstr "premier argument de « %s » doit être un mode"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 #, fuzzy
 #| msgid "ABS argument must be discrete or real mode"
 msgid "second argument must be slice or string"
 msgstr "argument ABS doit être en mode discret ou réel"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 #, fuzzy
 #| msgid "bit-field `%s' has invalid type"
 msgid "argument 2 has invalid type"
 msgstr "le champ de bits « %s » a un type invalide"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 #, fuzzy
 #| msgid "parameter `%s' has incomplete type"
 msgid "argument must have complex type"
 msgstr "le paramètre « %s » a un type incomplet"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 #, fuzzy
 #| msgid "macro names must be identifiers"
 msgid "complex arguments must have identical types"
 msgstr "les noms de macro doivent être des identificateurs"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 #, fuzzy
 #| msgid "argument 1 to `%s' must be of floating point mode"
 msgid "complex arguments must have floating-point type"
 msgstr "argument 1 de « %s » doit être en mode virgule flottante"
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 #, fuzzy
 #| msgid "In function"
 msgid "expected function"
 msgstr "Dans la fonction"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 msgid "multiple-value argument in single-value context"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 #, fuzzy
 #| msgid "invalid use of non-lvalue array"
 msgid "invalid use of %<...%> with non-slice"
 msgstr "utilisation invalide d'un tableau n'étant pas membre gauche"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 msgid "function result count mismatch"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 #, fuzzy
 #| msgid "incompatible types in %s"
 msgid "incompatible type for receiver"
 msgstr "type incompatibles dans %s"
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 #, fuzzy
 #| msgid "invalid use of `this' in non-member function"
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "utilisation invalide de « ceci » dans un non membre de fonction"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 #, fuzzy
 #| msgid "number of CASE selectors does not match the number of CASE label lists"
 msgid "number of results does not match number of values"
 msgstr "nombre de sélecteurs de CASE ne concorde pas avec la liste des étiquettes du CASE"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 #, fuzzy
 #| msgid "PROCESS copy number must be integer"
 msgid "index must be integer"
 msgstr "processus de copie de nombres doit être entier"
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 #, fuzzy
 #| msgid "PROCESS copy number must be integer"
 msgid "slice end must be integer"
 msgstr "processus de copie de nombres doit être entier"
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 #| msgid "switch quantity not an integer"
 msgid "slice capacity must be integer"
 msgstr "quantité du switch n'est pas un entier"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 #, fuzzy
 #| msgid "%s is not addressable"
 msgid "slice of unaddressable value"
 msgstr "%s n'est pas adressable"
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 #, fuzzy
 #| msgid "incompatible types in %s"
 msgid "incompatible type for map index"
 msgstr "type incompatibles dans %s"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 #, fuzzy
 #| msgid "too many index expressions"
 msgid "too many expressions for struct"
 msgstr "trop d'expressions d'index"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 #, fuzzy
 #| msgid "too few arguments for format"
 msgid "too few expressions for struct"
 msgstr "trop peu d'arguments dans le format"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 #, fuzzy
 #| msgid "Invalid interface type"
 msgid "type assertion only valid for interface types"
 msgstr "Type d'interface invalide"
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 #, fuzzy
 #| msgid "unexpected operand"
 msgid "expected channel"
 msgstr "opérande inattendue"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -16324,87 +16338,87 @@
 msgid "cannot use type %s as type %s"
 msgstr "ne peut convertir type « %T » vers le type « %T »"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 #, fuzzy
 #| msgid "different type"
 msgid "different receiver types"
 msgstr "type différent"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 #, fuzzy
 #| msgid "destructors take no parameters"
 msgid "different number of parameters"
 msgstr "destructeurs ne prend aucun paramètre"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 #, fuzzy
 #| msgid "different type"
 msgid "different parameter types"
 msgstr "type différent"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 #, fuzzy
 #| msgid "different type"
 msgid "different varargs"
 msgstr "type différent"
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 #, fuzzy
 #| msgid "different type"
 msgid "different result types"
 msgstr "type différent"
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "incompatible type for method %s%s%s"
 msgstr "type incompatible pour l'argument n°%d de « %s »"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "type incompatible pour l'argument n°%d de « %s »"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 #, fuzzy
 #| msgid "error while parsing methods"
 msgid "type has no methods"
 msgstr "erreur lors de l'analyse syntaxique des méthodes"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, fuzzy, c-format
 #| msgid "ambiguous abbreviation %s"
 msgid "ambiguous method %s%s%s"
 msgstr "abréviation %s est ambiguë"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, fuzzy, c-format
 #| msgid "missing argument to \"%s\""
 msgid "missing method %s%s%s"
 msgstr "argument manquant à \"%s\""
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -16539,7 +16553,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "troisième argument invalide de « __builtin_prefetch »; utilisation de zéro"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `va_start'"
 msgid "too few arguments to function %<va_start%>"
@@ -16740,12 +16754,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "l'appel de fonction a une valeur d'agrégat"
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "Pass all arguments on stack"
 msgid "passing too large argument on stack"
@@ -17369,247 +17383,252 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "nombre de bb noté dans la chaîne d'insn (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "caller edge count is negative"
 msgstr "le compteur de décalage vers la gauche est négatif"
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr ""
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr ""
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "no field (yet) for tag %s"
 msgid "aux field set for edge %s->%s"
 msgstr "pas de champ (encore) pour l'étiquette %s"
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "execution count is negative"
 msgstr "le compteur de décalage vers la gauche est négatif"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, fuzzy, gcc-internal-format
 #| msgid "no symbol table found"
 msgid "local symbols must be defined"
 msgstr "aucune table des symboles trouvée"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, fuzzy, gcc-internal-format
 #| msgid "section pointer missing"
 msgid "inlined_to pointer is wrong"
 msgstr "pointeur de section manquant"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple inline callers"
 msgstr "spécificateurs « virtual » multiples"
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer to bit-field `%D'"
 msgid "inlined_to pointer refers to itself"
 msgstr "pointeur invalide pour un champ de bits « %D »"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, fuzzy, gcc-internal-format
 #| msgid "range mode has non-constant limits"
 msgid "cgraph_node has wrong clone list"
 msgstr "mode d'étendue a des limites non contantes"
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare references to references"
 msgid "Wrong node is referenced with chkp reference"
 msgstr "ne peut décalrer des références vers des références"
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' used prior to declaration"
 msgid "edge points to wrong declaration:"
 msgstr "« %s » utilisé avant sa déclaration"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, fuzzy, gcc-internal-format
 #| msgid "verify_flow_info failed"
 msgid "verify_cgraph_node failed"
@@ -17616,7 +17635,7 @@
 msgstr "verify_flow_info a échoué"
 
 # FIXME
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "string section missing"
 msgid "%s: section %s is missing"
@@ -17761,7 +17780,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, gcc-internal-format
 msgid "atexit failed"
@@ -18024,13 +18043,13 @@
 msgid "          %s"
 msgstr "        « %D »"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr ""
 
 # FIXME
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "global destructors not supported on this target"
@@ -18037,7 +18056,7 @@
 msgstr "les limites de la pile ne sont pas supportées sur cette cible"
 
 # FIXME
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "global constructors not supported on this target"
@@ -18089,12 +18108,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -18308,7 +18327,7 @@
 msgid "total size of local objects too large"
 msgstr "la taille du tableau « %s » est trop grande"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, fuzzy, gcc-internal-format
 #| msgid "impossible constraint in `asm'"
 msgid "impossible constraint in %<asm%>"
@@ -18803,9 +18822,9 @@
 msgstr "ne peut écrire dans le fichier PCH"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared here"
@@ -18822,167 +18841,162 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr "vérification de l'arbre: attendait %s, obtenu %s dans %s, à %s:%d"
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "using result of function returning %<void%>"
 msgstr "« return » manquant dans une fonction devant retourner une valeur"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "invalid lvalue in asm output %d"
 msgstr "membre gauche invalide avec asm"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "output number %d not directly addressable"
 msgid "memory input %d is not directly addressable"
 msgstr "nombre de sortie %d n,est pas directement adressable"
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "variable de registre « %s » utilisée dans une fonction imbriquée"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "variable de registre « %s » utilisée dans une fonction imbriquée"
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr ""
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "instance de la variable « %s » est déclaré privée"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should be private"
 msgstr "instance de la variable « %s » est déclaré privée"
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qE should not be reduction"
 msgstr "variable de registre « %s » utilisée dans une fonction imbriquée"
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "instance de la variable « %s » est déclaré privée"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should not be private"
 msgstr "instance de la variable « %s » est déclaré privée"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, fuzzy, gcc-internal-format
 #| msgid "local variable `%D' may not appear in this context"
 msgid "%s variable %qE is private in outer context"
 msgstr "variable locale « %D » ne peut apparaître dans ce contexte"
 
-#: gimplify.c:7001
-#, gcc-internal-format
-msgid "lastprivate variable %qE is private in outer context"
-msgstr ""
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not yet implemented"
 msgid "directive not yet implemented"
 msgstr "trampolines ne sont pas encore implantées"
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr ""
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to `va_arg' not of type `va_list'"
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "premier argument de « va_arg » n'est pas de type « va_list »"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is promoted to `%s' when passed through `...'"
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "« %s » a été promu à « %s » lors du passage à travers « ... »"
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "(so you should pass `%s' not `%s' to `va_arg')"
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(vous devriez donc passer « %s » et non « %s » à « va_arg »)"
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "si ce code est atteint, le programme s'arrêtera"
@@ -19413,49 +19427,49 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class `%s'"
 msgid "cannot find LTO cgraph in %s"
 msgstr "ne peut repérer la classe « %s »"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find source file %s"
 msgid "cannot find LTO section refs in %s"
 msgstr "impossible de trouver le fichier source %s"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -19544,45 +19558,45 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "pas de fichier à l'entrée"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 #| msgid "%s:error writing output file `%s'\n"
 msgid "writing output file"
 msgstr "%s: ERREUR d'écriture dans le fichier de sortie « %s ».\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "variable d'environment DJGPP non définie"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
@@ -19589,7 +19603,7 @@
 msgstr "variable d'environment DJGPP non définie"
 
 # I18N
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen: %s: %m"
@@ -19730,12 +19744,12 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr ""
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "invalid entry to %s structured block"
@@ -19742,18 +19756,18 @@
 msgstr "type d'argument invalide pour l'attribut « %s »"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring pragma: %s"
 msgid "ignoring large linear step"
 msgstr "pragma: %s ignoré"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -20314,8 +20328,8 @@
 msgstr "ne peut utiliser « %s » comme le registre %s"
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "nom de registre inconnu: %s"
@@ -20800,7 +20814,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld a retourné %d code d'état d'exécution"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' used but never defined"
 msgid "%q+F used but never defined"
@@ -21886,43 +21900,43 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr "-fdata-sections n'est pas supporté pour cette machine cible"
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -22338,52 +22352,52 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript is outside array bounds"
 msgstr "l'indice du tableau n'est pas un entier"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript is above array bounds"
 msgstr "l'indice du tableau n'est pas un entier"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript is below array bounds"
 msgstr "l'indice du tableau n'est pas un entier"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr ""
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr ""
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, fuzzy, gcc-internal-format
 #| msgid "comparison is always false due to limited range of data type"
 msgid "comparison always false due to limited range of data type"
 msgstr "comparaison est toujours fausse en raison d'une gamme limitée de type de données"
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, fuzzy, gcc-internal-format
 #| msgid "comparison is always true due to limited range of data type"
 msgid "comparison always true due to limited range of data type"
 msgstr "comparaison est toujours vraie en raison d'une gamme limitée de type de données"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr ""
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr ""
@@ -22431,9 +22445,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
@@ -22695,7 +22709,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "requête d'alignement pour '%D' est plus grand que l'alignement implanté de %d"
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't known"
 msgid "storage size of %q+D isn%'t known"
@@ -22862,27 +22876,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "longueur de la chaîne « %d » plus grande que la longueur « %d » que les compilateurs ISO C%d doivent supporter"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "le compteur de décalage vers la gauche est négatif"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "le compteur de décalage vers la droite est négatif"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "compteur de décalage vers la gauche >= à la largeur du type"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "compteur de décalage vers la droite >= à la largeur du type"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "débordement dans l'expression de la constante"
@@ -23239,12 +23253,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "l'adresse de « %D » sera toujours évaluée comme étant « true »"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "parenthèses suggérées autour de l'affectation utilisée comme valeur de vérité"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of %<restrict%>"
@@ -23759,12 +23773,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "type de vecteur invalide pour l'attribut « %s »"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr ""
@@ -23774,24 +23788,24 @@
 msgid "number of components of the vector not a power of two"
 msgstr ""
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "attribut non nul sans argument sur un non-prototype"
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nonnull argument has invalid operand number (arg %lu)"
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "un argument non nul a un nombre d'opérande invalide (argument %lu)"
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nonnull argument with out-of-range operand number (arg %lu, operand %lu)"
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "un argument non nul a un nombre d'opérande hors des bornes (arg %lu, opérande %lu)"
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nonnull argument references non-pointer operand (arg %lu, operand %lu)"
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
@@ -23839,13 +23853,13 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "attribut « %s » s'applique seulement aux fonctions"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested position is not an integer constant"
 msgstr "init_priority demandé n'est pas une constante entière"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
@@ -23934,7 +23948,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, fuzzy, gcc-internal-format
 #| msgid "attempt to take address of bit-field structure member `%D'"
 msgid "attempt to take address of bit-field structure member %qD"
@@ -24409,7 +24423,7 @@
 msgstr "numéro de l'accumulateur est hors limite"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
@@ -24907,7 +24921,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid type-declaration attribute at %0"
 msgid "invalid type for iteration variable %qE"
@@ -24919,25 +24933,25 @@
 msgid "%qE is not initialized"
 msgstr "initialisation manquante"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, fuzzy, gcc-internal-format
 #| msgid "missing '(' after predicate"
 msgid "missing controlling predicate"
 msgstr "« ( » manquante après le prédicat"
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid controlling predicate"
 msgstr "Expression de contrôle invalide"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, fuzzy, gcc-internal-format
 #| msgid "missing index expression"
 msgid "missing increment expression"
 msgstr "expresion d'index manquante"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid increment expression"
@@ -25531,6 +25545,12 @@
 msgid "too many input files"
 msgstr "trop de fichiers d'entrée"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+#| msgid "stack frame too big"
+msgid "-mcpu string too large"
+msgstr "trame de pile trop grande"
+
 #: common/config/alpha/alpha-common.c:76
 #, fuzzy, gcc-internal-format
 #| msgid "bad value `%s' for -mtls-size switch"
@@ -25560,49 +25580,49 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops est obsolète, utiliser -falign-loops"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d n'est pas entre 0 et %d"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps est obsolète, utiliser -falign-loops"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-jumps=%d is not between 1 and %d"
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d n'est pas entre 1 et %d"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions est obsolète, utiliser -falign-loops"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-functions=%d is not between 1 and %d"
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d n'est pas entre 1 et %d"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d n'est pas entre 0 et 5"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -26025,69 +26045,69 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr "numéro de ligne hors limite"
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, fuzzy, gcc-internal-format
 #| msgid "bad value `%s' for -mtrap-precision switch"
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "valeur « %s » erronée pour l'option -mtrap-precision"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, fuzzy, gcc-internal-format
 #| msgid "bad value `%s' for -mfp-rounding-mode switch"
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "valeur « %s » erronée pour l'option -mfp-rounding-mode"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, fuzzy, gcc-internal-format
 #| msgid "bad value `%s' for -mfp-trap-mode switch"
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "valeur « %s » erronée pour l'option -mfp-trap-mode"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, fuzzy, gcc-internal-format
 #| msgid "bad value `%s' for -mcpu switch"
 msgid "bad value %qs for -mcpu switch"
 msgstr "valeur « %s » erronée pour l'option -mcpu"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for -mtune switch"
 msgstr "valeur erronée (%s) pour l'option -mtune="
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr "complétion logicielle FP requiert -mtrap-precision=i"
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "mode d'arrondissement n'est pas supporté pour les flottants sur VAX"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "mode trappe n'est pas supporté avec les flottants sur VAX"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr "long double de 128 bits ne sont pas supporté pour les flottants sur VAX"
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr "latence de la cache L%d inconnue pour %s"
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, fuzzy, gcc-internal-format
 #| msgid "bad value `%s' for -mmemory-latency"
 msgid "bad value %qs for -mmemory-latency"
 msgstr "valeur « %s » erronée pour -mmemory-latency"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -26580,14 +26600,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
@@ -27285,413 +27305,430 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "ne peut obtenir la position dans le fichier PCH: %m"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "error in args to spec function `%s'"
 msgid "wrong arg %s to option %s"
 msgstr "ERREUR d'arguments pour la spécification de fonction « %s »"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "return type specified for `operator %T'"
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "type spécifié retourné pour l'opérateur « %T »"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "return type specified for `operator %T'"
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr "type spécifié retourné pour l'opérateur « %T »"
+
+#: config/i386/i386.c:3012
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Tune alignment for the specified chip or CPU version"
 msgid "unknown alignment %s specified for option %s"
 msgstr "Ajuster l'alignement pour la version de processeur ou de circuit spécifiée"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "no class name specified with \"%s\""
 msgid "too many size ranges specified in option %s"
 msgstr "aucun nom de classe spécifié avec \"%s\""
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown cpu used in -mtune=%s."
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "Processeur inconnu dans -mtune=%s"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "code model `%s' not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "model de code « %s » n'est pas supporté dans le mode %s bits"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, fuzzy, gcc-internal-format
 #| msgid "code model `%s' not supported in the %s bit mode"
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "model de code « %s » n'est pas supporté dans le mode %s bits"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "model de code %s n'est pas supporté en mode PIC"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
 msgstr "model de code %s n'est pas supporté en mode PIC"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s n'est pas supporté par cette configuration"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "mode %i bits pas compilé en"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "le processeur sélectionné ne supporte pas le jeu d'instructions x86-64"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support APCS-32"
 msgid "Intel MPX does not support x32"
 msgstr "le processeur cible ne supporte pas APCS-32"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "valeur erronée (%s) pour l'option -march="
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "bad value (%s) for -tune= switch"
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "valeur erronée (%s) pour l'option -tune="
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d n'est pas entre 0 et %d"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-arrays n'est pas supporté pour cette machine cible"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d n'est pas entre %d et 12"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d n'est pas entre %d et 12"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-march=%s n'est pas compatible avec l'ABI sélectionné"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "jeu d'instructions SSE désactivé, arithmétique 387 est utilisé"
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "jeu d'instructions 387 désactivé, arithmétique SSE est utilisé"
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, fuzzy, gcc-internal-format
 #| msgid "mode of SYN incompatible with value"
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "mode de SYN incompatible avec la valeur"
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown cpu: -mcpu=%s"
 msgid "unknown option for -mrecip=%s"
 msgstr "Processeur inconnu : -mcpu=%s"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %<target%> argument not a string"
 msgstr "l'attribut « %s » de l'argument n'est pas une contante chaîne"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "les attributs fastcall et regparm ne sont pas compatibles"
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "les attributs fastcall et stdcall ne sont pas compatibles"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "l'attribut « %s » requiert un argument de type constante entière"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "l'argument pour l'attribut « %s » est plus grand que %d"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "les attributs fastcall et stdcall ne sont pas compatibles"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "les attributs fastcall et stdcall ne sont pas compatibles"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "les attributs fastcall et stdcall ne sont pas compatibles"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "les attributs fastcall et stdcall ne sont pas compatibles"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "les attributs fastcall et stdcall ne sont pas compatibles"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "les attributs fastcall et stdcall ne sont pas compatibles"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "les attributs fastcall et stdcall ne sont pas compatibles"
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "%qE attribute is used for non-class method"
 msgstr "attribut « %s » ignoré pour « %s »"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5923
-#, gcc-internal-format
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr ""
-
-#: config/i386/i386.c:6210
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "ne supporte pas multilib"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "-march=%s n'est pas compatible avec l'ABI sélectionné"
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "l'argument vecteur SSE sans autorisation MXX modifie l'ABI "
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "SSE vector return without SSE enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "vecteur SSE retourné sans autorisation SSE des changements de l'ABI "
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "l'argument vecteur SSE sans autorisation MXX modifie l'ABI "
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "SSE vector return without SSE enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "vecteur SSE retourné sans autorisation SSE des changements de l'ABI "
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "l'argument vecteur SSE sans autorisation SSE modifie l'ABI "
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "vecteur SSE retourné sans autorisation SSE des changements de l'ABI "
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "l'argument vecteur SSE sans autorisation MXX modifie l'ABI "
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "l'argument vecteur SSE sans autorisation MXX modifie l'ABI "
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, fuzzy, gcc-internal-format
 #| msgid "SSE vector return without SSE enabled changes the ABI"
 msgid "SSE register return with SSE disabled"
 msgstr "vecteur SSE retourné sans autorisation SSE des changements de l'ABI "
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, fuzzy, gcc-internal-format
 #| msgid "SSE vector argument without SSE enabled changes the ABI"
 msgid "SSE register argument with SSE disabled"
 msgstr "l'argument vecteur SSE sans autorisation SSE modifie l'ABI "
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, gcc-internal-format
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
 #, gcc-internal-format
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:11378
+#, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -27698,286 +27735,286 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, fuzzy, gcc-internal-format
 #| msgid "-mips%d does not support 64 bit fp registers"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-mips%d ne supporte pas les registres FP de 64 bits"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "registres étendus n'a pas de demis hauts"
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "taille d'opérande non supportée pour un registre étendu"
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No case for %s"
 msgid "No dispatcher found for %s"
 msgstr "Oas de case pour %s"
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "expression limitant la pile n'est pas supportée"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%D'"
 msgid "previous declaration of %D"
 msgstr "déclaration précédente de « %D »"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "le profilage n'est pas supporté sur cette cible"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 #| msgid "argument to dss must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "argument de dss doit être un littéral non signé de 2 bits"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "décalage doit être un immédiat"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "argument 3 doit être un littéral non signé de 4 bits"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "troisième argument de « __builtin_prefetch » doit être une constante"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "insn incoorect:"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect rounding operand"
 msgstr "insn incoorect:"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "argument 3 doit être un littéral non signé de 4 bits"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%i"
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "le sélecteur doit être une constante entière entre les bornes 0..%i"
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option %s"
 msgid "%qE needs isa option %s"
 msgstr "option invalide %s"
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "masque doit être un immédiat"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "insn incoorect:"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "attribut « %s » s'applique seulement aux variables"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argument de l'attribut « %s » n'est pas une chaîne de constante"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "les attributs fastcall et stdcall ne sont pas compatibles"
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "attribut « %s » incompatible ignoré"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %d"
 msgstr "version non reconnue"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "arguments inutilisés dans le format de style $"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -28079,13 +28116,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "l'attribut « %s » requiert un argument de type constante entière"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr "valeur de -mfixed-range doit avoir la forme REG1-REG2"
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -28165,7 +28202,7 @@
 msgstr "attributs de section ne sont pas supportés pour la cible"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "%qE attribute argument not an integer constant"
@@ -28235,7 +28272,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "expression limitant la pile n'est pas supportée"
@@ -29160,16 +29197,11 @@
 msgid "-g option disabled"
 msgstr "option -g désactivée"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr ""
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, fuzzy, gcc-internal-format
@@ -29445,343 +29477,348 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them."
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "Ne peut retourner la valeur dans le registre de vecteur parce que les instructions altivec sont désactivées, utiliser -maltivec pour les autoriser"
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them."
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "Ne peut relayer l'argument dans le registre de vecteur parce que les instructions altivec sont désactivées, utiliser -maltivec pour les autoriser"
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "internal error - bad built-in function `%s'"
 msgid "internal error: builtin function %s already processed"
 msgstr "erreur interne - mauvaise fonction interne « %s »"
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argument 1 doit être un littéral signé de 5 bits"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argument 2 doit être un littéral non signé de 5 bits"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "argument 1 de « __builtin_altivec_predicate » doit être une constante"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "argument 1 de « __builtin_altivec_predicate » est hors limite"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
+#, gcc-internal-format, gfc-internal-format
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "argument 2 doit être un littéral non signé de 5 bits"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argument 1 de « __builtin_spe_predicate » est hors limite"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argument 3 doit être un littéral non signé de 4 bits"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argument 3 doit être un littéral non signé de 4 bits"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argument 3 doit être un littéral non signé de 4 bits"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "le nombre doit être 0 ou 1"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argument 2 doit être un littéral non signé de 5 bits"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argument 2 doit être un littéral non signé de 5 bits"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "le nombre doit être 0 ou 1"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d must be referable"
 msgid "argument 3 must be in the range 0..15"
 msgstr "argument %d doit pouvoir être référencé"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' must be a 2-bit unsigned literal"
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argument de « %s » doit être un littéral non signé de 2 bits"
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "argument de dss doit être un littéral non signé de 2 bits"
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "argument 1 de « __builtin_spe_predicate » doit être une constante"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "argument 1 de « __builtin_spe_predicate » est hors limite"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "argument 1 de « __builtin_spe_predicate » doit être une constante"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "argument 1 de « __builtin_spe_predicate » est hors limite"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "l'option -ifile requiert l'option -map"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "l'option -ifile requiert l'option -map"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "l'option -ifile requiert l'option -map"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "l'option -ifile requiert l'option -map"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mspe option"
 msgstr "l'option -ifile requiert l'option -map"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "l'option -ifile requiert l'option -map"
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "l'option -ifile requiert l'option -map"
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "l'option -ifile requiert l'option -map"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "inline functions not supported for this return value type"
 msgid "Builtin function %s is not supported with the current options"
 msgstr "fonctions enligne ne peuvent pas être supportées pour ce type de valeur retournée"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "internal error - bad built-in function `%s'"
 msgid "internal error: builtin function %s had no type"
 msgstr "erreur interne - mauvaise fonction interne « %s »"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "internal error - bad built-in function `%s'"
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "erreur interne - mauvaise fonction interne « %s »"
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, fuzzy, gcc-internal-format
 #| msgid "stack frame too big"
 msgid "stack frame too large"
 msgstr "trame de pile trop grande"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "pas de profilage du code de 64 bits pour cet ABI"
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, fuzzy, gcc-internal-format
 #| msgid "use of 'long' in AltiVec types is deprecated; use 'int'"
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "utilisation du type 'long' Altivec est obsolète; utilisez 'int'"
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, fuzzy, gcc-internal-format
 #| msgid "use of 'long' in AltiVec types is deprecated; use 'int'"
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "utilisation du type 'long' Altivec est obsolète; utilisez 'int'"
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, fuzzy, gcc-internal-format
 #| msgid "use of 'long' in AltiVec types is deprecated; use 'int'"
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "utilisation du type 'long' Altivec est obsolète; utilisez 'int'"
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, fuzzy, gcc-internal-format
 #| msgid "use of 'long' in AltiVec types is deprecated; use 'int'"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "utilisation du type 'long' Altivec est obsolète; utilisez 'int'"
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, fuzzy, gcc-internal-format
 #| msgid "use of 'long' in AltiVec types is deprecated; use 'int'"
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "utilisation du type 'long' Altivec est obsolète; utilisez 'int'"
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, fuzzy, gcc-internal-format
 #| msgid "use of 'long' in AltiVec types is deprecated; use 'int'"
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "utilisation du type 'long' Altivec est obsolète; utilisez 'int'"
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid use of %D"
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "utilisation invalide de %D"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%s\"%s\"%s is not allowed"
 msgstr "« %s » n'est pas défini"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr ""
@@ -30040,97 +30077,97 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, fuzzy, gcc-internal-format
 #| msgid "Total size of local variables exceeds architecture limit."
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Taille totale des variables locales excède la limite de l'architecture"
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsize of '%D' is %d bytes"
 msgid "frame size of %qs is %wd bytes"
 msgstr "taille de « %D » est de %d octets"
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argument de \"%s\" doit être un entier non négatif"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "l'argument pour l'attribut « %s » est plus grand que %d"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "z/Architecture mode not supported on %s."
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/mode d'architecture n'est pas supporté sur %s"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode."
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "ABI 64 bits n'est pas supporté en mode ESA/390"
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Utiliser les instructions matérielles en virgule flottante"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, fuzzy, gcc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Utiliser les instructions matérielles en virgule flottante"
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, fuzzy, gcc-internal-format
 #| msgid "text length must be greater than 0"
 msgid "stack size must not be greater than 64k"
 msgstr "la longueur de texte doit être plus grande que 0"
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
@@ -30145,35 +30182,35 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr ""
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "__builtin_saveregs n'est pas supporté par la sous-cible"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to interrupt functions"
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "attribut « %s » s'applique seulement à des fonctions d'interruption"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute is not supported on this platform"
 msgid "%qE attribute is supported only for SH2A"
 msgstr "attribut « %s » n'est pas supporté sur cette plate-forme"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr "attribut interrupt_handler n'est pas compatible avec -m5-compact"
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qE attribute only applies to SH2A"
 msgstr "attribut « %s » s'applique seulement aux fonctions"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "%qE attribute argument should be between 0 to 255"
@@ -30180,24 +30217,24 @@
 msgstr "l'attribut « %s » de l'argument n'est pas une contante entière"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "%qE attribute argument not a string constant"
 msgstr "l'attribut « %s » de l'argument n'est pas une contante chaîne"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr ""
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, fuzzy, gcc-internal-format
 #| msgid "Use the BK register as a general purpose register"
 msgid "need a second call-clobbered general purpose register"
 msgstr "Utiliser le registre BK comme registre général tout usage"
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr ""
@@ -30609,50 +30646,50 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid element type for attribute %qs"
 msgstr "type de vecteur invalide pour l'attribut « %s »"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "number of arguments doesn't match prototype"
 msgid "number of components of vector not a power of two"
 msgstr "le nombre d'arguments ne concorde pas avec celui du prototype"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qs attribute ignored"
 msgstr "attribut « %s » ignoré"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "l'attribut « %s » requiert un argument de type constante entière"
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qs attribute only applies to variadic functions"
 msgstr "attribut « %s » s'applique seulement aux fonctions"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, fuzzy, gcc-internal-format
 #| msgid "%s has no effect"
 msgid "%qE attribute has no effect"
 msgstr "%s n'a pas d'effet"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "attribute %qs applies to array types only"
 msgstr "attribut « %s » s'applique seulement aux variables"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument `%s'"
@@ -30714,7 +30751,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "valeur void n'a pas été ignorée comme elle aurait dû l'être"
@@ -30745,72 +30782,72 @@
 msgid "GCC supports only %u nested scopes"
 msgstr ""
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "label %q+D used but not defined"
 msgstr "étiquette « %D » utilisée mais non définie"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, fuzzy, gcc-internal-format
 #| msgid "inline function `%D' used but never defined"
 msgid "nested function %q+D declared but never defined"
 msgstr "fonction enligne « %D » utilisé mais n'a jamais été défini"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, fuzzy, gcc-internal-format
 #| msgid "inline function `%D' used but never defined"
 msgid "inline function %q+D declared but never defined"
 msgstr "fonction enligne « %D » utilisé mais n'a jamais été défini"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, fuzzy, gcc-internal-format
 #| msgid "%Junused variable `%D'"
 msgid "unused variable %q+D"
 msgstr "variable inutilisée « %D »"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "variable %qD set but not used"
 msgstr "étiquette « %D » définie mais non utilisée"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "originally defined here"
 msgstr "  définition originale apparaît ici"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can't match an empty parameter name list declaration"
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr "un paramètre de la liste avec une ellipse ne peut concorder une déclaration vide de liste de noms de paramètres"
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, fuzzy, gcc-internal-format
 #| msgid "an argument type that has a default promotion can't match an empty parameter name list declaration"
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr "un type d'argument ayant une promotion par défaut ne peut concorder avec une déclaration vide de noms de paramètres"
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprototype for '%D' declares more arguments than previous old-style definition"
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "prototype pour « %D » déclare plus d'arguments que la définition précédente de style ancien"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprototype for '%D' declares fewer arguments than previous old-style definition"
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "prototype pour « %D » déclare moins d'arguments que la définition précédente de style ancien"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprototype for '%D' declares arg %d with incompatible type"
 msgid "prototype for %q+D declares argument %d with incompatible type"
@@ -30818,49 +30855,49 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprototype for '%D' follows non-prototype definition"
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "prototype pour « %D » suit la définition d'un non prototype"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition of '%D' was here"
 msgid "previous definition of %q+D was here"
 msgstr "définition précédente de « %D » était ici"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious implicit declaration of '%D' was here"
 msgid "previous implicit declaration of %q+D was here"
 msgstr "déclaration précédente implicite de « %D » était ici"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious declaration of '%D' was here"
 msgid "previous declaration of %q+D was here"
 msgstr "déclaration précédente de « %D » était ici"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' redeclared as different kind of symbol"
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "« %#D » redéclaré comme une sorte différente de symbole"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbuilt-in function '%D' declared as non-function"
 msgid "built-in function %q+D declared as non-function"
 msgstr "fonction interne « %D » n'est pas déclarée comme une fonction"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of '%D' shadows a global declaration"
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "déclaration de « %D » masque une déclaration globale"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of `enum %s'"
 msgid "redeclaration of enumerator %q+D"
@@ -30869,177 +30906,177 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, fuzzy, gcc-internal-format
 #| msgid "%Jconflicting types for built-in function '%D'"
 msgid "conflicting types for built-in function %q+D"
 msgstr "types conflictuels pour la fonction interne « %D »"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, fuzzy, gcc-internal-format
 #| msgid "%Jconflicting types for '%D'"
 msgid "conflicting types for %q+D"
 msgstr "types conflictuels pour « %D »"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, fuzzy, gcc-internal-format
 #| msgid "%Jconflicting types for '%D'"
 msgid "conflicting type qualifiers for %q+D"
 msgstr "types conflictuels pour « %D »"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, fuzzy, gcc-internal-format
 #| msgid "%Jredefinition of typedef '%D'"
 msgid "redefinition of typedef %q+D with different type"
 msgstr "redéfinition de « %D »"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, fuzzy, gcc-internal-format
 #| msgid "%Jredefinition of typedef '%D'"
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "redéfinition de « %D »"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, fuzzy, gcc-internal-format
 #| msgid "%Jredefinition of typedef '%D'"
 msgid "redefinition of typedef %q+D"
 msgstr "redéfinition de « %D »"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, fuzzy, gcc-internal-format
 #| msgid "%Jredefinition of '%D'"
 msgid "redefinition of %q+D"
 msgstr "redéfinition de « %D »"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, fuzzy, gcc-internal-format
 #| msgid "%Jstatic declaration of '%D' follows non-static declaration"
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "déclaration statique de « %D » suit une déclaration non statique"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, fuzzy, gcc-internal-format
 #| msgid "%Jnon-static declaration of '%D' follows static declaration"
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "déclaration non statique de « %D » suite une déclaration statique"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr ""
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, fuzzy, gcc-internal-format
 #| msgid "  from here"
 msgid "but not here"
 msgstr "  à partir d'ici"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, fuzzy, gcc-internal-format
 #| msgid "%Jthread-local declaration of '%D' follows non-thread-local declaration"
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "déclaration de thread local de « %D » suit une déclaration non thread-local"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, fuzzy, gcc-internal-format
 #| msgid "%Jnon-thread-local declaration of '%D' follows thread-local declaration"
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "déclaration non thread local de « %D » suit une déclaration de thread local"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, fuzzy, gcc-internal-format
 #| msgid "%Jextern declaration of '%D' follows declaration with no linkage"
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "déclaration externe de « %D » suit une déclaraion sans lien"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdeclaration of '%D' with no linkage follows extern declaration"
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "déclaration de « %D » sans lien suivant une déclaration externe"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, fuzzy, gcc-internal-format
 #| msgid "%Jredeclaration of '%D' with no linkage"
 msgid "redeclaration of %q+D with no linkage"
 msgstr "redéclaration de « %D » sans lien"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, fuzzy, gcc-internal-format
 #| msgid "%Jredeclaration of '%D' with different visibility (old visibility preserved)"
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr "redéclaration de « %D » avec une visibilité différente (visibilité précédente conservée)"
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinline declaration of '%D' follows declaration with attribute noinline"
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "déclaration enligne de « %D » suit la déclaration avec un attribut non enligne"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdeclaration of '%D' with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "éclaration de « %D » avec un attribut non enligne suit une déclaration enligne"
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdeclaration of '%D' with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "éclaration de « %D » avec un attribut non enligne suit une déclaration enligne"
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, fuzzy, gcc-internal-format
 #| msgid "%Jredefinition of parameter '%D'"
 msgid "redefinition of parameter %q+D"
 msgstr "redéfinition du paramètre « %D »"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, fuzzy, gcc-internal-format
 #| msgid "%Jredundant redeclaration of '%D'"
 msgid "redundant redeclaration of %q+D"
 msgstr "déclaration redondante de « %D »"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of '%D' shadows a previous local"
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "déclaration de « %D » masque la déclaration d'un local précédent"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of '%#D' shadows a parameter"
 msgid "declaration of %q+D shadows a parameter"
 msgstr "déclaration de « %#D » masque un paramètre"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of '%D' shadows a global declaration"
 msgid "declaration of %qD shadows a global declaration"
 msgstr "déclaration de « %D » masque une déclaration globale"
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of '%D' shadows a previous local"
 msgid "declaration of %q+D shadows a previous local"
 msgstr "déclaration de « %D » masque la déclaration d'un local précédent"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
@@ -31046,79 +31083,79 @@
 msgid "shadowed declaration is here"
 msgstr "déclaration est masquée ici"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, fuzzy, gcc-internal-format
 #| msgid "nested extern declaration of `%s'"
 msgid "nested extern declaration of %qD"
 msgstr "déclaration de « %s » externe imbriquée"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%s'"
 msgid "implicit declaration of function %qE"
 msgstr "déclaration implicite de la fonction « %s »"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "déclaration implicite de la fonction « %#D »"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "redéclaration invalide de « %D »"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "incompatible implicit declaration of function %qD"
 msgstr "déclaration implicite de la fonction « %#D »"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function)"
 msgstr "« %s » non déclaré ici (hors de toute fonction)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function)"
 msgstr "« %s » non déclaré (première utilisation dans cette fonction)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, fuzzy, gcc-internal-format
 #| msgid "(Each undeclared identifier is reported only once for each function it appears in.)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Chaque identificateur non déclaré est rapporté seulement une seule fois pour la fonction dans laquelle il apparaît.)"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, fuzzy, gcc-internal-format
 #| msgid "label %s referenced outside of any function"
 msgid "label %qE referenced outside of any function"
 msgstr "étiquette %s référencée à l'extérieur de toute fonction"
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is a variably modified type"
 msgid "jump into scope of identifier with variably modified type"
 msgstr "« %T » est type modifié de manière variable"
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, fuzzy, gcc-internal-format
 #| msgid "Missing variable initializer"
 msgid "jump skips variable initialization"
 msgstr "Initialiseur de variable manquant"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "label %qD defined here"
 msgstr "étiquette « %D » définie mais non utilisée"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
@@ -31125,142 +31162,142 @@
 msgid "%qD declared here"
 msgstr "  « %#D » déclaré ici"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant expression"
 msgid "jump into statement expression"
 msgstr "expression n'est pas une constante"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "duplicate label declaration %qE"
 msgstr "déclaration de l'étiquette « %s » en double"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%D'"
 msgid "duplicate label %qD"
 msgstr "étiquette « %D » apparaît en double"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, fuzzy, gcc-internal-format
 #| msgid "%Htraditional C lacks a separate namespace for labels, identifier `%s' conflicts"
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "%HC traditionnel manque d'un espace nom séparé pour les étiquettes, identificateur « %D » est en conflit"
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, fuzzy, gcc-internal-format
 #| msgid "Missing variable initializer"
 msgid "switch jumps over variable initialization"
 msgstr "Initialiseur de variable manquant"
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, fuzzy, gcc-internal-format
 #| msgid "index is not an integer expression"
 msgid "switch jumps into statement expression"
 msgstr "index n'est pas une expression entière"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, fuzzy, gcc-internal-format
 #| msgid "%H`%s' defined as wrong kind of tag"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%H« %s » défini incorrectement comme une mauvais sorte d'étiquette"
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "struct/union sans nom ne définissant aucune instance"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifier in array declarator"
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "spécificateur de classe de stockage dans le déclarateur de tableau"
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "déclaration ne déclarant rien du tout"
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "déclaration ne déclarant rien du tout"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, fuzzy, gcc-internal-format
 #| msgid "useless keyword or type name in empty declaration"
 msgid "useless type name in empty declaration"
 msgstr "mot clé ou nom de type inutile dans une déclaration vide"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "%<inline%> in empty declaration"
 msgstr "déclaration vide"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "déclaration vide"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, fuzzy, gcc-internal-format
 #| msgid "two types specified in one empty declaration"
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "deux types spécifiés dans une déclaration vide"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, fuzzy, gcc-internal-format
 #| msgid "two types specified in one empty declaration"
 msgid "%<register%> in file-scope empty declaration"
 msgstr "deux types spécifiés dans une déclaration vide"
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifier in array declarator"
 msgid "useless storage class specifier in empty declaration"
 msgstr "spécificateur de classe de stockage dans le déclarateur de tableau"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "useless keyword or type name in empty declaration"
 msgid "useless %qs in empty declaration"
 msgstr "mot clé ou nom de type inutile dans une déclaration vide"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate type qualifiers in %s declaration"
 msgid "useless type qualifier in empty declaration"
 msgstr "qualificateurs de types dupliqués dans déclaration %s"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 #| msgid "useless keyword or type name in empty declaration"
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "mot clé ou nom de type inutile dans une déclaration vide"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "déclaration vide"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `static' or type qualifiers in parameter array declarators"
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 ne supporte pas « static » ou les qualificateurs de type dans les déclarateurs de tableau de paramètres"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `[*]' array declarators"
 msgid "ISO C90 does not support %<[*]%> array declarators"
@@ -31269,34 +31306,34 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%D' is usually a function"
 msgid "%q+D is usually a function"
 msgstr "« %D » est habituellement une fonction"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, fuzzy, gcc-internal-format
 #| msgid "typedef `%D' is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "typedef « %D » est initialisé (use __typeof__ instead)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, fuzzy, gcc-internal-format
 #| msgid "function `%#D' is initialized like a variable"
 msgid "function %qD is initialized like a variable"
@@ -31303,7 +31340,7 @@
 msgstr "fonction « %#D » est initialisée comme une variable"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%s' is initialized"
 msgid "parameter %qD is initialized"
@@ -31313,301 +31350,301 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "un objet de taille variable peut ne pas être initialisé"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "variable `%#D' has initializer but incomplete type"
 msgid "variable %qD has initializer but incomplete type"
 msgstr "la variable « %#D » est initialisée, mais a un type incomplet"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinline function '%D' given attribute noinline"
 msgid "inline function %q+D given attribute noinline"
 msgstr " fonction enligne « %D » a reçu l'attribut non enligne"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member `%D'"
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "membre de constante non initialisé pour « %D »"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' will be initialized after"
 msgid "%qD should be initialized"
 msgstr "« %D » sera initialisé après"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of `%D'"
 msgid "initializer fails to determine size of %q+D"
 msgstr "l'initialisation n'a pu déterminer la taille de « %D »"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %q+D"
 msgstr "taille de tableau manquante dans « %D »"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, fuzzy, gcc-internal-format
 #| msgid "%Jzero or negative size array '%D'"
 msgid "zero or negative size array %q+D"
 msgstr "tableau « %D » de taille zéro ou négative"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't constant"
 msgid "storage size of %q+D isn%'t constant"
 msgstr "taille de stockage de « %D » n'est pas une constante"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, fuzzy, gcc-internal-format
 #| msgid "%Jignoring asm-specifier for non-static local variable '%D'"
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "spécificateur asm ignoré pour la variable locale non statique « %D »"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "impossible de mettre un objet avec un champ volatile dans un registre"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const `%D'"
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "constante « %D » non initialisée"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C interdit la déclaration anticipée de paramètres"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' width not an integer constant"
 msgid "bit-field %qs width not an integer constant"
 msgstr "la largeur du champ de bits « %s » n'est pas une constante entière"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' width not an integer constant"
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "la largeur du champ de bits « %s » n'est pas une constante entière"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, fuzzy, gcc-internal-format
 #| msgid "negative width in bit-field `%s'"
 msgid "negative width in bit-field %qs"
 msgstr "largeur négative du champ de bits « %s »"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, fuzzy, gcc-internal-format
 #| msgid "zero width for bit-field `%s'"
 msgid "zero width for bit-field %qs"
 msgstr "largeur nulle pour le champ de bits « %s »"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qs has invalid type"
 msgstr "le champ de bits « %s » a un type invalide"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, fuzzy, gcc-internal-format
 #| msgid "type of bit-field `%s' is a GCC extension"
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "le type de champ de bit « %s » est une extension GCC"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, fuzzy, gcc-internal-format
 #| msgid "width of `%s' exceeds its type"
 msgid "width of %qs exceeds its type"
 msgstr "la largeur de « %s » excède son type"
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is narrower than values of its type"
 msgid "%qs is narrower than values of its type"
 msgstr "« %s » est plus étroit que les valeurs de son type"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array `%s' whose size can't be evaluated"
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 interdit le tableau « %s » dont la taille ne peut être évaluée"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array `%s' whose size can't be evaluated"
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 interdit le tableau « %s » dont la taille ne peut être évaluée"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 interdit le tableau « %s » de taille variable"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C++ interdit le tableau de taille variable"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is a variably modified type"
 msgid "variably modified %qE at file scope"
 msgstr "« %T » est type modifié de manière variable"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is a variably modified type"
 msgid "variably modified field at file scope"
 msgstr "« %T » est type modifié de manière variable"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "dans la déclaration de « %s », utilisation de « int » par défaut pour le type"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "type defaults to %<int%> in type name"
 msgstr "dans la déclaration de « %s », utilisation de « int » par défaut pour le type"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `const'"
 msgid "duplicate %<const%>"
 msgstr "« const » apparaît en double"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<restrict%>"
 msgstr "« restrict » apparaît en double"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate %<volatile%>"
 msgstr "« volatile » apparaît en double"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<_Atomic%>"
 msgstr "« restrict » apparaît en double"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting super class name `%s'"
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "nom de super classe « %s » est conflictuel"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `auto'"
 msgid "function definition declared %<auto%>"
 msgstr "définition de fonction déclaré « auto »"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `register'"
 msgid "function definition declared %<register%>"
 msgstr "définition de fonction déclarée « register »"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `typedef'"
 msgid "function definition declared %<typedef%>"
 msgstr "définition de fonction déclarée « typedef »"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `auto'"
 msgid "function definition declared %qs"
 msgstr "définition de fonction déclaré « auto »"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "storage class specified for structure field %qE"
 msgstr "classe de stockage spécifiée pour le champ de structure « %s »"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "storage class specified for structure field"
 msgstr "classe de stockage spécifiée pour le champ de structure « %s »"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for parameter %qE"
 msgstr "classe de stockage spécifiée pour le paramètre « %s »"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for unnamed parameter"
 msgstr "classe de stockage spécifiée pour le paramètre « %s »"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "classe de stockage spécifié pour un typename"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' initialized and declared `extern'"
 msgid "%qE initialized and declared %<extern%>"
 msgstr "« %s » initialisé et déclaré « extern »"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' has both `extern' and initializer"
 msgid "%qE has both %<extern%> and initializer"
 msgstr "« %s » a les deux « extern » et initialisateur"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of `%s' specifies `auto'"
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "la déclaration de l'étendue de fichier « %s » spécifie « auto »"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of `%s' specifies `auto'"
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "la déclaration de l'étendue de fichier « %s » spécifie « auto »"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "nested function `%s' declared `extern'"
 msgid "nested function %qE declared %<extern%>"
 msgstr "fonction imbriquée « %s » déclarée « extern »"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope `%s' implicitly auto and declared `__thread'"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -31616,427 +31653,427 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static ou qualificateurs de type dans un déclarateur de tableau n'étant pas un paramètre"
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of %qE as array of voids"
 msgstr "déclaration de « %s » comme un tableau de « void »"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of type name as array of voids"
 msgstr "déclaration de « %s » comme un tableau de « void »"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qE as array of functions"
 msgstr "déclaration de « %s » comme un tableau de fonctions"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of type name as array of functions"
 msgstr "déclaration de « %s » comme un tableau de fonctions"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "utilisation invalide d'une structure ayant un membre flexible"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' has non-integer type"
 msgid "size of array %qE has non-integer type"
 msgstr "la taille du tableau « %s » n'est pas de type entier"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' has non-integer type"
 msgid "size of unnamed array has non-integer type"
 msgstr "la taille du tableau « %s » n'est pas de type entier"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids zero-size array `%s'"
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C interdit le tableau de taille zéro « %s »"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array"
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++ interdit les tableaux de taille zéro"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of array %qE is negative"
 msgstr "taille du tableau est négative"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "taille du tableau est négative"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array %qE is too large"
 msgstr "la taille du tableau « %s » est trop grande"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of unnamed array is too large"
 msgstr "la taille du tableau « %s » est trop grande"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 interdit les tableaux ayant des membres flexibles"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%<[*]%> not in a declaration"
 msgstr "« %s » n'est pas au début de la déclaration"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "les éléments du tableau sont de type incomplet"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "%qE declared as function returning a function"
 msgstr "« %s » déclaré comme une fonction retournant une fonction"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "type name declared as function returning a function"
 msgstr "« %s » déclaré comme une fonction retournant une fonction"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning an array"
 msgid "%qE declared as function returning an array"
 msgstr "« %s » déclaré comme une fonction retournant un tableau"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning an array"
 msgid "type name declared as function returning an array"
 msgstr "« %s » déclaré comme une fonction retournant un tableau"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type `%T'"
 msgid "function definition has qualified void return type"
 msgstr "définition invalide d'un type qualifié « %T »"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "qualificateurs de type ignorés pour le type à retourner par la fonction"
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C interdit les types de fonction qualifiés"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C interdit les types de fonction qualifiés"
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, fuzzy, gcc-internal-format
 #| msgid "%Jignoring asm-specifier for non-static local variable '%D'"
 msgid "%qs specified for auto variable %qE"
 msgstr "spécificateur asm ignoré pour la variable locale non statique « %D »"
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier omitted for parameter `%E'"
 msgid "%qs specified for parameter %qE"
 msgstr "spécificateur de type omis pour le paramètre « %E »"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier omitted for parameter"
 msgid "%qs specified for unnamed parameter"
 msgstr "spécificateur de type omis pour le paramètre"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%qs specified for structure field %qE"
 msgstr "classe de stockage spécifiée pour le champ de structure « %s »"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%qs specified for structure field"
 msgstr "classe de stockage spécifiée pour le champ de structure « %s »"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "le champ de bits « %s » a un type invalide"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field has atomic type"
 msgstr "le champ de bits « %s » a un type invalide"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, fuzzy, gcc-internal-format
 #| msgid "%Jalignment may not be specified for '%D'"
 msgid "alignment specified for typedef %qE"
 msgstr "l'alignement ne peut pas être spécifié pour « %D »"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "alignment specified for parameter %qE"
 msgstr "classe de stockage spécifiée pour le paramètre « %s »"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "alignment specified for unnamed parameter"
 msgstr "classe de stockage spécifiée pour le paramètre « %s »"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, fuzzy, gcc-internal-format
 #| msgid "%Jalignment may not be specified for '%D'"
 msgid "alignment specified for bit-field %qE"
 msgstr "l'alignement ne peut pas être spécifié pour « %D »"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 #| msgid "`__alignof' applied to a bit-field"
 msgid "alignment specified for unnamed bit-field"
 msgstr "« __alignof » appliqué sur un champ de bits"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "alignment specified for function %qE"
 msgstr "« %D » ne peut seulement être spécifier pour les fonctions"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, fuzzy, gcc-internal-format
 #| msgid "%Jvariable '%D' declared `inline'"
 msgid "typedef %q+D declared %<inline%>"
 msgstr "variable « %D » déclarée « inline »"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, fuzzy, gcc-internal-format
 #| msgid "operator `%T' declared to return `%T'"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "opérateur « %T » déclaré comme retournant « %T »"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C interdit les fonction de type volatile ou constante"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type `%T'"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "membre de données peut ne pas avoir de type « %T » modifié de manière variable"
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field `%E' declared void"
 msgid "variable or field %qE declared void"
 msgstr "variable ou champ « %E » déclaré « void »"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "les attributs dans un déclarateur de tableau de paramètres sont ignorés"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %q+D declared %<inline%>"
 msgstr "paramètre « %D » déclaré «void »"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "paramètre « %D » déclaré «void »"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' declared as a function"
 msgid "field %qE declared as a function"
 msgstr "champ « %s » déclaré comme une fonction"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' has incomplete type"
 msgid "field %qE has incomplete type"
 msgstr "champ « %s » est de type incomplet"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, fuzzy, gcc-internal-format
 #| msgid "name `%T' has incomplete type"
 msgid "unnamed field has incomplete type"
 msgstr "nom « %T » a un type incomplet"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function `%s'"
 msgid "invalid storage class for function %qE"
 msgstr "classe de stockage invalide pour la fonction « %s »"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, fuzzy, gcc-internal-format
 #| msgid "cannot inline function `main'"
 msgid "cannot inline function %<main%>"
 msgstr "ne peut transformer « main » en fonction enligne"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 ne permet pas les types « complex »"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 ne permet pas les types « complex »"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, fuzzy, gcc-internal-format
 #| msgid "variable previously declared `static' redeclared `extern'"
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "variable précédemment déclarée « static » redéclarée « extern »"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, fuzzy, gcc-internal-format
 #| msgid "%Jvariable '%D' declared `inline'"
 msgid "variable %q+D declared %<inline%>"
 msgstr "variable « %D » déclarée « inline »"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "%Jvariable '%D' declared `inline'"
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "variable « %D » déclarée « inline »"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is a variably modified type"
 msgid "non-nested function with variably modified type"
 msgstr "« %T » est type modifié de manière variable"
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, fuzzy, gcc-internal-format
 #| msgid "function declaration isn't a prototype"
 msgid "function declaration isn%'t a prototype"
 msgstr "la déclaration de fonction n'est pas un prototype valide"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "noms de paramètres (sans type) dans la déclaration de fonction"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter \"%D\" has incomplete type"
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "paramètre \"%D\" a un type incomplet"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter has incomplete type"
 msgid "parameter %u has incomplete type"
 msgstr "le paramètre a un type incomplet"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter \"%D\" has incomplete type"
 msgid "parameter %u (%q+D) has void type"
 msgstr "paramètre \"%D\" a un type incomplet"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter `%s' has incomplete type"
 msgid "parameter %u has void type"
 msgstr "le paramètre « %s » a un type incomplet"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "\"void\" as only parameter may not be qualified"
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "\"void\" comme seul paramètre ne peut être qualifié"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, fuzzy, gcc-internal-format
 #| msgid "\"void\" must be the only parameter"
 msgid "%<void%> must be the only parameter"
 msgstr "\"void\" doit être le seul paramètre"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter \"%D\" has just a forward declaration"
 msgid "parameter %q+D has just a forward declaration"
@@ -32043,7 +32080,7 @@
 msgstr "paramètre « %D » n'a qu'une déclaration anticipée"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s %s\" declared inside parameter list"
 msgid "%<%s %E%> declared inside parameter list"
@@ -32050,140 +32087,140 @@
 msgstr "\"%s %s\" déclarée à l'intérieur de la liste de paramètres"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "structure anonyme %s déclarée à l'intérieur de la liste des paramètres"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "visible uniquement depuis cette définition ou déclaration, ce qui n'est probablement pas ce que vous désirez"
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "enum type defined here"
 msgstr "« %s » précédemment défini ici"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "struct defined here"
 msgstr "« %s » précédemment défini ici"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "union defined here"
 msgstr "« %s » précédemment défini ici"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `union %s'"
 msgid "redefinition of %<union %E%>"
 msgstr "redéfinition de « union %s »"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `struct %s'"
 msgid "redefinition of %<struct %E%>"
 msgstr "redéfinition de « struct %s »"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "nested redefinition of %<union %E%>"
 msgstr "redéfinition imbriquée de « %s »"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "redéfinition imbriquée de « %s »"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "déclaration ne déclarant rien du tout"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn't support unnamed structs/unions"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ne permet pas les structures et unions sans nom"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn't support unnamed structs/unions"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ne permet pas les structures et unions sans nom"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate member `%D'"
 msgid "duplicate member %q+D"
 msgstr "membre « %D » est double"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, fuzzy, gcc-internal-format
 #| msgid "named members"
 msgid "union has no named members"
 msgstr "membres nommés"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous union with no members"
 msgid "union has no members"
 msgstr "agrégat anonyme sans aucun membre"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, fuzzy, gcc-internal-format
 #| msgid "named members"
 msgid "struct has no named members"
 msgstr "membres nommés"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, fuzzy, gcc-internal-format
 #| msgid "%s has no member named `%s'"
 msgid "struct has no members"
 msgstr "%s n'a pas de membre nommé « %s »"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
 msgstr "membre flexible de tableau dans l'union"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member not at end of struct"
 msgstr "le membre flexible de tableau n'est pas à la fin de la structure"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member in otherwise empty struct"
 msgstr "membre flexible de tableau dans une structure vide par ailleurs"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "type %qT is too large"
 msgstr "%s est trop grand"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union ne peut pas être rendu transparente"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "nested redefinition of %<enum %E%>"
@@ -32190,216 +32227,216 @@
 msgstr "redéfinition imbriquée de « %s »"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of `enum %s'"
 msgid "redeclaration of %<enum %E%>"
 msgstr "redéclaration de « enum %s »"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "valeurs d'énumération excède les bornes du plus grand entier"
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "valeur de l'énumérateur pour « %s » n'est pas une constante entière"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "valeur de l'énumérateur pour « %s » n'est pas une constante entière"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "débordement dans les valeurs de l'énumération"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of `int'"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C restreint les valeurs de l'énumérateur aux bornes d'un « int »"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinline function '%D' given attribute noinline"
 msgid "inline function %qD given attribute noinline"
 msgstr " fonction enligne « %D » a reçu l'attribut non enligne"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "le type du retour est incomplet"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, fuzzy, gcc-internal-format
 #| msgid "return type defaults to `int'"
 msgid "return type defaults to %<int%>"
 msgstr "le type du retour est « int » par défaut"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, fuzzy, gcc-internal-format
 #| msgid "%Jno previous prototype for '%D'"
 msgid "no previous prototype for %qD"
 msgstr "aucun prototype précédent pour « %D »"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%D' was used with no prototype before its definition"
 msgid "%qD was used with no prototype before its definition"
 msgstr "« %D » a été utilisé sans prototype avant sa définition"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, fuzzy, gcc-internal-format
 #| msgid "%Jno previous declaration for '%D'"
 msgid "no previous declaration for %qD"
 msgstr "aucune déclaration précédente pour « %D »"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, fuzzy, gcc-internal-format
 #| msgid "%J`%D' was used with no declaration before its definition"
 msgid "%qD was used with no declaration before its definition"
 msgstr "« %D » a été utilisé sans déclaration avant sa définition"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, fuzzy, gcc-internal-format
 #| msgid "%Jreturn type of '%D' is not `int'"
 msgid "return type of %qD is not %<int%>"
 msgstr "le type de retour de « %D » n'est pas « int »"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%D' is normally a non-static function"
 msgid "%qD is normally a non-static function"
 msgstr "« %D » n'est pas normalement une fonction statique"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style parameter declarations in prototyped function definition"
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "déclaration de paramètre d'ancien style dans la définition prototypée de fonction"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "le C traditionel rejette les définitions de fonction de style ISO C"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name omitted"
 msgid "parameter name omitted"
 msgstr "nom de paramètre omis"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "old-style function definition"
 msgstr "spécificateur pur lors de la définition d'une fonction"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name missing from parameter list"
 msgid "parameter name missing from parameter list"
 msgstr "nom du paramètre manquant dans la liste des paramètres"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, fuzzy, gcc-internal-format
 #| msgid "%J\"%D\" declared as a non-parameter"
 msgid "%qD declared as a non-parameter"
 msgstr "\"%D\" déclaré comme un non paramètre"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple parameters named \"%D\""
 msgid "multiple parameters named %qD"
 msgstr "plusieurs paramètres nommés « %D »"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %qD declared with void type"
 msgstr "paramètre « %D » déclaré «void »"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtype of \"%D\" defaults to \"int\""
 msgid "type of %qD defaults to %<int%>"
 msgstr "type de « %D » est « int » par défaut"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, fuzzy, gcc-internal-format
 #| msgid "parameter has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "le paramètre a un type incomplet"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdeclaration for parameter \"%D\" but no such parameter"
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "déclaration du paramètre « %D » mais pas de tel paramètre"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, fuzzy, gcc-internal-format
 #| msgid "number of arguments doesn't match prototype"
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "le nombre d'arguments ne concorde pas avec celui du prototype"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, fuzzy, gcc-internal-format
 #| msgid "number of arguments doesn't match prototype"
 msgid "number of arguments doesn%'t match prototype"
 msgstr "le nombre d'arguments ne concorde pas avec celui du prototype"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprototype declaration"
 msgid "prototype declaration"
 msgstr "%Hdéclaration de prototype"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, fuzzy, gcc-internal-format
 #| msgid "promoted argument \"%D\" doesn't match prototype"
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "argument promu \"%D\" ne concorde pas avec le prototype"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, fuzzy, gcc-internal-format
 #| msgid "promoted argument \"%D\" doesn't match prototype"
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "argument promu \"%D\" ne concorde pas avec le prototype"
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, fuzzy, gcc-internal-format
 #| msgid "argument \"%D\" doesn't match prototype"
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argument \"%D\" ne concorde pas avec le prototype"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, fuzzy, gcc-internal-format
 #| msgid "argument \"%D\" doesn't match prototype"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument \"%D\" ne concorde pas avec le prototype"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "« return » manquant dans une fonction devant retourner une valeur"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
@@ -32408,225 +32445,225 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, fuzzy, gcc-internal-format
 #| msgid "'for' loop initial declaration used outside C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "déclaration initiale de la boucle « for » utilisée en dehors du mode C99"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdeclaration of static variable '%D' in 'for' loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de la variable statique « %D » dans la déclaration initiale de la boucle « for »"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdeclaration of 'extern' variable '%D' in 'for' loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de la variable externe « %D » dans la déclaration initiale « for »"
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, fuzzy, gcc-internal-format
 #| msgid "'struct %s' declared in 'for' loop initial declaration"
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "« struct %s » déclarée dans la déclaration initiale de la boucle « for »"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, fuzzy, gcc-internal-format
 #| msgid "'union %s' declared in 'for' loop initial declaration"
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "« union %s » déclarée dans la déclaration initiale de la boucle « for »"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, fuzzy, gcc-internal-format
 #| msgid "'enum %s' declared in 'for' loop initial declaration"
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "« enum %s » déclarée dans la déclaration initiale de la boucle « for »"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdeclaration of non-variable '%D' in 'for' loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de « %D » (qui n'est pas une variable) dans la déclaration initiale de « for »"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible modes in send buffer action"
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "modes incompatibles dans le tampon de transmission d'action"
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qE"
 msgstr "« %s » apparaît en double"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "two or more data types in declaration of `%s'"
 msgid "two or more data types in declaration specifiers"
 msgstr "deux types de données ou plus dans la déclaration de « %s »"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
 msgstr "« long long long » est trop long pour GCC"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 ne permet pas « long long »"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 ne permet pas les types « complex »"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C interdit le type d'entiers complexes"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C interdit le type d'entiers complexes"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%<__int%d%> is not supported on this target"
 msgstr "le profilage n'est pas supporté sur cette cible"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 ne permet pas les types « complex »"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C90 ne permet pas « long long »"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "-fdata-sections n'est pas supporté pour cette machine cible"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C interdit le type d'entiers complexes"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' fails to be a typedef or built in type"
 msgid "%qE fails to be a typedef or built in type"
 msgstr "« %s » n'a pu devenir un typedef ou un type construit"
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not at beginning of declaration"
 msgstr "« %s » n'est pas au début de la déclaration"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s ne supporte pas %s"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 ne permet pas « long long »"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, fuzzy, gcc-internal-format
 #| msgid "`__thread' before `extern'"
 msgid "%<__thread%> before %<extern%>"
 msgstr "« __thread » avant « extern »"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, fuzzy, gcc-internal-format
 #| msgid "`__thread' before `static'"
 msgid "%<__thread%> before %<static%>"
 msgstr "« __thread » avant « static »"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "multiple storage classes in declaration specifiers"
 msgstr "multiples classes de stockage dans la déclaration de « %s »"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs used with %qE"
 msgstr "%s utilisé avec le format « %%%c » %s"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ne permet pas d'utiliser « complex » à la place de « double complex »"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C interdit le type d'entiers complexes"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -32637,7 +32674,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr "nom d'identificateur « %s » entre en conflit avec la stratégie interne de dénomination de GNU C++"
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "fin de ligne attendue"
@@ -32660,8 +32697,8 @@
 msgid "unknown type name %qE"
 msgstr "nom de registre inconnu: %s"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of unit `%s'"
 msgid "expected declaration specifiers"
@@ -32678,7 +32715,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored for methods"
@@ -32760,7 +32797,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 ne permet pas les types « complex »"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated string literal"
 msgid "expected string literal"
@@ -32824,15 +32861,15 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected identifier"
 msgstr "un nom de type attendu"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "virgule à la fin de liste d'énumerateurs"
@@ -33322,33 +33359,33 @@
 msgid "no type or storage class may be specified here,"
 msgstr "classe de stockage spécifié pour un typename"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "l'attribut de section ne peut être spécifié pour des variables locales"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
@@ -33359,47 +33396,47 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
@@ -33415,13 +33452,13 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "échec sur l'étendue (n'est pas à l'intérieur de la fonction)"
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, fuzzy, gcc-internal-format
 #| msgid "too many tag labels"
 msgid "too many %qs clauses"
 msgstr "trop d'étiquettes"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "expected integer expression before ')'"
@@ -33433,31 +33470,31 @@
 msgid "expression must be integral"
 msgstr "expression %s doit être référable"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 #| msgid "argument `%d' is not a constant"
 msgid "%qD is not a constant"
 msgstr "l'argument de « %d » n'est pas une constante"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not addressable"
 msgid "%qD is not a variable"
 msgstr "%s n'est pas adressable"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a pointer-to-object type"
 msgid "%qD is not a pointer variable"
 msgstr "« %T » n'est pas un type pointeur-vers-objet"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, fuzzy, gcc-internal-format
 #| msgid "case label must be a discrete constant expression"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "l'étiquette du CASE doit être une expression de constante discrète"
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
@@ -33490,17 +33527,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr ""
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template-id"
 msgid "invalid schedule kind"
@@ -33521,12 +33558,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -33549,19 +33586,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "l'étiquette du CASE doit être une expression de constante discrète"
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "opérande %%d invalide"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "masque invalide"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template-id"
 msgid "invalid dist_schedule kind"
@@ -33573,63 +33610,63 @@
 msgid "invalid proc_bind kind"
 msgstr "rotation invalide insn"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, fuzzy, gcc-internal-format
 #| msgid "expected another rename clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "attendait une autre clause de changement de nom"
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, fuzzy, gcc-internal-format
 #| msgid "%s: not for %s"
 msgid "%qs is not valid for %qs"
 msgstr "%s: non pour %s"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, fuzzy, gcc-internal-format
 #| msgid "expected another rename clause"
 msgid "expected %<#pragma omp%> clause"
 msgstr "attendait une autre clause de changement de nom"
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr ""
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid pragma"
 msgstr "#pragma %s invalde"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "#pragma %s invalde"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on array of chars"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "opération invalide pour des tableaux de caractères"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -33640,19 +33677,19 @@
 msgid "expected %<(%> or end of line"
 msgstr "attendait retourner au fichier \"%s\""
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, fuzzy, gcc-internal-format
 #| msgid "')' or term expected"
 msgid "for statement expected"
 msgstr "«)» or terme attendu"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 #| msgid "')' or term expected"
 msgid "_Cilk_for statement expected"
 msgstr "«)» or terme attendu"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, fuzzy, gcc-internal-format
 #| msgid "loc-identity declaration without initialization"
 msgid "expected iteration declaration or initialization"
@@ -33663,250 +33700,250 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<point%>"
 msgstr "opérande inattendue"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected %<target%>"
 msgstr "un nom de type attendu"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected %<declare%>"
 msgstr "un nom de type attendu"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr ""
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected function-name %<(%>"
 msgstr "un nom de type attendu"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter \"%D\" has incomplete type"
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "paramètre \"%D\" a un type incomplet"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, fuzzy, gcc-internal-format
 #| msgid "range failure (not inside function)"
 msgid "pragma simd must be inside a function"
 msgstr "échec sur l'étendue (n'est pas à l'intérieur de la fonction)"
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, fuzzy, gcc-internal-format
 #| msgid "starting bit in POS must be an integer constant"
 msgid "vectorlength must be an integer constant"
 msgstr "bit de départ dans la POSITION doit être une constante entière"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 #| msgid "text length must be greater than 0"
 msgid "vectorlength must be a power of 2"
 msgstr "la longueur de texte doit être plus grande que 0"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%i"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "le sélecteur doit être une constante entière entre les bornes 0..%i"
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, fuzzy, gcc-internal-format
 #| msgid "expected another rename clause"
 msgid "expected %<#pragma simd%> clause"
 msgstr "attendait une autre clause de changement de nom"
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "base of array section must be pointer or array type"
 msgstr "taille d'un nouveau tableau (new) doit avoir un type entier"
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<:%> or numeral"
 msgstr "opérande inattendue"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "array notations cannot be used with function type"
 msgstr "new ne peut être appliqué à un type de fonction"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected array notation expression"
@@ -33918,7 +33955,7 @@
 msgid "%qD has an incomplete type"
 msgstr "« %s » a un type incomplet"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "utilisation invalide d'expression void"
@@ -34033,7 +34070,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "la valeur indicée n'est ni un tableau ni un pointeur"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "l'indice du tableau n'est pas un entier"
@@ -34174,7 +34211,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "%s est signé en raison du prototype"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
@@ -34207,7 +34244,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "arithmétique sur un pointeur vers un type incomplet"
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -34306,7 +34343,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "mode non booléen dans l'expression conditionnelle"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
@@ -34344,7 +34381,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "non concordance entre pointeur et entier dans une expression conditionnelle"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr ""
@@ -34432,7 +34469,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "transtypage vers un pointeur depuis un entier de taille différente"
@@ -34610,7 +34647,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "la fonction est peut être candidate pour l'attribut de format de « %s »"
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "return type might be a candidate for a format attribute"
@@ -34770,7 +34807,7 @@
 msgid "initialization of a flexible array member"
 msgstr "initialisation d'un membre de tableau flexible"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "tableau de caractères initialisé à l'aide d'une chaîne large de caractères"
@@ -34820,7 +34857,7 @@
 msgid "invalid initializer"
 msgstr "initialisation invalide"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "type de vecteur opaque ne peut être initialisé"
@@ -34971,7 +35008,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C interdit « goto *expr; »"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, fuzzy, gcc-internal-format
 #| msgid "function declared `noreturn' has a `return' statement"
 msgid "function declared %<noreturn%> has a %<return%> statement"
@@ -34983,7 +35020,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "expression virgule utilsée pour initialiser la valeur de retour"
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -35101,19 +35138,19 @@
 msgid "expression statement has incomplete type"
 msgstr "la déclaration de l'expression a un type incomplet"
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "comparing vectors with different element types"
 msgstr "opérande vers ?: a différents types"
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, fuzzy, gcc-internal-format
 #| msgid "operand constraints for `asm' differ in number of alternatives"
 msgid "comparing vectors with different number of elements"
 msgstr "contraintes de l'opérande pour « asm » diffèrent en nombre d'alternatives"
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "comparer des nombres flottants à l'aide de == ou != n'est pas sûr"
@@ -35167,12 +35204,12 @@
 msgstr "comparaison ordonnée de pointeur avec le zéro entier"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "comparaison ordonnée de pointeur avec le zéro entier"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
@@ -35201,89 +35238,89 @@
 msgid "used vector type where scalar is required"
 msgstr "valeur de type « struct » utilisé là où un scalaire est attendu"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %qs clause"
 msgstr "« %s » n'est pas un nom de classe valide"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
 msgstr "« %s » n'est pas un nom de classe valide"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "taille d'un nouveau tableau (new) doit avoir un type entier"
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "taille d'un nouveau tableau (new) doit avoir un type entier"
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE does not have pointer or array type"
@@ -35295,17 +35332,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "type retourné invalide pour la fonction « %#D »"
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -35315,7 +35352,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in clause %qs"
@@ -35326,19 +35363,19 @@
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "instance de la variable « %s » est déclaré privée"
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "instance de la variable « %s » est déclaré privée"
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -35355,49 +35392,49 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "« %s » n'est pas un nom de classe valide"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' does not declare a template type"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "« %D » ne déclare pas un type de patron"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -35408,36 +35445,36 @@
 msgstr ""
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "passant « %T» comme «cet» argument de « %#D » écarte les qualificateurs"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  no known conversion from %qT to %qT"
 msgstr " pour la conversion de « %T » vers « %T »"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr " pour la conversion de « %T » vers « %T »"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -35444,92 +35481,92 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T, %T) <built-in>"
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr "%s %D(%T, %T, %T) <construit-interne>"
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T) <built-in>"
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "%s %D(%T, %T) <construit-interne>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T) <built-in>"
 msgid "%s%D(%T) <built-in>"
 msgstr "%s %D(%T) <interne>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "%s %T <conversion>"
 msgid "%s%T <conversion>"
 msgstr "%s %T <conversion>"
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, fuzzy, gcc-internal-format
 #| msgid "%J%s %+#D <near match>"
 msgid "%s%#D <near match>"
 msgstr "%s %+#D <près d'une concordance>"
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr ""
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr ""
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument deduction/substitution failed:"
 msgstr "patron de l'argument %d est invalide"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%T' to `%T' is ambiguous"
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "conversion de « %T » vers « %T » est ambiguë"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%T' to non-scalar type `%T' requested"
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr "conversion de « %T » vers un type non scalaire « %T » demandée"
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%D(%A)'"
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "pas de fonction concordante pour l'appel de « %D(%A) »"
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, fuzzy, gcc-internal-format
 #| msgid "call of overloaded `%D(%A)' is ambiguous"
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
@@ -35537,520 +35574,520 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr "pointeur vers fonction membre %E ne peut être appelé sans un objet; utilisez  .* ou  ->*"
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to `(%T) (%A)'"
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "pas de concordance pour l'appel de « (%T) (%A) »"
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, fuzzy, gcc-internal-format
 #| msgid "call of `(%T) (%A)' is ambiguous"
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "appel de « (%T) (%A) » est ambiguë"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "comversion ambigue pour un sous-tableau"
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, fuzzy, gcc-internal-format
 #| msgid "operand is r0"
 msgid " (operand type is %qT)"
 msgstr "opérande est R0"
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: %s"
 msgid "ternary %<operator?:%>"
 msgstr "erreur interne: %s"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, fuzzy, gcc-internal-format
 #| msgid "%s for ternary 'operator?:' in '%E ? %E : %E'"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%s pour « operator?: » ternaire dans « %E ? %E : %E »"
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, fuzzy, gcc-internal-format
 #| msgid "%s for 'operator%s' in '%E%s'"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s pour « operator%s » dans « %E%s »"
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, fuzzy, gcc-internal-format
 #| msgid "%s for 'operator[]' in '%E[%E]'"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%s pour « operator[] » dans « %E[%E] »"
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, fuzzy, gcc-internal-format
 #| msgid "%s for 'operator%s' in '%E %s %E'"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s pour « operator%s » dans « %E %s %E »"
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, fuzzy, gcc-internal-format
 #| msgid "%s for 'operator%s' in '%s%E'"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s pour « operator%s » dans « %s%E »"
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ interdit l'omission du terme milieu de l'expression ?:"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible modes in concat expression"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "modes incompatibles dans l'expression de concaténation"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "opérande vers ?: a différents types"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, fuzzy, gcc-internal-format
 #| msgid "methods cannot be converted to function pointers"
 msgid "  and each type can be converted to the other"
 msgstr "méthode ne peuvent être converties en des pointeurs de fonction"
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: `%T' vs `%T'"
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "non concordance de type énuméré dans l'expression conditionnelle: « %T » vs « %T »"
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "type énuméré et non énuméré dans l'expression conditionnelle"
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, fuzzy, gcc-internal-format
 #| msgid "no `%D(int)' declared for postfix `%s', trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "pas « %D(int) » déclaré pour le postfixe « %s », essaie avec l'oprateur préfixe à la place"
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, fuzzy, gcc-internal-format
 #| msgid "no `%D(int)' declared for postfix `%s', trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "pas « %D(int) » déclaré pour le postfixe « %s », essaie avec l'oprateur préfixe à la place"
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between `%#T' and `%#T'"
 msgid "comparison between %q#T and %q#T"
 msgstr "comparaison entre « %#T » et « %#T »"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "non-placement deallocation function %q+D"
 msgstr "déclaration implicite de la fonction « %#D »"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr ""
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, fuzzy, gcc-internal-format
 #| msgid "no suitable `operator %s' for `%T'"
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "pas « operator %s » adapté pour « %T »"
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is private"
 msgid "%q+#D is private"
 msgstr "« %+#D » est privé"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is protected"
 msgid "%q+#D is protected"
 msgstr "« %+#D » est protégé"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is inaccessible"
 msgid "%q+#D is inaccessible"
 msgstr "« %+#D » et inaccessible"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr "à l'intérieur du contexte"
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, fuzzy, gcc-internal-format
 #| msgid "passing NULL used for non-pointer %s %P of `%D'"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "passage d'un NULL utilisé pour un non pointeur %s %P de « %D »"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, fuzzy, gcc-internal-format
 #| msgid "%s to non-pointer type `%T' from NULL"
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "%s vers un type non pointeur « %T » à partir d'un NULL"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "type incompatible pour l'argument n°%d de « %s »"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "conversion d'un NULL vers un type non pointeur"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "too many braces around initializer for %qT"
 msgstr "accolades autour de l'initialiseur scalaire pour « %T »"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, gcc-internal-format
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "conversion invalide de « %T » vers « %T »"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, fuzzy, gcc-internal-format
 #| msgid "  initializing argument %P of `%D'"
 msgid "  initializing argument %P of %qD"
 msgstr "  initialisation de l'argument %P de « %D »"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "invalid conversion from %qT to %qT"
 msgstr "conversion invalide de « %T » vers « %T »"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, fuzzy, gcc-internal-format
 #| msgid "  initializing argument %P of `%D'"
 msgid "  initializing argument %P of %q+D"
 msgstr "  initialisation de l'argument %P de « %D »"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind rvalue `%E' to `%T'"
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "ne peut lier la rvalue « %E » avec « %T »"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initialization of non-const reference of type '%T' from a temporary of type '%T'"
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "initialisation invalide pour une référence à un non constante de type « %T » à partir d'un type temporaire de type « %T »"
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "passant « %T» comme «cet» argument de « %#D » écarte les qualificateurs"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield `%E' to `%T'"
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "ne peut lier le champ de bits « %E » avec « %T »"
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind packed field `%E' to `%T'"
 msgid "cannot bind packed field %qE to %qT"
 msgstr "ne peut lier le champs empaqueté « %E » avec « %T »"
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind rvalue `%E' to `%T'"
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "ne peut lier la rvalue « %E » avec « %T »"
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type `%#T' through `...'"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "ne peut recevoir d'objets de type non POD « %#T » through « ... »"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "redéfinition de l'argument par défaut pour « %#D »"
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, fuzzy, gcc-internal-format
 #| msgid "the default argument for parameter %d of `%D' has not yet been parsed"
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "argument par défaut pour le paramètre %d de « %D » n'a pas encore été analysé"
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "Avertir à propos des fonctions qui pourraient être candidates pour les attributs de format"
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "passant « %T» comme «cet» argument de « %#D » écarte les qualificateurs"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, fuzzy, gcc-internal-format
 #| msgid "  in call to `%D'"
 msgid "  in call to %qD"
 msgstr " dans l'appel de « %D »"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not an accessible base of `%T'"
 msgid "%qT is not an accessible base of %qT"
 msgstr "« %T » est une base accessible de « %T »"
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, fuzzy, gcc-internal-format
 #| msgid "  in call to `%D'"
 msgid "  in call to %q+D"
 msgstr " dans l'appel de « %D »"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, fuzzy, gcc-internal-format
 #| msgid "could not find class$ field in java interface type `%T'"
 msgid "could not find class$ field in java interface type %qT"
 msgstr "ne peut repérer le champ classe$ dans le type d'interface JAVA « %T »"
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "constructeurs ne peut être déclarés virtuels"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to non-function %qD"
 msgstr "appel à une non fonction « %D »"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call destructor `%T::~%T' without object"
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "ne peut appeler le destructeur «%T::~%T» sans objet"
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%T::%s(%A)%#V'"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "pas de fonction concordante pour l'appel à « %T::%s(%A)%#V »"
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%T::%s(%A)%#V'"
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr "pas de fonction concordante pour l'appel à « %T::%s(%A)%#V »"
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%D(%A)'"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "pas de fonction concordante pour l'appel de « %D(%A) »"
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, fuzzy, gcc-internal-format
 #| msgid "call of overloaded `%s(%A)' is ambiguous"
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "appel du surchargé « %s(%A) » est ambiguë"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, fuzzy, gcc-internal-format
 #| msgid "abstract virtual `%#D' called from constructor"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "abstrait virtuel « %#D » appelé à partir d'un constructeur"
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call member function `%D' without object"
 msgid "cannot call member function %qD without object"
 msgstr "ne peut appeler la fonction membre « %D » sans objet"
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' chooses `%T' over `%T'"
 msgid "passing %qT chooses %qT over %qT"
 msgstr "passant « %T » à choisit « %T » au lieu de « %T »"
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, fuzzy, gcc-internal-format
 #| msgid "choosing `%D' over `%D'"
 msgid "choosing %qD over %qD"
 msgstr "choix de « %D » à la place de « %D »"
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  for conversion from %qT to %qT"
 msgstr " pour la conversion de « %T » vers « %T »"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  parce que la séquence de conversion pour l'argument est meilleure"
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "argument par défaut spécifié dans la spécialisation explicite"
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, fuzzy, gcc-internal-format
 #| msgid "candidate 1:"
 msgid " candidate 1: %q+#F"
 msgstr "candidat 1:"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, fuzzy, gcc-internal-format
 #| msgid "candidate 2:"
 msgid " candidate 2: %q+#F"
 msgstr "candidat 2:"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ indique qu'ils sont ambiguës même à travers la plus mauvaise conversion pour le premier que la plus mauvaise pour la seconde:"
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert `%E' to `%T'"
 msgid "could not convert %qE from %qT to %qT"
 msgstr "ne peut convertir « %E » vers « %T »"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initialization of reference of type '%T' from expression of type '%T'"
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
@@ -36227,7 +36264,7 @@
 msgid "  by %q+D"
 msgstr "  par « %D »"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' invalid; an anonymous union can only have non-static data members"
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
@@ -36239,7 +36276,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "« %#D » invalide; une union anonyme peut seulement avoir des données non statiques de membres"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, fuzzy, gcc-internal-format
 #| msgid "private member `%#D' in anonymous union"
 msgid "private member %q+#D in anonymous union"
@@ -36251,7 +36288,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "membre privé « %#D » dans une union anonyme"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, fuzzy, gcc-internal-format
 #| msgid "protected member `%#D' in anonymous union"
 msgid "protected member %q+#D in anonymous union"
@@ -36405,74 +36442,85 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  mais n'écrase pas « operator=(const %T&) »"
 
-#: cp/class.c:4538
+#: cp/class.c:4300
+#, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
 #, fuzzy, gcc-internal-format
+#| msgid "assignment (not initialization) in declaration"
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr "affectation (non pas l'initialisation) dans la déclaration"
+
+#: cp/class.c:4557
+#, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-virtual method `%D'"
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "initialisation spécifiée pour une méthode non virtuelle « %D »"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, fuzzy, gcc-internal-format
 #| msgid "%T is not a class type"
 msgid "%q+T is not literal because:"
 msgstr "« %T » n'est pas un type de classe"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "classe de base « %#T » a un destructeur non virtuel"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "initialisation invalide dans la class de données de membre statiques d'un non entier de type « %T »"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "  non-static data member %q+D has volatile type"
 msgstr "« %T » n'a pas de membre de données non statique nommé « %D »"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "classe de base « %#T » a un destructeur non virtuel"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference `%#D' in class without a constructor"
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr "référence non statique « %#D » dans la classe sans un constructeur"
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member `%#D' in class without a constructor"
 msgid "non-static const member %q+#D in class without a constructor"
@@ -36480,115 +36528,115 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, fuzzy, gcc-internal-format
 #| msgid "direct base `%T' inaccessible in `%T' due to ambiguity"
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "base directe « %T » inaccessible dans « %T » en raison de l'ambiguité"
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, fuzzy, gcc-internal-format
 #| msgid "virtual base `%T' inaccessible in `%T' due to ambiguity"
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "base virtuelle « %T » inaccessible dans « %T » en raison de l'ambiguité"
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "offset of `%D' is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr "le décalage relatif de « %D » peut ne pas être compatible avec l'ABI et peut être modifié dans une version future de GCC"
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "redefinition of %q#T"
 msgstr "redéfinition de « %#T »"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "« %#T » a des fonctions virtuelles mais un destructeur non virtuel"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "type transparent %q#T does not have any fields"
 msgstr "classe « %T » n'a pas aucun champ nommé « %D »"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, fuzzy, gcc-internal-format
 #| msgid "type `%s' has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "type « %s » a des membres de fonction virtuelle"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "tentative de complétion du struct, mais a été stoppé en raison d'erreurs précédentes d'analyses syntaxiques"
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, fuzzy, gcc-internal-format
 #| msgid "language string `\"%s\"' not recognized"
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "chaîne du langage « \"%s\" » n'est pas reconnue"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, fuzzy, gcc-internal-format
 #| msgid "cannot resolve overloaded function `%D' based on conversion to type `%T'"
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "ne peut résoudre la fonction surchargé « %D » basé sur la conversion vers le type « %T »"
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, fuzzy, gcc-internal-format
 #| msgid "no matches converting function `%D' to type `%#T'"
 msgid "no matches converting function %qD to type %q#T"
 msgstr "pas de concordance de conversion de fonction « %D » vers le type « %#T »"
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, fuzzy, gcc-internal-format
 #| msgid "converting overloaded function `%D' to type `%#T' is ambiguous"
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "conversion d'une fonction surchargée « %D » vers le type « %#T » est ambiguë"
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, fuzzy, gcc-internal-format
 #| msgid "assuming pointer to member `%D'"
 msgid "assuming pointer to member %qD"
 msgstr "pointeur assumé vers le membre « %D »"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with `&%E')"
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(un pointeur vers un membre peut seulement être formé avec «&%E»)"
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "pas assez d'information sur le type"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%E' from type `%T' to type `%T'"
 msgid "cannot convert %qE from type %qT to type %qT"
@@ -36599,13 +36647,13 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %q#D"
 msgstr "déclaration de « %#D »"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of `%D' from `%+#D'"
 msgid "changes meaning of %qD from %q+#D"
@@ -36650,44 +36698,44 @@
 msgid "constexpr constructor does not have empty body"
 msgstr "expression IN n'a pas de mode"
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr ""
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to internal function"
 msgstr "appel à une non fonction « %D »"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "expression %qE does not designate a constexpr function"
 msgstr "déclaration amie ne nomme pas une classe ou une fonction"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to non-constexpr function %qD"
@@ -36694,244 +36742,244 @@
 msgstr "appel à une non fonction « %D »"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot appear in a constant-expression"
 msgid "%qD called in a constant expression"
 msgstr "« %D » ne peut apparaître dans une expression de constante"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' implicitly declared before its definition"
 msgid "%qD used before its definition"
 msgstr "« %D » implicitement déclaré avant sa définition"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "protocol `%s' has circular dependency"
 msgid "call has circular dependency"
 msgstr "le protocole « %s » a une dépendance circulaire"
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "instantiation de la profondeur du patron excède le maximum de %d (utiliser -ftemplate-depth-NN pour augmenter le maximum) lors de l'instantiation de « %D »"
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant expression"
 msgid "%q+E is not a constant expression"
 msgstr "expression n'est pas une constante"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "le compteur de décalage vers la droite est négatif"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "l'opérande à gauche de la virgule n'a pas d'effet"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript out of bound"
 msgstr "l'indice du tableau n'est pas un entier"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "negative array subscript"
 msgstr "comversion ambigue pour un sous-tableau"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant expression"
 msgid "%qE is not a constant expression"
 msgstr "expression n'est pas une constante"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%s ne peut apparaître dans une expression de constante"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "accessing uninitialized member %qD"
 msgstr "initialiseur manquant pour le membre « %D »"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "Expresion de constante manquante ou invalide"
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "taille du tableau « %D » n'a pas une expression de constante de type entier"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "%qD used in its own initializer"
 msgstr "éléments en excès dans l'initialisation d'union"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%q#D is not const"
 msgstr "« %D » n'est pas une fonction"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is private"
 msgid "%q#D is volatile"
 msgstr "« %+#D » est privé"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "« %D » ne peut apparaître dans une expression de constante"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "« %D » n'a pas été déclaré dans cet horizon"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "expression dans le nouveau déclarateur doit être un type entier ou d'énumération"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "modification of %qE is not a constant-expression"
 msgstr "taille du tableau n'est pas une expression de constante de type entier"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "type énuméré et non énuméré dans l'expression conditionnelle"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast invalide à partir du type « %T » vers le type « %T »"
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression `%E' is not constant"
 msgid "expression %qE is not a constant-expression"
 msgstr "expression intégrale « %E » n'est pas une constante"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "statement is not a constant-expression"
 msgstr "%s ne peut apparaître dans une expression de constante"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "expression d'adresse inattendue"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "débordement dans l'expression de la constante"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "taille du tableau n'est pas une expression de constante de type entier"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression `%E' is not constant"
 msgid "pointer comparison expression is not a constant expression"
 msgstr "expression intégrale « %E » n'est pas une constante"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "%s ne peut apparaître dans une expression de constante"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant-expression"
 msgstr "taille du tableau n'est pas une expression de constante de type entier"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "index de tableau non constant dans l'initialisation"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unexpected type for `id' (%s)"
 msgid "unexpected AST of kind %s"
@@ -37006,7 +37054,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr ""
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr ""
@@ -37053,7 +37101,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "conversion de « %T » à « %T » écarte les qualificateurs"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, fuzzy, gcc-internal-format
 #| msgid "casting `%T' to `%T' does not dereference pointer"
 msgid "casting %qT to %qT does not dereference pointer"
@@ -37065,327 +37113,327 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "ne peut convertir type « %T » vers le type « %T »"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%#T' to `%#T'"
 msgid "conversion from %q#T to %q#T"
 msgstr "conversion de « %#T » vers « %#T »"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' used where a `%T' was expected"
 msgid "%q#T used where a %qT was expected"
 msgstr "« %#T » utilisé où « %T » était attendu"
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert `%E' to `%T'"
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "ne peut convertir « %E » vers « %T »"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' used where a floating point value was expected"
 msgid "%q#T used where a floating point value was expected"
 msgstr "« %#T » utilisé où un nombre flottant était attendu"
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%T' to non-scalar type `%T' requested"
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "conversion de « %T » vers un type non scalaire « %T » demandée"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, fuzzy, gcc-internal-format
 #| msgid "arguments to destructor are not allowed"
 msgid "pseudo-destructor is not called"
 msgstr "arguments au destructeur ne sont pas permis"
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "conversion vers un type incomplet"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of type `%T'"
 msgid "conversion to void will not access object of type %qT"
 msgstr "ne peut allouer un objet de type « %T »"
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "objet « %E » d'un type incomplet « %T » ne sera pas accessible dans %s"
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "objet « %E » d'un type incomplet « %T » ne sera pas accessible dans %s"
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "objet « %E » d'un type incomplet « %T » ne sera pas accessible dans %s"
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "objet « %E » d'un type incomplet « %T » ne sera pas accessible dans %s"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "objet « %E » d'un type incomplet « %T » ne sera pas accessible dans %s"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "objet « %E » d'un type incomplet « %T » ne sera pas accessible dans %s"
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s ne peut résoudre l'adresse la fonction surchargée"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s ne peut résoudre l'adresse la fonction surchargée"
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s ne peut résoudre l'adresse la fonction surchargée"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s ne peut résoudre l'adresse la fonction surchargée"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s ne peut résoudre l'adresse la fonction surchargée"
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s ne peut résoudre l'adresse la fonction surchargée"
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s ne peut résoudre l'adresse la fonction surchargée"
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s est un référence, pas un appel, à la fonction « %E »"
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s est un référence, pas un appel, à la fonction « %E »"
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s est un référence, pas un appel, à la fonction « %E »"
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s est un référence, pas un appel, à la fonction « %E »"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s est un référence, pas un appel, à la fonction « %E »"
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s est un référence, pas un appel, à la fonction « %E »"
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "second operand of conditional expression has no effect"
 msgstr "l'opérande à gauche de la virgule n'a pas d'effet"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "third operand of conditional expression has no effect"
 msgstr "l'opérande à gauche de la virgule n'a pas d'effet"
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right operand of comma operator has no effect"
 msgstr "l'opérande à gauche de la virgule n'a pas d'effet"
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of comma operator has no effect"
 msgstr "l'opérande à gauche de la virgule n'a pas d'effet"
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, fuzzy, gcc-internal-format
 #| msgid "%Hstatement with no effect"
 msgid "statement has no effect"
 msgstr "%Hdéclaration sans effet"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "for increment expression has no effect"
 msgstr "l'opérande à gauche de la virgule n'a pas d'effet"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "conversion d'un NULL vers un type non pointeur"
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument `%E' to `%T'"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "ne peut convertir l'argument du patron « %E » vers « %T »"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous default type conversion from `%T'"
 msgid "ambiguous default type conversion from %qT"
 msgstr "conversion de type par défaut ambiguë à partir de « %T »"
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, fuzzy, gcc-internal-format
 #| msgid "  candidate conversions include `%D' and `%D'"
 msgid "  candidate conversions include %qD and %qD"
@@ -37858,129 +37906,129 @@
 msgid "template parameters do not match template %qD"
 msgstr "paramètres du patron ne peuvent pas être amis"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, fuzzy, gcc-internal-format
 #| msgid "%Jan anonymous union cannot have function members"
 msgid "an anonymous struct cannot have function members"
 msgstr "un UNION  anonyme ne peut avoir de fonctions membres"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "%Jan anonymous union cannot have function members"
 msgid "an anonymous union cannot have function members"
 msgstr "un UNION  anonyme ne peut avoir de fonctions membres"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with constructor not allowed in anonymous aggregate"
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "membre « %#D » avec constructeur n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with destructor not allowed in anonymous aggregate"
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "membre « %#D » avec destructeur n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with copy assignment operator not allowed in anonymous aggregate"
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "membre « %#D » avec opérateur d'affectation par copie n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "previous friend declaration of `%D'"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "déclaration amie précédente de « %D »"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "types multiples dans une déclaration"
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type `%T'"
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redéclaration du type interne C++ « %T »"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "« %D » ne peut seulement être spécifié pour les objets et les fonctions"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "nom de type manquant dans la déclaration typedef"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ interdit les structures anonymes"
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%qs can only be specified for functions"
 msgstr "« %D » ne peut seulement être spécifier pour les fonctions"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified inside a class"
 msgid "%<friend%> can only be specified inside a class"
 msgstr "« %D » peut seulement être spécifié à l'intérieur d'une classe"
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for constructors"
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "« %D » ne peut seulement être spécifié pour les constructeurs"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "a storage class can only be specified for objects and functions"
 msgstr "« %D » ne peut seulement être spécifié pour les objets et les fonctions"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "qualifiers can only be specified for objects and functions"
 msgstr "« %D » ne peut seulement être spécifié pour les objets et les fonctions"
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "dans la déclaration de « %s », utilisation de « int » par défaut pour le type"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprototype declaration"
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%Hdéclaration de prototype"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter list used in explicit instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "patron de liste de paramètres utilisé dans une instantiation explicite"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "attribut « %s » peut seulement être appliqué aux définitions de classes"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
@@ -37987,148 +38035,148 @@
 msgstr "attribut « %s » peut seulement être appliqué aux définitions de classes"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, fuzzy, gcc-internal-format
 #| msgid "typedef `%D' is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef « %D » est initialisé (use __typeof__ instead)"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "déclaration de « %#D » est externe et initialisé"
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, fuzzy, gcc-internal-format
 #| msgid "%Jfunction `%D' definition is marked dllimport."
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "définition de la fonction « %D » est marquée dllimport"
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' is not a non-static data member of `%T'"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "« %#D » n'est pas un membre statique de données de « %T »"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "non-member-template declaration of %qD"
 msgstr "déclaration du patron de « %#D »"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "does not match member template declaration here"
 msgstr "déclaration de membre de patron invalide « %D »"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not permit `%T::%D' to be defined as `%T::%D'"
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ ne permet pas que « %T::%D » soit défini comme « %T::%D »"
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "duplicate initialization of %qD"
 msgstr "initialisation en double de %D"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr ""
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "déclaraion de « %#D » en dehors de la classe n'est pas une définition"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "champ « %D » déclaré statique dans l'union"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, fuzzy, gcc-internal-format
 #| msgid "variable `%#D' has initializer but incomplete type"
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "la variable « %#D » est initialisée, mais a un type incomplet"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#D have incomplete type"
 msgstr "éléments du tableau « %#D » ont un type incomplet"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "déclaration de « %#D » est externe et initialisé"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, fuzzy, gcc-internal-format
 #| msgid "aggregate `%#D' has incomplete type and cannot be defined"
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "agrégat « %#D » a un type incomplet et ne peut être défini"
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as reference but not initialized"
 msgid "%qD declared as reference but not initialized"
 msgstr "« %D » déclaré comme référence mais n'est pas initialisé"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "name `%D' used in a GNU-style designated initializer for an array"
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "nom « %D » utilisé dans un style GNU de l'initialisateur désigné pour un tableau"
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "name `%D' used in a GNU-style designated initializer for an array"
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "nom « %D » utilisé dans un style GNU de l'initialisateur désigné pour un tableau"
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, fuzzy, gcc-internal-format
 #| msgid "non-trivial labeled initializers"
 msgid "non-trivial designated initializers not supported"
 msgstr "initialiseur étiqueté de manière non trivial"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "taille du tableau « %D » n'a pas une expression de constante de type entier"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of `%D'"
 msgid "initializer fails to determine size of %qD"
 msgstr "l'initialisation n'a pu déterminer la taille de « %D »"
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qD"
 msgstr "taille de tableau manquante dans « %D »"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qD"
@@ -38137,114 +38185,114 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't known"
 msgid "storage size of %qD isn%'t known"
 msgstr "taille de stockage de « %D » n'est pas connue"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "taille de stockage de « %D » n'est pas une constante"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data `%#D' are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "désolé: sémantique de fonction enligne de données statiques « %#D » est erronée (vous obtiendrez de multiples copies)"
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "  vous pouvez contourner cela en enlevant l'initialiseur"
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const `%D'"
 msgid "uninitialized const %qD"
 msgstr "constante « %D » non initialisée"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variable de registre « %s » utilisée dans une fonction imbriquée"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, fuzzy, gcc-internal-format
 #| msgid "type `%s' has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "type « %s » a un constructeur défini par l'usager"
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for virtual method `%D'"
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "initialisation invalide pour la méthode virtuelle « %D »"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for `%T' must be brace-enclosed"
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "initialiseur de « %T » doit être entre accolades"
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, fuzzy, gcc-internal-format
 #| msgid "name `%D' used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "nom « %D » utilisé dans un style GNU de l'initialisateur désigné pour un tableau"
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "%qT has no non-static data member named %qD"
 msgstr "« %T » n'a pas de membre de données non statique nommé « %D »"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "initialisation invalide"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in aggregate initializer"
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "éléments en excès dans l'initialiseur d'agrégat"
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, fuzzy, gcc-internal-format
 #| msgid "too many initializers for `%T'"
 msgid "too many initializers for %qT"
 msgstr "trop d'initialiseurs pour « %T »"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "braces around scalar initializer for type %qT"
 msgstr "accolades autour de l'initialiseur scalaire pour « %T »"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer"
 msgid "missing braces around initializer for %qT"
 msgstr "accolades manquantes autour de l'initialisation"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#T have incomplete type"
@@ -38251,227 +38299,227 @@
 msgstr "éléments du tableau « %#D » ont un type incomplet"
 
 # FIXME
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ISO C90 interdit les mots composés"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "« %D » a un type incomplet"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "scalar object %qD requires one element in initializer"
 msgstr "éléments en excès dans l'initialisation d'union"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be initialized by constructor, not by `{...}'"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "« %D » doit être initialisé par un constructeur, non pas par « {...} »"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "_Pragma prend une chaîne entourée de parenthèrese"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "initialisation invalide pour un membre statique avec constructeur"
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ interdit l'initialisation intra-classe d'un membre statique non constant « %D »"
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(une initialisation en dehors de la classe est requise)"
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' with uninitialized const fields"
 msgid "reference %qD is initialized with itself"
 msgstr "membre « %D » avec des champs de constantes non initialisée"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "affectation (non pas l'initialisation) dans la déclaration"
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing previous type declaration of `%#D'"
 msgid "shadowing previous type declaration of %q#D"
 msgstr "masque la déclaration précédente de « %#D »"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr ""
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr ""
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, fuzzy, gcc-internal-format
 #| msgid "function `%#D' is initialized like a variable"
 msgid "function %q#D is initialized like a variable"
 msgstr "fonction « %#D » est initialisée comme une variable"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of `%D'"
 msgid "initializer fails to determine size of %qT"
 msgstr "l'initialisation n'a pu déterminer la taille de « %D »"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "taille de tableau manquante dans « %D »"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "tableau « %D » de taille zéro"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, fuzzy, gcc-internal-format
 #| msgid "destructor for alien class `%T' cannot be a member"
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destructeur pour la classe étrangère « %T » ne peut être un membre"
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, fuzzy, gcc-internal-format
 #| msgid "constructor for alien class `%T' cannot be a member"
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "constructeur pour la classe étrangère « %T » ne peut être un membre"
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "« %D» déclaré comme « virtual » %s"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> variable"
 msgstr "« %D» déclaré comme « inline » %s"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "spécificateurs de fonction « const» et «volatile» invalide pour « %D » dans la déclaration %s"
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "« %D» déclaré comme « virtual » %s"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, fuzzy, gcc-internal-format
 #| msgid "%J\"%D\" declared as a non-parameter"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "\"%D\" déclaré comme un non paramètre"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "spécificateurs de fonction « const» et «volatile» invalide pour « %D » dans la déclaration %s"
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "« %D» déclaré comme « virtual » %s"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "« %D» déclaré comme « inline » %s"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "spécificateurs de fonction « const» et «volatile» invalide pour « %D » dans la déclaration %s"
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "« %D» déclaré comme « virtual » %s"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "« %D» déclaré comme « inline » %s"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "spécificateurs de fonction « const» et «volatile» invalide pour « %D » dans la déclaration %s"
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%q+D declared as a friend"
 msgstr "« %D » déclaré comme un ami"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared with an exception specification"
 msgid "%q+D declared with an exception specification"
 msgstr "« %D » déclaré avec une exception de spécification"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' not in a namespace surrounding `%D'"
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "déclaration de « %D » n'est pas dans l'espace de noms entourant « %D »"
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, fuzzy, gcc-internal-format
 #| msgid "static member function `%#D' declared with type qualifiers"
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "membre de fonction statique « %#D » déclaré avec des qualificateurs de tyep"
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "defining explicit specialization %qD in friend declaration"
@@ -38478,618 +38526,618 @@
 msgstr "définition explicite de spécialisation « %D » dans lka déclaration ami"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-id `%D' in declaration of primary template"
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "utilisation invalide du template-id « %D » dans la déclaration du patron primaire"
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "arguments par défaut ne sont pas permis dans la déclaration amie de la spécialisation du patron « %D »"
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, fuzzy, gcc-internal-format
 #| msgid "`inline' is not allowed in declaration of friend template specialization `%D'"
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "« inline» n'estpas permis dans la déclaration amie de la spécialisation du patron « %D »"
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, fuzzy, gcc-internal-format
 #| msgid "`inline' is not allowed in declaration of friend template specialization `%D'"
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr "« inline» n'estpas permis dans la déclaration amie de la spécialisation du patron « %D »"
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be a template"
 msgid "cannot declare %<::main%> to be a template"
 msgstr "ne peut déclarer « ::main » comme étant un patron"
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be inline"
 msgid "cannot declare %<::main%> to be inline"
 msgstr "ne peut déclarer «::main» à être enligne"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be inline"
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "ne peut déclarer «::main» à être enligne"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be static"
 msgid "cannot declare %<::main%> to be static"
 msgstr "ne peut déclarer « ::main » comme étant static"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%sfonction membre « %D » ne peut avoir « %T » comme qualificateur de méthode"
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%sfonction membre « %D » ne peut avoir « %T » comme qualificateur de méthode"
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%sfonction membre « %D » ne peut avoir « %T » comme qualificateur de méthode"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%sfonction membre « %D » ne peut avoir « %T » comme qualificateur de méthode"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "patron avec liaison C"
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "%qD has invalid argument list"
 msgstr "type d'argument invalide"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "« %D » doit être une fonction membre non statique"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, fuzzy, gcc-internal-format
 #| msgid "`main' must return `int'"
 msgid "%<::main%> must return %<int%>"
 msgstr "« main» doit retourner « int »"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of implicitly-declared %qD"
 msgstr "définition implicitement déclarée « %D »"
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "définition implicitement déclarée « %D »"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' previously defined here"
 msgid "%q+#D explicitly defaulted here"
 msgstr "« %#D » précédemment défini ici"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, fuzzy, gcc-internal-format
 #| msgid "no `%#D' member function declared in class `%T'"
 msgid "no %q#D member function declared in class %qT"
 msgstr "pas de fonction membre « %#D » déclarée dans la classe « %T »"
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "initialisation invalide dans la class de données de membre statiques d'un non entier de type « %T »"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "initialisation invalide dans la class de données de membre statiques d'un non entier de type « %T »"
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "initialisation invalide dans la class de données de membre statiques d'un non entier de type « %T »"
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "initialisation invalide dans la class de données de membre statiques d'un non entier de type « %T »"
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ interdit l'initialisation intra-classe d'un membre statique non constant « %D »"
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids initialization of member constant `%D' of non-integral type `%T'"
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ interdit l'initialisation d'une membre constant « %D » d'un type non entier « %T »"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integral type `%T'"
 msgid "size of array %qD has non-integral type %qT"
 msgstr "taille du tableau « %D » n'est pas de type entier « %T »"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type `%T'"
 msgid "size of array has non-integral type %qT"
 msgstr "taille du tableau a type non entier « %T »"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is negative"
 msgid "size of array %qD is negative"
 msgstr "taille du tableau « %D » est négative"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "taille du tableau est négative"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array `%D'"
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ interdit les tableaux de taille zéro « %D »"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ interdit les tableaux de taille zéro"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "taille du tableau « %D » n'a pas une expression de constante de type entier"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "taille du tableau n'est pas une expression de constante de type entier"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array `%D'"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ interdit les tableaus de taille variable « %D »"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ interdit le tableau de taille variable"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "débordement dans les dimensions du tableau"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "« %D » déclaré comme un ami"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "déclaration de « %s » comme un tableau de « void »"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of void"
 msgstr "création du tableau « %T »"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "déclaration de « %s » comme un tableau de fonctions"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of functions"
 msgstr "déclaration de « %s » comme un tableau de fonctions"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "déclaration de « %s » comme un tableau de fonctions"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of references"
 msgstr "création du tableau « %T »"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "déclaration de « %s » comme un tableau de fonctions"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of function members"
 msgstr "déclaration de « %s » comme un tableau de fonctions"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "déclaration de « %D » comme tableau multidimensionel doit avoir des bornes pour chaque dimension excepté pour la première"
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "tableau multidimensionel doit avoir des bornes pour chaque dimension excepté pour la première"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "spécification de type retourné pour un constructeur est invalide"
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "spécification de type retourné pour un destructeur est invalide"
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, fuzzy, gcc-internal-format
 #| msgid "return type specified for `operator %T'"
 msgid "return type specified for %<operator %T%>"
 msgstr "type spécifié retourné pour l'opérateur « %T »"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "variable non nommée ou champ déclaré void"
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variable ou champ déclaré void"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "utilisation invalide du membre « %D »"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type `%T'"
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "définition invalide d'un type qualifié « %T »"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "utilisation invalide du membre « %D »"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%q#T is not a class or a namespace"
 msgstr "« %T » n'est pas une classe ou un espace de noms"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qD as non-function"
 msgstr "déclaration de « %D » comme non-fonction"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of `%T' as a non-template"
 msgid "declaration of %qD as non-member"
 msgstr "redéclaration de « %T » qui n'est pas un patron"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, fuzzy, gcc-internal-format
 #| msgid "declarator-id missing; using reserved word `%D'"
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "declarator-id manquant; utilisation du mot réservé « %D »"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `register'"
 msgid "function definition does not declare parameters"
 msgstr "définition de fonction déclarée « register »"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "déclaration de « %D » comme « %s »"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of '%#D' shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "déclaration de « %#D » masque un paramètre"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "un id de patron ne peut pas apparaître dans l'utilisation de la déclaration"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, fuzzy, gcc-internal-format
 #| msgid "two or more data types in declaration of `%s'"
 msgid "two or more data types in declaration of %qs"
 msgstr "deux types de données ou plus dans la déclaration de « %s »"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration '%#D'"
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "déclaration conflictuelle « %#D »"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ne permet pas d'utiliser « complex » à la place de « double complex »"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids declaration of `%s' with no type"
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ interdit la déclaration de « %s » sans type"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_trap not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_trap n'est pas supporté par la cible"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ ne permet pas « long long »"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for `%s'"
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "short, signed ou unsigned est invalide pour « %s »"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, fuzzy, gcc-internal-format
 #| msgid "signed and unsigned given together for `%s'"
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "signed et unsigned donnés ensembles pour « %s »"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long long%> invalid for %qs"
 msgstr "« complex » invalide pour « %s »"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long%> invalid for %qs"
 msgstr "« complex » invalide pour « %s »"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<short%> invalid for %qs"
 msgstr "« complex » invalide pour « %s »"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "« long », « short », « signed » ou « unsigned » invalide pour « %s »"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, fuzzy, gcc-internal-format
 #| msgid "long or short specified with char for `%s'"
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "« long » ou « short » spécifié avec « char » pour « %s »"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, fuzzy, gcc-internal-format
 #| msgid "long and short specified together for `%s'"
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "long et short spécifiés ensembles pour « %s »"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for `%s'"
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "short, signed ou unsigned est invalide pour « %s »"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned used invalidly for `%s'"
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "« long », « short », « signed » ou « unsigned » utilisé incorrectement pour « %s »"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "complex invalid for %qs"
 msgstr "« complex » invalide pour « %s »"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "qualificateurs ne sont pas permis dans la déclaration de « operator %T »"
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both virtual and static"
 msgstr "membre « %D » ne peut être déclaré virtuel et statique"
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "déclaration typedef invalide dans le paramètre de la déclaration"
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for template parameter %qs"
 msgstr "classe de stockage spécifiée pour le paramètre « %s »"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "spécificateurs de classe de stockage invalides dans la déclaration des paramètres"
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "paramètres du patron ne peuvent pas être amis"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "virtuel en dehors de la déclaration de classe"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "multiple storage classes in declaration of %qs"
 msgstr "multiples classes de stockage dans la déclaration de « %s »"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %s `%s'"
 msgid "storage class specified for %qs"
 msgstr "classe de stockage spécifiée pour %s « %s »"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for parameter %qs"
 msgstr "classe de stockage spécifiée pour le paramètre « %s »"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, fuzzy, gcc-internal-format
 #| msgid "nested function `%s' declared `extern'"
 msgid "nested function %qs declared %<extern%>"
 msgstr "fonction imbriquée « %s » déclarée « extern »"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, fuzzy, gcc-internal-format
 #| msgid "top-level declaration of `%s' specifies `auto'"
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "la déclaration hors de toute fonction de « %s » a spécifié « auto »"
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope `%s' implicitly auto and declared `__thread'"
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "« %s » dans le champ de la fonction est implicitement déclaré auto, et déclaré « __thread »"
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "spécificateurs de classe de stockage invalide dans les déclarations de fonction amie"
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "%qs declared as function returning a function"
 msgstr "« %s » déclaré comme une fonction retournant une fonction"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning an array"
 msgid "%qs declared as function returning an array"
 msgstr "« %s » déclaré comme une fonction retournant un tableau"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "fonctions virtuelles ne peuvent être amies"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
@@ -39096,301 +39144,301 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "le destructeur ne peut être une fonction membre statique"
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "le constructeur ne peut être une fonction membre statique"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be cv-qualified"
 msgstr "destructeurs ne peut être « %s »"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be `%s'"
 msgid "constructors may not be cv-qualified"
 msgstr "constructeurs ne peuvent pas être « %s »"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be ref-qualified"
 msgstr "destructeurs ne peut être « %s »"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr "constructeurs ne peut être déclarés virtuels"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "fonctions virtuelles ne peuvent être amies"
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "déclaration amie n'est pas dans la définition de classe"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function `%s' in a local class definition"
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "ne peut définir une fonction amie « %s » dans une définition locale de classe"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destructeurs ne peuvent pas avoir de paramètre"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T'"
 msgid "cannot declare pointer to %q#T"
 msgstr "ne peut déclarer un pointeur vers « %#T »"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to `%#T'"
 msgid "cannot declare reference to %q#T"
 msgstr "ne peut déclarer une référence vers « %#T »"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T' member"
 msgid "cannot declare pointer to %q#T member"
 msgstr "ne peut déclarer un pointeur vers le membre « %#T »"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare references to references"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "ne peut décalrer des références vers des références"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ne peut déclarer un champ de bits « %D » avec un type de fonction"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' used as a declarator"
 msgid "template-id %qD used as a declarator"
 msgstr "identificateur de patron « %D » utilisé comme déclarateur"
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "les fonctions membres sont implicitement amis de leur classe"
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification `%T::' on member `%s' ignored"
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "qualification additionnelle « %T:: » sur le membre « %s » est ignorée"
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "ne peut déclarer la fonction membre « %T::%s » à l'intérieur de « %T »"
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "ne peut déclarer la fonction membre « %T::%s » à l'intérieur de « %T »"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member `%T::%s' within `%T'"
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "ne peut déclarer le membre « %T::%s » à l'intérieur de « %T »"
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "membre de données « %D » ne peut être membre du patron"
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array %qs is too large"
 msgstr "la taille du tableau « %s » est trop grande"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type `%T'"
 msgid "data member may not have variably modified type %qT"
 msgstr "membre de données peut ne pas avoir de type « %T » modifié de manière variable"
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type `%T'"
 msgid "parameter may not have variably modified type %qT"
 msgstr "paramètre peut ne pas avoir de type « %T » modifié de manière variable"
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtuel en dehors de la déclaration de classe"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "définition explicite de spécialisation « %D » dans lka déclaration ami"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be `explicit'"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "seuls les déclarations de constructeurs peuvent être « explicit »"
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, fuzzy, gcc-internal-format
 #| msgid "non-member `%s' cannot be declared `mutable'"
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "le non membre « %s » ne peut être déclaré « mutable »"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, fuzzy, gcc-internal-format
 #| msgid "non-object member `%s' cannot be declared `mutable'"
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "un membre non objet « %s » ne peut être déclaré « mutable »"
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "fonction « %s » ne peut être déclarée « mutable »"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, fuzzy, gcc-internal-format
 #| msgid "static `%s' cannot be declared `mutable'"
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "static « %s » ne peut être déclaré « mutable »"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, fuzzy, gcc-internal-format
 #| msgid "const `%s' cannot be declared `mutable'"
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const « %s » ne peut être déclaré « mutable »"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "fonction « %s » ne peut être déclarée « mutable »"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, fuzzy, gcc-internal-format
 #| msgid "type is deprecated (declared at %s:%d)"
 msgid "typedef declared %<auto%>"
 msgstr "type est obsolète (déclaré à %s:%d)"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "nom du typedef peut ne pas être un nom de spécificateur imbriqué"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids nested type `%D' with same name as enclosing class"
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ interdit le type imbriqué « %D » avec le même nom que la classe de fermeture"
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr "qulificateurs de types spécifiés pour la déclaration d'une classe amie"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, fuzzy, gcc-internal-format
 #| msgid "`inline' specified for friend class declaration"
 msgid "%<inline%> specified for friend class declaration"
 msgstr "« inline » spécifié pour la déclaration d'une classe amie"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "paramètres du patron ne peuvent pas être amis"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration requires class-key, i.e. `friend class %T::%D'"
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "déclaration ami requiert une clé de classe, i.e. « friend class %T::%D »"
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration requires class-key, i.e. `friend %#T'"
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "déclaration amie requiert une clé de classes, i.e. « friend %#T »"
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, fuzzy, gcc-internal-format
 #| msgid "trying to make class `%T' a friend of global scope"
 msgid "trying to make class %qT a friend of global scope"
 msgstr "tentative de rendre la classe « %T » un ami de la portée globale"
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "qualificteurs invalide pour un type de fonction (autre que fonction membre)"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, fuzzy, gcc-internal-format
 #| msgid "abstract declarator `%T' used as declaration"
 msgid "abstract declarator %qT used as declaration"
 msgstr "déclaration abstrait « %T » utilisé dans la déclaration"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use `::' in parameter declaration"
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "ne peut utiliser «::» dans le paramètre d'un déclaration"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 #| msgid "`this' may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "« cela » ne peut être utilisé dans ce contexte"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter declared %<auto%>"
 msgstr "paramètre « %D » déclaré «void »"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "non-static data member declared %<auto%>"
@@ -39397,156 +39445,156 @@
 msgstr "« %T » n'a pas de membre de données non statique nommé « %D »"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "utilisation invalide de « :: »"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function `%#D' conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "déclaration de la fonction C « %#D » en conflit avec"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' declared virtual inside a union"
 msgid "function %qD declared virtual inside a union"
 msgstr "fonction « %D » déclaré comme virtuelle à l'intérieur d'un agrégat"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr "« %D » ne peut être déclaré virtuel, alors qu'il est toujours statique"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "qualificateurs ne sont pas permis dans la déclaration de « operator %T »"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of '%D' shadows a member of 'this'"
 msgid "declaration of %qD as member of %qT"
 msgstr "déclaration de « %D » masque un membre de « this »"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "destructeurs ne peut être « %s »"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "qualificateurs ne sont pas permis dans la déclaration de « operator %T »"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "spécialisation d'un membre spécial d'nue fonction déclaré implicitement"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 #| msgid "variant label declared here..."
 msgid "variable template declared here"
 msgstr "étiquette variante déclarée ici..."
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "champ « %D » a un type incomplet"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, fuzzy, gcc-internal-format
 #| msgid "name `%T' has incomplete type"
 msgid "name %qT has incomplete type"
 msgstr "nom « %T » a un type incomplet"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is neither function nor member function; cannot be declared friend"
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "« %s » n'est ni une fonction ni une fonction membre ; ne peut être déclaré ami"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "mambre statique « %D» déclaré «register »"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `auto' invalid for function `%s'"
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "classe de stockage « auto» invalide pour une fonction « %s  »"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `register' invalid for function `%s'"
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "classe de stockage « register» invalide pour une fonction « %s  »"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "classe de stockage « __thread » invalide pour la fonction « %s  »"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "classe de stockage « __thread » invalide pour la fonction « %s  »"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "une spécification asm n'est pas permise dans la définition de fonction"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr "classe de stockage « inline» invalide pour une fonction « %s  » déclarée en dehors de la portée globale"
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "classe de stockage « inline» invalide pour une fonction « %s  » déclarée en dehors de la portée globale"
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, fuzzy, gcc-internal-format
 #| msgid "virtual non-class function `%s'"
 msgid "virtual non-class function %qs"
 msgstr "fonction virtuelle d'une non classe « %s »"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, fuzzy, gcc-internal-format
 #| msgid "method definition not in class context"
 msgid "%qs defined in a non-class scope"
 msgstr "méthode de définition n'est pas dans un contexte de classe"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "l'utilisation de déclaration pour un non membre au niveau de la portée de la classe"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%D' to have static linkage"
 msgid "cannot declare member function %qD to have static linkage"
@@ -39553,90 +39601,90 @@
 msgstr "ne peut déclarer la fonction membre « %D » comme ayant un lien statique"
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "ne peut déclarer une fonction statique à l'intérieur d'une autre fonction"
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, fuzzy, gcc-internal-format
 #| msgid "`static' may not be used when defining (as opposed to declaring) a static data member"
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "« static » ne peut pas être utilisé lors de la définition (contrairement à la déclaration) de données de membres statiques"
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static member %qD declared %<register%>"
 msgstr "mambre statique « %D» déclaré «register »"
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, fuzzy, gcc-internal-format
 #| msgid "cannot explicitly declare member `%#D' to have extern linkage"
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "ne peut explicitement déclarer le membre « %#D » comme ayant une liaison externe"
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "déclaraion de « %#D » en dehors de la classe n'est pas une définition"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' initialized and declared `extern'"
 msgid "%qs initialized and declared %<extern%>"
 msgstr "« %s » initialisé et déclaré « extern »"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' has both `extern' and initializer"
 msgid "%qs has both %<extern%> and initializer"
 msgstr "« %s » a les deux « extern » et initialisateur"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses %qD"
 msgstr "argument par défaut « %E » utiliser une variable locale « %D »"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses local variable %qD"
 msgstr "argument par défaut « %E » utiliser une variable locale « %D »"
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `virtual' in template declaration of `%#D'"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "utilisation invalide de « virtual» dans la déclaration d'un patron de « %#D »"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "utilisation invalide du template-name « %E » dans le déclarateur"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter \"%D\" has incomplete type"
 msgid "parameter %qD has Java class type"
 msgstr "paramètre \"%D\" a un type incomplet"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' invalidly declared method type"
 msgid "parameter %qD invalidly declared method type"
 msgstr "paramètre « %D » incorrectement validé comme type de méthode"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "paramètre « %D » inclut %s au tableau de bornes inconnues « %T »"
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
@@ -39657,78 +39705,78 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constructor; you probably meant `%T (const %T&)'"
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructeur invalide; vous vouliez probablement dire « %T (const %T&) »"
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD may not be declared within a namespace"
 msgstr "« %D » n'a pas été déclaré dans cet horizon"
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' has not been declared"
 msgid "%qD may not be declared as static"
 msgstr "« %D » n'a pas été déclaré"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a nonstatic member function"
 msgstr "« %D » doit être une fonction membre non statique"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be either a non-static member function or a non-member function"
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "« %D » doit être soit un membre non statique de fonction ou une fonction non membre"
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must have an argument of class or enumerated type"
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "« %D » doit avoir un argument de classe ou de type énuméré"
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "conversion de %s%s ne sera jamais utilisé dans un type d'opérateur de conversion"
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to void will never use a type conversion operator"
 msgstr "conversion de %s%s ne sera jamais utilisé dans un type d'opérateur de conversion"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "conversion de %s%s ne sera jamais utilisé dans un type d'opérateur de conversion"
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "conversion de %s%s ne sera jamais utilisé dans un type d'opérateur de conversion"
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "conversion de %s%s ne sera jamais utilisé dans un type d'opérateur de conversion"
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a base class will never use a type conversion operator"
@@ -39735,126 +39783,126 @@
 msgstr "conversion de %s%s ne sera jamais utilisé dans un type d'opérateur de conversion"
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ interdit la surcharge de l'opérateur ?:"
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must not have variable number of arguments"
 msgstr "« %D » doit prendre seulement un OU deux arguments"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its argument"
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr "postfixe « %D» doit prendre « int » comme argument"
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its second argument"
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr "postfixe « %D» doit prndre « int » pour son second argument"
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either zero or one argument"
 msgid "%qD must take either zero or one argument"
 msgstr "« %D » doit prendre seulement zéro ou un autre argument"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must take either one or two arguments"
 msgstr "« %D » doit prendre seulement un OU deux arguments"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, fuzzy, gcc-internal-format
 #| msgid "prefix `%D' should return `%T'"
 msgid "prefix %qD should return %qT"
 msgstr "préfixe « %D » devrait retourner « %T »"
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' should return `%T'"
 msgid "postfix %qD should return %qT"
 msgstr "postfixe « %D » devrait retourner « %T »"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take `void'"
 msgid "%qD must take %<void%>"
 msgstr "« %D» doit prendre « void »"
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "%qD must take exactly one argument"
 msgstr "« %D » doit prendre exactement un argument"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must take exactly two arguments"
 msgstr "« %D » doit prendre exactement deux arguments"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined `%D' always evaluates both arguments"
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "« %D » défini par l'usager évalue toujours les 2 arguments"
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should return by value"
 msgid "%qD should return by value"
 msgstr "« %D » devrait retourner par valeur"
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "%qD cannot have default arguments"
 msgstr "« %D » ne peut avoir d'arguments par défaut"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter `%T' after `%s'"
 msgid "using template type parameter %qT after %qs"
 msgstr "utilisation de type de patron de paramètre « %T » après « %s »"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization `%D' for `%+D'"
 msgid "using alias template specialization %qT after %qs"
 msgstr "spécialisation de patron ambiguë « %D » pour « %+D »"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, fuzzy, gcc-internal-format
 #| msgid "using typedef-name `%D' after `%s'"
 msgid "using typedef-name %qD after %qs"
 msgstr "utilisation d'un nom de typedef « %D » après « %s »"
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has a previous declaration as `%#D'"
 msgid "%qD has a previous declaration here"
 msgstr "« %D » a une déclaration précédente tel que « %#D »"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' referred to as `%s'"
 msgid "%qT referred to as %qs"
 msgstr "« %TD » référé comme « %s »"
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, fuzzy, gcc-internal-format
 #| msgid "%Jthis is a previous declaration"
 msgid "%q+T has a previous declaration here"
 msgstr "est la déclaration précédente"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' referred to as enum"
 msgid "%qT referred to as enum"
@@ -39867,101 +39915,101 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, fuzzy, gcc-internal-format
 #| msgid "template argument required for `%s %T'"
 msgid "template argument required for %<%s %T%>"
 msgstr "argument du patron est requis pour « %s %T »"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' has the same name as the class in which it is declared"
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "« %D » a le même nom que la classe dans laquelle il est déclaré"
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, fuzzy, gcc-internal-format
 #| msgid "reference to `%D' is ambiguous"
 msgid "reference to %qD is ambiguous"
 msgstr "référence à « %D » est ambiguë"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, fuzzy, gcc-internal-format
 #| msgid "use of enum `%#D' without previous declaration"
 msgid "use of enum %q#D without previous declaration"
 msgstr "utilisation de enum « %#D » sans déclaration précédente"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of `%T' as a non-template"
 msgid "redeclaration of %qT as a non-template"
 msgstr "redéclaration de « %T » qui n'est pas un patron"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %q+D"
 msgstr "déclaration précédente de « %D »"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, fuzzy, gcc-internal-format
 #| msgid "derived union `%T' invalid"
 msgid "derived union %qT invalid"
 msgstr "union dérivée « %T » invalide"
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, fuzzy, gcc-internal-format
 #| msgid "Java class '%T' cannot have multiple bases"
 msgid "Java class %qT cannot have multiple bases"
 msgstr "classe Java « %T » ne peut avoir de bases multiples"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, fuzzy, gcc-internal-format
 #| msgid "Java class '%T' cannot have virtual bases"
 msgid "Java class %qT cannot have virtual bases"
 msgstr "classe Java « %T » ne peut avoir de bases virtuelles"
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, fuzzy, gcc-internal-format
 #| msgid "base type `%T' fails to be a struct or class type"
 msgid "base type %qT fails to be a struct or class type"
 msgstr "type de base « %T » a échoué pour devenir un type de classe ou un type construit"
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, fuzzy, gcc-internal-format
 #| msgid "recursive type `%T' undefined"
 msgid "recursive type %qT undefined"
 msgstr "type récursif « %T » non défini"
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate base type `%T' invalid"
 msgid "duplicate base type %qT invalid"
 msgstr "duplication du type de base « %T » invalide"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "définition précédente ici"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d to ABSTIME must be of integer type"
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
@@ -39971,98 +40019,98 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, fuzzy, gcc-internal-format
 #| msgid "no integral type can represent all of the enumerator values for `%T'"
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "aucun type entier peut représenter toutes les valeurs de l'énumérateur pour « %T »"
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "valeur de l'énumérateur pour « %s » n'est pas une constante entière"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in enumeration values at `%D'"
 msgid "overflow in enumeration values at %qD"
 msgstr "débordement dans les valeurs de l'énumération à « %D »"
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr ""
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "return type %q#T is incomplete"
 msgstr "type retourné « %#T » est incomplet"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, fuzzy, gcc-internal-format
 #| msgid "return type is an incomplete type"
 msgid "return type has Java class type %q#T"
 msgstr "le type du retour est incomplet"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, fuzzy, gcc-internal-format
 #| msgid "`operator=' should return a reference to `*this'"
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "« operator= » devrait retourner une référence à «*ceci »"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, fuzzy, gcc-internal-format
 #| msgid "%Jno previous declaration for '%D'"
 msgid "no previous declaration for %q+D"
 msgstr "aucune déclaration précédente pour « %D »"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "déclaration de fonction invalide"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %qD declared void"
 msgstr "paramètre « %D » déclaré «void »"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "« return » manquant dans une fonction devant retourner une valeur"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %q+D set but not used"
 msgstr "étiquette « %D » définie mais non utilisée"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "déclaration de membre de fonction invalide"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in class `%T'"
 msgid "%qD is already defined in class %qT"
 msgstr "« %D » est déjà défini dans la classe « %T »"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -40107,7 +40155,7 @@
 msgid "deleting %qT is undefined"
 msgstr "destruction de « %T » est indéfinie"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %q#D"
@@ -40134,7 +40182,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, fuzzy, gcc-internal-format
 #| msgid "destructor `%D' declared as member template"
 msgid "destructor %qD declared as member template"
@@ -40241,27 +40289,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "largeur du champ de bits « %#D » n'est pas une constante entière"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "struct anonyme n'est pas l'intérieur du type nommé"
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "agrégats anonymes de champs d'espace nom doit être statique"
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "agrégat anonyme sans aucun membre"
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' must return type `%T'"
 msgid "%<operator new%> must return type %qT"
@@ -40271,50 +40319,50 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' takes type `size_t' (`%T') as first parameter"
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "« operator new » prend le type « size_t » (« %T ») comme premier paramètre"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, fuzzy, gcc-internal-format
 #| msgid "`operator delete' must return type `%T'"
 msgid "%<operator delete%> must return type %qT"
 msgstr "« operator delete » doit retourner le type « %T »"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, fuzzy, gcc-internal-format
 #| msgid "`operator delete' takes type `%T' as first parameter"
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "« operator delete » prend le type « %T » comme premier paramètre"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using anonymous type, is used but never defined"
@@ -40324,51 +40372,51 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "« %#D » ne réfère pas à un type non qualifié, aussi il n'est pas utilisé pour la liaison"
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "« %F » déclaré « static » mais n'a jamais été définie"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "déclaration précédente de « %#D » avec le lien %L"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, fuzzy, gcc-internal-format
 #| msgid "inline function `%D' used but never defined"
 msgid "inline function %q+D used but never defined"
 msgstr "fonction enligne « %D » utilisé mais n'a jamais été défini"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, fuzzy, gcc-internal-format
 #| msgid "default argument missing for parameter %P of `%+#D'"
 msgid "default argument missing for parameter %P of %q+#D"
@@ -40376,12 +40424,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "use of deleted function %qD"
@@ -41037,43 +41085,43 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "ni le destructeur ni l'opérateur « delete » spécifique à la classe ne sera appellé, même s'ils sont déclarés lorsque la classe est définie"
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "fin prématurée de l'initialisation"
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr "ne peut initialiser un table multi-dimensionnel avec initialiseur"
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "taille du tableau inconnue dans delete"
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "problème possible détecté dans l'invocation de l'opérateur delete:"
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "ni le destructeur ni l'opérateur « delete » spécifique à la classe ne sera appellé, même s'ils sont déclarés lorsque la classe est définie"
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "type du vesteur delete n'est ni un pointeur ou un type tableau"
@@ -41211,17 +41259,17 @@
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, gcc-internal-format
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, gcc-internal-format
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
@@ -41686,7 +41734,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr ""
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -41715,7 +41763,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "requête du membre « %D » dans « %E », lequel n'est pas de type classe « %T »"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -41792,7 +41840,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "«;» manquant après la déclaration « %T »"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qT is not a template"
@@ -41821,7 +41869,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "%s ne peut apparaître dans une expression de constante"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -42125,7 +42173,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
@@ -42321,7 +42369,7 @@
 msgid "capture of non-variable %qD "
 msgstr ""
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%q+#D declared here"
@@ -42387,7 +42435,7 @@
 msgid "compound-statement in constexpr function"
 msgstr "Dans la déclaration de fonction"
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
@@ -42420,7 +42468,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected iteration-statement"
@@ -42453,13 +42501,13 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ interdit les gotos calculés"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected jump-statement"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, fuzzy, gcc-internal-format
 #| msgid "extra `;'"
 msgid "extra %<;%>"
@@ -42509,7 +42557,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "définition de classe ne peut pas être déclaré comme ami"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
@@ -42611,13 +42659,13 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "mot clé « export » n'est pas implanté et sera ignoré"
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "« %D » ne peut avoir d'arguments par défaut"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
@@ -42635,7 +42683,7 @@
 msgid "expected template-id"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<<%>"
@@ -42725,102 +42773,102 @@
 msgid "expected type specifier"
 msgstr "spécificateur du type sigof"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C interdit la déclaration anticipée de paramètres"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type `%D', got `%D'"
 msgid "expected template-id for type"
 msgstr "  attendait un patron de type « %D », a obtenu « %D »"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "déclaration ne déclarant rien du tout"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on uninstantiated type"
 msgid "attributes ignored on uninstantiated type"
 msgstr "opération invalide sur un type non instancié"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "attributes ignored on template instantiation"
 msgstr "classe de stockage « %D » appliqué à l'instantiation du patron"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "« %D » n'est pas un patron de fonction"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qD is not an enumerator-name"
 msgstr "« %D » n'est pas un espace de noms"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Autoriser l'instantiation automatique de patron"
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "déclaration de « %D » dans « %D » lequel n'entoure pas « %D »"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "déclaration de « %D » dans « %D » lequel n'entoure pas « %D »"
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, fuzzy, gcc-internal-format
 #| msgid "multiple definition of `%#T'"
 msgid "multiple definition of %q#T"
@@ -42827,131 +42875,131 @@
 msgstr "définition multiple de « %#T »"
 
 # FIXME: I18N
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C++ interdit de %ser un enum"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qD is not a namespace-name"
 msgstr "« %D » n'est pas un espace de noms"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected namespace-name"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "instructions min/max ne sont pas permises"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "un id de patron ne peut pas apparaître dans l'utilisation de la déclaration"
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, fuzzy, gcc-internal-format
 #| msgid "POS may not be specified for a list of field declarations"
 msgid "types may not be defined in alias template declarations"
 msgstr "POS ne peut pas être spécifiés pour une liste de déclarations de champs"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: définition de fonction n'a pas été convertie\n"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "une spécification asm n'est pas permise dans la définition de fonction"
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "attributs ne sont pas permis dans la définition de fonction"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, fuzzy, gcc-internal-format
 #| msgid "excess unnamed initializers"
 msgid "expected initializer"
 msgstr "débordement d'initialiseurs sans nom"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-member function `%D'"
 msgid "initializer provided for function"
 msgstr "initialisation spécifiée pour une fonction « %D » n'étant pas membre"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "attributs après l'initialisateur mis entre parenthèses sont ignorés"
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 #| msgid "%Jfunction '%D' redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "fonction « %D » redéclarée comme étant enligne"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, fuzzy, gcc-internal-format
 #| msgid "repetition count is not an integer constant"
 msgid "array bound is not an integer constant"
 msgstr "compteur de répétition n'est pas une constante entière"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "création d'un pointeur vers le membre de référence du type « %T »"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, fuzzy, gcc-internal-format
 #| msgid "`%T::%D' is not a type"
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> n'est pas un type"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template `%D'"
 msgid "invalid use of constructor as a template"
 msgstr "utilisation invalide du patron « %D »"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -42960,7 +43008,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "déclarateur invalide"
@@ -42967,324 +43015,324 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Déclaration invalide"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "déclarateur attendu"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD est un nom d'espace"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "création d'un pointeur vers le membre d'un type non classe « %T »"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "opérande inattendue"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate qualifier (offset %d)"
 msgid "duplicate cv-qualifier"
 msgstr "duplication du qualificateur (décalage %d)"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple ref-qualifiers"
 msgstr "spécificateurs « virtual » multiples"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "duplicate virt-specifier"
 msgstr "spécificateurs « virtual » multiples"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %D"
 msgid "invalid use of %<auto%>"
 msgstr "utilisation invalide de %D"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "nouveaux types ne peuvent être définis dans un type à retourner"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%D' as a non-type template-argument"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "utilisation invalide de « %D » pour un non type de paramètre de patron"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected type-specifier"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "nouveaux types ne peuvent être définis dans un type à retourner"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr "utilisation de l'argument par défaut pour un paramètre d'une non fonction"
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "arguments par défaut sont permis seulement pour les paramètres de fonction"
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "« %D » ne peut avoir d'arguments par défaut"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "« %D » ne peut avoir d'arguments par défaut"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ ne permet de désigner les initialiseurs"
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ ne permet de désigner les initialiseurs"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected class-name"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%D' declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "« %D » déclaré enligne après sa définition"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "expected %<;%> after union definition"
 msgstr "spécificateur pur lors de la définition d'une fonction"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "ne peut repérer le fichier pour la classe %s."
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "nom qualifié ne nomme pas une classe"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of `%D'"
 msgid "invalid class name in declaration of %qD"
 msgstr "déclaration de patron invalide « %D »"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification ignored"
 msgid "extra qualification not allowed"
 msgstr "qualification superflue ignorée"
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, fuzzy, gcc-internal-format
 #| msgid "an explicit specialization must be preceded by 'template <>'"
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "spécialisation explicite doit être précédé par « template <> »"
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, fuzzy, gcc-internal-format
 #| msgid "non-template `%D' used as template"
 msgid "function template %qD redeclared as a class template"
 msgstr "« %D » qui n'est pas un patron est utilisé comme patron"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "previous definition of %q+#T"
 msgstr "définition précédente de « %#T »"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected class-key"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected %<class%> or %<typename%>"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, fuzzy, gcc-internal-format
 #| msgid "a class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "une clé de classe doit être utilise lors de la déclaration d'un ami"
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "déclaration amie ne nomme pas une classe ou une fonction"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "spécificateur pur lors de la définition d'une fonction"
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "initialiseur utilisé entre accolades pour initialiser « %T »"
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr ""
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, fuzzy, gcc-internal-format
 #| msgid "keyword `typename' not allowed outside of templates"
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "mot clé « typename » n'est pas permis en dehors du patron"
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, fuzzy, gcc-internal-format
 #| msgid "keyword `typename' not allowed in this context (the base class is implicitly a type)"
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "mot clé « typename » n'est pas permis dans ce contexte (la classe de base est implicitement un type)"
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "nouveaux types ne peuvent être définis dans un type à retourner"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "nouveaux types ne peuvent être définis dans un type à retourner"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "redéclaration invalide de « %D »"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "trop peu de patron de listes de paramètres"
@@ -43293,589 +43341,589 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "trop de patron de listes de paramètres"
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "valeurs nommées à retourner ne sont plus supportées"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template `%#D' in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "déclaration invalide du patron de membre « %#D » dans la classe locale"
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "patron avec liaison C"
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "invalid explicit specialization"
 msgstr "spécialisation explicite ici"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "déclaration du patron de %<typedef%>"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "spécialisation explicite ici"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 #| msgid "`>>' should be `> >' within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "« >> » devrait être « > > » à l'intérieur du patron de la liste d'arguments"
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, fuzzy, gcc-internal-format
 #| msgid "spurious `>>', use `>' to terminate a template argument list"
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "faux « >> », utiliser « > » pour terminer la liste d'argument du patron"
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "spécification de base de classe invalide"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> avant %qD"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 ne permet pas %<long long%>"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qD"
 msgstr "« %s » apparaît en double"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qs"
 msgstr "« %s » apparaît en double"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected %<new%>"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<return%>"
 msgstr "opérande inattendue"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<extern%>"
 msgstr "opérande inattendue"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected %<decltype%>"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<operator%>"
 msgstr "opérande inattendue"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected %<template%>"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected %<namespace%>"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected %<asm%>"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected %<try%>"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected %<@try%>"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<*%>"
 msgstr "«;» attendu"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<~%>"
 msgstr "«;» attendu"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' tag used in naming `%#T'"
 msgid "%qs tag used in naming %q#T"
 msgstr "étiquette « %s » utilisée dans la dénomination de « %#T »"
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "« %s » précédemment déclaré ici"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, fuzzy, gcc-internal-format
 #| msgid "%D redeclared with different access"
 msgid "%qD redeclared with different access"
 msgstr "« %#D » redéclaré avec un accès différent"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, fuzzy, gcc-internal-format
 #| msgid "`template' (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "« template » (afin de rendre moins ambiguë) est seulement permis à l'intérieur des patron"
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "fin de fichier dans l'argument par défaut"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Déclaration de classe ou d'interface attendue"
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "l'attribut de section ne peut être spécifié pour des variables locales"
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name `%s' for register variable"
 msgid "invalid type for instance variable"
 msgstr "nom de registre invalide « %s » pour un variable registre"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, fuzzy, gcc-internal-format
 #| msgid "Identifier expected"
 msgid "identifier expected after %<@protocol%>"
 msgstr "Identificateur attendu"
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "attribut « %s » ignoré pour « %s »"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "type d'argument invalide"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 #| msgid "index is not an integer expression"
 msgid "expected positive integer expression"
 msgstr "index n'est pas une expression entière"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression must be referable"
 msgid "%<wait%> expression must be integral"
 msgstr "expression %s doit être référable"
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "initialisation invalide"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 #| msgid "no initialization allowed for `%s'"
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "pas d'initialisation permise pour « %s »"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "variable de registre « %s » utilisée dans une fonction imbriquée"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough collapsed for loops"
 msgstr "pas assez d'information sur le type"
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "attributs ne sont pas permis dans la définition de fonction"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "initialisation invalide"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 #| msgid "untyped expression as argument %d"
 msgid "expected id-expression (arguments)"
 msgstr "expression sans type comme argument %d"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "nouveaux types ne peuvent être définis dans un type à retourner"
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma GCC java_exceptions"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "rebut à la fin de #pragma GCC java_exceptions"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "contrainte invalide pour l'opérande"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 #| msgid "%s parameter %d must be a location"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%s paramètre %d doit être une localisation"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, fuzzy, gcc-internal-format
 #| msgid "%s parameter %d must be a location"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "%s paramètre %d doit être une localisation"
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimisations not implemented yet"
 msgid "inter-module optimizations not implemented for C++"
 msgstr "les optimisations inter-module n'est pas implanté encore"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-name"
 msgid "expected variable-name"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "data member %qD cannot be a member template"
 msgstr "membre de données « %D » ne peut être membre du patron"
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid member template declaration %qD"
 msgstr "déclaration de membre de patron invalide « %D »"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope `%D'"
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "spécialisation explicite dans la portée d'un non espace de noms « %D »"
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "fermetures de patrons de classe ne sont pas explicitement spécialisées"
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of `%D' in different namespace"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "spécialisation de « %D » dans différents espaces de noms"
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of `%D' in different namespace"
 msgid "specialization of %qD in different namespace"
 msgstr "spécialisation de « %D » dans différents espaces de noms"
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of `%#D'"
 msgid "  from definition of %q+#D"
 msgstr "  à partir de la définition de « %#D »"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "déclaration de « %D » dans « %D » lequel n'entoure pas « %D »"
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, fuzzy, gcc-internal-format
 #| msgid "invalid default argument for a template template parameter"
 msgid "name of class shadows template template parameter %qD"
 msgstr "utilisation invalide d'argument pour un patron de paramètres de patron"
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of alias template %qD"
 msgstr "déclaration du patron « %#D »"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit specialization of non-template %qT"
 msgstr "spécialisation explicite du non patron « %T »"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of `%T' after instantiation"
 msgid "specialization of %qT after instantiation"
 msgstr "spécialisation de « %T » après instantiation"
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, fuzzy, gcc-internal-format
 #| msgid "specializing `%#T' in different namespace"
 msgid "specializing %q#T in different namespace"
@@ -43883,77 +43931,77 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, fuzzy, gcc-internal-format
 #| msgid "specialization `%T' after instantiation `%T'"
 msgid "specialization %qT after instantiation %qT"
 msgstr "spécialisation de « %T » après instantiation « %T »"
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, fuzzy, gcc-internal-format
 #| msgid "template specialization with C linkage"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "spécialisation de patron avec édition de liens C"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "specialization of %qD after instantiation"
 msgstr "spécialisation de %D après instantiation"
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, fuzzy, gcc-internal-format
 #| msgid "candidate 1:"
 msgid "candidate is: %#D"
 msgstr "candidat 1:"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
 msgstr "%s %+#D"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%qD is not a function template"
 msgstr "« %D » n'est pas un patron de fonction"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a variable template"
 msgstr "« %T » n'est pas un patron"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "template-id « %D » pour « %+D » ne concorde pas avec aucune déclaration de patron"
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization `%D' for `%+D'"
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "spécialisation de patron ambiguë « %D » pour « %+D »"
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %D (should be %d)"
 msgstr "nombre erroné d'arguments du patron (%d devrait être %d)"
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -43960,63 +44008,63 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' in declaration of primary template"
 msgid "template-id %qD in declaration of primary template"
 msgstr "template-id « %D » dans la déclaration de patron primaire"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "patron de liste de paramètres utilisé dans une instantiation explicite"
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "définition fournie pour une instantiation explicite"
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of `%D'"
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "trop de patrons de listes de paramètres dans la déclaration de « %D »"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, fuzzy, gcc-internal-format
 #| msgid "too few template parameter lists in declaration of `%D'"
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "trop peu de patrons de listes de paramètres dans la déclaration de « %D »"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, fuzzy, gcc-internal-format
 #| msgid "an explicit specialization must be preceded by 'template <>'"
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "spécialisation explicite doit être précédé par « template <> »"
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%D' of function template"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "spécialisation partielle « %D » du patron de fonction"
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "argument par défaut spécifié dans la spécialisation explicite"
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD is not a template function"
 msgstr "« %D » n'est pas une membre du patron de fonction"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD is not declared in %qD"
@@ -44030,100 +44078,100 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "spécialisation d'un membre spécial d'une fonction déclaré implicitement"
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, fuzzy, gcc-internal-format
 #| msgid "no member function `%D' declared in `%T'"
 msgid "no member function %qD declared in %qT"
 msgstr "pas de membre de fonction « %D » déclaré dans « %T »"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, fuzzy, gcc-internal-format
 #| msgid "        `%D'"
 msgid "        %qD"
 msgstr "        « %D »"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, fuzzy, gcc-internal-format
 #| msgid "<anonymous>"
 msgid "        <anonymous>"
 msgstr "<anonymous>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %q+#D"
 msgstr "déclaration de « %#D »"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, fuzzy, gcc-internal-format
 #| msgid " shadows template parm `%#D'"
 msgid " shadows template parm %q+#D"
 msgstr " masque le paramètre du patron « %#D »"
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "paramètres du patron ne sont pas utilisés dans la spécialisation partielle:"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr "spécialisation partielle « %T » ne spécialise pas aucun patron d'arguments"
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "template argument %qE involves template parameter(s)"
 msgstr "patron d'argument « %E » implique des paramètres du patron"
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' of template argument `%E' depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -44131,13 +44179,13 @@
 msgstr[0] "type « %T » du patron d'argument « %E » dépend des paramètres du patron"
 msgstr[1] "type « %T » du patron d'argument « %E » dépend des paramètres du patron"
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "spécialisation de %D après instantiation"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, fuzzy, gcc-internal-format
 #| msgid "no default argument for `%D'"
 msgid "no default argument for %qD"
@@ -44146,46 +44194,46 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "arguments par défaut ne sont pas permis dans la déclaration amie de la spécialisation du patron « %D »"
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr "arguments par défaut ne sont pas permis dans la déclaration amie de la spécialisation du patron « %D »"
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "paramètres du patron ne sont pas utilisés dans la spécialisation partielle:"
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type `%T' has type `%T'"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argument par défaut pour le paramètre de type « %T » a le type « %T »"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "patron de classe sans nom"
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -44195,66 +44243,66 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of `%D'"
 msgid "invalid template declaration of %qD"
 msgstr "déclaration de patron invalide « %D »"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "template definition of non-template `%#D'"
 msgid "template definition of non-template %q#D"
 msgstr "définition de patron d'un non patron « %#D »"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, fuzzy, gcc-internal-format
 #| msgid "expected %d levels of template parms for `%#D', got %d"
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "attendait %d niveaux de patron de paramètres pour « %#D », obtenu %d"
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "got %d template parameters for %q#D"
 msgstr "a obtenu %d paramètres de patron pour « %#D »"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#T'"
 msgid "got %d template parameters for %q#T"
 msgstr "a obtenu %d paramètres de patron pour « %#T »"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  mais %d son requis"
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "template-id « %D » pour « %+D » ne concorde pas avec aucune déclaration de patron"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use template<> for an explicit specialization"
 msgstr "fermetures de patrons de classe ne sont pas explicitement spécialisées"
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "%qT is not a template type"
 msgstr "« %T » n'est pas un type patron"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, fuzzy, gcc-internal-format
 #| msgid "too few template parameter lists in declaration of `%D'"
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "trop peu de patrons de listes de paramètres dans la déclaration de « %D »"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -44262,7 +44310,7 @@
 msgstr[0] "« %D » utilisé sans patron de paramètres"
 msgstr[1] "« %D » utilisé sans patron de paramètres"
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "previous declaration %q+D used %d template parameter"
@@ -44270,13 +44318,13 @@
 msgstr[0] "déclaration précédente de « %#D » ici"
 msgstr[1] "déclaration précédente de « %#D » ici"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter `%#D'"
 msgid "template parameter %q+#D"
 msgstr "patron de paramètre « %#D »"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as `%#D'"
 msgid "redeclared here as %q#D"
@@ -44286,114 +44334,114 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "redefinition of default argument for %q#D"
 msgstr "redéfinition de l'argument par défaut pour « %#D »"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original definition appeared here"
 msgstr "  définition originale apparaît ici"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "« %E » n'est pas un argument valide pour le patron"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "il doit être l'adresse d'une fonction avec lien externe"
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "il doit être l'adresse d'une fonction avec lien externe"
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "chaîne %E n'est pas un patron d'argument valide parce que c'est l'adresse d'un objet avec lien statique"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "chaîne %E n'est pas un patron d'argument valide parce que c'est l'adresse d'un objet avec lien statique"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, fuzzy, gcc-internal-format
 #| msgid "it must be a pointer-to-member of the form `&X::Y'"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "il doit être un pointeur-vers-un-membre de la forme «&X::Y»"
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "a obtenu %d paramètres de patron pour « %#D »"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types `%#T' and `%#T'"
 msgid "  mismatched types %qT and %qT"
 msgstr "comparaison entre les types « %#T » et « %#T »"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "patron d'argument « %E » implique des paramètres du patron"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "« %E » n'est pas un argument valide pour le patron"
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "« %E » n'est pas un argument valide pour le patron"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -44400,200 +44448,200 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type `%T' to type `%T'"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "ne peut convertir type « %T » vers le type « %T »"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is an ambiguous base of `%T'"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "« %T » est une base ambiguë de « %T »"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' is not derived from type `%T'"
 msgid "  %qT is not derived from %qT"
 msgstr "type « %T » n'est pas dérivé du type « %T »"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument %qE does not match %qD"
 msgstr "patron de l'argument %d est invalide"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "  could not resolve address from overloaded function %qE"
 msgstr "%s ne peut résoudre l'adresse la fonction surchargée"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "chaîne %E n'est pas un patron d'argument valide parce que c'est l'adresse d'un objet avec lien statique"
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, fuzzy, gcc-internal-format
 #| msgid "template argument required for `%s %T'"
 msgid "in template argument for type %qT "
 msgstr "argument du patron est requis pour « %s %T »"
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "chaîne %E n'est pas un patron d'argument valide parce que c'est l'adresse d'un objet avec lien statique"
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "chaîne %E n'est pas un patron d'argument valide parce que c'est l'adresse d'un objet avec lien statique"
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "chaîne %E n'est pas un patron d'argument valide parce que c'est l'adresse d'un objet avec lien statique"
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "chaîne %E n'est pas un patron d'argument valide parce que c'est l'adresse d'un objet avec lien statique"
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "chaîne %E n'est pas un patron d'argument valide parce que c'est l'adresse d'un objet avec lien statique"
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "chaîne %E n'est pas un patron d'argument valide parce que c'est l'adresse d'un objet avec lien statique"
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "chaîne %E n'est pas un patron d'argument valide parce que c'est l'adresse d'un objet avec lien statique"
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr "chaîne %E n'est pas un patron d'argument valide parce que c'est l'adresse d'un objet avec lien statique"
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "« %E » n'est pas un argument valide pour le patron"
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "« %E » n'est pas un argument valide pour le patron"
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, fuzzy, gcc-internal-format
 #| msgid "conditional expression not allowed in this context"
 msgid "standard conversions are not allowed in this context"
 msgstr "expression conditionnelle n'est pas permise dans ce contexte"
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, fuzzy, gcc-internal-format
 #| msgid "missing `>' to terminate the template argument list"
 msgid "ignoring attributes on template argument %qT"
 msgstr "« > » manquant pour terminer la liste d'argument du patron"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%D' as a non-type template-argument"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "utilisation invalide de « %D » pour un non type de paramètre de patron"
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "usage de « restrict » invalide"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, fuzzy, gcc-internal-format
 #| msgid "to refer to a type member of a template parameter, use `typename %E'"
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "pour référencer un type de membre de patron de paramètres, utiliser « typename %E »"
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "non concordance de type/valeur pour l'argument %d dans la liste des paramètres du patron de « %D »"
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a constant of type `%T', got `%T'"
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  attendait une constante de type « %T », a obtenu « %T »"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got `%E'"
 msgid "  expected a class template, got %qE"
 msgstr "  attendait un patron de classe, a obtenu « %E »"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected a type, got %qE"
 msgstr "  attendait un type, a obtenu « %E »"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%T'"
 msgid "  expected a type, got %qT"
 msgstr "  attendait un type, a obtenu « %T »"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got `%T'"
 msgid "  expected a class template, got %qT"
 msgstr "  attendait un patron de classe, a obtenu « %T »"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type `%D', got `%D'"
 msgid "  expected a template of type %qD, got %qT"
@@ -44601,85 +44649,85 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, fuzzy, gcc-internal-format
 #| msgid "mode mismatch in parameter %d"
 msgid "type mismatch in nontype parameter pack"
 msgstr "non concordance du mode dans le paramètre %d"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument `%E' to `%T'"
 msgid "could not convert template argument %qE to %qT"
 msgstr "ne peut convertir l'argument du patron « %E » vers « %T »"
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "patron de l'argument %d est invalide"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "nombre erroné d'arguments du patron (%d devrait être %d)"
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "nombre erroné d'arguments du patron (%d devrait être %d)"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, fuzzy, gcc-internal-format
 #| msgid "provided for `%D'"
 msgid "provided for %q+D"
 msgstr "fournie pour « %D »"
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%q#D is not a function template"
 msgstr "« %D » n'est pas un patron de fonction"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, fuzzy, gcc-internal-format
 #| msgid "non-template type `%T' used as a template"
 msgid "non-template type %qT used as a template"
 msgstr "type non patron « %T » utilisé comme un patron"
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration `%D'"
 msgid "for template declaration %q+D"
 msgstr "pour la déclaration du patron « %D »"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "instantiation de la profondeur du patron excède le maximum de %d (utiliser -ftemplate-depth-NN pour augmenter le maximum) lors de l'instantiation de « %D »"
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "  when instantiating default argument for call to %D"
@@ -44698,312 +44746,312 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "variable %qD has function type"
 msgstr "sizeof appliqué sur un type de fonction"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "paramètre invalide pour le type « %T »"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "dans la déclaration de « %D »"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, fuzzy, gcc-internal-format
 #| msgid "function returns an aggregate"
 msgid "function returning an array"
 msgstr "fonction retourne un agrégat"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "function returning a function"
 msgstr "« %s » déclaré comme une fonction retournant une fonction"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member function of non-class type `%T'"
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "création d'un pointeur vers le membre d'une fonction d'un type non classe « %T »"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formation d'une référence en void"
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming pointer to reference type %qT"
 msgstr "formant %s pour référencer le type « %T »"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming reference to reference type %qT"
 msgstr "formant %s pour référencer le type « %T »"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming pointer to qualified function type %qT"
 msgstr "ISO C interdit les types de fonction qualifiés"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming reference to qualified function type %qT"
 msgstr "ISO C interdit les types de fonction qualifiés"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "creating pointer to member of non-class type %qT"
 msgstr "création d'un pointeur vers le membre d'un type non classe « %T »"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member reference type %qT"
 msgstr "création d'un pointeur vers le membre de référence du type « %T »"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member of type void"
 msgstr "création d'un pointeur vers le membre de référence du type « %T »"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of %qT"
 msgstr "création du tableau « %T »"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class, struct, or union type"
 msgid "%qT is not a class, struct, or union type"
 msgstr "« %T » n'est pas une classe, struct ou un type d'union"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, fuzzy, gcc-internal-format
 #| msgid "%T is not a class type"
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "« %T » n'est pas un type de classe"
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%s' in template"
 msgid "use of %qs in template"
 msgstr "utilisation de « %s » dans le patron"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "type qualifié « %T » ne concorde pas le nom du destructeur «~%T»"
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, fuzzy, gcc-internal-format
 #| msgid "dependent-name `%E' is parsed as a non-type, but instantiation yields a type"
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "nom dépendant « %E » est analysé comme un non type, mais son instantiation le rend comme un type"
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, fuzzy, gcc-internal-format
 #| msgid "say `typename %E' if a type is meant"
 msgid "say %<typename %E%> if a type is meant"
 msgstr "utiliser « typename %E » si un type est désiré"
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, fuzzy, gcc-internal-format
 #| msgid "missing static field `%s'"
 msgid "using invalid field %qD"
 msgstr "champ statique manquant « %s »"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "utilisation invalide d'expression void"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%q+D declared here, later in the translation unit"
 msgstr "« %s » non déclaré ici (hors de toute fonction)"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qT is not a class or namespace"
 msgstr "« %T » n'est pas une classe ou un espace de noms"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a class or namespace"
 msgid "%qD is not a class or namespace"
 msgstr "« %D » n'est pas une classe ou un espace de noms"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' uses anonymous type"
 msgid "%qT is/uses anonymous type"
 msgstr "« %T » utilise un type anonyme"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "argument par défaut pour « %#D » à un type « %T »"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is a variably modified type"
 msgid "%qT is a variably modified type"
 msgstr "« %T » est type modifié de manière variable"
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression `%E' is not constant"
 msgid "integral expression %qE is not constant"
 msgstr "expression intégrale « %E » n'est pas une constante"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, fuzzy, gcc-internal-format
 #| msgid "  trying to instantiate `%D'"
 msgid "  trying to instantiate %qD"
 msgstr "  tentative d'instantiation « %D »"
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instantiation ambiguë de patron de classe pour « %#T »"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instantiation ambiguë de patron de classe pour « %#T »"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instantiation explicite d'un non patron « %#D »"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' is not a non-static data member of `%T'"
 msgid "%qD is not a static data member of a class template"
 msgstr "« %#D » n'est pas un membre statique de données de « %T »"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching template for %qD found"
 msgstr "non concordance de patron pour « %D » repéré"
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "instantiation explicite de type non patron « %T »"
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D'"
 msgid "explicit instantiation of %q#D"
 msgstr "instantiation explicite de « %#D »"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#D'"
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "duplication d'instantiation explicite de « %#D »"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `extern' on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ interdit l'utilisation de « extern » sur instantiations explicites"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "storage class %qD applied to template instantiation"
 msgstr "classe de stockage « %D » appliqué à l'instantiation du patron"
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instantiation explicite d'un non patron « %#D »"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instantiation explicite de type non patron « %T »"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#T' before definition of template"
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instantiation explicite de « %#T » avant la définition de patron"
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `%s' on explicit instantiations"
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ interdit l'utilisation de « %s » sur instantiations explicites"
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#T'"
 msgid "duplicate explicit instantiation of %q#T"
@@ -45016,70 +45064,70 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%D' but no definition available"
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instantiation explicite de « %D » mais pas de définition disponible"
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "instantiation de la profondeur du patron excède le maximum de %d (utiliser -ftemplate-depth-NN pour augmenter le maximum) lors de l'instantiation de « %D »"
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "paramètre d'interception invalide"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "« %#T » n'a pas un type valide pour un patron de paramètre de constante"
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "initialiseur utilisé entre accolades pour initialiser « %T »"
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, fuzzy, gcc-internal-format
 #| msgid "%s as integer rather than floating due to prototype"
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%s est entier plutôt que flottant en raison du prototype"
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Déclaration de méthode invalide, type retourné requis"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "nouveaux types ne peuvent être définis dans un type à retourner"
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
@@ -45349,53 +45397,53 @@
 msgid "invalid base-class specification"
 msgstr "spécification de base de classe invalide"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, fuzzy, gcc-internal-format
 #| msgid "protected member `%#D' in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "membre protégé « %#D » dans une union anonyme"
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD is not captured"
 msgstr "« %D » n'est pas déclaré"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "utilisation de %s d'un fonction contenante"
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of parameter from containing function"
 msgstr "utilisation de %s d'un fonction contenante"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter `%D' of type `%T' is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "paramètre « %D » du patron du type « %T » ne sont pas permises dans une expression intégrale de constante parce qu'elle n'est pas intégral ou un type énumération"
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace `%D' as expression"
 msgid "use of namespace %qD as expression"
 msgstr "utilisation d'un espace de noms « %D » comme expression"
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "use of class template %qT as expression"
@@ -45402,25 +45450,25 @@
 msgstr "utilisation du patron de classe « %T » comme expression"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' is ambiguous in multiple inheritance lattice"
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "requête du membre « %D » est ambiguë dans de multiples héritage de treillis"
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot appear in a constant-expression"
 msgid "%qD cannot appear in a constant-expression"
 msgstr "« %D » ne peut apparaître dans une expression de constante"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "type of `%E' is unknown"
 msgid "type of %qE is unknown"
 msgstr "type « %E » est inconnu"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "%qT is not an enumeration type"
@@ -45427,213 +45475,213 @@
 msgstr "« %T » n'est pas un type patron"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "spécificateurs de classe de stockage invalides dans la déclaration des paramètres"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function `%D'"
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "utilisation invalide d'un membre non statique de fonction « %D »"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, fuzzy, gcc-internal-format
 #| msgid "reference to `%D' is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "référence à « %D » est ambiguë"
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, fuzzy, gcc-internal-format
 #| msgid "invalid return type for function `%#D'"
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "type retourné invalide pour la fonction « %#D »"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression must be referable"
 msgid "linear step expression must be integral"
 msgstr "expression %s doit être référable"
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in clause %qs"
 msgstr "« %s » n'est pas un nom de classe valide"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "instance de la variable « %s » est déclaré privée"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "instance de la variable « %s » est déclaré privée"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression must be referable"
 msgid "num_threads expression must be integral"
 msgstr "expression %s doit être référable"
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression must be referable"
 msgid "schedule chunk size expression must be integral"
 msgstr "expression %s doit être référable"
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression must be referable"
 msgid "%qs length expression must be integral"
 msgstr "expression %s doit être référable"
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, fuzzy, gcc-internal-format
 #| msgid "case label must be a discrete constant expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "l'étiquette du CASE doit être une expression de constante discrète"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression must be referable"
 msgid "%<num_teams%> expression must be integral"
 msgstr "expression %s doit être référable"
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression must be referable"
 msgid "%<async%> expression must be integral"
 msgstr "expression %s doit être référable"
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression must be referable"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "expression %s doit être référable"
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "« %s » n'est pas un nom de classe valide"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "« %s » n'est pas un nom de classe valide"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid reference type"
 msgid "%qE has reference type for %qs"
 msgstr "Type de référence invalide"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, fuzzy, gcc-internal-format
 #| msgid "%Jnon-static declaration of '%D' follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "déclaration non statique de « %D » suite une déclaration statique"
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 to MODIFY must be a string"
 msgid "argument to decltype must be an expression"
 msgstr "argument 2 de MODIFY doit être une chaîne"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
@@ -45651,135 +45699,135 @@
 msgid "lambda-expression in a constant expression"
 msgstr "débordement dans l'expression de la constante"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to Java class definitions"
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "attribut « %s » peut seulement être appliqué aux définitions de classes Java"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "attribut « %s » peut seulement être appliqué aux définitions de classes"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is obsolete; g++ vtables are now COM-compatible by default"
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr "« %s » est obsolète; vtables g++ sont maintenant COM-compatibles par défaut"
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "init_priority demandé n'est pas une constante entière"
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, fuzzy, gcc-internal-format
 #| msgid "can only use `%s' attribute on file-scope definitions of objects of class type"
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "peut seulement utiliser l'attribut « %s » sur la portée de fichier de définitions des objets de type de classe"
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "init_priority demandé est hors limite"
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "init_priority demandé est réservé pour un usage interne"
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute is not supported on this platform"
 msgid "%qE attribute is not supported on this platform"
 msgstr "attribut « %s » n'est pas supporté sur cette plate-forme"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "déclaration de « %D » comme « %s »"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "previous declaration here"
 msgstr "déclaration précédente de « %#D » ici"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "the %qE attribute requires arguments"
 msgstr "l'attribut « %s » requiert un argument de type constante entière"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argument de l'attribut « %s » n'est pas une chaîne de constante"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argument de l'attribut « %s » n'est pas une chaîne de constante"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "'%%%c' is not a valid operand prefix"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "« %%%c » n'est pas un préfixe d'opérande valide"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "l'attribut « %s » ne s'applique qu'à des types de fonction"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "attribut « %s » peut seulement être appliqué aux définitions de classes"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "classe de stockage « %D » appliqué à l'instantiation du patron"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "classe de stockage « %D » appliqué à l'instantiation du patron"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%E' attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "'%E l'attribut ne s'applique seulement qu'à des fonctions"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%E' attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "'%E l'attribut ne s'applique seulement qu'à des fonctions"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, fuzzy, gcc-internal-format
 #| msgid "use of C99 long long integer constant"
 msgid "zero as null pointer constant"
 msgstr "usage d'une constante entière « long long » à la C99"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "vérification lang_* : échec dans %s, à %s:%d"
@@ -46000,246 +46048,241 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr ""
 
-#: cp/typeck.c:3141
-#, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr "ISO C++ interdit le souscriptage de non lvalue de tableau"
-
-#: cp/typeck.c:3157
+#: cp/typeck.c:3148
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared `register'"
 msgid "subscripting array declared %<register%>"
 msgstr "souscriptage de tableau déclaré « register »"
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "la valeur indicée n'est ni un tableau ni un pointeur"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, fuzzy, gcc-internal-format
 #| msgid "object missing in use of `%E'"
 msgid "object missing in use of %qE"
 msgstr "objet manquant dans l'usage de « %E »"
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids calling `::main' from within program"
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ interdit l'appel de «::main» depuis l'intérieur du programme"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, fuzzy, gcc-internal-format
 #| msgid "must use .* or ->* to call pointer-to-member function in `%E (...)'"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "doit utiliser .* ou ->* pour l'appel de la fonction pointer-to-member dans « %E (...) »"
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "%qE cannot be used as a function"
 msgstr "« %E » ne peut être utilisé comme une fonction"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "« %E » ne peut être utilisé comme une fonction"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "« %E » ne peut être utilisé comme une fonction"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "too many arguments to constructor %q#D"
 msgstr "trop d'arguments pour %s « %+#D »"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "too few arguments to constructor %q#D"
 msgstr "pas assez d'argument pour %s « %+#D »"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to member function %q#D"
 msgstr "trop d'arguments pour la fonction"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to member function %q#D"
 msgstr "trop peu d'arguments pour la fonction"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %q#D"
 msgstr "trop d'arguments pour la fonction"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %q#D"
 msgstr "trop peu d'arguments pour la fonction"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "too many arguments to method %q#D"
 msgstr "trop d'arguments pour %s « %+#D »"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "too few arguments to method %q#D"
 msgstr "pas assez d'argument pour %s « %+#D »"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "trop d'arguments pour la fonction"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "trop peu d'arguments pour la fonction"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %P of `%D' has incomplete type `%T'"
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "paramètre %P de « %D » a un type incomplet « %T »"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %P has incomplete type `%T'"
 msgid "parameter %P has incomplete type %qT"
 msgstr "paramètre %P a un type incomplet « %T »"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, fuzzy, gcc-internal-format
 #| msgid "assuming cast to type `%T' from overloaded function"
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "transtypage vers le type « %T » est assumé à partir de la fonction surchargée"
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL utilisé en arithmétique"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "left rotate count is negative"
 msgstr "compteur de rotation %s est négatif"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "right rotate count is negative"
 msgstr "compteur de rotation %s est négatif"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "left rotate count >= width of type"
 msgstr "compteur de rotation %s >= largeur du type"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "right rotate count >= width of type"
 msgstr "compteur de rotation %s >= largeur du type"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweak declaration of '%D' after first use results in unspecified behavior"
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr "déclaration faible de « %D » après une première utilisation des résultats d'un comportement non spécifié"
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, fuzzy, gcc-internal-format
 #| msgid "the address of `%D', will always evaluate as `true'"
 msgid "the address of %qD will never be NULL"
 msgstr "l'adresse de « %D » sera toujours évaluée comme étant « true »"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ interdit la comparaison entre un pointeur et un entier"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "comparaison non ordonnée sur un argument n'étant pas en virgule flottante"
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands of types `%T' and `%T' to binary `%O'"
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "opérandes invalides pour les types « %T » et « %T » en binaire « %O »"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids using pointer of type `void *' in subtraction"
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ interdit l'utilisation d'un pointeur de type « void * » dans une soustraction"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ interdit l'utilisation d'un pointeur survers une fonction dans une soustraction"
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ interdit l'utilisation d'un pointeur survers une méthode dans une soustraction"
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "utilisation invalide d'un pointeur vers un type incomplet dans un pointeur arithmétique"
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of constructor %qE"
 msgstr "prise de l'adresse du destructeur"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of destructor %qE"
 msgstr "prise de l'adresse du destructeur"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' to form a pointer-to-member-function.  Use a qualified-id."
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "utilisation invalide de « %E » pour former pointer-to-member-function. Utiliser un identificateur qualifié"
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesis around '%E' cannot be used to form a pointer-to-member-function"
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
@@ -46246,13 +46289,13 @@
 msgstr "parenthèses autour de « %E » ne peuvent être utilisées pour former pointer-to-member-function"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say `&%T::%D'"
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ interdit de prendre l'adresse d'un membre de fonction non statique non qualifié ou entre parenthèses pour former un pointeur d'un membre de fonction. Utiliser «&%T::%D»"
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say `&%T::%D'"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
@@ -46259,29 +46302,29 @@
 msgstr "ISO C++ interdit de prendre l'adresse d'une borne d'un membre de fonction pour former un membre à la fonction. Disons «&%T::%D»"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "prise de l'adresse du temporaire"
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "prise de l'adresse du temporaire"
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking address of function `::main'"
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ interdit de prendre l'adresse d'une fonction «::main»"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr "ISO C++ interdit de prendre l'adresse du transtypage vers une expression n'étant pas membre gauche"
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member `%D'"
 msgid "cannot create pointer to reference member %qD"
@@ -46288,7 +46331,7 @@
 msgstr "ne peut déclarer un pointeur vers le membre de référence « %D »"
 
 # FIXME: I18N
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
@@ -46295,360 +46338,360 @@
 msgstr "ISO C++ interdit de %ser un enum"
 
 # FIXME: I18N
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ interdit de %ser un enum"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "ne peut utiliser %s comme pointeur sur un type incomplet « %T »"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "ne peut utiliser %s comme pointeur sur un type incomplet « %T »"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type `%T'"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ interdit %s utilisation d'un pointeur de type « %T »"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type `%T'"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ interdit %s utilisation d'un pointeur de type « %T »"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "expression invalide comme opérande"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of `this', which is an rvalue expression"
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "ne peut prendre l'adresse de « ceci », laquelle est une expression rvalue"
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable `%s' requested"
 msgid "address of explicit register variable %qD requested"
 msgstr "adresse d'une variable registre « %s » requise"
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, fuzzy, gcc-internal-format
 #| msgid "address requested for `%D', which is declared `register'"
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adresse requise pour « %D», lequel est déclaré «register »"
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s liste d'expressions traitée comme une expression composée"
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s liste d'expressions traitée comme une expression composée"
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s liste d'expressions traitée comme une expression composée"
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s liste d'expressions traitée comme une expression composée"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "%s from type `%T' to type `%T' casts away constness"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "%S à partir du « %T » vers le type « %T » provoque un transtypage sans constante"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, fuzzy, gcc-internal-format
 #| msgid "%s from type `%T' to type `%T' casts away constness"
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "%S à partir du « %T » vers le type « %T » provoque un transtypage sans constante"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from `%T' to `%T' casts away const (or volatile)"
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast de « %T » vers « %T » fait un transtypage écartant la constante (ou volatile)"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' uses local type `%T'"
 msgid "useless cast to type %qT"
 msgstr "« %T » utilise un type local « %T »"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type `%T' to type `%T'"
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "static_cast invalide du type « %T » au type « %T »"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "converting from %qT to %qT"
 msgstr "conversion de « %T » vers « %T »"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast of an rvalue expression of type `%T' to type `%T'"
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "reinterpret_cast invalide d'une expression rvalue de type « %T » vers le type « %T »"
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from `%T' to `%T' loses precision"
 msgid "cast from %qT to %qT loses precision"
 msgstr "reinterpret_cast de « %T » vers « %T » génère une perte de précision"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, fuzzy, gcc-internal-format
 #| msgid "cast from `%T' to `%T' increases required alignment of target type"
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "transtypage de « %T » vers « %T » augmente l'alignement requis pour le type ciblé"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ interdit le transtypage entre un pointeur de fonction et un pointeur d'objet"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type `%T' to type `%T'"
 msgid "invalid cast from type %qT to type %qT"
 msgstr "const_cast invalide à partir du type « %T » vers le type « %T »"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type `%T', which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "utilisation invalide de const_cast avec le type « %T », lequel n'est pas un pointeur, une référence, ni un type pointeur-vers-données-membre"
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type `%T', which is a pointer or reference to a function type"
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "utilisation invalide de const_cast avec le type « %T », lequel est un pointeur ou un référence à un type de fonction"
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type `%T' to type `%T'"
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "const_cast invalide de la rvalue du type « %T » vers le type « %T »"
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type `%T' to type `%T'"
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "const_cast invalide à partir du type « %T » vers le type « %T »"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting to an array type `%T'"
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ interdit le transtypage vers un type tableau « %T »"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "invalid cast to function type %qT"
 msgstr "transtypage invalide pour un type de fonction « %T »"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, fuzzy, gcc-internal-format
 #| msgid "  in evaluation of `%Q(%#T, %#T)'"
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  lors de l'évaluation de « %Q(%#T, %#T) »"
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "index de tableau non constant dans l'initialisation"
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "type incompatible dans l'affectation de « %T » vers « %T »"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, fuzzy, gcc-internal-format
 #| msgid "bad array initializer"
 msgid "array used as initializer"
 msgstr "mauvaise initialisation de tableau"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "invalid array assignment"
 msgstr "membre gauche de l'affectation invalide"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   dans la conversion d'un pointeur vers un membre de fonction"
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member conversion via virtual base `%T'"
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "conversion de pointeur à membre à l'aide de la base virtuelle « %T »"
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   dans la conversion d'un pointeur vers un membre"
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion to type `%T' from type `%T'"
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "conversion invalide vers un type « %T » à partir du type « %T »"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' for argument `%P' to `%D'"
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "ne peut convertir « %T » à « %T » pour l'argument « %P » vers « %D »"
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' for argument `%P' to `%D'"
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "ne peut convertir « %T » à « %T » pour l'argument « %P » vers « %D »"
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "ne peut convertir « %T » vers « %T » dans %s"
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT"
 msgstr "ne peut convertir « %T » vers « %T » dans %s"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "ne peut convertir « %T » vers « %T » dans %s"
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT in return"
 msgstr "ne peut convertir « %T » vers « %T » dans %s"
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "ne peut convertir « %T » vers « %T » dans %s"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "type retourné « %#T » est incomplet"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "Avertir à propos des fonctions qui pourraient être candidates pour les attributs de format"
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "la fonction est peut être candidate pour l'attribut de format de « %s »"
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Avertir à propos des fonctions qui pourraient être candidates pour les attributs de format"
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "la fonction est peut être candidate pour l'attribut de format de « %s »"
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "la fonction est peut être candidate pour l'attribut de format de « %s »"
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of `%+D'"
 msgid "in passing argument %P of %q+D"
 msgstr "dans le passage de l'argument %P de « %+D »"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "retourné la référence vers le temporaire"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "une référence vers quelque chose n'étant pas un membre gauche a été retourné"
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable `%D' returned"
 msgid "reference to local variable %q+D returned"
 msgstr "référence vers une variable locale « %D » retourné"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of label %q+D returned"
 msgstr "adresse d'une variable locale « %D » retournée"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of local variable %q+D returned"
 msgstr "adresse d'une variable locale « %D » retournée"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "retourné une valeur du destructeur"
@@ -46655,36 +46698,36 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "ne peut retourner d'un handler d'une fonction try-block d'un constructeur"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "retourné une valeur d'un constructeur"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning '%T'"
 msgid "return-statement with no value, in function returning %qT"
 msgstr "déclaration à retourner sans valeur dans une fonction retournant « %T »"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "initialisation manquante"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "déclaration éa retourner avec une valeur dans une fonction retournant un « void »"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' must not return NULL unless it is declared `throw()' (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
@@ -46691,12 +46734,12 @@
 msgstr "« operator new» ne doit pas retourner NULL à moins qu'il ne soit déclaré «throw() » (ou -fcheck-new est utilisée)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -46957,139 +47000,139 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of `%E' from `%T' to `%T' is ambiguous"
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "conversion de « %E » à partir de « %T » vers « %T » est ambiguë"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "tableau d'entier initialisé à l'aide d'une chaîne non-large"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "int-array initialized from non-wide string"
 msgid "int-array initialized from incompatible wide string"
 msgstr "tableau d'entier initialisé à l'aide d'une chaîne non-large"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "la chaîne d'initialisation est trop longue pour le tableau de caractères"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "missing initializer for member %qD"
 msgstr "initialiseur manquant pour le membre « %D »"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD is uninitialized reference"
 msgstr "membre « %D » est une référence non initialisée"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "membre « %D » est une référence non initialisée"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, fuzzy, gcc-internal-format
 #| msgid "no field `%D' in union being initialized"
 msgid "no field %qD found in union being initialized"
 msgstr "pas de champ « %D » dans l'agrégat n'a été initialisé"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valeur index au lieu du nom de champ dans l'initialiseur d'union"
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "délégation de pointeur circulaire détecté"
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' has non-pointer type `%T'"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "l'opérande de base de «->» a un type non pointeur « %T »"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, fuzzy, gcc-internal-format
 #| msgid "result of `operator->()' yields non-pointer result"
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "résultat de « operator->() » laisse comme résultat un non pointeur"
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' is not a pointer"
 msgid "base operand of %<->%> is not a pointer"
 msgstr "l'opérande de base de «->» n'est pas un pointeur"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a member pointer, since it is of type `%T'"
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "« %E » ne peut être utilisé comme pointeur de membre, alors qu'il est de type « %T »"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer `%E' to `%E', which is of non-aggregate type `%T'"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "ne peut appliquer un pointeur de membre « %E » à « %E », lequel n'est pas un type d'agrégat « %T »"
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, fuzzy, gcc-internal-format
 #| msgid "member type `%T::' incompatible with object type `%T'"
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "type du membre « %T:: » incompatible avec le type d'objet « %T »"
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "usage en arithmétique d'un pointeur vers une fonction membre"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "usage en arithmétique d'un pointeur vers une fonction membre"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "functional cast to array type %qT"
 msgstr "transtypage invalide pour un type de fonction « %T »"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, fuzzy, gcc-internal-format
 #| msgid "default-initialization of `%#D', which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "initialisation par défaut de « %#D », lequel a un type référencé"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "call to function `%D' which throws incomplete type `%#T'"
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "l'appel à la fonction « %D » laquelle écarte le type incomplet « %T »"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, fuzzy, gcc-internal-format
 #| msgid "call to function which throws incomplete type `%#T'"
 msgid "call to function which throws incomplete type %q#T"
@@ -47274,8 +47317,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -47420,7 +47463,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -47540,7 +47583,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -48151,12 +48194,12 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
@@ -48430,6 +48473,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr ""
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -48437,7 +48485,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -48669,427 +48717,427 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "ne peut initialiser un table multi-dimensionnel avec initialiseur"
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization designators may not nest"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "l'initialisation des désignateurs ne doit pas être imbriquée"
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Error in pointer initialization at %C"
 msgstr "initialisation en double de %D"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "non-NULL pointer initialization at %C"
 msgstr "initialisation en double de %D"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute not allowed for '%D'"
 msgid "Function name %qs not allowed at %C"
 msgstr "attribut de section n'est pas permis pour « %D »"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Zero-size array at %0"
 msgid "Implied-shape array at %L"
 msgstr "tableau de taille zéro à %0"
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Old-style initialization at %C"
 msgstr "initialisation en double de %D"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected an initialization expression at %C"
 msgstr "initialisation de la nouvelle expression avec « = »"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jweak declaration of '%D' not supported"
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "déclaration faible de « %D » n'est pas supportée"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid type-declaration attribute at %0"
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "type d'attribut de déclaration invalide à %0"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing formal parameter term"
 msgid "Missing right parenthesis at %C"
 msgstr "Paramètre term formel manquant"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected initialization expression at %C"
 msgstr "initialisation de la nouvelle expression avec « = »"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected scalar initialization expression at %C"
 msgstr "initialisation de la nouvelle expression avec « = »"
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "rounding mode not supported for VAX floats"
 msgid "Kind %d not supported for type %s at %C"
 msgstr "mode d'arrondissement n'est pas supporté pour les flottants sur VAX"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing parenthesis for procedure call"
 msgid "Missing right parenthesis or comma at %C"
 msgstr "parenthèse manquante dans l'appel de procédure"
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "rounding mode not supported for VAX floats"
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "mode d'arrondissement n'est pas supporté pour les flottants sur VAX"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error in exception list"
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "erreur de syntaxe dans la liste d'exception"
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "CLASS statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "reference to `%D' is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "référence à « %D » est ambiguë"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "déclaration VXT non supporté à %0"
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Empty IMPLICIT statement at %C"
 msgstr "déclaration VXT non supporté à %0"
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "IMPORT statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "faux nombre dans la déclaration de FORMAT à %0"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflicting I/O control specifications at %0 and %1"
 msgid "Missing codimension specification at %C"
 msgstr "spécifications conflictuelles de contrôle d'E/S à %0 et %1"
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing dimension specification at %C"
 msgstr "spécificateur %A manquant dans la déclaration à %0"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate %s attribute at %L"
 msgstr "duplication de  l'attribut ConstanValue pour le champ « %s »"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "attributs ne sont pas permis dans la définition de fonction"
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type attributes are honored only at type definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "type d'attributs sont honorés seulement lors de la définitions de type"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -49096,296 +49144,297 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "Missing term"
 msgid "Missing symbol"
 msgstr "Terme manquant"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "BIND(C) statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error in action"
 msgid "Syntax error in data declaration at %C"
 msgstr "erreur de syntaxe dans l,action"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "Alternate-return argument at %C"
 msgstr "type d'argument erroné pour %s"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "Do not schedule the start and end of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Ne pas ordonnancer le début et la fin de la procédure"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicts with function declaration `%#D'"
 msgid "Unexpected junk after function declaration at %C"
 msgstr "conflits avec la déclaration de fonction de « %#D »"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "l'attribut de section ne peut être spécifié pour des variables locales"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "faux nombre dans la déclaration de FORMAT à %0"
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "PROCEDURE statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "ENTRY statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "déclaration RETURN à %0 invalide à l'intérieur de l'unité du programme principal"
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "déclaration RETURN à %0 invalide à l'intérieur de l'unité du programme principal"
 
-#: fortran/decl.c:5597
-#, gcc-internal-format
-msgid "gfc_match_entry(): Bad state"
-msgstr ""
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Unsupported VXT statement at %0"
+msgid "Unexpected ENTRY statement at %C"
+msgstr "déclaration VXT non supporté à %0"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%s ne peut apparaître dans une expression de constante"
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid I specifier in FORMAT statement at %0"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "spécificateur I invalide dans la déclaration de FORMAT à %0"
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-> operator not allow in constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "opérateur -> n'est pas permis dans l'expression d'une constante"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing first operand for binary operator at %0"
 msgid "Missing closing paren for binding label at %C"
 msgstr "première opérande manquante pour l'opérateur biunaire à %0"
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected END statement at %C"
 msgstr "déclaration VXT non supporté à %0"
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "END statement instead of %s statement at %L"
@@ -49392,545 +49441,551 @@
 msgstr "pas de définition d'étiquette pour la déclaration de FORMAT à %0"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid %A statement at %0"
 msgid "%s statement expected at %L"
 msgstr "Déclaration %A invalide à %0"
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid %A statement at %0"
 msgid "Expecting %s statement at %L"
 msgstr "Déclaration %A invalide à %0"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid form for %A statement at %0"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Forme invalide pour la déclaration %A à %0"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "spécificateur %A manquant dans la déclaration à %0"
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr ""
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> atterdu à %C"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected a name string here"
 msgid "Expected variable name at %C"
 msgstr "un nom de chaîne est attendu ici"
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter 2 must be a positive integer"
 msgid "Cray pointer at %C must be an integer"
 msgstr "paramètre 2 doit être un entier positif"
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s not allowed outside a PROC"
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "%s n'est pas permis en dehors d'une procédure"
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "PROTECTED statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "faux nombre dans la déclaration de FORMAT à %0"
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Access specifier or PRIVATE statement at %0 invalid for derived-type definition within other than the specification part of a module"
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "spécificateur d'accès ou déclaration PRIVATE à %0 invalide pour une définition de type dérivé à l'intérieur d'autre chose que la portion de spécification d'un module"
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Access specifier or PRIVATE statement at %0 invalid for derived-type definition within other than the specification part of a module"
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "spécificateur d'accès ou déclaration PRIVATE à %0 invalide pour une définition de type dérivé à l'intérieur d'autre chose que la portion de spécification d'un module"
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious sign in FORMAT statement at %0"
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "faux signe dans la déclaration de FORMAT à %0"
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializing array with parameter list"
 msgid "Initializing already initialized variable at %C"
 msgstr "initialise le tableau avec la liste des paramètres"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Virgule superflue dans la déclaration de FORMAT à %0"
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form for %A statement at %0"
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Forme invalide pour la déclaration %A à %0"
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s not allowed outside a PROC"
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "%s n'est pas permis en dehors d'une procédure"
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "VALUE statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form for %A statement at %0"
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Forme invalide pour la déclaration %A à %0"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "VOLATILE statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "faux nombre dans la déclaration de FORMAT à %0"
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at `%D' because it has a destructor"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "  ne peut utiliser une liaison obsolète à « %D » parce qu'il a un destructeur"
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "Type name at %0 not the same as name at %1"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Nom de type à %0 n'est pas le même que le nom à %1"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type name expected before `*'"
 msgid "ENUM definition statement expected before %C"
 msgstr "nom de type attendu avec «*»"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error in exception list"
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "erreur de syntaxe dans la liste d'exception"
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "multiple access specifiers"
 msgid "Duplicate access-specifier at %C"
 msgstr "spécificateurs d'accès multiples"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "multiple access specifiers"
 msgid "Expected access-specifier at %C"
 msgstr "spécificateurs d'accès multiples"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> attendu à %C"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Invalid statement at %0"
+msgid "Malformed GENERIC statement at %C"
+msgstr "Déclaration invalide à %0"
+
+#: fortran/decl.c:8526
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "nom de registre inconnu: %s"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr ""
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
@@ -50219,352 +50274,352 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr ""
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "type incompatible dans l'affectation de « %T » vers « %T »"
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "type incompatible dans l'affectation de « %T » vers « %T »"
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "right hand side of assignment is a mode"
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "côté droit de l'affectation est un mode"
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "conversion invalide de « %T » vers « %T »"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "conversion invalide de « %T » vers « %T »"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from NaN to int"
 msgid "Conversion from %qs to %qs at %L"
 msgstr "conversion de NaN en int"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, fuzzy, gcc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Tableau ou sous-chaîne de spécification pour « %A » hors limite dans la déclaration à %0"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "membre gauche de l'affectation invalide"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "déclaration à %0 invalide dans le contexte établi par la déclaration à %1"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conditional expression not allowed in this context"
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "expression conditionnelle n'est pas permise dans ce contexte"
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "can't open output file `%s'"
 msgid "can't open input file: %s"
@@ -50589,27 +50644,27 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Pas d'appel dans la fonction %s\n"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr ""
@@ -50668,607 +50723,612 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr ""
+
+#: fortran/interface.c:353
+#, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr ""
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr ""
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr ""
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr ""
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr ""
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr ""
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr ""
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr ""
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr ""
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr ""
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
 msgstr ""
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, gcc-internal-format
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr ""
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, fuzzy, gcc-internal-format
 #| msgid "reference `%s' is ambiguous: appears in interface `%s' and interface `%s'"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "référence « %s » est ambigue: apparaît dans l'interface « %s » et l'interface « %s »"
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not a declared process"
 msgid "%qs at %L is not a module procedure"
 msgstr "%s n'est pas processus déclaré"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid actual argument at %0"
 msgid "Invalid procedure argument at %L"
 msgstr "argument actuel invalide à %0"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "non concordance de type/valeur pour l'argument %d dans la liste des paramètres du patron de « %D »"
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to `%s' must be a mode"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "premier argument de « %s » doit être un mode"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' must be of integer type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "argument de « %s » doit être de type entier"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to `%s' must be a mode"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "premier argument de « %s » doit être un mode"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %s must be a location"
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "argument %d de %s doit être une localisation"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "trop peu d'arguments pour la procédure"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' must be of integer type"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "argument de « %s » doit être de type entier"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to `%s' must be a mode"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "premier argument de « %s » doit être un mode"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Missing value at %1 for real-number exponent at %0"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Valeur manquante à %1 pour l'exposant d'un nombre réeal à %0"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "procédure externe « %A » est pass comme argument actuel à %0 mais non pas déclaré explicitement déclaré EXTERNAL"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "Unable to find symbol %qs"
 msgstr "échec de repérage de la classe « %s »"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - too many interface type"
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "erreur interne - trop de type d'interface"
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, gcc-internal-format
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
@@ -51709,12 +51769,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
@@ -51724,7 +51784,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
@@ -51749,134 +51809,134 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "FLUSH statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Range specification at %0 invalid"
 msgid "Duplicate UNIT specification at %C"
 msgstr "spécification d'étendue à %0 invalide"
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "bad format specification character (offset %d)"
 msgid "Duplicate format specification at %C"
 msgstr "caractère de format de spécification erroné (décalage %d)"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Range specification at %0 invalid"
 msgid "Duplicate NML specification at %C"
 msgstr "spécification d'étendue à %0 invalide"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported FORMAT specifier at %0"
 msgid "UNIT not specified at %L"
 msgstr "spécificateur de FORMAT non supporté à %0"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form for %A statement at %0"
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "Forme invalide pour la déclaration %A à %0"
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "ERR tag label %d at %L not defined"
 msgstr "étiquette « %D » utilisée mais non définie"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "END tag label %d at %L not defined"
 msgstr "étiquette « %D » utilisée mais non définie"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "EOR tag label %d at %L not defined"
 msgstr "étiquette « %D » utilisée mais non définie"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "FORMAT label %d at %L not defined"
 msgstr "étiquette « %D » utilisée mais non définie"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error in action"
 msgid "Syntax error in I/O iterator at %C"
 msgstr "erreur de syntaxe dans l,action"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expected variable in READ statement at %C"
 msgstr "Virgule superflue dans la déclaration de FORMAT à %0"
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "untyped expression as argument %d"
 msgid "Expected expression in %s statement at %C"
@@ -51883,690 +51943,690 @@
 msgstr "expression sans type comme argument %d"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form for %A statement at %0"
 msgid "Syntax error in %s statement at %C"
 msgstr "Forme invalide pour la déclaration %A à %0"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expected comma in I/O list at %C"
 msgstr "Virgule superflue dans la déclaration de FORMAT à %0"
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "déclaration RETURN à %0 invalide à l'intérieur de l'unité du programme principal"
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid %A statement at %0"
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "Déclaration %A invalide à %0"
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr ""
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
 msgstr ""
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "spécificateur %A manquant dans la déclaration à %0"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "spécificateur %A manquant dans la déclaration à %0"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer at %0 too large"
 msgid "Integer too large at %C"
 msgstr "entier à %0 est trop grand"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Too many dimensions at %0"
 msgid "Too many digits in statement label at %C"
 msgstr "trop de dimensions à %0"
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr ""
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 #| msgid "reference to `%D' is ambiguous"
 msgid "Label name %qs at %C is ambiguous"
 msgstr "référence à « %D » est ambiguë"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, gcc-internal-format
 msgid "Duplicate construct label %qs at %C"
 msgstr ""
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid `%c' character in name"
 msgid "Invalid character in name at %C"
 msgstr "caractère «%c» invalide dans le nom"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr ""
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr ""
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr ""
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr ""
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr ""
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error in action"
 msgid "Syntax error in iterator at %C"
 msgstr "erreur de syntaxe dans l,action"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, gcc-internal-format, gfc-internal-format
 msgid "gfc_match(): Bad match code %c"
 msgstr ""
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form for %A statement at %0"
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr "Forme invalide pour la déclaration %A à %0"
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Arithmetic IF statement at %C"
 msgstr "déclaration VXT non supporté à %0"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error in exception list"
 msgid "Syntax error in IF-expression at %C"
 msgstr "erreur de syntaxe dans la liste d'exception"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr "pas de définition d'étiquette pour la déclaration de FORMAT à %0"
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr ""
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error in action"
 msgid "Syntax error in IF-clause at %C"
 msgstr "erreur de syntaxe dans l,action"
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr "déclaration VXT non supporté à %0"
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "start label '%s' does not match end label '%s'"
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "étiquette de départ « %s » ne concorde pas avec l'étiquette de fin « %s »"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "CRITICAL statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr ""
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr ""
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr ""
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Duplicate name %qs in association at %C"
 msgstr "initialisation en double de %D"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, gcc-internal-format
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr ""
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid %A statement at %0"
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr "Déclaration %A invalide à %0"
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, gcc-internal-format
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid typeless constant at %1"
 msgid "Invalid type-spec at %C"
 msgstr "constante sans type invalide à %1"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error in action"
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "erreur de syntaxe dans l,action"
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr ""
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "%s statement at %C is not within a construct"
 msgstr "déclaration à %0 invalide dans ce contexte"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "%s statement at %C is not within construct %qs"
 msgstr "déclaration à %0 invalide dans ce contexte"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 follows ELSE block for IF construct at %1"
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "Déclaration à %0 suivant un bloc ELSE pour le construit IF à %1"
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr ""
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "PAUSE statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid %A statement at %0"
 msgid "ERROR STOP statement at %C"
 msgstr "Déclaration %A invalide à %0"
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "LOCK statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "UNLOCK statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "SYNC statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid statement at %0"
 msgid "ASSIGN statement at %C"
 msgstr "Déclaration invalide à %0"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious sign in FORMAT statement at %0"
 msgid "Assigned GOTO statement at %C"
 msgstr "faux signe dans la déclaration de FORMAT à %0"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "RETURN statement in main program at %C"
 msgstr "déclaration RETURN à %0 invalide à l'intérieur de l'unité du programme principal"
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "object missing in reference to `%D'"
 msgid "Expected component reference at %C"
 msgstr "objet manquant dans la référence à « %D »"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error in macro parameter list"
 msgid "Syntax error in common block name at %C"
@@ -52575,157 +52635,157 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr ""
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attempt to extend COMMON area beyond its starting point via EQUIVALENCE of `%A'"
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Tentative d'étendre la zone COMMON au delà de son point de départ via EQUIVALENCE de « %A »"
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement function `%A' defined at %0 is not used"
 msgid "Statement function at %L is recursive"
 msgstr "déclaration de fonction « %A » définie à %0 n'est pas utilisée"
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In statement function"
 msgid "Statement function at %C"
 msgstr "Dans la déclaration de fonction"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected initialization expression in CASE at %C"
 msgstr "initialisation de la nouvelle expression avec « = »"
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "faux nombre dans la déclaration de FORMAT à %0"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected CASE statement at %C"
 msgstr "déclaration VXT non supporté à %0"
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in CASE specification at %C"
 msgstr "erreur d'analyse syntaxique dans la spécification de fonction"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "déclaration VXT non supporté à %0"
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "erreur d'analyse syntaxique dans la spécification de fonction"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "erreur d'analyse syntaxique dans la spécification de fonction"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "start label '%s' does not match end label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -52880,175 +52940,175 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s for writing: %m"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "ne peut ouvrir %s en écriture: %m"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 #| msgid "%s: error writing file `%s': %s\n"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: erreur d'écriture au fichier « %s »: %s\n"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file `%s': %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: ne peut détruire le fichier « %s »: %s\n"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "%s: warning: can't rename file `%s' to `%s': %s\n"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: AVERTISSEMENT: ne peut renommer le fichier « %s » à « %s »: %s\n"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete aux info file `%s': %s\n"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: ne peut détruire le fichier auxiliaire d'infos « %s »: %s\n"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 #| msgid "Symbols have a leading underscore"
 msgid "Symbol %qs already declared"
 msgstr "Les symboles sont précédées d'un caractère de soulignement "
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: ne peut ouvrir le fichier « %s » en lecture: %s\n"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr ""
@@ -53347,7 +53407,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -54052,380 +54112,375 @@
 msgid "Unexpected %s statement at %C"
 msgstr "déclaration VXT non supporté à %0"
 
-#: fortran/parse.c:2428
-#, gcc-internal-format, gfc-internal-format
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr ""
-
-#: fortran/parse.c:2439
+#: fortran/parse.c:2438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "déclaration à %0 invalide dans le contexte établi par la déclaration à %1"
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 #| msgid "expected to return to file \"%s\""
 msgid "Unexpected end of file in %qs"
 msgstr "attendait retourner au fichier \"%s\""
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of `%D'"
 msgid "FINAL procedure declaration at %C"
 msgstr "déclaration précédente de « %D »"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "déclaration VXT non supporté à %0"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "déclaration VXT non supporté à %0"
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr ""
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in BLOCK DATA program unit at %1"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "Déclaration à %0 invalide dans le bloc de donnée de l'unité programme à %1"
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid token at %0 in expression or subexpression at %1"
 msgid "Bad kind expression for function %qs at %L"
 msgstr "élément lexical invalide à %0 dans l'expression ou la sous-expression à %1"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr ""
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PUBLIC or PRIVATE statement at %1 cannot be specified along with PUBLIC or PRIVATE statement at %0"
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "déclaration PUBLIC ou PRIVATE à %1 ne peut être spécifié en même temps avec la déclaration PUBLIC ou PRIVATE à %0"
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In construct"
 msgid "BLOCK construct at %C"
 msgstr "Dans le construit"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "start label '%s' does not match end label '%s'"
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "étiquette de départ « %s » ne concorde pas avec l'étiquette de fin « %s »"
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "Expecting %s at %C"
 msgstr "dans %s, à %s:%d"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr ""
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORMAT at %0 with run-time expression must follow first executable statement"
 msgid "DATA statement at %C after the first executable statement"
 msgstr "FORMAT à %0 dans l'expression lors de l'exécution doit suivre la première déclaration exécutable"
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr ""
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "déclaration RETURN à %0 invalide à l'intérieur de l'unité du programme principal"
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected %s statement in MODULE at %C"
@@ -54434,7 +54489,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -55159,7 +55214,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Label %d referenced at %L is never defined"
@@ -55220,376 +55275,376 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr ""
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, fuzzy, gcc-internal-format
 #| msgid "Reference to intrinsic function `%A' as if it were a subroutine at %0"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "référence à une fonction intrinsèque «%A» comme s'il est une sous-routine à %0"
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qs at %L is not a function"
 msgstr "« %D » n'est pas une fonction"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "resolve_function(): bad function type"
 msgstr "sizeof appliqué sur un type de fonction"
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, fuzzy, gcc-internal-format
 #| msgid "cast does not match function type"
 msgid "resolve_subroutine(): bad function type"
 msgstr "le transtypage ne concorde pas avec le type de la fonction"
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "shared and mdll are not compatible"
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "shared et mdll ne sont pas compatibles"
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible modes in concat expression"
 msgid "compare_bound_int(): Bad expression"
 msgstr "modes incompatibles dans l'expression de concaténation"
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "indice manquant dans la référence du tableau"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "mode mismatch in parameter %d"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "non concordance du mode dans le paramètre %d"
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument %d of %s must be a location"
 msgid "Argument dim at %L must be scalar"
 msgstr "argument %d de %s doit être une localisation"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to `%s' must be of integer type"
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "argument de « %s » doit être de type entier"
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array `%A' at %0 is too large to handle"
 msgid "Array index at %L is an array of rank %d"
 msgstr "tableau « %A » à %0 est trop grand pour être traité"
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring begin/end point at %0 out of defined range"
 msgid "Substring end index at %L must be scalar"
 msgstr "point begin/end de la sous-chaîne à %0 en dehors de la plage définie"
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is too large"
 msgid "Substring end index at %L is too large"
 msgstr "l'alignement demandé est trop grand"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -55598,12 +55653,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -55612,256 +55667,256 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s parameter %d must be a location"
 msgid "%s at %L must be a scalar"
 msgstr "%s paramètre %d doit être une localisation"
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to `%s' must be of integer type"
 msgid "%s at %L must be integer"
 msgstr "argument de « %s » doit être de type entier"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DO FOR start expression is a numbered SET"
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "expression de départ de DO FOR est un SET énuméré"
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid I specifier in FORMAT statement at %0"
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "spécificateur I invalide dans la déclaration de FORMAT à %0"
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid I specifier in FORMAT statement at %0"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "spécificateur I invalide dans la déclaration de FORMAT à %0"
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid I specifier in FORMAT statement at %0"
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "spécificateur I invalide dans la déclaration de FORMAT à %0"
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid I specifier in FORMAT statement at %0"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "spécificateur I invalide dans la déclaration de FORMAT à %0"
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid I specifier in FORMAT statement at %0"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "spécificateur I invalide dans la déclaration de FORMAT à %0"
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -55870,120 +55925,120 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "la déclaration de l'expression a un type incomplet"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Range specification at %0 invalid"
 msgid "Range specification at %L can never be matched"
 msgstr "spécification d'étendue à %0 invalide"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 #| msgid "Unimplemented intrinsic `%A' at %0"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "intrinsèque «%A» non implanté à %0"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid reference to intrinsic `%A' at %0"
 msgid "Invalid context for NULL () intrinsic at %L"
@@ -55990,75 +56045,75 @@
 msgstr "référence invalide vers l'intrinsèque «%A» à %0"
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument %d must be referable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "argument %d doit pouvoir être référencé"
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "first argument to `%s' must be a mode"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "premier argument de « %s » doit être un mode"
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "déclaration à %0 invalide dans le contexte établi par la déclaration à %1"
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -56065,12 +56120,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -56078,160 +56133,160 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "déclaration à %0 invalide dans le contexte établi par la déclaration à %1"
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "déclaration VXT non supporté à %0"
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr ""
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr ""
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr ""
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -56238,7 +56293,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -56246,58 +56301,58 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr ""
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer at %0 too large"
 msgid "String length at %L is too large"
 msgstr "entier à %0 est trop grand"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
@@ -56304,431 +56359,431 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, fuzzy, gcc-internal-format
 #| msgid "%Jfinal field '%D' may not have been initialized"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "champ final « %D » peut ne pas avoir été initialisé"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, fuzzy, gcc-internal-format
 #| msgid "%Jfinal field '%D' may not have been initialized"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "champ final « %D » peut ne pas avoir été initialisé"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, fuzzy, gcc-internal-format
 #| msgid "%Jfinal field '%D' may not have been initialized"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "champ final « %D » peut ne pas avoir été initialisé"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, fuzzy, gcc-internal-format
 #| msgid "%Jfinal field '%D' may not have been initialized"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "champ final « %D » peut ne pas avoir été initialisé"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "%Jfinal field '%D' may not have been initialized"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "champ final « %D » peut ne pas avoir été initialisé"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "fonction ne pas pas être enligne"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object of type `%T' may not be initialized"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "un objet de taille variable de type « %T » peut ne pas être initialisé"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "« %D » doit prendre exactement un argument"
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %s must be a location"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "argument %d de %s doit être une localisation"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -56735,400 +56790,400 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible types in %s"
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "type incompatibles dans %s"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "étiquette « %D » définie mais non utilisée"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "étiquette « %D » définie mais non utilisée"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -57160,51 +57215,51 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr ""
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr ""
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr ""
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "Unrecognized value for character constant at %0"
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "valeur non reconnue pour la constante caractère à %0"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "converting to execution character set"
 msgid "Nonconforming tab character at %C"
 msgstr "conversion vers un jeu d'exécution de caractères"
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
 msgstr ""
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr ""
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "file \"%s\" left but not entered"
 msgid "%s:%d: file %s left but not entered"
 msgstr "fichier \"%s\" a été laissé mais n'a pas été entré"
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s in preprocessing directive"
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr "%s dans la directive du préprocesseur"
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "can't open output file `%s'"
 msgid "Can't open file %qs"
@@ -57479,54 +57534,54 @@
 msgid "Reshaped array too large at %C"
 msgstr ""
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr ""
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "function call has aggregate value"
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "l'appel de fonction a une valeur d'agrégat"
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "invalid argument of SQRT at %L"
 msgstr "type d'argument invalide pour l'attribut « %s »"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -57605,320 +57660,326 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "procédure externe « %A » est pass comme argument actuel à %0 mais non pas déclaré explicitement déclaré EXTERNAL"
+
+#: fortran/symbol.c:489
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr ""
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%s attribute applied to %s %s at %L"
 msgstr "attribut « %s » s'applique seulement aux fonctions"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "attribut « %s » s'applique seulement aux variables"
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, gcc-internal-format
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "%s attribute with %s attribute at %L"
 msgstr "l'argument pour l'attribut « %s » est plus grand que %d"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, gcc-internal-format
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "duplication de l'attribut « %s » spécifié par %L"
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement or attribute at %1 cannot be specified along with SAVE statement or attribute at %0"
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "déclaration SAVE ou attribut à %1 ne peut être spécifiée en même temps avec la déclaration SAVE ou l'attribut à %0"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "duplication de  l'attribut ConstantValue pour le champ « %s »"
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "duplication de  l'attribut ConstantValue pour le champ « %s »"
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area of '%s' conflicts with previous declaration"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "l'adresse de la zone « %s » entre en conflit avec un déclaration précédente"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) à %L"
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS à %L"
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr ""
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Le symbole %qs à %C est ambiguë"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs à %C n'est pas un membre de la structure %qs"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -58187,7 +58248,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -59796,3 +59857,6 @@
 #, gcc-internal-format
 msgid "creating selector for nonexistent method %qE"
 msgstr "création du sélection pour une méthode inexistante %qE"
+
+#~ msgid "ISO C++ forbids subscripting non-lvalue array"
+#~ msgstr "ISO C++ interdit le souscriptage de non lvalue de tableau"
Index: gcc/po/hr.po
===================================================================
--- gcc/po/hr.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/hr.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.7.1\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2012-07-05 15:49+0200\n"
 "Last-Translator: Tomislav Krznar <tomislav.krznar@gmail.com>\n"
 "Language-Team: Croatian <lokalizacija@linux.hr>\n"
@@ -201,13 +201,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1376,7 +1376,7 @@
 msgid "options enabled: "
 msgstr "omogućene opcije: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2568,97 +2568,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr ""
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr ""
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr ""
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr ""
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr ""
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr ""
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr ""
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr ""
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr ""
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr ""
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr ""
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr ""
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr ""
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr ""
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr ""
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr ""
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr ""
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, c-format
 msgid "invalid operand address"
 msgstr ""
@@ -2711,7 +2711,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr ""
@@ -2865,8 +2865,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3086,65 +3086,65 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand size for operand code 'O'"
 msgstr "neispravni izraz kao operand"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand size for operand code 'z'"
 msgstr "neispravni izraz kao operand"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr ""
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "neispravni izraz kao operand"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr ""
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr ""
 
@@ -3184,7 +3184,7 @@
 msgid "invalid %%P operand"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -3248,7 +3248,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr ""
 
@@ -3411,100 +3411,100 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid %%e value"
 msgstr "neispravni %%-kod"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 msgid "Unable to generate load offset for fusion"
 msgstr ""
 
@@ -3598,60 +3598,60 @@
 msgid "invalid operand to %%S"
 msgstr ""
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr ""
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr ""
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr ""
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr ""
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr ""
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, c-format
 msgid "invalid %%C operand"
 msgstr ""
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, c-format
 msgid "invalid %%D operand"
 msgstr ""
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr ""
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr ""
@@ -3854,7 +3854,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "očekujem %<;%>"
@@ -3870,15 +3870,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "očekujem %<(%>"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "očekujem %<,%>"
@@ -3900,8 +3900,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "očekujem %<)%>"
@@ -3908,8 +3908,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "očekujem %<]%>"
@@ -3918,13 +3918,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "očekujem %<}%>"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "očekujem %<{%>"
@@ -3931,8 +3931,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "očekujem %<:%>"
@@ -3953,7 +3953,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "očekujem %<while%>"
@@ -3970,34 +3970,34 @@
 msgid "expected %<.%>"
 msgstr "očekujem %<.%>"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "očekujem %<@end%>"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "očekujem %<>%>"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "očekujem %<=%>"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "očekujem %<[%>"
@@ -4006,11 +4006,11 @@
 msgid "(anonymous)"
 msgstr ""
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr ""
 
@@ -4224,11 +4224,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4275,48 +4275,48 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4411,7 +4411,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr ""
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 msgid "array assignment"
 msgstr ""
 
@@ -4430,7 +4430,7 @@
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4496,13 +4496,13 @@
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4580,7 +4580,7 @@
 msgid "Bad type in constant expression"
 msgstr ""
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 msgid "Unexpected end of module"
 msgstr ""
 
@@ -4608,11 +4608,11 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 msgid "pointer assignment"
 msgstr ""
 
@@ -4628,189 +4628,189 @@
 msgid "internal function"
 msgstr ""
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 msgid "allocatable argument"
 msgstr ""
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 msgid "asynchronous argument"
 msgstr ""
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 msgid "optional argument"
 msgstr ""
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 msgid "pointer argument"
 msgstr ""
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 msgid "target argument"
 msgstr ""
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 msgid "value argument"
 msgstr ""
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 msgid "volatile argument"
 msgstr ""
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 msgid "assumed-shape argument"
 msgstr ""
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 msgid "assumed-rank argument"
 msgstr ""
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 msgid "coarray argument"
 msgstr ""
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 msgid "polymorphic argument"
 msgstr ""
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 msgid "assumed-type argument"
 msgstr ""
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr ""
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5214,16 +5214,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr ""
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr ""
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr ""
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr ""
@@ -5236,6 +5226,10 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr ""
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+msgid "profiling not supported with -mg"
+msgstr ""
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr ""
@@ -5244,10 +5238,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr ""
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr ""
-
 #: config/cris/cris.h:184
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr ""
@@ -5276,6 +5266,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr ""
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5282,6 +5278,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr ""
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr ""
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr ""
@@ -5294,6 +5294,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr ""
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr ""
+
 #: config/avr/specs.h:68
 msgid "shared is not supported"
 msgstr ""
@@ -5319,17 +5323,19 @@
 msgid "no processor type specified for linking"
 msgstr ""
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr ""
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr ""
 
@@ -5365,10 +5371,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr ""
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-msgid "profiling not supported with -mg"
-msgstr ""
-
 #: fortran/lang.opt:146
 msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgstr ""
@@ -5547,9 +5549,9 @@
 msgstr ""
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -5754,10 +5756,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -5803,7 +5805,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr ""
@@ -7650,44 +7652,48 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 msgid "Specify the code model"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -8753,10 +8759,14 @@
 msgstr ""
 
 #: config/i386/i386.opt:864
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:868
 msgid "Use given stack-protector guard"
 msgstr ""
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr ""
 
@@ -9103,7 +9113,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -9250,7 +9260,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 msgid "Use LRA instead of reload"
 msgstr ""
@@ -9375,7 +9385,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr ""
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr ""
 
@@ -9692,299 +9702,299 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 msgid "Generate isel instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 msgid "Deprecated option.  Use -misel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 msgid "Generate PPC750CL paired-single instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 msgid "Deprecated option.  Use -mspe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 msgid "-mdebug=\tEnable debug output"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 msgid "Use the AltiVec ABI extensions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 msgid "Do not use the AltiVec ABI extensions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 msgid "Use the SPE ABI extensions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 msgid "Do not use the SPE ABI extensions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 msgid "Use the ELFv1 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 msgid "Use the ELFv2 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 msgid "using darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 msgid "using old darwin ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 msgid "Generate Cell microcode"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 msgid "Valid arguments to -malign-:"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 msgid "Single-precision floating point unit"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 msgid "Double-precision floating point unit"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 msgid "Floating point unit does not support divide & sqrt"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 msgid "Specify Xilinx FPU."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 msgid "Allow sign extension in fusion operations"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
-msgid "Use ISA 2.07 crypto instructions"
+#: config/rs6000/rs6000.opt:566
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -12761,1540 +12771,1540 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr ""
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr ""
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr ""
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr ""
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr ""
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr ""
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr ""
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr ""
 
-#: common.opt:918
+#: common.opt:921
 msgid "Generate auto-inc/dec instructions"
 msgstr ""
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr ""
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr ""
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr ""
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr ""
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr ""
 
-#: common.opt:960
+#: common.opt:963
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr ""
 
-#: common.opt:964
+#: common.opt:967
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr ""
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr ""
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr ""
 
-#: common.opt:979
+#: common.opt:982
 msgid "Check the return value of new in C++"
 msgstr ""
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr ""
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr ""
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr ""
 
-#: common.opt:1003
+#: common.opt:1006
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr ""
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr ""
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr ""
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr ""
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr ""
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr ""
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr ""
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr ""
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr ""
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr ""
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr ""
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr ""
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 msgid "Perform speculative devirtualization"
 msgstr ""
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1085
+#: common.opt:1088
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr ""
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1145
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr ""
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr ""
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr ""
 
-#: common.opt:1157
+#: common.opt:1160
 msgid "Suppress output of addresses in debugging dumps"
 msgstr ""
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 msgid "Dump optimization passes"
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1173
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1177
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr ""
 
-#: common.opt:1190
+#: common.opt:1193
 msgid "Perform interprocedural reduction of aggregates"
 msgstr ""
 
-#: common.opt:1194
+#: common.opt:1197
 msgid "Perform unused symbol elimination in debug info"
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr ""
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr ""
 
-#: common.opt:1217
+#: common.opt:1220
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr ""
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr ""
 
-#: common.opt:1238
+#: common.opt:1241
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr ""
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr ""
 
-#: common.opt:1250
+#: common.opt:1253
 msgid "Perform a forward propagation pass on RTL"
 msgstr ""
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr ""
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr ""
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr ""
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr ""
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr ""
 
-#: common.opt:1305
+#: common.opt:1308
 msgid "Enable in and out of Graphite representation"
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1312
 msgid "Enable Graphite Identity transformation"
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1316
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr ""
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr ""
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr ""
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr ""
 
-#: common.opt:1330
+#: common.opt:1333
 msgid "Enable Loop Blocking transformation"
 msgstr ""
 
-#: common.opt:1334
+#: common.opt:1337
 msgid "Enable Loop Unroll Jam transformation"
 msgstr ""
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr ""
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr ""
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr ""
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr ""
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1394
+#: common.opt:1397
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr ""
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr ""
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr ""
 
-#: common.opt:1410
+#: common.opt:1413
 msgid "Perform indirect inlining"
 msgstr ""
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr ""
 
-#: common.opt:1424
+#: common.opt:1427
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr ""
 
-#: common.opt:1428
+#: common.opt:1431
 msgid "Integrate functions only required by their single caller"
 msgstr ""
 
-#: common.opt:1435
+#: common.opt:1438
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr ""
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1458
 msgid "Perform interprocedural constant propagation"
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1466
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1470
 msgid "Perform interprocedural profile propagation"
 msgstr ""
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr ""
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 msgid "Perform Identical Code Folding for variables"
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr ""
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr ""
 
-#: common.opt:1506
+#: common.opt:1509
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr ""
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr ""
 
-#: common.opt:1519
+#: common.opt:1522
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr ""
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr ""
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr ""
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr ""
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr ""
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 msgid "Enable link-time optimization."
 msgstr ""
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr ""
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr ""
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 msgid "Report various link-time optimization statistics"
 msgstr ""
 
-#: common.opt:1625
+#: common.opt:1628
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr ""
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr ""
 
-#: common.opt:1641
+#: common.opt:1644
 msgid "Report on permanent memory allocation in WPA only"
 msgstr ""
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr ""
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1659
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr ""
 
-#: common.opt:1660
+#: common.opt:1663
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr ""
 
-#: common.opt:1676
+#: common.opt:1679
 msgid "Use the RTL dead code elimination pass"
 msgstr ""
 
-#: common.opt:1680
+#: common.opt:1683
 msgid "Use the RTL dead store elimination pass"
 msgstr ""
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1694
 #, c-format
 msgid "options or targets missing after %qs"
 msgstr ""
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, c-format
 msgid "unknown offload ABI %qs"
 msgstr ""
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr ""
 
-#: common.opt:1713
+#: common.opt:1716
 msgid "Enable all optimization info dumps on stderr"
 msgstr ""
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr ""
 
-#: common.opt:1729
+#: common.opt:1732
 msgid "Perform partial inlining"
 msgstr ""
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr ""
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr ""
 
-#: common.opt:1745
+#: common.opt:1748
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr ""
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr ""
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr ""
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr ""
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr ""
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr ""
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr ""
 
-#: common.opt:1781
+#: common.opt:1784
 msgid "Specify a plugin to load"
 msgstr ""
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr ""
 
-#: common.opt:1789
+#: common.opt:1792
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr ""
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr ""
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr ""
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1821
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1826
+#: common.opt:1829
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1837
 msgid "Report on consistency of profile"
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1841
 msgid "Enable function reordering that improves code placement"
 msgstr ""
 
-#: common.opt:1845
+#: common.opt:1848
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr ""
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr ""
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr ""
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr ""
 
-#: common.opt:1880
+#: common.opt:1883
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr ""
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr ""
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr ""
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr ""
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr ""
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr ""
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr ""
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr ""
 
-#: common.opt:1928
+#: common.opt:1931
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr ""
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr ""
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr ""
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr ""
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr ""
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr ""
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr ""
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1981
+#: common.opt:1984
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr ""
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1993
+#: common.opt:1996
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1997
+#: common.opt:2000
 msgid "Enable the group heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2009
+#: common.opt:2012
 msgid "Enable the rank heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr ""
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr ""
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr ""
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr ""
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr ""
 
-#: common.opt:2062
+#: common.opt:2065
 msgid "Generate discontiguous stack frames"
 msgstr ""
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr ""
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr ""
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr ""
 
-#: common.opt:2082
+#: common.opt:2085
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr ""
 
-#: common.opt:2086
+#: common.opt:2089
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr ""
 
-#: common.opt:2093
+#: common.opt:2096
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr ""
 
-#: common.opt:2097
+#: common.opt:2100
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr ""
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr ""
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr ""
 
-#: common.opt:2109
+#: common.opt:2112
 msgid "Use a smart stack protection method for certain functions"
 msgstr ""
 
-#: common.opt:2113
+#: common.opt:2116
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr ""
 
-#: common.opt:2117
+#: common.opt:2120
 msgid "Output stack usage information on a per-function basis"
 msgstr ""
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr ""
 
-#: common.opt:2133
+#: common.opt:2136
 msgid "Treat signed overflow as undefined"
 msgstr ""
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr ""
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr ""
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr ""
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr ""
 
-#: common.opt:2157
+#: common.opt:2160
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2163
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr ""
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr ""
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr ""
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr ""
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr ""
 
-#: common.opt:2199
+#: common.opt:2202
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr ""
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr ""
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr ""
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr ""
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr ""
 
-#: common.opt:2231
+#: common.opt:2234
 msgid "Transform condition stores into unconditional ones"
 msgstr ""
 
-#: common.opt:2235
+#: common.opt:2238
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr ""
 
-#: common.opt:2243
+#: common.opt:2246
 msgid "Enable dominator optimizations"
 msgstr ""
 
-#: common.opt:2247
+#: common.opt:2250
 msgid "Enable tail merging on trees"
 msgstr ""
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr ""
 
-#: common.opt:2255
+#: common.opt:2258
 msgid "Enable forward propagation on trees"
 msgstr ""
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr ""
 
-#: common.opt:2263
+#: common.opt:2266
 msgid "Enable string length optimizations on trees"
 msgstr ""
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 msgid "Enable loop distribution on trees"
 msgstr ""
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr ""
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr ""
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr ""
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr ""
 
-#: common.opt:2300
+#: common.opt:2303
 msgid "Enable loop optimizations on tree level"
 msgstr ""
 
-#: common.opt:2304
+#: common.opt:2307
 msgid "Enable automatic parallelization of loops"
 msgstr ""
 
-#: common.opt:2308
+#: common.opt:2311
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2312
+#: common.opt:2315
 msgid "Enable SSA-PRE optimization on trees"
 msgstr ""
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2324
+#: common.opt:2327
 msgid "Enable reassociation on tree level"
 msgstr ""
 
-#: common.opt:2332
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
 msgstr ""
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr ""
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr ""
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr ""
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr ""
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr ""
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr ""
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr ""
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr ""
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr ""
 
-#: common.opt:2424
+#: common.opt:2427
 msgid "Perform variable tracking by annotating assignments"
 msgstr ""
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr ""
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr ""
 
-#: common.opt:2442
+#: common.opt:2445
 msgid "Enable vectorization on trees"
 msgstr ""
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr ""
 
-#: common.opt:2454
+#: common.opt:2457
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr ""
 
-#: common.opt:2458
+#: common.opt:2461
 msgid "Specifies the cost model for vectorization"
 msgstr ""
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr ""
 
-#: common.opt:2478
+#: common.opt:2481
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2485
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2493
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr ""
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr ""
 
-#: common.opt:2507
+#: common.opt:2510
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr ""
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr ""
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2558
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr ""
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr ""
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2582
 msgid "Generate debug information in default version of DWARF format"
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2586
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2614
 msgid "Don't generate debug information in separate .dwo files"
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2618
 msgid "Generate debug information in separate .dwo files"
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr ""
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2638
 msgid "Toggle debug information generation"
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr ""
 
-#: common.opt:2665
+#: common.opt:2668
 msgid "Generate compressed debug sections"
 msgstr ""
 
-#: common.opt:2669
+#: common.opt:2672
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr ""
 
-#: common.opt:2676
+#: common.opt:2679
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr ""
 
-#: common.opt:2680
+#: common.opt:2683
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr ""
 
-#: common.opt:2702
+#: common.opt:2705
 msgid "-o <file>\tPlace output into <file>"
 msgstr ""
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr ""
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr ""
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr ""
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr ""
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr ""
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr ""
 
-#: common.opt:2806
+#: common.opt:2809
 msgid "Create a shared library"
 msgstr ""
 
-#: common.opt:2851
+#: common.opt:2854
 msgid "Create a position independent executable"
 msgstr ""
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr ""
@@ -14324,221 +14334,221 @@
 msgid "expected integer or boolean type"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 msgid "invalid comparison of nil with nil"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 msgid "incompatible types in binary expression"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 msgid "integer division by zero"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 msgid "shift of non-integer operand"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 msgid "shift count not unsigned integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 msgid "negative shift count"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 msgid "object is not a method"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 msgid "method type does not match object type"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 msgid "invalid use of %<...%> with builtin function"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 msgid "invalid use of method value as argument of Offsetof"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 msgid "not enough arguments"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 msgid "too many arguments"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 msgid "argument 1 must be a map"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 msgid "invalid type for make function"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 msgid "too many arguments to make"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 msgid "argument must be array or slice or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 msgid "unsupported argument type to builtin function"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 msgid "argument must be channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 msgid "argument must be a field reference"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 msgid "left argument must be a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 msgid "first argument must be []byte"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 msgid "second argument must be slice or string"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 msgid "argument 2 has invalid type"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 msgid "argument must have complex type"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 msgid "complex arguments must have identical types"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 msgid "complex arguments must have floating-point type"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 msgid "expected function"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 msgid "multiple-value argument in single-value context"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 msgid "invalid use of %<...%> with non-slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 msgid "function result count mismatch"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 msgid "incompatible type for receiver"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 msgid "number of results does not match number of values"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 msgid "index must be integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 msgid "slice end must be integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 msgid "slice capacity must be integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 msgid "incompatible type for map index"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 msgid "too many expressions for struct"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 msgid "too few expressions for struct"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 msgid "type assertion only valid for interface types"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 msgid "expected channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -14648,71 +14658,71 @@
 msgid "cannot use type %s as type %s"
 msgstr ""
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 msgid "different receiver types"
 msgstr ""
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 msgid "different number of parameters"
 msgstr ""
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 msgid "different parameter types"
 msgstr ""
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr ""
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 msgid "type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, c-format
 msgid "missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -14834,7 +14844,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr ""
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr ""
@@ -15015,12 +15025,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr ""
 
-#: calls.c:3179
+#: calls.c:3195
 #, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr ""
@@ -15580,242 +15590,247 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr ""
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr ""
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr ""
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, gcc-internal-format
 msgid "execution count is negative"
 msgstr ""
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr ""
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr ""
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr ""
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr ""
@@ -15945,7 +15960,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, gcc-internal-format
 msgid "atexit failed"
@@ -16186,17 +16201,17 @@
 msgid "          %s"
 msgstr ""
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr ""
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr ""
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr ""
@@ -16241,12 +16256,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -16441,7 +16456,7 @@
 msgid "total size of local objects too large"
 msgstr ""
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -16891,9 +16906,9 @@
 msgstr ""
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, gcc-internal-format
 msgid "declared here"
 msgstr ""
@@ -16908,153 +16923,148 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr ""
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr ""
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr ""
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:7001
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, gcc-internal-format
-msgid "lastprivate variable %qE is private in outer context"
-msgstr ""
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
-#, gcc-internal-format
 msgid "directive not yet implemented"
 msgstr ""
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr ""
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -17474,47 +17484,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr ""
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr ""
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr ""
@@ -17597,47 +17607,47 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "izobličen COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, gcc-internal-format
 msgid "reading input file"
 msgstr ""
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, gcc-internal-format
 msgid "writing output file"
 msgstr ""
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "varijabla okoline COLLECT_GCC mora biti postavljena "
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "varijabla okoline COLLECT_GCC_OPTIONS mora biti postavljena"
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "fopen: %s"
 msgid "fopen: %s: %m"
@@ -17774,29 +17784,29 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr ""
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr ""
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "ignoring large linear step"
 msgstr "zanemarujem direktorij duplikat „%s”\n"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -18308,8 +18318,8 @@
 msgstr ""
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr ""
@@ -18749,7 +18759,7 @@
 msgid "ld returned %d exit status"
 msgstr ""
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr ""
@@ -19726,42 +19736,42 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr ""
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -20142,47 +20152,47 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, gcc-internal-format
 msgid "array subscript is outside array bounds"
 msgstr ""
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, gcc-internal-format
 msgid "array subscript is above array bounds"
 msgstr ""
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, gcc-internal-format
 msgid "array subscript is below array bounds"
 msgstr ""
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr ""
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr ""
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr ""
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr ""
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr ""
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr ""
@@ -20226,9 +20236,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -20459,7 +20469,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
@@ -20607,27 +20617,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr ""
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -20957,12 +20967,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr ""
@@ -21409,12 +21419,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr ""
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr ""
@@ -21424,22 +21434,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr ""
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr ""
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr ""
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr ""
@@ -21479,12 +21489,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr ""
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr ""
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
@@ -21564,7 +21574,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr ""
@@ -21980,7 +21990,7 @@
 msgstr ""
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
@@ -22436,7 +22446,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -22446,22 +22456,22 @@
 msgid "%qE is not initialized"
 msgstr ""
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr ""
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr ""
@@ -22997,6 +23007,11 @@
 msgid "too many input files"
 msgstr ""
 
+#: common/config/aarch64/aarch64-common.c:116
+#, gcc-internal-format
+msgid "-mcpu string too large"
+msgstr ""
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -23022,47 +23037,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr ""
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr ""
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr ""
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -23444,63 +23459,63 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr ""
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr ""
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr ""
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr ""
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr ""
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, gcc-internal-format
 msgid "bad value %qs for -mtune switch"
 msgstr ""
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr ""
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr ""
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr ""
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr ""
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr ""
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr ""
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -23974,14 +23989,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, gcc-internal-format
 msgid "%qE attribute only applies to functions"
@@ -24620,374 +24635,390 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr ""
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong arg %s to option %s"
 msgstr ""
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr ""
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
 #, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386.c:3012
+#, gcc-internal-format, gfc-internal-format
 msgid "unknown alignment %s specified for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, gcc-internal-format, gfc-internal-format
 msgid "too many size ranges specified in option %s"
 msgstr ""
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr ""
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr ""
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr ""
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr ""
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr ""
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr ""
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr ""
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5923
+#: config/i386/i386.c:6235
 #, gcc-internal-format
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr ""
-
-#: config/i386/i386.c:6210
-#, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr ""
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, gcc-internal-format
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
 #, gcc-internal-format
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:11378
+#, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -24994,252 +25025,252 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr ""
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr ""
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr ""
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr ""
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -25332,13 +25363,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr ""
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -25410,7 +25441,7 @@
 msgstr ""
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, gcc-internal-format
 msgid "%qE attribute argument not an integer constant"
 msgstr ""
@@ -25470,7 +25501,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -26319,16 +26350,11 @@
 msgid "-g option disabled"
 msgstr ""
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr ""
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, gcc-internal-format
@@ -26586,307 +26612,312 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
 #, gcc-internal-format, gfc-internal-format
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12763
+#, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had no type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr ""
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr ""
@@ -27137,88 +27168,88 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr ""
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr ""
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr ""
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
@@ -27233,53 +27264,53 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr ""
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr ""
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, gcc-internal-format
 msgid "%qE attribute only applies to interrupt functions"
 msgstr ""
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, gcc-internal-format
 msgid "%qE attribute is supported only for SH2A"
 msgstr ""
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr ""
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, gcc-internal-format
 msgid "%qE attribute only applies to SH2A"
 msgstr ""
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, gcc-internal-format
 msgid "%qE attribute argument should be between 0 to 255"
 msgstr ""
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, gcc-internal-format
 msgid "%qE attribute argument not a string constant"
 msgstr ""
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr ""
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, gcc-internal-format
 msgid "need a second call-clobbered general purpose register"
 msgstr ""
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr ""
@@ -27656,43 +27687,43 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr ""
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -27750,7 +27781,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -27780,62 +27811,62 @@
 msgid "GCC supports only %u nested scopes"
 msgstr ""
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr ""
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr ""
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr ""
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr ""
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, gcc-internal-format
 msgid "variable %qD set but not used"
 msgstr ""
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr ""
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr ""
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr ""
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr ""
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr ""
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr ""
@@ -27842,42 +27873,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr ""
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr ""
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr ""
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr ""
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr ""
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr ""
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr ""
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr ""
@@ -27885,339 +27916,339 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr ""
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
 msgstr ""
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr ""
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr ""
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr ""
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr ""
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr ""
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, gcc-internal-format
 msgid "but not here"
 msgstr ""
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr ""
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr ""
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr ""
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr ""
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr ""
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr ""
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr ""
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr ""
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr ""
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr ""
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr ""
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr ""
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr ""
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr ""
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr ""
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr ""
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr ""
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr ""
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr ""
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr ""
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr ""
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr ""
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr ""
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr ""
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr ""
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr ""
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr ""
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr ""
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr ""
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr ""
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr ""
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr ""
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr ""
@@ -28225,38 +28256,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr ""
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr ""
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr ""
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr ""
@@ -28265,257 +28296,257 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr ""
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr ""
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr ""
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr ""
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr ""
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr ""
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr ""
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr ""
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr ""
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr ""
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, gcc-internal-format
 msgid "uninitialized const %qD is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr ""
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr ""
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr ""
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr ""
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr ""
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr ""
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr ""
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr ""
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr ""
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr ""
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr ""
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr ""
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr ""
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr ""
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr ""
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -28523,683 +28554,683 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr ""
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr ""
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr ""
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr ""
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr ""
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr ""
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr ""
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr ""
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr ""
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr ""
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr ""
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr ""
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr ""
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr ""
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr ""
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr ""
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr ""
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr ""
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr ""
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr ""
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr ""
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr ""
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr ""
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr ""
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr ""
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr ""
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr ""
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr ""
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr ""
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, gcc-internal-format
 msgid "union defined here"
 msgstr ""
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr ""
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr ""
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr ""
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr ""
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr ""
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr ""
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr ""
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr ""
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr ""
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr ""
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr ""
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr ""
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr ""
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr ""
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr ""
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr ""
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr ""
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr ""
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr ""
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr ""
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr ""
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr ""
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr ""
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr ""
@@ -29207,197 +29238,197 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr ""
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr ""
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr ""
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr ""
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr ""
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr ""
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr ""
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr ""
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr ""
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr ""
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr ""
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -29407,7 +29438,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr ""
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "očekujem kraj retka"
@@ -29427,8 +29458,8 @@
 msgid "unknown type name %qE"
 msgstr ""
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr ""
@@ -29443,7 +29474,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -29519,7 +29550,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr ""
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -29576,14 +29607,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -30032,32 +30063,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
@@ -30067,47 +30098,47 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
@@ -30122,12 +30153,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr ""
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr ""
@@ -30137,27 +30168,27 @@
 msgid "expression must be integral"
 msgstr ""
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, gcc-internal-format
 msgid "%qD is not a constant"
 msgstr ""
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr ""
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr ""
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
@@ -30189,17 +30220,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr ""
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr ""
@@ -30219,12 +30250,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -30244,19 +30275,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid depend kind"
 msgstr "neispravni izraz kao operand"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid 'asm': "
 msgid "invalid map kind"
 msgstr "neispravni „asm”: "
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -30266,58 +30297,58 @@
 msgid "invalid proc_bind kind"
 msgstr ""
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr ""
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr ""
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid 'asm': "
 msgid "invalid pragma"
 msgstr "neispravni „asm”: "
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -30327,17 +30358,17 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr ""
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr ""
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -30347,244 +30378,244 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<for%> after %qs"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<point%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<target%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<while%>"
 msgid "expected %<declare%>"
 msgstr "očekujem %<while%>"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr ""
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%>"
 msgid "expected function-name %<(%>"
 msgstr "očekujem %<(%>"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, gcc-internal-format
 msgid "pragma simd must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr ""
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr ""
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr ""
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr ""
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, gcc-internal-format
 msgid "base of array section must be pointer or array type"
 msgstr ""
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>"
 msgid "expected %<:%> or numeral"
 msgstr "očekujem %<:%>"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, gcc-internal-format
 msgid "array notations cannot be used with function type"
 msgstr ""
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, gcc-internal-format
 msgid "expected array notation expression"
 msgstr ""
@@ -30594,7 +30625,7 @@
 msgid "%qD has an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -30700,7 +30731,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -30823,7 +30854,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
@@ -30853,7 +30884,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -30938,7 +30969,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
@@ -30973,7 +31004,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr ""
@@ -31056,7 +31087,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -31209,7 +31240,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -31346,7 +31377,7 @@
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr ""
@@ -31392,7 +31423,7 @@
 msgid "invalid initializer"
 msgstr ""
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -31537,7 +31568,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
@@ -31547,7 +31578,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -31652,17 +31683,17 @@
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
@@ -31713,12 +31744,12 @@
 msgstr ""
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
@@ -31743,85 +31774,85 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
@@ -31831,17 +31862,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -31851,7 +31882,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
@@ -31861,17 +31892,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
@@ -31886,47 +31917,47 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -31937,33 +31968,33 @@
 msgstr ""
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, gcc-internal-format
 msgid "  no known conversion from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, gcc-internal-format
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -31971,83 +32002,83 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, gcc-internal-format
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr ""
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, gcc-internal-format
 msgid "%s%D(%T, %T) <built-in>"
 msgstr ""
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, gcc-internal-format
 msgid "%s%D(%T) <built-in>"
 msgstr ""
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, gcc-internal-format
 msgid "%s%T <conversion>"
 msgstr ""
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr ""
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr ""
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr ""
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr ""
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr ""
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, gcc-internal-format
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr ""
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
@@ -32054,458 +32085,458 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr ""
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr ""
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 #| msgid "%s\n"
 msgid "%qs"
 msgstr "%s\n"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr ""
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, gcc-internal-format
 msgid "non-placement deallocation function %q+D"
 msgstr ""
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr ""
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr ""
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr ""
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr ""
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr ""
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr ""
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, gcc-internal-format
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, gcc-internal-format
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, gcc-internal-format
 msgid "  initializing argument %P of %q+D"
 msgstr ""
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, gcc-internal-format
 msgid "cannot bind %qT lvalue to %qT"
 msgstr ""
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr ""
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, gcc-internal-format
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr ""
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, gcc-internal-format
 msgid "  in call to %q+D"
 msgstr ""
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr ""
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr ""
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr ""
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr ""
@@ -32661,7 +32692,7 @@
 msgid "  by %q+D"
 msgstr ""
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
@@ -32671,7 +32702,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr ""
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr ""
@@ -32681,7 +32712,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr ""
@@ -32811,67 +32842,77 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4538
+#: cp/class.c:4300
 #, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, gcc-internal-format
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr ""
+
+#: cp/class.c:4557
+#, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, gcc-internal-format
 msgid "  non-static data member %q+D has non-literal type"
 msgstr ""
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, gcc-internal-format
 msgid "  non-static data member %q+D has volatile type"
 msgstr ""
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr ""
@@ -32878,102 +32919,102 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -32983,12 +33024,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr ""
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr ""
@@ -33028,253 +33069,253 @@
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr ""
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, gcc-internal-format
 msgid "call to internal function"
 msgstr ""
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr ""
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr ""
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr ""
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "array subscript out of bound"
 msgstr ""
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, gcc-internal-format
 msgid "negative array subscript"
 msgstr ""
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr ""
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr ""
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, gcc-internal-format
 msgid "modification of %qE is not a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, gcc-internal-format
 msgid "statement is not a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, gcc-internal-format
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, gcc-internal-format
 msgid "division by zero is not a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
@@ -33345,7 +33386,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr ""
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr ""
@@ -33385,7 +33426,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -33395,292 +33436,292 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr ""
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr ""
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr ""
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr ""
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr ""
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr ""
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr ""
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr ""
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -34091,238 +34132,238 @@
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr ""
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr ""
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr ""
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr ""
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr ""
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr ""
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr ""
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
@@ -34330,824 +34371,824 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr ""
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr ""
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr ""
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr ""
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr ""
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr ""
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr ""
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr ""
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr ""
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> variable"
 msgstr ""
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, gcc-internal-format
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr ""
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, gcc-internal-format
 msgid "%q+#D explicitly defaulted here"
 msgstr ""
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr ""
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr ""
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr ""
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr ""
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr ""
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr ""
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr ""
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr ""
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr ""
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr ""
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr ""
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr ""
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr ""
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr ""
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
@@ -35154,470 +35195,470 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr ""
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr ""
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr ""
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr ""
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr ""
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, gcc-internal-format
 msgid "non-static data member declared %<auto%>"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr ""
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr ""
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr ""
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr ""
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, gcc-internal-format
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr ""
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -35637,173 +35678,173 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr ""
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr ""
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -35815,88 +35856,88 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr ""
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr ""
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr ""
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr ""
@@ -35905,87 +35946,87 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr ""
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr ""
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr ""
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr ""
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr ""
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, gcc-internal-format
 msgid "parameter %q+D set but not used"
 msgstr ""
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr ""
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -36025,7 +36066,7 @@
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr ""
@@ -36048,7 +36089,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -36138,27 +36179,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -36167,47 +36208,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr ""
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, gcc-internal-format
 msgid "%q#D, declared using anonymous type, is used but never defined"
 msgstr ""
@@ -36216,47 +36257,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr ""
@@ -36263,12 +36304,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
@@ -36845,42 +36886,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr ""
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -37010,17 +37051,17 @@
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, gcc-internal-format
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, gcc-internal-format
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
@@ -37434,7 +37475,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr ""
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -37459,7 +37500,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -37524,7 +37565,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr ""
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
@@ -37549,7 +37590,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -37817,7 +37858,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
@@ -37992,7 +38033,7 @@
 msgid "capture of non-variable %qD "
 msgstr ""
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, gcc-internal-format
 msgid "%q+#D declared here"
 msgstr ""
@@ -38052,7 +38093,7 @@
 msgid "compound-statement in constexpr function"
 msgstr ""
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
@@ -38082,7 +38123,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
@@ -38113,12 +38154,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
@@ -38165,7 +38206,7 @@
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
@@ -38257,12 +38298,12 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
@@ -38277,7 +38318,7 @@
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -38354,208 +38395,208 @@
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr ""
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr ""
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, gcc-internal-format
 msgid "%qD is not an enumerator-name"
 msgstr ""
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, gcc-internal-format
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr ""
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr ""
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr ""
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr ""
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr ""
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -38564,7 +38605,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr ""
@@ -38571,293 +38612,293 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr ""
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr ""
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr ""
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, gcc-internal-format
 msgid "invalid use of %<auto%>"
 msgstr ""
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr ""
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr ""
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr ""
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr ""
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr ""
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr ""
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr ""
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -38866,534 +38907,534 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr ""
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr ""
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr ""
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr ""
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected positive integer expression"
 msgstr ""
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr ""
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr ""
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, gcc-internal-format
 msgid "not enough collapsed for loops"
 msgstr ""
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr ""
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr ""
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<while%>"
 msgid "expected variable-name"
 msgstr "očekujem %<while%>"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr ""
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr ""
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr ""
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -39400,67 +39441,67 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, gcc-internal-format
 msgid "candidate is: %#D"
 msgstr ""
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr ""
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr ""
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr ""
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, gcc-internal-format
 msgid "too many template headers for %D (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -39467,57 +39508,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr ""
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr ""
@@ -39530,92 +39571,92 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr ""
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr ""
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr ""
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr ""
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr ""
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -39623,12 +39664,12 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -39636,42 +39677,42 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr ""
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -39681,57 +39722,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr ""
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -39739,7 +39780,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, gcc-internal-format
 msgid "previous declaration %q+D used %d template parameter"
 msgid_plural "previous declaration %q+D used %d template parameters"
@@ -39747,12 +39788,12 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr ""
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
@@ -39761,102 +39802,102 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr ""
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr ""
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -39864,172 +39905,172 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qD"
 msgstr ""
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, gcc-internal-format
 msgid "  could not resolve address from overloaded function %qE"
 msgstr ""
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, gcc-internal-format
 msgid "in template argument for type %qT "
 msgstr ""
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr ""
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr ""
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr ""
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
@@ -40036,77 +40077,77 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr ""
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr ""
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr ""
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr ""
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr ""
@@ -40124,266 +40165,266 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr ""
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr ""
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, gcc-internal-format
 msgid "%q+D declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr ""
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr ""
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 msgid "%s %#S"
 msgstr ""
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
@@ -40395,62 +40436,62 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
@@ -40687,260 +40728,260 @@
 msgid "invalid base-class specification"
 msgstr ""
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr ""
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, gcc-internal-format
 msgid "%<num_teams%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr ""
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
@@ -40955,117 +40996,117 @@
 msgid "lambda-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr ""
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr ""
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr ""
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr ""
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr ""
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr ""
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr ""
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr ""
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr ""
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr ""
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -41255,564 +41296,559 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr ""
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr ""
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr ""
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr ""
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr ""
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr ""
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr ""
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr ""
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr ""
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, gcc-internal-format
 msgid "taking address of constructor %qE"
 msgstr ""
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, gcc-internal-format
 msgid "taking address of destructor %qE"
 msgstr ""
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr ""
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr ""
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr ""
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, gcc-internal-format
 msgid "useless cast to type %qT"
 msgstr ""
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr ""
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr ""
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr ""
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr ""
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr ""
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr ""
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr ""
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr ""
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr ""
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr ""
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr ""
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr ""
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr ""
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr ""
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, gcc-internal-format
 msgid "address of label %q+D returned"
 msgstr ""
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr ""
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -41819,45 +41855,45 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr ""
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr ""
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -42084,122 +42120,122 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr ""
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr ""
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr ""
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr ""
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr ""
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -42376,8 +42412,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -42512,7 +42548,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -42628,7 +42664,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr ""
@@ -43215,12 +43251,12 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
@@ -43490,6 +43526,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr ""
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -43497,7 +43538,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -43718,399 +43759,399 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, gcc-internal-format
 msgid "Function name %qs not allowed at %C"
 msgstr ""
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -44117,799 +44158,804 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr ""
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:5597
-#, gcc-internal-format
-msgid "gfc_match_entry(): Bad state"
+#: fortran/decl.c:5595
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr ""
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%>"
 msgid "Expected %<(%> at %C"
 msgstr "očekujem %<(%>"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr ""
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>"
 msgid "Expected %<::%> at %C"
 msgstr "očekujem %<:%>"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, gcc-internal-format, gfc-internal-format
+msgid "Malformed GENERIC statement at %C"
+msgstr ""
+
+#: fortran/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>"
 msgid "Expected %<=>%> at %C"
 msgstr "očekujem %<=%>"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>"
 msgid "Expected %<,%> at %C"
 msgstr "očekujem %<,%>"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr ""
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
@@ -45189,342 +45235,342 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr ""
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, gcc-internal-format
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, gcc-internal-format
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, gcc-internal-format
 msgid "Conversion from %qs to %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr ""
@@ -45546,27 +45592,27 @@
 msgid "Removing call to function %qs at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr ""
@@ -45621,592 +45667,597 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr ""
+
+#: fortran/interface.c:353
+#, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr ""
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr ""
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr ""
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr ""
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr ""
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr ""
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr ""
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr ""
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr ""
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr ""
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
 msgstr ""
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, gcc-internal-format
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr ""
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, gcc-internal-format
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr ""
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr ""
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr ""
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr ""
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr ""
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, gcc-internal-format
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
@@ -46616,12 +46667,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
@@ -46631,7 +46682,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
@@ -46656,777 +46707,777 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr ""
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr ""
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr ""
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr ""
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr ""
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr ""
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr ""
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr ""
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
 msgstr ""
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, gcc-internal-format
 msgid "Missing %<)%> in statement at or before %L"
 msgstr ""
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, gcc-internal-format
 msgid "Missing %<(%> in statement at or before %L"
 msgstr ""
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr ""
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr ""
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, gcc-internal-format
 msgid "Label name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, gcc-internal-format
 msgid "Duplicate construct label %qs at %C"
 msgstr ""
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr ""
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr ""
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr ""
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr ""
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr ""
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr ""
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr ""
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, gcc-internal-format, gfc-internal-format
 msgid "gfc_match(): Bad match code %c"
 msgstr ""
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr ""
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr ""
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr ""
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
 msgstr ""
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr ""
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr ""
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr ""
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, gcc-internal-format
 msgid "Duplicate name %qs in association at %C"
 msgstr ""
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr ""
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, gcc-internal-format
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr ""
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr ""
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr ""
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr ""
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr ""
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr ""
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr ""
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr ""
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr ""
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr ""
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr ""
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr ""
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr ""
@@ -47434,147 +47485,147 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr ""
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr ""
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr ""
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr ""
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr ""
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -47720,172 +47771,172 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "Failed to open file %s for writing state: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Nisam uspio otvoriti datoteku %s za pisanje stanja: %s"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 #| msgid "Failed to open file %s for writing state: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Nisam uspio otvoriti datoteku %s za pisanje stanja: %s"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot open source file %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "Ne mogu otvoriti datoteku koda %s\n"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr ""
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr ""
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr ""
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 #| msgid "Failed to open file %s for writing state: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Nisam uspio otvoriti datoteku %s za pisanje stanja: %s"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr ""
@@ -48180,7 +48231,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -48873,368 +48924,363 @@
 msgid "Unexpected %s statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2428
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr ""
-
-#: fortran/parse.c:2439
-#, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 #| msgid "expected end of line"
 msgid "Unexpected end of file in %qs"
 msgstr "očekujem kraj retka"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr ""
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr ""
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr ""
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr ""
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr ""
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr ""
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr ""
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr ""
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr ""
@@ -49242,7 +49288,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -49937,7 +49983,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -49992,363 +50038,363 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr ""
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr ""
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -50357,12 +50403,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -50371,248 +50417,248 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -50621,188 +50667,188 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -50809,12 +50855,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -50822,158 +50868,158 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr ""
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr ""
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr ""
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -50980,7 +51026,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -50988,57 +51034,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr ""
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
@@ -51045,422 +51091,422 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -51467,397 +51513,397 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -51888,47 +51934,47 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr ""
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr ""
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr ""
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, gcc-internal-format
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr ""
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr ""
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
 msgstr ""
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr ""
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr ""
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr ""
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot open source file %s\n"
 msgid "Can't open file %qs"
@@ -52195,52 +52241,52 @@
 msgid "Reshaped array too large at %C"
 msgstr ""
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr ""
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr ""
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr ""
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -52318,313 +52364,318 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
 #, gcc-internal-format, gfc-internal-format
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr ""
+
+#: fortran/symbol.c:489
+#, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr ""
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, gcc-internal-format
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, gcc-internal-format
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr ""
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr ""
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr ""
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -52884,7 +52935,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
Index: gcc/po/nl.po
===================================================================
--- gcc/po/nl.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/nl.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.9-b20140202\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2014-02-05 12:25+0100\n"
 "Last-Translator: Benno Schulenberg <benno@vertaalt.nl>\n"
 "Language-Team: Dutch <vertaling@vrijschrift.org>\n"
@@ -194,13 +194,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "floating-point constante verkeerd gebruikt"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1363,7 +1363,7 @@
 msgid "options enabled: "
 msgstr "ingeschakelde opties: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2573,98 +2573,98 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "ongeldige operandprefix '%%%c'"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "ongeldige waarde voor %%J"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "ongeldige waarde voor %%r"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "ongeldige waarde voor %%R"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "ongeldige waarde voor %%N"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "ongeldige waarde voor %%P"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "ongeldige waarde voor %%h"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "ongeldige waarde voor %%L"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "ongeldige waarde voor %%m"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "ongeldige waarde voor %%M"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "ongeldige waarde voor %%U"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "ongeldige waarde voor %%s"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "ongeldige waarde voor %%C"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "ongeldige waarde voor %%E"
 
 # mja, is nogal technisch - ikke nie snap nie
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "onbekende 'unspec' relocatie"
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ongeldige code voor %%xn"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 msgid "invalid operand address"
 msgstr "Ongeldige modus voor gen_tst_reg"
@@ -2712,7 +2712,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "ongeldige code voor operanduitvoer"
@@ -2869,8 +2869,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3092,63 +3092,63 @@
 msgid "bad output_condmove_single operand"
 msgstr "ongeldige output_condmove_single operand"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ongeldige UNSPEC als operand"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ongeldige operand voor '%c'"
 
 # "constraints" hier te vertalen ("beperkingen"/"restricties") of niet?
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ongeldige constraints voor operand"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "onbekende insn-modus"
 
@@ -3188,7 +3188,7 @@
 msgid "invalid %%P operand"
 msgstr "ongeldige operand voor %%P"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "ongeldige waarde voor %%p"
@@ -3256,7 +3256,7 @@
 msgstr "post-increment adres is geen register"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "slecht adres"
 
@@ -3423,102 +3423,102 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "case-label niet in een switch-statement"
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 #, fuzzy
 msgid "bad move"
 msgstr "slechte test"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "ongeldige waarde voor %%K"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "ongeldige waarde voor %%O"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "ongeldige waarde voor %%q"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "ongeldige waarde voor %%x"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "twee %<u%>s in integerconstante"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 msgid "Unable to generate load offset for fusion"
 msgstr ""
 
@@ -3613,61 +3613,61 @@
 msgid "invalid operand to %%S"
 msgstr "ongeldige operand voor %%N"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr "aangemaakt en gebruikt met verschillende architecturen / ABIs"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr "aangemaakt en gebruikt met verschillende ABIs"
 
 # Vertaling voor "endianness"? Of niet nodig?
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr "aangemaakt en gebruikt met verschillende \"endianness\""
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "ongeldige operand voor %%Y"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "ongeldige operand voor %%A"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "ongeldige operand voor %%B"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, fuzzy, c-format
 msgid "invalid %%C operand"
 msgstr "ongeldige operand voor %%P"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, fuzzy, c-format
 msgid "invalid %%D operand"
 msgstr "ongeldige operand voor %%P"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "ongeldige operand voor %%f"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "ongeldige operand voor %%s"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "een long long constante is geen geldige onmiddellijke operand"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "een floating-point constante is geen geldige onmiddellijke operand"
@@ -3876,7 +3876,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ongeldige operand van %s"
@@ -3892,15 +3892,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ongeldige operand van %s"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ongeldige operand van %s"
@@ -3922,8 +3922,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ongeldige operand van %s"
@@ -3930,8 +3930,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ongeldige operand van %s"
@@ -3941,13 +3941,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ongeldige operand van %s"
@@ -3954,8 +3954,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ongeldige operand van %s"
@@ -3980,7 +3980,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr "cast geeft functie-type op"
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ongeldige operand van %s"
@@ -4000,34 +4000,34 @@
 msgid "expected %<.%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ongeldige operand van %s"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ongeldige operand van %s"
@@ -4036,11 +4036,11 @@
 msgid "(anonymous)"
 msgstr "(anoniem)"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "kandidaat 1:"
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "kandidaat 2:"
 
@@ -4269,11 +4269,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "kandidaten zijn:"
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -4327,54 +4327,54 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "argument van verkeerd type voor unaire min"
 
 # 'unary' = 'unair'?
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "argument van verkeerd type voor unaire plus"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "argument van verkeerd type voor bit-complement"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "argument van verkeerd type voor abs"
 
 # OK, ik geef het op: wat is hier een goede vertaling voor 'conjugation'?
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "argument van verkeerd type voor vervoeging"
 
 # 'unary' = 'unair'?
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "argument van verkeerd type voor unaire plus"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4473,7 +4473,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "integer overflow in expressie"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 #, fuzzy
 msgid "array assignment"
 msgstr "beginwaarde ontbreekt"
@@ -4493,7 +4493,7 @@
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4567,13 +4567,13 @@
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4658,7 +4658,7 @@
 msgid "Bad type in constant expression"
 msgstr "overflow in constante expressie"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "ongeldige operand van %s"
@@ -4690,12 +4690,12 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 #, fuzzy
 msgid "assignment"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 #, fuzzy
 msgid "pointer assignment"
 msgstr "ongeldige lvalue in toewijzing"
@@ -4714,203 +4714,203 @@
 msgid "internal function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 msgid "allocatable argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 msgid "optional argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 msgid "pointer argument"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 msgid "target argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 msgid "value argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 msgid "volatile argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "slechte combinatie van argumenten"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 msgid "assumed-rank argument"
 msgstr "slechte combinatie van argumenten"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 msgid "coarray argument"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 msgid "polymorphic argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "slechte combinatie van argumenten"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, fuzzy, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, fuzzy, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 #, fuzzy
 msgid "iterator variable"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5315,16 +5315,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr ""
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr ""
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr ""
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr "ondersteunt geen multilib"
@@ -5337,6 +5327,11 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "-Xbind-now en -Xbind-lazy zijn incompatibel"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+#, fuzzy
+msgid "profiling not supported with -mg"
+msgstr "profileren wordt niet ondersteund wanneer -mg gebruikt wordt\n"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "-mhard-float wordt niet ondersteund"
@@ -5345,10 +5340,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "-msingle-float en -msoft-float gaan niet samen"
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr ""
-
 #: config/cris/cris.h:184
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "-march=... en -mcpu=... gaan niet samen"
@@ -5379,6 +5370,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr ""
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5385,6 +5382,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr "-m32 en -m64 gaan niet samen"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr ""
+
 #: config/s390/tpf.h:106
 #, fuzzy
 msgid "static is not supported on TPF-OS"
@@ -5398,6 +5399,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian en -mlittle-endian gaan niet samen"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr ""
+
 #: config/avr/specs.h:68
 #, fuzzy
 msgid "shared is not supported"
@@ -5426,17 +5431,19 @@
 msgid "no processor type specified for linking"
 msgstr "specbestand heeft geen spec voor het linken"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr ""
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr ""
 
@@ -5473,11 +5480,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "De -shared optie wordt op het ogenblik niet ondersteund voor VAX ELF."
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-#, fuzzy
-msgid "profiling not supported with -mg"
-msgstr "profileren wordt niet ondersteund wanneer -mg gebruikt wordt\n"
-
 #: fortran/lang.opt:146
 msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgstr ""
@@ -5673,9 +5675,9 @@
 msgstr ""
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -5885,10 +5887,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -5939,7 +5941,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, fuzzy, c-format
 msgid "missing filename after %qs"
 msgstr "beginwaarde ontbreekt"
@@ -7887,44 +7889,48 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 msgid "Specify the code model"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -9051,10 +9057,15 @@
 msgstr "ingebouwde functie %qs is niet geïmplementeerd"
 
 #: config/i386/i386.opt:864
+#, fuzzy
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "ingebouwde functie %qs is niet geïmplementeerd"
+
+#: config/i386/i386.opt:868
 msgid "Use given stack-protector guard"
 msgstr ""
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr ""
 
@@ -9416,7 +9427,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -9567,7 +9578,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 msgid "Use LRA instead of reload"
 msgstr ""
@@ -9696,7 +9707,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr ""
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr ""
 
@@ -10029,312 +10040,312 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 #, fuzzy
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "%<__builtin_next_arg%> opgeroepen zonder argument"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 #, fuzzy
 msgid "Do not place floating point constants in TOC"
 msgstr "misvormde floating-point constante"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 #, fuzzy
 msgid "Place floating point constants in TOC"
 msgstr "misvormde floating-point constante"
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 #, fuzzy
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "misvormde floating-point constante"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 #, fuzzy
 msgid "Generate isel instructions"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 msgid "Deprecated option.  Use -misel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 #, fuzzy
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 msgid "Deprecated option.  Use -mspe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 #, fuzzy
 msgid "-mdebug=\tEnable debug output"
 msgstr "Schakel uitgebreide boodschappen in"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 msgid "Use the AltiVec ABI extensions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 #, fuzzy
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 msgid "Use the SPE ABI extensions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 #, fuzzy
 msgid "Do not use the SPE ABI extensions"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 msgid "Use the ELFv1 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 msgid "Use the ELFv2 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 msgid "using darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 msgid "using old darwin ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 msgid "Generate Cell microcode"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 #, fuzzy
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Pngeldige optie %<-%s%>"
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 msgid "Valid arguments to -malign-:"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 msgid "Single-precision floating point unit"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 msgid "Double-precision floating point unit"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 #, fuzzy
 msgid "Floating point unit does not support divide & sqrt"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 msgid "Specify Xilinx FPU."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 msgid "Allow sign extension in fusion operations"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
+#: config/rs6000/rs6000.opt:566
 #, fuzzy
-msgid "Use ISA 2.07 crypto instructions"
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -13288,1597 +13299,1597 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr "Geef het register op dat voor PIC-adressering gebruikt moet worden"
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 #, fuzzy
 msgid "Align the start of functions"
 msgstr "impliciete declaratie van functie %qs"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr ""
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr ""
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr ""
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr ""
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr ""
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr ""
 
-#: common.opt:918
+#: common.opt:921
 #, fuzzy
 msgid "Generate auto-inc/dec instructions"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr ""
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr ""
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr ""
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr ""
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr ""
 
-#: common.opt:960
+#: common.opt:963
 #, fuzzy
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: common.opt:964
+#: common.opt:967
 #, fuzzy
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr ""
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr ""
 
-#: common.opt:979
+#: common.opt:982
 msgid "Check the return value of new in C++"
 msgstr ""
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr ""
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr ""
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr ""
 
-#: common.opt:1003
+#: common.opt:1006
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr ""
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr ""
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr ""
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr ""
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr ""
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr ""
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr ""
 
-#: common.opt:1035
+#: common.opt:1038
 #, fuzzy
 msgid "Place data items into their own section"
 msgstr "keer vermeld voor elke functie waarin hij staat.)"
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr ""
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr ""
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr ""
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr ""
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 msgid "Perform speculative devirtualization"
 msgstr ""
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1085
+#: common.opt:1088
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr ""
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1145
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr ""
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr ""
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr ""
 
-#: common.opt:1157
+#: common.opt:1160
 msgid "Suppress output of addresses in debugging dumps"
 msgstr ""
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 #, fuzzy
 msgid "Dump optimization passes"
 msgstr "meegegeven opties: "
 
-#: common.opt:1170
+#: common.opt:1173
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1177
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1185
 #, fuzzy
 msgid "Perform early inlining"
 msgstr "recursieve inlining"
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr ""
 
-#: common.opt:1190
+#: common.opt:1193
 msgid "Perform interprocedural reduction of aggregates"
 msgstr ""
 
-#: common.opt:1194
+#: common.opt:1197
 msgid "Perform unused symbol elimination in debug info"
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr ""
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr ""
 
-#: common.opt:1217
+#: common.opt:1220
 #, fuzzy, c-format
 msgid "unknown excess precision style %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr ""
 
-#: common.opt:1238
+#: common.opt:1241
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr ""
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr ""
 
-#: common.opt:1250
+#: common.opt:1253
 msgid "Perform a forward propagation pass on RTL"
 msgstr ""
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, fuzzy, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "niet-floating-point argument voor functie %qs"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr ""
 
-#: common.opt:1278
+#: common.opt:1281
 #, fuzzy
 msgid "Place each function into its own section"
 msgstr "keer vermeld voor elke functie waarin hij staat.)"
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr ""
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr ""
 
-#: common.opt:1305
+#: common.opt:1308
 #, fuzzy
 msgid "Enable in and out of Graphite representation"
 msgstr "lege declaratie"
 
-#: common.opt:1309
+#: common.opt:1312
 msgid "Enable Graphite Identity transformation"
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1316
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr ""
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr ""
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr ""
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr ""
 
-#: common.opt:1330
+#: common.opt:1333
 #, fuzzy
 msgid "Enable Loop Blocking transformation"
 msgstr "lege declaratie"
 
-#: common.opt:1334
+#: common.opt:1337
 #, fuzzy
 msgid "Enable Loop Unroll Jam transformation"
 msgstr "lege declaratie"
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr ""
 
-#: common.opt:1366
+#: common.opt:1369
 #, fuzzy
 msgid "Process #ident directives"
 msgstr "ongeldig preprocessing-commando"
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr ""
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr ""
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, fuzzy, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1394
+#: common.opt:1397
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr ""
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr ""
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr ""
 
-#: common.opt:1410
+#: common.opt:1413
 #, fuzzy
 msgid "Perform indirect inlining"
 msgstr "recursieve inlining"
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 #, fuzzy
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: common.opt:1424
+#: common.opt:1427
 #, fuzzy
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: common.opt:1428
+#: common.opt:1431
 #, fuzzy
 msgid "Integrate functions only required by their single caller"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: common.opt:1435
+#: common.opt:1438
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr ""
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1458
 msgid "Perform interprocedural constant propagation"
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1466
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1470
 msgid "Perform interprocedural profile propagation"
 msgstr ""
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr ""
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 msgid "Perform Identical Code Folding for variables"
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr ""
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr ""
 
-#: common.opt:1506
+#: common.opt:1509
 #, fuzzy, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr ""
 
-#: common.opt:1519
+#: common.opt:1522
 #, fuzzy, c-format
 msgid "unknown IRA region %qs"
 msgstr "onbekende 'unspec' relocatie"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1561
 #, fuzzy
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "case-label niet in een switch-statement"
 
-#: common.opt:1562
+#: common.opt:1565
 #, fuzzy
 msgid "Generate code for functions even if they are fully inlined"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr ""
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr ""
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 #, fuzzy
 msgid "Enable link-time optimization."
 msgstr "lege declaratie"
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr ""
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 msgid "Report various link-time optimization statistics"
 msgstr ""
 
-#: common.opt:1625
+#: common.opt:1628
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1632
 #, fuzzy
 msgid "Set errno after built-in math functions"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr ""
 
-#: common.opt:1641
+#: common.opt:1644
 msgid "Report on permanent memory allocation in WPA only"
 msgstr ""
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr ""
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1659
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr ""
 
-#: common.opt:1660
+#: common.opt:1663
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr ""
 
-#: common.opt:1676
+#: common.opt:1679
 #, fuzzy
 msgid "Use the RTL dead code elimination pass"
 msgstr "lege declaratie"
 
-#: common.opt:1680
+#: common.opt:1683
 #, fuzzy
 msgid "Use the RTL dead store elimination pass"
 msgstr "lege declaratie"
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr ""
 
 # Assertie? Dat moet beter kunnen!
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 msgid "options or targets missing after %qs"
 msgstr "Assertie ontbreekt na -A optie"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 msgid "unknown offload ABI %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr ""
 
-#: common.opt:1713
+#: common.opt:1716
 #, fuzzy
 msgid "Enable all optimization info dumps on stderr"
 msgstr "lege declaratie"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr ""
 
-#: common.opt:1729
+#: common.opt:1732
 #, fuzzy
 msgid "Perform partial inlining"
 msgstr "recursieve inlining"
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr ""
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr ""
 
-#: common.opt:1745
+#: common.opt:1748
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr ""
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr ""
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr ""
 
-#: common.opt:1765
+#: common.opt:1768
 #, fuzzy
 msgid "Generate position-independent code if possible (large mode)"
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:1769
+#: common.opt:1772
 #, fuzzy
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:1773
+#: common.opt:1776
 #, fuzzy
 msgid "Generate position-independent code if possible (small mode)"
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:1777
+#: common.opt:1780
 #, fuzzy
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:1781
+#: common.opt:1784
 msgid "Specify a plugin to load"
 msgstr ""
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr ""
 
-#: common.opt:1789
+#: common.opt:1792
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr ""
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr ""
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr ""
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1821
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1826
+#: common.opt:1829
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1837
 msgid "Report on consistency of profile"
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1841
 msgid "Enable function reordering that improves code placement"
 msgstr ""
 
-#: common.opt:1845
+#: common.opt:1848
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr ""
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr ""
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr ""
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr ""
 
-#: common.opt:1880
+#: common.opt:1883
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr ""
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr ""
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr ""
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr ""
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr ""
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr ""
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr ""
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr ""
 
-#: common.opt:1928
+#: common.opt:1931
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr ""
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr ""
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr ""
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr ""
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr ""
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr ""
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr ""
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1981
+#: common.opt:1984
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr ""
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1993
+#: common.opt:1996
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1997
+#: common.opt:2000
 msgid "Enable the group heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2009
+#: common.opt:2012
 msgid "Enable the rank heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr ""
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr ""
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr ""
 
-#: common.opt:2054
+#: common.opt:2057
 #, fuzzy
 msgid "Convert floating point constants to single precision constants"
 msgstr "floating-point fout bij het uitschrijven van een constante"
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr ""
 
-#: common.opt:2062
+#: common.opt:2065
 msgid "Generate discontiguous stack frames"
 msgstr ""
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr ""
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 #, fuzzy
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr ""
 
-#: common.opt:2082
+#: common.opt:2085
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr ""
 
-#: common.opt:2086
+#: common.opt:2089
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr ""
 
-#: common.opt:2093
+#: common.opt:2096
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr ""
 
-#: common.opt:2097
+#: common.opt:2100
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr ""
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr ""
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr ""
 
-#: common.opt:2109
+#: common.opt:2112
 #, fuzzy
 msgid "Use a smart stack protection method for certain functions"
 msgstr "ISO C verbiedt geneste functies"
 
-#: common.opt:2113
+#: common.opt:2116
 #, fuzzy
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr "ISO C verbiedt geneste functies"
 
-#: common.opt:2117
+#: common.opt:2120
 msgid "Output stack usage information on a per-function basis"
 msgstr ""
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr ""
 
-#: common.opt:2133
+#: common.opt:2136
 msgid "Treat signed overflow as undefined"
 msgstr ""
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr ""
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr ""
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr ""
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr ""
 
-#: common.opt:2157
+#: common.opt:2160
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2163
 #, fuzzy, c-format
 msgid "unknown TLS model %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr ""
 
-#: common.opt:2187
+#: common.opt:2190
 #, fuzzy
 msgid "Assume floating-point operations can trap"
 msgstr "floating-point constante buiten bereik"
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr ""
 
-#: common.opt:2195
+#: common.opt:2198
 #, fuzzy
 msgid "Enable SSA-CCP optimization on trees"
 msgstr "lege declaratie"
 
-#: common.opt:2199
+#: common.opt:2202
 #, fuzzy
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr "lege declaratie"
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr ""
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr ""
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr ""
 
-#: common.opt:2223
+#: common.opt:2226
 #, fuzzy
 msgid "Enable copy propagation on trees"
 msgstr "lege declaratie"
 
-#: common.opt:2231
+#: common.opt:2234
 #, fuzzy
 msgid "Transform condition stores into unconditional ones"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: common.opt:2235
+#: common.opt:2238
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr ""
 
-#: common.opt:2243
+#: common.opt:2246
 #, fuzzy
 msgid "Enable dominator optimizations"
 msgstr "lege declaratie"
 
-#: common.opt:2247
+#: common.opt:2250
 #, fuzzy
 msgid "Enable tail merging on trees"
 msgstr "lege declaratie"
 
-#: common.opt:2251
+#: common.opt:2254
 #, fuzzy
 msgid "Enable dead store elimination"
 msgstr "lege declaratie"
 
-#: common.opt:2255
+#: common.opt:2258
 #, fuzzy
 msgid "Enable forward propagation on trees"
 msgstr "lege declaratie"
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr ""
 
-#: common.opt:2263
+#: common.opt:2266
 msgid "Enable string length optimizations on trees"
 msgstr ""
 
-#: common.opt:2267
+#: common.opt:2270
 #, fuzzy
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: common.opt:2273
+#: common.opt:2276
 #, fuzzy
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: common.opt:2280
+#: common.opt:2283
 #, fuzzy
 msgid "Enable loop distribution on trees"
 msgstr "lege declaratie"
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr ""
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr ""
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr ""
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr ""
 
-#: common.opt:2300
+#: common.opt:2303
 #, fuzzy
 msgid "Enable loop optimizations on tree level"
 msgstr "lege declaratie"
 
-#: common.opt:2304
+#: common.opt:2307
 msgid "Enable automatic parallelization of loops"
 msgstr ""
 
-#: common.opt:2308
+#: common.opt:2311
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2312
+#: common.opt:2315
 #, fuzzy
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "lege declaratie"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2324
+#: common.opt:2327
 #, fuzzy
 msgid "Enable reassociation on tree level"
 msgstr "lege declaratie"
 
-#: common.opt:2332
+#: common.opt:2335
 #, fuzzy
 msgid "Enable SSA code sinking on trees"
 msgstr "lege declaratie"
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr ""
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr ""
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr ""
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr ""
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr ""
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr ""
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr ""
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr ""
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr ""
 
-#: common.opt:2424
+#: common.opt:2427
 msgid "Perform variable tracking by annotating assignments"
 msgstr ""
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr ""
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr ""
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 msgid "Enable vectorization on trees"
 msgstr "lege declaratie"
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr ""
 
-#: common.opt:2454
+#: common.opt:2457
 #, fuzzy
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr "lege declaratie"
 
-#: common.opt:2458
+#: common.opt:2461
 #, fuzzy
 msgid "Specifies the cost model for vectorization"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:2478
+#: common.opt:2481
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2485
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2493
 #, fuzzy
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "lege declaratie"
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr ""
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr ""
 
-#: common.opt:2507
+#: common.opt:2510
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "niet-herkende zichtbaarheidswaarde %qs"
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr ""
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2558
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2562
 #, fuzzy
 msgid "Perform whole program optimizations"
 msgstr "lege declaratie"
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr ""
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2582
 msgid "Generate debug information in default version of DWARF format"
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2586
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2614
 msgid "Don't generate debug information in separate .dwo files"
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2618
 msgid "Generate debug information in separate .dwo files"
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr ""
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2638
 msgid "Toggle debug information generation"
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr ""
 
-#: common.opt:2665
+#: common.opt:2668
 #, fuzzy
 msgid "Generate compressed debug sections"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:2669
+#: common.opt:2672
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr ""
 
-#: common.opt:2676
+#: common.opt:2679
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr ""
 
-#: common.opt:2680
+#: common.opt:2683
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr ""
 
-#: common.opt:2702
+#: common.opt:2705
 msgid "-o <file>\tPlace output into <file>"
 msgstr ""
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr ""
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr "Zoals -pedantic, maar beschouw problemen als fouten"
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr ""
 
 # kan beter
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr "Schakel uitgebreide boodschappen in"
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr ""
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "Onderdruk waarschuwingen"
 
-#: common.opt:2806
+#: common.opt:2809
 msgid "Create a shared library"
 msgstr ""
 
-#: common.opt:2851
+#: common.opt:2854
 #, fuzzy
 msgid "Create a position independent executable"
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, fuzzy, gcc-internal-format
 msgid "value computed is not used"
 msgstr "modus van %qs is geen modus"
@@ -14914,251 +14925,251 @@
 msgid "expected integer or boolean type"
 msgstr "ongeldige waarheidsexpressie"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 #, fuzzy
 msgid "invalid comparison of nil with nil"
 msgstr "ongeldige operand voor %%s-code"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 msgid "incompatible types in binary expression"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 msgid "integer division by zero"
 msgstr "deling door nul"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 #, fuzzy
 msgid "shift of non-integer operand"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 #, fuzzy
 msgid "shift count not unsigned integer"
 msgstr "switch-waarde is geen integer"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 #, fuzzy
 msgid "negative shift count"
 msgstr "negatieve insn-lengte"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 #, fuzzy
 msgid "object is not a method"
 msgstr "opgeroepen object is geen functie"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 #, fuzzy
 msgid "method type does not match object type"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 #, fuzzy
 msgid "invalid use of %<...%> with builtin function"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 #, fuzzy
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 #, fuzzy
 msgid "not enough arguments"
 msgstr "geen argumenten"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 #, fuzzy
 msgid "too many arguments"
 msgstr "te veel argumenten voor formaat"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 msgid "argument 1 must be a map"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 #, fuzzy
 msgid "invalid type for make function"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 #, fuzzy
 msgid "too many arguments to make"
 msgstr "te veel argumenten voor formaat"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 msgid "argument must be array or slice or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 #, fuzzy
 msgid "unsupported argument type to builtin function"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 msgid "argument must be channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 #, fuzzy
 msgid "argument must be a field reference"
 msgstr "%<defined%> zonder een naam"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 #, fuzzy
 msgid "left argument must be a slice"
 msgstr "%<defined%> zonder een naam"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 #, fuzzy
 msgid "first argument must be []byte"
 msgstr "%<defined%> zonder een naam"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 msgid "second argument must be slice or string"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 #, fuzzy
 msgid "argument 2 has invalid type"
 msgstr "%Jparameter %u heeft %<void%> als type"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 #, fuzzy
 msgid "argument must have complex type"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 #, fuzzy
 msgid "complex arguments must have identical types"
 msgstr "het argument van %<cleanup%> is geen naam"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 msgid "complex arguments must have floating-point type"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 #, fuzzy
 msgid "expected function"
 msgstr "ongeldige operand van %s"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 msgid "multiple-value argument in single-value context"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 #, fuzzy
 msgid "invalid use of %<...%> with non-slice"
 msgstr "ongeldig gebruik van %<this%> op hoogste niveau"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 #, fuzzy
 msgid "function result count mismatch"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 msgid "incompatible type for receiver"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 #, fuzzy
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 #, fuzzy
 msgid "number of results does not match number of values"
 msgstr "aantal argumenten kom niet overeen met prototype"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 #, fuzzy
 msgid "index must be integer"
 msgstr "%<defined%> zonder een naam"
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 msgid "slice end must be integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 msgid "slice capacity must be integer"
 msgstr "switch-waarde is geen integer"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 msgid "incompatible type for map index"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 #, fuzzy
 msgid "too many expressions for struct"
 msgstr "te veel argumenten voor formaat"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 #, fuzzy
 msgid "too few expressions for struct"
 msgstr "te weinig argumenten voor formaat"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 msgid "type assertion only valid for interface types"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 #, fuzzy
 msgid "expected channel"
 msgstr "ongeldige operand van %s"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -15278,75 +15289,75 @@
 msgid "cannot use type %s as type %s"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 #, fuzzy
 msgid "different receiver types"
 msgstr "ongeldige operand voor %p-code"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 #, fuzzy
 msgid "different number of parameters"
 msgstr "%Jherdefinitie van parameter %qD"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 #, fuzzy
 msgid "different parameter types"
 msgstr "ongeldige operand voor %p-code"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "expliciete conversie is nodig; ontbrekende methode %s%s%s"
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr ""
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 #, fuzzy
 msgid "type has no methods"
 msgstr "struct heeft geen leden"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, fuzzy, c-format
 msgid "missing method %s%s%s"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -15467,7 +15478,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "ongeldig derde argument voor __builtin_prefetch; zal nul gebruiken"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
@@ -15650,12 +15661,12 @@
 msgstr ""
 
 # dit klinkt niet al te best
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "%qs is geen iterator"
@@ -16215,242 +16226,247 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, fuzzy, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr "teller van links shift is negatief"
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, fuzzy, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr "teller van links shift is negatief"
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, fuzzy, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr "teller van links shift is negatief"
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, fuzzy, gcc-internal-format
 msgid "execution count is negative"
 msgstr "teller van links shift is negatief"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr ""
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr "teller van links shift is negatief"
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr "teller van links shift is negatief"
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, fuzzy, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, fuzzy, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, fuzzy, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr "herhaald lid %qs"
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "dit is een eerdere declaratie"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "ongeldige beginwaarde"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "het argument van '-%s' ontbreekt"
@@ -16580,7 +16596,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, fuzzy, gcc-internal-format
 msgid "atexit failed"
@@ -16826,17 +16842,17 @@
 msgid "          %s"
 msgstr ""
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr ""
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, fuzzy, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, fuzzy, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
@@ -16881,12 +16897,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -17081,7 +17097,7 @@
 msgid "total size of local objects too large"
 msgstr "variabele %qs is te groot"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -17529,9 +17545,9 @@
 msgstr "kan bestand '%s' niet openen"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -17546,153 +17562,148 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr ""
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, fuzzy, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr ""
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:7001
-#, fuzzy, gcc-internal-format
-msgid "lastprivate variable %qE is private in outer context"
-msgstr "registervariabele %qs gebruikt in geneste functie"
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, gcc-internal-format
 msgid "directive not yet implemented"
 msgstr ""
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, fuzzy, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "ongeldige operand van %s"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
 # Of misschien beter "... niet van het %<va_list%> type"?
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "het eerste argument van %<va_arg%> is geen %<va_list%>"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT wordt tot %qT gepromoveerd indien het via %<...%> wordt doorgegeven"
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(dus U zou %qT, en niet %qT, moeten doorgeven aan %<va_arg%>)"
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "indien deze code bereikt wordt, zal het programma afgebroken worden"
@@ -18106,47 +18117,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "kan %s niet vinden"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "geen eerdere declaratie voor %qs"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -18228,49 +18239,49 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "geen invoerbestanden"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing output file '%s'\n"
 msgid "writing output file"
 msgstr "Fout bij schrijven van uitvoerbestand '%s'\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr ""
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr ""
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen %s"
@@ -18407,28 +18418,28 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "continue-statement niet in een lus"
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "continue-statement niet in een lus"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr "continue-statement niet in een lus"
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, gcc-internal-format
 msgid "ignoring large linear step"
 msgstr ""
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -18943,8 +18954,8 @@
 msgstr ""
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr ""
@@ -19384,7 +19395,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld gaf exit-status %d terug"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
@@ -20360,42 +20371,42 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr ""
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -20777,49 +20788,49 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, fuzzy, gcc-internal-format
 msgid "array subscript is outside array bounds"
 msgstr "array subscript is geen integer"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, fuzzy, gcc-internal-format
 msgid "array subscript is above array bounds"
 msgstr "array subscript is geen integer"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, fuzzy, gcc-internal-format
 msgid "array subscript is below array bounds"
 msgstr "array subscript is geen integer"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr ""
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr ""
 
 # XXX FIXME:  near-duplicate
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr "vergelijking is altijd onwaar vanwege beperkte bereik van datatype"
 
 # XXX FIXME:  near-duplicate
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr "vergelijking is altijd waar vanwege beperkte bereik van datatype"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr ""
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr ""
@@ -20863,9 +20874,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21096,7 +21107,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "het gevraagde alignment voor %s is groter dan het geïmplementeerde aligment van %d."
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "opslaggrootte van %qs is onbekend"
@@ -21245,27 +21256,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "stringlengte %qd is groter dan %qd, de lengte die ISO C%d compilers moeten ondersteunen"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "teller van links shift is negatief"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "teller van rechtse shift is negatief"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "teller van links shift is >= breedte van het type"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "teller van rechtse shift is >= breedte van het type"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overflow in constante expressie"
@@ -21596,12 +21607,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "gebruik liefst haakjes rond toewijzingen die als waarheid gebruikt worden"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "ongeldig gebruik van %<restrict%>"
@@ -22055,12 +22066,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "ongeldig vector-type voor attribuut %qE"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr ""
@@ -22070,22 +22081,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr "het aantal componenten van de vector is geen macht van twee"
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "attribuut 'nonnull' is gebruikt zonder argumenten voor een niet-prototype"
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "argument van %<nonnull%> heeft een ongeldig operandnummer (argument %lu)"
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "argument van %<nonnull%> heeft een operandnummer dat buiten bereik is (argument %lu, operand %lu)"
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "argument van %<nonnull%> verwijst naar niet-pointer operand (argument %lu, operand %lu)"
@@ -22127,12 +22138,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "attribuut %qE is enkel van toepassing op variadische functies"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "gevraagde positie is geen integerconstante"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "gevraagde positie is kleiner dan nul"
@@ -22213,7 +22224,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "poging om het adres te nemen van lid %qs van een bitveld-structure"
@@ -22631,7 +22642,7 @@
 msgstr "indexwaarde valt buiten bereik"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
@@ -23091,7 +23102,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ongeldig type voor iteratie-variabele %qE"
@@ -23101,22 +23112,22 @@
 msgid "%qE is not initialized"
 msgstr "parameter %qD krijgt beginwaarde"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "toewijzingsonderdrukking"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Ongeldig token in expressie"
@@ -23652,6 +23663,11 @@
 msgid "too many input files"
 msgstr "te veel invoerbestanden"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+msgid "-mcpu string too large"
+msgstr "bestand %qs is te groot"
+
 #: common/config/alpha/alpha-common.c:76
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -23677,47 +23693,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, fuzzy, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, fuzzy, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, fuzzy, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d ligt niet tussen 0 en 5"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -24101,64 +24117,64 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr "operandnummer buiten bereik"
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "slechte waarde %qs voor optie -mtrap-precision"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "slechte waarde %qs voor optie -mfp-rounding-mode"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "slechte waarde %qs voor optie -mfp-trap-mode"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr "slechte waarde (%s) voor optie -mcpu"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mtune switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr "fp vervollediging in software heeft -mtrap-precision=i nodig"
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "trapmodus niet ondersteund voor VAX-floats"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, fuzzy, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr "trapmodus niet ondersteund voor VAX-floats"
 
 # goed Nederlands voor 'latency'
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr "L%d cache-latency niet gekend voor %s"
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr "slechte waarde %qs voor -mmeroy-latency"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -24633,14 +24649,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, gcc-internal-format
 msgid "%qE attribute only applies to functions"
@@ -25282,378 +25298,394 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong arg %s to option %s"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr ""
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
+#, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386.c:3012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown alignment %s specified for option %s"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too many size ranges specified in option %s"
 msgstr "Bestandsnaam voor uitvoer twee keer opgegeven"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s ondersteunt %s niet"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d ligt niet tussen 0 en %d"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, fuzzy, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, fuzzy, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument van attribuut %qE is groter dan %d"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, fuzzy, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, fuzzy, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, fuzzy, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, fuzzy, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
 # XXX FIXME, ERROR:  s/none /non-/
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "attribuut %qE is gebruikt voor non-class-methode"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5923
-#, gcc-internal-format
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr ""
-
-#: config/i386/i386.c:6210
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "ondersteunt geen multilib"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, gcc-internal-format
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
 #, gcc-internal-format
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:11378
+#, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "conflicterende types voor ingebouwde functie %qs"
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "conflicterende types voor ingebouwde functie %qs"
@@ -25660,252 +25692,252 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "herdefinitie van %<union %s%>"
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "eerdere declaratie van %qs"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "derde argument voor %<__builtin_prefetch%> moet een constante zijn"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attribuut %qE is alleen beschikbaar voor 32-bits"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, fuzzy, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "incompatibel attribuut %qE wordt genegeerd"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, fuzzy, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "niet-ondersteunde versie"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -25997,13 +26029,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "attribuut %qE vereist een string-constante als argument"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr ""
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -26075,7 +26107,7 @@
 msgstr "%Jsectie-attributen worden niet ondersteund voor dit doelsysteem"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument not an integer constant"
 msgstr "herhalings-aantal is geen integerconstante"
@@ -26135,7 +26167,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, fuzzy, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "-pipe wordt niet ondersteund"
@@ -26985,16 +27017,11 @@
 msgid "-g option disabled"
 msgstr "ingeschakelde opties: "
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr ""
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, fuzzy, gcc-internal-format
@@ -27255,308 +27282,313 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "argument voor %<__builtin_args_info%> moet een constante zijn"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
+
+#: config/rs6000/rs6000.c:12763
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "het derde argument moet in het bereik 0..15 liggen"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "argument voor %<__builtin_args_info%> moet een constante zijn"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "argument voor %<__builtin_args_info%> moet een constante zijn"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had no type"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "bestand %qs is te groot"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "ongeldig gebruik van '%%%c'"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "spec '%s' is ongeldig"
@@ -27807,89 +27839,89 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "gevraagde positie is geen integerconstante"
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argument van %qs moet een niet-negatieve integer zijn"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argument van %qs is te groot (max. %d)"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "trapmodus niet ondersteund voor VAX-floats"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, fuzzy, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
@@ -27904,32 +27936,32 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr ""
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "__builtin_saveregs wordt niet ondersteund door dit sub-doelsysteem"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, gcc-internal-format
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "attribuut %qE is enkel van toepassing op interrupt-functies"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is supported only for SH2A"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr ""
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, gcc-internal-format
 msgid "%qE attribute only applies to SH2A"
 msgstr "attribuut %qE is enkel van toepassing op SH2A"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument should be between 0 to 255"
 msgstr "herhalings-aantal is geen integerconstante"
@@ -27936,22 +27968,22 @@
 
 # XXX FIXME:  duplicate
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, gcc-internal-format
 msgid "%qE attribute argument not a string constant"
 msgstr "het argument van attribuut %qE is geen string-constante"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr ""
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, gcc-internal-format
 msgid "need a second call-clobbered general purpose register"
 msgstr ""
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr ""
@@ -28328,46 +28360,46 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "ongeldig element-type voor attribuut %qs"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "het aantal componenten van de vector is geen macht van twee"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "attribuut %qs wordt genegeerd"
 
 # XXX FIXME:  near-duplicate
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "attribuut %qs vereist prototypes met benoemde argumenten"
 
 # goede vertaling van variadic?
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "attribuut %qs is enkel van toepassing op variadische functies"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "attribuut %qE heeft geen effect"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "attribuut %qs is enkel van toepassing op array-types"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -28425,7 +28457,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void-waarde niet genegeerd zoals het hoort"
@@ -28456,62 +28488,62 @@
 msgid "GCC supports only %u nested scopes"
 msgstr "GCC ondersteunt maar %u geneste bereiken (scopes)"
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, fuzzy, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, fuzzy, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "%Jgeneste functie %qD gedeclareerd maar niet gedefinieerd"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr "%Jgeneste functie %qD gedeclareerd maar niet gedefinieerd"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, fuzzy, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "%Jniet-gebruikte variabele %qD"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, fuzzy, gcc-internal-format
 msgid "variable %qD set but not used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr "een parameterlijst met een beletselteken kan niet overeenkomen met een declaratie met lege parameterlijst"
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr "een argumenttype dat een standaardpromotie heeft kan niet overeenkomen met een declaratie met lege parameterlijst"
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, fuzzy, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "%Jprototype voor %qD delcareert argument %d met een onverenigbaar type"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, fuzzy, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "%Jprototype voor %qD delcareert argument %d met een onverenigbaar type"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, fuzzy, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr "%Jprototype voor %qD delcareert argument %d met een onverenigbaar type"
@@ -28519,43 +28551,43 @@
 # wringt een beetje...
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, fuzzy, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "%Jprototype voor %qD volgt niet-prototype definitie"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "%Jeerdere definitie van %qD was hier"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, fuzzy, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "%Jeerdere impliciete declaratie van %qD was hier"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "%Jeerdere declaratie van %qD was hier"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, fuzzy, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
 # "verbergt" is niet verkeerd, maar "schaduwt" of iets dergelijks is misschien toch beter
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "%Jdeclaratie van %qD verbergt een ingebouwde functie"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "%Jherdeclaratie van enum %qD"
@@ -28563,342 +28595,342 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, fuzzy, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "%Jonverenigbare types voor ingebouwde functie %qD"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, fuzzy, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "%Jonverenigbare types voor %qD"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, fuzzy, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr "conflicterende types voor %qs"
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, fuzzy, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr "conflicterende types voor %qs"
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, fuzzy, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr "conflicterende types voor %qs"
 
 # misschien toch houden op type-qualifiers?
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, fuzzy, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "%J onverenigbare typekwalificaties voor %qD"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
 msgstr "%Jherdefinitie van typedef %qD"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "%Jherdefinitie van typedef %qD"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "%Jherdefinitie van %qD"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, fuzzy, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "%Jdeclaratie van %qD als static volgt declaratie als niet-static"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, fuzzy, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "%Jdeclaratie van %qD als niet-static volgt declaratie als static"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr ""
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, fuzzy, gcc-internal-format
 msgid "but not here"
 msgstr "van hieruit opgeroepen"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "%Jdeclaratie van %qD als thread-local volgt declaratie als niet-thread-local"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "%Jdeclaratie van %qD als niet-thread-local volgt declaratie als thread-local"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, fuzzy, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "%Jdeclaratie van %qD as extern volgt declaratie zonder specifieke linkage"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "%Jdeclaratie van %qD zonder specifieke linkage volgt declaratie als extern"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "%Jherdeclaratie van %qD zonder specifieke linkage"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr "%Jherdeclaratie van %qD met andere zichtbaarheid (oude zichtbaarheid blijft behouden)"
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, fuzzy, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "%Jdeclaratie van %qD als inline volgt declaratie met %<noinline%> attribuut"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "%Jdeclaratie van %qD met %<noinline%> attribuut volgt declaratie als inline"
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "%Jdeclaratie van %qD met %<noinline%> attribuut volgt declaratie als inline"
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, fuzzy, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "%Jherdefinitie van parameter %qD"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "%Joverbodige herdeclaratie van %qD"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "%Jdeclaratie van %qD verbergt een eerdere niet-variabele"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "%Jde verborgen declaratie is hier"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "geneste declaratie van %qD als extern"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "impliciete declaratie van functie %qE"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "onverenigbare impliciete declaratie van ingebouwde functie %qD"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "onverenigbare impliciete declaratie van functie %qD"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE is hier niet gedeclareerd (niet in een functie)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, fuzzy, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Elke niet-gedeclareerde naam wordt slechts één"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, fuzzy, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "naar label %s gerefereerd buiten enige functie"
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, fuzzy, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, fuzzy, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, fuzzy, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, fuzzy, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "overflow in constante expressie"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, fuzzy, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "herhaalde label-declaratie %qs"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "herhaald label %qs"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr ""
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr ""
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, fuzzy, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "overflow in constante expressie"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "naamloze struct/union die geen instanties definieert"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, fuzzy, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "declaratie declareert niets"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "nutteloze typenaam in lege declaratie"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> bij lege declaratie"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, fuzzy, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<inline%> bij lege declaratie"
 
 # betere vertaling voor "file-scope"?
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> in lege declaratie op bestandsniveau"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> in lege declaratie op bestandsniveau"
 
 # vertaling voor "storage class specifier"?
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "nutteloze storage class specifier in lege declaratie"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "nutteloze typenaam in lege declaratie"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "nutteloze %<__thread%> in lege declaratie"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "lege declaratie"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 ondersteunt geen %<static%> of type-qualificaties in declaratoren van parameter arrays"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 ondersteunt geen %<[*]%> declaratoren van arrays"
@@ -28906,38 +28938,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, fuzzy, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%J%qD is meestal een functie"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "typedef %qD krijgt beginwaarde (gebruik beter __typeof__)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "functie %qD krijgt beginwaarde alsof het een variabele is"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "parameter %qD krijgt beginwaarde"
@@ -28946,258 +28978,258 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "variabele %qD heeft beginwaarde, maar een onvolledig type"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "%J%<noinline%> attribuut gegeven aan ingebouwde functie %qD"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, fuzzy, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "%Jarray %qD heeft grootte die negatief of nul is"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, fuzzy, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "opslaggrootte van %qs is niet constant"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, fuzzy, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "%Jasm-specificatie wordt genegeerd voor niet-static locale variabele %qD"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "een object met een volatile veld kan niet in een register geplaatst worden"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, gcc-internal-format
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "ongeïnitialiseerde const %qD is ongeldig in C++"
 
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "bitveld %qs heeft een negatieve breedte"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "bitveld %qs heeft breedte 0"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "het type van bitveld %qs is een uitbreiding van GCC"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "breedte van %qs overschrijdt zijn type"
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 verbiedt array %qs, wiens grootte niet geëvalueerd kan worden"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 verbiedt array %qs, wiens grootte niet geëvalueerd kan worden"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, fuzzy, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "type krijgt standaardwaarde %<int%> in de declaratie van %qs"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "type krijgt standaardwaarde %<int%> in de declaratie van %qs"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "herhaalde %<const%>"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "herhaalde %<restrict%>"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "herhaalde %<volatile%>"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "herhaalde %<restrict%>"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "conflicterende declaraties van %qs"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "functie-definitie als %<register%> gedeclareerd"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "opslagklasse opgegeven voor structure-veld %qs"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "opslagklasse opgegeven voor structure-veld %qs"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "opslagklasse opgegeven voor typenaam"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, fuzzy, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs krijgt beginwaarde en is als %<extern%> gedeclareerd"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, fuzzy, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs heeft zowel %<extern%> als een beginwaarde"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "declaratie van %qs op bestandsniveau specifieert %<auto%>"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "declaratie van %qs op bestandsniveau specifieert %<auto%>"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, fuzzy, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
@@ -29205,685 +29237,685 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "%qs wordt gedeclareerd als een array van voids"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "%qs wordt gedeclareerd als een array van voids"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ongeldig gebruik van strcture met flexibel array-lid"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C verbiedt array %qs met grootte 0"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "arraytype heeft onvolledig elementtype"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, fuzzy, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
 # misschien toch houden op type-qualifiers?
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%J onverenigbare typekwalificaties voor %qD"
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "opslagklasse opgegeven voor structure-veld %qs"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "opslagklasse opgegeven voor structure-veld %qs"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "%<__alignof%> toegepast op bitveld"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "%Jtypedef %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "%Jtypedef %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C verbiedt %<const%> of %<volatile%> functie-types"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, fuzzy, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabele of veld %qs als void gedeclareerd"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, fuzzy, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, fuzzy, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, fuzzy, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "kan functie %<main%> niet %<inline%> maken"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs krijgt beginwaarde en is als %<extern%> gedeclareerd"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "eerder als %<static%> gedeclareerde variabele als %<extern%> geherdeclareerd"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "%Jvariabele %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "%Jvariabele %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, fuzzy, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "functie-declaratie is geen prototype"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "%Jparameter %u (%qD) heeft een onvolledig type"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "%Jparameter %u (%qD) heeft %<void%> als type"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "%Jparameter %u heeft %<void%> als type"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> als enige parameter mag niet gekwalificeerd worden"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> moet de enige parameter zijn"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "%Jparameter %qD heeft enkel een voorwaartse declaratie"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "%<%s %E%> gedeclareerd binnen parameterlijst"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "anonieme %s gedeclareerd binnen parameterlijst"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "het bereik ervan is enkel deze definitie of declaratie, hetgeen waarschijnlijk niet de bedoeling is"
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, fuzzy, gcc-internal-format
 msgid "enum type defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, fuzzy, gcc-internal-format
 msgid "struct defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, fuzzy, gcc-internal-format
 msgid "union defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "herdefinitie van %<union %s%>"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "geneste herdefinitie van %<union %s%>"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "geneste herdefinitie van %<struct %s%>"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "declaratie declareert niets"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ondersteunt geen naamloze structs/unions"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ondersteunt geen naamloze structs/unions"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, fuzzy, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "%Jherhaald lid %qD"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union heeft geen benoemde leden"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union heeft geen leden"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct heeft geen benoemde leden"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct heeft geen leden"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "%Jflexibel array-lid in union"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr "%Jflexibel array-lid in overigens lege struct"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union kan niet transparant gemaakt worden"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "geneste herdefinitie van %<enum %qs%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "herdeclaratie van %<enum %qs%>"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "enumeratiewaarden overschrijden het bereik van de grootste integer"
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "opgegeven modus is te klein voor enumeratiewaarden"
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "overflow in enumeratiewaarden"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "%J%<noinline%> attribuut gegeven aan ingebouwde functie %qD"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "teruggeeftype is onvolledig"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "teruggeeftype krijgt standaardwaarde %<int%>"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "%Jgeen eerder prototype voor %qD"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder protoype"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%Jgeen eerdere declaratie voor %qD"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder declaratie"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%Jteruggeeftype van %qD is niet %<int%>"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%J%qD is gewoonlijk een niet-static funtie"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, fuzzy, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%Jparameterdeclaraties in oude stijl gebruikt in de definitie van een functie die een prototype heeft"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, fuzzy, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%Jtraditionele C verwerpt functiedefinities in de stijl van ISO C"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, fuzzy, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "%Jparameternaam weggelaten"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, fuzzy, gcc-internal-format
 msgid "old-style function definition"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "%Jparameternaam ontbreekt in parameterlijst"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%J%qD als niet-parameter gedeclareerd"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "%Jmeerdere parameters hebben de naam %qD"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "%Jparameter %qD als void gedeclareerd"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%Jtype van %qD krijgt standaardtype %<int%>"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "%Jparameter %qD heeft een onvolledig type"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "%Jdeclaratie voor parameter %qD maar er is zo geen parameter"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, fuzzy, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "aantal argumenten kom niet overeen met prototype"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "aantal argumenten kom niet overeen met prototype"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "%Hdeclaratie van prototype"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "gepromoveerd argument %qD komt niet overeen met prototype"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "gepromoveerd argument %qD komt niet overeen met prototype"
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parameter %qD krijgt beginwaarde"
@@ -29891,199 +29923,199 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "initiële declaratie voor %<for%> lus gebruikt buiten C99 modus"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, fuzzy, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, fuzzy, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, fuzzy, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "herhaalde %qs"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "twee of meer data types opgegeven bij declaratie"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> is te lang voor GCC"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 ondersteunt geen complexe types"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 ondersteunt geen complexe types"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
 # is letterlijke vertaling maar klinkt zo vreemd...
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, fuzzy, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qs slaagt er niet in een typedef of ingebouwd type te zijn"
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, fuzzy, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> samen met %<auto%> gebruikt"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> samen met %<register%> gebruikt"
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> samen met %<typedef%> gebruikt"
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "%s ondersteunt %s niet"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> vóór %<extern%> gebruikt"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> vóór %<static%> gebruikt"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<__thread%> samen met %<auto%> gebruikt"
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ondersteunt gewone %<complex%> niet in de betekenis van %<double complex%>"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -30093,7 +30125,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr ""
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "ongeldige operand van %s"
@@ -30113,8 +30145,8 @@
 msgid "unknown type name %qE"
 msgstr "onbekende machine-modus %qs"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "meerdere opslagklassen in declaratie van %qs"
@@ -30129,7 +30161,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -30206,7 +30238,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -30263,14 +30295,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma aan het einde van enumerator-lijst"
@@ -30723,32 +30755,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "misvormde #pragma pack"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "misvormde #pragma pack"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "attribuut %<getter%> mag slechts één keer opgegeven worden"
@@ -30758,47 +30790,47 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "misvormde #pragma pack(pop[,id])"
@@ -30813,12 +30845,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "ongeldige waarheidsexpressie"
@@ -30828,27 +30860,27 @@
 msgid "expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a constant"
 msgstr "%qs is geen iterator"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
@@ -30880,17 +30912,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr ""
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ongeldige const_double operand"
@@ -30910,12 +30942,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -30935,17 +30967,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ongeldige const_double operand"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr ""
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ongeldige const_double operand"
@@ -30955,57 +30987,57 @@
 msgid "invalid proc_bind kind"
 msgstr "ongeldige const_double operand"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 msgid "invalid pragma"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -31015,17 +31047,17 @@
 msgid "expected %<(%> or end of line"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "herdeclaratie van %qs"
@@ -31035,237 +31067,237 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, fuzzy, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, gcc-internal-format
 msgid "pragma simd must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "vectorlengte moet een integerconstante zijn"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr ""
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr ""
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, fuzzy, gcc-internal-format
 msgid "base of array section must be pointer or array type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 msgid "array notations cannot be used with function type"
 msgstr "cast geeft functie-type op"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 msgid "expected array notation expression"
 msgstr "ongeldige waarheidsexpressie"
@@ -31275,7 +31307,7 @@
 msgid "%qD has an incomplete type"
 msgstr "%qs heeft een onvolledig type"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ongeldig gebruik van een void-expressie"
@@ -31382,7 +31414,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "array subscript is geen integer"
@@ -31505,7 +31537,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "%s als signed ten gevolge van prototype"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "ongeldige registernaam voor %qs"
@@ -31537,7 +31569,7 @@
 msgstr "rekensom met pointer naar onvolledig type"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "rekensom met pointer naar onvolledig type"
@@ -31623,7 +31655,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "ongeldige registernaam voor %qs"
@@ -31659,7 +31691,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen (pointer/integer)"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr ""
@@ -31744,7 +31776,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "cast naar pointer van integer met andere grootte"
@@ -31906,7 +31938,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -32047,7 +32079,7 @@
 msgid "initialization of a flexible array member"
 msgstr "initialisatie van flexibel array-lid"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-array heeft wide string als beginwaarde"
@@ -32093,7 +32125,7 @@
 msgid "invalid initializer"
 msgstr "ongeldige beginwaarde"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
@@ -32239,7 +32271,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C verbiedt %<goto *expr;%>"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, fuzzy, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> gedeclareerde functie bevat een %<return%> statement"
@@ -32249,7 +32281,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -32356,17 +32388,17 @@
 msgid "expression statement has incomplete type"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
@@ -32418,12 +32450,12 @@
 msgstr "geordende vergelijking van pointer met null-pointer"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "geordende vergelijking van pointer met integer nul"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
@@ -32448,85 +32480,85 @@
 msgid "used vector type where scalar is required"
 msgstr "waarde van struct-type gebruikt waar een scalair nodig is"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qs is smaller dan waarden van zijn type"
@@ -32536,17 +32568,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -32556,7 +32588,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -32566,17 +32598,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -32591,47 +32623,47 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -32642,33 +32674,33 @@
 msgstr ""
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, fuzzy, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "ongeldige registernaam voor %qs"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 msgid "  no known conversion from %qT to %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, fuzzy, gcc-internal-format
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -32675,83 +32707,83 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, gcc-internal-format
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr ""
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, fuzzy, gcc-internal-format
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "<ingebouwd>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, fuzzy, gcc-internal-format
 msgid "%s%D(%T) <built-in>"
 msgstr "<ingebouwd>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, gcc-internal-format
 msgid "%s%T <conversion>"
 msgstr ""
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr ""
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr ""
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr ""
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr "conversie naar niet-scalair type gevraagd"
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
@@ -32758,457 +32790,457 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr ""
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, fuzzy, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "ongeldige operand voor %P"
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "ongeldige operand voor %P"
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "%s\n"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%J%s %<%c%s%>"
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ verbiedt het weglaten van de middelste term van een ?: expresie"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, fuzzy, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "vergelijking tussen %q#T en %q#T"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, fuzzy, gcc-internal-format
 msgid "non-placement deallocation function %q+D"
 msgstr "impliciete declaratie van functie %qE"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr ""
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is private"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr "%s is niet addresseerbaar"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr ""
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, fuzzy, gcc-internal-format
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, fuzzy, gcc-internal-format
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %q+D"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, gcc-internal-format
 msgid "cannot bind %qT lvalue to %qT"
 msgstr ""
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, fuzzy, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, fuzzy, gcc-internal-format
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "kan oproep van %qs niet inline maken"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "herdeclaratie van %qs"
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, fuzzy, gcc-internal-format
 msgid "  in call to %q+D"
 msgstr "kan oproep van %qs niet inline maken"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr ""
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, fuzzy, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, fuzzy, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, fuzzy, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr "kandidaat is: %+#D"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr "kandidaat is: %+#D"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr ""
@@ -33364,7 +33396,7 @@
 msgid "  by %q+D"
 msgstr "%s voor %qs"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, fuzzy, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
@@ -33374,7 +33406,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, fuzzy, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
@@ -33384,7 +33416,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr ""
@@ -33514,67 +33546,77 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4538
+#: cp/class.c:4300
+#, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
 #, fuzzy, gcc-internal-format
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr "de declaratie van %qs verbergt een parameter"
+
+#: cp/class.c:4557
+#, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "geen beginwaarde voor variant-veld %qs"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%qs is geen iterator"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has volatile type"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr ""
@@ -33581,102 +33623,102 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "taal-string %<\"%E\"%> wordt niet herkend"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "herhaald lid %qs"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -33686,12 +33728,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr ""
@@ -33731,254 +33773,254 @@
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, fuzzy, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, fuzzy, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr "%J%qD is gewoonlijk een niet-static funtie"
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 msgid "call to internal function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, fuzzy, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder protoype"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 msgid "array subscript out of bound"
 msgstr "array subscript is geen integer"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 msgid "negative array subscript"
 msgstr "Array subscript verwacht op %C"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "array-index in beginwaarde van niet-array"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%qs is geen iterator"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant-expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant-expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, fuzzy, gcc-internal-format
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, fuzzy, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant-expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "niet-constante array-index in beginwaarde"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "onverwachte operand"
@@ -34049,7 +34091,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr ""
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr ""
@@ -34089,7 +34131,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, fuzzy, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "kan niet derefereren, is geen pointer."
@@ -34099,292 +34141,292 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, fuzzy, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr ""
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr ""
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "conversie naar niet-scalair type gevraagd"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "ongeldige toepassing van %qs op onvolledig type %qT "
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, fuzzy, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, fuzzy, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, fuzzy, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, fuzzy, gcc-internal-format
 msgid "statement has no effect"
 msgstr "statement zonder effect"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, fuzzy, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -34795,238 +34837,238 @@
 msgid "template parameters do not match template %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, fuzzy, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr "anonieme %s gedeclareerd binnen parameterlijst"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, fuzzy, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr "anonieme %s gedeclareerd binnen parameterlijst"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, fuzzy, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "nutteloos sleutelwoord of typenaam in lege declaratie"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, fuzzy, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, fuzzy, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, fuzzy, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "type krijgt standaardwaarde %<int%> in de declaratie van %qs"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<register%> in lege declaratie op bestandsniveau"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD krijgt beginwaarde (gebruik beter __typeof__)"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabele %qs heeft beginwaarde, maar een onvolledig type"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementen van array %qs hebben een onvolledig type"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "array %qs heeft grootte die negatief of 0 is"
@@ -35034,825 +35076,825 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "opslaggrootte van %qs is niet constant"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "ongeïnitialiseerde const %qD"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ongeldige beginwaarde"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "ongeldige beginwaarde voor veld %qs"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementen van array %qs hebben een onvolledig type"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ISO C90 verbiedt het gebruik van samengestelde expressies als lvalues"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%qs heeft een onvolledig type"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr ""
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, fuzzy, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "typedef %qs krijgt beginwaarde alsof het een variabele is"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "array %qs heeft grootte die negatief of 0 is"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> variable"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, fuzzy, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, gcc-internal-format
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "Ongeldige optie %qs"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, fuzzy, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, fuzzy, gcc-internal-format
 msgid "%q+#D explicitly defaulted here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, fuzzy, gcc-internal-format
 msgid "size of array is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, fuzzy, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ verbiedt array %qs van variabele lengte"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ verbiedt array %qs van variabele lengte"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qs wordt gedeclareerd als een array van voids"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "functie-definitie als %<register%> gedeclareerd"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ondersteunt gewone %<complex%> niet in de betekenis van %<double complex%>"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ verbiedt lid-declaraties zonder leden"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs wordt niet ondersteund door dit doelsysteem"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "'long', 'short', 'signed' of 'unsigned' ongeldig voor %qs"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "zowel 'signed' als 'unsigned' opgegeven voor %qs"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, fuzzy, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, fuzzy, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, fuzzy, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "'long', 'short', 'signed' of 'unsigned' ongeldig voor %qs"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, fuzzy, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "'long', 'short', 'signed' of 'unsigned' ongeldig voor %qs"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "'long' of 'short' opgegeven bij 'char' voor %qs"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "zowel 'long' als 'short' opgegeven voor %qs"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, fuzzy, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "'long', 'short', 'signed' of 'unsigned' ongeldig voor %qs"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, fuzzy, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "ongeldig gebruik van 'long', 'short', 'signed' of 'unsigned' voor %qs"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr ""
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
@@ -35859,472 +35901,472 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr ""
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, fuzzy, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, fuzzy, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> bij lege declaratie"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, fuzzy, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "%Jtypedef %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, fuzzy, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr "twee types opgegeven in één lege declaratie"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared %<auto%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr ""
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabele of veld %qs als void gedeclareerd"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, fuzzy, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, fuzzy, gcc-internal-format
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs krijgt beginwaarde en is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs heeft zowel %<extern%> als een beginwaarde"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "ongeldig type-argument %qs"
 
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "%Jparameter %qD heeft een onvolledig type"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -36344,173 +36386,173 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, fuzzy, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr ""
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, fuzzy, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, fuzzy, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, fuzzy, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -36522,88 +36564,88 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, fuzzy, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr ""
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr ""
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "%qs is geen typedef of ingebouwd type"
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "herhaalde case-waarde"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "eerdere definitie van %qs"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr ""
@@ -36612,87 +36654,87 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow in enumeratiewaarden"
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr ""
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, fuzzy, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr "teruggeeftype is onvolledig"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "%Jgeen eerdere declaratie voor %qD"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, fuzzy, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D set but not used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "kan klasse '%s' niet vinden"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -36732,7 +36774,7 @@
 msgid "deleting %qT is undefined"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "herdeclaratie van %qs"
@@ -36755,7 +36797,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "%<%s %s%> binnen parameterlijst gedeclareerd"
@@ -36845,27 +36887,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, fuzzy, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qs is geen static veld"
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, fuzzy, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonieme %s gedeclareerd binnen parameterlijst"
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, fuzzy, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonieme %s gedeclareerd binnen parameterlijst"
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -36874,47 +36916,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, fuzzy, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "de tweede parameter van %<va_start%> is niet het laatste benoemde argument"
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, fuzzy, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using anonymous type, is used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
@@ -36923,47 +36965,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "parameternaam ontbreekt uit parameterlijst"
@@ -36970,12 +37012,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "kan functie %<main%> niet inline maken"
@@ -37552,42 +37594,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr ""
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -37717,17 +37759,17 @@
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, gcc-internal-format
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, gcc-internal-format
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
@@ -38140,7 +38182,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr ""
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -38165,7 +38207,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
@@ -38230,7 +38272,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qs is geen iterator"
@@ -38255,7 +38297,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -38524,7 +38566,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ongeldige operand van %s"
@@ -38699,7 +38741,7 @@
 msgid "capture of non-variable %qD "
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, fuzzy, gcc-internal-format
 msgid "%q+#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -38759,7 +38801,7 @@
 msgid "compound-statement in constexpr function"
 msgstr ""
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "herdeclaratie van %qs"
@@ -38790,7 +38832,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "herdeclaratie van %qs"
@@ -38821,12 +38863,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ verbiedt geneste functies"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
@@ -38873,7 +38915,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
@@ -38964,12 +39006,12 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
@@ -38984,7 +39026,7 @@
 msgid "expected template-id"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ongeldige operand van %s"
@@ -39061,209 +39103,209 @@
 msgid "expected type specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "declaratie declareert niets"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an enumerator-name"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "geen eerdere declaratie voor %qs"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "functie %qs geherdeclareerd als inline"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "array subscript is geen integer"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -39272,7 +39314,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "herdeclaratie van %qs"
@@ -39279,292 +39321,292 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, fuzzy, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "herhaald lid %qs"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "onverwachte operand"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, fuzzy, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, fuzzy, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "[kan %s niet vinden]"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr "eerdere definitie van %qs"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr ""
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "twee of meer data types in de declaratie van %qs"
@@ -39573,428 +39615,428 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vóór %<extern%> gebruikt"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "zowel %<short%> als %<char%> opgegeven bij declaratie"
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "herhaalde %qs"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "herhaalde %qs"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Ongeldige optie %qs"
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefix-attributen worden genegeerd vóór %<@%D%>"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ongeldige operand voor 'p' modifier"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 msgid "expected positive integer expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr ""
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, gcc-internal-format
 msgid "not enough collapsed for loops"
 msgstr ""
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, fuzzy, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "rommel aan einde van %<#pragma GCC pch_preprocess%>"
 
 # "constraints" hier te vertalen ("beperkingen"/"restricties") of niet?
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
@@ -40001,107 +40043,107 @@
 msgstr "ongeldige constraints voor operand"
 
 # 'braced-group'? Wie schrijft verdorie die foutmeldingen?
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 msgid "expected variable-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, fuzzy, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr "herdefinitie van %qs"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -40108,67 +40150,67 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, fuzzy, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, fuzzy, gcc-internal-format
 msgid "candidate is: %#D"
 msgstr "kandidaat is: %+#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr ""
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, gcc-internal-format
 msgid "too many template headers for %D (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -40175,57 +40217,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qs is meestal een functie"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, fuzzy, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "%<%.*s%> is niet gedefinieerd"
@@ -40238,92 +40280,92 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, fuzzy, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "%qs impliciet als functie gedeclareerd"
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, fuzzy, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "<anoniem>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, fuzzy, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -40330,12 +40372,12 @@
 msgstr[0] "argument %d is alleen-lezen"
 msgstr[1] "argument %d is alleen-lezen"
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "ongeldig type-argument %qs"
@@ -40343,42 +40385,42 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
@@ -40388,57 +40430,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "herdefinitie van %<union %s%>"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, fuzzy, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -40445,7 +40487,7 @@
 msgstr[0] "macro %qs gebruikt zonder argumenten"
 msgstr[1] "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q+D used %d template parameter"
 msgid_plural "previous declaration %q+D used %d template parameters"
@@ -40452,12 +40494,12 @@
 msgstr[0] "eerdere declaratie van %qs"
 msgstr[1] "eerdere declaratie van %qs"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, fuzzy, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "ongeldige naam %qs"
@@ -40466,102 +40508,102 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -40568,172 +40610,172 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "iterator %qs is van een afgeleid type"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, fuzzy, gcc-internal-format
 msgid "  could not resolve address from overloaded function %qE"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT "
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr ""
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr ""
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "meerdere parameters hebben de naam %qs"
@@ -40740,78 +40782,78 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d or more)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "verkeerd aantal sjabloonargumenten (%d, moet %d of meer zijn)"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "gegeven voor %q+D"
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D is geen functiesjabloon"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, fuzzy, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "lege declaratie"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "herdefinitie van %<struct %s%>"
@@ -40829,269 +40871,269 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ongeldige operand voor %p-code"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared here, later in the translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr ""
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "herhaalde definitie %qs"
 
 # XXX FIXME:  useless gettextization
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 #| msgid "%s %qs"
 msgid "%s %#S"
 msgstr "%s %qs"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qs is geen static veld"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "herhaalde definitie %qs"
@@ -41103,62 +41145,62 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan %qs niet nabootsen"
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
@@ -41395,260 +41437,260 @@
 msgid "invalid base-class specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, fuzzy, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "modi in %s expressie komen niet overeen"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qs is geen iterator"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, fuzzy, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, gcc-internal-format
 msgid "%<num_teams%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, fuzzy, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr "Ongeldige modus voor gen_tst_reg"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "%Jdeclaratie van %qD als niet-static volgt declaratie als static"
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, fuzzy, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
@@ -41663,122 +41705,122 @@
 msgid "lambda-expression in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "attribuut %qE is enkel van toepassing op Java-class-definities"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "attribuut %qE is enkel van toepassing op class-definities"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr ""
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "herdeclaratie van %qs"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "'%%%c' is not a valid operand prefix"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "'%%%c' is geen geldige operand-prefix"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "herhaalde definitie %qs"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attribuut %qE is enkel van toepassing op functies, niet %s"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attribuut %qE is enkel van toepassing op functies"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "array subscript is geen integer"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -41968,566 +42010,561 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr "alignment van %qs is groter dan het maximale alignment van het objectbestand. %d wordt gebruikt."
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, fuzzy, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr "ISO C++ verbiedt het gebruik van subscripts bij een array die geen lvalue is"
-
-#: cp/typeck.c:3157
-#, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ verbiedt accolade-groepen in expressies"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "te veel argumenten voor functie %qE"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "te veel argumenten voor functie %qE"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "te veel argumenten voor functie"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "te weinig argumenten voor functie"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter heeft een onvolledig type"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameter heeft een onvolledig type"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, fuzzy, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, fuzzy, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, fuzzy, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "teller van links shift is negatief"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, fuzzy, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "teller van rechtse shift is negatief"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, fuzzy, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "teller van links shift is >= breedte van het type"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, fuzzy, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "teller van rechtse shift is >= breedte van het type"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr ""
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ verbiedt een vergelijking tussen pointer en integer"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "operand-types zijn %qT en %qT"
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr ""
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "pointer van type %<void *%> gebruikt in aftrekking"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, fuzzy, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "rekensom met pointer naar onvolledig type"
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, gcc-internal-format
 msgid "taking address of constructor %qE"
 msgstr ""
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qE"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr ""
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ verbiedt het %sen van een pointer van type %qT"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ verbiedt het %sen van een pointer van type %qT"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "ongeldige expressie als operand"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, fuzzy, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adres van registervariabele %qs gevraagd"
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, fuzzy, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, fuzzy, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, fuzzy, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, fuzzy, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr ""
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "cast verhoogt het benodigde alignment van het doeltype"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, fuzzy, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ verbiedt voorwaardelijke expressies tussen 0 en een functiepointer"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, fuzzy, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ verbiedt casts naar een union-type"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "array-index in beginwaarde van niet-array"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr ""
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, fuzzy, gcc-internal-format
 msgid "address of label %q+D returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -42534,45 +42571,45 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "%<return%> met waarde in een functie die void teruggeeft"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -42799,122 +42836,122 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, fuzzy, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-array heeft niet-wide string als beginwaarde"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, fuzzy, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-array heeft niet-wide string als beginwaarde"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "beginwaarde-string voor array van chars is te lang"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "onbekend veld %qs opgegeven in beginwaarde"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "dubbele beginwaarde"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
@@ -43093,8 +43130,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -43229,7 +43266,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr "eerdere definitie van %qs"
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -43352,7 +43389,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -43995,13 +44032,13 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
@@ -44278,6 +44315,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -44285,7 +44327,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -44506,400 +44548,400 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "Function name %qs not allowed at %C"
 msgstr "Functienaam '%s' niet toegestaan op %C"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, fuzzy, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "dubbele beginwaarde"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "dubbele beginwaarde"
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Initialisatie op %C is niet voor een pointervariable"
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, fuzzy, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, fuzzy, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
@@ -44906,795 +44948,800 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "%qs is geen iterator"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Array subscript-stap verwacht op %C"
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:5597
-#, gcc-internal-format
-msgid "gfc_match_entry(): Bad state"
-msgstr ""
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Unexpected ENTRY statement at %C"
+msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Functienaam '%s' niet toegestaan op %C"
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "ongeldige beginwaarde"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr ""
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, fuzzy, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initialisatie op %C is niet voor een pointervariable"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "kan klasse '%s' niet vinden"
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Array subscript verwacht op %C"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Array subscript verwacht op %C"
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Malformed GENERIC statement at %C"
+msgstr "ongeldige beginwaarde"
+
+#: fortran/decl.c:8526
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, fuzzy, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%s voor %qs"
@@ -45975,343 +46022,343 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "%qs is meestal een functie"
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetische underflow bij conversie van %s naar %s op %L"
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetische underflow bij conversie van %s naar %s op %L"
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetische underflow bij conversie van %s naar %s op %L"
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "ongeldige registernaam voor %qs"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "ongeldige registernaam voor %qs"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 msgid "Conversion from %qs to %qs at %L"
 msgstr "ongeldige registernaam voor %qs"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, fuzzy, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
 # dit klinkt niet al te best
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "kan bestand '%s' niet openen"
@@ -46333,27 +46380,27 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, fuzzy, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "ongeldige operand in de instructie"
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr ""
@@ -46408,592 +46455,597 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr ""
+
+#: fortran/interface.c:353
+#, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr ""
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr ""
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr ""
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr ""
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr ""
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr ""
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, gcc-internal-format
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr ""
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, gcc-internal-format
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr ""
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, fuzzy, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "kan klasse '%s' niet vinden"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, fuzzy, gcc-internal-format
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
@@ -47403,12 +47455,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
@@ -47418,7 +47470,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
@@ -47444,778 +47496,778 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "-I- twee keer opgegeven"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "ongeldige registernaam voor %qs"
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr ""
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr ""
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "ongeldige expressie als operand"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr "case-selector niet compatibel met label"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "overflow in constante expressie"
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
 msgstr ""
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr ""
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr "herhaalde case-waarde"
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 msgid "Label name %qs at %C is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, fuzzy, gcc-internal-format
 msgid "Duplicate construct label %qs at %C"
 msgstr "herhaalde case-waarde"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr "opvulkarakter in strfmon-formaat"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr ""
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr ""
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr ""
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr ""
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr ""
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, gcc-internal-format, gfc-internal-format
 msgid "gfc_match(): Bad match code %c"
 msgstr ""
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %C"
 msgstr "Arithmetische NaN op %L"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr "integer overflow in expressie"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr "floating-point overflow in expressie"
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr ""
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr ""
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr "Array subscript-stap verwacht op %C"
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr "Array subscript verwacht op %C"
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in association at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, fuzzy, gcc-internal-format
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "opvulkarakter in strfmon-formaat"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr ""
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "continue-statement niet in een lus"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "break-statement niet in een lus of switch"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, fuzzy, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "break-statement niet in een lus of switch"
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "break-statement niet in een lus of switch"
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "vector overflow in expressie"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr ""
@@ -48223,147 +48275,147 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr ""
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, fuzzy, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr ""
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr ""
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, fuzzy, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -48509,168 +48561,168 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "naar label %s gerefereerd buiten enige functie"
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, fuzzy, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "%s: kan bestand '%s' niet openen om te lezen: %s\n"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: fout bij schrijven van bestand '%s': %s\n"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: kan aux-infobestand '%s' niet verwijderen: %s\n"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: waarschuwing: kan naam van bestand '%s' niet wijzigen in '%s': %s\n"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: kan aux-infobestand '%s' niet verwijderen: %s\n"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: kan bestand '%s' niet openen om te lezen: %s\n"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr ""
@@ -48966,7 +49018,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -49659,367 +49711,362 @@
 msgid "Unexpected %s statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/parse.c:2428
-#, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr "ongeldige beginwaarde"
-
-#: fortran/parse.c:2439
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr "ongeldige operand van %s"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "eerdere declaratie van %qs"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "overflow in constante expressie"
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, fuzzy, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, fuzzy, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr ""
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr ""
@@ -50027,7 +50074,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -50722,7 +50769,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "naar label %s gerefereerd buiten enige functie"
@@ -50777,364 +50824,364 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, fuzzy, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, fuzzy, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs is meestal een functie"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, fuzzy, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "%s voor %qs"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, fuzzy, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, fuzzy, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, fuzzy, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, fuzzy, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "-shared en -mdll zijn niet compatibel"
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
@@ -51143,12 +51190,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
@@ -51157,248 +51204,248 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -51407,191 +51454,191 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "expressie-statement heeft onvolledig type"
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%<defined%> zonder een naam"
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -51598,12 +51645,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -51611,158 +51658,158 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr ""
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%s van alleen-lezen variabele %qs"
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr ""
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr ""
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -51769,7 +51816,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -51777,57 +51824,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr ""
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "String-lengte bij %L is te groot"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
@@ -51834,426 +51881,426 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, fuzzy, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, fuzzy, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -52260,398 +52307,398 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring bij %L heeft lengte nul"
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -52683,47 +52730,47 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr ""
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr ""
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr ""
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "karakterconstante met meer dan één karakter"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr ""
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
 msgstr ""
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr ""
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr ""
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr ""
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 msgid "Can't open file %qs"
 msgstr "kan bestand '%s' niet openen"
@@ -52989,52 +53036,52 @@
 msgid "Reshaped array too large at %C"
 msgstr "omvang van array %qs is te groot"
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, fuzzy, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr "overflow in constante expressie"
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -53112,316 +53159,321 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
+
+#: fortran/symbol.c:489
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr ""
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr ""
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "herhaalde case-waarde"
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -53682,7 +53734,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -55506,6 +55558,10 @@
 #~ msgstr "union heeft geen lid dat %qs heet"
 
 #, fuzzy
+#~ msgid "ISO C++ forbids subscripting non-lvalue array"
+#~ msgstr "ISO C++ verbiedt het gebruik van subscripts bij een array die geen lvalue is"
+
+#, fuzzy
 #~ msgid "taking address of array of runtime bound"
 #~ msgstr "ongeldig gebruik van een array zonder opgegeven grenzen"
 
Index: gcc/po/ChangeLog
===================================================================
--- gcc/po/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,18 @@
+2015-08-17  Joseph Myers  <joseph@codesourcery.com>
+
+	* da.po: Update.
+
+2015-07-31  Joseph Myers  <joseph@codesourcery.com>
+
+	* sv.po: Update.
+
+2015-07-24  Joseph Myers  <joseph@codesourcery.com>
+
+	* be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
+	ja.po, nl.po, ru.po, sr.po, sv.po, tr.po, vi.po, zh_CN.po,
+	zh_TW.po: Update.
+	* uk.po: New file.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: gcc/po/vi.po
===================================================================
--- gcc/po/vi.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/vi.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: gcc 5.1-b20150208\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2015-02-24 15:18+0700\n"
 "Last-Translator: Trần Ngọc Quân <vnwildman@gmail.com>\n"
 "Language-Team: Vietnamese <translation-team-vi@lists.sourceforge.net>\n"
@@ -194,13 +194,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "sai sử dụng hằng số dấu chấm động"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1414,7 +1414,7 @@
 msgid "options enabled: "
 msgstr "tùy chọn đã bật: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2608,97 +2608,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "tiền tố toán hạng không hợp lệ “%%%c”"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "“%%&” bị sử dụng mà không có tham chiếu TLS năng động cục bộ"
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "giá trị %%H sai"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "giá trị %%J sai"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "giá trị %%r sai"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "giá trị %%R sai"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "giá trị %%N sai"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "giá trị %%P sai"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "giá trị %%h sai"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "giá trị %%L sai"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "giá trị %%m sai"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "giá trị %%M sai"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "giá trị %%U sai"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "giá trị %%s sai"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "giá trị %%C sai"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "giá trị %%E sai"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "không rõ bỏ ghi rõ bố trí lại"
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "mã %%xn sai"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, c-format
 msgid "invalid operand address"
 msgstr "địa chỉ toán hạng không hợp lệ"
@@ -2746,7 +2746,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "sai đặt mã kết xuất toán hạng"
@@ -2900,8 +2900,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3121,62 +3121,62 @@
 msgid "bad output_condmove_single operand"
 msgstr "đặt sai toán hạng output_condmove_single"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "đặt sai UNSPEC như là toán hạng"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “O”"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “z”"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "sử dụng loại toán hạng không hợp lệ với mã toán hạng “Z”"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “Z”"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “D”"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng không hợp lệ “%c”"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "mã toán hạng sai “%c”"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "sai đặt ràng buộc cho toán hạng"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "không rõ chế độ lệnh"
 
@@ -3216,7 +3216,7 @@
 msgid "invalid %%P operand"
 msgstr "gặp toán hạng %%P sai"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "gặp giá trị %%p sai"
@@ -3280,7 +3280,7 @@
 msgstr "địa chỉ hậu gia không phải là một thanh ghi"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "địa chỉ sai"
 
@@ -3442,99 +3442,99 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory không sẵn sàng trên chế độ little endian"
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 msgid "bad move"
 msgstr "sai di chuyển"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, c-format
 msgid "invalid %%e value"
 msgstr "giá trị %%e sai"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "giá trị %%f sai"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "giá trị %%F sai"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "giá trị %%G sai"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "mã %%j sai"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "mã %%J sai"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "giá trị %%k sai"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "giá trị %%K sai"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "giá trị %%O sai"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "giá trị %%q sai"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "giá trị %%S sai"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "giá trị %%T sai"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "giá trị %%u sai"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "giá trị %%v sai"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "giá trị %%x sai"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "giá trị %%y sai, hãy thử sử dụng ràng buộc “Z”"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "đối số AltiVec bị gửi cho hàm không nguyên mẫu"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 msgid "Could not generate addis value for fusion"
 msgstr "Không thể tạo addis cho sát nhập"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 #, fuzzy
 msgid "Unable to generate load offset for fusion"
 msgstr "không thể tạo ra việc nạp lại cho:"
@@ -3629,60 +3629,60 @@
 msgid "invalid operand to %%S"
 msgstr "sai đặt toán hạng tới %%S"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr "tạo và sử dụng với các kiến trúc hoặc ABI khác nhau"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr "tạo và sử dụng với các ABI khác nhau"
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr "tạo và sử dụng với các trình trạng cuối khác nhau"
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "toán hạng %%Y sai"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "toán hạng %%A sai"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "toán hạng %%B sai"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, c-format
 msgid "invalid %%C operand"
 msgstr "sai toán hạng %%C"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, c-format
 msgid "invalid %%D operand"
 msgstr "sai toán hạng %%D"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "toán hạng %%f sai"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "toán hạng %%s sai"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "hằng số dài dài không phải là một toán hạng số trực tiếp"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "hằng số dấu chấm động không phải là một giá trị trực tiếp đúng"
@@ -3885,7 +3885,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "cần %<;%>"
@@ -3901,15 +3901,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "cần %<(%>"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "cần %<,%>"
@@ -3931,8 +3931,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "cần %<)%>"
@@ -3939,8 +3939,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "cần %<]%>"
@@ -3949,13 +3949,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "cần %<;%>, %<,%> hoặc %<)%>"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "cần %<}%>"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "cần %<{%>"
@@ -3962,8 +3962,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "cần %<:%>"
@@ -3984,7 +3984,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "cần %<while%>"
@@ -4001,34 +4001,34 @@
 msgid "expected %<.%>"
 msgstr "cần %<.%>"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "cần %<@end%>"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "cần %<>%>"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "cần %<,%> hoặc %<)%>"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "cần %<=%>"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "cần %<#pragma omp section%> hoặc %<}%>"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "cần %<[%>"
@@ -4037,11 +4037,11 @@
 msgid "(anonymous)"
 msgstr "(nặc danh)"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "ứng cử 1:"
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "ứng cử 2:"
 
@@ -4257,11 +4257,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "ứng cử là:"
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ứng cử là:"
@@ -4306,48 +4306,48 @@
 msgid "source type is not polymorphic"
 msgstr "nguồn không có loại nhiều dạng"
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "đối số có loại sai đối với dấu trừ nguyên phân"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "đối số có loại sai đối với dấu cộng nguyên phân"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "đối số có loại sai đối với phần bù bit"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "đối số có loại sai đối với bộ tuyệt đối"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "đối số có loại sai đối với phần chia"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 msgid "in argument to unary !"
 msgstr "trong đối số tới bộ nguyên phân !"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 msgid "no pre-increment operator for type"
 msgstr "không có toán tử tiền gia cho loại"
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr "không có toán tử hậu gia cho loại"
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 msgid "no pre-decrement operator for type"
 msgstr "không có toán tử giảm gia cho loại"
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr "không có toán tử hậu giảm cho loại"
 
@@ -4442,7 +4442,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "Giá trị số nguyên quá lớn trong biểu thức tại %C"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 msgid "array assignment"
 msgstr "sự gán mảng"
 
@@ -4467,7 +4467,7 @@
 msgid "Driving:"
 msgstr "Đang điều khiển:"
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "tham số thực tế cho INTENT = OUT/INOUT"
 
@@ -4533,13 +4533,13 @@
 msgid "%s tag"
 msgstr "thẻ %s"
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr "đơn vị bên trong trong GHI"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "thẻ %s với INQUIRE"
@@ -4617,7 +4617,7 @@
 msgid "Bad type in constant expression"
 msgstr "Gặp loại saio trong biểu thức bất biến"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 msgid "Unexpected end of module"
 msgstr "Gặp kết thức mô-đun bất thường"
 
@@ -4645,11 +4645,11 @@
 msgid "implied END DO"
 msgstr "ngụ ý END DO (kết thúc làm)"
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr "sự gán"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 msgid "pointer assignment"
 msgstr "sự gán hàm trỏ"
 
@@ -4665,190 +4665,190 @@
 msgid "internal function"
 msgstr "hàm nội bộ"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 msgid "elemental procedure"
 msgstr "thủ tục loại yếu tố"
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 msgid "allocatable argument"
 msgstr "đối số hay thay đổi"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 msgid "asynchronous argument"
 msgstr "đối số không đồng bộ"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 msgid "optional argument"
 msgstr "đối số tùy chọn"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 msgid "pointer argument"
 msgstr "đối số con trỏ"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 msgid "target argument"
 msgstr "đối số đích"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 msgid "value argument"
 msgstr "đối số giá trị"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 msgid "volatile argument"
 msgstr "đối số hay thay đổi"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 msgid "assumed-shape argument"
 msgstr "đối số assumed-shape"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 msgid "assumed-rank argument"
 msgstr "đối số assumed-rank"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 msgid "coarray argument"
 msgstr "đối số coarray"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 msgid "polymorphic argument"
 msgstr "đối số polymorphic"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr "thuộc tính NO_ARG_CHECK"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 msgid "assumed-type argument"
 msgstr "đối số assumed-type"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr "kết quả mảng"
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 msgid "bind(c) procedure"
 msgstr "thủ tục bind(c)"
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Gặp ngữ cảnh sai cho hàm trỏ NULL() tại %%L"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr "Tại %%L có một toán tử thuộc số nguyên phân “%s” với toán hạng %s"
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử thuộc số nhị phân “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử ghép nối chuỗi với các toán hạng %s/%s"
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử hợp lý “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Tại %%L có một toán tử .not. với toán hạng %s"
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Không thể so sánh các số lượng PHỨC TẠP tại %L"
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Tại %%L thì các bộ hợp lý phải được so sánh với %s thay cho %s"
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử so sánh “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr "Không rõ toán tử “%s” tại %%L"
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr "Tại %%L có một toán tử người dùng “%s” với toán hạng %s"
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử người dùng “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Tại %%L và %%L có một toán tử với các phân hàng mâu thuẫn nhau"
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr "Biến vòng lặp"
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 msgid "iterator variable"
 msgstr "biến iterator"
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 msgid "Start expression in DO loop"
 msgstr "Biểu thức bắt đầu trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 msgid "End expression in DO loop"
 msgstr "Biểu thức kết thúc trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 msgid "Step expression in DO loop"
 msgstr "Biểu thức bước trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 msgid "DEALLOCATE object"
 msgstr "đối tượng DEALLOCATE"
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 msgid "ALLOCATE object"
 msgstr "đối tượng ALLOCATE"
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr "biến STAT"
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr "Biến ERRMSG"
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr "mục tin trong READ"
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr "biến ACQUIRED_LOCK"
 
@@ -5242,16 +5242,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr "CPU rx200 không có phần cứng đơn vị dấu chấm động (FPU)"
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr "cân nhắc dùng “-pg” thay cho “-p” với gprof(1)"
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr "sử dụng gprof(1) thì đề nghị bạn đặt \"-pg\" thay cho \"-p\""
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr "không hỗ trợ chức năng đa thư viện"
@@ -5264,6 +5254,10 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "hai tùy chọn -Xbind-now và -Xbind-lazy không tương thích với nhau"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+msgid "profiling not supported with -mg"
+msgstr "không hỗ trợ sử dụng chức năng đo hiệu năng sử dụng với -mg"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "không hỗ trợ -mhard-float"
@@ -5272,10 +5266,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "không cho phép sử dụng đồng thời hai tùy chọn -msingle-float và -msoft-float"
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr "m210 không có hỗ trợ về cuối nhỏ"
-
 #: config/cris/cris.h:184
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "không dùng đồng thời hai tùy chọn -march=… và -mcpu=…"
@@ -5304,6 +5294,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr "Bạn cần một tập-tin khởi chạy C cho -msys-crt0="
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr "cân nhắc dùng “-pg” thay cho “-p” với gprof(1)"
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5310,6 +5306,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr "không cho phép sử dụng đồng thời hai tùy chọn -m32 và -m64"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr "sử dụng gprof(1) thì đề nghị bạn đặt \"-pg\" thay cho \"-p\""
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr "trên TPF-OS thì không hỗ trợ static"
@@ -5322,6 +5322,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "không cho phép sử dụng đồng thời hai tùy chọn -mbig-endian (về cuối lớn) và -mlittle-endian (về cuối nhỏ)"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr "m210 không có hỗ trợ về cuối nhỏ"
+
 #: config/avr/specs.h:68
 msgid "shared is not supported"
 msgstr "chia sẻ (dùng chung) không được hỗ trợ"
@@ -5347,17 +5351,19 @@
 msgid "no processor type specified for linking"
 msgstr "chưa ghi rõ loại bộ xử lý cần liên kết"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr "cảnh báo: nên cân nhắc liên kết dùng “-static” như là thư viện hệ thống"
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr "  cũng hỗ trợ chức năng đo hiệu năng sử dụng chỉ được cung cấp theo định dạng kho lưu"
 
@@ -5393,10 +5399,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "tùy chọn -shared (chia sẻ) hiện thời không được hỗ trợ cho VAX ELF"
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-msgid "profiling not supported with -mg"
-msgstr "không hỗ trợ sử dụng chức năng đo hiệu năng sử dụng với -mg"
-
 #: fortran/lang.opt:146
 msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgstr "-J<thư_mục>\tĐể vào thư mục này các tập tin MÔ-ĐUN"
@@ -5577,9 +5579,9 @@
 msgstr "Cho phép tên thực thể chứa dấu đồng đô la \"$\""
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Không làm gì. Giữ lại vì mục đích tương thích ngược."
 
@@ -5783,10 +5785,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Không làm gì. Dành cho mục đích tương thích ngược."
 
@@ -5832,7 +5834,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr "thiếu tên tập tin sau %qs"
@@ -7695,44 +7697,48 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr "Coi là CPU đích được cấu hình về cuối nhỏ"
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 msgid "Specify the code model"
 msgstr "Chỉ định mô hình mã"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr "Bỏ sót hàm trỏ khung trong hàm lá"
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr "-mcpu=KTrúc\tSử dụng các tính năng của Ktrúc đã cho"
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr "-mcpu=CPU\tDùng các tính năng của và tối ưu hóa cho CPU"
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr "-mtune=BXL\tTối ưu hóa kết xuất cho bộ xử lý này"
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr "-mabi=ABI\tTạo ra mã phù hợp với ABI đưa ra"
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr "Không hiểu AArch64 ABIs (để dùng với tùy chọn -mabi=):"
 
@@ -8802,10 +8808,16 @@
 msgstr "Hỗ trợ tạo mã MPX"
 
 #: config/i386/i386.opt:864
+#, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "Hỗ trợ các hàm dựng sẵn và chức năng tạo ra mã loại MMX và SSE"
+
+#: config/i386/i386.opt:868
 msgid "Use given stack-protector guard"
 msgstr ""
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 #, fuzzy
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr "Không hiểu kiến trúc ARM (để dùng với tùy chọn -march=):"
@@ -9160,7 +9172,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -9316,7 +9328,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 #, fuzzy
 msgid "Use LRA instead of reload"
@@ -9444,7 +9456,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr "Cho phép định thời dãy đoạn mở đầu của một hàm nào đó"
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr "Đừng nạp thanh ghi PIC trong đoạn mở đầu hàm"
 
@@ -9763,303 +9775,303 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "Sử dụng câu lệnh véc-tơ/vô_hướng (VSX)"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr "Đừng tạo ra câu lệnh nạp/lưu với bản cập nhật"
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr "Tạo ra câu lệnh nạp/lưu với bản cập nhật"
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr "Tránh sự tạo ra câu lệnh nạp/lưu phụ lục khi có thể"
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "Đánh dấu cuộc gọi __tls_get_addr bằng thông tin về đối số"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr "Định thời bắt đầu và kết thúc thủ tục"
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr "Trả lại tất cả các cấu trúc trong vùng nhớ (AIX mặc định)"
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr "Trả lại các cấu trúc nhỏ trong thanh ghi (SVR4 mặc định)"
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr "Làm cho hợp hơn với cú pháp XLC của IBM"
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr "Đừng để vào TOC hằng số dấu chấm động"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr "Để vào TOC hằng số dấu chấm động"
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "Đừng để vào TOC hằng số loại ký_hiệu+hiệu_số"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr "Để vào TOC hằng số loại ký_hiệu+hiệu_số"
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr "Sử dụng chỉ một mục nhập TOC từng thủ tục"
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr "Để tất cả vào TOC bình thường"
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr "Tạo ra câu lệnh VRSAVE khi tạo ra mã AltiVec"
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr "Tùy chọn bị phản đối.  Dùng -mno-vrsave để thay thế"
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr "Tùy chọn bị phản đối.  Dùng -mvrsave để thay thế"
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 msgid "Generate isel instructions"
 msgstr "Tạo ra câu lệnh isel"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr "Tùy chọn bị phản đối.  Dùng -mno để thay thế"
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 msgid "Deprecated option.  Use -misel instead"
 msgstr "Tùy chọn bị phản đối.  Dùng -misel để thay thế"
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr "Tạo ra câu lệnh SIMD SPE trong E500"
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "Tạo ra câu lệnh đôi-đơn PPC750CL"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr "Tùy chọn bị phản đối.  Dùng -mno-spe để thay thế"
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 msgid "Deprecated option.  Use -mspe instead"
 msgstr "Tùy chọn bị phản đối.  Dùng -mspe để thay thế"
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 msgid "-mdebug=\tEnable debug output"
 msgstr "-mdebug=\tBật kết xuất gỡ rối"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 msgid "Use the AltiVec ABI extensions"
 msgstr "Dùng lệnh mở rộng AltiVec ABI"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "Không dùng lệnh mở rộng AltiVec ABI"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 msgid "Use the SPE ABI extensions"
 msgstr "Dùng lệnh mở rộng SPE ABI"
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 msgid "Do not use the SPE ABI extensions"
 msgstr "Không dùng lệnh mở rộng SPE ABI"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 msgid "Use the ELFv1 ABI"
 msgstr "Sử dụng ELFv1 ABI"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 msgid "Use the ELFv2 ABI"
 msgstr "Sử dụng ELFv2 ABI"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 msgid "using darwin64 ABI"
 msgstr "sử dụng darwin64 ABI"
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 msgid "using old darwin ABI"
 msgstr "sử dụng darwin ABI kiểu cũ"
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr "dùng phần mở rộng số nguyên chính đôi IEEE"
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr "dùng phần mở rộng số nguyên chính đôi IBM"
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr "-mcpu=\tSử dụng các tính năng của CPU đưa ra, và định thời mã cho CPU đó"
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "-mtune=\tĐịnh thời mã cho CPU đưa ra"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr "-mtraceback=\tChọn bảng vét lùi đầy đủ (full), bộ phận (part) hoặc không có (none)"
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr "Tránh giới hạn phạm vi nào trong câu lệnh gọi"
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 msgid "Generate Cell microcode"
 msgstr "Tạo ra mã vi Cell"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "Cảnh báo khi xuất một câu lệnh mã vi Cell"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr "Cảnh báo về sử dụng loại AltiVec “vector long …”"
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr "-mfloat-gprs=\tChọn phương pháp dấu chấm động GPR"
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Đối số hợp lệ cho -mfloat-gprs=:"
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr "-mlong-double-<số>\tGhi rõ kích cỡ của đôi dài (64 hay 128 bit)"
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr "Quyết định những quan hệ phụ thuộc nào giữa các câu lệnh thì được thấy có giá cao"
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr "Ghi rõ lược đồ chèn nop hậu định thời nào cần áp dụng"
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr "Ghi rõ cách xếp hàng các trường cấu trúc: mặc định (default) hay tự nhiên (natural)"
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 msgid "Valid arguments to -malign-:"
 msgstr "Đối số hợp lệ cho -malign-:"
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr "Ghi rõ mức ưu tiên định thời cho câu lệnh bị hạn chế khe gửi đi"
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 msgid "Single-precision floating point unit"
 msgstr "Đơn vị dấu chấm động chính xác đơn"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 msgid "Double-precision floating point unit"
 msgstr "Đơn vị dấu chấm động chính xác đôi"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 msgid "Floating point unit does not support divide & sqrt"
 msgstr "Đơn vị dấu chấm động không hỗ trợ phép chia và phép tính căn bậc hai"
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr "-mfpu=\tGhi rõ dấu chấm động (sp, dp, sp-lite, dp-lite) (cũng ngụ ý -mxilinx-fpu)"
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 msgid "Specify Xilinx FPU."
 msgstr "Ghi rõ FPU loại Xilinx."
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 #, fuzzy
 msgid "Allow sign extension in fusion operations"
 msgstr "Đích xếp hàng của các thao tác chuỗi"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
+#: config/rs6000/rs6000.opt:566
 #, fuzzy
-msgid "Use ISA 2.07 crypto instructions"
-msgstr "Sử dụng các chỉ lệnh microMIPS"
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr "Sử dụng câu lệnh véc-tơ/vô_hướng (VSX)"
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 #, fuzzy
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr "Sử dụng câu lệnh véc-tơ/vô_hướng (VSX)"
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Tạo ra câu lệnh nạp/lưu nội"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -12882,1547 +12894,1547 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr ""
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "Chỉnh đầu của hàm"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr ""
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr "Cân chỉnh tất cả các nhãn"
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "Chỉnh đầu của vòng lặp"
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr "Chọn cái gì để cải thiện"
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 #, fuzzy
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr "Cái chuyển này bị phản đối: hãy thay thế bằng -Werror=implicit-function-declaration"
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr ""
 
-#: common.opt:918
+#: common.opt:921
 msgid "Generate auto-inc/dec instructions"
 msgstr ""
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr ""
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr ""
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr ""
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr ""
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr ""
 
-#: common.opt:960
+#: common.opt:963
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr ""
 
-#: common.opt:964
+#: common.opt:967
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr ""
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr ""
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr ""
 
-#: common.opt:979
+#: common.opt:982
 msgid "Check the return value of new in C++"
 msgstr "Kiểm tra giá trị trả về của new trong C++"
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr ""
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr ""
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr ""
 
-#: common.opt:1003
+#: common.opt:1006
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr ""
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr ""
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr ""
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr ""
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr ""
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr ""
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr ""
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr ""
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr ""
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr ""
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr ""
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr ""
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 msgid "Perform speculative devirtualization"
 msgstr ""
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1085
+#: common.opt:1088
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr ""
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr "-fdisable-[tree|rtl|ipa]-<pass>=vùng1+vùng2 tắt chuyển qua tối ưu hóa"
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr "-fenable-[tree|rtl|ipa]-<pass>=vùng1+vùng2 bật chuyển qua tối ưu hóa"
 
-#: common.opt:1142
+#: common.opt:1145
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr ""
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr ""
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr ""
 
-#: common.opt:1157
+#: common.opt:1160
 msgid "Suppress output of addresses in debugging dumps"
 msgstr ""
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 msgid "Dump optimization passes"
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1173
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1177
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr ""
 
-#: common.opt:1190
+#: common.opt:1193
 msgid "Perform interprocedural reduction of aggregates"
 msgstr ""
 
-#: common.opt:1194
+#: common.opt:1197
 msgid "Perform unused symbol elimination in debug info"
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "Bật tiếp nhận ngoại lệ"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr ""
 
-#: common.opt:1217
+#: common.opt:1220
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr ""
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr ""
 
-#: common.opt:1238
+#: common.opt:1241
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr ""
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr ""
 
-#: common.opt:1250
+#: common.opt:1253
 msgid "Perform a forward propagation pass on RTL"
 msgstr ""
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr ""
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr ""
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr ""
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr ""
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr ""
 
-#: common.opt:1305
+#: common.opt:1308
 msgid "Enable in and out of Graphite representation"
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1312
 msgid "Enable Graphite Identity transformation"
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1316
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr ""
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr "Đánh dấu tất cả các vòng lặp là xử lý song song"
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr ""
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr ""
 
-#: common.opt:1330
+#: common.opt:1333
 msgid "Enable Loop Blocking transformation"
 msgstr ""
 
-#: common.opt:1334
+#: common.opt:1337
 msgid "Enable Loop Unroll Jam transformation"
 msgstr ""
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr ""
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr ""
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr ""
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr ""
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1394
+#: common.opt:1397
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr ""
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr ""
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr "Đừng tạo ra chỉ thị .size"
 
-#: common.opt:1410
+#: common.opt:1413
 msgid "Perform indirect inlining"
 msgstr ""
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr ""
 
-#: common.opt:1424
+#: common.opt:1427
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr ""
 
-#: common.opt:1428
+#: common.opt:1431
 msgid "Integrate functions only required by their single caller"
 msgstr ""
 
-#: common.opt:1435
+#: common.opt:1438
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr ""
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1458
 msgid "Perform interprocedural constant propagation"
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1466
 #, fuzzy
 #| msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)"
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr "Độ tăng lên (theo phần trăm) được phép cho đơn vị biên dịch đưa ra do sự lan truyền bất biến thuộc liên quá trình"
 
-#: common.opt:1467
+#: common.opt:1470
 msgid "Perform interprocedural profile propagation"
 msgstr ""
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr ""
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 msgid "Perform Identical Code Folding for variables"
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr ""
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr "-fira-algorithm=[CB|priority] Đặt dùng thuật toán IRA"
 
-#: common.opt:1506
+#: common.opt:1509
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "không hiểu thuật toán IRA %qs"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr "-fira-region=[one|all|mixed] Đặt vùng cho IRA"
 
-#: common.opt:1519
+#: common.opt:1522
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr "không hiểu vùng IRA %qs"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr ""
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr ""
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr ""
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr ""
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 msgid "Enable link-time optimization."
 msgstr ""
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "không hiểu mô hình TLS %qs"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr "-flto-compression-level=<số>\tDùng mức nén zlib <số> cho IL"
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 msgid "Report various link-time optimization statistics"
 msgstr ""
 
-#: common.opt:1625
+#: common.opt:1628
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr ""
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr "-fmax-errors=<số>\tSố lượng tối đa các lỗi cần thông báo"
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr ""
 
-#: common.opt:1641
+#: common.opt:1644
 msgid "Report on permanent memory allocation in WPA only"
 msgstr ""
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr ""
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1659
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr ""
 
-#: common.opt:1660
+#: common.opt:1663
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr ""
 
-#: common.opt:1676
+#: common.opt:1679
 msgid "Use the RTL dead code elimination pass"
 msgstr ""
 
-#: common.opt:1680
+#: common.opt:1683
 msgid "Use the RTL dead store elimination pass"
 msgstr ""
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 msgid "options or targets missing after %qs"
 msgstr "thiếu quyết toán sau %qs"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 msgid "unknown offload ABI %qs"
 msgstr "không hiểu mô hình TLS %qs"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr ""
 
-#: common.opt:1713
+#: common.opt:1716
 msgid "Enable all optimization info dumps on stderr"
 msgstr ""
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr "-fopt-info[-<type>=tập-tin]\tĐổ chi tiết việc tối ưu hóa bộ dịch"
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr ""
 
-#: common.opt:1729
+#: common.opt:1732
 msgid "Perform partial inlining"
 msgstr ""
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr ""
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr ""
 
-#: common.opt:1745
+#: common.opt:1748
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr ""
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr ""
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr ""
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr ""
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr ""
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr ""
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr ""
 
-#: common.opt:1781
+#: common.opt:1784
 msgid "Specify a plugin to load"
 msgstr "Chỉ định phần bổ sung cần nạp"
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr "-fplugin-arg-<tên>-<khóa>[=<giá trị>]\tChỉ định đối số <khóa>=<giá trị> cho plugin <tên>"
 
-#: common.opt:1789
+#: common.opt:1792
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr ""
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr ""
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr ""
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1821
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1826
+#: common.opt:1829
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1837
 msgid "Report on consistency of profile"
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1841
 msgid "Enable function reordering that improves code placement"
 msgstr ""
 
-#: common.opt:1845
+#: common.opt:1848
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr ""
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr ""
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr ""
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr ""
 
-#: common.opt:1880
+#: common.opt:1883
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr ""
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr ""
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr ""
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr ""
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr ""
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr ""
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr ""
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr ""
 
-#: common.opt:1928
+#: common.opt:1931
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr ""
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr ""
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr ""
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr ""
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr ""
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr ""
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr ""
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1981
+#: common.opt:1984
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr ""
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1993
+#: common.opt:1996
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1997
+#: common.opt:2000
 msgid "Enable the group heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2009
+#: common.opt:2012
 msgid "Enable the rank heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr ""
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr ""
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr ""
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr ""
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr ""
 
-#: common.opt:2062
+#: common.opt:2065
 msgid "Generate discontiguous stack frames"
 msgstr "Tạo ra các khung ngăn xếp không liên tiếp"
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr ""
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr ""
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr ""
 
-#: common.opt:2082
+#: common.opt:2085
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "-fstack-check=[no|generic|specific]\t Chèn mã kiểm tra ngăn xếp vào chương trình"
 
-#: common.opt:2086
+#: common.opt:2089
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "Chèn mã kiểm tra ngăn xếp vào chương trình. Giống với -fstack-check=specific"
 
-#: common.opt:2093
+#: common.opt:2096
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr "-fstack-limit-register=<register>\tBẫy nếu ngăn xếp đi qua <register>"
 
-#: common.opt:2097
+#: common.opt:2100
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr "-fstack-limit-symbol=<tên>\tBẫy nếu ngăn xếp đi qua ký hiệu <tên>"
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr ""
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr ""
 
-#: common.opt:2109
+#: common.opt:2112
 msgid "Use a smart stack protection method for certain functions"
 msgstr ""
 
-#: common.opt:2113
+#: common.opt:2116
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr ""
 
-#: common.opt:2117
+#: common.opt:2120
 msgid "Output stack usage information on a per-function basis"
 msgstr ""
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr ""
 
-#: common.opt:2133
+#: common.opt:2136
 msgid "Treat signed overflow as undefined"
 msgstr ""
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr "Kiểm tra lỗi cú pháp, sau đó dừng lại"
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr "Tạo tập tin dữ liệu cần bởi \"gcov\""
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr ""
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr ""
 
-#: common.opt:2157
+#: common.opt:2160
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2163
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "không hiểu mô hình TLS %qs"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr ""
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr ""
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr ""
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr ""
 
-#: common.opt:2199
+#: common.opt:2202
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr ""
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr ""
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr ""
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr ""
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr ""
 
-#: common.opt:2231
+#: common.opt:2234
 msgid "Transform condition stores into unconditional ones"
 msgstr ""
 
-#: common.opt:2235
+#: common.opt:2238
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr ""
 
-#: common.opt:2243
+#: common.opt:2246
 #, fuzzy
 msgid "Enable dominator optimizations"
 msgstr "Bật số tối ưu hóa bộ liên kết"
 
-#: common.opt:2247
+#: common.opt:2250
 msgid "Enable tail merging on trees"
 msgstr ""
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr ""
 
-#: common.opt:2255
+#: common.opt:2258
 msgid "Enable forward propagation on trees"
 msgstr ""
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr ""
 
-#: common.opt:2263
+#: common.opt:2266
 msgid "Enable string length optimizations on trees"
 msgstr ""
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 msgid "Enable loop distribution on trees"
 msgstr ""
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr ""
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr ""
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr ""
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr ""
 
-#: common.opt:2300
+#: common.opt:2303
 msgid "Enable loop optimizations on tree level"
 msgstr ""
 
-#: common.opt:2304
+#: common.opt:2307
 msgid "Enable automatic parallelization of loops"
 msgstr ""
 
-#: common.opt:2308
+#: common.opt:2311
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2312
+#: common.opt:2315
 msgid "Enable SSA-PRE optimization on trees"
 msgstr ""
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2324
+#: common.opt:2327
 msgid "Enable reassociation on tree level"
 msgstr ""
 
-#: common.opt:2332
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
 msgstr ""
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr ""
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr ""
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr ""
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr ""
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr ""
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr ""
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr ""
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr ""
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr ""
 
-#: common.opt:2424
+#: common.opt:2427
 msgid "Perform variable tracking by annotating assignments"
 msgstr ""
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr ""
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr ""
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 msgid "Enable vectorization on trees"
 msgstr "Bật sự di chuyển có điều kiện"
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr ""
 
-#: common.opt:2454
+#: common.opt:2457
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr ""
 
-#: common.opt:2458
+#: common.opt:2461
 msgid "Specifies the cost model for vectorization"
 msgstr ""
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "không hiểu mô hình kích thước con trỏ %qs"
 
-#: common.opt:2478
+#: common.opt:2481
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2485
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2493
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr ""
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr ""
 
-#: common.opt:2507
+#: common.opt:2510
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr ""
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(gần chỗ khởi tạo cho %qs)"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr ""
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2558
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr ""
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr ""
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2582
 msgid "Generate debug information in default version of DWARF format"
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2586
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2614
 msgid "Don't generate debug information in separate .dwo files"
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2618
 msgid "Generate debug information in separate .dwo files"
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr ""
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2638
 msgid "Toggle debug information generation"
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr ""
 
-#: common.opt:2665
+#: common.opt:2668
 #, fuzzy
 msgid "Generate compressed debug sections"
 msgstr "Tạo ra câu lệnh isel"
 
-#: common.opt:2669
+#: common.opt:2672
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr ""
 
-#: common.opt:2676
+#: common.opt:2679
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr ""
 
-#: common.opt:2680
+#: common.opt:2683
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr ""
 
-#: common.opt:2702
+#: common.opt:2705
 msgid "-o <file>\tPlace output into <file>"
 msgstr "-o <tập tin>\tĐặt kết xuất vào <tập tin>"
 
-#: common.opt:2706
+#: common.opt:2709
 #, fuzzy
 msgid "Enable function profiling"
 msgstr "Bật tiếp nhận ngoại lệ"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr ""
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr ""
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr "Bật kết xuất chi tiết"
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr "Hiển thị thông tin về phiên bản của bộ biên dịch"
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "Thu hồi cảnh báo"
 
-#: common.opt:2806
+#: common.opt:2809
 msgid "Create a shared library"
 msgstr "Tạo thư viện dùng chung"
 
-#: common.opt:2851
+#: common.opt:2854
 msgid "Create a position independent executable"
 msgstr "Tạo một bản thực hiện không phụ thuộc vào vị trí"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "giá trị được tính không được sử dụng"
@@ -14452,222 +14464,222 @@
 msgid "expected integer or boolean type"
 msgstr "cần số nguyên hoặc lôgíc"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 msgid "invalid comparison of nil with nil"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 msgid "incompatible types in binary expression"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 msgid "integer division by zero"
 msgstr "số nguyên chia cho không"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 msgid "shift of non-integer operand"
 msgstr "dịch của toán hạng không nguyên"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 msgid "shift count not unsigned integer"
 msgstr "số lượng dịch không phải số nguyên không dấu"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 msgid "negative shift count"
 msgstr "số lượng dịch âm"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 msgid "object is not a method"
 msgstr "đối tượng không phải là phương thức"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 msgid "method type does not match object type"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 msgid "invalid use of %<...%> with builtin function"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 msgid "invalid use of method value as argument of Offsetof"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 msgid "not enough arguments"
 msgstr "không đủ đối số"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 msgid "too many arguments"
 msgstr "quá nhiều đối số"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 msgid "argument 1 must be a map"
 msgstr "đối số 1 phải là ánh xạ"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 msgid "invalid type for make function"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr "len lớn hơn cap"
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 msgid "too many arguments to make"
 msgstr "quá nhiều đối số để thực hiện"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 msgid "argument must be array or slice or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 msgid "unsupported argument type to builtin function"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 msgid "argument must be channel"
 msgstr "đối số phải là kênh"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 msgid "argument must be a field reference"
 msgstr "đối số pahỉ là một tham chiếu trường"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 msgid "left argument must be a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr "các kiểu phần tử phải đồng nhất"
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 msgid "first argument must be []byte"
 msgstr "đối số đầu tiên phải là []byte"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 msgid "second argument must be slice or string"
 msgstr "đối số thứ hai phải là kiểu slice hay chuỗi"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 msgid "argument 2 has invalid type"
 msgstr "đối số 2 có kiểu không hợp lệ"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 msgid "argument must have complex type"
 msgstr "đối số phải có kiểu phức"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 msgid "complex arguments must have identical types"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 msgid "complex arguments must have floating-point type"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 msgid "expected function"
 msgstr "cần hàm"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 msgid "multiple-value argument in single-value context"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 msgid "invalid use of %<...%> with non-slice"
 msgstr "dùng %<…%> mà không có non-slice là không hợp lệ"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 msgid "function result count mismatch"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 msgid "incompatible type for receiver"
 msgstr "không tương thích kiểu đối với bộ nhận"
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 msgid "number of results does not match number of values"
 msgstr "số của kết quả không khớp với số của giá trị"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 msgid "index must be integer"
 msgstr "chỉ số phải là số nguyên"
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 msgid "slice end must be integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 msgid "slice capacity must be integer"
 msgstr "%s tại %L phải là số nguyên"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 msgid "incompatible type for map index"
 msgstr "kiểu không tương thích cho chỉ mục ánh xạ"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr "cần giao diện hay con trỏ đến giao diện"
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 msgid "too many expressions for struct"
 msgstr "quá nhiều biểu thức cho cấu trúc"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 msgid "too few expressions for struct"
 msgstr "quá ít biểu thức cho cấu trúc"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 msgid "type assertion only valid for interface types"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 msgid "expected channel"
 msgstr "cần kênh"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -14778,72 +14790,72 @@
 msgid "cannot use type %s as type %s"
 msgstr "không thể dùng kiểu %s như là %s"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 msgid "different receiver types"
 msgstr "khác kiểu nhận được"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 msgid "different number of parameters"
 msgstr "khác số lượng đối số"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 msgid "different parameter types"
 msgstr ""
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr "varargs khác biệt"
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 #, fuzzy
 msgid "different number of results"
 msgstr "khác số lượng đối số"
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 msgid "different result types"
 msgstr "kiểu kết quả khác biệt"
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "kiểu không tương thích cho phương thức %s%s%s"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "kiểu không tương thích cho phương thức %s%s%s (%s)"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 msgid "type has no methods"
 msgstr "kiểu không có phương thức"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "phương thức còn chưa rõ ràng %s%s%s"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "thiếu phương thức%s%s%s"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "phương thức %s%s%s yêu cầu bộ nhận con trỏ"
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -14963,7 +14975,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr ""
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr ""
@@ -15144,12 +15156,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr ""
 
-#: calls.c:3179
+#: calls.c:3195
 #, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "chuyển đối số quá lớn cho ngăn xếp"
@@ -15709,242 +15721,247 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr ""
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr ""
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr ""
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, gcc-internal-format
 msgid "execution count is negative"
 msgstr "số lượng thừa hành là âm"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "ký hiệu cục bộ phải được định nghĩa"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to con trỏ là sai"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "nhiều bộ gọi chung dòng"
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "con trỏ inlined_to chỉ đến chính nó"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "cgraph_node có clone_of sai"
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "cgraph_node có danh sách nhân bản sai"
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Bí danh có cạnh gọi"
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Bí danh có tham chiếu non-alias"
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "call_stmt được chia sẻ:"
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr ""
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "cần biểu thức"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node gặp lỗi"
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "%s: phần %s còn thiếu"
@@ -16074,7 +16091,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER phải được đặt"
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, gcc-internal-format
 msgid "atexit failed"
@@ -16317,17 +16334,17 @@
 msgid "          %s"
 msgstr "          %s"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr ""
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr ""
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr ""
@@ -16372,12 +16389,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -16572,7 +16589,7 @@
 msgid "total size of local objects too large"
 msgstr ""
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -17019,9 +17036,9 @@
 msgstr "can%'t ghi tập tin PCH"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, gcc-internal-format
 msgid "declared here"
 msgstr "được khai báo ở đây"
@@ -17036,152 +17053,147 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr ""
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, fuzzy, gcc-internal-format
 msgid "enclosing target region"
 msgstr "tác vụ bao quanh"
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "tác vụ bao quanh"
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, fuzzy, gcc-internal-format
 msgid "enclosing parallel"
 msgstr "tác vụ bao quanh"
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr "%q#D chưa được khai báo trong lớp"
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, fuzzy, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr "tác vụ bao quanh"
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "chưa định nghĩa biến môi trường%qs"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:7001
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, gcc-internal-format
-msgid "lastprivate variable %qE is private in outer context"
-msgstr ""
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
-#, gcc-internal-format
 msgid "directive not yet implemented"
 msgstr ""
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, fuzzy, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "cần %<}%> trước %<else%>"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification gặp lỗi"
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr ""
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -17593,47 +17605,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "không thể tìm thấy LTO cgraph trong %s"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr ""
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "toán hạng không hợp lệ (%s)"
@@ -17716,48 +17728,48 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "COLLECT_GCC_OPTIONS dị hình"
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, gcc-internal-format
 msgid "reading input file"
 msgstr "đang đọc tập tin đầu vào"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, gcc-internal-format
 msgid "writing output file"
 msgstr "đang ghi tập tin đầu ra"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "biến môi trường COLLECT_GCC cần được đặt"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "biến môi trường COLLECT_GCC_OPTIONS cần được đặt"
 
 # Literal: don't translate; Nghĩa chữ: dừng dịch
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen: %s: %m"
@@ -17892,28 +17904,28 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "  thoát khỏi khối được cấu trúc OpenMP"
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "  vào khối được cấu trúc OpenMP"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 msgid "ignoring large linear step"
 msgstr "đang bỏ qua thư mục trùng \"%s\"\n"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -18429,8 +18441,8 @@
 msgstr ""
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "không hiểu tên thanh ghi: %s"
@@ -18870,7 +18882,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld trả về trạng thái thoát %d"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F được dùng mà chưa từng được định nghĩa"
@@ -19847,43 +19859,43 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-fcheck-pointer-bounds is not supported for this target"
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr "-fcheck-pointer-bounds không hỗ trợ đích này"
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -20264,47 +20276,47 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, gcc-internal-format
 msgid "array subscript is outside array bounds"
 msgstr "chỉ số mảng nằm ngoài phạm vi của mảng"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, gcc-internal-format
 msgid "array subscript is above array bounds"
 msgstr "chỉ số mảng lớn hơn cận trên"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, gcc-internal-format
 msgid "array subscript is below array bounds"
 msgstr "chỉ số mảng nhỏ hơn cận dưới"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr ""
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr ""
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr ""
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr ""
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr ""
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr ""
@@ -20348,9 +20360,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -20581,7 +20593,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
@@ -20729,27 +20741,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr ""
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "số lượng dịch trái  >= độ rộng của kiểu"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "số lượng dịch phải  >= độ rộng của kiểu"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "tràn trong biểu thức hằng"
@@ -21079,12 +21091,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh phép gán được dùng như là giá trị chân lý"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "dùng %<restrict%> không hợp lệ"
@@ -21531,12 +21543,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr ""
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "kích thước véc-tơ không"
@@ -21546,22 +21558,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr ""
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr ""
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr ""
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr ""
@@ -21601,12 +21613,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr ""
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr ""
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
@@ -21686,7 +21698,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr ""
@@ -22102,7 +22114,7 @@
 msgstr "giá trị chỉ mục nằm ngoài phạm vi cho phép"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
@@ -22558,7 +22570,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -22568,22 +22580,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE chưa được khởi tạo"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "thiếu biểu thức gia số"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "biểu thức gia không hợp lệ"
@@ -23119,6 +23131,12 @@
 msgid "too many input files"
 msgstr "quá nhiều tập tin nhập vào"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+#| msgid "type %qT is too large"
+msgid "-mcpu string too large"
+msgstr "kiểu %qT quá lớn"
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -23144,47 +23162,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s không hợp lệ"
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops đã cũ, hãy dùng -falign-loops"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d không nằm giữa 0 và %d"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps đã cũ, hãy dùng -falign-jumps"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d không nằm giữa 0 và %d"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions đã cũ, hãy dùng -falign-functions"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d không nằm giữa 0 và %d"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d không nằm trong khoảng 0 và 5"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> hiện nay chỉ được hỗ trợ trên GNU/Linux"
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -23566,63 +23584,63 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr ""
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "giá trị sai %qs cho -mtrap-precision"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "giá trị sai %qs cho -mfp-rounding-mode"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "giá trị sai %qs cho -mfp-trap-mode"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr "giá trị sai %qs cho -mcpu"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, gcc-internal-format
 msgid "bad value %qs for -mtune switch"
 msgstr "giá trị sai %qs cho -mtune"
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr ""
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr ""
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr ""
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr ""
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr ""
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr "giá trị sai %qs cho -mmemory-latency"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -24096,14 +24114,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, gcc-internal-format
 msgid "%qE attribute only applies to functions"
@@ -24747,375 +24765,392 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "Không thể đặt vị trí trong tập tin PCH: %m"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong arg %s to option %s"
 msgstr "sai đối số %s cho tùy chọn %s"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr "vùng bộ chọn phải nằm từ 0 đến 7"
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr ""
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
+
+#: config/i386/i386.c:3012
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown alignment %s specified for option %s"
 msgstr "không hiểu hàm đặc tả %qs"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too many size ranges specified in option %s"
 msgstr "Vùng %s không hợp lệ trong tùy chọn %s"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr ""
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr "%stune=x86-64%s đã lỗi thời, dùng %stune=k8%s hay %stune=generic%s để thay thế là thích hợp"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "mô hình mã %qs không được hỗ trợ trong chế độ x32"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "mô hình mã %s không hỗ trợ chế độ PIC"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel không được hỗ trợ trong cấu hình này"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "chế độ %i-bit chưa được biên dịch bên trong"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU bạn chọn không hỗ trợ chỉ lệnh x86-64"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "Intel MPX không hỗ trợ x32"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "giá trị sai (%s) cho %sarch=%s %s"
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "giá trị sai (%s) cho %stune=%s %s"
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm bị bỏ qua trên chế độ 64-bit"
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d không nằm giữa 0 và %d"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr "%srtd%s bị bỏ qua trong chế độ 64bit"
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary không được hỗ trợ trên đích này"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d không nằm giữa %d và %d"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d không ở giữa %d và 12"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry không hỗ trợ cho 32-bit trong tổ hợp cùng với -fpic"
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry không tương thích với SEH"
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "không hiểu tùy chọn cho -mrecip=%s"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "thuộc tính %<target%> không là một chuỗi"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "tùy chọn (\"%s\") đã sẵn được đưa ra rồi"
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "không tương thích với nhau"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính fastcall và thiscall không tương thích với nhau"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính stdcall và thiscal không tương thích với nhau"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "các thuộc tính cdecl và thiscall không tương thích với nhau"
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "%qE attribute is used for non-class method"
 msgstr "thuộc tính %qE bị lờ đi cho %qE"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5923
-#, gcc-internal-format
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr ""
-
-#: config/i386/i386.c:6210
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "không hỗ trợ chức năng đa thư viện"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, gcc-internal-format
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
 #, gcc-internal-format
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:11378
+#, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -25122,253 +25157,253 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "khai báo trước đây của %D"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_thread_pointer không được hỗ trợ trên đích này"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr ""
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 2-bít"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "đối số thứ năm phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 1-bít"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 32-bít"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 4-bít"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 1-bít"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 5-bít"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 8-bít"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "đối số thứ năm phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 #| msgid "incorect comparison mode"
 msgid "incorrect comparison mode"
 msgstr "chế độ so sánh không đúng"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "lệnh không đúng:"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 4-bít"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 5-bít"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 8-bít"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 32-bít"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE cần là tùy chọn %s"
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "đối số cuối phải là tỷ lệ 1, 2, 4, 8"
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "đối số thứ tư phải là tỷ lệ 1, 2, 4, 8"
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "lệnh không đúng:"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Thuộc tính %qE chỉ dùng được trên hệ thống 32-bit"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "simdlen không được hỗ trợ %d"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -25459,13 +25494,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr ""
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -25537,7 +25572,7 @@
 msgstr ""
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, gcc-internal-format
 msgid "%qE attribute argument not an integer constant"
 msgstr ""
@@ -25597,7 +25632,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -26443,16 +26478,11 @@
 msgid "-g option disabled"
 msgstr "tùy chọn -g bị tắt"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr "-munix=98 cần cho C89 Hiệu chỉnh 1 tính năng.\n"
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, fuzzy, gcc-internal-format
@@ -26710,307 +26740,313 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "đối số 1 phải là trường 8-bit"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "đối số 1 phải là kiểu văn có dấu 5-bit"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "%srtd%s is ignored in 64bit mode"
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr "%srtd%s bị bỏ qua trong chế độ 64bit"
+
+#: config/rs6000/rs6000.c:12763
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "đối số 1 của __builtin_paired_predicate nằm ngoài phạm vi"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 4-bit"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 2-bit"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 1-bit"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "đối số 1 phải là 0 hay 2"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "đối số 1 phải là kiểu văn không dấu 1-bit"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 6-bit"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "đối số 2 phải là 0 hay 1"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "đối số 3 phải nằm trong vùng 0…15"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "đối số 1 của __builtin_paired_predicate phải là một hằng"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "đối số 1 của __builtin_paired_predicate nằm ngoài phạm vi"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had no type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "khung stack quá lớn"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "sai cpu \"%s\" cho %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s\"%s\"%s là không được phép"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s\"%s\"%s không hợp lệ"
@@ -27261,88 +27297,88 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr ""
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "đối số đầu tiên của %q+D phải là %<int%>"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "đối số cho %qs quá lớn (tối đa là %d)"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr ""
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float không được hỗ trợ trong tổ hợp"
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
@@ -27357,53 +27393,53 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr ""
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr ""
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, gcc-internal-format
 msgid "%qE attribute only applies to interrupt functions"
 msgstr ""
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, gcc-internal-format
 msgid "%qE attribute is supported only for SH2A"
 msgstr ""
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr ""
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, gcc-internal-format
 msgid "%qE attribute only applies to SH2A"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho SH2A"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, gcc-internal-format
 msgid "%qE attribute argument should be between 0 to 255"
 msgstr ""
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, gcc-internal-format
 msgid "%qE attribute argument not a string constant"
 msgstr ""
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr ""
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, gcc-internal-format
 msgid "need a second call-clobbered general purpose register"
 msgstr ""
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr ""
@@ -27780,43 +27816,43 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr "số lượng đối số không giống với nó khi khai báo mẫu hàm"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "thuộc tính %qs bị bỏ qua"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr ""
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -27874,7 +27910,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -27904,62 +27940,62 @@
 msgid "GCC supports only %u nested scopes"
 msgstr ""
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "nhãn %q+D được dùng nhưng chưa định nghĩa"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr ""
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr "hàm chung dòng %q+D được khai báo nhưng chưa bao giờ được định nghĩa"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "biến chưa được dùng %q+D"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, gcc-internal-format
 msgid "variable %qD set but not used"
 msgstr "biến %qD được đặt nhưng lại chưa được dùng"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "định nghĩa lần đầu ở đây"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr ""
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr ""
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr ""
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr ""
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr ""
@@ -27966,42 +28002,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr ""
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "khai báo trước đây của %q+D là đây"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr ""
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "khai báo trước đây của %q+D ở đây"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr ""
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr ""
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr ""
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "khai báo lại của %<enum %E%>"
@@ -28009,339 +28045,339 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "xung đột kiểu cho hàm dựng sẵn %q+D"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "kiểu xung đột cho %q+D"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
 msgstr "định nghĩa lại của typedef %q+D với kiểu khác"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "định nghĩa lại của typedef %q+D với kiểu sửa biến đổi"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "định nghĩa lại của typedef %q+D"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "định nghĩa lại của %q+D"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr ""
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr ""
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr "thuộc tính %<gnu_inline%> hiện tại trên %q+D"
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, gcc-internal-format
 msgid "but not here"
 msgstr "nhưng không phải ở đây"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr ""
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr ""
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr ""
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr ""
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr ""
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr ""
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr ""
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr ""
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr ""
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "định nghĩa lại của đối số %q+D"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "tái khai báo không hợp lệ cho %q+D"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr ""
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr ""
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr ""
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr ""
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr ""
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "khai báo ngầm của hàm %qE"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr ""
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "tái khai báo không hợp lệ cho %q+D"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr ""
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr ""
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr ""
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr ""
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "nhãn %qD được định nghĩa ở đây"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr ""
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr ""
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "nhãn nhân đôi %qD"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr ""
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr ""
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "switch bắt đầu ở đây"
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr ""
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr ""
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> trong khai báo trống rỗng"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<_Noreturn%> trong khai báo trống rỗng"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "%<inline%> trong khai báo trống rỗng"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "khai báo trống rỗng"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr ""
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr ""
@@ -28349,38 +28385,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D thường là một hàm"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr ""
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "hàm %qD được khởi tạo giống như là một biến"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "tham số %qD được khởi tạo"
@@ -28389,257 +28425,257 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "không thể khởi tạo một đối tượng có kích cỡ biến đổi"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr ""
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr ""
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD cần được khởi tạo"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr ""
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "thiếu kích thước mảng trong %q+D"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "mảng có kích thước bằng không hay bị âm %q+D"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr ""
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr ""
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr ""
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, gcc-internal-format
 msgid "uninitialized const %qD is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "độ rộng bằng không cho bit-field %qs"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr ""
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr ""
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr ""
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr ""
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr ""
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "lặp lại %<const%>"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "lặp lại %<restrict%>"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "lặp lại %<volatile%>"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "trùng lặp %<_Atomic%>"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr ""
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "định nghĩa hàm được khai báo là %<register%>"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "định nghĩa hàm được khai báo là %<typedef%>"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "định nghĩa hàm được khai báo là %qs"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr ""
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -28647,683 +28683,683 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "sự khai báo của %qE như là mảng của void"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr ""
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "sự khai báo của %qE như là mảng của các hàm"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C cấm chỉ mảng có độ dài là không %qE"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C cấm chỉ mảng có độ dài là không"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "kích cỡ mảng %qE bị âm"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "cỡ của mảng không tên là âm"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "kích cỡ mảng %qE quá lớn"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "kích thước của mảng chưa đặt tên là quá lớn"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 không hỗ trợ thành viên mảng linh động"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> không trong khai báo"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "định nghĩa hàm có kiểu trả về là void"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr ""
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr ""
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr ""
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr ""
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr ""
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D được khai báo %<inline%>"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D được khai báo %<_Noreturn%>"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "đối số %q+D được khai báo %<inline%>"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "trường %qE được khai báo như là một hàm"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr ""
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr ""
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> được khai báo %<_Noreturn%>"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 không hỗ trợ %<_Noreturn%>"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 không hỗ trợ %<_Noreturn%>"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "biến %q+D được khai báo %<inline%>"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "biến %q+D được khai báo %<_Noreturn%>"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "đối số %u (%q+D) có kiểu void"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "tham số %u có kiểu void"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> phải là đối số duy nhất"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "%<%s %E%> được khai báo bên trong danh sách đối số"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr ""
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr ""
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "kiểu enum được định nghĩa ở đây"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "struct được định nghĩa ở đây"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "union được định nghĩa ở đây"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "định nghĩa lại của %<union %E%>"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "định nghĩa lại của %<struct %E%>"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "định nghĩa lại bị lồng của %<union %E%>"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "định nghĩa lại bị lồng của %<struct %E%>"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "thành viên trùng lặp %q+D"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union không có thành viên nào"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union không có thành viên nào"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "cấu có không thành viên đã đặt tên"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct không có thành viên nào"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr ""
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "kiểu %qT quá lớn"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr ""
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "khai báo lại của %<enum %E%>"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "tràn giá trị liệt kê"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr ""
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "kiểu trả về là một kiểu không hoàn toàn"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "trả về kiểu mặc định cho %<int%>"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "chưa có khai báo nguyên mẫu trước đây cho %qD"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "chưa có khai báo trước đây cho %qD"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr ""
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "%<_Atomic%> áp dụng cho kiểu hạn định"
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD thường không phải là hàm non-static"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "tên đối số bị bỏ qua"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "định nghĩa hàm theo cách cũ"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD đã được định nghĩa là không có tham số"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr ""
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "đối số %qD được khai báo với kiểu void"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "kiểu của %qD mặc định đến %<int%>"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "số lượng đối số không giống với nó khi khai báo mẫu hàm"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "khai báo mẫu trước"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> (trả lại) không có giá trị, trong hàm trả lại non-void (không rỗng)"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "đối số %qD đặt nhưng chưa được dùng"
@@ -29331,197 +29367,197 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "lặp lại %qE"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> là quá dài đối với GCC"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 không hỗ trợ %<long long%>"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 không hỗ trợ kiểu complex"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C không hỗ trợ kiểu saturating"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C không hỗ trợ kiểu %<__int%d%>"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 không hỗ trợ kiểu lô-gíc"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C không hỗ trợ kiểu dấu chấm động hệ thập phân"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "kiểu dấu chấm cố định không được hỗ trợ trên đích này"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C không hỗ trợ kiểu dấu chấm cố định"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE không ở đầu của khai báo"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE được dùng với %<auto%>"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE được dùng với %<register%>"
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE được dùng với %<typedef%>"
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 không hỗ trợ %qE"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 không hỗ trợ %qE"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> trước %<extern%>"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> trước %<static%>"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "trùng %<_Thread_local%> hay %<__thread%>"
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs được dùng với %qE"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> được dùng mà không có %<_Fract%> or %<_Accum%>"
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -29531,7 +29567,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr ""
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "cần kết thúc dòng"
@@ -29551,8 +29587,8 @@
 msgid "unknown type name %qE"
 msgstr "không hiểu tên kiểu %qE"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "cần các định danh khai báo"
@@ -29567,7 +29603,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "cần %<;%>, định danh hoặc %<(%>"
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -29643,7 +29679,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 không hỗ trợ %<_Static_assert%>"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "cần chuỗi văn chương"
@@ -29700,14 +29736,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "cần định danh"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "dấu phẩy ở cuối của danh dánh liệt kê"
@@ -30156,32 +30192,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "thiếu %<=%> (sau thuộc tính %<getter%>)"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "thiếu %<=%> (sau thuộc tính %<setter%>)"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
@@ -30191,47 +30227,47 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr "%<#pragma omp cancel%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr "%<#pragma omp taskyield%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr "%<#pragma omp cancel%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr "%<#pragma omp cancellation point%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<#pragma omp sections%>"
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "cần câu lệnh for, while hoặc do"
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> phải là đầu tiên"
@@ -30246,12 +30282,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "quá nhiều mệnh đề %qs"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "cần biểu thức nguyên"
@@ -30261,27 +30297,27 @@
 msgid "expression must be integral"
 msgstr "chỉ số phải là số nguyên"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a constant"
 msgstr "%q#D không là const"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD không phải là một biến"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD không phải là một biến"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "cần %<none%> hoặc %<shared%>"
@@ -30313,17 +30349,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> hoặc %<max%>"
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "kiểu lịch biểu không hợp lệ"
@@ -30343,12 +30379,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<thread_limit%> giá trị phải dương"
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -30368,17 +30404,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "kiểu phụ thuộc không hợp lệ"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "kiểu ánh xạ không hợp lệ"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "kiểu dist_schedule không hợp lệ"
@@ -30388,57 +30424,57 @@
 msgid "invalid proc_bind kind"
 msgstr "kiểu proc_bind không hợp lệ"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "cần mệnh đề %<#pragma omp%>"
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs phải là mệnh đề đầu tiên của %qs"
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "cần mệnh đề %<#pragma omp%>"
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr "cần %<,%> hoặc %<)%> sau %qE"
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 msgid "invalid pragma"
 msgstr "#pragma %s không hợp lệ"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -30448,17 +30484,17 @@
 msgid "expected %<(%> or end of line"
 msgstr "cần %<(%> hoặc xuống dòng"
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "cần câu lệnh for"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "cần câu lệnh for"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "cần khai báo nhắc lại hay sự khởi tạo"
@@ -30468,237 +30504,237 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "cần %<for%> sau %qs"
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "cần %<point%>"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:13854 cp/parser.c:31398
-#, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
-msgstr ""
+#: c/c-parser.c:13851 cp/parser.c:31433
+#, fuzzy, gcc-internal-format
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
+msgstr "%<#pragma omp taskwait%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> phải xuất hiện trước khai báo của %D, đang lờ đi"
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "cần %<target%>"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "cần %<declare%>"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> hoặc định danh"
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, fuzzy, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "khai báo trước"
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "cần %<omp_priv%> hoặc tên-hàm"
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "cần tên-hàm %<(%>"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "cần %<#pragma omp section%> hoặc %<}%>"
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, fuzzy, gcc-internal-format
 msgid "pragma simd must be inside a function"
 msgstr "biểu thức không thể được dùng như một hàm"
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "chiều dài véc-tơ phải là một hằng nguyên"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr "vectorlength phải là lũy thừa 2"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr ""
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "cần mệnh đề %<#pragma simd%>"
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma%> là không được phép ở đây"
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> nằm trong một %<__transaction_relaxed%>"
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "vòng ngoài hơn %<__transaction_cancel%> không nằm trong vòng ngoài hơn %<__transaction_atomic%>"
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  hoặc một hàm %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> không nằm trong %<__transaction_atomic%>"
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, gcc-internal-format
 msgid "base of array section must be pointer or array type"
 msgstr ""
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "cần %<:%> hoặc số"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 msgid "array notations cannot be used with function type"
 msgstr "biểu thức không thể được dùng như một hàm"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 msgid "expected array notation expression"
 msgstr "cần một biểu thức lôgíc"
@@ -30708,7 +30744,7 @@
 msgid "%qD has an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "sử dụng sai biểu thức void"
@@ -30814,7 +30850,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "chỉ số mảng không phải là số nguyên"
@@ -30937,7 +30973,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
@@ -30967,7 +31003,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -31052,7 +31088,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
@@ -31087,7 +31123,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, fuzzy, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr "cú gọi hàm không được xuất hiện trong biểu thức hằng"
@@ -31170,7 +31206,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -31323,7 +31359,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -31460,7 +31496,7 @@
 msgid "initialization of a flexible array member"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "mảng ký tự bị khởi tạo từ chuỗi rộng"
@@ -31506,7 +31542,7 @@
 msgid "invalid initializer"
 msgstr "bộ khởi tạo sai"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -31651,7 +31687,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C cấm %<goto *expr;%>"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "hàm đã khai báo %<noreturn%> có một câu lệnh %<return%>"
@@ -31661,7 +31697,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "biểu thức không thể được dùng như một hàm"
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -31766,17 +31802,17 @@
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
@@ -31827,12 +31863,12 @@
 msgstr ""
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
@@ -31857,85 +31893,85 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE không phải một biến trong mệnh đề %<depend%>"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "mảng có độ dài biến đổi được dùng"
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "Vào thủ tục thì cũng sao chép các phần mảng vào một khối kề nhau"
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE không có kiểu lớp"
@@ -31945,17 +31981,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -31965,7 +32001,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
@@ -31975,17 +32011,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<aligned%>"
@@ -32000,47 +32036,47 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<depend%>"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD không phải một đối số trong mệnh đề %<uniform%>"
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE không phải một đối số trong mệnh đề %<uniform%>"
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -32051,115 +32087,115 @@
 msgstr ""
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "  không hiểu chuyển đổi cho đối số %d từ %qT thành %qT"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 msgid "  no known conversion from %qT to %qT"
 msgstr "  cho chuyển đổi từ %qT thành %qT"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, gcc-internal-format
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "  không hiểu chuyển đổi cho đối số %d từ %qT thành %qT"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] "  ứng cử cần %d đối số, %d được cung cấp"
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, gcc-internal-format
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr "%s%D(%T, %T, %T) <dựng-sắn>"
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, gcc-internal-format
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "%s%D(%T, %T) <dựng-sẵn>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, gcc-internal-format
 msgid "%s%D(%T) <built-in>"
 msgstr "%s%D(%T) <dựng-sẵn>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, gcc-internal-format
 msgid "%s%T <conversion>"
 msgstr "%s%T <chuyển đổi>"
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr "%s%#D <gần khớp>"
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr "%s%#D <xóa>"
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr "%s%#D"
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr ""
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr ""
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, gcc-internal-format
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr ""
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "gọi hàm quá tải %<%D(%A)%> chưa rõ ràng"
@@ -32166,457 +32202,457 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr ""
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "cú gọi của %<(%T) (%A)%> chưa rõ ràng"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "quá tải chưa rõ ràng đối với"
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, gcc-internal-format
 msgid "no match for "
 msgstr "không khớp cho"
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (các kiểu toán hạng là %qT, %qT, and %qT)"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (các kiểu toán hạng là %qT và %qT)"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (kiểu toán hạng là %qT)"
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "bộ tam nguyên %<operator?:%>"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "bộ tam nguyên %<operator?:%> trong %<%E ? %E : %E%>"
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> trong %<%E%s%>"
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> trong %<%E[%E]%>"
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs trong %<%s %E%>"
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> trong %<%E %s %E%>"
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> trong %<%s%E%>"
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr ""
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "các toán hạng ?: có kiểu khác %qT và %qT"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "so sánh giữ %q#T và %q#T"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, gcc-internal-format
 msgid "non-placement deallocation function %q+D"
 msgstr ""
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr ""
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr "%q+#D là private"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr "%q+#D là protected"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr "%q+#D là không thể truy cập"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr "trong ngữ cảnh này"
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, fuzzy, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "Cảnh báo về chuyển đổi NULL từ/đến một loại không phải hàm trỏ"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr ""
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, gcc-internal-format
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, gcc-internal-format
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  đang khởi tạo đối số %P của %qD"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %q+D"
 msgstr "  đang khởi tạo đối số %P của %qD"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, gcc-internal-format
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "không thể buộc %qT lvalue thành %qT"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr ""
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, gcc-internal-format
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr ""
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "Cảnh báo về sự gán mà loại bỏ đoạn điều kiện"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  trong gọi đến %qD"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "suy diễn %qT như là %qT"
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, gcc-internal-format
 msgid "  in call to %q+D"
 msgstr "  trong gọi đến %q+D"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr ""
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "hằng tham chiếu đến chính nó"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "không thể gọi cấu tử %<%T::%D%> một cách trực tiếp"
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "gọi hàm quá tải %<%s(%A)%> chưa rõ ràng"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "đóng %qD thông qua %qD"
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  cho chuyển đổi từ %qT thành %qT"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr " ứng cử 1: %q+#F"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr " ứng cử 2: %q+#F"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "không thể chuyển đổi %qE từ %qT thành %qT"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr ""
@@ -32772,7 +32808,7 @@
 msgid "  by %q+D"
 msgstr "  bởi %q+D"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
@@ -32782,7 +32818,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr ""
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr "thành viên riêng %q+#D trong hỗn hợp nặc danh"
@@ -32792,7 +32828,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "thành viên riêng %q+#D trong cấu trúc nặc danh"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr ""
@@ -32922,67 +32958,77 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  nhưng không được ghi đè %<operator=(const %T&)%>"
 
-#: cp/class.c:4538
+#: cp/class.c:4300
 #, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, gcc-internal-format
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr ""
+
+#: cp/class.c:4557
+#, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T không là kiểu văn chương vì:"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T có một cấu tử non-trivial"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  lớp cơ sở %qT của %q+T là non-literal"
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, gcc-internal-format
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "  thành viên dữ liệu không-tĩnh %q+D có kiểu không-văn-chương"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has volatile type"
 msgstr "  thành viên dữ liệu không-tĩnh %q+D có kiểu không-văn-chương"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "  %q+T có một cấu tử non-trivial"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr ""
@@ -32989,102 +33035,102 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "định nghĩa lại của %q#T"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "không đủ thông tin kiểu"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -33094,12 +33140,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "khai báo của %q#D"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr "thay đổi nghĩa của %qD từ %q+#D"
@@ -33139,253 +33185,253 @@
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr ""
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 msgid "call to internal function"
 msgstr "hàm nội bộ"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr ""
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr ""
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD được gọi trong một biểu thức hằng"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD được dùng trước khi nó được định nghĩa"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E không phải biểu thức hằng"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "biểu thức nguyên %qE không là hằng"
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "array subscript out of bound"
 msgstr "chỉ số mảng nằm ngoài phạm vi"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 msgid "negative array subscript"
 msgstr "Cần chỉ số mảng tại %C"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "gán thành viên chỉ-đọc %qD"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD được dùng trong bộ khởi tạo của chính nó"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D không là const"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D là volatile"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD không được khởi tạo với một biểu thức hằng"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD chưa được khai báo %<constexpr%>"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant-expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant-expression"
 msgstr "yếu tố khởi tạo không phải là một biểu tượng hằng số"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, gcc-internal-format
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, gcc-internal-format
 msgid "division by zero is not a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "cần AST thuộc kiểu %s"
@@ -33456,7 +33502,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr ""
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr ""
@@ -33496,7 +33542,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -33506,292 +33552,292 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "chuyển đổi từ %q#T sang %q#T"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T được dùng ở nơi mà %qT cần"
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr ""
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr ""
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr ""
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "câu lệnh không có tác động gì"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -34202,238 +34248,238 @@
 msgid "template parameters do not match template %qD"
 msgstr "đối số mẫu %q+#D"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr ""
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr ""
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> chỉ có thể được dùng trong một lớp"
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> chỉ có thể được chỉ định cho cấu tử"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> bị bỏ qua trong khai báo này"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%> không thể dùng cho khai báo kiểu"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr ""
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%qD không phải là thành viên của %qT"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "%qD không phải là hàm thành viên mẫu"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ không cho phép %<%T::%D%> được định nghĩa như là %<%T::%D%>"
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "khởi tạo lặp lại cho %qD"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr "%qD được khai báo %<constexpr%> ngoài lớp của nó"
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qD được khai báo %<constexpr%> ngoài lớp của nó"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%qD được khai báo %<constexpr%> ngoài lớp của nó"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "khai báo của %q#D chưa có bộ khởi tạo"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD được khai báo như là một tham chiếu nhưng lại chưa được khởi tạo"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "thiếu kích thước mảng trong %qD"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "mảng có kích thước bằng không %qD"
@@ -34441,824 +34487,824 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr ""
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "bộ khởi tạo được cung cấp cho hàm"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "quá nhiều bộ khởi tạo cho %qT"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD được khởi tạo bằng chính nó"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr ""
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr ""
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "thiếu kích thước mảng trong %qT"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "mảng có kích thước không %qT"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD được khai báo là một biến %<virtual%>"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> variable"
 msgstr "%qD được khai báo là một biến %<inline%>"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD được khai báo như là đối số %<virtual%>"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD được khai báo là một đối số %<inline%>"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD được khai báo như là kiểu %<virtual%>"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD được khai báo là một kiểu %<inline%>"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD được khai báo như là trường %<virtual%>"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD được khai báo là một trường %<inline%>"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D được khai báo là friend"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, gcc-internal-format
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "%qD chưa được khai báo %<constexpr%>"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "Trong hàm bộ phận tĩnh %qs"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%qs hàm không có đối số"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD phải là một hàm không-thành-viên"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> phải trả về %<int%>"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, gcc-internal-format
 msgid "%q+#D explicitly defaulted here"
 msgstr ""
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "kích cỡ mảng %qD bị âm"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "kích cỡ mảng bị âm"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ cấm mảng có kích thước bằng không %qD"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ cấm mảng có kích thước bằng không"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ cấm biến có kích thước biến đổi %qD"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ cấm biến có kích thước biến đổi"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "mảng có độ dài biến đổi %qD được dùng"
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "mảng có độ dài biến đổi được dùng"
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "tràn kích thước mảng"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%q+D được khai báo là friend"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "sự khai báo của %qD như là mảng void"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "tạo mảng void"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "sự khai báo của %qD như là mảng của các hàm"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "tạo mảng hàm"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "sự khai báo của %qD như là mảng của các tham chiếu"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "tạo mảng tham chiếu"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "sự khai báo của %qD như là mảng của các thành viên hàm"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "tạo mảng của thành viên hàm"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "biến hay trường được khai báo là void"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<::%D%>"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<%T::%D%>"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<%D::%D%>"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T không phải là một lớp hay namespace"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "sự khai báo của %qD như là non-function"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "sự khai báo của %qD như là non-member"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "định nghĩa hàm không khai báo đối số"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "sự khai báo của %qD như là %<typedef%>"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "khai báo của %qD như là đối số"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C90 không hỗ trợ kiểu complex"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C không hỗ trợ kiểu %<__int%d%>"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> hoặc %<unsigned%> không hợp lệ với %qs"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> và %<unsigned%> được chỉ định cùng với nhau cho %qs"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> không hợp lệ với %qs"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%>không hợp lệ với %qs"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> không hợp lệ với %qs"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> hoặc %<short%> không hợp lệ với %qs"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%>, hoặc %<char%> không hợp lệ cho %qs"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> hoặc %<short%> đựoc chỉ định với kiểu char với %qs"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> và %<short%> được chỉ định cùng nhau với %qs"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> hoặc %<long%> không hợp lệ với %qs"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr ""
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "số ảo không hợp lệ cho %qs"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr ""
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> ngoài khai báo lớp"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "hàm không thể trả lại loại __fp16"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
@@ -35265,470 +35311,470 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr ""
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "không thể khai báo con trỏ đến %q#T"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "không thể khai báo con trỏ cho thành viên %q#T"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD được dùng như bộ khai báo"
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr ""
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr ""
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "kích cỡ mảng %qs quá lớn"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> ngoài khai báo lớp"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> trong khai báo trống rỗng"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef được khai báo %<auto%>"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> được chỉ định cho khai báo lớp bạn"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "các đối số tạm không thể là bạn"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<dynamic_cast%> không thừa nhận với -fno-rtti"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, gcc-internal-format
 msgid "non-static data member declared %<auto%>"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "dùng %<::%> không hợp lệ"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "hàm %qD được khai báo nằm trong ảo một union"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr ""
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "sự khai báo của %qD như là thành viên của %qT"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "biến %qD được định nghĩa lại là một hàm"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "biến hay trường được khai báo là void"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> không sử dụng khi định nghĩa (như ngược với khai báo) một thành viên dữ liệu tĩnh"
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, gcc-internal-format
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "đối số %qD có kiểu lớp Java"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -35748,173 +35794,173 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD không được khai báo như là tĩnh"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số của nó"
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số thứ hai của nó"
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "tiền tố %qD cần trả về %qT"
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD cần trả về %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr "%qD phải nhận %<void%>"
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr "%qD cần chính các là một đối số"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD cần trả về bằng giá trị"
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD không thể có đối số mặc định"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT được coi là %qs"
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "%q+T có một khai báo trước ở đây"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT được coi là enum"
@@ -35926,88 +35972,88 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "khai báo trước đây %q+D"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr ""
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr ""
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "định nghĩa trước ở đây"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr ""
@@ -36016,87 +36062,87 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr ""
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "kiểu trả về là một kiểu không hoàn toàn"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr ""
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> cần trả về một tham chiếu đến %<*this%>"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr ""
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "khai báo hàm không hợp lệ"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "đối số %qD được khai báo là void"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, gcc-internal-format
 msgid "parameter %q+D set but not used"
 msgstr "đối số %q+D đặt như không được dùng"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "khai báo hàm thành viên không hợp lệ"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD đã sẵn định nghĩa trong %qT"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -36136,7 +36182,7 @@
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "cho khai báo hàm mẫu %q+D"
@@ -36159,7 +36205,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -36249,27 +36295,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, fuzzy, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD không phải là một thành viên dữ liệu tĩnh của một mẫu lớp"
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> phải trả về kiểu %qT"
@@ -36278,47 +36324,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> nhận kiểu %<size_t%> (%qT) như là đối số thứ nhất"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> phải trả về kiểu %qT"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> nhận kiểu %qT như là đối số thứ nhất"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, gcc-internal-format
 msgid "%q#D, declared using anonymous type, is used but never defined"
 msgstr ""
@@ -36327,47 +36373,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "hàm chung dòng %q+D được dùng nhưng chưa bao giờ được định nghĩa"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "hàm chung dòng %q+D được dùng nhưng chưa bao giờ được định nghĩa"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr ""
@@ -36374,12 +36420,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "dùng hàm bị xóa %qD"
@@ -36956,42 +37002,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "bộ khởi tạo kết thúc bất ngờ"
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr ""
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -37121,17 +37167,17 @@
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, gcc-internal-format
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, gcc-internal-format
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
@@ -37543,7 +37589,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr ""
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -37568,7 +37614,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> chưa được khai báo"
@@ -37633,7 +37679,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr ""
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT không phải một mẫu"
@@ -37658,7 +37704,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -37926,7 +37972,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "cần unqualified-id"
@@ -38101,7 +38147,7 @@
 msgid "capture of non-variable %qD "
 msgstr ""
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, gcc-internal-format
 msgid "%q+#D declared here"
 msgstr "%q+#D được khai báo ở đây"
@@ -38161,7 +38207,7 @@
 msgid "compound-statement in constexpr function"
 msgstr ""
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "cần selection-statement"
@@ -38191,7 +38237,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "cần iteration-statement"
@@ -38222,12 +38268,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ cấm tính toán gotos"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "cần jump-statement"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "%<;%> mở rộng"
@@ -38274,7 +38320,7 @@
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "các mẫu không thể là %<virtual%>"
@@ -38365,12 +38411,12 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
@@ -38385,7 +38431,7 @@
 msgid "expected template-id"
 msgstr "cần template-id"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "cần %<<%>"
@@ -38462,208 +38508,208 @@
 msgid "expected type specifier"
 msgstr "cần bộ chỉ định kiểu"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "cần template-id cho kiểu"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "cần type-name (tên kiểu)"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD là một mẫu liệt kê"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, gcc-internal-format
 msgid "%qD is not an enumerator-name"
 msgstr "%qD không phải là một enumerator-name"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "cần %<;%> hoặc %<{%>"
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "nhiều định nghĩa cho %q#T"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, gcc-internal-format
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C++ cấm kiểu liệt kê nặc danh trống rỗng"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD không là một namespace-name"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "cần namespace-name"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> không cho phép định nghĩa ở đây"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "không cho phép định nghĩa hàm tại đây"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "cần bộ khởi tạo"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "bộ khởi tạo được cung cấp cho hàm"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "hàm %q+D được khai báo lại là chung dòng (inline)"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> không phải một kiểu"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "dùng cấu tử như là một mẫu là không hợp lệ"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "dùng %<%T::%D%> thay cho %<%T::%D%> cho tên của cấu tử trong tên hạn định"
@@ -38672,7 +38718,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "bộ khai báo không hợp lệ"
@@ -38679,292 +38725,292 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "mã hạn định trong khai báo"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "cần câu khai báo"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD là một namespace"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "cần ptr-operator"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "trùng cv-qualifier"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "trùng cv-qualifier"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "trùng virt-specifier"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, gcc-internal-format
 msgid "invalid use of %<auto%>"
 msgstr "dùng %<auto%> không hợp lệ"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "các kiểu không nên được định nghĩa trong đối số mẫu"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "dùng %<auto%> không hợp lệ"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "cần type-specifier"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "cần %<,%> hoặc %<…%>"
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr ""
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr ""
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "cần class-name"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "cần %<;%> sau định nghĩa lớp"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "cần %<;%> sau định nghĩa cấu trúc"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "cần %<;%> sau định nghĩa kiểu hỗn hợp"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "cần %<{%> hoặc %<:%>"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "không thể chỉ định %<override%> cho lớp"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "không cho phép từ hạn định mở rộng"
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr "khai báo trước đây của %q+#T"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "cần class-key"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "cần %<;%> tại cuối khai báo thành viên"
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr ""
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "khai báo không hợp lệ của %<%T::%E%>"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -38973,532 +39019,532 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "đặc tả rõ ràng không hợp lệ"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "đối số cho %<sizeof…%> phải được bao quanh bởi dấu ngoặc đơn"
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> trước %qD"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "đã chỉ ra cả hai %<__thread%> và %<thread_local%>"
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "trùng %qD"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "trùng %qs"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "cần %<new%>"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "cần %<delete%>"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "cần %<return%>"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "cần %<extern%>"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "cần %<static_assert%>"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "cần %<decltype%>"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "cần %<operator%>"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "cần %<class%>"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "cần %<template%>"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "cần %<namespace%>"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "cần %<using%>"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "cần %<asm%>"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "cần %<try%>"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "cần %<catch%>"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "cần %<throw%>"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "cần %<__label__%>"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "cần %<@try%>"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "cần %<@synchronized%>"
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "cần %<@throw%>"
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "cần %<__transaction_atomic%>"
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "cần %<__transaction_relaxed%>"
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "cần %<::%>"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "cần %<…%>"
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "cần %<*%>"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "cần %<~%>"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "cần %<:%> hoặc %<::%>"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T trước đã khai báo ở đây"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "kiểu không hợp lệ cho biến instance (minh dụ)"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "kiểu không hợp lệ cho thuộc tính"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 msgid "expected positive integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "bộ khởi tạo sai"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "không cho phép định nghĩa hàm tại đây"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, gcc-internal-format
 msgid "not enough collapsed for loops"
 msgstr ""
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "mệnh đề khởi tạo không hợp lệ"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "cần id-expression"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> hoặc định danh"
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr "sai đặt ràng buộc cho toán hạng"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "biểu thức không thể được dùng như một hàm"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, gcc-internal-format
 msgid "expected variable-name"
 msgstr "cần tên biến"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "cần %<,%> hoặc %<)%> sau %qE"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "các mẫu không thể là %<virtual%>"
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr ""
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr "  từ định nghĩa của %q+#D"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr ""
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -39505,67 +39551,67 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, gcc-internal-format
 msgid "candidate is: %#D"
 msgstr "ứng cử là: %#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %#D"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD không phải là một mẫu hàm"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD không phải là một biến"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "template-id %qD cho %q+D không khớp bất kỳ khai báo mẫu nào"
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, gcc-internal-format
 msgid "too many template headers for %D (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -39572,57 +39618,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "template-id %qD trong khai báo của mẫu nguyên gốc"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD không phải là một hàm mẫu"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "%qD chưa được khai báo trong %qD"
@@ -39635,103 +39681,103 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr ""
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <nặc danh>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "khai báo của %q+#D"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr ""
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "các đối số tạm không thể là bạn"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr ""
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "Mẫu nguyên gốc ở đây"
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -39739,42 +39785,42 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr ""
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -39784,74 +39830,74 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "phần khai báo mẫu của %qD không hợp lệ"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "nhận được %d đối số mẫu cho %q#D"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "nhận được %d đối số mẫu cho %q#T"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  nhưng cần %d"
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT không phải là một kiểu mẫu"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, gcc-internal-format
 msgid "previous declaration %q+D used %d template parameter"
 msgid_plural "previous declaration %q+D used %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "đối số mẫu %q+#D"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "khai báo lại ở đây như là %q#D"
@@ -39860,273 +39906,273 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "định nghĩa nguyên bản xuất hiện ở đây"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  kiểu không khớp %qT và %qT"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE không tương đương với %qE"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  ứng cử cần ít nhất %d đối số, nhưng cung cấp %d"
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  không thể chuyển đổi %qE (kiểu %qT) thành kiểu %qT"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT là lớp cơ sở chưa rõ ràng của %qT"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT không được dẫn xuất từ %qT"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qD"
 msgstr ""
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, gcc-internal-format
 msgid "  could not resolve address from overloaded function %qE"
 msgstr ""
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, gcc-internal-format
 msgid "in template argument for type %qT "
 msgstr ""
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr ""
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr ""
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "dùng %qE để thay thế"
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr ""
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  cần hằng của kiểu %qT, nhưng lại nhận được %qT"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qE"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  cần kiểu, nhưng lại nhận %qE"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  cần một kiểu, nhưng lại nhận được %qT"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  cần hằng của kiểu %qD, nhưng lại nhận được %qT"
@@ -40133,77 +40179,77 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr ""
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr ""
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "sai số lượng đối số hàm mẫu (%d, phải là %d)"
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "sai số lượng đối số mẫu (%d, cần ít nhất phải là %d)"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "được cung cấp cho %q+D"
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D không phải là hàm mẫu"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr ""
@@ -40221,267 +40267,267 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "biến %qD có kiểu hàm"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "kiểu đối số không hợp lệ %qT"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "trong khai báo %q+D"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "hàm trả về một mảng"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "hàm trả về hàm"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "định nghĩa không hợp lệ của kiểu hạn định %qT"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "định nghĩa không hợp lệ của kiểu hạn định %qT"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "đang tạo con trỏ đến thành viên của kiểu void"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "đang tạo mảng của %qT"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT không phải có kiểu lớp, cấu trúc hay union"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "dùng %qs trong mẫu"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "đang dùng trường không hợp lệ %qD"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "dùng %<this->%D%> thay thế"
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "dùng %<%T::%D%> thay thế"
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, gcc-internal-format
 msgid "%q+D declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT không phải là một lớp hay namespace"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD không phải là một lớp hay namespace"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr "%qT là/dùng kiểu nặc danh"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "biểu thức nguyên %qE không là hằng"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%s: Trong minh dụ của %q#D:\n"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%s: Trong minh dụ của %q#D:\n"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 msgid "%s %#S"
 msgstr "%s %#D"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD không phải là một thành viên dữ liệu tĩnh của một mẫu lớp"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "khởi tạo lặp lại cho %qD"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
@@ -40493,62 +40539,62 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
@@ -40785,260 +40831,260 @@
 msgid "invalid base-class specification"
 msgstr "đặc tả lớp-cơ-sở không hợp lệ"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "không thể chụp thành viên %qD trong hỗn hợp nặc danh"
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD không bị bắt"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "không hiểu kiểu của %qE"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT không phải một kiểu enumeration"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "chỉ số phải là số nguyên"
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD không phải một biến trong mệnh đề %<lastprivate%>"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "%s tại %L phải là số nguyên"
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, gcc-internal-format
 msgid "%<num_teams%> expression must be integral"
 msgstr "%<num_teams%> biểu thức phải nguyên"
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%> biểu thức phải nguyên"
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%> biểu thức phải nguyên"
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD không phải một biến trong mệnh đề  %<aligned%>"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD không phải một biến trong mệnh đề %<depend%>"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr ""
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "thẩm tra gặp lỗi: %s"
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
@@ -41053,120 +41099,120 @@
 msgid "lambda-expression in a constant expression"
 msgstr "Gặp loại saio trong biểu thức bất biến"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr ""
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr ""
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr ""
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr ""
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr ""
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "khai báo trước ở đây"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a void return type"
 msgid "the %qE attribute requires arguments"
 msgstr "Thuộc tính %qE cần kiểu trả về là void"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "đối số %d của %qE phải nằm trong vùng %d…%d"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "đối số %qd không phải hằng số"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "'%%%c' is not a valid operand prefix"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "“%%%c” không phải là một tiền tố toán hạng đúng"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "thuộc tính %s được áp dụng cho %s %s tại %L"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "thuộc tính %s được áp dụng cho %s %s tại %L"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "thuộc tính %s được áp dụng cho %s %s tại %L"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check: gặp lỗi trong %s, tại %s:%d"
@@ -41356,564 +41402,559 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr ""
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr ""
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ cấm gọi %<::main%> từ bên trong chương trình"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE không thể dùng như một hàm"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD không thể được dùng như một hàm"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "biểu thức không thể được dùng như một hàm"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "quá nhiều đối số cho cấu tử %q#D"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "quá ít đối số cho hủy tử %q#D"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "quá nhiều đối số cho hàm thành viên %q#D"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "quá ít đối số cho hàm thành viên %q#D"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "quá nhiều đối số cho hàm %q#D"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "quá ít đối số cho hàm %q#D"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "quá nhiều đối số cho phương thức %q#D"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "quá ít đối số cho phương thức %q#D"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "quá nhiều đối số cho hàm"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "quá ít đối số cho hàm"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL được dùng trong số học"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "số lượng dịch trái bị âm"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr ""
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "số lượng quay trái >= độ rộng của kiểu"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "số lượng quay phải >= độ rộng của kiểu"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr ""
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "địa chỉ của %qD sẽ không bao giờ là NULL"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "các kiểu toán hạng là %qT và %qT"
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "không tìm thấy giao diện cho lớp %qE"
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr ""
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, gcc-internal-format
 msgid "taking address of constructor %qE"
 msgstr "lấy địa chỉ của cấu tử %qE"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, gcc-internal-format
 msgid "taking address of destructor %qE"
 msgstr "lấy địa chỉ của hủy tử %qE"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  cần qualified-id"
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "đang lấy địa chỉ của mẫu"
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr ""
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr ""
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, gcc-internal-format
 msgid "useless cast to type %qT"
 msgstr "trừ phi ép thành kiểu %qT"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "đang chuyển đổi từ %qT thành %qT"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr "áp đổi kiểu tử %qT thành %qT làm mất độ chính xác"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "áp đổi kiểu tử %qT thành %qT yêu cầu tăng cân chỉnh của kiểu đích"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ cấm việc áp đổi kiểu của mảng %qT"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr ""
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  trong định giá %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "gán giá trị cho mảng từ một danh sách bộ khởi tạo"
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "phép gán %qT cho %qT không tương thích kiểu"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "mảng được dùng như là bộ khởi tạo"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "gán mảng không hợp lệ"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr ""
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr ""
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr ""
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr ""
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr ""
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr ""
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "lớp %qE bị phản đối"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "trong đối số chuyển qua %P của %q+D"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "trả về tham chiếu đến tạm thời (temporary)"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr ""
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, gcc-internal-format
 msgid "address of label %q+D returned"
 msgstr "địa chỉ của nhãn %q+D được trả về"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr "địa chỉ của biến cục bộ %q+D được trả về"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "trả về một giá trị từ hủy tử"
@@ -41920,45 +41961,45 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "trả về một giá trị từ cấu tử"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "trả về danh sách bộ khởi tạo"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "%<return%> với một giá trị, trong hàm trả lại void (rỗng)"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "đang dùng mẫu như là lvalue"
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -42184,122 +42225,122 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr ""
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, fuzzy, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "mảng ký tự bị khởi tạo từ chuỗi rộng"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, fuzzy, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "mảng ký tự rộng bị khởi tạo từ chuỗi rộng không tương thích"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr ""
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr ""
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "toán hạng cơ sở của %<->%> không phải là một con trỏ"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -42476,8 +42517,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -42612,7 +42653,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -42728,7 +42769,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là NGUYÊN hay THỦ TỤC"
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là hằng"
@@ -43315,12 +43356,12 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "Đối số của hàm %s tại %L là âm"
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "Đối số của hàm %s tại %L là âm"
@@ -43590,6 +43631,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr ""
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -43597,7 +43643,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -43817,399 +43863,399 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Lỗi trong khởi tạo con trỏ tại %C"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Khởi tạo con trỏ khác KHÔNG tại %C"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 msgid "Function name %qs not allowed at %C"
 msgstr "không cho phép định nghĩa hàm tại đây"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Sự khởi tạo kiểu cũ tại %C"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Cần danh sách kết hợp tại %C"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Cần danh sách kết hợp tại %C"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "kiểu BYTE tại %C"
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Giả định kiểu tại %C"
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "câu lệnh CLASS tại %C"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "câu lệnh IMPORT tại %C"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Trùng thuộc tính %s tại %L"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "thuộc tính ASYNCHRONOUS tại%C"
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "thuộc tính CONTIGUOUS tại %C"
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "thuộc tính BẢO VỆ tại %C"
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "thuộc tính VALUE tại %C"
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "thuộc tính VOLATILE tại %C"
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Thuộc tính sai"
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -44216,795 +44262,801 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Thiếu ký hiệu"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "câu lệnh SYNC tại %C"
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "thủ tục IMPURE tại %C"
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "Đối số âm N tại %L"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Định thời bắt đầu và kết thúc thủ tục"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Cần danh sách đối số tại %C"
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Thủ tục “%s” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Cần thuộc tính ràng buộc tại %C"
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "câu lệnh ENTRY tại %C"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:5597
-#, gcc-internal-format
-msgid "gfc_match_entry(): Bad state"
-msgstr "gfc_match_entry(): Trạng thái sai"
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Unexpected ENTRY statement at %C"
+msgstr "Không cần câu lệnh CASE tại %C"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "%qD được gọi trong một biểu thức hằng"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Không cần câu lệnh CASE tại %C"
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "cần biểu thức %s tại %L"
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "Cần câu lệnh %s tại %L"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Cần một giao diện không tên tại %C"
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Cần tên chấm dứt tại %C"
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Không cần câu lệnh CASE tại %C"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr ""
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "Cần %<(%> tại %C"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Cần tên biến tại %C"
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Cần \",\" tại %C"
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Cần \")\" tại %C"
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "cần %<,%> hoặc kết thúc câu lệnh tại %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "câu lệnh CONTIGUOUS tại %C"
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "câu lệnh VALUE tại %C"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "câu lệnh VOLATILE tại %C"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "câu lệnh ASYNCHRONOUS tại %C"
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "Kiểu TRỪU TƯỢNG tại %C"
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Cần :: trong định nghĩa KIỂU tại %C"
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%qD đã định nghĩa rồi"
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM và ENUMERATOR tại %C"
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Trùng DEFERRED tại %C"
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Cần access-specifier tại %C"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Cần thuộc tính ràng buộc tại %C"
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "Cần \",\" tại %C"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Cần tên ràng buộc tại %C"
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "SOURCE tag tại %L"
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Cần thuộc tính ràng buộc tại %C"
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "cần %<::%>"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY statement at %C"
+msgid "Malformed GENERIC statement at %C"
+msgstr "câu lệnh ENTRY tại %C"
+
+#: fortran/decl.c:8526
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "Cần \",\" tại %C"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "FINAL trống rỗng tại %C"
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "Cần %<,%> tại %C"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Không rõ toán tử “%s” tại %%L"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "Thủ tục “%s” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
@@ -45284,342 +45336,342 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr ""
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "Chuyển đổi từ %s sang %s tại %L"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, gcc-internal-format
 msgid "Conversion from %qs to %qs at %L"
 msgstr "Chuyển đổi từ %qs sang %qs tại %L"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Cần danh sách kết hợp tại %C"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "không thể mở tập tin đầu vào: %s"
@@ -45641,27 +45693,27 @@
 msgid "Removing call to function %qs at %L"
 msgstr "gặp lỗi trong các đối số tới hàm đặc tả %qs"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr ""
@@ -45716,592 +45768,598 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr "Cần %<END INTERFACE ASSIGNMENT (=)%> tại %C"
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
+#, fuzzy, gcc-internal-format
+#| msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr "Cần %<END INTERFACE OPERATOR (.%s.)%> tại %C"
+
+#: fortran/interface.c:353
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr "Cần %<END INTERFACE OPERATOR (%s)%> tại %C, nhưng lại nhận được %s"
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr "Cần %<END INTERFACE OPERATOR (.%s.)%> tại %C"
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr "Cần %<END INTERFACE %s%> tại %C"
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr ""
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr ""
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr ""
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr ""
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr ""
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr ""
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr ""
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr ""
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
 msgstr "Đối số thủ tục không hợp lệ tại %L"
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, gcc-internal-format
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr ""
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, gcc-internal-format
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr ""
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "thủ tục mô-đun"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Đối số thủ tục không hợp lệ tại %L"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Chiều dài chuỗi thật vẫn nhỏ hơn điều tuyên bố cho đối số giả “%s” (%ld/%ld)"
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Chiều dài chuỗi thật không tương ứng với điều tuyên bố cho đối số giả “%s” (%ld/%ld)"
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Cần một giao diện không tên tại %C"
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Đối số thủ tục không hợp lệ tại %L"
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "sắp hàng cho %q+D phải ít nhất %d"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "sắp hàng cho %q+D phải ít nhất %d"
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "sắp hàng cho %q+D phải ít nhất %d"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Thiếu đối số đối thực tế cho đối số %qs tại %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Mã thành phần sai"
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Danh sách không khớp"
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Danh sách không khớp"
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Cảnh báo về thủ tục được gọi mà không phải được tuyên bố dứt khoát"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Cảnh báo về cuộc gọi có giao diện ngầm"
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Cảnh báo về cuộc gọi có giao diện ngầm"
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "không thể tìm thấy ký hiệu %qs"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Kiểu giao diện sai"
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, gcc-internal-format
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr "không thể đè GENERIC %qs tại %L"
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
@@ -46711,12 +46769,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "BLANK= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "DECIMAL= tại %C không được phép trong Fortran 95"
@@ -46726,7 +46784,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "ENCODING= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "ROUND= tại %C không được phép trong Fortran 95"
@@ -46751,776 +46809,776 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "câu lệnh FLUSH tại %C"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr ""
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr ""
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr ""
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "UNIT không được chỉ ra tại %L"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr ""
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "PAD= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "DELIM= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr "Câu lệnh V/R chứa con số đơn vị quá lớn"
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, fuzzy, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
 msgstr "gfc_trans_code(): Mã câu lệnh sai"
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, gcc-internal-format
 msgid "Missing %<)%> in statement at or before %L"
 msgstr ""
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, gcc-internal-format
 msgid "Missing %<(%> in statement at or before %L"
 msgstr ""
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr "Số nguyên quá lớn tại %C"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr ""
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, gcc-internal-format
 msgid "Label name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, fuzzy, gcc-internal-format
 msgid "Duplicate construct label %qs at %C"
 msgstr "Trùng thuộc tính %s tại %L"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr "Tên có chứa ký tự không hợp lệ tại %C"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr "Tên tại %C quá dài"
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr ""
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr ""
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr ""
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr ""
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, gcc-internal-format, gfc-internal-format
 msgid "gfc_match(): Bad match code %c"
 msgstr "gfc__match(): Mã khớp sai %c"
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %C"
 msgstr "Câu lệnh IF số học tại %C"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr ""
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr ""
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr ""
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
 msgstr ""
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr ""
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr "Cần danh sách kết hợp tại %C"
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr "Cần kết hợp tại %C"
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in association at %C"
 msgstr "Cần kết hợp tại %C"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, fuzzy, gcc-internal-format
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "cần %<,%> hoặc %<)%> sau %qE"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr ""
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, gcc-internal-format
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "type-spec không hợp lệ tại %C"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr ""
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr ""
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr ""
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr ""
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr ""
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "  vào khối được cấu trúc OpenMP"
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr ""
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "câu lệnh SYNC tại %C"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "câu lệnh ASSIGN tại %C"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr ""
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "Được tính toán GOTO tại %C"
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "Sai trong type-spec tại %L"
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "ERRMSG tag tại %L"
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "SOURCE tag tại %L"
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "MOLD tag tại %L"
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "ERRMSG tại %L"
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Cần tham chiếu thành phần tại %C"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr ""
@@ -47528,147 +47586,147 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr ""
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Thủ tục “%s” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr ""
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr ""
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr ""
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, fuzzy, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Cần một giao diện không tên tại %C"
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "câu lệnh ENTRY tại %C"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Không cần câu lệnh CASE tại %C"
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -47814,168 +47872,168 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "can%'t mở %s để ghi: %m"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Gặp lỗi khi ghi tập tin môt-đun: %s"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "can%'t đóng tập tin đầu vào %s: %m"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr ""
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "không thể tạo tập tin tạm thời"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Thành phần “%s” tại %C đã sẵn được khai báo tại %L"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "mô đun ISO_C_BINDING tại %C"
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "\"USE :: module\" tại %C"
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "mô đun ISO_C_BINDING tại %C"
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "mô đun ISO_C_BINDING tại %C"
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Gặp lỗi khi mở tập tin thống kê %s để đọc [%s]"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr ""
@@ -48270,7 +48328,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -48962,367 +49020,362 @@
 msgid "Unexpected %s statement at %C"
 msgstr "Không cần câu lệnh CASE tại %C"
 
-#: fortran/parse.c:2428
-#, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr "Không cần câu lệnh CASE tại %C"
-
-#: fortran/parse.c:2439
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr "cần kết thúc dòng"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "GENERIC ràng buộc tại %C"
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr ""
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr ""
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "Chuyển đổi từ %s sang %s tại %L"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, fuzzy, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Đối số của hàm %s tại %L là âm"
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "cấu trúc BLOCK tại %C"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "cấu trúc ASSOCIATE tại %C"
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr "Cần \",\" tại %C"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr "Cần \",\" tại %C"
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "Thủ tục “%s” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr "Thủ tục “%s” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr ""
@@ -49330,7 +49383,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -50025,7 +50078,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -50080,363 +50133,363 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr ""
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "gặp lỗi trong các đối số tới hàm đặc tả %qs"
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "“%qs” tại %L không phải là một hàm"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, fuzzy, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT INTERFACE tại %C"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "resolve_function(): kiểu hàm sai"
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "resolve_subroutine(): kiểu hàm sai"
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): intrinsic sai"
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "tạo mảng tham chiếu"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "tạo mảng tham chiếu"
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -50445,12 +50498,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -50459,248 +50512,248 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Mong đợi một loại biểu thức"
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s tại %L phải là một scalar"
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s tại %L phải là số nguyên"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -50709,188 +50762,188 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "%s tại %L phải là số nguyên"
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "cần kiểu số"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Gặp ngữ cảnh sai cho hàm trỏ NULL() tại %%L"
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -50897,12 +50950,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -50910,158 +50963,158 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Kiểu khối sai"
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr ""
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr ""
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr ""
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Không có biểu thức trên DO WHILE"
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Mã câu lệnh sai"
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -51068,7 +51121,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -51076,57 +51129,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr ""
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Chiều dài chuỗi tại %L là quá lớn"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
@@ -51133,422 +51186,422 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng không phải hằng số"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "không thể khởi tạo một đối tượng có kích cỡ biến đổi"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%s tại %L phải là một scalar"
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "thuộc tính %<readonly%> xung đột với %<setter%>"
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "thẻ %s tại %L phải là scalar"
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Cảnh báo nếu một thủ tục người dùng có cùng một tên với một điều thực chất"
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -51555,397 +51608,397 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "nhãn %d tại %L đã định nghĩa nhưng chưa được dùng"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Chuỗi con tại %L có độ dài là không"
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -51975,47 +52028,47 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr ""
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr "Dòng bị cắt cụt tại %L"
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr ""
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "Cảnh báo về ký hiệu “&” còn thiếu trong hằng ký tự tiếp tục"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr "Cho phép sử dụng ký tự tab một cách không phù hợp"
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
 msgstr ""
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr ""
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr "%s:%d: tập tin còn %s nhưng không vào được"
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr "%s:%d: chỉ thị tiền xử lý không hợp lệ"
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, gcc-internal-format
 msgid "Can't open file %qs"
 msgstr "Không thể mở tập tin %qs"
@@ -52281,52 +52334,52 @@
 msgid "Reshaped array too large at %C"
 msgstr "Số nguyên quá lớn tại %C"
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, fuzzy, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Gặp loại saio trong biểu thức bất biến"
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr "in gfc_simplify_sin(): Kiểu sai"
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr ""
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "đối số của thuộc tính %qE không hợp lệ"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -52404,313 +52457,318 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "Đối số thủ tục không hợp lệ tại %L"
+
+#: fortran/symbol.c:489
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr ""
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "thuộc tính %s được áp dụng cho %s %s tại %L"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) được áp dụng với %s %s tại %L"
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, fuzzy, gcc-internal-format
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr "thuộc tính %<readonly%> xung đột với %<setter%>"
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute with %s attribute at %L"
 msgstr "thuộc tính %s được áp dụng cho %s %s tại %L"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, fuzzy, gcc-internal-format
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr "thuộc tính %s được áp dụng cho %s %s tại %L"
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr ""
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "thuộc tính %<readonly%> xung đột với %<setter%>"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) tại %L"
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS tại %L"
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "%qE không có kiểu lớp"
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr "Thành phần “%s” tại %C đã sẵn được khai báo tại %L"
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qD không phải là thành viên của %qT"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr "new_symbol(): Tên ký hiệu quá dài"
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -52969,7 +53027,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -54525,13 +54583,27 @@
 #~ msgstr "-march=KTrúc Chọn kiến trúc đích"
 
 #, fuzzy
+#~ msgid "Use ISA 2.07 crypto instructions"
+#~ msgstr "Sử dụng các chỉ lệnh microMIPS"
+
+#, fuzzy
 #~ msgid "mcu not found"
 #~ msgstr "không tìm thấy trường %qs"
 
+#~ msgid "-munix=98 option required for C89 Amendment 1 features.\n"
+#~ msgstr "-munix=98 cần cho C89 Hiệu chỉnh 1 tính năng.\n"
+
 #, fuzzy
 #~ msgid "hotpatching is not compatible with nested functions"
 #~ msgstr "-mnop-mcount không tương thích với đích này"
 
+#~ msgid "gfc_match_entry(): Bad state"
+#~ msgstr "gfc_match_entry(): Trạng thái sai"
+
+#, fuzzy
+#~ msgid "Unexpected %s statement in verify_st_order() at %C"
+#~ msgstr "Không cần câu lệnh CASE tại %C"
+
 #~ msgid "%s:%d:%d: Invalid state file; %s"
 #~ msgstr "%s:%d:%d: Không phải tập tin thống kê hợp lệ; %s"
 
Index: gcc/po/uk.po
===================================================================
--- gcc/po/uk.po	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ gcc/po/uk.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,54354 @@
+# Ukrainian translation of gcc
+# Copyright (C) 2015 Free Software Foundation, Inc.
+# This file is distributed under the same license as the gcc package.
+#
+# Yuri Chornoivan <yurchor@ukr.net>, 2015.
+msgid ""
+msgstr ""
+"Project-Id-Version: gcc 5.2.0\n"
+"Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
+"PO-Revision-Date: 2015-07-22 14:22+0300\n"
+"Last-Translator: Yuri Chornoivan <yurchor@ukr.net>\n"
+"Language-Team: Ukrainian <translation-team-uk@lists.sourceforge.net>\n"
+"Language: uk\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"Plural-Forms: nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);\n"
+"X-Generator: Lokalize 1.5\n"
+
+#: cfgrtl.c:2698
+msgid "flow control insn inside a basic block"
+msgstr "інструкція з керування потоком у основному блоці"
+
+#: cfgrtl.c:2930
+msgid "wrong insn in the fallthru edge"
+msgstr "помилкова інструкція на краю fallthru"
+
+#: cfgrtl.c:2987
+msgid "insn outside basic block"
+msgstr "інструкція поза основним блоком"
+
+#: cfgrtl.c:2994
+msgid "return not followed by barrier"
+msgstr "за return немає barrier"
+
+#: collect-utils.c:164
+#, c-format
+msgid "[cannot find %s]"
+msgstr "[не вдалося знайти %s]"
+
+#: collect2.c:1557
+#, c-format
+msgid "collect2 version %s\n"
+msgstr "collect2 версії %s\n"
+
+#: collect2.c:1664
+#, c-format
+msgid "%d constructor found\n"
+msgid_plural "%d constructors found\n"
+msgstr[0] "знайдено %d конструктор\n"
+msgstr[1] "знайдено %d конструктори\n"
+msgstr[2] "знайдено %d конструкторів\n"
+
+#: collect2.c:1668
+#, c-format
+msgid "%d destructor found\n"
+msgid_plural "%d destructors found\n"
+msgstr[0] "знайдено %d деструктор\n"
+msgstr[1] "знайдено %d деструктори\n"
+msgstr[2] "знайдено %d деструкторів\n"
+
+#: collect2.c:1672
+#, c-format
+msgid "%d frame table found\n"
+msgid_plural "%d frame tables found\n"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: collect2.c:1836 config/i386/intelmic-mkoffload.c:67
+#, c-format
+msgid "[Leaving %s]\n"
+msgstr "[Полишаємо %s]\n"
+
+#: collect2.c:2068
+#, c-format
+msgid ""
+"\n"
+"write_c_file - output name is %s, prefix is %s\n"
+msgstr ""
+"\n"
+"write_c_file - назвою результату є %s, префіксом є %s\n"
+
+#: collect2.c:2573
+#, c-format
+msgid ""
+"\n"
+"ldd output with constructors/destructors.\n"
+msgstr ""
+"\n"
+"Виведені ldd дані з конструкторами та деструкторами.\n"
+
+#: cprop.c:1793
+msgid "const/copy propagation disabled"
+msgstr ""
+
+#: diagnostic.c:212
+#, c-format
+msgid "%s: all warnings being treated as errors"
+msgstr "%s: усі попередження вважаються помилками"
+
+#: diagnostic.c:217
+#, c-format
+msgid "%s: some warnings being treated as errors"
+msgstr "%s: деякі попередження вважаються помилками"
+
+#: diagnostic.c:299 input.c:170 c-family/c-opts.c:1300 cp/error.c:1207
+#: fortran/cpp.c:591 fortran/error.c:1181
+msgid "<built-in>"
+msgstr ""
+
+#: diagnostic.c:502
+#, c-format
+msgid "compilation terminated due to -Wfatal-errors.\n"
+msgstr "компіляцію перервано через -Wfatal-errors.\n"
+
+#: diagnostic.c:513
+#, c-format
+msgid "compilation terminated due to -fmax-errors=%u.\n"
+msgstr "компіляцію перервано через -fmax-errors=%u.\n"
+
+#: diagnostic.c:534
+#, c-format
+msgid ""
+"Please submit a full bug report,\n"
+"with preprocessed source if appropriate.\n"
+msgstr ""
+
+#: diagnostic.c:540
+#, c-format
+msgid "See %s for instructions.\n"
+msgstr ""
+
+#: diagnostic.c:549
+#, c-format
+msgid "compilation terminated.\n"
+msgstr ""
+
+#: diagnostic.c:829
+#, c-format
+msgid "%s:%d: confused by earlier errors, bailing out\n"
+msgstr ""
+
+#: diagnostic.c:1273
+#, c-format
+msgid "Internal compiler error: Error reporting routines re-entered.\n"
+msgstr ""
+
+#: final.c:1229
+msgid "negative insn length"
+msgstr ""
+
+#: final.c:3020
+msgid "could not split insn"
+msgstr ""
+
+#: final.c:3435
+msgid "invalid 'asm': "
+msgstr ""
+
+#: final.c:3564
+#, c-format
+msgid "nested assembly dialect alternatives"
+msgstr ""
+
+#: final.c:3592 final.c:3604
+#, c-format
+msgid "unterminated assembly dialect alternative"
+msgstr ""
+
+#: final.c:3746
+#, c-format
+msgid "operand number missing after %%-letter"
+msgstr ""
+
+#: final.c:3749 final.c:3790
+#, c-format
+msgid "operand number out of range"
+msgstr ""
+
+#: final.c:3807
+#, c-format
+msgid "invalid %%-code"
+msgstr ""
+
+#: final.c:3837
+#, c-format
+msgid "'%%l' operand isn't a label"
+msgstr ""
+
+#. We can't handle floating point constants;
+#. PRINT_OPERAND must handle them.
+#. We can't handle floating point constants;
+#. TARGET_PRINT_OPERAND must handle them.
+#. We can't handle floating point constants;
+#. PRINT_OPERAND must handle them.
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
+#: config/pdp11/pdp11.c:1727
+#, c-format
+msgid "floating constant misused"
+msgstr ""
+
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
+#: config/pdp11/pdp11.c:1768
+#, c-format
+msgid "invalid expression as operand"
+msgstr ""
+
+#: gcc.c:1506
+#, c-format
+msgid "Using built-in specs.\n"
+msgstr ""
+
+#: gcc.c:1703
+#, c-format
+msgid ""
+"Setting spec %s to '%s'\n"
+"\n"
+msgstr ""
+
+#: gcc.c:1808
+#, c-format
+msgid "Reading specs from %s\n"
+msgstr ""
+
+#: gcc.c:1935
+#, c-format
+msgid "could not find specs file %s\n"
+msgstr ""
+
+#: gcc.c:2010
+#, c-format
+msgid "rename spec %s to %s\n"
+msgstr ""
+
+#: gcc.c:2012
+#, c-format
+msgid ""
+"spec is '%s'\n"
+"\n"
+msgstr ""
+
+#: gcc.c:2448
+#, c-format
+msgid "%s\n"
+msgstr "%s\n"
+
+#: gcc.c:2815
+#, c-format
+msgid ""
+"\n"
+"Go ahead? (y or n) "
+msgstr ""
+
+#: gcc.c:2965
+#, c-format
+msgid "# %s %.2f %.2f\n"
+msgstr ""
+
+#: gcc.c:3171
+#, c-format
+msgid "Usage: %s [options] file...\n"
+msgstr "Використання: %s [параметри] файл…\n"
+
+#: gcc.c:3172
+msgid "Options:\n"
+msgstr "Параметри:\n"
+
+#: gcc.c:3174
+msgid "  -pass-exit-codes         Exit with highest error code from a phase\n"
+msgstr ""
+
+#: gcc.c:3175
+msgid "  --help                   Display this information\n"
+msgstr ""
+
+#: gcc.c:3176
+msgid "  --target-help            Display target specific command line options\n"
+msgstr ""
+
+#: gcc.c:3177
+msgid "  --help={common|optimizers|params|target|warnings|[^]{joined|separate|undocumented}}[,...]\n"
+msgstr ""
+
+#: gcc.c:3178
+msgid "                           Display specific types of command line options\n"
+msgstr ""
+
+#: gcc.c:3180
+msgid "  (Use '-v --help' to display command line options of sub-processes)\n"
+msgstr ""
+
+#: gcc.c:3181
+msgid "  --version                Display compiler version information\n"
+msgstr ""
+
+#: gcc.c:3182
+msgid "  -dumpspecs               Display all of the built in spec strings\n"
+msgstr ""
+
+#: gcc.c:3183
+msgid "  -dumpversion             Display the version of the compiler\n"
+msgstr ""
+
+#: gcc.c:3184
+msgid "  -dumpmachine             Display the compiler's target processor\n"
+msgstr ""
+
+#: gcc.c:3185
+msgid "  -print-search-dirs       Display the directories in the compiler's search path\n"
+msgstr ""
+
+#: gcc.c:3186
+msgid "  -print-libgcc-file-name  Display the name of the compiler's companion library\n"
+msgstr ""
+
+#: gcc.c:3187
+msgid "  -print-file-name=<lib>   Display the full path to library <lib>\n"
+msgstr ""
+
+#: gcc.c:3188
+msgid "  -print-prog-name=<prog>  Display the full path to compiler component <prog>\n"
+msgstr ""
+
+#: gcc.c:3189
+msgid ""
+"  -print-multiarch         Display the target's normalized GNU triplet, used as\n"
+"                           a component in the library path\n"
+msgstr ""
+
+#: gcc.c:3192
+msgid "  -print-multi-directory   Display the root directory for versions of libgcc\n"
+msgstr ""
+
+#: gcc.c:3193
+msgid ""
+"  -print-multi-lib         Display the mapping between command line options and\n"
+"                           multiple library search directories\n"
+msgstr ""
+
+#: gcc.c:3196
+msgid "  -print-multi-os-directory Display the relative path to OS libraries\n"
+msgstr ""
+
+#: gcc.c:3197
+msgid "  -print-sysroot           Display the target libraries directory\n"
+msgstr ""
+
+#: gcc.c:3198
+msgid "  -print-sysroot-headers-suffix Display the sysroot suffix used to find headers\n"
+msgstr ""
+
+#: gcc.c:3199
+msgid "  -Wa,<options>            Pass comma-separated <options> on to the assembler\n"
+msgstr ""
+
+#: gcc.c:3200
+msgid "  -Wp,<options>            Pass comma-separated <options> on to the preprocessor\n"
+msgstr ""
+
+#: gcc.c:3201
+msgid "  -Wl,<options>            Pass comma-separated <options> on to the linker\n"
+msgstr ""
+
+#: gcc.c:3202
+msgid "  -Xassembler <arg>        Pass <arg> on to the assembler\n"
+msgstr ""
+
+#: gcc.c:3203
+msgid "  -Xpreprocessor <arg>     Pass <arg> on to the preprocessor\n"
+msgstr ""
+
+#: gcc.c:3204
+msgid "  -Xlinker <arg>           Pass <arg> on to the linker\n"
+msgstr ""
+
+#: gcc.c:3205
+msgid "  -save-temps              Do not delete intermediate files\n"
+msgstr ""
+
+#: gcc.c:3206
+msgid "  -save-temps=<arg>        Do not delete intermediate files\n"
+msgstr ""
+
+#: gcc.c:3207
+msgid ""
+"  -no-canonical-prefixes   Do not canonicalize paths when building relative\n"
+"                           prefixes to other gcc components\n"
+msgstr ""
+
+#: gcc.c:3210
+msgid "  -pipe                    Use pipes rather than intermediate files\n"
+msgstr ""
+
+#: gcc.c:3211
+msgid "  -time                    Time the execution of each subprocess\n"
+msgstr ""
+
+#: gcc.c:3212
+msgid "  -specs=<file>            Override built-in specs with the contents of <file>\n"
+msgstr ""
+
+#: gcc.c:3213
+msgid "  -std=<standard>          Assume that the input sources are for <standard>\n"
+msgstr ""
+
+#: gcc.c:3214
+msgid ""
+"  --sysroot=<directory>    Use <directory> as the root directory for headers\n"
+"                           and libraries\n"
+msgstr ""
+
+#: gcc.c:3217
+msgid "  -B <directory>           Add <directory> to the compiler's search paths\n"
+msgstr ""
+
+#: gcc.c:3218
+msgid "  -v                       Display the programs invoked by the compiler\n"
+msgstr ""
+
+#: gcc.c:3219
+msgid "  -###                     Like -v but options quoted and commands not executed\n"
+msgstr ""
+
+#: gcc.c:3220
+msgid "  -E                       Preprocess only; do not compile, assemble or link\n"
+msgstr ""
+
+#: gcc.c:3221
+msgid "  -S                       Compile only; do not assemble or link\n"
+msgstr ""
+
+#: gcc.c:3222
+msgid "  -c                       Compile and assemble, but do not link\n"
+msgstr ""
+
+#: gcc.c:3223
+msgid "  -o <file>                Place the output into <file>\n"
+msgstr ""
+
+#: gcc.c:3224
+msgid "  -pie                     Create a position independent executable\n"
+msgstr ""
+
+#: gcc.c:3225
+msgid "  -shared                  Create a shared library\n"
+msgstr ""
+
+#: gcc.c:3226
+msgid ""
+"  -x <language>            Specify the language of the following input files\n"
+"                           Permissible languages include: c c++ assembler none\n"
+"                           'none' means revert to the default behavior of\n"
+"                           guessing the language based on the file's extension\n"
+msgstr ""
+
+#: gcc.c:3233
+#, c-format
+msgid ""
+"\n"
+"Options starting with -g, -f, -m, -O, -W, or --param are automatically\n"
+" passed on to the various sub-processes invoked by %s.  In order to pass\n"
+" other options on to these processes the -W<letter> options must be used.\n"
+msgstr ""
+
+#: gcc.c:5637
+#, c-format
+msgid "Processing spec (%s), which is '%s'\n"
+msgstr ""
+
+#: gcc.c:6334
+#, c-format
+msgid "Target: %s\n"
+msgstr ""
+
+#: gcc.c:6335
+#, c-format
+msgid "Configured with: %s\n"
+msgstr ""
+
+#: gcc.c:6349
+#, c-format
+msgid "Thread model: %s\n"
+msgstr ""
+
+#: gcc.c:6360
+#, c-format
+msgid "gcc version %s %s\n"
+msgstr ""
+
+#: gcc.c:6363
+#, c-format
+msgid "gcc driver version %s %sexecuting gcc version %s\n"
+msgstr ""
+
+#: gcc.c:6436 gcc.c:6648
+#, c-format
+msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
+msgstr ""
+
+#: gcc.c:6572
+#, c-format
+msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
+msgstr ""
+
+#: gcc.c:7398
+#, c-format
+msgid "install: %s%s\n"
+msgstr ""
+
+#: gcc.c:7401
+#, c-format
+msgid "programs: %s\n"
+msgstr ""
+
+#: gcc.c:7403
+#, c-format
+msgid "libraries: %s\n"
+msgstr ""
+
+#: gcc.c:7520
+#, c-format
+msgid ""
+"\n"
+"For bug reporting instructions, please see:\n"
+msgstr ""
+
+#: gcc.c:7536 gcov-tool.c:528
+#, c-format
+msgid "%s %s%s\n"
+msgstr "%s %s%s\n"
+
+#: gcc.c:7539 gcov-tool.c:530 gcov.c:504 fortran/gfortranspec.c:280
+#: java/jcf-dump.c:1240
+msgid "(C)"
+msgstr "©"
+
+#: gcc.c:7540 java/jcf-dump.c:1241
+#, c-format
+msgid ""
+"This is free software; see the source for copying conditions.  There is NO\n"
+"warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
+"\n"
+msgstr ""
+
+#: gcc.c:7845
+#, c-format
+msgid ""
+"\n"
+"Linker options\n"
+"==============\n"
+"\n"
+msgstr ""
+
+#: gcc.c:7846
+#, c-format
+msgid ""
+"Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
+"\n"
+msgstr ""
+
+#: gcc.c:9110
+#, c-format
+msgid ""
+"Assembler options\n"
+"=================\n"
+"\n"
+msgstr ""
+
+#: gcc.c:9111
+#, c-format
+msgid ""
+"Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
+"\n"
+msgstr ""
+
+#: gcov-tool.c:166
+#, c-format
+msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
+msgstr ""
+
+#: gcov-tool.c:167 gcov-tool.c:264 gcov-tool.c:420
+#, c-format
+msgid "    -v, --verbose                       Verbose mode\n"
+msgstr "    -v, --verbose                       докладний режим\n"
+
+#: gcov-tool.c:168 gcov-tool.c:265
+#, c-format
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr ""
+
+#: gcov-tool.c:169
+#, c-format
+msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
+msgstr ""
+
+#: gcov-tool.c:185
+#, c-format
+msgid "Merge subcomand usage:"
+msgstr ""
+
+#: gcov-tool.c:263
+#, c-format
+msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
+msgstr ""
+
+#: gcov-tool.c:266
+#, c-format
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgstr ""
+
+#: gcov-tool.c:267
+#, c-format
+msgid "    -n, --normalize <long long>         Normalize the profile\n"
+msgstr ""
+
+#: gcov-tool.c:284
+#, c-format
+msgid "Rewrite subcommand usage:"
+msgstr ""
+
+#: gcov-tool.c:329
+#, c-format
+msgid "scaling cannot co-exist with normalization, skipping\n"
+msgstr ""
+
+#: gcov-tool.c:342 gcov-tool.c:352
+#, c-format
+msgid "incorrect format in scaling, using 1/1\n"
+msgstr ""
+
+#: gcov-tool.c:362
+#, c-format
+msgid "normalization cannot co-exist with scaling\n"
+msgstr ""
+
+#: gcov-tool.c:419
+#, c-format
+msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
+msgstr ""
+
+#: gcov-tool.c:421
+#, c-format
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgstr ""
+
+#: gcov-tool.c:422
+#, c-format
+msgid "    -f, --function                      Print function level info\n"
+msgstr ""
+
+#: gcov-tool.c:423
+#, c-format
+msgid "    -F, --fullname                      Print full filename\n"
+msgstr ""
+
+#: gcov-tool.c:424
+#, c-format
+msgid "    -o, --object                        Print object level info\n"
+msgstr ""
+
+#: gcov-tool.c:425
+#, c-format
+msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
+msgstr ""
+
+#: gcov-tool.c:445
+#, c-format
+msgid "Overlap subcomand usage:"
+msgstr ""
+
+#: gcov-tool.c:511
+#, c-format
+msgid ""
+"Usage: %s [OPTION]... SUB_COMMAND [OPTION]...\n"
+"\n"
+msgstr ""
+
+#: gcov-tool.c:512
+#, c-format
+msgid ""
+"Offline tool to handle gcda counts\n"
+"\n"
+msgstr ""
+
+#: gcov-tool.c:513
+#, c-format
+msgid "  -h, --help                            Print this help, then exit\n"
+msgstr ""
+
+#: gcov-tool.c:514
+#, c-format
+msgid "  -v, --version                         Print version number, then exit\n"
+msgstr ""
+
+#: gcov-tool.c:518 gcov.c:492
+#, c-format
+msgid ""
+"\n"
+"For bug reporting instructions, please see:\n"
+"%s.\n"
+msgstr ""
+"\n"
+"Настанови щодо звітування про вади наведено тут:\n"
+"%s.\n"
+
+#: gcov-tool.c:529
+#, c-format
+msgid "Copyright %s 2014-2015 Free Software Foundation, Inc.\n"
+msgstr ""
+
+#: gcov-tool.c:532 gcov.c:506
+#, c-format
+msgid ""
+"This is free software; see the source for copying conditions.\n"
+"There is NO warranty; not even for MERCHANTABILITY or \n"
+"FITNESS FOR A PARTICULAR PURPOSE.\n"
+"\n"
+msgstr ""
+
+#: gcov.c:472
+#, c-format
+msgid ""
+"Usage: gcov [OPTION]... SOURCE|OBJ...\n"
+"\n"
+msgstr ""
+
+#: gcov.c:473
+#, c-format
+msgid ""
+"Print code coverage information.\n"
+"\n"
+msgstr ""
+
+#: gcov.c:474
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr ""
+
+#: gcov.c:475
+#, c-format
+msgid "  -a, --all-blocks                Show information for every basic block\n"
+msgstr ""
+
+#: gcov.c:476
+#, c-format
+msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
+msgstr ""
+
+#: gcov.c:477
+#, c-format
+msgid ""
+"  -c, --branch-counts             Output counts of branches taken\n"
+"                                    rather than percentages\n"
+msgstr ""
+
+#: gcov.c:479
+#, c-format
+msgid "  -d, --display-progress          Display progress information\n"
+msgstr ""
+
+#: gcov.c:480
+#, c-format
+msgid "  -f, --function-summaries        Output summaries for each function\n"
+msgstr ""
+
+#: gcov.c:481
+#, c-format
+msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
+msgstr ""
+
+#: gcov.c:482
+#, c-format
+msgid ""
+"  -l, --long-file-names           Use long output file names for included\n"
+"                                    source files\n"
+msgstr ""
+
+#: gcov.c:484
+#, c-format
+msgid "  -m, --demangled-names           Output demangled function names\n"
+msgstr ""
+
+#: gcov.c:485
+#, c-format
+msgid "  -n, --no-output                 Do not create an output file\n"
+msgstr ""
+
+#: gcov.c:486
+#, c-format
+msgid "  -o, --object-directory DIR|FILE Search for object files in DIR or called FILE\n"
+msgstr ""
+
+#: gcov.c:487
+#, c-format
+msgid "  -p, --preserve-paths            Preserve all pathname components\n"
+msgstr ""
+
+#: gcov.c:488
+#, c-format
+msgid "  -r, --relative-only             Only show data for relative sources\n"
+msgstr ""
+
+#: gcov.c:489
+#, c-format
+msgid "  -s, --source-prefix DIR         Source prefix to elide\n"
+msgstr ""
+
+#: gcov.c:490
+#, c-format
+msgid "  -u, --unconditional-branches    Show unconditional branch counts too\n"
+msgstr ""
+
+#: gcov.c:491
+#, c-format
+msgid "  -v, --version                   Print version number, then exit\n"
+msgstr ""
+
+#: gcov.c:502
+#, c-format
+msgid "gcov %s%s\n"
+msgstr ""
+
+#: gcov.c:794
+#, c-format
+msgid "Creating '%s'\n"
+msgstr ""
+
+#: gcov.c:797
+#, c-format
+msgid "Error writing output file '%s'\n"
+msgstr ""
+
+#: gcov.c:801
+#, c-format
+msgid "Could not open output file '%s'\n"
+msgstr ""
+
+#: gcov.c:806
+#, c-format
+msgid "Removing '%s'\n"
+msgstr "Вилучаємо «%s»\n"
+
+#: gcov.c:834 gcov.c:890
+#, c-format
+msgid "\n"
+msgstr "\n"
+
+#: gcov.c:856
+#, c-format
+msgid "Cannot open intermediate output file %s\n"
+msgstr ""
+
+#: gcov.c:1139
+#, c-format
+msgid "%s:source file is newer than notes file '%s'\n"
+msgstr ""
+
+#: gcov.c:1144
+#, c-format
+msgid "(the message is displayed only once per source file)\n"
+msgstr ""
+
+#: gcov.c:1169
+#, c-format
+msgid "%s:cannot open notes file\n"
+msgstr ""
+
+#: gcov.c:1175
+#, c-format
+msgid "%s:not a gcov notes file\n"
+msgstr ""
+
+#: gcov.c:1188
+#, c-format
+msgid "%s:version '%.4s', prefer '%.4s'\n"
+msgstr ""
+
+#: gcov.c:1234
+#, c-format
+msgid "%s:already seen blocks for '%s'\n"
+msgstr ""
+
+#: gcov.c:1365
+#, c-format
+msgid "%s:corrupted\n"
+msgstr ""
+
+#: gcov.c:1372
+#, c-format
+msgid "%s:no functions found\n"
+msgstr ""
+
+#: gcov.c:1391
+#, c-format
+msgid "%s:cannot open data file, assuming not executed\n"
+msgstr ""
+
+#: gcov.c:1398
+#, c-format
+msgid "%s:not a gcov data file\n"
+msgstr ""
+
+#: gcov.c:1411
+#, c-format
+msgid "%s:version '%.4s', prefer version '%.4s'\n"
+msgstr ""
+
+#: gcov.c:1417
+#, c-format
+msgid "%s:stamp mismatch with notes file\n"
+msgstr ""
+
+#: gcov.c:1452
+#, c-format
+msgid "%s:unknown function '%u'\n"
+msgstr "%s:невідома функція «%u»\n"
+
+#: gcov.c:1466
+#, c-format
+msgid "%s:profile mismatch for '%s'\n"
+msgstr "%s:невідповідність профілів для «%s»\n"
+
+#: gcov.c:1485
+#, c-format
+msgid "%s:overflowed\n"
+msgstr "%s:переповнено\n"
+
+#: gcov.c:1531
+#, c-format
+msgid "%s:'%s' lacks entry and/or exit blocks\n"
+msgstr ""
+
+#: gcov.c:1536
+#, c-format
+msgid "%s:'%s' has arcs to entry block\n"
+msgstr ""
+
+#: gcov.c:1544
+#, c-format
+msgid "%s:'%s' has arcs from exit block\n"
+msgstr ""
+
+#: gcov.c:1752
+#, c-format
+msgid "%s:graph is unsolvable for '%s'\n"
+msgstr ""
+
+#: gcov.c:1860
+#, c-format
+msgid "Lines executed:%s of %d\n"
+msgstr "Виконаних рядків:%s з %d\n"
+
+#: gcov.c:1863
+#, c-format
+msgid "No executable lines\n"
+msgstr "Немає виконуваних рядків\n"
+
+#: gcov.c:1871
+#, c-format
+msgid "%s '%s'\n"
+msgstr "%s «%s»\n"
+
+#: gcov.c:1878
+#, c-format
+msgid "Branches executed:%s of %d\n"
+msgstr ""
+
+#: gcov.c:1882
+#, c-format
+msgid "Taken at least once:%s of %d\n"
+msgstr ""
+
+#: gcov.c:1888
+#, c-format
+msgid "No branches\n"
+msgstr ""
+
+#: gcov.c:1890
+#, c-format
+msgid "Calls executed:%s of %d\n"
+msgstr ""
+
+#: gcov.c:1894
+#, c-format
+msgid "No calls\n"
+msgstr ""
+
+#: gcov.c:2142
+#, c-format
+msgid "%s:no lines for '%s'\n"
+msgstr ""
+
+#: gcov.c:2336
+#, c-format
+msgid "call   %2d returned %s\n"
+msgstr ""
+
+#: gcov.c:2341
+#, c-format
+msgid "call   %2d never executed\n"
+msgstr ""
+
+#: gcov.c:2346
+#, c-format
+msgid "branch %2d taken %s%s\n"
+msgstr ""
+
+#: gcov.c:2351
+#, c-format
+msgid "branch %2d never executed\n"
+msgstr ""
+
+#: gcov.c:2356
+#, c-format
+msgid "unconditional %2d taken %s\n"
+msgstr ""
+
+#: gcov.c:2359
+#, c-format
+msgid "unconditional %2d never executed\n"
+msgstr ""
+
+#: gcov.c:2424
+#, c-format
+msgid "Cannot open source file %s\n"
+msgstr ""
+
+#: gcse.c:2601
+msgid "PRE disabled"
+msgstr ""
+
+#: gcse.c:3529
+msgid "GCSE disabled"
+msgstr ""
+
+#: gimple-ssa-isolate-paths.c:441 c/c-typeck.c:9507
+#, gcc-internal-format
+msgid "function returns address of local variable"
+msgstr ""
+
+#: gimple-ssa-isolate-paths.c:443 gimple-ssa-isolate-paths.c:316
+#, gcc-internal-format
+msgid "function may return address of local variable"
+msgstr ""
+
+#: incpath.c:74
+#, c-format
+msgid "ignoring duplicate directory \"%s\"\n"
+msgstr ""
+
+#: incpath.c:77
+#, c-format
+msgid "  as it is a non-system directory that duplicates a system directory\n"
+msgstr ""
+
+#: incpath.c:81
+#, c-format
+msgid "ignoring nonexistent directory \"%s\"\n"
+msgstr ""
+
+#: incpath.c:375
+#, c-format
+msgid "#include \"...\" search starts here:\n"
+msgstr ""
+
+#: incpath.c:379
+#, c-format
+msgid "#include <...> search starts here:\n"
+msgstr ""
+
+#: incpath.c:384
+#, c-format
+msgid "End of search list.\n"
+msgstr ""
+
+#. Opening quotation mark.
+#: intl.c:62
+msgid "`"
+msgstr ""
+
+#. Closing quotation mark.
+#: intl.c:65
+msgid "'"
+msgstr ""
+
+#: ipa-pure-const.c:218
+msgid "function might be candidate for attribute %<%s%>"
+msgstr ""
+
+#: ipa-pure-const.c:219
+msgid "function might be candidate for attribute %<%s%> if it is known to return normally"
+msgstr ""
+
+#: langhooks.c:402
+msgid "At top level:"
+msgstr ""
+
+#: langhooks.c:422 cp/error.c:3252
+#, c-format
+msgid "In member function %qs"
+msgstr ""
+
+#: langhooks.c:426 cp/error.c:3255
+#, c-format
+msgid "In function %qs"
+msgstr ""
+
+#: langhooks.c:477 cp/error.c:3205
+msgid "    inlined from %qs at %r%s:%d:%d%R"
+msgstr ""
+
+#: langhooks.c:482 cp/error.c:3210
+msgid "    inlined from %qs at %r%s:%d%R"
+msgstr ""
+
+#: langhooks.c:488 cp/error.c:3216
+#, c-format
+msgid "    inlined from %qs"
+msgstr ""
+
+#: loop-iv.c:3098 tree-ssa-loop-niter.c:2066
+msgid "assuming that the loop is not infinite"
+msgstr ""
+
+#: loop-iv.c:3099 tree-ssa-loop-niter.c:2067
+msgid "cannot optimize possibly infinite loops"
+msgstr ""
+
+#: loop-iv.c:3107 tree-ssa-loop-niter.c:2071
+msgid "assuming that the loop counter does not overflow"
+msgstr ""
+
+#: loop-iv.c:3108 tree-ssa-loop-niter.c:2072
+msgid "cannot optimize loop, the loop counter may overflow"
+msgstr ""
+
+#: lra-assigns.c:1428 reload1.c:2143
+msgid "this is the insn:"
+msgstr ""
+
+#: lra-constraints.c:3495 reload.c:3862
+msgid "unable to generate reloads for:"
+msgstr ""
+
+#. What to print when a switch has no documentation.
+#: opts.c:187
+msgid "This switch lacks documentation"
+msgstr "Цей перемикач не документовано"
+
+#: opts.c:1014
+#, c-format
+msgid "default %d minimum %d maximum %d"
+msgstr "типово: %d мінімум: %d максимум: %d"
+
+#: opts.c:1121
+msgid "[default]"
+msgstr "[типовий]"
+
+#: opts.c:1132
+msgid "[enabled]"
+msgstr "[увімкнено]"
+
+#: opts.c:1132
+msgid "[disabled]"
+msgstr "[вимкнено]"
+
+#: opts.c:1151
+#, c-format
+msgid " No options with the desired characteristics were found\n"
+msgstr ""
+
+#: opts.c:1160
+#, c-format
+msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end\n"
+msgstr ""
+
+#: opts.c:1166
+#, c-format
+msgid " All options with the desired characteristics have already been displayed\n"
+msgstr ""
+
+#: opts.c:1251
+msgid "The following options are target specific"
+msgstr ""
+
+#: opts.c:1254
+msgid "The following options control compiler warning messages"
+msgstr ""
+
+#: opts.c:1257
+msgid "The following options control optimizations"
+msgstr ""
+
+#: opts.c:1260 opts.c:1299
+msgid "The following options are language-independent"
+msgstr ""
+
+#: opts.c:1263
+msgid "The --param option recognizes the following as parameters"
+msgstr ""
+
+#: opts.c:1269
+msgid "The following options are specific to just the language "
+msgstr ""
+
+#: opts.c:1271
+msgid "The following options are supported by the language "
+msgstr ""
+
+#: opts.c:1282
+msgid "The following options are not documented"
+msgstr ""
+
+#: opts.c:1284
+msgid "The following options take separate arguments"
+msgstr ""
+
+#: opts.c:1286
+msgid "The following options take joined arguments"
+msgstr ""
+
+#: opts.c:1297
+msgid "The following options are language-related"
+msgstr ""
+
+#: plugin.c:806
+msgid "Event"
+msgstr "Подія"
+
+#: plugin.c:806
+msgid "Plugins"
+msgstr "Додатки"
+
+#: plugin.c:838
+#, c-format
+msgid "*** WARNING *** there are active plugins, do not report this as a bug unless you can reproduce it without enabling any plugins.\n"
+msgstr ""
+
+#. It's the compiler's fault.
+#: reload1.c:6170
+msgid "could not find a spill register"
+msgstr ""
+
+#. It's the compiler's fault.
+#: reload1.c:8067
+msgid "VOIDmode on an output"
+msgstr ""
+
+#: reload1.c:8830
+msgid "failure trying to reload:"
+msgstr ""
+
+#: rtl-error.c:118
+msgid "unrecognizable insn:"
+msgstr ""
+
+#: rtl-error.c:120
+msgid "insn does not satisfy its constraints:"
+msgstr ""
+
+#: targhooks.c:1659
+#, c-format
+msgid "created and used with differing settings of '%s'"
+msgstr ""
+
+#: targhooks.c:1674
+msgid "created and used with different settings of -fpic"
+msgstr ""
+
+#: targhooks.c:1676
+msgid "created and used with different settings of -fpie"
+msgstr ""
+
+#: tlink.c:389
+#, c-format
+msgid "collect: reading %s\n"
+msgstr ""
+
+#: tlink.c:545
+#, c-format
+msgid "collect: recompiling %s\n"
+msgstr ""
+
+#: tlink.c:629
+#, c-format
+msgid "collect: tweaking %s in %s\n"
+msgstr ""
+
+#: tlink.c:846
+#, c-format
+msgid "collect: relinking\n"
+msgstr ""
+
+#: toplev.c:379
+#, c-format
+msgid "unrecoverable error"
+msgstr "критична помилка"
+
+#: toplev.c:747
+#, c-format
+msgid ""
+"%s%s%s %sversion %s (%s)\n"
+"%s\tcompiled by GNU C version %s, "
+msgstr ""
+
+#: toplev.c:749
+#, c-format
+msgid "%s%s%s %sversion %s (%s) compiled by CC, "
+msgstr ""
+
+#: toplev.c:753
+#, c-format
+msgid "GMP version %s, MPFR version %s, MPC version %s\n"
+msgstr ""
+
+#: toplev.c:755
+#, c-format
+msgid "%s%swarning: %s header version %s differs from library version %s.\n"
+msgstr ""
+
+#: toplev.c:757
+#, c-format
+msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
+msgstr ""
+
+#: toplev.c:923
+msgid "options passed: "
+msgstr ""
+
+#: toplev.c:951
+msgid "options enabled: "
+msgstr ""
+
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
+#: cp/error.c:1006 c-family/c-pretty-print.c:443
+#, gcc-internal-format
+msgid "<anonymous>"
+msgstr ""
+
+#: cif-code.def:39
+msgid "function not considered for inlining"
+msgstr ""
+
+#: cif-code.def:43
+msgid "caller is not optimized"
+msgstr ""
+
+#: cif-code.def:47
+msgid "function body not available"
+msgstr ""
+
+#: cif-code.def:51
+msgid "redefined extern inline functions are not considered for inlining"
+msgstr ""
+
+#: cif-code.def:56
+msgid "function not inlinable"
+msgstr ""
+
+#: cif-code.def:60
+msgid "function body can be overwritten at link time"
+msgstr ""
+
+#: cif-code.def:64
+msgid "function not inline candidate"
+msgstr ""
+
+#: cif-code.def:68
+msgid "--param large-function-growth limit reached"
+msgstr ""
+
+#: cif-code.def:70
+msgid "--param large-stack-frame-growth limit reached"
+msgstr ""
+
+#: cif-code.def:72
+msgid "--param max-inline-insns-single limit reached"
+msgstr ""
+
+#: cif-code.def:74
+msgid "--param max-inline-insns-auto limit reached"
+msgstr ""
+
+#: cif-code.def:76
+msgid "--param inline-unit-growth limit reached"
+msgstr ""
+
+#: cif-code.def:80
+msgid "recursive inlining"
+msgstr ""
+
+#: cif-code.def:84
+msgid "call is unlikely and code size would grow"
+msgstr ""
+
+#: cif-code.def:88
+msgid "function not declared inline and code size would grow"
+msgstr ""
+
+#: cif-code.def:92
+msgid "mismatched arguments"
+msgstr ""
+
+#: cif-code.def:96
+msgid "originally indirect function call not considered for inlining"
+msgstr ""
+
+#: cif-code.def:100
+msgid "indirect function call with a yet undetermined callee"
+msgstr ""
+
+#: cif-code.def:104
+msgid "exception handling personality mismatch"
+msgstr ""
+
+#: cif-code.def:109
+msgid "non-call exception handling mismatch"
+msgstr ""
+
+#: cif-code.def:113
+msgid "target specific option mismatch"
+msgstr ""
+
+#: cif-code.def:117
+msgid "optimization level attribute mismatch"
+msgstr ""
+
+#: cif-code.def:121
+msgid "callee refers to comdat-local symbols"
+msgstr ""
+
+#: cif-code.def:125
+msgid "function attribute mismatch"
+msgstr "невідповідність атрибутів функції"
+
+#: cif-code.def:129
+msgid "caller function contains cilk spawn"
+msgstr ""
+
+#: cif-code.def:133
+msgid "unreachable"
+msgstr "недоступний"
+
+#. The remainder are real diagnostic types.
+#: diagnostic.def:33
+msgid "fatal error: "
+msgstr "критична помилка: "
+
+#. This is like DK_ICE, but backtrace is not printed.  Used in the driver
+#. when reporting fatal signal in the compiler.
+#: diagnostic.def:34 diagnostic.def:50
+msgid "internal compiler error: "
+msgstr "внутрішня помилка компілятора: "
+
+#. This one is just for counting DK_WARNING promoted to DK_ERROR
+#. due to -Werror and -Werror=warning.
+#: diagnostic.def:35 diagnostic.def:47
+msgid "error: "
+msgstr "помилка: "
+
+#: diagnostic.def:36
+msgid "sorry, unimplemented: "
+msgstr "вибачте, не реалізовано: "
+
+#: diagnostic.def:37
+msgid "warning: "
+msgstr "попередження: "
+
+#: diagnostic.def:38
+msgid "anachronism: "
+msgstr "анахронізм: "
+
+#: diagnostic.def:39
+msgid "note: "
+msgstr "зауваження: "
+
+#: diagnostic.def:40
+msgid "debug: "
+msgstr "діагностика: "
+
+#. These two would be re-classified as DK_WARNING or DK_ERROR, so the
+#. prefix does not matter.
+#: diagnostic.def:43
+msgid "pedwarn: "
+msgstr "педантичне попередження: "
+
+#: diagnostic.def:44
+msgid "permerror: "
+msgstr "постійна помилка: "
+
+#: params.def:44
+msgid "Maximal estimated outcome of branch considered predictable"
+msgstr ""
+
+#: params.def:49
+msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-isnsns-auto"
+msgstr ""
+
+#: params.def:66
+msgid "The maximum number of instructions in a single function eligible for inlining"
+msgstr ""
+
+#: params.def:78
+msgid "The maximum number of instructions when automatically inlining"
+msgstr ""
+
+#: params.def:83
+msgid "The maximum number of instructions inline function can grow to via recursive inlining"
+msgstr ""
+
+#: params.def:88
+msgid "The maximum number of instructions non-inline function can grow to via recursive inlining"
+msgstr ""
+
+#: params.def:93
+msgid "The maximum depth of recursive inlining for inline functions"
+msgstr ""
+
+#: params.def:98
+msgid "The maximum depth of recursive inlining for non-inline functions"
+msgstr ""
+
+#: params.def:103
+msgid "Inline recursively only when the probability of call being executed exceeds the parameter"
+msgstr ""
+
+#: params.def:111
+msgid "The maximum number of nested indirect inlining performed by early inliner"
+msgstr ""
+
+#: params.def:117
+msgid "Probability that COMDAT function will be shared with different compilation unit"
+msgstr ""
+
+#: params.def:123
+msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen"
+msgstr ""
+
+#: params.def:130
+msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling"
+msgstr ""
+
+#: params.def:136
+msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization"
+msgstr ""
+
+#: params.def:147
+msgid "The maximum number of instructions to consider to fill a delay slot"
+msgstr ""
+
+#: params.def:158
+msgid "The maximum number of instructions to consider to find accurate live register information"
+msgstr ""
+
+#: params.def:168
+msgid "The maximum length of scheduling's pending operations list"
+msgstr ""
+
+#: params.def:175
+msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop"
+msgstr ""
+
+#: params.def:180
+msgid "The size of function body to be considered large"
+msgstr ""
+
+#: params.def:184
+msgid "Maximal growth due to inlining of large function (in percent)"
+msgstr ""
+
+#: params.def:188
+msgid "The size of translation unit to be considered large"
+msgstr ""
+
+#: params.def:192
+msgid "How much can given compilation unit grow because of the inlining (in percent)"
+msgstr ""
+
+#: params.def:196
+msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)"
+msgstr ""
+
+#: params.def:200
+msgid "Maximal estimated growth of function body caused by early inlining of single call"
+msgstr ""
+
+#: params.def:204
+msgid "The size of stack frame to be considered large"
+msgstr ""
+
+#: params.def:208
+msgid "Maximal stack frame growth due to inlining (in percent)"
+msgstr ""
+
+#: params.def:215
+msgid "The maximum amount of memory to be allocated by GCSE"
+msgstr ""
+
+#: params.def:222
+msgid "The maximum ratio of insertions to deletions of expressions in GCSE"
+msgstr ""
+
+#: params.def:233
+msgid "The threshold ratio for performing partial redundancy elimination after reload"
+msgstr ""
+
+#: params.def:240
+msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload"
+msgstr ""
+
+#: params.def:248
+msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations"
+msgstr ""
+
+#: params.def:254
+msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel"
+msgstr ""
+
+#: params.def:262
+msgid "Maximum depth of search in the dominator tree for expressions to hoist"
+msgstr ""
+
+#: params.def:274
+msgid "The maximum number of instructions to consider to unroll in a loop"
+msgstr ""
+
+#: params.def:280
+msgid "The maximum number of instructions to consider to unroll in a loop on average"
+msgstr ""
+
+#: params.def:285
+msgid "The maximum number of unrollings of a single loop"
+msgstr ""
+
+#: params.def:290
+msgid "The maximum number of insns of a peeled loop"
+msgstr ""
+
+#: params.def:295
+msgid "The maximum number of peelings of a single loop"
+msgstr ""
+
+#: params.def:300
+msgid "The maximum number of branches on the path through the peeled sequence"
+msgstr ""
+
+#: params.def:305
+msgid "The maximum number of insns of a completely peeled loop"
+msgstr ""
+
+#: params.def:310
+msgid "The maximum number of peelings of a single loop that is peeled completely"
+msgstr ""
+
+#: params.def:315
+msgid "The maximum number of insns of a peeled loop that rolls only once"
+msgstr ""
+
+#: params.def:320
+msgid "The maximum depth of a loop nest we completely peel"
+msgstr ""
+
+#: params.def:326
+msgid "The maximum number of insns of an unswitched loop"
+msgstr ""
+
+#: params.def:331
+msgid "The maximum number of unswitchings in a single loop"
+msgstr ""
+
+#: params.def:338
+msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates"
+msgstr ""
+
+#: params.def:344
+msgid "Bound on the cost of an expression to compute the number of iterations"
+msgstr ""
+
+#: params.def:350
+msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop"
+msgstr ""
+
+#: params.def:355
+msgid "The minimum value of stage count that swing modulo scheduler will generate."
+msgstr ""
+
+#: params.def:359
+msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA"
+msgstr ""
+
+#: params.def:363
+msgid "A threshold on the average loop count considered by the swing modulo scheduler"
+msgstr ""
+
+#: params.def:368
+msgid "A basic block profile count is considered hot if it contributes to the given permillage of the entire profiled execution"
+msgstr ""
+
+#: params.def:373
+msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot"
+msgstr ""
+
+#: params.def:378
+msgid "The minimum fraction of profile runs a given basic block execution count must be not to be considered unlikely"
+msgstr ""
+
+#: params.def:383
+msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block get alignment"
+msgstr ""
+
+#: params.def:388
+msgid "Loops iterating at least selected number of iterations will get loop alignement."
+msgstr ""
+
+#: params.def:404
+msgid "The maximum number of loop iterations we predict statically"
+msgstr ""
+
+#: params.def:417
+#, c-format
+msgid "Set the estimated probability in percentage for builtin expect. The default value is 90% probability."
+msgstr ""
+
+#: params.def:421
+msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available"
+msgstr ""
+
+#: params.def:425
+msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available"
+msgstr ""
+
+#: params.def:429
+msgid "Maximal code growth caused by tail duplication (in percent)"
+msgstr ""
+
+#: params.def:433
+msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)"
+msgstr ""
+
+#: params.def:437
+msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available"
+msgstr ""
+
+#: params.def:441
+msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available"
+msgstr ""
+
+#: params.def:447
+msgid "The maximum number of incoming edges to consider for crossjumping"
+msgstr ""
+
+#: params.def:453
+msgid "The minimum number of matching instructions to consider for crossjumping"
+msgstr ""
+
+#: params.def:459
+msgid "The maximum expansion factor when copying basic blocks"
+msgstr ""
+
+#: params.def:465
+msgid "The maximum number of insns to duplicate when unfactoring computed gotos"
+msgstr ""
+
+#: params.def:471
+msgid "The maximum length of path considered in cse"
+msgstr ""
+
+#: params.def:475
+msgid "The maximum instructions CSE process before flushing"
+msgstr ""
+
+#: params.def:482
+msgid "The minimum cost of an expensive expression in the loop invariant motion"
+msgstr ""
+
+#: params.def:491
+msgid "Bound on number of candidates below that all candidates are considered in iv optimizations"
+msgstr ""
+
+#: params.def:499
+msgid "Bound on number of iv uses in loop optimized in iv optimizations"
+msgstr ""
+
+#: params.def:507
+msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization"
+msgstr ""
+
+#: params.def:512
+msgid "Bound on size of expressions used in the scalar evolutions analyzer"
+msgstr ""
+
+#: params.def:517
+msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer"
+msgstr ""
+
+#: params.def:522
+msgid "Bound on the number of variables in Omega constraint systems"
+msgstr ""
+
+#: params.def:527
+msgid "Bound on the number of inequalities in Omega constraint systems"
+msgstr ""
+
+#: params.def:532
+msgid "Bound on the number of equalities in Omega constraint systems"
+msgstr ""
+
+#: params.def:537
+msgid "Bound on the number of wild cards in Omega constraint systems"
+msgstr ""
+
+#: params.def:542
+msgid "Bound on the size of the hash table in Omega constraint systems"
+msgstr ""
+
+#: params.def:547
+msgid "Bound on the number of keys in Omega constraint systems"
+msgstr ""
+
+#: params.def:552
+msgid "When set to 1, use expensive methods to eliminate all redundant constraints"
+msgstr ""
+
+#: params.def:557
+msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check"
+msgstr ""
+
+#: params.def:562
+msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check"
+msgstr ""
+
+#: params.def:567
+msgid "Max number of loop peels to enhancement alignment of data references in a loop"
+msgstr ""
+
+#: params.def:572
+msgid "The maximum memory locations recorded by cselib"
+msgstr ""
+
+#: params.def:585
+msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap"
+msgstr ""
+
+#: params.def:590
+msgid "Minimum heap size before we start collecting garbage, in kilobytes"
+msgstr ""
+
+#: params.def:598
+msgid "The maximum number of instructions to search backward when looking for equivalent reload"
+msgstr ""
+
+#: params.def:603
+msgid "Target block's relative execution frequency (as a percentage) required to sink a statement"
+msgstr ""
+
+#: params.def:608 params.def:618
+msgid "The maximum number of blocks in a region to be considered for interblock scheduling"
+msgstr ""
+
+#: params.def:613 params.def:623
+msgid "The maximum number of insns in a region to be considered for interblock scheduling"
+msgstr ""
+
+#: params.def:628
+msgid "The minimum probability of reaching a source block for interblock speculative scheduling"
+msgstr ""
+
+#: params.def:633
+msgid "The maximum number of iterations through CFG to extend regions"
+msgstr ""
+
+#: params.def:638
+msgid "The maximum conflict delay for an insn to be considered for speculative motion"
+msgstr ""
+
+#: params.def:643
+msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
+msgstr ""
+
+#: params.def:648
+msgid "The minimum probability an edge must have for the scheduler to save its state across it."
+msgstr ""
+
+#: params.def:653
+msgid "The maximum size of the lookahead window of selective scheduling"
+msgstr ""
+
+#: params.def:658
+msgid "Maximum number of times that an insn could be scheduled"
+msgstr ""
+
+#: params.def:663
+msgid "Maximum number of instructions in the ready list that are considered eligible for renaming"
+msgstr ""
+
+#: params.def:668
+msgid "Minimal distance between possibly conflicting store and load"
+msgstr ""
+
+#: params.def:673
+msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into; at '0' only enable instruction sorting heuristic.  Disabled by default."
+msgstr ""
+
+#: params.def:678
+msgid "The maximum number of RTL nodes that can be recorded as combiner's last value"
+msgstr ""
+
+#: params.def:683
+msgid "The maximum number of insns combine tries to combine"
+msgstr ""
+
+#: params.def:692
+msgid "The upper bound for sharing integer constants"
+msgstr ""
+
+#: params.def:697
+msgid "The lower bound for a buffer to be considered for stack smashing protection"
+msgstr ""
+
+#: params.def:702
+msgid "The minimum size of variables taking part in stack slot sharing when not optimizing"
+msgstr ""
+
+#: params.def:721
+msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps"
+msgstr ""
+
+#: params.def:730
+msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable"
+msgstr ""
+
+#: params.def:735
+msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass"
+msgstr ""
+
+#: params.def:741
+msgid "Maximum number of active local stores in RTL dead store elimination"
+msgstr ""
+
+#: params.def:751
+msgid "The number of insns executed before prefetch is completed"
+msgstr ""
+
+#: params.def:758
+msgid "The number of prefetches that can run at the same time"
+msgstr ""
+
+#: params.def:765
+msgid "The size of L1 cache"
+msgstr ""
+
+#: params.def:772
+msgid "The size of L1 cache line"
+msgstr ""
+
+#: params.def:779
+msgid "The size of L2 cache"
+msgstr ""
+
+#: params.def:790
+msgid "Whether to use canonical types"
+msgstr ""
+
+#: params.def:795
+msgid "Maximum length of partial antic set when performing tree pre optimization"
+msgstr ""
+
+#: params.def:805
+msgid "Maximum size of a SCC before SCCVN stops processing a function"
+msgstr ""
+
+#: params.def:816
+msgid "Maximum number of disambiguations to perform per memory access"
+msgstr ""
+
+#: params.def:821
+msgid "Max loops number for regional RA"
+msgstr ""
+
+#: params.def:826
+msgid "Max size of conflict table in MB"
+msgstr ""
+
+#: params.def:831
+msgid "The number of registers in each class kept unused by loop invariant motion"
+msgstr ""
+
+#: params.def:836
+msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo"
+msgstr ""
+
+#: params.def:841
+msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA"
+msgstr ""
+
+#: params.def:849
+msgid "The maximum ratio between array size and switch branches for a switch conversion to take place"
+msgstr ""
+
+#: params.def:857
+msgid "size of tiles for loop blocking"
+msgstr ""
+
+#: params.def:864
+msgid "size of unrolling factor for unroll-and-jam"
+msgstr ""
+
+#: params.def:871
+msgid "depth of unrolled loop for unroll-and-jam"
+msgstr ""
+
+#: params.def:879
+msgid "maximum number of parameters in a SCoP"
+msgstr ""
+
+#: params.def:886
+msgid "maximum number of basic blocks per function to be analyzed by Graphite"
+msgstr ""
+
+#: params.def:892
+msgid "Maximum number of datarefs in loop for building loop data dependencies"
+msgstr ""
+
+#: params.def:899
+msgid "Max basic blocks number in loop for loop invariant motion"
+msgstr ""
+
+#: params.def:907
+msgid "use internal function id in profile lookup"
+msgstr ""
+
+#: params.def:915
+msgid "track topn target addresses in indirect-call profile"
+msgstr ""
+
+#: params.def:921
+msgid "Maximum number of instructions in basic block to be considered for SLP vectorization"
+msgstr ""
+
+#: params.def:926
+msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count"
+msgstr ""
+
+#: params.def:932
+msgid "Min. ratio of insns to mem ops to enable prefetching in a loop"
+msgstr ""
+
+#: params.def:939
+msgid "Max. size of var tracking hash tables"
+msgstr ""
+
+#: params.def:947
+msgid "Max. recursion depth for expanding var tracking expressions"
+msgstr ""
+
+#: params.def:955
+msgid "Max. size of loc list for which reverse ops should be added"
+msgstr ""
+
+#: params.def:962
+msgid "The minimum UID to be used for a nondebug insn"
+msgstr ""
+
+#: params.def:967
+msgid "Maximum allowed growth of size of new parameters ipa-sra replaces a pointer to an aggregate with"
+msgstr ""
+
+#: params.def:973
+msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs"
+msgstr ""
+
+#: params.def:980
+msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed"
+msgstr ""
+
+#: params.def:986
+msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size"
+msgstr ""
+
+#: params.def:992
+msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation"
+msgstr ""
+
+#: params.def:998
+msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
+msgstr ""
+
+#: params.def:1004
+msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
+msgstr ""
+
+#: params.def:1010
+msgid "Percentage penalty functions containg a single call to another function will receive when they are evaluated for cloning."
+msgstr ""
+
+#: params.def:1016
+msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices"
+msgstr ""
+
+#: params.def:1022
+msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
+msgstr ""
+
+#: params.def:1028
+msgid "Compile-time bonus IPA-CP assigns to candidates which make an array index known."
+msgstr ""
+
+#: params.def:1034
+msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function"
+msgstr ""
+
+#: params.def:1042
+msgid "Number of partitions the program should be split to"
+msgstr ""
+
+#: params.def:1047
+msgid "Minimal size of a partition for LTO (in estimated instructions)"
+msgstr ""
+
+#: params.def:1054
+msgid "Maximum number of namespaces to search for alternatives when name lookup fails"
+msgstr ""
+
+#: params.def:1061
+msgid "Maximum number of conditional store pairs that can be sunk"
+msgstr ""
+
+#: params.def:1069
+msgid "The smallest number of different values for which it is best to use a jump-table instead of a tree of conditional branches, if 0, use the default for the machine"
+msgstr ""
+
+#: params.def:1077
+msgid "Allow new data races on stores to be introduced"
+msgstr ""
+
+#: params.def:1083
+msgid "Set the maximum number of instructions executed in parallel in reassociated tree. If 0, use the target dependent heuristic."
+msgstr ""
+
+#: params.def:1089
+msgid "Maximum amount of similar bbs to compare a bb with"
+msgstr ""
+
+#: params.def:1094
+msgid "Maximum amount of iterations of the pass over a function"
+msgstr ""
+
+#: params.def:1101
+msgid "Maximum number of strings for which strlen optimization pass will track string lengths"
+msgstr ""
+
+#: params.def:1108
+msgid "Which -fsched-pressure algorithm to apply"
+msgstr ""
+
+#: params.def:1114
+msgid "Maximum length of candidate scans for straight-line strength reduction"
+msgstr ""
+
+#: params.def:1120
+msgid "Enable asan stack protection"
+msgstr ""
+
+#: params.def:1125
+msgid "Enable asan globals protection"
+msgstr ""
+
+#: params.def:1130
+msgid "Enable asan store operations protection"
+msgstr ""
+
+#: params.def:1135
+msgid "Enable asan load operations protection"
+msgstr ""
+
+#: params.def:1140
+msgid "Enable asan builtin functions protection"
+msgstr ""
+
+#: params.def:1145
+msgid "Enable asan detection of use-after-return bugs"
+msgstr ""
+
+#: params.def:1150
+msgid "Use callbacks instead of inline code if number of accesses in function becomes greater or equal to this number"
+msgstr ""
+
+#: params.def:1156
+msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis"
+msgstr ""
+
+#: params.def:1162
+msgid "Maximum number of statements to be included into a single static constructor generated by Pointer Bounds Checker"
+msgstr ""
+
+#: params.def:1168
+msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path"
+msgstr ""
+
+#: params.def:1173
+msgid "Maximum number of basic blocks on a finite state automaton jump thread path"
+msgstr ""
+
+#: params.def:1178
+msgid "Maximum number of new jump thread paths to create for a finite state automaton"
+msgstr ""
+
+#: c-family/c-format.c:356
+msgid "format"
+msgstr "формат"
+
+#: c-family/c-format.c:357
+msgid "field width specifier"
+msgstr ""
+
+#: c-family/c-format.c:358
+msgid "field precision specifier"
+msgstr ""
+
+#: c-family/c-format.c:472 c-family/c-format.c:496 config/i386/msformat-c.c:56
+msgid "' ' flag"
+msgstr "прапорець ' '"
+
+#: c-family/c-format.c:472 c-family/c-format.c:496 config/i386/msformat-c.c:56
+msgid "the ' ' printf flag"
+msgstr "прапорець printf ' '"
+
+#: c-family/c-format.c:473 c-family/c-format.c:497 c-family/c-format.c:527
+#: c-family/c-format.c:591 config/i386/msformat-c.c:57
+msgid "'+' flag"
+msgstr "прапорець '+'"
+
+#: c-family/c-format.c:473 c-family/c-format.c:497 c-family/c-format.c:527
+#: config/i386/msformat-c.c:57
+msgid "the '+' printf flag"
+msgstr ""
+
+#: c-family/c-format.c:474 c-family/c-format.c:498 c-family/c-format.c:528
+#: c-family/c-format.c:567 config/i386/msformat-c.c:58
+#: config/i386/msformat-c.c:93
+msgid "'#' flag"
+msgstr "прапорець '#'"
+
+#: c-family/c-format.c:474 c-family/c-format.c:498 c-family/c-format.c:528
+#: config/i386/msformat-c.c:58
+msgid "the '#' printf flag"
+msgstr "прапорець printf '#'"
+
+#: c-family/c-format.c:475 c-family/c-format.c:499 c-family/c-format.c:565
+#: config/i386/msformat-c.c:59
+msgid "'0' flag"
+msgstr "прапорець '0'"
+
+#: c-family/c-format.c:475 c-family/c-format.c:499 config/i386/msformat-c.c:59
+msgid "the '0' printf flag"
+msgstr "прапорець printf '0'"
+
+#: c-family/c-format.c:476 c-family/c-format.c:500 c-family/c-format.c:564
+#: c-family/c-format.c:594 config/i386/msformat-c.c:60
+msgid "'-' flag"
+msgstr "прапорець '-'"
+
+#: c-family/c-format.c:476 c-family/c-format.c:500 config/i386/msformat-c.c:60
+msgid "the '-' printf flag"
+msgstr ""
+
+#: c-family/c-format.c:477 c-family/c-format.c:547 config/i386/msformat-c.c:61
+#: config/i386/msformat-c.c:81
+msgid "''' flag"
+msgstr "прапорець '''"
+
+#: c-family/c-format.c:477 config/i386/msformat-c.c:61
+msgid "the ''' printf flag"
+msgstr "прапорець printf '''"
+
+#: c-family/c-format.c:478 c-family/c-format.c:548
+msgid "'I' flag"
+msgstr "прапорець 'I'"
+
+#: c-family/c-format.c:478
+msgid "the 'I' printf flag"
+msgstr ""
+
+#: c-family/c-format.c:479 c-family/c-format.c:501 c-family/c-format.c:545
+#: c-family/c-format.c:568 c-family/c-format.c:595 config/sol2-c.c:56
+#: config/i386/msformat-c.c:62 config/i386/msformat-c.c:79
+msgid "field width"
+msgstr ""
+
+#: c-family/c-format.c:479 c-family/c-format.c:501 config/sol2-c.c:56
+#: config/i386/msformat-c.c:62
+msgid "field width in printf format"
+msgstr ""
+
+#: c-family/c-format.c:480 c-family/c-format.c:502 c-family/c-format.c:530
+#: config/i386/msformat-c.c:63
+msgid "precision"
+msgstr "точність"
+
+#: c-family/c-format.c:480 c-family/c-format.c:502 c-family/c-format.c:530
+#: config/i386/msformat-c.c:63
+msgid "precision in printf format"
+msgstr ""
+
+#: c-family/c-format.c:481 c-family/c-format.c:503 c-family/c-format.c:531
+#: c-family/c-format.c:546 c-family/c-format.c:598 config/sol2-c.c:57
+#: config/i386/msformat-c.c:64 config/i386/msformat-c.c:80
+msgid "length modifier"
+msgstr ""
+
+#: c-family/c-format.c:481 c-family/c-format.c:503 c-family/c-format.c:531
+#: config/sol2-c.c:57 config/i386/msformat-c.c:64
+msgid "length modifier in printf format"
+msgstr ""
+
+#: c-family/c-format.c:529
+msgid "'q' flag"
+msgstr ""
+
+#: c-family/c-format.c:529
+msgid "the 'q' diagnostic flag"
+msgstr ""
+
+#: c-family/c-format.c:542 config/i386/msformat-c.c:77
+msgid "assignment suppression"
+msgstr ""
+
+#: c-family/c-format.c:542 config/i386/msformat-c.c:77
+msgid "the assignment suppression scanf feature"
+msgstr ""
+
+#: c-family/c-format.c:543 config/i386/msformat-c.c:78
+msgid "'a' flag"
+msgstr ""
+
+#: c-family/c-format.c:543 config/i386/msformat-c.c:78
+msgid "the 'a' scanf flag"
+msgstr ""
+
+#: c-family/c-format.c:544
+msgid "'m' flag"
+msgstr ""
+
+#: c-family/c-format.c:544
+msgid "the 'm' scanf flag"
+msgstr ""
+
+#: c-family/c-format.c:545 config/i386/msformat-c.c:79
+msgid "field width in scanf format"
+msgstr ""
+
+#: c-family/c-format.c:546 config/i386/msformat-c.c:80
+msgid "length modifier in scanf format"
+msgstr ""
+
+#: c-family/c-format.c:547 config/i386/msformat-c.c:81
+msgid "the ''' scanf flag"
+msgstr ""
+
+#: c-family/c-format.c:548
+msgid "the 'I' scanf flag"
+msgstr ""
+
+#: c-family/c-format.c:563
+msgid "'_' flag"
+msgstr "прапорець '_'"
+
+#: c-family/c-format.c:563
+msgid "the '_' strftime flag"
+msgstr ""
+
+#: c-family/c-format.c:564
+msgid "the '-' strftime flag"
+msgstr ""
+
+#: c-family/c-format.c:565
+msgid "the '0' strftime flag"
+msgstr ""
+
+#: c-family/c-format.c:566 c-family/c-format.c:590
+msgid "'^' flag"
+msgstr "прапорець '^'"
+
+#: c-family/c-format.c:566
+msgid "the '^' strftime flag"
+msgstr ""
+
+#: c-family/c-format.c:567 config/i386/msformat-c.c:93
+msgid "the '#' strftime flag"
+msgstr ""
+
+#: c-family/c-format.c:568
+msgid "field width in strftime format"
+msgstr ""
+
+#: c-family/c-format.c:569
+msgid "'E' modifier"
+msgstr ""
+
+#: c-family/c-format.c:569
+msgid "the 'E' strftime modifier"
+msgstr ""
+
+#: c-family/c-format.c:570
+msgid "'O' modifier"
+msgstr ""
+
+#: c-family/c-format.c:570
+msgid "the 'O' strftime modifier"
+msgstr ""
+
+#: c-family/c-format.c:571
+msgid "the 'O' modifier"
+msgstr ""
+
+#: c-family/c-format.c:589
+msgid "fill character"
+msgstr ""
+
+#: c-family/c-format.c:589
+msgid "fill character in strfmon format"
+msgstr ""
+
+#: c-family/c-format.c:590
+msgid "the '^' strfmon flag"
+msgstr ""
+
+#: c-family/c-format.c:591
+msgid "the '+' strfmon flag"
+msgstr "прапорець strfmon '+'"
+
+#: c-family/c-format.c:592
+msgid "'(' flag"
+msgstr "прапорець '('"
+
+#: c-family/c-format.c:592
+msgid "the '(' strfmon flag"
+msgstr "прапорець strfmon '('"
+
+#: c-family/c-format.c:593
+msgid "'!' flag"
+msgstr "прапорець '!'"
+
+#: c-family/c-format.c:593
+msgid "the '!' strfmon flag"
+msgstr ""
+
+#: c-family/c-format.c:594
+msgid "the '-' strfmon flag"
+msgstr ""
+
+#: c-family/c-format.c:595
+msgid "field width in strfmon format"
+msgstr ""
+
+#: c-family/c-format.c:596
+msgid "left precision"
+msgstr ""
+
+#: c-family/c-format.c:596
+msgid "left precision in strfmon format"
+msgstr ""
+
+#: c-family/c-format.c:597
+msgid "right precision"
+msgstr ""
+
+#: c-family/c-format.c:597
+msgid "right precision in strfmon format"
+msgstr ""
+
+#: c-family/c-format.c:598
+msgid "length modifier in strfmon format"
+msgstr ""
+
+#. Handle deferred options from command-line.
+#: c-family/c-opts.c:1324 fortran/cpp.c:605
+msgid "<command-line>"
+msgstr ""
+
+#: config/aarch64/aarch64.c:4058 config/arm/arm.c:21673 config/arm/arm.c:21686
+#: config/arm/arm.c:21711 config/nios2/nios2.c:2118
+#, c-format
+msgid "Unsupported operand for code '%c'"
+msgstr ""
+
+#: config/aarch64/aarch64.c:4070 config/aarch64/aarch64.c:4086
+#: config/aarch64/aarch64.c:4099 config/aarch64/aarch64.c:4111
+#: config/aarch64/aarch64.c:4122 config/aarch64/aarch64.c:4140
+#: config/aarch64/aarch64.c:4164 config/aarch64/aarch64.c:4215
+#: config/aarch64/aarch64.c:4412 config/aarch64/aarch64.c:4429
+#, c-format
+msgid "invalid operand for '%%%c'"
+msgstr ""
+
+#: config/aarch64/aarch64.c:4182 config/aarch64/aarch64.c:4195
+#: config/aarch64/aarch64.c:4205
+#, c-format
+msgid "incompatible floating point / vector register operand for '%%%c'"
+msgstr ""
+
+#: config/aarch64/aarch64.c:4251 config/arm/arm.c:22218
+#, c-format
+msgid "missing operand"
+msgstr "пропущено операнд"
+
+#: config/aarch64/aarch64.c:4315
+#, c-format
+msgid "invalid constant"
+msgstr "некоректна константа"
+
+#: config/aarch64/aarch64.c:4318
+#, c-format
+msgid "invalid operand"
+msgstr "некоректний операнд"
+
+#: config/aarch64/aarch64.c:4440
+#, c-format
+msgid "invalid operand prefix '%%%c'"
+msgstr ""
+
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
+#, c-format
+msgid "'%%&' used without any local dynamic TLS references"
+msgstr ""
+
+#: config/alpha/alpha.c:5213
+#, c-format
+msgid "invalid %%H value"
+msgstr ""
+
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
+#, c-format
+msgid "invalid %%J value"
+msgstr ""
+
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
+#, c-format
+msgid "invalid %%r value"
+msgstr ""
+
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
+#, c-format
+msgid "invalid %%R value"
+msgstr ""
+
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
+#: config/xtensa/xtensa.c:2358
+#, c-format
+msgid "invalid %%N value"
+msgstr ""
+
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
+#, c-format
+msgid "invalid %%P value"
+msgstr ""
+
+#: config/alpha/alpha.c:5296
+#, c-format
+msgid "invalid %%h value"
+msgstr ""
+
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
+#, c-format
+msgid "invalid %%L value"
+msgstr ""
+
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
+#, c-format
+msgid "invalid %%m value"
+msgstr ""
+
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
+#, c-format
+msgid "invalid %%M value"
+msgstr ""
+
+#: config/alpha/alpha.c:5395
+#, c-format
+msgid "invalid %%U value"
+msgstr ""
+
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
+#, c-format
+msgid "invalid %%s value"
+msgstr ""
+
+#: config/alpha/alpha.c:5425
+#, c-format
+msgid "invalid %%C value"
+msgstr ""
+
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
+#, c-format
+msgid "invalid %%E value"
+msgstr ""
+
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
+#, c-format
+msgid "unknown relocation unspec"
+msgstr ""
+
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
+#, c-format
+msgid "invalid %%xn code"
+msgstr ""
+
+#: config/alpha/alpha.c:5600
+#, c-format
+msgid "invalid operand address"
+msgstr ""
+
+#: config/arc/arc.c:2824
+#, c-format
+msgid "invalid operand to %%Z code"
+msgstr ""
+
+#: config/arc/arc.c:2832
+#, c-format
+msgid "invalid operand to %%z code"
+msgstr ""
+
+#: config/arc/arc.c:2840
+#, c-format
+msgid "invalid operand to %%M code"
+msgstr ""
+
+#: config/arc/arc.c:2986 config/m32r/m32r.c:2126
+#, c-format
+msgid "invalid operand to %%R code"
+msgstr ""
+
+#: config/arc/arc.c:3025 config/m32r/m32r.c:2149
+#, c-format
+msgid "invalid operand to %%H/%%L code"
+msgstr ""
+
+#: config/arc/arc.c:3073 config/m32r/m32r.c:2220
+#, c-format
+msgid "invalid operand to %%U code"
+msgstr ""
+
+#: config/arc/arc.c:3084
+#, c-format
+msgid "invalid operand to %%V code"
+msgstr ""
+
+#: config/arc/arc.c:3141
+#, c-format
+msgid "invalid operand to %%O code"
+msgstr ""
+
+#. Unknown flag.
+#. Undocumented flag.
+#: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
+#, c-format
+msgid "invalid operand output code"
+msgstr ""
+
+#: config/arc/arc.c:4719
+#, c-format
+msgid "invalid UNSPEC as operand: %d"
+msgstr ""
+
+#: config/arm/arm.c:18956 config/arm/arm.c:18981 config/arm/arm.c:18991
+#: config/arm/arm.c:19000 config/arm/arm.c:19008
+#, c-format
+msgid "invalid shift operand"
+msgstr ""
+
+#: config/arm/arm.c:21528 config/arm/arm.c:21546
+#, c-format
+msgid "predicated Thumb instruction"
+msgstr ""
+
+#: config/arm/arm.c:21534
+#, c-format
+msgid "predicated instruction in conditional sequence"
+msgstr ""
+
+#: config/arm/arm.c:21788 config/arm/arm.c:21810 config/arm/arm.c:21820
+#: config/arm/arm.c:21830 config/arm/arm.c:21840 config/arm/arm.c:21879
+#: config/arm/arm.c:21897 config/arm/arm.c:21922 config/arm/arm.c:21937
+#: config/arm/arm.c:21964 config/arm/arm.c:21971 config/arm/arm.c:21989
+#: config/arm/arm.c:21996 config/arm/arm.c:22004 config/arm/arm.c:22025
+#: config/arm/arm.c:22032 config/arm/arm.c:22165 config/arm/arm.c:22172
+#: config/arm/arm.c:22199 config/arm/arm.c:22206 config/bfin/bfin.c:1475
+#: config/bfin/bfin.c:1482 config/bfin/bfin.c:1489 config/bfin/bfin.c:1496
+#: config/bfin/bfin.c:1505 config/bfin/bfin.c:1512 config/bfin/bfin.c:1519
+#: config/bfin/bfin.c:1526
+#, c-format
+msgid "invalid operand for code '%c'"
+msgstr ""
+
+#: config/arm/arm.c:21892
+#, c-format
+msgid "instruction never executed"
+msgstr ""
+
+#. Former Maverick support, removed after GCC-4.7.
+#: config/arm/arm.c:21913
+#, c-format
+msgid "obsolete Maverick format code '%c'"
+msgstr ""
+
+#: config/arm/arm.c:23339
+msgid "function parameters cannot have __fp16 type"
+msgstr ""
+
+#: config/arm/arm.c:23349
+msgid "functions cannot return __fp16 type"
+msgstr ""
+
+#: config/avr/avr.c:2152
+#, c-format
+msgid "address operand requires constraint for X, Y, or Z register"
+msgstr ""
+
+#: config/avr/avr.c:2310
+msgid "operands to %T/%t must be reg + const_int:"
+msgstr ""
+
+#: config/avr/avr.c:2360 config/avr/avr.c:2426
+msgid "bad address, not an I/O address:"
+msgstr ""
+
+#: config/avr/avr.c:2369
+msgid "bad address, not a constant:"
+msgstr ""
+
+#: config/avr/avr.c:2387 config/avr/avr.c:2394
+msgid "bad address, not (reg+disp):"
+msgstr ""
+
+#: config/avr/avr.c:2401
+msgid "bad address, not post_inc or pre_dec:"
+msgstr ""
+
+#: config/avr/avr.c:2412
+msgid "internal compiler error.  Bad address:"
+msgstr ""
+
+#: config/avr/avr.c:2445
+#, c-format
+msgid "Unsupported code '%c' for fixed-point:"
+msgstr ""
+
+#: config/avr/avr.c:2454
+msgid "internal compiler error.  Unknown mode:"
+msgstr ""
+
+#: config/avr/avr.c:3426 config/avr/avr.c:4356 config/avr/avr.c:4805
+msgid "invalid insn:"
+msgstr ""
+
+#: config/avr/avr.c:3480 config/avr/avr.c:3585 config/avr/avr.c:3643
+#: config/avr/avr.c:3689 config/avr/avr.c:3708 config/avr/avr.c:3900
+#: config/avr/avr.c:4208 config/avr/avr.c:4492 config/avr/avr.c:4698
+#: config/avr/avr.c:4862 config/avr/avr.c:4956 config/avr/avr.c:5152
+msgid "incorrect insn:"
+msgstr ""
+
+#: config/avr/avr.c:3724 config/avr/avr.c:3999 config/avr/avr.c:4279
+#: config/avr/avr.c:4564 config/avr/avr.c:4744 config/avr/avr.c:5012
+#: config/avr/avr.c:5210
+msgid "unknown move insn:"
+msgstr ""
+
+#: config/avr/avr.c:5641
+msgid "bad shift insn:"
+msgstr ""
+
+#: config/avr/avr.c:5749 config/avr/avr.c:6230 config/avr/avr.c:6645
+msgid "internal compiler error.  Incorrect shift:"
+msgstr ""
+
+#: config/avr/avr.c:7982
+msgid "unsupported fixed-point conversion"
+msgstr ""
+
+#: config/avr/driver-avr.c:71
+#, c-format
+msgid ""
+"Running spec function '%s' with %d args\n"
+"\n"
+msgstr ""
+
+#: config/avr/driver-avr.c:118
+#, c-format
+msgid ""
+"'%s': mmcu='%s'\n"
+"'%s': specfile='%s'\n"
+"\n"
+msgstr ""
+
+#: config/bfin/bfin.c:1424
+#, c-format
+msgid "invalid %%j value"
+msgstr ""
+
+#: config/bfin/bfin.c:1617 config/c6x/c6x.c:2331
+#, c-format
+msgid "invalid const_double operand"
+msgstr ""
+
+#: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
+#: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: lto/lto-object.c:365 lto/lto-object.c:389
+#, gcc-internal-format, gfc-internal-format
+msgid "%s"
+msgstr "%s"
+
+#: config/cris/cris.c:696
+msgid "unexpected index-type in cris_print_index"
+msgstr ""
+
+#: config/cris/cris.c:713
+msgid "unexpected base-type in cris_print_base"
+msgstr ""
+
+#: config/cris/cris.c:777
+msgid "invalid operand for 'b' modifier"
+msgstr ""
+
+#: config/cris/cris.c:794
+msgid "invalid operand for 'o' modifier"
+msgstr ""
+
+#: config/cris/cris.c:813
+msgid "invalid operand for 'O' modifier"
+msgstr ""
+
+#: config/cris/cris.c:846
+msgid "invalid operand for 'p' modifier"
+msgstr ""
+
+#: config/cris/cris.c:885
+msgid "invalid operand for 'z' modifier"
+msgstr ""
+
+#: config/cris/cris.c:949 config/cris/cris.c:983
+msgid "invalid operand for 'H' modifier"
+msgstr ""
+
+#: config/cris/cris.c:959
+msgid "bad register"
+msgstr "помилковий регістр"
+
+#: config/cris/cris.c:1003
+msgid "invalid operand for 'e' modifier"
+msgstr ""
+
+#: config/cris/cris.c:1020
+msgid "invalid operand for 'm' modifier"
+msgstr ""
+
+#: config/cris/cris.c:1045
+msgid "invalid operand for 'A' modifier"
+msgstr ""
+
+#: config/cris/cris.c:1115
+msgid "invalid operand for 'D' modifier"
+msgstr ""
+
+#: config/cris/cris.c:1129
+msgid "invalid operand for 'T' modifier"
+msgstr ""
+
+#: config/cris/cris.c:1149 config/moxie/moxie.c:213
+msgid "invalid operand modifier letter"
+msgstr ""
+
+#: config/cris/cris.c:1206
+msgid "unexpected multiplicative operand"
+msgstr ""
+
+#: config/cris/cris.c:1226 config/moxie/moxie.c:238
+msgid "unexpected operand"
+msgstr ""
+
+#: config/cris/cris.c:1265 config/cris/cris.c:1275
+msgid "unrecognized address"
+msgstr ""
+
+#: config/cris/cris.c:2592
+msgid "unrecognized supposed constant"
+msgstr ""
+
+#: config/cris/cris.c:2997 config/cris/cris.c:3061
+msgid "unexpected side-effects in address"
+msgstr ""
+
+#. Can't possibly get anything else for a function-call, right?
+#: config/cris/cris.c:3909
+msgid "unidentifiable call op"
+msgstr ""
+
+#: config/cris/cris.c:3971
+#, c-format
+msgid "PIC register isn't set up"
+msgstr ""
+
+#: config/fr30/fr30.c:534
+#, c-format
+msgid "fr30_print_operand_address: unhandled address"
+msgstr ""
+
+#: config/fr30/fr30.c:558
+#, c-format
+msgid "fr30_print_operand: unrecognized %%p code"
+msgstr ""
+
+#: config/fr30/fr30.c:578
+#, c-format
+msgid "fr30_print_operand: unrecognized %%b code"
+msgstr ""
+
+#: config/fr30/fr30.c:599
+#, c-format
+msgid "fr30_print_operand: unrecognized %%B code"
+msgstr ""
+
+#: config/fr30/fr30.c:607
+#, c-format
+msgid "fr30_print_operand: invalid operand to %%A code"
+msgstr ""
+
+#: config/fr30/fr30.c:624
+#, c-format
+msgid "fr30_print_operand: invalid %%x code"
+msgstr ""
+
+#: config/fr30/fr30.c:631
+#, c-format
+msgid "fr30_print_operand: invalid %%F code"
+msgstr ""
+
+#: config/fr30/fr30.c:648
+#, c-format
+msgid "fr30_print_operand: unknown code"
+msgstr ""
+
+#: config/fr30/fr30.c:676 config/fr30/fr30.c:685 config/fr30/fr30.c:696
+#: config/fr30/fr30.c:709
+#, c-format
+msgid "fr30_print_operand: unhandled MEM"
+msgstr ""
+
+#: config/frv/frv.c:2545
+msgid "bad insn to frv_print_operand_address:"
+msgstr ""
+
+#: config/frv/frv.c:2556
+msgid "bad register to frv_print_operand_memory_reference_reg:"
+msgstr ""
+
+#: config/frv/frv.c:2595 config/frv/frv.c:2605 config/frv/frv.c:2614
+#: config/frv/frv.c:2635 config/frv/frv.c:2640
+msgid "bad insn to frv_print_operand_memory_reference:"
+msgstr ""
+
+#: config/frv/frv.c:2726
+#, c-format
+msgid "bad condition code"
+msgstr ""
+
+#: config/frv/frv.c:2802
+msgid "bad insn in frv_print_operand, bad const_double"
+msgstr ""
+
+#: config/frv/frv.c:2863
+msgid "bad insn to frv_print_operand, 'e' modifier:"
+msgstr ""
+
+#: config/frv/frv.c:2871
+msgid "bad insn to frv_print_operand, 'F' modifier:"
+msgstr ""
+
+#: config/frv/frv.c:2887
+msgid "bad insn to frv_print_operand, 'f' modifier:"
+msgstr ""
+
+#: config/frv/frv.c:2901
+msgid "bad insn to frv_print_operand, 'g' modifier:"
+msgstr ""
+
+#: config/frv/frv.c:2949
+msgid "bad insn to frv_print_operand, 'L' modifier:"
+msgstr ""
+
+#: config/frv/frv.c:2962
+msgid "bad insn to frv_print_operand, 'M/N' modifier:"
+msgstr ""
+
+#: config/frv/frv.c:2983
+msgid "bad insn to frv_print_operand, 'O' modifier:"
+msgstr ""
+
+#: config/frv/frv.c:3001
+msgid "bad insn to frv_print_operand, P modifier:"
+msgstr ""
+
+#: config/frv/frv.c:3021
+msgid "bad insn in frv_print_operand, z case"
+msgstr ""
+
+#: config/frv/frv.c:3052
+msgid "bad insn in frv_print_operand, 0 case"
+msgstr ""
+
+#: config/frv/frv.c:3057
+msgid "frv_print_operand: unknown code"
+msgstr ""
+
+#: config/frv/frv.c:4464
+msgid "bad output_move_single operand"
+msgstr ""
+
+#: config/frv/frv.c:4591
+msgid "bad output_move_double operand"
+msgstr ""
+
+#: config/frv/frv.c:4733
+msgid "bad output_condmove_single operand"
+msgstr ""
+
+#: config/i386/i386.c:14807
+#, c-format
+msgid "invalid UNSPEC as operand"
+msgstr ""
+
+#: config/i386/i386.c:15521
+#, c-format
+msgid "invalid operand size for operand code 'O'"
+msgstr ""
+
+#: config/i386/i386.c:15556
+#, c-format
+msgid "invalid operand size for operand code 'z'"
+msgstr ""
+
+#: config/i386/i386.c:15626
+#, c-format
+msgid "invalid operand type used with operand code 'Z'"
+msgstr ""
+
+#: config/i386/i386.c:15631
+#, c-format
+msgid "invalid operand size for operand code 'Z'"
+msgstr ""
+
+#: config/i386/i386.c:15707
+#, c-format
+msgid "operand is not a condition code, invalid operand code 'Y'"
+msgstr ""
+
+#: config/i386/i386.c:15780
+#, c-format
+msgid "operand is not a condition code, invalid operand code 'D'"
+msgstr ""
+
+#: config/i386/i386.c:15797
+#, c-format
+msgid "operand is not a condition code, invalid operand code '%c'"
+msgstr ""
+
+#: config/i386/i386.c:15810
+#, c-format
+msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
+msgstr ""
+
+#: config/i386/i386.c:15975
+#, c-format
+msgid "invalid operand code '%c'"
+msgstr ""
+
+#: config/i386/i386.c:16031
+#, c-format
+msgid "invalid constraints for operand"
+msgstr ""
+
+#: config/i386/i386.c:26087
+msgid "unknown insn mode"
+msgstr ""
+
+#: config/i386/i386-interix.h:77 config/i386/i386.opt:374
+msgid "Use native (MS) bitfield layout"
+msgstr ""
+
+#: config/i386/i386-interix.h:78
+msgid "Use gcc default bitfield layout"
+msgstr ""
+
+#: config/ia64/ia64.c:5410
+#, c-format
+msgid "invalid %%G mode"
+msgstr ""
+
+#: config/ia64/ia64.c:5580
+#, c-format
+msgid "ia64_print_operand: unknown code"
+msgstr ""
+
+#: config/ia64/ia64.c:11156
+msgid "invalid conversion from %<__fpreg%>"
+msgstr ""
+
+#: config/ia64/ia64.c:11159
+msgid "invalid conversion to %<__fpreg%>"
+msgstr ""
+
+#: config/ia64/ia64.c:11172 config/ia64/ia64.c:11183
+msgid "invalid operation on %<__fpreg%>"
+msgstr ""
+
+#: config/iq2000/iq2000.c:3166 config/tilegx/tilegx.c:5351
+#: config/tilepro/tilepro.c:4747
+#, c-format
+msgid "invalid %%P operand"
+msgstr ""
+
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
+#, c-format
+msgid "invalid %%p value"
+msgstr ""
+
+#: config/iq2000/iq2000.c:3231
+#, c-format
+msgid "invalid use of %%d, %%x, or %%X"
+msgstr ""
+
+#: config/lm32/lm32.c:545
+#, c-format
+msgid "only 0.0 can be loaded as an immediate"
+msgstr ""
+
+#: config/lm32/lm32.c:615
+msgid "bad operand"
+msgstr "помилковий операнд"
+
+#: config/lm32/lm32.c:627
+msgid "can't use non gp relative absolute address"
+msgstr ""
+
+#: config/lm32/lm32.c:631
+msgid "invalid addressing mode"
+msgstr "некоректний режим адресування"
+
+#: config/m32r/m32r.c:2096
+#, c-format
+msgid "invalid operand to %%s code"
+msgstr ""
+
+#: config/m32r/m32r.c:2103
+#, c-format
+msgid "invalid operand to %%p code"
+msgstr ""
+
+#: config/m32r/m32r.c:2158
+msgid "bad insn for 'A'"
+msgstr ""
+
+#: config/m32r/m32r.c:2205
+#, c-format
+msgid "invalid operand to %%T/%%B code"
+msgstr ""
+
+#: config/m32r/m32r.c:2228
+#, c-format
+msgid "invalid operand to %%N code"
+msgstr ""
+
+#: config/m32r/m32r.c:2261
+msgid "pre-increment address is not a register"
+msgstr ""
+
+#: config/m32r/m32r.c:2268
+msgid "pre-decrement address is not a register"
+msgstr ""
+
+#: config/m32r/m32r.c:2275
+msgid "post-increment address is not a register"
+msgstr ""
+
+#: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
+#: config/rs6000/rs6000.c:29313
+msgid "bad address"
+msgstr "помилкова адреса"
+
+#: config/m32r/m32r.c:2371
+msgid "lo_sum not of register"
+msgstr ""
+
+#: config/mep/mep.c:3278
+#, c-format
+msgid "invalid %%L code"
+msgstr ""
+
+#: config/microblaze/microblaze.c:2225
+#, c-format
+msgid "unknown punctuation '%c'"
+msgstr ""
+
+#: config/microblaze/microblaze.c:2234
+#, c-format
+msgid "null pointer"
+msgstr "нульовий вказівник"
+
+#: config/microblaze/microblaze.c:2269
+#, c-format
+msgid "PRINT_OPERAND, invalid insn for %%C"
+msgstr ""
+
+#: config/microblaze/microblaze.c:2298
+#, c-format
+msgid "PRINT_OPERAND, invalid insn for %%N"
+msgstr ""
+
+#: config/microblaze/microblaze.c:2318 config/microblaze/microblaze.c:2498
+msgid "insn contains an invalid address !"
+msgstr ""
+
+#: config/microblaze/microblaze.c:2333 config/microblaze/microblaze.c:2557
+#: config/xtensa/xtensa.c:2478
+msgid "invalid address"
+msgstr "некоректна адреса"
+
+#: config/microblaze/microblaze.c:2441
+#, c-format
+msgid "letter %c was found & insn was not CONST_INT"
+msgstr ""
+
+#: config/mips/mips.c:8400 config/mips/mips.c:8427 config/mips/mips.c:8562
+#, c-format
+msgid "'%%%c' is not a valid operand prefix"
+msgstr ""
+
+#: config/mips/mips.c:8486 config/mips/mips.c:8493 config/mips/mips.c:8500
+#: config/mips/mips.c:8507 config/mips/mips.c:8517 config/mips/mips.c:8520
+#: config/mips/mips.c:8580 config/mips/mips.c:8594 config/mips/mips.c:8612
+#: config/mips/mips.c:8621
+#, c-format
+msgid "invalid use of '%%%c'"
+msgstr ""
+
+#: config/mmix/mmix.c:1575 config/mmix/mmix.c:1705
+msgid "MMIX Internal: Expected a CONST_INT, not this"
+msgstr ""
+
+#: config/mmix/mmix.c:1654
+msgid "MMIX Internal: Bad value for 'm', not a CONST_INT"
+msgstr ""
+
+#: config/mmix/mmix.c:1673
+msgid "MMIX Internal: Expected a register, not this"
+msgstr ""
+
+#: config/mmix/mmix.c:1683
+msgid "MMIX Internal: Expected a constant, not this"
+msgstr ""
+
+#. We need the original here.
+#: config/mmix/mmix.c:1767
+msgid "MMIX Internal: Cannot decode this operand"
+msgstr ""
+
+#: config/mmix/mmix.c:1823
+msgid "MMIX Internal: This is not a recognized address"
+msgstr ""
+
+#: config/mmix/mmix.c:2700
+msgid "MMIX Internal: Trying to output invalidly reversed condition:"
+msgstr ""
+
+#: config/mmix/mmix.c:2707
+msgid "MMIX Internal: What's the CC of this?"
+msgstr ""
+
+#: config/mmix/mmix.c:2711
+msgid "MMIX Internal: What is the CC of this?"
+msgstr ""
+
+#: config/mmix/mmix.c:2758
+msgid "MMIX Internal: This is not a constant:"
+msgstr ""
+
+#: config/msp430/msp430.c:2664
+#, c-format
+msgid "invalid operand prefix"
+msgstr ""
+
+#: config/msp430/msp430.c:2698
+#, c-format
+msgid "invalid zero extract"
+msgstr ""
+
+#: config/rl78/rl78.c:1771 config/rl78/rl78.c:1831
+#, c-format
+msgid "q/Q modifiers invalid for symbol references"
+msgstr ""
+
+#: config/rs6000/host-darwin.c:94
+#, c-format
+msgid "Out of stack space.\n"
+msgstr ""
+
+#: config/rs6000/host-darwin.c:115
+#, c-format
+msgid "Try running '%s' in the shell to raise its limit.\n"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3485
+msgid "-maltivec=le not allowed for big-endian targets"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3497
+msgid "-mvsx requires hardware floating point"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3505
+msgid "-mvsx and -mpaired are incompatible"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3507
+msgid "-mvsx needs indexed addressing"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3512
+msgid "-mvsx and -mno-altivec are incompatible"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3514
+msgid "-mno-altivec disables vsx"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3652
+msgid "-mquad-memory requires 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3655
+msgid "-mquad-memory-atomic requires 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3667
+msgid "-mquad-memory is not available in little endian mode"
+msgstr ""
+
+#: config/rs6000/rs6000.c:8925
+msgid "bad move"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18534
+#, c-format
+msgid "invalid %%e value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18555
+#, c-format
+msgid "invalid %%f value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18564
+#, c-format
+msgid "invalid %%F value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18573
+#, c-format
+msgid "invalid %%G value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18608
+#, c-format
+msgid "invalid %%j code"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18618
+#, c-format
+msgid "invalid %%J code"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18628
+#, c-format
+msgid "invalid %%k value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
+#, c-format
+msgid "invalid %%K value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18707
+#, c-format
+msgid "invalid %%O value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18754
+#, c-format
+msgid "invalid %%q value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18797
+#, c-format
+msgid "invalid %%S value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18837
+#, c-format
+msgid "invalid %%T value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18849
+#, c-format
+msgid "invalid %%u value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
+#, c-format
+msgid "invalid %%v value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
+#, c-format
+msgid "invalid %%x value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:19079
+#, c-format
+msgid "invalid %%y value, try using the 'Z' constraint"
+msgstr ""
+
+#: config/rs6000/rs6000.c:32204
+msgid "AltiVec argument passed to unprototyped function"
+msgstr ""
+
+#: config/rs6000/rs6000.c:33940
+msgid "Could not generate addis value for fusion"
+msgstr ""
+
+#: config/rs6000/rs6000.c:33999
+msgid "Unable to generate load offset for fusion"
+msgstr ""
+
+#: config/s390/s390.c:5396
+#, c-format
+msgid "symbolic memory references are only supported on z10 or later"
+msgstr ""
+
+#: config/s390/s390.c:5407
+#, c-format
+msgid "cannot decompose address"
+msgstr ""
+
+#: config/s390/s390.c:5473
+#, c-format
+msgid "invalid comparison operator for 'E' output modifier"
+msgstr ""
+
+#: config/s390/s390.c:5496
+#, c-format
+msgid "invalid reference for 'J' output modifier"
+msgstr ""
+
+#: config/s390/s390.c:5510
+#, c-format
+msgid "memory reference expected for 'O' output modifier"
+msgstr ""
+
+#: config/s390/s390.c:5521
+#, c-format
+msgid "invalid address for 'O' output modifier"
+msgstr ""
+
+#: config/s390/s390.c:5539
+#, c-format
+msgid "memory reference expected for 'R' output modifier"
+msgstr ""
+
+#: config/s390/s390.c:5550
+#, c-format
+msgid "invalid address for 'R' output modifier"
+msgstr ""
+
+#: config/s390/s390.c:5568
+#, c-format
+msgid "memory reference expected for 'S' output modifier"
+msgstr ""
+
+#: config/s390/s390.c:5578
+#, c-format
+msgid "invalid address for 'S' output modifier"
+msgstr ""
+
+#: config/s390/s390.c:5599
+#, c-format
+msgid "register or memory expression expected for 'N' output modifier"
+msgstr ""
+
+#: config/s390/s390.c:5610
+#, c-format
+msgid "register or memory expression expected for 'M' output modifier"
+msgstr ""
+
+#: config/s390/s390.c:5685 config/s390/s390.c:5705
+#, c-format
+msgid "invalid constant for output modifier '%c'"
+msgstr ""
+
+#: config/s390/s390.c:5702
+#, c-format
+msgid "invalid constant - try using an output modifier"
+msgstr ""
+
+#: config/s390/s390.c:5712
+#, c-format
+msgid "invalid expression - try using an output modifier"
+msgstr ""
+
+#: config/s390/s390.c:5715
+#, c-format
+msgid "invalid expression for output modifier '%c'"
+msgstr ""
+
+#: config/sh/sh.c:1323
+#, c-format
+msgid "invalid operand to %%R"
+msgstr ""
+
+#: config/sh/sh.c:1350
+#, c-format
+msgid "invalid operand to %%S"
+msgstr ""
+
+#: config/sh/sh.c:9957
+msgid "created and used with different architectures / ABIs"
+msgstr ""
+
+#: config/sh/sh.c:9959
+msgid "created and used with different ABIs"
+msgstr ""
+
+#: config/sh/sh.c:9961
+msgid "created and used with different endianness"
+msgstr ""
+
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
+#, c-format
+msgid "invalid %%Y operand"
+msgstr ""
+
+#: config/sparc/sparc.c:8910
+#, c-format
+msgid "invalid %%A operand"
+msgstr ""
+
+#: config/sparc/sparc.c:8920
+#, c-format
+msgid "invalid %%B operand"
+msgstr ""
+
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
+#: config/tilepro/tilepro.c:4550
+#, c-format
+msgid "invalid %%C operand"
+msgstr ""
+
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
+#, c-format
+msgid "invalid %%D operand"
+msgstr ""
+
+#: config/sparc/sparc.c:8982
+#, c-format
+msgid "invalid %%f operand"
+msgstr ""
+
+#: config/sparc/sparc.c:8996
+#, c-format
+msgid "invalid %%s operand"
+msgstr ""
+
+#: config/sparc/sparc.c:9050
+#, c-format
+msgid "long long constant not a valid immediate operand"
+msgstr ""
+
+#: config/sparc/sparc.c:9053
+#, c-format
+msgid "floating point constant not a valid immediate operand"
+msgstr ""
+
+#: config/stormy16/stormy16.c:1773 config/stormy16/stormy16.c:1844
+#, c-format
+msgid "'B' operand is not constant"
+msgstr ""
+
+#: config/stormy16/stormy16.c:1800
+#, c-format
+msgid "'B' operand has multiple bits set"
+msgstr ""
+
+#: config/stormy16/stormy16.c:1826
+#, c-format
+msgid "'o' operand is not constant"
+msgstr ""
+
+#: config/stormy16/stormy16.c:1858
+#, c-format
+msgid "xstormy16_print_operand: unknown code"
+msgstr ""
+
+#: config/tilegx/tilegx.c:5119 config/tilepro/tilepro.c:4535
+#, c-format
+msgid "invalid %%c operand"
+msgstr ""
+
+#: config/tilegx/tilegx.c:5150
+#, c-format
+msgid "invalid %%d operand"
+msgstr ""
+
+#: config/tilegx/tilegx.c:5247
+#, c-format
+msgid "invalid %%H specifier"
+msgstr ""
+
+#: config/tilegx/tilegx.c:5289 config/tilepro/tilepro.c:4564
+#, c-format
+msgid "invalid %%h operand"
+msgstr ""
+
+#: config/tilegx/tilegx.c:5301 config/tilepro/tilepro.c:4628
+#, c-format
+msgid "invalid %%I operand"
+msgstr ""
+
+#: config/tilegx/tilegx.c:5315 config/tilepro/tilepro.c:4642
+#, c-format
+msgid "invalid %%i operand"
+msgstr ""
+
+#: config/tilegx/tilegx.c:5338 config/tilepro/tilepro.c:4665
+#, c-format
+msgid "invalid %%j operand"
+msgstr ""
+
+#: config/tilegx/tilegx.c:5369
+#, c-format
+msgid "invalid %%%c operand"
+msgstr ""
+
+#: config/tilegx/tilegx.c:5384 config/tilepro/tilepro.c:4779
+#, c-format
+msgid "invalid %%N operand"
+msgstr ""
+
+#: config/tilegx/tilegx.c:5428
+#, c-format
+msgid "invalid operand for 'r' specifier"
+msgstr ""
+
+#: config/tilegx/tilegx.c:5453 config/tilepro/tilepro.c:4861
+#, c-format
+msgid "unable to print out operand yet; code == %d (%c)"
+msgstr ""
+
+#: config/tilepro/tilepro.c:4600
+#, c-format
+msgid "invalid %%H operand"
+msgstr ""
+
+#: config/tilepro/tilepro.c:4704
+#, c-format
+msgid "invalid %%L operand"
+msgstr ""
+
+#: config/tilepro/tilepro.c:4764
+#, c-format
+msgid "invalid %%M operand"
+msgstr ""
+
+#: config/tilepro/tilepro.c:4807
+#, c-format
+msgid "invalid %%t operand"
+msgstr ""
+
+#: config/tilepro/tilepro.c:4814
+#, c-format
+msgid "invalid %%t operand '"
+msgstr ""
+
+#: config/tilepro/tilepro.c:4835
+#, c-format
+msgid "invalid %%r operand"
+msgstr ""
+
+#: config/v850/v850.c:324
+msgid "const_double_split got a bad insn:"
+msgstr ""
+
+#: config/v850/v850.c:931
+msgid "output_move_single:"
+msgstr ""
+
+#: config/vax/vax.c:488
+#, c-format
+msgid "symbol used with both base and indexed registers"
+msgstr ""
+
+#: config/vax/vax.c:497
+#, c-format
+msgid "symbol with offset used in PIC mode"
+msgstr ""
+
+#: config/vax/vax.c:585
+#, c-format
+msgid "symbol used as immediate operand"
+msgstr ""
+
+#: config/vax/vax.c:1610
+msgid "illegal operand detected"
+msgstr ""
+
+#: config/visium/visium.c:3146
+msgid "illegal operand "
+msgstr "неприпустимий операнд "
+
+#: config/visium/visium.c:3196
+msgid "illegal operand address (1)"
+msgstr ""
+
+#: config/visium/visium.c:3203
+msgid "illegal operand address (2)"
+msgstr ""
+
+#: config/visium/visium.c:3218
+msgid "illegal operand address (3)"
+msgstr ""
+
+#: config/visium/visium.c:3226
+msgid "illegal operand address (4)"
+msgstr ""
+
+#: config/xtensa/xtensa.c:803 config/xtensa/xtensa.c:835
+#: config/xtensa/xtensa.c:844
+msgid "bad test"
+msgstr ""
+
+#: config/xtensa/xtensa.c:2335
+#, c-format
+msgid "invalid %%D value"
+msgstr ""
+
+#: config/xtensa/xtensa.c:2372
+msgid "invalid mask"
+msgstr ""
+
+#: config/xtensa/xtensa.c:2405
+#, c-format
+msgid "invalid %%d value"
+msgstr "некоректне значення %%d"
+
+#: config/xtensa/xtensa.c:2426 config/xtensa/xtensa.c:2436
+#, c-format
+msgid "invalid %%t/%%b value"
+msgstr "некоректне значення %%t/%%b"
+
+#: config/xtensa/xtensa.c:2503
+msgid "no register in address"
+msgstr "немає регістру у адресі"
+
+#: config/xtensa/xtensa.c:2511
+msgid "address offset not a constant"
+msgstr ""
+
+#: c/c-objc-common.c:173
+msgid "aka"
+msgstr "або"
+
+#: c/c-objc-common.c:200
+msgid "({anonymous})"
+msgstr ""
+
+#: c/c-parser.c:2022 c/c-parser.c:2036 c/c-parser.c:4592 c/c-parser.c:4996
+#: c/c-parser.c:5117 c/c-parser.c:5410 c/c-parser.c:5574 c/c-parser.c:5605
+#: c/c-parser.c:5778 c/c-parser.c:8404 c/c-parser.c:8439 c/c-parser.c:8470
+#: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
+#: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
+#: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
+#: cp/parser.c:24294 cp/parser.c:24866
+#, gcc-internal-format
+msgid "expected %<;%>"
+msgstr "мало бути %<;%>"
+
+#: c/c-parser.c:2063 c/c-parser.c:2744 c/c-parser.c:3041 c/c-parser.c:3108
+#: c/c-parser.c:3757 c/c-parser.c:3955 c/c-parser.c:3960 c/c-parser.c:5161
+#: c/c-parser.c:5299 c/c-parser.c:5490 c/c-parser.c:5714 c/c-parser.c:5837
+#: c/c-parser.c:6851 c/c-parser.c:7257 c/c-parser.c:7295 c/c-parser.c:7423
+#: c/c-parser.c:7606 c/c-parser.c:7621 c/c-parser.c:7645 c/c-parser.c:8989
+#: c/c-parser.c:9061 c/c-parser.c:10049 c/c-parser.c:10234 c/c-parser.c:10367
+#: c/c-parser.c:10419 c/c-parser.c:10572 c/c-parser.c:10617 c/c-parser.c:10662
+#: c/c-parser.c:10796 c/c-parser.c:10893 c/c-parser.c:11007 c/c-parser.c:11084
+#: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
+#: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
+#: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
+#, gcc-internal-format
+msgid "expected %<(%>"
+msgstr "мало бути %<(%>"
+
+#: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
+#, gcc-internal-format
+msgid "expected %<,%>"
+msgstr "мало бути %<,%>"
+
+#: c/c-parser.c:2089 c/c-parser.c:2456 c/c-parser.c:2759 c/c-parser.c:3082
+#: c/c-parser.c:3119 c/c-parser.c:3334 c/c-parser.c:3520 c/c-parser.c:3582
+#: c/c-parser.c:3634 c/c-parser.c:3764 c/c-parser.c:4048 c/c-parser.c:4059
+#: c/c-parser.c:4068 c/c-parser.c:5164 c/c-parser.c:5314 c/c-parser.c:5637
+#: c/c-parser.c:5772 c/c-parser.c:5845 c/c-parser.c:6414 c/c-parser.c:6626
+#: c/c-parser.c:6701 c/c-parser.c:6791 c/c-parser.c:6994 c/c-parser.c:7186
+#: c/c-parser.c:7204 c/c-parser.c:7225 c/c-parser.c:7274 c/c-parser.c:7378
+#: c/c-parser.c:7447 c/c-parser.c:7614 c/c-parser.c:7637 c/c-parser.c:7658
+#: c/c-parser.c:7872 c/c-parser.c:8247 c/c-parser.c:8783 c/c-parser.c:8804
+#: c/c-parser.c:9012 c/c-parser.c:9067 c/c-parser.c:9450 c/c-parser.c:10086
+#: c/c-parser.c:10237 c/c-parser.c:10370 c/c-parser.c:10450 c/c-parser.c:10579
+#: c/c-parser.c:10624 c/c-parser.c:10669 c/c-parser.c:10719 c/c-parser.c:10874
+#: c/c-parser.c:10957 c/c-parser.c:11014 c/c-parser.c:11091 c/c-parser.c:11135
+#: c/c-parser.c:11201 c/c-parser.c:11248 c/c-parser.c:11276 c/c-parser.c:11312
+#: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
+#: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
+#: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
+#, gcc-internal-format
+msgid "expected %<)%>"
+msgstr "мало бути %<)%>"
+
+#: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
+#: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
+#, gcc-internal-format
+msgid "expected %<]%>"
+msgstr "мало бути %<]%>"
+
+#: c/c-parser.c:3615
+msgid "expected %<;%>, %<,%> or %<)%>"
+msgstr "мало бути %<;%>, %<,%> або %<)%>"
+
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
+#, gcc-internal-format
+msgid "expected %<}%>"
+msgstr "мало бути %<}%>"
+
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
+#, gcc-internal-format
+msgid "expected %<{%>"
+msgstr "мало бути %<{%>"
+
+#: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
+#: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
+#, gcc-internal-format
+msgid "expected %<:%>"
+msgstr "мало бути %<:%>"
+
+#: c/c-parser.c:5017 cp/semantics.c:633
+msgid "Cilk array notation cannot be used as a computed goto expression"
+msgstr ""
+
+#: c/c-parser.c:5075
+msgid "Cilk array notation cannot be used for a throw expression"
+msgstr ""
+
+#: c/c-parser.c:5310 cp/semantics.c:1153
+msgid "Cilk array notation cannot be used as a condition for switch statement"
+msgstr ""
+
+#: c/c-parser.c:5354 cp/semantics.c:808
+msgid "Cilk array notation cannot be used as a condition for while statement"
+msgstr ""
+
+#: c/c-parser.c:5396 cp/parser.c:24802
+#, gcc-internal-format
+msgid "expected %<while%>"
+msgstr "мало бути %<while%>"
+
+#: c/c-parser.c:5403 cp/semantics.c:867
+msgid "Cilk array notation cannot be used as a condition for a do-while statement"
+msgstr ""
+
+#: c/c-parser.c:5601 cp/semantics.c:986
+msgid "Cilk array notation cannot be used in a condition for a for-loop"
+msgstr ""
+
+#: c/c-parser.c:7139
+msgid "expected %<.%>"
+msgstr "мало бути %<.%>"
+
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
+#, gcc-internal-format
+msgid "expected %<@end%>"
+msgstr "мало бути %<@end%>"
+
+#: c/c-parser.c:8946 cp/parser.c:24893
+#, gcc-internal-format
+msgid "expected %<>%>"
+msgstr "мало бути %<>%>"
+
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
+#, gcc-internal-format
+msgid "expected %<,%> or %<)%>"
+msgstr "мало бути %<,%> або %<)%>"
+
+#: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
+#, gcc-internal-format
+msgid "expected %<=%>"
+msgstr "мало бути %<=%>"
+
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
+#, gcc-internal-format
+msgid "expected %<#pragma omp section%> or %<}%>"
+msgstr "мало бути %<#pragma omp section%> або %<}%>"
+
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
+#, gcc-internal-format
+msgid "expected %<[%>"
+msgstr "мало бути %<[%>"
+
+#: c/c-typeck.c:7146
+msgid "(anonymous)"
+msgstr "(анонімний)"
+
+#: cp/call.c:9242
+msgid "candidate 1:"
+msgstr "кандидат 1:"
+
+#: cp/call.c:9243
+msgid "candidate 2:"
+msgstr "кандидат 2:"
+
+#: cp/decl2.c:778
+msgid "candidates are: %+#D"
+msgstr "кандидати: %+#D"
+
+#: cp/decl2.c:780
+msgid "candidate is: %+#D"
+msgstr "кандидат: %+#D"
+
+#: cp/error.c:342
+msgid "<missing>"
+msgstr "<пропущено>"
+
+#: cp/error.c:437
+msgid "<brace-enclosed initializer list>"
+msgstr ""
+
+#: cp/error.c:439
+msgid "<unresolved overloaded function type>"
+msgstr ""
+
+#: cp/error.c:599
+msgid "<type error>"
+msgstr "<помилка типу>"
+
+#: cp/error.c:702
+#, c-format
+msgid "<anonymous %s>"
+msgstr "<анонімний %s>"
+
+#. A lambda's "type" is essentially its signature.
+#: cp/error.c:707
+msgid "<lambda"
+msgstr "<lambda"
+
+#: cp/error.c:837
+msgid "<typeprefixerror>"
+msgstr ""
+
+#: cp/error.c:964
+#, c-format
+msgid "(static initializers for %s)"
+msgstr ""
+
+#: cp/error.c:966
+#, c-format
+msgid "(static destructors for %s)"
+msgstr ""
+
+#: cp/error.c:1074
+msgid "vtable for "
+msgstr ""
+
+#: cp/error.c:1098
+msgid "<return value> "
+msgstr ""
+
+#: cp/error.c:1113
+msgid "{anonymous}"
+msgstr "{анонімний}"
+
+#: cp/error.c:1115
+msgid "(anonymous namespace)"
+msgstr ""
+
+#: cp/error.c:1231
+msgid "<template arguments error>"
+msgstr ""
+
+#: cp/error.c:1252
+msgid "<enumerator>"
+msgstr ""
+
+#: cp/error.c:1292
+msgid "<declaration error>"
+msgstr ""
+
+#: cp/error.c:1793 cp/error.c:1813
+msgid "<template parameter error>"
+msgstr ""
+
+#: cp/error.c:1943
+msgid "<statement>"
+msgstr ""
+
+#: cp/error.c:1970 cp/error.c:2980 c-family/c-pretty-print.c:2207
+#, gcc-internal-format
+msgid "<unknown>"
+msgstr ""
+
+#. While waiting for caret diagnostics, avoid printing
+#. __cxa_allocate_exception, __cxa_throw, and the like.
+#: cp/error.c:1988
+msgid "<throw-expression>"
+msgstr ""
+
+#: cp/error.c:2089
+msgid "<ubsan routine call>"
+msgstr ""
+
+#: cp/error.c:2546
+msgid "<unparsed>"
+msgstr ""
+
+#: cp/error.c:2693
+msgid "<lambda>"
+msgstr ""
+
+#: cp/error.c:2703
+msgid "*this"
+msgstr "*this"
+
+#: cp/error.c:2713
+msgid "<expression error>"
+msgstr ""
+
+#: cp/error.c:2728
+msgid "<unknown operator>"
+msgstr "<невідомий оператор>"
+
+#: cp/error.c:3024
+msgid "{unknown}"
+msgstr "{невідомий}"
+
+#: cp/error.c:3136
+msgid "At global scope:"
+msgstr ""
+
+#: cp/error.c:3242
+#, c-format
+msgid "In static member function %qs"
+msgstr ""
+
+#: cp/error.c:3244
+#, c-format
+msgid "In copy constructor %qs"
+msgstr ""
+
+#: cp/error.c:3246
+#, c-format
+msgid "In constructor %qs"
+msgstr ""
+
+#: cp/error.c:3248
+#, c-format
+msgid "In destructor %qs"
+msgstr ""
+
+#: cp/error.c:3250
+msgid "In lambda function"
+msgstr ""
+
+#: cp/error.c:3270
+#, c-format
+msgid "%s: In substitution of %qS:\n"
+msgstr ""
+
+#: cp/error.c:3271
+msgid "%s: In instantiation of %q#D:\n"
+msgstr ""
+
+#: cp/error.c:3296
+msgid "%r%s:%d:%d:%R   "
+msgstr ""
+
+#: cp/error.c:3299
+msgid "%r%s:%d:%R   "
+msgstr ""
+
+#: cp/error.c:3307
+#, c-format
+msgid "recursively required by substitution of %qS\n"
+msgstr ""
+
+#: cp/error.c:3308
+#, c-format
+msgid "required by substitution of %qS\n"
+msgstr ""
+
+#: cp/error.c:3313
+msgid "recursively required from %q#D\n"
+msgstr ""
+
+#: cp/error.c:3314
+msgid "required from %q#D\n"
+msgstr ""
+
+#: cp/error.c:3321
+msgid "recursively required from here"
+msgstr ""
+
+#: cp/error.c:3322
+msgid "required from here"
+msgstr ""
+
+#: cp/error.c:3374
+msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
+msgstr ""
+
+#: cp/error.c:3380
+msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
+msgstr ""
+
+#: cp/error.c:3435
+msgid "%r%s:%d:%d:%R   in constexpr expansion of %qs"
+msgstr ""
+
+#: cp/error.c:3439
+msgid "%r%s:%d:%R   in constexpr expansion of %qs"
+msgstr ""
+
+#: cp/pt.c:1808 cp/semantics.c:4856
+msgid "candidates are:"
+msgstr ""
+
+#: cp/pt.c:19576
+msgid "candidate is:"
+msgid_plural "candidates are:"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: cp/rtti.c:557
+msgid "target is not pointer or reference to class"
+msgstr ""
+
+#: cp/rtti.c:562
+msgid "target is not pointer or reference to complete type"
+msgstr ""
+
+#: cp/rtti.c:568
+msgid "target is not pointer or reference"
+msgstr ""
+
+#: cp/rtti.c:584
+msgid "source is not a pointer"
+msgstr ""
+
+#: cp/rtti.c:589
+msgid "source is not a pointer to class"
+msgstr ""
+
+#: cp/rtti.c:594
+msgid "source is a pointer to incomplete type"
+msgstr ""
+
+#: cp/rtti.c:609
+msgid "source is not of class type"
+msgstr ""
+
+#: cp/rtti.c:614
+msgid "source is of incomplete class type"
+msgstr ""
+
+#: cp/rtti.c:623
+msgid "conversion casts away constness"
+msgstr ""
+
+#: cp/rtti.c:777
+msgid "source type is not polymorphic"
+msgstr ""
+
+#: cp/typeck.c:5654 c/c-typeck.c:3884
+#, gcc-internal-format
+msgid "wrong type argument to unary minus"
+msgstr ""
+
+#: cp/typeck.c:5655 c/c-typeck.c:3871
+#, gcc-internal-format
+msgid "wrong type argument to unary plus"
+msgstr ""
+
+#: cp/typeck.c:5682 c/c-typeck.c:3910
+#, gcc-internal-format
+msgid "wrong type argument to bit-complement"
+msgstr ""
+
+#: cp/typeck.c:5689 c/c-typeck.c:3918
+#, gcc-internal-format
+msgid "wrong type argument to abs"
+msgstr ""
+
+#: cp/typeck.c:5701 c/c-typeck.c:3930
+#, gcc-internal-format
+msgid "wrong type argument to conjugation"
+msgstr ""
+
+#: cp/typeck.c:5719
+msgid "in argument to unary !"
+msgstr ""
+
+#: cp/typeck.c:5768
+msgid "no pre-increment operator for type"
+msgstr ""
+
+#: cp/typeck.c:5770
+msgid "no post-increment operator for type"
+msgstr ""
+
+#: cp/typeck.c:5772
+msgid "no pre-decrement operator for type"
+msgstr ""
+
+#: cp/typeck.c:5774
+msgid "no post-decrement operator for type"
+msgstr ""
+
+#: fortran/arith.c:95
+msgid "Arithmetic OK at %L"
+msgstr ""
+
+#: fortran/arith.c:98
+msgid "Arithmetic overflow at %L"
+msgstr ""
+
+#: fortran/arith.c:101
+msgid "Arithmetic underflow at %L"
+msgstr ""
+
+#: fortran/arith.c:104
+msgid "Arithmetic NaN at %L"
+msgstr ""
+
+#: fortran/arith.c:107
+msgid "Division by zero at %L"
+msgstr ""
+
+#: fortran/arith.c:110
+msgid "Array operands are incommensurate at %L"
+msgstr ""
+
+#: fortran/arith.c:114
+msgid "Integer outside symmetric range implied by Standard Fortran at %L"
+msgstr ""
+
+#: fortran/arith.c:1350
+msgid "elemental binary operation"
+msgstr ""
+
+#: fortran/check.c:2063 fortran/check.c:3054 fortran/check.c:3108
+#, c-format
+msgid "arguments '%s' and '%s' for intrinsic %s"
+msgstr ""
+
+#: fortran/check.c:2860
+#, c-format
+msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
+msgstr ""
+
+#: fortran/check.c:3383 fortran/intrinsic.c:4237
+#, c-format
+msgid "arguments '%s' and '%s' for intrinsic '%s'"
+msgstr ""
+
+#: fortran/error.c:827 fortran/error.c:949 fortran/error.c:1087
+#: fortran/error.c:1368
+msgid "Warning:"
+msgstr "Попередження:"
+
+#: fortran/error.c:951 fortran/error.c:1348 fortran/error.c:1462
+msgid "Error:"
+msgstr "Помилка:"
+
+#: fortran/error.c:959 fortran/error.c:1028
+msgid "Fortran 2008 obsolescent feature:"
+msgstr ""
+
+#: fortran/error.c:968 fortran/error.c:1037
+msgid "GNU Extension:"
+msgstr ""
+
+#: fortran/error.c:971 fortran/error.c:1040
+msgid "Legacy Extension:"
+msgstr ""
+
+#: fortran/error.c:974 fortran/error.c:1043
+msgid "Obsolescent feature:"
+msgstr ""
+
+#: fortran/error.c:977 fortran/error.c:1046
+msgid "Deleted feature:"
+msgstr ""
+
+#: fortran/expr.c:622
+#, c-format
+msgid "Constant expression required at %C"
+msgstr ""
+
+#: fortran/expr.c:625
+#, c-format
+msgid "Integer expression required at %C"
+msgstr ""
+
+#: fortran/expr.c:630
+#, c-format
+msgid "Integer value too large in expression at %C"
+msgstr ""
+
+#: fortran/expr.c:3196
+msgid "array assignment"
+msgstr ""
+
+#: fortran/gfortranspec.c:281
+#, c-format
+msgid ""
+"GNU Fortran comes with NO WARRANTY, to the extent permitted by law.\n"
+"You may redistribute copies of GNU Fortran\n"
+"under the terms of the GNU General Public License.\n"
+"For more information about these matters, see the file named COPYING\n"
+"\n"
+msgstr ""
+
+#: fortran/gfortranspec.c:426
+#, c-format
+msgid "Driving:"
+msgstr ""
+
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
+msgid "actual argument to INTENT = OUT/INOUT"
+msgstr ""
+
+#: fortran/io.c:551
+msgid "Positive width required"
+msgstr ""
+
+#: fortran/io.c:552
+msgid "Nonnegative width required"
+msgstr ""
+
+#: fortran/io.c:553
+msgid "Unexpected element %<%c%> in format string at %L"
+msgstr ""
+
+#: fortran/io.c:555
+msgid "Unexpected end of format string"
+msgstr ""
+
+#: fortran/io.c:556
+msgid "Zero width in format descriptor"
+msgstr ""
+
+#: fortran/io.c:576
+msgid "Missing leading left parenthesis"
+msgstr ""
+
+#: fortran/io.c:605
+msgid "Left parenthesis required after %<*%>"
+msgstr ""
+
+#: fortran/io.c:636
+msgid "Expected P edit descriptor"
+msgstr ""
+
+#. P requires a prior number.
+#: fortran/io.c:644
+msgid "P descriptor requires leading scale factor"
+msgstr ""
+
+#: fortran/io.c:737 fortran/io.c:751
+msgid "Comma required after P descriptor"
+msgstr ""
+
+#: fortran/io.c:765
+msgid "Positive width required with T descriptor"
+msgstr ""
+
+#: fortran/io.c:844
+msgid "E specifier not allowed with g0 descriptor"
+msgstr ""
+
+#: fortran/io.c:914
+msgid "Positive exponent width required"
+msgstr ""
+
+#: fortran/io.c:944
+msgid "Period required in format specifier"
+msgstr ""
+
+#: fortran/io.c:1532
+#, c-format
+msgid "%s tag"
+msgstr ""
+
+#: fortran/io.c:2861
+msgid "internal unit in WRITE"
+msgstr ""
+
+#. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
+#. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
+#: fortran/io.c:4053
+#, c-format
+msgid "%s tag with INQUIRE"
+msgstr ""
+
+#: fortran/matchexp.c:28
+#, c-format
+msgid "Syntax error in expression at %C"
+msgstr "Синтаксична помилка у виразі у %C"
+
+#: fortran/module.c:1112
+msgid "Unexpected EOF"
+msgstr "Неочікуваний символ кінця файла"
+
+#: fortran/module.c:1196
+msgid "Integer overflow"
+msgstr "Переповнення типу цілого значення"
+
+#: fortran/module.c:1226
+msgid "Name too long"
+msgstr "Назва є надто довгою"
+
+#: fortran/module.c:1328 fortran/module.c:1431
+msgid "Bad name"
+msgstr "Помилкова назва"
+
+#: fortran/module.c:1455
+msgid "Expected name"
+msgstr ""
+
+#: fortran/module.c:1458
+msgid "Expected left parenthesis"
+msgstr ""
+
+#: fortran/module.c:1461
+msgid "Expected right parenthesis"
+msgstr ""
+
+#: fortran/module.c:1464
+msgid "Expected integer"
+msgstr ""
+
+#: fortran/module.c:1467 fortran/module.c:2408
+msgid "Expected string"
+msgstr ""
+
+#: fortran/module.c:1492
+msgid "find_enum(): Enum not found"
+msgstr ""
+
+#: fortran/module.c:2148
+msgid "Expected attribute bit name"
+msgstr ""
+
+#: fortran/module.c:3012
+msgid "Expected integer string"
+msgstr ""
+
+#: fortran/module.c:3016
+msgid "Error converting integer"
+msgstr ""
+
+#: fortran/module.c:3038
+msgid "Expected real string"
+msgstr ""
+
+#: fortran/module.c:3262
+msgid "Expected expression type"
+msgstr ""
+
+#: fortran/module.c:3342
+msgid "Bad operator"
+msgstr ""
+
+#: fortran/module.c:3457
+msgid "Bad type in constant expression"
+msgstr ""
+
+#: fortran/module.c:6741
+msgid "Unexpected end of module"
+msgstr ""
+
+#: fortran/parse.c:1563
+msgid "arithmetic IF"
+msgstr ""
+
+#: fortran/parse.c:1572
+msgid "attribute declaration"
+msgstr ""
+
+#: fortran/parse.c:1608
+msgid "data declaration"
+msgstr ""
+
+#: fortran/parse.c:1617
+msgid "derived type declaration"
+msgstr ""
+
+#: fortran/parse.c:1711
+msgid "block IF"
+msgstr ""
+
+#: fortran/parse.c:1720
+msgid "implied END DO"
+msgstr ""
+
+#: fortran/parse.c:1811 fortran/resolve.c:10175
+msgid "assignment"
+msgstr "присвоювання"
+
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
+msgid "pointer assignment"
+msgstr ""
+
+#: fortran/parse.c:1832
+msgid "simple IF"
+msgstr ""
+
+#: fortran/resolve.c:608
+msgid "module procedure"
+msgstr ""
+
+#: fortran/resolve.c:609
+msgid "internal function"
+msgstr ""
+
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
+msgid "elemental procedure"
+msgstr ""
+
+#: fortran/resolve.c:2245
+msgid "allocatable argument"
+msgstr ""
+
+#: fortran/resolve.c:2250
+msgid "asynchronous argument"
+msgstr ""
+
+#: fortran/resolve.c:2255
+msgid "optional argument"
+msgstr ""
+
+#: fortran/resolve.c:2260
+msgid "pointer argument"
+msgstr ""
+
+#: fortran/resolve.c:2265
+msgid "target argument"
+msgstr ""
+
+#: fortran/resolve.c:2270
+msgid "value argument"
+msgstr ""
+
+#: fortran/resolve.c:2275
+msgid "volatile argument"
+msgstr ""
+
+#: fortran/resolve.c:2280
+msgid "assumed-shape argument"
+msgstr ""
+
+#: fortran/resolve.c:2285
+msgid "assumed-rank argument"
+msgstr ""
+
+#: fortran/resolve.c:2290
+msgid "coarray argument"
+msgstr ""
+
+#: fortran/resolve.c:2295
+msgid "parametrized derived type argument"
+msgstr ""
+
+#: fortran/resolve.c:2300
+msgid "polymorphic argument"
+msgstr ""
+
+#: fortran/resolve.c:2305
+msgid "NO_ARG_CHECK attribute"
+msgstr ""
+
+#. As assumed-type is unlimited polymorphic (cf. above).
+#. See also TS 29113, Note 6.1.
+#: fortran/resolve.c:2312
+msgid "assumed-type argument"
+msgstr ""
+
+#: fortran/resolve.c:2323
+msgid "array result"
+msgstr ""
+
+#: fortran/resolve.c:2328
+msgid "pointer or allocatable result"
+msgstr ""
+
+#: fortran/resolve.c:2335
+msgid "result with non-constant character length"
+msgstr ""
+
+#: fortran/resolve.c:2347
+msgid "bind(c) procedure"
+msgstr ""
+
+#: fortran/resolve.c:3544
+#, c-format
+msgid "Invalid context for NULL() pointer at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3560
+#, c-format
+msgid "Operand of unary numeric operator '%s' at %%L is %s"
+msgstr ""
+
+#: fortran/resolve.c:3576
+#, c-format
+msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
+msgstr ""
+
+#: fortran/resolve.c:3591
+#, c-format
+msgid "Operands of string concatenation operator at %%L are %s/%s"
+msgstr ""
+
+#: fortran/resolve.c:3610
+#, c-format
+msgid "Operands of logical operator '%s' at %%L are %s/%s"
+msgstr ""
+
+#: fortran/resolve.c:3624
+#, c-format
+msgid "Operand of .not. operator at %%L is %s"
+msgstr ""
+
+#: fortran/resolve.c:3638
+msgid "COMPLEX quantities cannot be compared at %L"
+msgstr ""
+
+#: fortran/resolve.c:3689
+#, c-format
+msgid "Logicals at %%L must be compared with %s instead of %s"
+msgstr ""
+
+#: fortran/resolve.c:3695
+#, c-format
+msgid "Operands of comparison operator '%s' at %%L are %s/%s"
+msgstr ""
+
+#: fortran/resolve.c:3703
+#, c-format
+msgid "Unknown operator '%s' at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3705
+#, c-format
+msgid "Operand of user operator '%s' at %%L is %s"
+msgstr ""
+
+#: fortran/resolve.c:3709
+#, c-format
+msgid "Operands of user operator '%s' at %%L are %s/%s"
+msgstr ""
+
+#: fortran/resolve.c:3797
+#, c-format
+msgid "Inconsistent ranks for operator at %%L and %%L"
+msgstr ""
+
+#: fortran/resolve.c:6380
+msgid "Loop variable"
+msgstr ""
+
+#: fortran/resolve.c:6384
+msgid "iterator variable"
+msgstr ""
+
+#: fortran/resolve.c:6388
+msgid "Start expression in DO loop"
+msgstr ""
+
+#: fortran/resolve.c:6392
+msgid "End expression in DO loop"
+msgstr ""
+
+#: fortran/resolve.c:6396
+msgid "Step expression in DO loop"
+msgstr ""
+
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
+msgid "DEALLOCATE object"
+msgstr ""
+
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
+msgid "ALLOCATE object"
+msgstr ""
+
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
+msgid "STAT variable"
+msgstr ""
+
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
+msgid "ERRMSG variable"
+msgstr ""
+
+#: fortran/resolve.c:8428
+msgid "item in READ"
+msgstr ""
+
+#: fortran/resolve.c:8591
+msgid "ACQUIRED_LOCK variable"
+msgstr ""
+
+#: fortran/trans-array.c:1441
+#, c-format
+msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
+msgstr ""
+
+#: fortran/trans-array.c:5307
+msgid "Integer overflow when calculating the amount of memory to allocate"
+msgstr ""
+
+#: fortran/trans-decl.c:5315
+#, c-format
+msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
+msgstr ""
+
+#: fortran/trans-decl.c:5323
+#, c-format
+msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
+msgstr ""
+
+#: fortran/trans-expr.c:7807
+#, c-format
+msgid "Target of rank remapping is too small (%ld < %ld)"
+msgstr ""
+
+#: fortran/trans-intrinsic.c:908
+#, c-format
+msgid "Unequal character lengths (%ld/%ld) in %s"
+msgstr ""
+
+#: fortran/trans-intrinsic.c:6947
+#, c-format
+msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
+msgstr ""
+
+#: fortran/trans-intrinsic.c:6979
+msgid "Argument NCOPIES of REPEAT intrinsic is too large"
+msgstr ""
+
+#: fortran/trans-io.c:572
+msgid "Unit number in I/O statement too small"
+msgstr ""
+
+#: fortran/trans-io.c:581
+msgid "Unit number in I/O statement too large"
+msgstr ""
+
+#: fortran/trans-stmt.c:168
+msgid "Assigned label is not a target label"
+msgstr ""
+
+#: fortran/trans-stmt.c:929
+#, c-format
+msgid "Invalid image number %d in SYNC IMAGES"
+msgstr ""
+
+#: fortran/trans-stmt.c:1670 fortran/trans-stmt.c:1955
+msgid "Loop variable has been modified"
+msgstr ""
+
+#: fortran/trans-stmt.c:1810
+msgid "DO step value is zero"
+msgstr ""
+
+#: fortran/trans.c:58
+msgid "Array reference out of bounds"
+msgstr ""
+
+#: fortran/trans.c:59
+msgid "Incorrect function return value"
+msgstr ""
+
+#: fortran/trans.c:588
+msgid "Memory allocation failed"
+msgstr "Не вдалося отримати місце у пам'яті"
+
+#: fortran/trans.c:674 fortran/trans.c:1513
+msgid "Allocation would exceed memory limit"
+msgstr ""
+
+#: fortran/trans.c:836
+#, c-format
+msgid "Attempting to allocate already allocated variable '%s'"
+msgstr ""
+
+#: fortran/trans.c:842
+msgid "Attempting to allocate already allocated variable"
+msgstr ""
+
+#: fortran/trans.c:1266 fortran/trans.c:1412
+#, c-format
+msgid "Attempt to DEALLOCATE unallocated '%s'"
+msgstr ""
+
+#. The remainder are real diagnostic types.
+#: fortran/gfc-diagnostic.def:33
+msgid "Fatal Error"
+msgstr "Критична помилка"
+
+#. This is like DK_ICE, but backtrace is not printed.  Used in the driver
+#. when reporting fatal signal in the compiler.
+#: fortran/gfc-diagnostic.def:34 fortran/gfc-diagnostic.def:50
+msgid "internal compiler error"
+msgstr ""
+
+#: fortran/gfc-diagnostic.def:35
+msgid "Error"
+msgstr "Помилка"
+
+#: fortran/gfc-diagnostic.def:36
+msgid "sorry, unimplemented"
+msgstr ""
+
+#: fortran/gfc-diagnostic.def:37
+msgid "Warning"
+msgstr "Попередження"
+
+#: fortran/gfc-diagnostic.def:38
+msgid "anachronism"
+msgstr "анахронізм"
+
+#: fortran/gfc-diagnostic.def:39
+msgid "note"
+msgstr "зауваження"
+
+#: fortran/gfc-diagnostic.def:40
+msgid "debug"
+msgstr "діагностика"
+
+#. These two would be re-classified as DK_WARNING or DK_ERROR, so the
+#. prefix does not matter.
+#: fortran/gfc-diagnostic.def:43
+msgid "pedwarn"
+msgstr ""
+
+#: fortran/gfc-diagnostic.def:44
+msgid "permerror"
+msgstr ""
+
+#. This one is just for counting DK_WARNING promoted to DK_ERROR
+#. due to -Werror and -Werror=warning.
+#: fortran/gfc-diagnostic.def:47
+msgid "error"
+msgstr "помилка"
+
+#: go/go-backend.c:182
+msgid "lseek failed while reading export data"
+msgstr ""
+
+#: go/go-backend.c:189
+msgid "memory allocation failed while reading export data"
+msgstr ""
+
+#: go/go-backend.c:197
+msgid "read failed while reading export data"
+msgstr ""
+
+#: go/go-backend.c:203
+msgid "short read while reading export data"
+msgstr ""
+
+#: java/jcf-dump.c:1138
+#, c-format
+msgid "Not a valid Java .class file.\n"
+msgstr ""
+
+#: java/jcf-dump.c:1144
+#, c-format
+msgid "error while parsing constant pool\n"
+msgstr ""
+
+#: java/jcf-dump.c:1150 java/jcf-parse.c:1452
+#, gcc-internal-format, gfc-internal-format
+msgid "error in constant pool entry #%d\n"
+msgstr ""
+
+#: java/jcf-dump.c:1160
+#, c-format
+msgid "error while parsing fields\n"
+msgstr ""
+
+#: java/jcf-dump.c:1166
+#, c-format
+msgid "error while parsing methods\n"
+msgstr ""
+
+#: java/jcf-dump.c:1172
+#, c-format
+msgid "error while parsing final attributes\n"
+msgstr ""
+
+#: java/jcf-dump.c:1209
+#, c-format
+msgid "Try 'jcf-dump --help' for more information.\n"
+msgstr ""
+
+#: java/jcf-dump.c:1216
+#, c-format
+msgid ""
+"Usage: jcf-dump [OPTION]... CLASS...\n"
+"\n"
+msgstr ""
+
+#: java/jcf-dump.c:1217
+#, c-format
+msgid ""
+"Display contents of a class file in readable form.\n"
+"\n"
+msgstr ""
+
+#: java/jcf-dump.c:1218
+#, c-format
+msgid "  -c                      Disassemble method bodies\n"
+msgstr ""
+
+#: java/jcf-dump.c:1219
+#, c-format
+msgid "  --javap                 Generate output in 'javap' format\n"
+msgstr ""
+
+#: java/jcf-dump.c:1221
+#, c-format
+msgid "  --classpath PATH        Set path to find .class files\n"
+msgstr ""
+
+#: java/jcf-dump.c:1222
+#, c-format
+msgid "  -IDIR                   Append directory to class path\n"
+msgstr ""
+
+#: java/jcf-dump.c:1223
+#, c-format
+msgid "  --bootclasspath PATH    Override built-in class path\n"
+msgstr ""
+
+#: java/jcf-dump.c:1224
+#, c-format
+msgid "  --extdirs PATH          Set extensions directory path\n"
+msgstr ""
+
+#: java/jcf-dump.c:1225
+#, c-format
+msgid "  -o FILE                 Set output file name\n"
+msgstr ""
+
+#: java/jcf-dump.c:1227
+#, c-format
+msgid "  --help                  Print this help, then exit\n"
+msgstr ""
+
+#: java/jcf-dump.c:1228
+#, c-format
+msgid "  --version               Print version number, then exit\n"
+msgstr ""
+
+#: java/jcf-dump.c:1229
+#, c-format
+msgid "  -v, --verbose           Print extra information while running\n"
+msgstr ""
+
+#: java/jcf-dump.c:1231
+#, c-format
+msgid ""
+"For bug reporting instructions, please see:\n"
+"%s.\n"
+msgstr ""
+"Настанови щодо звітування про вади можна знайти тут:\n"
+"%s.\n"
+
+#: java/jcf-dump.c:1269 java/jcf-dump.c:1337
+#, c-format
+msgid "jcf-dump: no classes specified\n"
+msgstr ""
+
+#: java/jcf-dump.c:1357
+#, c-format
+msgid "Cannot open '%s' for output.\n"
+msgstr ""
+
+#: java/jcf-dump.c:1402
+#, c-format
+msgid "bad format of .zip/.jar archive\n"
+msgstr ""
+
+#: java/jcf-dump.c:1520
+#, c-format
+msgid "Bad byte codes.\n"
+msgstr ""
+
+#: java/jvgenmain.c:56
+#, c-format
+msgid "Usage: %s [OPTIONS]... CLASSNAMEmain [OUTFILE]\n"
+msgstr ""
+
+#: java/jvgenmain.c:129
+#, c-format
+msgid "%s: Cannot open output file: %s\n"
+msgstr ""
+
+#: java/jvgenmain.c:179
+#, c-format
+msgid "%s: Failed to close output file %s\n"
+msgstr ""
+
+#: objc/objc-act.c:6208 cp/cxx-pretty-print.c:158
+#, gcc-internal-format
+msgid "<unnamed>"
+msgstr ""
+
+#: gcc.c:616 gcc.c:620 gcc.c:675
+msgid "-gz is not supported in this configuration"
+msgstr ""
+
+#: gcc.c:626 gcc.c:686
+msgid "-gz=zlib is not supported in this configuration"
+msgstr ""
+
+#: gcc.c:783
+msgid "-fuse-linker-plugin is not supported in this configuration"
+msgstr ""
+
+#: gcc.c:798
+msgid "cannot specify -static with -fsanitize=address"
+msgstr ""
+
+#: gcc.c:800
+msgid "cannot specify -static with -fsanitize=thread"
+msgstr ""
+
+#: gcc.c:938 ada/gcc-interface/lang-specs.h:33 java/jvspec.c:79
+msgid "-pg and -fomit-frame-pointer are incompatible"
+msgstr ""
+
+#: gcc.c:1113
+msgid "GNU C no longer supports -traditional without -E"
+msgstr ""
+
+#: gcc.c:1122
+msgid "-E or -x required when input is from standard input"
+msgstr ""
+
+#: config/darwin.h:242
+msgid "-current_version only allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:244
+msgid "-install_name only allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:249
+msgid "-bundle not allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:250
+msgid "-bundle_loader not allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:251
+msgid "-client_name not allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:256
+msgid "-force_flat_namespace not allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:258
+msgid "-keep_private_externs not allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:259
+msgid "-private_bundle not allowed with -dynamiclib"
+msgstr ""
+
+#: config/rx/rx.h:75
+msgid "-mas100-syntax is incompatible with -gdwarf"
+msgstr ""
+
+#: config/rx/rx.h:76
+msgid "rx100 cpu does not have FPU hardware"
+msgstr ""
+
+#: config/rx/rx.h:77
+msgid "rx200 cpu does not have FPU hardware"
+msgstr ""
+
+#: config/sol2.h:222 config/sol2.h:227
+msgid "does not support multilib"
+msgstr ""
+
+#: config/arc/arc.h:128 config/mips/mips.h:1322
+msgid "may not use both -EB and -EL"
+msgstr ""
+
+#: config/vxworks.h:70
+msgid "-Xbind-now and -Xbind-lazy are incompatible"
+msgstr ""
+
+#: config/vax/vax.h:46 config/vax/vax.h:47
+msgid "profiling not supported with -mg"
+msgstr ""
+
+#: config/mips/r3900.h:37
+msgid "-mhard-float not supported"
+msgstr ""
+
+#: config/mips/r3900.h:39
+msgid "-msingle-float and -msoft-float cannot both be specified"
+msgstr ""
+
+#: config/cris/cris.h:184
+msgid "do not specify both -march=... and -mcpu=..."
+msgstr ""
+
+#: objc/lang-specs.h:30 objc/lang-specs.h:41
+msgid "GNU Objective C no longer supports traditional compilation"
+msgstr ""
+
+#: objc/lang-specs.h:55
+msgid "objc-cpp-output is deprecated; please use objective-c-cpp-output instead"
+msgstr ""
+
+#: ada/gcc-interface/lang-specs.h:34
+msgid "-c or -S required for Ada"
+msgstr ""
+
+#: ada/gcc-interface/lang-specs.h:52
+msgid "-c required for gnat2why"
+msgstr ""
+
+#: ada/gcc-interface/lang-specs.h:65
+msgid "-c required for gnat2scil"
+msgstr ""
+
+#: config/nios2/elf.h:44
+msgid "You need a C startup file for -msys-crt0="
+msgstr ""
+
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr ""
+
+#: config/sparc/linux64.h:149 config/sparc/linux64.h:156
+#: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
+#: config/sparc/sol2.h:219 config/sparc/sol2.h:225
+msgid "may not use both -m32 and -m64"
+msgstr ""
+
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr ""
+
+#: config/s390/tpf.h:106
+msgid "static is not supported on TPF-OS"
+msgstr ""
+
+#: config/arm/arm.h:225
+msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
+msgstr ""
+
+#: config/arm/arm.h:227 config/tilegx/tilegx.h:546 config/tilegx/tilegx.h:551
+msgid "-mbig-endian and -mlittle-endian may not be used together"
+msgstr ""
+
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr ""
+
+#: config/avr/specs.h:68
+msgid "shared is not supported"
+msgstr ""
+
+#: objcp/lang-specs.h:58
+msgid "objc++-cpp-output is deprecated; please use objective-c++-cpp-output instead"
+msgstr ""
+
+#: fortran/lang-specs.h:54 fortran/lang-specs.h:68
+msgid "gfortran does not support -E without -cpp"
+msgstr ""
+
+#: config/arm/freebsd.h:49
+msgid "consider using `-pg' instead of `-p' with gprof (1) "
+msgstr ""
+
+#: config/i386/mingw-w64.h:87 config/i386/cygwin-w64.h:64
+#: config/i386/mingw32.h:117 config/i386/cygwin.h:129
+msgid "shared and mdll are not compatible"
+msgstr ""
+
+#: config/bfin/elf.h:55
+msgid "no processor type specified for linking"
+msgstr ""
+
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
+msgid "warning: consider linking with '-static' as system libraries with"
+msgstr ""
+
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
+msgid "  profiling support are only provided in archive format"
+msgstr ""
+
+#: config/rs6000/darwin.h:95
+msgid " conflicting code gen style switches are used"
+msgstr ""
+
+#: config/sh/sh.h:375 config/sh/sh.h:378
+msgid "SH2a does not support little-endian"
+msgstr ""
+
+#: config/lynx.h:69
+msgid "cannot use mthreads and mlegacy-threads together"
+msgstr ""
+
+#: config/lynx.h:94
+msgid "cannot use mshared and static together"
+msgstr ""
+
+#: java/lang-specs.h:32
+msgid "-fjni and -femit-class-files are incompatible"
+msgstr ""
+
+#: java/lang-specs.h:33
+msgid "-fjni and -femit-class-file are incompatible"
+msgstr ""
+
+#: java/lang-specs.h:34 java/lang-specs.h:35
+msgid "-femit-class-file should used along with -fsyntax-only"
+msgstr ""
+
+#: config/vax/netbsd-elf.h:51
+msgid "the -shared option is not currently supported for VAX ELF"
+msgstr ""
+
+#: fortran/lang.opt:146
+msgid "-J<directory>\tPut MODULE files in 'directory'"
+msgstr ""
+
+#: fortran/lang.opt:198
+msgid "Warn about possible aliasing of dummy arguments"
+msgstr ""
+
+#: fortran/lang.opt:202
+msgid "Warn about alignment of COMMON blocks"
+msgstr ""
+
+#: fortran/lang.opt:206
+msgid "Warn about missing ampersand in continued character constants"
+msgstr ""
+
+#: fortran/lang.opt:210
+msgid "Warn about creation of array temporaries"
+msgstr ""
+
+#: fortran/lang.opt:214
+msgid "Warn if the type of a variable might be not interoperable with C"
+msgstr ""
+
+#: fortran/lang.opt:222
+msgid "Warn about truncated character expressions"
+msgstr ""
+
+#: fortran/lang.opt:226
+msgid "Warn about equality comparisons involving REAL or COMPLEX expressions"
+msgstr ""
+
+#: fortran/lang.opt:234
+msgid "Warn about most implicit conversions"
+msgstr ""
+
+#: fortran/lang.opt:242
+msgid "Warn about function call elimination"
+msgstr ""
+
+#: fortran/lang.opt:246
+msgid "Warn about calls with implicit interface"
+msgstr ""
+
+#: fortran/lang.opt:250
+msgid "Warn about called procedures not explicitly declared"
+msgstr ""
+
+#: fortran/lang.opt:254
+msgid "Warn about truncated source lines"
+msgstr ""
+
+#: fortran/lang.opt:258
+msgid "Warn on intrinsics not part of the selected standard"
+msgstr ""
+
+#: fortran/lang.opt:270
+msgid "Warn about USE statements that have no ONLY qualifier"
+msgstr ""
+
+#: fortran/lang.opt:282
+msgid "Warn about real-literal-constants with 'q' exponent-letter"
+msgstr ""
+
+#: fortran/lang.opt:286
+msgid "Warn when a left-hand-side array variable is reallocated"
+msgstr ""
+
+#: fortran/lang.opt:290
+msgid "Warn when a left-hand-side variable is reallocated"
+msgstr ""
+
+#: fortran/lang.opt:294
+msgid "Warn if the pointer in a pointer assignment might outlive its target"
+msgstr ""
+
+#: fortran/lang.opt:302
+msgid "Warn about \"suspicious\" constructs"
+msgstr ""
+
+#: fortran/lang.opt:306
+msgid "Permit nonconforming uses of the tab character"
+msgstr ""
+
+#: fortran/lang.opt:310
+msgid "Warn about underflow of numerical constant expressions"
+msgstr ""
+
+#: fortran/lang.opt:318
+msgid "Warn if a user-procedure has the same name as an intrinsic"
+msgstr ""
+
+#: fortran/lang.opt:326
+msgid "Warn about unused dummy arguments."
+msgstr ""
+
+#: fortran/lang.opt:330
+msgid "Warn about zero-trip DO loops"
+msgstr ""
+
+#: fortran/lang.opt:334
+msgid "Enable preprocessing"
+msgstr ""
+
+#: fortran/lang.opt:342
+msgid "Disable preprocessing"
+msgstr ""
+
+#: fortran/lang.opt:350
+msgid "Eliminate multiple function invokations also for impure functions"
+msgstr ""
+
+#: fortran/lang.opt:354
+msgid "Enable alignment of COMMON blocks"
+msgstr ""
+
+#: fortran/lang.opt:358
+msgid "All intrinsics procedures are available regardless of selected standard"
+msgstr ""
+
+#: fortran/lang.opt:366
+msgid "Do not treat local variables and COMMON blocks as if they were named in SAVE statements"
+msgstr ""
+
+#: fortran/lang.opt:370
+msgid "Specify that backslash in string introduces an escape character"
+msgstr ""
+
+#: fortran/lang.opt:374
+msgid "Produce a backtrace when a runtime error is encountered"
+msgstr ""
+
+#: fortran/lang.opt:378
+msgid "-fblas-matmul-limit=<n>\tSize of the smallest matrix for which matmul will use BLAS"
+msgstr ""
+
+#: fortran/lang.opt:382
+msgid "Produce a warning at runtime if a array temporary has been created for a procedure argument"
+msgstr ""
+
+#: fortran/lang.opt:386
+msgid "-fconvert=<big-endian|little-endian|native|swap> The endianness used for unformatted files."
+msgstr ""
+
+#: fortran/lang.opt:389
+#, c-format
+msgid "Unrecognized option to endianess value: %qs"
+msgstr ""
+
+#: fortran/lang.opt:405
+msgid "Use the Cray Pointer extension"
+msgstr ""
+
+#: fortran/lang.opt:409
+msgid "Ignore 'D' in column one in fixed form"
+msgstr ""
+
+#: fortran/lang.opt:413
+msgid "Treat lines with 'D' in column one as comments"
+msgstr ""
+
+#: fortran/lang.opt:417
+msgid "Set the default double precision kind to an 8 byte wide type"
+msgstr ""
+
+#: fortran/lang.opt:421
+msgid "Set the default integer kind to an 8 byte wide type"
+msgstr ""
+
+#: fortran/lang.opt:425
+msgid "Set the default real kind to an 8 byte wide type"
+msgstr ""
+
+#: fortran/lang.opt:429
+msgid "Allow dollar signs in entity names"
+msgstr ""
+
+#: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
+msgid "Does nothing. Preserved for backward compatibility."
+msgstr ""
+
+#: fortran/lang.opt:437
+msgid "Display the code tree after parsing"
+msgstr ""
+
+#: fortran/lang.opt:441
+msgid "Display the code tree after front end optimization"
+msgstr ""
+
+#: fortran/lang.opt:445
+msgid "Display the code tree after parsing; deprecated option"
+msgstr ""
+
+#: fortran/lang.opt:449
+msgid "Specify that an external BLAS library should be used for matmul calls on large-size arrays"
+msgstr ""
+
+#: fortran/lang.opt:453
+msgid "Use f2c calling convention"
+msgstr ""
+
+#: fortran/lang.opt:457
+msgid "Assume that the source file is fixed form"
+msgstr ""
+
+#: fortran/lang.opt:461
+msgid "Interpret any INTEGER(4) as an INTEGER(8)"
+msgstr ""
+
+#: fortran/lang.opt:465 fortran/lang.opt:469
+msgid "Specify where to find the compiled intrinsic modules"
+msgstr ""
+
+#: fortran/lang.opt:473
+msgid "Allow arbitrary character line width in fixed mode"
+msgstr ""
+
+#: fortran/lang.opt:477
+msgid "-ffixed-line-length-<n>\tUse n as character line width in fixed mode"
+msgstr ""
+
+#: fortran/lang.opt:481
+msgid "-ffpe-trap=[...]\tStop on following floating point exceptions"
+msgstr ""
+
+#: fortran/lang.opt:485
+msgid "-ffpe-summary=[...]\tPrint summary of floating point exceptions"
+msgstr ""
+
+#: fortran/lang.opt:489
+msgid "Assume that the source file is free form"
+msgstr ""
+
+#: fortran/lang.opt:493
+msgid "Allow arbitrary character line width in free mode"
+msgstr ""
+
+#: fortran/lang.opt:497
+msgid "-ffree-line-length-<n>\tUse n as character line width in free mode"
+msgstr ""
+
+#: fortran/lang.opt:501
+msgid "Enable front end optimization"
+msgstr ""
+
+#: fortran/lang.opt:505
+msgid "Specify that no implicit typing is allowed, unless overridden by explicit IMPLICIT statements"
+msgstr ""
+
+#: fortran/lang.opt:509
+msgid "-finit-character=<n>\tInitialize local character variables to ASCII value n"
+msgstr ""
+
+#: fortran/lang.opt:513
+msgid "-finit-integer=<n>\tInitialize local integer variables to n"
+msgstr ""
+
+#: fortran/lang.opt:517
+msgid "Initialize local variables to zero (from g77)"
+msgstr ""
+
+#: fortran/lang.opt:521
+msgid "-finit-logical=<true|false>\tInitialize local logical variables"
+msgstr ""
+
+#: fortran/lang.opt:525
+msgid "-finit-real=<zero|snan|nan|inf|-inf>\tInitialize local real variables"
+msgstr ""
+
+#: fortran/lang.opt:528
+#, c-format
+msgid "Unrecognized option to floating-point init value: %qs"
+msgstr ""
+
+#: fortran/lang.opt:547
+msgid "-fmax-array-constructor=<n>\tMaximum number of objects in an array constructor"
+msgstr ""
+
+#: fortran/lang.opt:551
+msgid "-fmax-identifier-length=<n>\tMaximum identifier length"
+msgstr ""
+
+#: fortran/lang.opt:555
+msgid "-fmax-subrecord-length=<n>\tMaximum length for subrecords"
+msgstr ""
+
+#: fortran/lang.opt:559
+msgid "-fmax-stack-var-size=<n>\tSize in bytes of the largest array that will be put on the stack"
+msgstr ""
+
+#: fortran/lang.opt:563
+msgid "Put all local arrays on stack."
+msgstr ""
+
+#: fortran/lang.opt:567
+msgid "Set default accessibility of module entities to PRIVATE."
+msgstr ""
+
+#: fortran/lang.opt:583
+msgid "Try to lay out derived types as compactly as possible"
+msgstr ""
+
+#: fortran/lang.opt:591
+msgid "Protect parentheses in expressions"
+msgstr ""
+
+#: fortran/lang.opt:595
+msgid "Enable range checking during compilation"
+msgstr ""
+
+#: fortran/lang.opt:599
+msgid "Interpret any REAL(4) as a REAL(8)"
+msgstr ""
+
+#: fortran/lang.opt:603
+msgid "Interpret any REAL(4) as a REAL(10)"
+msgstr ""
+
+#: fortran/lang.opt:607
+msgid "Interpret any REAL(4) as a REAL(16)"
+msgstr ""
+
+#: fortran/lang.opt:611
+msgid "Interpret any REAL(8) as a REAL(4)"
+msgstr ""
+
+#: fortran/lang.opt:615
+msgid "Interpret any REAL(8) as a REAL(10)"
+msgstr ""
+
+#: fortran/lang.opt:619
+msgid "Interpret any REAL(8) as a REAL(16)"
+msgstr ""
+
+#: fortran/lang.opt:623
+msgid "Reallocate the LHS in assignments"
+msgstr ""
+
+#: fortran/lang.opt:627
+msgid "Use a 4-byte record marker for unformatted files"
+msgstr ""
+
+#: fortran/lang.opt:631
+msgid "Use an 8-byte record marker for unformatted files"
+msgstr ""
+
+#: fortran/lang.opt:635
+msgid "Allocate local variables on the stack to allow indirect recursion"
+msgstr ""
+
+#: fortran/lang.opt:639
+msgid "Copy array sections into a contiguous block on procedure entry"
+msgstr ""
+
+#: fortran/lang.opt:643
+msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used"
+msgstr ""
+
+#: fortran/lang.opt:646
+#, c-format
+msgid "Unrecognized option: %qs"
+msgstr ""
+
+#: fortran/lang.opt:659
+msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed"
+msgstr ""
+
+#: fortran/lang.opt:663
+msgid "Append a second underscore if the name already contains an underscore"
+msgstr ""
+
+#: fortran/lang.opt:671
+msgid "Apply negative sign to zero values"
+msgstr ""
+
+#: fortran/lang.opt:675
+msgid "Append underscores to externally visible names"
+msgstr ""
+
+#: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
+#: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
+msgid "Does nothing.  Preserved for backward compatibility."
+msgstr ""
+
+#: fortran/lang.opt:719
+msgid "Statically link the GNU Fortran helper library (libgfortran)"
+msgstr ""
+
+#: fortran/lang.opt:723
+msgid "Conform to the ISO Fortran 2003 standard"
+msgstr ""
+
+#: fortran/lang.opt:727
+msgid "Conform to the ISO Fortran 2008 standard"
+msgstr ""
+
+#: fortran/lang.opt:731
+msgid "Conform to the ISO Fortran 2008 standard including TS 29113"
+msgstr ""
+
+#: fortran/lang.opt:735
+msgid "Conform to the ISO Fortran 95 standard"
+msgstr ""
+
+#: fortran/lang.opt:739
+msgid "Conform to nothing in particular"
+msgstr ""
+
+#: fortran/lang.opt:743
+msgid "Accept extensions to support legacy code"
+msgstr ""
+
+#: c-family/c.opt:43 c-family/c.opt:46 c-family/c.opt:181
+#, c-format
+msgid "assertion missing after %qs"
+msgstr ""
+
+#: c-family/c.opt:55 c-family/c.opt:58 c-family/c.opt:163 c-family/c.opt:166
+#: c-family/c.opt:193 c-family/c.opt:252
+#, c-format
+msgid "macro name missing after %qs"
+msgstr ""
+
+#: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
+#: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
+#: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
+#, c-format
+msgid "missing filename after %qs"
+msgstr ""
+
+#: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
+#: c-family/c.opt:200 c-family/c.opt:208 c-family/c.opt:1493
+#: c-family/c.opt:1513 c-family/c.opt:1517 c-family/c.opt:1521
+#, c-format
+msgid "missing path after %qs"
+msgstr ""
+
+#: c-family/c.opt:182
+msgid "-A<question>=<answer>\tAssert the <answer> to <question>.  Putting '-' before <question> disables the <answer> to <question>"
+msgstr ""
+
+#: c-family/c.opt:186
+msgid "Do not discard comments"
+msgstr ""
+
+#: c-family/c.opt:190
+msgid "Do not discard comments in macro expansions"
+msgstr ""
+
+#: c-family/c.opt:194
+msgid "-D<macro>[=<val>]\tDefine a <macro> with <val> as its value.  If just <macro> is given, <val> is taken to be 1"
+msgstr ""
+
+#: c-family/c.opt:201
+msgid "-F <dir>\tAdd <dir> to the end of the main framework include path"
+msgstr ""
+
+#: c-family/c.opt:205
+msgid "Print the name of header files as they are used"
+msgstr ""
+
+#: c-family/c.opt:209
+msgid "-I <dir>\tAdd <dir> to the end of the main include path"
+msgstr ""
+
+#: c-family/c.opt:213
+msgid "Generate make dependencies"
+msgstr ""
+
+#: c-family/c.opt:217
+msgid "Generate make dependencies and compile"
+msgstr ""
+
+#: c-family/c.opt:221
+msgid "-MF <file>\tWrite dependency output to the given file"
+msgstr ""
+
+#: c-family/c.opt:225
+msgid "Treat missing header files as generated files"
+msgstr ""
+
+#: c-family/c.opt:229
+msgid "Like -M but ignore system header files"
+msgstr ""
+
+#: c-family/c.opt:233
+msgid "Like -MD but ignore system header files"
+msgstr ""
+
+#: c-family/c.opt:237
+msgid "Generate phony targets for all headers"
+msgstr ""
+
+#: c-family/c.opt:240 c-family/c.opt:244
+#, c-format
+msgid "missing makefile target after %qs"
+msgstr ""
+
+#: c-family/c.opt:241
+msgid "-MQ <target>\tAdd a MAKE-quoted target"
+msgstr ""
+
+#: c-family/c.opt:245
+msgid "-MT <target>\tAdd an unquoted target"
+msgstr ""
+
+#: c-family/c.opt:249
+msgid "Do not generate #line directives"
+msgstr ""
+
+#: c-family/c.opt:253
+msgid "-U<macro>\tUndefine <macro>"
+msgstr ""
+
+#: c-family/c.opt:257
+msgid "Warn about things that will change when compiling with an ABI-compliant compiler"
+msgstr ""
+
+#: c-family/c.opt:261
+msgid "Warn about things that change between the current -fabi-version and the specified version"
+msgstr ""
+
+#: c-family/c.opt:265
+msgid "Warn if a subobject has an abi_tag attribute that the complete object type does not have"
+msgstr ""
+
+#: c-family/c.opt:272
+msgid "Warn about suspicious uses of memory addresses"
+msgstr ""
+
+#: c-family/c.opt:276 ada/gcc-interface/lang.opt:57
+msgid "Enable most warning messages"
+msgstr ""
+
+#: c-family/c.opt:288
+msgid "Warn whenever an Objective-C assignment is being intercepted by the garbage collector"
+msgstr ""
+
+#: c-family/c.opt:292
+msgid "Warn about casting functions to incompatible types"
+msgstr ""
+
+#: c-family/c.opt:296
+msgid "Warn about boolean expression compared with an integer value different from true/false"
+msgstr ""
+
+#: c-family/c.opt:300
+msgid "Warn when a built-in preprocessor macro is undefined or redefined"
+msgstr ""
+
+#: c-family/c.opt:304
+msgid "Warn about features not present in ISO C90, but present in ISO C99"
+msgstr ""
+
+#: c-family/c.opt:308
+msgid "Warn about features not present in ISO C99, but present in ISO C11"
+msgstr ""
+
+#: c-family/c.opt:312
+msgid "Warn about C constructs that are not in the common subset of C and C++"
+msgstr ""
+
+#: c-family/c.opt:316
+msgid "Deprecated in favor of -Wc++11-compat"
+msgstr ""
+
+#: c-family/c.opt:320
+msgid "Warn about C++ constructs whose meaning differs between ISO C++ 1998 and ISO C++ 2011"
+msgstr ""
+
+#: c-family/c.opt:324
+msgid "Warn about C++ constructs whose meaning differs between ISO C++ 2011 and ISO C++ 2014"
+msgstr ""
+
+#: c-family/c.opt:328
+msgid "Warn about casts which discard qualifiers"
+msgstr ""
+
+#: c-family/c.opt:332
+msgid "Warn about subscripts whose type is \"char\""
+msgstr ""
+
+#: c-family/c.opt:336
+msgid "Warn about memory access errors found by Pointer Bounds Checker"
+msgstr ""
+
+#: c-family/c.opt:340
+msgid "Warn about variables that might be changed by \"longjmp\" or \"vfork\""
+msgstr ""
+
+#: c-family/c.opt:344
+msgid "Warn about possibly nested block comments, and C++ comments spanning more than one physical line"
+msgstr ""
+
+#: c-family/c.opt:348
+msgid "Synonym for -Wcomment"
+msgstr ""
+
+#: c-family/c.opt:352
+msgid "Warn for conditionally-supported constructs"
+msgstr ""
+
+#: c-family/c.opt:356
+msgid "Warn for implicit type conversions that may change a value"
+msgstr ""
+
+#: c-family/c.opt:360
+msgid "Warn for converting NULL from/to a non-pointer type"
+msgstr ""
+
+#: c-family/c.opt:368
+msgid "Warn when all constructors and destructors are private"
+msgstr ""
+
+#: c-family/c.opt:372
+msgid "Warn about __TIME__, __DATE__ and __TIMESTAMP__ usage"
+msgstr ""
+
+#: c-family/c.opt:376
+msgid "Warn when a declaration is found after a statement"
+msgstr ""
+
+#: c-family/c.opt:380
+msgid "Warn when deleting a pointer to incomplete type"
+msgstr ""
+
+#: c-family/c.opt:384
+msgid "Warn about deleting polymorphic objects with non-virtual destructors"
+msgstr ""
+
+#: c-family/c.opt:388
+msgid "Warn if a deprecated compiler feature, class, method, or field is used"
+msgstr ""
+
+#: c-family/c.opt:392
+msgid "Warn about positional initialization of structs requiring designated initializers"
+msgstr ""
+
+#: c-family/c.opt:396
+msgid "Warn if qualifiers on arrays which are pointer targets are discarded"
+msgstr ""
+
+#: c-family/c.opt:400
+msgid "Warn if type qualifiers on pointers are discarded"
+msgstr ""
+
+#: c-family/c.opt:404
+msgid "Warn about compile-time integer division by zero"
+msgstr ""
+
+#: c-family/c.opt:408
+msgid "Warn about violations of Effective C++ style rules"
+msgstr ""
+
+#: c-family/c.opt:412
+msgid "Warn about an empty body in an if or else statement"
+msgstr ""
+
+#: c-family/c.opt:416
+msgid "Warn about stray tokens after #elif and #endif"
+msgstr ""
+
+#: c-family/c.opt:420
+msgid "Warn about comparison of different enum types"
+msgstr ""
+
+#: c-family/c.opt:428
+msgid "This switch is deprecated; use -Werror=implicit-function-declaration instead"
+msgstr ""
+
+#: c-family/c.opt:432
+msgid "Warn for implicit type conversions that cause loss of floating point precision"
+msgstr ""
+
+#: c-family/c.opt:436
+msgid "Warn if testing floating point numbers for equality"
+msgstr ""
+
+#: c-family/c.opt:440 c-family/c.opt:472
+msgid "Warn about printf/scanf/strftime/strfmon format string anomalies"
+msgstr ""
+
+#: c-family/c.opt:444
+msgid "Warn about format strings that contain NUL bytes"
+msgstr ""
+
+#: c-family/c.opt:448
+msgid "Warn if passing too many arguments to a function for its format string"
+msgstr ""
+
+#: c-family/c.opt:452
+msgid "Warn about format strings that are not literals"
+msgstr ""
+
+#: c-family/c.opt:456
+msgid "Warn about possible security problems with format functions"
+msgstr ""
+
+#: c-family/c.opt:460
+msgid "Warn about sign differences with format functions"
+msgstr ""
+
+#: c-family/c.opt:464
+msgid "Warn about strftime formats yielding 2-digit years"
+msgstr ""
+
+#: c-family/c.opt:468
+msgid "Warn about zero-length formats"
+msgstr ""
+
+#: c-family/c.opt:476
+msgid "Warn whenever type qualifiers are ignored."
+msgstr ""
+
+#: c-family/c.opt:480
+msgid "Warn when there is a conversion between pointers that have incompatible types"
+msgstr ""
+
+#: c-family/c.opt:484
+msgid "Warn about variables which are initialized to themselves"
+msgstr ""
+
+#: c-family/c.opt:488
+msgid "Warn about implicit declarations"
+msgstr ""
+
+#: c-family/c.opt:492
+msgid "Warn about implicit conversions from \"float\" to \"double\""
+msgstr ""
+
+#: c-family/c.opt:496
+msgid "Warn about implicit function declarations"
+msgstr ""
+
+#: c-family/c.opt:500
+msgid "Warn when a declaration does not specify a type"
+msgstr ""
+
+#: c-family/c.opt:507
+msgid "Warn about C++11 inheriting constructors when the base has a variadic constructor"
+msgstr ""
+
+#: c-family/c.opt:511
+msgid "Warn about incompatible integer to pointer and pointer to integer conversions"
+msgstr ""
+
+#: c-family/c.opt:515
+msgid "Warn when there is a cast to a pointer from an integer of a different size"
+msgstr ""
+
+#: c-family/c.opt:519
+msgid "Warn about invalid uses of the \"offsetof\" macro"
+msgstr ""
+
+#: c-family/c.opt:523
+msgid "Warn about PCH files that are found but not used"
+msgstr ""
+
+#: c-family/c.opt:527
+msgid "Warn when a jump misses a variable initialization"
+msgstr ""
+
+#: c-family/c.opt:531
+msgid "Warn when a string or character literal is followed by a ud-suffix which does not begin with an underscore."
+msgstr ""
+
+#: c-family/c.opt:535
+msgid "Warn when a logical operator is suspiciously always evaluating to true or false"
+msgstr ""
+
+#: c-family/c.opt:539
+msgid "Warn when logical not is used on the left hand side operand of a comparison"
+msgstr ""
+
+#: c-family/c.opt:543
+msgid "Do not warn about using \"long long\" when -pedantic"
+msgstr ""
+
+#: c-family/c.opt:547
+msgid "Warn about suspicious declarations of \"main\""
+msgstr ""
+
+#: c-family/c.opt:555
+msgid "Warn about suspicious calls to memset where the third argument is constant literal zero and the second is not"
+msgstr ""
+
+#: c-family/c.opt:559
+msgid "Warn about possibly missing braces around initializers"
+msgstr ""
+
+#: c-family/c.opt:563
+msgid "Warn about global functions without previous declarations"
+msgstr ""
+
+#: c-family/c.opt:567
+msgid "Warn about missing fields in struct initializers"
+msgstr ""
+
+#: c-family/c.opt:571
+msgid "Warn about missing sized deallocation functions"
+msgstr ""
+
+#: c-family/c.opt:575
+msgid "Warn about suspicious length parameters to certain string functions if the argument uses sizeof"
+msgstr ""
+
+#: c-family/c.opt:579
+msgid "Warn when sizeof is applied on a parameter declared as an array"
+msgstr ""
+
+#: c-family/c.opt:583
+msgid "Warn about functions which might be candidates for format attributes"
+msgstr ""
+
+#: c-family/c.opt:587
+msgid "Suggest that the override keyword be used when the declaration of a virtual"
+msgstr ""
+
+#: c-family/c.opt:592
+msgid "Warn about enumerated switches, with no default, missing a case"
+msgstr ""
+
+#: c-family/c.opt:596
+msgid "Warn about enumerated switches missing a \"default:\" statement"
+msgstr ""
+
+#: c-family/c.opt:600
+msgid "Warn about all enumerated switches missing a specific case"
+msgstr ""
+
+#: c-family/c.opt:604
+msgid "Warn about switches with boolean controlling expression"
+msgstr ""
+
+#: c-family/c.opt:612
+msgid "Warn about user-specified include directories that do not exist"
+msgstr ""
+
+#: c-family/c.opt:616
+msgid "Warn about function parameters declared without a type specifier in K&R-style functions"
+msgstr ""
+
+#: c-family/c.opt:620
+msgid "Warn about global functions without prototypes"
+msgstr ""
+
+#: c-family/c.opt:623 c-family/c.opt:937 c-family/c.opt:944
+#: c-family/c.opt:1114 c-family/c.opt:1133 c-family/c.opt:1156
+#: c-family/c.opt:1162 c-family/c.opt:1169 c-family/c.opt:1193
+#: c-family/c.opt:1204 c-family/c.opt:1207 c-family/c.opt:1210
+#: c-family/c.opt:1213 c-family/c.opt:1216 c-family/c.opt:1253
+#: c-family/c.opt:1384 c-family/c.opt:1395 c-family/c.opt:1413
+#: c-family/c.opt:1444 c-family/c.opt:1448 c-family/c.opt:1464
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:426
+#, gcc-internal-format
+msgid "switch %qs is no longer supported"
+msgstr ""
+
+#: c-family/c.opt:627
+msgid "Warn about use of multi-character character constants"
+msgstr ""
+
+#: c-family/c.opt:631
+msgid "Warn about narrowing conversions within { } that are ill-formed in C++11"
+msgstr ""
+
+#: c-family/c.opt:635
+msgid "Warn about \"extern\" declarations not at file scope"
+msgstr ""
+
+#: c-family/c.opt:639
+msgid "Warn when a noexcept expression evaluates to false even though the expression can't actually throw"
+msgstr ""
+
+#: c-family/c.opt:643
+msgid "Warn when non-templatized friend functions are declared within a template"
+msgstr ""
+
+#: c-family/c.opt:647
+msgid "Warn about non-virtual destructors"
+msgstr ""
+
+#: c-family/c.opt:651
+msgid "Warn about NULL being passed to argument slots marked as requiring non-NULL"
+msgstr ""
+
+#: c-family/c.opt:663
+msgid "-Wnormalized=<none|id|nfc|nfkc>\tWarn about non-normalised Unicode strings"
+msgstr ""
+
+#: c-family/c.opt:670
+msgid "argument %qs to %<-Wnormalized%> not recognized"
+msgstr ""
+
+#: c-family/c.opt:686
+msgid "Warn if a C-style cast is used in a program"
+msgstr ""
+
+#: c-family/c.opt:690
+msgid "Warn for obsolescent usage in a declaration"
+msgstr ""
+
+#: c-family/c.opt:694
+msgid "Warn if an old-style parameter definition is used"
+msgstr ""
+
+#: c-family/c.opt:698
+msgid "Warn if a simd directive is overridden by the vectorizer cost model"
+msgstr ""
+
+#: c-family/c.opt:702
+msgid "Warn if a string is longer than the maximum portable length specified by the standard"
+msgstr ""
+
+#: c-family/c.opt:706
+msgid "Warn about overloaded virtual function names"
+msgstr ""
+
+#: c-family/c.opt:710
+msgid "Warn about overriding initializers without side effects"
+msgstr ""
+
+#: c-family/c.opt:714
+msgid "Warn about packed bit-fields whose offset changed in GCC 4.4"
+msgstr ""
+
+#: c-family/c.opt:718
+msgid "Warn about possibly missing parentheses"
+msgstr ""
+
+#: c-family/c.opt:726
+msgid "Warn when converting the type of pointers to member functions"
+msgstr ""
+
+#: c-family/c.opt:730
+msgid "Warn about function pointer arithmetic"
+msgstr ""
+
+#: c-family/c.opt:734
+msgid "Warn when a pointer differs in signedness in an assignment"
+msgstr ""
+
+#: c-family/c.opt:738
+msgid "Warn when a pointer is cast to an integer of a different size"
+msgstr ""
+
+#: c-family/c.opt:742
+msgid "Warn about misuses of pragmas"
+msgstr ""
+
+#: c-family/c.opt:746
+msgid "Warn if a property for an Objective-C object has no assign semantics specified"
+msgstr ""
+
+#: c-family/c.opt:750
+msgid "Warn if inherited methods are unimplemented"
+msgstr ""
+
+#: c-family/c.opt:754
+msgid "Warn about multiple declarations of the same object"
+msgstr ""
+
+#: c-family/c.opt:758
+msgid "Warn when the compiler reorders code"
+msgstr ""
+
+#: c-family/c.opt:762
+msgid "Warn whenever a function's return type defaults to \"int\" (C), or about inconsistent return types (C++)"
+msgstr ""
+
+#: c-family/c.opt:766
+msgid "Warn if a selector has multiple methods"
+msgstr ""
+
+#: c-family/c.opt:770
+msgid "Warn about possible violations of sequence point rules"
+msgstr ""
+
+#: c-family/c.opt:774
+msgid "Warn if a local declaration hides an instance variable"
+msgstr ""
+
+#: c-family/c.opt:778
+msgid "Warn if shift count is negative"
+msgstr ""
+
+#: c-family/c.opt:782
+msgid "Warn if shift count >= width of type"
+msgstr ""
+
+#: c-family/c.opt:786
+msgid "Warn about signed-unsigned comparisons"
+msgstr ""
+
+#: c-family/c.opt:794
+msgid "Warn for implicit type conversions between signed and unsigned integers"
+msgstr ""
+
+#: c-family/c.opt:798
+msgid "Warn when overload promotes from unsigned to signed"
+msgstr ""
+
+#: c-family/c.opt:802
+msgid "Warn about uncasted NULL used as sentinel"
+msgstr ""
+
+#: c-family/c.opt:806
+msgid "Warn about unprototyped function declarations"
+msgstr ""
+
+#: c-family/c.opt:818
+msgid "Warn if type signatures of candidate methods do not match exactly"
+msgstr ""
+
+#: c-family/c.opt:822
+msgid "Warn when __sync_fetch_and_nand and __sync_nand_and_fetch built-in functions are used"
+msgstr ""
+
+#: c-family/c.opt:826
+msgid "Deprecated.  This switch has no effect"
+msgstr ""
+
+#: c-family/c.opt:834
+msgid "Warn about features not present in traditional C"
+msgstr ""
+
+#: c-family/c.opt:838
+msgid "Warn of prototypes causing type conversions different from what would happen in the absence of prototype"
+msgstr ""
+
+#: c-family/c.opt:842
+msgid "Warn if trigraphs are encountered that might affect the meaning of the program"
+msgstr ""
+
+#: c-family/c.opt:846
+msgid "Warn about @selector()s without previously declared methods"
+msgstr ""
+
+#: c-family/c.opt:850
+msgid "Warn if an undefined macro is used in an #if directive"
+msgstr ""
+
+#: c-family/c.opt:862
+msgid "Warn about unrecognized pragmas"
+msgstr ""
+
+#: c-family/c.opt:866
+msgid "Warn about unsuffixed float constants"
+msgstr ""
+
+#: c-family/c.opt:874
+msgid "Warn when typedefs locally defined in a function are not used"
+msgstr ""
+
+#: c-family/c.opt:878
+msgid "Warn about macros defined in the main file that are not used"
+msgstr ""
+
+#: c-family/c.opt:882
+msgid "Warn if a caller of a function, marked with attribute warn_unused_result, does not use its return value"
+msgstr ""
+
+#: c-family/c.opt:886
+msgid "Warn about using variadic macros"
+msgstr ""
+
+#: c-family/c.opt:890
+msgid "Warn about questionable usage of the macros used to retrieve variable arguments"
+msgstr ""
+
+#: c-family/c.opt:894
+msgid "Warn if a variable length array is used"
+msgstr ""
+
+#: c-family/c.opt:898
+msgid "Warn when a register variable is declared volatile"
+msgstr ""
+
+#: c-family/c.opt:902
+msgid "Warn if a virtual base has a non-trivial move assignment operator"
+msgstr ""
+
+#: c-family/c.opt:906
+msgid "In C++, nonzero means warn about deprecated conversion from string literals to 'char *'.  In C, similar warning, except that the conversion is of course not deprecated by the ISO C standard."
+msgstr ""
+
+#: c-family/c.opt:910
+msgid "Warn when a literal '0' is used as null pointer"
+msgstr ""
+
+#: c-family/c.opt:914
+msgid "Warn about useless casts"
+msgstr ""
+
+#: c-family/c.opt:918
+msgid "A synonym for -std=c89 (for C) or -std=c++98 (for C++)"
+msgstr ""
+
+#: c-family/c.opt:926
+msgid "The version of the C++ ABI used for -Wabi warnings and link compatibility aliases"
+msgstr ""
+
+#: c-family/c.opt:930
+msgid "Enforce class member access control semantics"
+msgstr ""
+
+#: c-family/c.opt:934
+msgid "-fada-spec-parent=unit  Dump Ada specs as child units of given parent"
+msgstr ""
+
+#: c-family/c.opt:941
+msgid "Allow variadic functions without named parameter"
+msgstr ""
+
+#: c-family/c.opt:945 c-family/c.opt:1170 c-family/c.opt:1445
+#: c-family/c.opt:1449 c-family/c.opt:1465
+msgid "No longer supported"
+msgstr "Більше не підтримується"
+
+#: c-family/c.opt:949
+msgid "Recognize the \"asm\" keyword"
+msgstr ""
+
+#: c-family/c.opt:957
+msgid "Recognize built-in functions"
+msgstr ""
+
+#: c-family/c.opt:964
+msgid "Where shorter, use canonicalized paths to systems headers."
+msgstr ""
+
+#: c-family/c.opt:968
+msgid "Add Pointer Bounds Checker instrumentation.  fchkp-* flags are used to"
+msgstr ""
+
+#: c-family/c.opt:973
+msgid "Generate pointer bounds checks for variables with incomplete type"
+msgstr ""
+
+#: c-family/c.opt:977
+msgid "Use zero bounds for all incoming arguments in 'main' function.  It helps when"
+msgstr ""
+
+#: c-family/c.opt:982
+msgid "Forces Pointer Bounds Checker to use narrowed bounds for address of the first"
+msgstr ""
+
+#: c-family/c.opt:988
+msgid "Control how Pointer Bounds Checker handle pointers to object fields.  When"
+msgstr ""
+
+#: c-family/c.opt:993
+msgid "Forces Pointer Bounds Checker to use bounds of the innermost arrays in case of"
+msgstr ""
+
+#: c-family/c.opt:998
+msgid "Allow Pointer Bounds Checker optimizations.  By default allowed"
+msgstr ""
+
+#: c-family/c.opt:1003
+msgid "Allow to use *_nobnd versions of string functions by Pointer Bounds Checker."
+msgstr ""
+
+#: c-family/c.opt:1007
+msgid "Allow to use *_nochk versions of string functions by Pointer Bounds Checker."
+msgstr ""
+
+#: c-family/c.opt:1011
+msgid "Use statically initialized variable for vars bounds instead of"
+msgstr ""
+
+#: c-family/c.opt:1016
+msgid "Use statically initialized variable for constant bounds instead of"
+msgstr ""
+
+#: c-family/c.opt:1021
+msgid "With this option zero size obtained dynamically for objects with"
+msgstr ""
+
+#: c-family/c.opt:1026
+msgid "Generate checks for all read accesses to memory."
+msgstr ""
+
+#: c-family/c.opt:1030
+msgid "Generate checks for all write accesses to memory."
+msgstr ""
+
+#: c-family/c.opt:1034
+msgid "Generate bounds stores for pointer writes."
+msgstr ""
+
+#: c-family/c.opt:1038
+msgid "Generate bounds passing for calls."
+msgstr ""
+
+#: c-family/c.opt:1042
+msgid "Instrument only functions marked with bnd_instrument attribute."
+msgstr ""
+
+#: c-family/c.opt:1046
+msgid "Transform instrumented builtin calls into calls to wrappers."
+msgstr ""
+
+#: c-family/c.opt:1056
+msgid "Enable Cilk Plus"
+msgstr ""
+
+#: c-family/c.opt:1060
+msgid "Allow the arguments of the '?' operator to have different types"
+msgstr ""
+
+#: c-family/c.opt:1067
+#, c-format
+msgid "no class name specified with %qs"
+msgstr ""
+
+#: c-family/c.opt:1068
+msgid "-fconst-string-class=<name>\tUse class <name> for constant strings"
+msgstr ""
+
+#: c-family/c.opt:1072
+msgid "-fconstexpr-depth=<number>\tSpecify maximum constexpr recursion depth"
+msgstr ""
+
+#: c-family/c.opt:1076
+msgid "Emit debug annotations during preprocessing"
+msgstr ""
+
+#: c-family/c.opt:1080
+msgid "-fdeduce-init-list\tenable deduction of std::initializer_list for a template type parameter from a brace-enclosed initializer-list"
+msgstr ""
+
+#: c-family/c.opt:1084
+msgid "Factor complex constructors and destructors to favor space over speed"
+msgstr ""
+
+#: c-family/c.opt:1092
+msgid "Preprocess directives only."
+msgstr ""
+
+#: c-family/c.opt:1096
+msgid "Permit '$' as an identifier character"
+msgstr ""
+
+#: c-family/c.opt:1100
+msgid "Write all declarations as Ada code transitively"
+msgstr ""
+
+#: c-family/c.opt:1104
+msgid "Write all declarations as Ada code for the given file only"
+msgstr ""
+
+#: c-family/c.opt:1111
+msgid "Generate code to check exception specifications"
+msgstr ""
+
+#: c-family/c.opt:1118
+msgid "-fexec-charset=<cset>\tConvert all strings and character constants to character set <cset>"
+msgstr ""
+
+#: c-family/c.opt:1122
+msgid "Permit universal character names (\\u and \\U) in identifiers"
+msgstr ""
+
+#: c-family/c.opt:1126
+msgid "-finput-charset=<cset>\tSpecify the default character set for source files"
+msgstr ""
+
+#: c-family/c.opt:1130
+msgid "Support dynamic initialization of thread-local variables in a different translation unit"
+msgstr ""
+
+#: c-family/c.opt:1137
+msgid "Scope of for-init-statement variables is local to the loop"
+msgstr ""
+
+#: c-family/c.opt:1141
+msgid "Do not assume that standard C libraries and \"main\" exist"
+msgstr ""
+
+#: c-family/c.opt:1145
+msgid "Recognize GNU-defined keywords"
+msgstr ""
+
+#: c-family/c.opt:1149
+msgid "Generate code for GNU runtime environment"
+msgstr ""
+
+#: c-family/c.opt:1153
+msgid "Use traditional GNU semantics for inline functions"
+msgstr ""
+
+#: c-family/c.opt:1159
+msgid "-fhandle-exceptions has been renamed -fexceptions (and is now on by default)"
+msgstr ""
+
+#: c-family/c.opt:1166
+msgid "Assume normal C execution environment"
+msgstr ""
+
+#: c-family/c.opt:1174
+msgid "Export functions even if they can be inlined"
+msgstr ""
+
+#: c-family/c.opt:1178
+msgid "Emit implicit instantiations of inline templates"
+msgstr ""
+
+#: c-family/c.opt:1182
+msgid "Emit implicit instantiations of templates"
+msgstr ""
+
+#: c-family/c.opt:1186
+msgid "Inject friend functions into enclosing namespace"
+msgstr ""
+
+#: c-family/c.opt:1190
+msgid "Don't emit dllexported inline functions unless needed"
+msgstr ""
+
+#: c-family/c.opt:1197
+msgid "Allow implicit conversions between vectors with differing numbers of subparts and/or differing element types."
+msgstr ""
+
+#: c-family/c.opt:1201
+msgid "Don't warn about uses of Microsoft extensions"
+msgstr ""
+
+#: c-family/c.opt:1220
+msgid "Generate code for NeXT (Apple Mac OS X) runtime environment"
+msgstr ""
+
+#: c-family/c.opt:1224
+msgid "Assume that receivers of Objective-C messages may be nil"
+msgstr ""
+
+#: c-family/c.opt:1228
+msgid "Allow access to instance variables as if they were local declarations within instance method implementations."
+msgstr ""
+
+#: c-family/c.opt:1232
+msgid "-fvisibility=[private|protected|public|package]\tSet the default symbol visibility"
+msgstr ""
+
+#: c-family/c.opt:1235
+#, c-format
+msgid "unrecognized ivar visibility value %qs"
+msgstr ""
+
+#: c-family/c.opt:1257
+msgid "Treat a throw() exception specification as noexcept to improve code size"
+msgstr ""
+
+#: c-family/c.opt:1261
+msgid "Specify which ABI to use for Objective-C family code and meta-data generation."
+msgstr ""
+
+#: c-family/c.opt:1267
+msgid "Generate special Objective-C methods to initialize/destroy non-POD C++ ivars, if needed"
+msgstr ""
+
+#: c-family/c.opt:1271
+msgid "Allow fast jumps to the message dispatcher"
+msgstr ""
+
+#: c-family/c.opt:1277
+msgid "Enable Objective-C exception and synchronization syntax"
+msgstr ""
+
+#: c-family/c.opt:1281
+msgid "Enable garbage collection (GC) in Objective-C/Objective-C++ programs"
+msgstr ""
+
+#: c-family/c.opt:1285
+msgid "Enable inline checks for nil receivers with the NeXT runtime and ABI version 2."
+msgstr ""
+
+#: c-family/c.opt:1290
+msgid "Enable Objective-C setjmp exception handling runtime"
+msgstr ""
+
+#: c-family/c.opt:1294
+msgid "Conform to the Objective-C 1.0 language as implemented in GCC 4.0"
+msgstr ""
+
+#: c-family/c.opt:1298
+msgid "Enable OpenACC"
+msgstr ""
+
+#: c-family/c.opt:1302
+msgid "Enable OpenMP (implies -frecursive in Fortran)"
+msgstr ""
+
+#: c-family/c.opt:1306
+msgid "Enable OpenMP's SIMD directives"
+msgstr ""
+
+#: c-family/c.opt:1310
+msgid "Recognize C++ keywords like \"compl\" and \"xor\""
+msgstr ""
+
+#: c-family/c.opt:1321
+msgid "Look for and use PCH files even when preprocessing"
+msgstr ""
+
+#: c-family/c.opt:1325
+msgid "Downgrade conformance errors to warnings"
+msgstr ""
+
+#: c-family/c.opt:1329
+msgid "Enable Plan 9 language extensions"
+msgstr ""
+
+#: c-family/c.opt:1333
+msgid "Treat the input file as already preprocessed"
+msgstr ""
+
+#: c-family/c.opt:1341
+msgid "-ftrack-macro-expansion=<0|1|2>  Track locations of tokens coming from macro expansion and display them in error messages"
+msgstr ""
+
+#: c-family/c.opt:1345
+msgid "-fno-pretty-templates Do not pretty-print template specializations as the template signature followed by the arguments"
+msgstr ""
+
+#: c-family/c.opt:1349
+msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime"
+msgstr ""
+
+#: c-family/c.opt:1353
+msgid "Enable automatic template instantiation"
+msgstr ""
+
+#: c-family/c.opt:1357
+msgid "Generate run time type descriptor information"
+msgstr ""
+
+#: c-family/c.opt:1361
+msgid "Use the same size for double as for float"
+msgstr ""
+
+#: c-family/c.opt:1365 ada/gcc-interface/lang.opt:77
+msgid "Use the narrowest integer type possible for enumeration types"
+msgstr ""
+
+#: c-family/c.opt:1369
+msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\""
+msgstr ""
+
+#: c-family/c.opt:1373
+msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed"
+msgstr ""
+
+#: c-family/c.opt:1377
+msgid "Make \"char\" signed by default"
+msgstr ""
+
+#: c-family/c.opt:1381
+msgid "Enable C++14 sized deallocation support"
+msgstr ""
+
+#: c-family/c.opt:1388
+msgid "Display statistics accumulated during compilation"
+msgstr ""
+
+#: c-family/c.opt:1392
+msgid "Assume that values of enumeration type are always within the minimum range of that type"
+msgstr ""
+
+#: c-family/c.opt:1399
+msgid "-ftabstop=<number>\tDistance between tab stops for column reporting"
+msgstr ""
+
+#: c-family/c.opt:1403
+msgid "Set the maximum number of template instantiation notes for a single warning or error"
+msgstr ""
+
+#: c-family/c.opt:1410
+msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth"
+msgstr ""
+
+#: c-family/c.opt:1417
+msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics"
+msgstr ""
+
+#: c-family/c.opt:1421
+msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned"
+msgstr ""
+
+#: c-family/c.opt:1425
+msgid "Make \"char\" unsigned by default"
+msgstr ""
+
+#: c-family/c.opt:1429
+msgid "Use __cxa_atexit to register destructors"
+msgstr ""
+
+#: c-family/c.opt:1433
+msgid "Use __cxa_get_exception_ptr in exception handling"
+msgstr ""
+
+#: c-family/c.opt:1437
+msgid "Marks all inlined functions and methods as having hidden visibility"
+msgstr ""
+
+#: c-family/c.opt:1441
+msgid "Changes visibility to match Microsoft Visual Studio by default"
+msgstr ""
+
+#: c-family/c.opt:1453
+msgid "Emit common-like symbols as weak symbols"
+msgstr ""
+
+#: c-family/c.opt:1457
+msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>"
+msgstr ""
+
+#: c-family/c.opt:1461
+msgid "Generate a #line directive pointing at the current working directory"
+msgstr ""
+
+#: c-family/c.opt:1469
+msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode"
+msgstr ""
+
+#: c-family/c.opt:1473
+msgid "Dump declarations to a .decl file"
+msgstr ""
+
+#: c-family/c.opt:1477
+msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs"
+msgstr ""
+
+#: c-family/c.opt:1481
+msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs"
+msgstr ""
+
+#: c-family/c.opt:1485
+msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs"
+msgstr ""
+
+#: c-family/c.opt:1489
+msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding"
+msgstr ""
+
+#: c-family/c.opt:1494
+msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path"
+msgstr ""
+
+#: c-family/c.opt:1498
+msgid "-imacros <file>\tAccept definition of macros in <file>"
+msgstr ""
+
+#: c-family/c.opt:1502
+msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory"
+msgstr ""
+
+#: c-family/c.opt:1506
+msgid "-include <file>\tInclude the contents of <file> before other files"
+msgstr ""
+
+#: c-family/c.opt:1510
+msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options"
+msgstr ""
+
+#: c-family/c.opt:1514
+msgid "-isysroot <dir>\tSet <dir> to be the system root directory"
+msgstr ""
+
+#: c-family/c.opt:1518
+msgid "-isystem <dir>\tAdd <dir> to the start of the system include path"
+msgstr ""
+
+#: c-family/c.opt:1522
+msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path"
+msgstr ""
+
+#: c-family/c.opt:1526
+msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path"
+msgstr ""
+
+#: c-family/c.opt:1530
+msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path"
+msgstr ""
+
+#: c-family/c.opt:1540
+msgid "Do not search standard system include directories (those specified with -isystem will still be used)"
+msgstr ""
+
+#: c-family/c.opt:1544
+msgid "Do not search standard system include directories for C++"
+msgstr ""
+
+#: c-family/c.opt:1556
+msgid "Generate C header of platform-specific features"
+msgstr ""
+
+#: c-family/c.opt:1560
+msgid "Remap file names when including files"
+msgstr ""
+
+#: c-family/c.opt:1564 c-family/c.opt:1568
+msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum"
+msgstr ""
+
+#: c-family/c.opt:1572
+msgid "Conform to the ISO 2011 C++ standard"
+msgstr ""
+
+#: c-family/c.opt:1576
+msgid "Deprecated in favor of -std=c++11"
+msgstr ""
+
+#: c-family/c.opt:1580
+msgid "Deprecated in favor of -std=c++14"
+msgstr ""
+
+#: c-family/c.opt:1584
+msgid "Conform to the ISO 2014 C++ standard (experimental and incomplete support)"
+msgstr ""
+
+#: c-family/c.opt:1588
+msgid "Conform to the ISO 2017(?) C++ draft standard (experimental and incomplete support)"
+msgstr ""
+
+#: c-family/c.opt:1595 c-family/c.opt:1691
+msgid "Conform to the ISO 2011 C standard (experimental and incomplete support)"
+msgstr ""
+
+#: c-family/c.opt:1599
+msgid "Deprecated in favor of -std=c11"
+msgstr ""
+
+#: c-family/c.opt:1603 c-family/c.opt:1607 c-family/c.opt:1675
+msgid "Conform to the ISO 1990 C standard"
+msgstr ""
+
+#: c-family/c.opt:1611 c-family/c.opt:1683
+msgid "Conform to the ISO 1999 C standard"
+msgstr ""
+
+#: c-family/c.opt:1615
+msgid "Deprecated in favor of -std=c99"
+msgstr ""
+
+#: c-family/c.opt:1619 c-family/c.opt:1624
+msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical"
+msgstr ""
+
+#: c-family/c.opt:1629
+msgid "Conform to the ISO 2011 C++ standard with GNU extensions (experimental and incomplete support)"
+msgstr ""
+
+#: c-family/c.opt:1633
+msgid "Deprecated in favor of -std=gnu++11"
+msgstr ""
+
+#: c-family/c.opt:1640
+msgid "Conform to the ISO 2014 C++ standard with GNU extensions (experimental and incomplete support)"
+msgstr ""
+
+#: c-family/c.opt:1644
+msgid "Conform to the ISO 201z(7?) C++ draft standard with GNU extensions (experimental and incomplete support)"
+msgstr ""
+
+#: c-family/c.opt:1651
+msgid "Conform to the ISO 2011 C standard with GNU extensions (experimental and incomplete support)"
+msgstr ""
+
+#: c-family/c.opt:1655
+msgid "Deprecated in favor of -std=gnu11"
+msgstr ""
+
+#: c-family/c.opt:1659 c-family/c.opt:1663
+msgid "Conform to the ISO 1990 C standard with GNU extensions"
+msgstr ""
+
+#: c-family/c.opt:1667
+msgid "Conform to the ISO 1999 C standard with GNU extensions"
+msgstr ""
+
+#: c-family/c.opt:1671
+msgid "Deprecated in favor of -std=gnu99"
+msgstr ""
+
+#: c-family/c.opt:1679
+msgid "Conform to the ISO 1990 C standard as amended in 1994"
+msgstr ""
+
+#: c-family/c.opt:1687
+msgid "Deprecated in favor of -std=iso9899:1999"
+msgstr ""
+
+#: c-family/c.opt:1698
+msgid "Enable traditional preprocessing"
+msgstr ""
+
+#: c-family/c.opt:1702
+msgid "-trigraphs\tSupport ISO C trigraphs"
+msgstr ""
+
+#: c-family/c.opt:1706
+msgid "Do not predefine system-specific and GCC-specific macros"
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:61
+msgid "Synonym of -gnatk8"
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:69
+msgid "Do not look for object files in standard path"
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:73
+msgid "Select the runtime"
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:81
+msgid "Catch typos"
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:85
+msgid "Set name of output ALI file (internal switch)"
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:89
+msgid "-gnat<options>\tSpecify options to GNAT"
+msgstr ""
+
+#: go/lang.opt:42
+msgid "Add explicit checks for division by zero"
+msgstr ""
+
+#: go/lang.opt:46
+msgid "Add explicit checks for division overflow in INT_MIN / -1"
+msgstr ""
+
+#: go/lang.opt:50
+msgid "-fgo-dump-<type>\tDump Go frontend internal information"
+msgstr ""
+
+#: go/lang.opt:54
+msgid "-fgo-optimize-<type>\tTurn on optimization passes in the frontend"
+msgstr ""
+
+#: go/lang.opt:58
+msgid "-fgo-pkgpath=<string>\tSet Go package path"
+msgstr ""
+
+#: go/lang.opt:62
+msgid "-fgo-prefix=<string>\tSet package-specific prefix for exported Go names"
+msgstr ""
+
+#: go/lang.opt:66
+msgid "-fgo-relative-import-path=<path> Treat a relative import as relative to path"
+msgstr ""
+
+#: go/lang.opt:70
+msgid "Functions which return values must end with return statements"
+msgstr ""
+
+#: config/vms/vms.opt:27
+msgid "Malloc data into P2 space"
+msgstr ""
+
+#: config/vms/vms.opt:31
+msgid "Set name of main routine for the debugger"
+msgstr ""
+
+#: config/vms/vms.opt:35
+msgid "Use VMS exit codes instead of posix ones"
+msgstr ""
+
+#: config/vms/vms.opt:39
+msgid "-mpointer-size=[no,32,short,64,long]\tSet the default pointer size"
+msgstr ""
+
+#: config/vms/vms.opt:42
+#, c-format
+msgid "unknown pointer size model %qs"
+msgstr ""
+
+#: config/mcore/mcore.opt:23
+msgid "Generate code for the M*Core M210"
+msgstr ""
+
+#: config/mcore/mcore.opt:27
+msgid "Generate code for the M*Core M340"
+msgstr ""
+
+#: config/mcore/mcore.opt:31
+msgid "Force functions to be aligned to a 4 byte boundary"
+msgstr ""
+
+#: config/mcore/mcore.opt:35 config/moxie/moxie.opt:23
+msgid "Generate big-endian code"
+msgstr ""
+
+#: config/mcore/mcore.opt:39
+msgid "Emit call graph information"
+msgstr ""
+
+#: config/mcore/mcore.opt:43
+msgid "Use the divide instruction"
+msgstr ""
+
+#: config/mcore/mcore.opt:47
+msgid "Inline constants if it can be done in 2 insns or less"
+msgstr ""
+
+#: config/mcore/mcore.opt:51 config/moxie/moxie.opt:27
+msgid "Generate little-endian code"
+msgstr ""
+
+#: config/mcore/mcore.opt:56 config/fr30/fr30.opt:27
+msgid "Assume that run-time support has been provided, so omit -lsim from the linker command line"
+msgstr ""
+
+#: config/mcore/mcore.opt:60
+msgid "Use arbitrary sized immediates in bit operations"
+msgstr ""
+
+#: config/mcore/mcore.opt:64
+msgid "Prefer word accesses over byte accesses"
+msgstr ""
+
+#: config/mcore/mcore.opt:71
+msgid "Set the maximum amount for a single stack increment operation"
+msgstr ""
+
+#: config/mcore/mcore.opt:75
+msgid "Always treat bitfields as int-sized"
+msgstr ""
+
+#: config/linux-android.opt:23
+msgid "Generate code for the Android platform."
+msgstr ""
+
+#: config/mmix/mmix.opt:24
+msgid "For intrinsics library: pass all parameters in registers"
+msgstr ""
+
+#: config/mmix/mmix.opt:28
+msgid "Use register stack for parameters and return value"
+msgstr ""
+
+#: config/mmix/mmix.opt:32
+msgid "Use call-clobbered registers for parameters and return value"
+msgstr ""
+
+#: config/mmix/mmix.opt:37
+msgid "Use epsilon-respecting floating point compare instructions"
+msgstr ""
+
+#: config/mmix/mmix.opt:41
+msgid "Use zero-extending memory loads, not sign-extending ones"
+msgstr ""
+
+#: config/mmix/mmix.opt:45
+msgid "Generate divide results with reminder having the same sign as the divisor (not the dividend)"
+msgstr ""
+
+#: config/mmix/mmix.opt:49
+msgid "Prepend global symbols with \":\" (for use with PREFIX)"
+msgstr ""
+
+#: config/mmix/mmix.opt:53
+msgid "Do not provide a default start-address 0x100 of the program"
+msgstr ""
+
+#: config/mmix/mmix.opt:57
+msgid "Link to emit program in ELF format (rather than mmo)"
+msgstr ""
+
+#: config/mmix/mmix.opt:61
+msgid "Use P-mnemonics for branches statically predicted as taken"
+msgstr ""
+
+#: config/mmix/mmix.opt:65
+msgid "Don't use P-mnemonics for branches"
+msgstr ""
+
+#: config/mmix/mmix.opt:79
+msgid "Use addresses that allocate global registers"
+msgstr ""
+
+#: config/mmix/mmix.opt:83
+msgid "Do not use addresses that allocate global registers"
+msgstr ""
+
+#: config/mmix/mmix.opt:87
+msgid "Generate a single exit point for each function"
+msgstr ""
+
+#: config/mmix/mmix.opt:91
+msgid "Do not generate a single exit point for each function"
+msgstr ""
+
+#: config/mmix/mmix.opt:95
+msgid "Set start-address of the program"
+msgstr ""
+
+#: config/mmix/mmix.opt:99
+msgid "Set start-address of data"
+msgstr ""
+
+#: config/darwin.opt:114
+msgid "Generate compile-time CFString objects"
+msgstr ""
+
+#: config/darwin.opt:208
+msgid "Warn if constant CFString objects contain non-portable characters"
+msgstr ""
+
+#: config/darwin.opt:213
+msgid "Generate AT&T-style stubs for Mach-O"
+msgstr ""
+
+#: config/darwin.opt:217
+msgid "Generate code suitable for executables (NOT shared libs)"
+msgstr ""
+
+#: config/darwin.opt:221
+msgid "Generate code suitable for fast turn around debugging"
+msgstr ""
+
+#: config/darwin.opt:230
+msgid "The earliest MacOS X version on which this program will run"
+msgstr ""
+
+#: config/darwin.opt:234
+msgid "Set sizeof(bool) to 1"
+msgstr ""
+
+#: config/darwin.opt:238
+msgid "Generate code for darwin loadable kernel extensions"
+msgstr ""
+
+#: config/darwin.opt:242
+msgid "Generate code for the kernel or loadable kernel extensions"
+msgstr ""
+
+#: config/darwin.opt:246
+msgid "-iframework <dir>\tAdd <dir> to the end of the system framework include path"
+msgstr ""
+
+#: config/bfin/bfin.opt:40 config/msp430/msp430.opt:3 config/c6x/c6x.opt:38
+#: config/mep/mep.opt:143
+msgid "Use simulator runtime"
+msgstr ""
+
+#: config/bfin/bfin.opt:44 config/arm/arm.opt:106
+msgid "Specify the name of the target CPU"
+msgstr ""
+
+#: config/bfin/bfin.opt:48
+msgid "Omit frame pointer for leaf functions"
+msgstr ""
+
+#: config/bfin/bfin.opt:52
+msgid "Program is entirely located in low 64k of memory"
+msgstr ""
+
+#: config/bfin/bfin.opt:56
+msgid "Work around a hardware anomaly by adding a number of NOPs before a"
+msgstr ""
+
+#: config/bfin/bfin.opt:61
+msgid "Avoid speculative loads to work around a hardware anomaly."
+msgstr ""
+
+#: config/bfin/bfin.opt:65
+msgid "Enabled ID based shared library"
+msgstr ""
+
+#: config/bfin/bfin.opt:69
+msgid "Generate code that won't be linked against any other ID shared libraries,"
+msgstr ""
+
+#: config/bfin/bfin.opt:74 config/m68k/m68k.opt:171
+msgid "ID of shared library to build"
+msgstr ""
+
+#: config/bfin/bfin.opt:78 config/m68k/m68k.opt:167
+msgid "Enable separate data segment"
+msgstr ""
+
+#: config/bfin/bfin.opt:82 config/c6x/c6x.opt:63
+msgid "Avoid generating pc-relative calls; use indirection"
+msgstr ""
+
+#: config/bfin/bfin.opt:86
+msgid "Link with the fast floating-point library"
+msgstr ""
+
+#: config/bfin/bfin.opt:90 config/frv/frv.opt:130
+msgid "Enable Function Descriptor PIC mode"
+msgstr ""
+
+#: config/bfin/bfin.opt:94 config/frv/frv.opt:162
+msgid "Enable inlining of PLT in function calls"
+msgstr ""
+
+#: config/bfin/bfin.opt:98
+msgid "Do stack checking using bounds in L1 scratch memory"
+msgstr ""
+
+#: config/bfin/bfin.opt:102
+msgid "Enable multicore support"
+msgstr ""
+
+#: config/bfin/bfin.opt:106
+msgid "Build for Core A"
+msgstr ""
+
+#: config/bfin/bfin.opt:110
+msgid "Build for Core B"
+msgstr ""
+
+#: config/bfin/bfin.opt:114
+msgid "Build for SDRAM"
+msgstr ""
+
+#: config/bfin/bfin.opt:118
+msgid "Assume ICPLBs are enabled at runtime."
+msgstr ""
+
+#: config/m68k/m68k-tables.opt:25
+msgid "Known M68K CPUs (for use with the -mcpu= option):"
+msgstr ""
+
+#: config/m68k/m68k-tables.opt:365
+msgid "Known M68K microarchitectures (for use with the -mtune= option):"
+msgstr ""
+
+#: config/m68k/m68k-tables.opt:411
+msgid "Known M68K ISAs (for use with the -march= option):"
+msgstr ""
+
+#: config/m68k/ieee.opt:24 config/i386/i386.opt:358
+msgid "Use IEEE math for fp comparisons"
+msgstr ""
+
+#: config/m68k/m68k.opt:30
+msgid "Generate code for a 520X"
+msgstr ""
+
+#: config/m68k/m68k.opt:34
+msgid "Generate code for a 5206e"
+msgstr ""
+
+#: config/m68k/m68k.opt:38
+msgid "Generate code for a 528x"
+msgstr ""
+
+#: config/m68k/m68k.opt:42
+msgid "Generate code for a 5307"
+msgstr ""
+
+#: config/m68k/m68k.opt:46
+msgid "Generate code for a 5407"
+msgstr ""
+
+#: config/m68k/m68k.opt:50 config/m68k/m68k.opt:111
+msgid "Generate code for a 68000"
+msgstr ""
+
+#: config/m68k/m68k.opt:54
+msgid "Generate code for a 68010"
+msgstr ""
+
+#: config/m68k/m68k.opt:58 config/m68k/m68k.opt:115
+msgid "Generate code for a 68020"
+msgstr ""
+
+#: config/m68k/m68k.opt:62
+msgid "Generate code for a 68040, without any new instructions"
+msgstr ""
+
+#: config/m68k/m68k.opt:66
+msgid "Generate code for a 68060, without any new instructions"
+msgstr ""
+
+#: config/m68k/m68k.opt:70
+msgid "Generate code for a 68030"
+msgstr ""
+
+#: config/m68k/m68k.opt:74
+msgid "Generate code for a 68040"
+msgstr ""
+
+#: config/m68k/m68k.opt:78
+msgid "Generate code for a 68060"
+msgstr ""
+
+#: config/m68k/m68k.opt:82
+msgid "Generate code for a 68302"
+msgstr ""
+
+#: config/m68k/m68k.opt:86
+msgid "Generate code for a 68332"
+msgstr ""
+
+#: config/m68k/m68k.opt:91
+msgid "Generate code for a 68851"
+msgstr ""
+
+#: config/m68k/m68k.opt:95
+msgid "Generate code that uses 68881 floating-point instructions"
+msgstr ""
+
+#: config/m68k/m68k.opt:99
+msgid "Align variables on a 32-bit boundary"
+msgstr ""
+
+#: config/m68k/m68k.opt:103 config/arm/arm.opt:81 config/c6x/c6x.opt:67
+msgid "Specify the name of the target architecture"
+msgstr ""
+
+#: config/m68k/m68k.opt:107
+msgid "Use the bit-field instructions"
+msgstr ""
+
+#: config/m68k/m68k.opt:119
+msgid "Generate code for a ColdFire v4e"
+msgstr ""
+
+#: config/m68k/m68k.opt:123
+msgid "Specify the target CPU"
+msgstr ""
+
+#: config/m68k/m68k.opt:127
+msgid "Generate code for a cpu32"
+msgstr ""
+
+#: config/m68k/m68k.opt:131
+msgid "Use hardware division instructions on ColdFire"
+msgstr ""
+
+#: config/m68k/m68k.opt:135
+msgid "Generate code for a Fido A"
+msgstr ""
+
+#: config/m68k/m68k.opt:139
+msgid "Generate code which uses hardware floating point instructions"
+msgstr ""
+
+#: config/m68k/m68k.opt:143
+msgid "Enable ID based shared library"
+msgstr ""
+
+#: config/m68k/m68k.opt:147
+msgid "Do not use the bit-field instructions"
+msgstr ""
+
+#: config/m68k/m68k.opt:151
+msgid "Use normal calling convention"
+msgstr ""
+
+#: config/m68k/m68k.opt:155
+msgid "Consider type 'int' to be 32 bits wide"
+msgstr ""
+
+#: config/m68k/m68k.opt:159
+msgid "Generate pc-relative code"
+msgstr ""
+
+#: config/m68k/m68k.opt:163
+msgid "Use different calling convention using 'rtd'"
+msgstr ""
+
+#: config/m68k/m68k.opt:175
+msgid "Consider type 'int' to be 16 bits wide"
+msgstr ""
+
+#: config/m68k/m68k.opt:179
+msgid "Generate code with library calls for floating point"
+msgstr ""
+
+#: config/m68k/m68k.opt:183
+msgid "Do not use unaligned memory references"
+msgstr ""
+
+#: config/m68k/m68k.opt:187
+msgid "Tune for the specified target CPU or architecture"
+msgstr ""
+
+#: config/m68k/m68k.opt:191
+msgid "Support more than 8192 GOT entries on ColdFire"
+msgstr ""
+
+#: config/m68k/m68k.opt:195
+msgid "Support TLS segment larger than 64K"
+msgstr ""
+
+#: config/m32c/m32c.opt:23
+msgid "-msim\tUse simulator runtime"
+msgstr ""
+
+#: config/m32c/m32c.opt:27
+msgid "-mcpu=r8c\tCompile code for R8C variants"
+msgstr ""
+
+#: config/m32c/m32c.opt:31
+msgid "-mcpu=m16c\tCompile code for M16C variants"
+msgstr ""
+
+#: config/m32c/m32c.opt:35
+msgid "-mcpu=m32cm\tCompile code for M32CM variants"
+msgstr ""
+
+#: config/m32c/m32c.opt:39
+msgid "-mcpu=m32c\tCompile code for M32C variants"
+msgstr ""
+
+#: config/m32c/m32c.opt:43
+msgid "-memregs=\tNumber of memreg bytes (default: 16, range: 0..16)"
+msgstr ""
+
+#: config/msp430/msp430.opt:7
+msgid "Force assembly output to always use hex constants"
+msgstr ""
+
+#: config/msp430/msp430.opt:11
+msgid "Specify the MCU to build for."
+msgstr ""
+
+#: config/msp430/msp430.opt:15
+msgid "Specify the ISA to build for: msp430, mdsp430x, msp430xv2"
+msgstr ""
+
+#: config/msp430/msp430.opt:19
+msgid "Select large model - 20-bit addresses/pointers"
+msgstr ""
+
+#: config/msp430/msp430.opt:23
+msgid "Select small model - 16-bit addresses/pointers (default)"
+msgstr ""
+
+#: config/msp430/msp430.opt:27
+msgid "Optimize opcode sizes at link time"
+msgstr ""
+
+#: config/msp430/msp430.opt:34
+msgid "Use a minimum runtime (no static initializers or ctors) for memory-constrained devices."
+msgstr ""
+
+#: config/msp430/msp430.opt:41
+msgid "Specify the type of hardware multiply to support"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:28
+msgid "The possible TLS dialects:"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:40
+msgid "The code model option names for -mcmodel:"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:64 config/arm/arm.opt:94
+#: config/microblaze/microblaze.opt:60
+msgid "Assume target CPU is configured as big endian"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:68
+msgid "Generate code which uses only the general registers"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:72
+msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
+#: config/microblaze/microblaze.opt:64
+msgid "Assume target CPU is configured as little endian"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:84
+msgid "Specify the code model"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:88
+msgid "Don't assume that unaligned accesses are handled by the system"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
+msgid "Omit the frame pointer in leaf functions"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:96
+msgid "Specify TLS dialect"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:100
+msgid "-march=ARCH\tUse features of architecture ARCH"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:104
+msgid "-mcpu=CPU\tUse features of and optimize for CPU"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:108
+msgid "-mtune=CPU\tOptimize for CPU"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:112
+msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:116
+msgid "Known AArch64 ABIs (for use with the -mabi= option):"
+msgstr ""
+
+#: config/linux.opt:24
+msgid "Use Bionic C library"
+msgstr ""
+
+#: config/linux.opt:28
+msgid "Use GNU C library"
+msgstr ""
+
+#: config/linux.opt:32
+msgid "Use uClibc C library"
+msgstr ""
+
+#: config/ia64/ilp32.opt:3
+msgid "Generate ILP32 code"
+msgstr ""
+
+#: config/ia64/ilp32.opt:7
+msgid "Generate LP64 code"
+msgstr ""
+
+#: config/ia64/ia64.opt:28
+msgid "Generate big endian code"
+msgstr ""
+
+#: config/ia64/ia64.opt:32
+msgid "Generate little endian code"
+msgstr ""
+
+#: config/ia64/ia64.opt:36
+msgid "Generate code for GNU as"
+msgstr ""
+
+#: config/ia64/ia64.opt:40
+msgid "Generate code for GNU ld"
+msgstr ""
+
+#: config/ia64/ia64.opt:44
+msgid "Emit stop bits before and after volatile extended asms"
+msgstr ""
+
+#: config/ia64/ia64.opt:48
+msgid "Use in/loc/out register names"
+msgstr ""
+
+#: config/ia64/ia64.opt:55
+msgid "Enable use of sdata/scommon/sbss"
+msgstr ""
+
+#: config/ia64/ia64.opt:59
+msgid "Generate code without GP reg"
+msgstr ""
+
+#: config/ia64/ia64.opt:63
+msgid "gp is constant (but save/restore gp on indirect calls)"
+msgstr ""
+
+#: config/ia64/ia64.opt:67
+msgid "Generate self-relocatable code"
+msgstr ""
+
+#: config/ia64/ia64.opt:71
+msgid "Generate inline floating point division, optimize for latency"
+msgstr ""
+
+#: config/ia64/ia64.opt:75
+msgid "Generate inline floating point division, optimize for throughput"
+msgstr ""
+
+#: config/ia64/ia64.opt:82
+msgid "Generate inline integer division, optimize for latency"
+msgstr ""
+
+#: config/ia64/ia64.opt:86
+msgid "Generate inline integer division, optimize for throughput"
+msgstr ""
+
+#: config/ia64/ia64.opt:90
+msgid "Do not inline integer division"
+msgstr ""
+
+#: config/ia64/ia64.opt:94
+msgid "Generate inline square root, optimize for latency"
+msgstr ""
+
+#: config/ia64/ia64.opt:98
+msgid "Generate inline square root, optimize for throughput"
+msgstr ""
+
+#: config/ia64/ia64.opt:102
+msgid "Do not inline square root"
+msgstr ""
+
+#: config/ia64/ia64.opt:106
+msgid "Enable Dwarf 2 line debug info via GNU as"
+msgstr ""
+
+#: config/ia64/ia64.opt:110
+msgid "Enable earlier placing stop bits for better scheduling"
+msgstr ""
+
+#: config/ia64/ia64.opt:114 config/spu/spu.opt:72 config/pa/pa.opt:58
+#: config/sh/sh.opt:269
+msgid "Specify range of registers to make fixed"
+msgstr ""
+
+#: config/ia64/ia64.opt:118 config/rs6000/sysv4.opt:32
+#: config/alpha/alpha.opt:130
+msgid "Specify bit size of immediate TLS offsets"
+msgstr ""
+
+#: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:504
+#: config/s390/s390.opt:143 config/sparc/sparc.opt:126
+#: config/visium/visium.opt:49
+msgid "Schedule code for given CPU"
+msgstr ""
+
+#: config/ia64/ia64.opt:126
+msgid "Known Itanium CPUs (for use with the -mtune= option):"
+msgstr ""
+
+#: config/ia64/ia64.opt:136
+msgid "Use data speculation before reload"
+msgstr ""
+
+#: config/ia64/ia64.opt:140
+msgid "Use data speculation after reload"
+msgstr ""
+
+#: config/ia64/ia64.opt:144
+msgid "Use control speculation"
+msgstr ""
+
+#: config/ia64/ia64.opt:148
+msgid "Use in block data speculation before reload"
+msgstr ""
+
+#: config/ia64/ia64.opt:152
+msgid "Use in block data speculation after reload"
+msgstr ""
+
+#: config/ia64/ia64.opt:156
+msgid "Use in block control speculation"
+msgstr ""
+
+#: config/ia64/ia64.opt:160
+msgid "Use simple data speculation check"
+msgstr ""
+
+#: config/ia64/ia64.opt:164
+msgid "Use simple data speculation check for control speculation"
+msgstr ""
+
+#: config/ia64/ia64.opt:174
+msgid "Count speculative dependencies while calculating priority of instructions"
+msgstr ""
+
+#: config/ia64/ia64.opt:178
+msgid "Place a stop bit after every cycle when scheduling"
+msgstr ""
+
+#: config/ia64/ia64.opt:182
+msgid "Assume that floating-point stores and loads are not likely to cause conflict when placed into one instruction group"
+msgstr ""
+
+#: config/ia64/ia64.opt:186
+msgid "Soft limit on number of memory insns per instruction group, giving lower priority to subsequent memory insns attempting to schedule in the same insn group. Frequently useful to prevent cache bank conflicts.  Default value is 1"
+msgstr ""
+
+#: config/ia64/ia64.opt:190
+msgid "Disallow more than 'msched-max-memory-insns' in instruction group. Otherwise, limit is 'soft' (prefer non-memory operations when limit is reached)"
+msgstr ""
+
+#: config/ia64/ia64.opt:194
+msgid "Don't generate checks for control speculation in selective scheduling"
+msgstr ""
+
+#: config/spu/spu.opt:20
+msgid "Emit warnings when run-time relocations are generated"
+msgstr ""
+
+#: config/spu/spu.opt:24
+msgid "Emit errors when run-time relocations are generated"
+msgstr ""
+
+#: config/spu/spu.opt:28
+msgid "Specify cost of branches (Default 20)"
+msgstr ""
+
+#: config/spu/spu.opt:32
+msgid "Make sure loads and stores are not moved past DMA instructions"
+msgstr ""
+
+#: config/spu/spu.opt:36
+msgid "volatile must be specified on any memory that is effected by DMA"
+msgstr ""
+
+#: config/spu/spu.opt:40 config/spu/spu.opt:44
+msgid "Insert nops when it might improve performance by allowing dual issue (default)"
+msgstr ""
+
+#: config/spu/spu.opt:48
+msgid "Use standard main function as entry for startup"
+msgstr ""
+
+#: config/spu/spu.opt:52
+msgid "Generate branch hints for branches"
+msgstr ""
+
+#: config/spu/spu.opt:56
+msgid "Maximum number of nops to insert for a hint (Default 2)"
+msgstr ""
+
+#: config/spu/spu.opt:60
+msgid "Approximate maximum number of instructions to allow between a hint and its branch [125]"
+msgstr ""
+
+#: config/spu/spu.opt:64
+msgid "Generate code for 18 bit addressing"
+msgstr ""
+
+#: config/spu/spu.opt:68
+msgid "Generate code for 32 bit addressing"
+msgstr ""
+
+#: config/spu/spu.opt:76
+msgid "Insert hbrp instructions after hinted branch targets to avoid the SPU hang issue"
+msgstr ""
+
+#: config/spu/spu.opt:80 config/i386/i386.opt:247 config/s390/s390.opt:47
+msgid "Generate code for given CPU"
+msgstr ""
+
+#: config/spu/spu.opt:88
+msgid "Access variables in 32-bit PPU objects (default)"
+msgstr ""
+
+#: config/spu/spu.opt:92
+msgid "Access variables in 64-bit PPU objects"
+msgstr ""
+
+#: config/spu/spu.opt:96
+msgid "Allow conversions between __ea and generic pointers (default)"
+msgstr ""
+
+#: config/spu/spu.opt:100
+msgid "Size (in KB) of software data cache"
+msgstr ""
+
+#: config/spu/spu.opt:104
+msgid "Atomically write back software data cache lines (default)"
+msgstr ""
+
+#: config/epiphany/epiphany.opt:24
+msgid "Don't use any of r32..r63."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:28
+msgid "preferentially allocate registers that allow short instruction generation."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:32
+msgid "Set branch cost"
+msgstr ""
+
+#: config/epiphany/epiphany.opt:36
+msgid "enable conditional move instruction usage."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:40
+msgid "set number of nops to emit before each insn pattern"
+msgstr ""
+
+#: config/epiphany/epiphany.opt:52
+msgid "Use software floating point comparisons"
+msgstr ""
+
+#: config/epiphany/epiphany.opt:56
+msgid "Enable split of 32 bit immediate loads into low / high part"
+msgstr ""
+
+#: config/epiphany/epiphany.opt:60
+msgid "Enable use of POST_INC / POST_DEC"
+msgstr ""
+
+#: config/epiphany/epiphany.opt:64
+msgid "Enable use of POST_MODIFY"
+msgstr ""
+
+#: config/epiphany/epiphany.opt:68
+msgid "Set number of bytes on the stack preallocated for use by the callee."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:72
+msgid "Assume round to nearest is selected for purposes of scheduling."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:76
+msgid "Generate call insns as indirect calls"
+msgstr ""
+
+#: config/epiphany/epiphany.opt:80
+msgid "Generate call insns as direct calls"
+msgstr ""
+
+#: config/epiphany/epiphany.opt:84
+msgid "Assume labels and symbols can be addressed using 16 bit absolute addresses."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:108
+msgid "A floatig point to integer truncation may be replaced with rounding to save mode switching"
+msgstr ""
+
+#: config/epiphany/epiphany.opt:112
+msgid "Vectorize for double-word operations."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:128
+msgid "Split unaligned 8 byte vector moves before post-modify address generation."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:132
+msgid "Use the floating point unit for integer add/subtract."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:136
+msgid "Set register to hold -1."
+msgstr ""
+
+#: config/h8300/h8300.opt:23
+msgid "Generate H8S code"
+msgstr ""
+
+#: config/h8300/h8300.opt:27
+msgid "Generate H8SX code"
+msgstr ""
+
+#: config/h8300/h8300.opt:31
+msgid "Generate H8S/2600 code"
+msgstr ""
+
+#: config/h8300/h8300.opt:35
+msgid "Make integers 32 bits wide"
+msgstr ""
+
+#: config/h8300/h8300.opt:42
+msgid "Use registers for argument passing"
+msgstr ""
+
+#: config/h8300/h8300.opt:46
+msgid "Consider access to byte sized memory slow"
+msgstr ""
+
+#: config/h8300/h8300.opt:50
+msgid "Enable linker relaxing"
+msgstr ""
+
+#: config/h8300/h8300.opt:54
+msgid "Generate H8/300H code"
+msgstr ""
+
+#: config/h8300/h8300.opt:58
+msgid "Enable the normal mode"
+msgstr ""
+
+#: config/h8300/h8300.opt:62
+msgid "Use H8/300 alignment rules"
+msgstr ""
+
+#: config/h8300/h8300.opt:66
+msgid "Push extended registers on stack in monitor functions"
+msgstr ""
+
+#: config/h8300/h8300.opt:70
+msgid "Do not push extended registers on stack in monitor functions"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:23
+msgid "Generate code for an 11/10"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:27
+msgid "Generate code for an 11/40"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:31
+msgid "Generate code for an 11/45"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:35
+msgid "Return floating-point results in ac0 (fr0 in Unix assembler syntax)"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:39
+msgid "Do not use inline patterns for copying memory"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:43
+msgid "Use inline patterns for copying memory"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:47
+msgid "Do not pretend that branches are expensive"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:51
+msgid "Pretend that branches are expensive"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:55
+msgid "Use the DEC assembler syntax"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:59
+msgid "Use 32 bit float"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:63
+msgid "Use 64 bit float"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:67 config/rs6000/rs6000.opt:177
+#: config/frv/frv.opt:158
+msgid "Use hardware floating point"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:71
+msgid "Use 16 bit int"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:75
+msgid "Use 32 bit int"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:79 config/rs6000/rs6000.opt:173
+msgid "Do not use hardware floating point"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:83
+msgid "Target has split I&D"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:87
+msgid "Use UNIX assembler syntax"
+msgstr ""
+
+#: config/xtensa/xtensa.opt:23
+msgid "Use CONST16 instruction to load constants"
+msgstr ""
+
+#: config/xtensa/xtensa.opt:27
+msgid "Disable position-independent code (PIC) for use in OS kernel code"
+msgstr ""
+
+#: config/xtensa/xtensa.opt:31
+msgid "Use indirect CALLXn instructions for large programs"
+msgstr ""
+
+#: config/xtensa/xtensa.opt:35
+msgid "Automatically align branch targets to reduce branch penalties"
+msgstr ""
+
+#: config/xtensa/xtensa.opt:39
+msgid "Intersperse literal pools with code in the text section"
+msgstr ""
+
+#: config/xtensa/xtensa.opt:43
+msgid "-mno-serialize-volatile\tDo not serialize volatile memory references with MEMW instructions"
+msgstr ""
+
+#: config/i386/cygming.opt:23
+msgid "Create console application"
+msgstr ""
+
+#: config/i386/cygming.opt:27
+msgid "Generate code for a DLL"
+msgstr ""
+
+#: config/i386/cygming.opt:31
+msgid "Ignore dllimport for functions"
+msgstr ""
+
+#: config/i386/cygming.opt:35
+msgid "Use Mingw-specific thread support"
+msgstr ""
+
+#: config/i386/cygming.opt:39
+msgid "Set Windows defines"
+msgstr ""
+
+#: config/i386/cygming.opt:43
+msgid "Create GUI application"
+msgstr ""
+
+#: config/i386/cygming.opt:47 config/i386/interix.opt:32
+msgid "Use the GNU extension to the PE format for aligned common data"
+msgstr ""
+
+#: config/i386/cygming.opt:51
+msgid "Compile code that relies on Cygwin DLL wrappers to support C++ operator new/delete replacement"
+msgstr ""
+
+#: config/i386/cygming.opt:58
+msgid "Put relocated read-only data into .data section."
+msgstr ""
+
+#: config/i386/mingw.opt:29
+msgid "Warn about none ISO msvcrt scanf/printf width extensions"
+msgstr ""
+
+#: config/i386/mingw.opt:33
+msgid "For nested functions on stack executable permission is set."
+msgstr ""
+
+#: config/i386/mingw-w64.opt:23
+msgid "Use unicode startup and define UNICODE macro"
+msgstr ""
+
+#: config/i386/djgpp.opt:25
+msgid "Ignored (obsolete)"
+msgstr ""
+
+#: config/i386/i386.opt:182
+msgid "sizeof(long double) is 16"
+msgstr ""
+
+#: config/i386/i386.opt:186 config/i386/i386.opt:354
+msgid "Use hardware fp"
+msgstr ""
+
+#: config/i386/i386.opt:190
+msgid "sizeof(long double) is 12"
+msgstr ""
+
+#: config/i386/i386.opt:194
+msgid "Use 80-bit long double"
+msgstr ""
+
+#: config/i386/i386.opt:198 config/s390/s390.opt:115
+#: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
+msgid "Use 64-bit long double"
+msgstr ""
+
+#: config/i386/i386.opt:202 config/s390/s390.opt:111
+#: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
+msgid "Use 128-bit long double"
+msgstr ""
+
+#: config/i386/i386.opt:206 config/sh/sh.opt:209
+msgid "Reserve space for outgoing arguments in the function prologue"
+msgstr ""
+
+#: config/i386/i386.opt:210
+msgid "Align some doubles on dword boundary"
+msgstr ""
+
+#: config/i386/i386.opt:214
+msgid "Function starts are aligned to this power of 2"
+msgstr ""
+
+#: config/i386/i386.opt:218
+msgid "Jump targets are aligned to this power of 2"
+msgstr ""
+
+#: config/i386/i386.opt:222
+msgid "Loop code aligned to this power of 2"
+msgstr ""
+
+#: config/i386/i386.opt:226
+msgid "Align destination of the string operations"
+msgstr ""
+
+#: config/i386/i386.opt:230
+msgid "Use the given data alignment"
+msgstr ""
+
+#: config/i386/i386.opt:234
+msgid "Known data alignment choices (for use with the -malign-data= option):"
+msgstr ""
+
+#: config/i386/i386.opt:251
+msgid "Use given assembler dialect"
+msgstr ""
+
+#: config/i386/i386.opt:255
+msgid "Known assembler dialects (for use with the -masm-dialect= option):"
+msgstr ""
+
+#: config/i386/i386.opt:265
+msgid "Branches are this expensive (1-5, arbitrary units)"
+msgstr ""
+
+#: config/i386/i386.opt:269
+msgid "Data greater than given threshold will go into .ldata section in x86-64 medium model"
+msgstr ""
+
+#: config/i386/i386.opt:273
+msgid "Use given x86-64 code model"
+msgstr ""
+
+#: config/i386/i386.opt:277 config/rs6000/aix64.opt:36
+#: config/rs6000/linux64.opt:32 config/tilegx/tilegx.opt:57
+msgid "Known code models (for use with the -mcmodel= option):"
+msgstr ""
+
+#: config/i386/i386.opt:296
+msgid "Use given address mode"
+msgstr ""
+
+#: config/i386/i386.opt:300
+msgid "Known address mode (for use with the -maddress-mode= option):"
+msgstr ""
+
+#: config/i386/i386.opt:309
+msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
+msgstr ""
+
+#: config/i386/i386.opt:313
+msgid "Generate sin, cos, sqrt for FPU"
+msgstr ""
+
+#: config/i386/i386.opt:317
+msgid "Always use Dynamic Realigned Argument Pointer (DRAP) to realign stack"
+msgstr ""
+
+#: config/i386/i386.opt:321
+msgid "Return values of functions in FPU registers"
+msgstr ""
+
+#: config/i386/i386.opt:325
+msgid "Generate floating point mathematics using given instruction set"
+msgstr ""
+
+#: config/i386/i386.opt:329
+msgid "Valid arguments to -mfpmath=:"
+msgstr ""
+
+#: config/i386/i386.opt:362
+msgid "Inline all known string operations"
+msgstr ""
+
+#: config/i386/i386.opt:366
+msgid "Inline memset/memcpy string operations, but perform inline version only for small blocks"
+msgstr ""
+
+#: config/i386/i386.opt:369
+msgid "%<-mintel-syntax%> and %<-mno-intel-syntax%> are deprecated; use %<-masm=intel%> and %<-masm=att%> instead"
+msgstr ""
+
+#: config/i386/i386.opt:394
+msgid "Set 80387 floating-point precision to 32-bit"
+msgstr ""
+
+#: config/i386/i386.opt:398
+msgid "Set 80387 floating-point precision to 64-bit"
+msgstr ""
+
+#: config/i386/i386.opt:402
+msgid "Set 80387 floating-point precision to 80-bit"
+msgstr ""
+
+#: config/i386/i386.opt:406
+msgid "Attempt to keep stack aligned to this power of 2"
+msgstr ""
+
+#: config/i386/i386.opt:410
+msgid "Assume incoming stack aligned to this power of 2"
+msgstr ""
+
+#: config/i386/i386.opt:414
+msgid "Use push instructions to save outgoing arguments"
+msgstr ""
+
+#: config/i386/i386.opt:418
+msgid "Use red-zone in the x86-64 code"
+msgstr ""
+
+#: config/i386/i386.opt:422
+msgid "Number of registers used to pass integer arguments"
+msgstr ""
+
+#: config/i386/i386.opt:426
+msgid "Alternate calling convention"
+msgstr ""
+
+#: config/i386/i386.opt:430 config/alpha/alpha.opt:23
+msgid "Do not use hardware fp"
+msgstr ""
+
+#: config/i386/i386.opt:434
+msgid "Use SSE register passing conventions for SF and DF mode"
+msgstr ""
+
+#: config/i386/i386.opt:438
+msgid "Realign stack in prologue"
+msgstr ""
+
+#: config/i386/i386.opt:442
+msgid "Enable stack probing"
+msgstr ""
+
+#: config/i386/i386.opt:446
+msgid "Specify memcpy expansion strategy when expected size is known"
+msgstr ""
+
+#: config/i386/i386.opt:450
+msgid "Specify memset expansion strategy when expected size is known"
+msgstr ""
+
+#: config/i386/i386.opt:454
+msgid "Chose strategy to generate stringop using"
+msgstr ""
+
+#: config/i386/i386.opt:458
+msgid "Valid arguments to -mstringop-strategy=:"
+msgstr ""
+
+#: config/i386/i386.opt:486
+msgid "Use given thread-local storage dialect"
+msgstr ""
+
+#: config/i386/i386.opt:490
+msgid "Known TLS dialects (for use with the -mtls-dialect= option):"
+msgstr ""
+
+#: config/i386/i386.opt:500
+#, c-format
+msgid "Use direct references against %gs when accessing tls data"
+msgstr ""
+
+#: config/i386/i386.opt:508
+msgid "Fine grain control of tune features"
+msgstr ""
+
+#: config/i386/i386.opt:512
+msgid "Clear all tune features"
+msgstr ""
+
+#: config/i386/i386.opt:519
+msgid "Generate code that conforms to the given ABI"
+msgstr ""
+
+#: config/i386/i386.opt:523
+msgid "Known ABIs (for use with the -mabi= option):"
+msgstr ""
+
+#: config/i386/i386.opt:533 config/rs6000/rs6000.opt:189
+msgid "Vector library ABI to use"
+msgstr ""
+
+#: config/i386/i386.opt:537
+msgid "Known vectorization library ABIs (for use with the -mveclibabi= option):"
+msgstr ""
+
+#: config/i386/i386.opt:547
+msgid "Return 8-byte vectors in memory"
+msgstr ""
+
+#: config/i386/i386.opt:551
+msgid "Generate reciprocals instead of divss and sqrtss."
+msgstr ""
+
+#: config/i386/i386.opt:555
+msgid "Control generation of reciprocal estimates."
+msgstr ""
+
+#: config/i386/i386.opt:559
+msgid "Generate cld instruction in the function prologue."
+msgstr ""
+
+#: config/i386/i386.opt:563
+msgid "Generate vzeroupper instruction before a transfer of control flow out of"
+msgstr ""
+
+#: config/i386/i386.opt:568
+msgid "Do dispatch scheduling if processor is bdver1 or bdver2 or bdver3 or bdver4 and Haifa scheduling"
+msgstr ""
+
+#: config/i386/i386.opt:573
+msgid "Use 128-bit AVX instructions instead of 256-bit AVX instructions in the auto-vectorizer."
+msgstr ""
+
+#: config/i386/i386.opt:579
+msgid "Generate 32bit i386 code"
+msgstr ""
+
+#: config/i386/i386.opt:583
+msgid "Generate 64bit x86-64 code"
+msgstr ""
+
+#: config/i386/i386.opt:587
+msgid "Generate 32bit x86-64 code"
+msgstr ""
+
+#: config/i386/i386.opt:591
+msgid "Generate 16bit i386 code"
+msgstr ""
+
+#: config/i386/i386.opt:595
+msgid "Support MMX built-in functions"
+msgstr ""
+
+#: config/i386/i386.opt:599
+msgid "Support 3DNow! built-in functions"
+msgstr ""
+
+#: config/i386/i386.opt:603
+msgid "Support Athlon 3Dnow! built-in functions"
+msgstr ""
+
+#: config/i386/i386.opt:607
+msgid "Support MMX and SSE built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:611
+msgid "Support MMX, SSE and SSE2 built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:615
+msgid "Support MMX, SSE, SSE2 and SSE3 built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:619
+msgid "Support MMX, SSE, SSE2, SSE3 and SSSE3 built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:623
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3 and SSE4.1 built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:627 config/i386/i386.opt:631
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1 and SSE4.2 built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:635
+msgid "Do not support SSE4.1 and SSE4.2 built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:638
+msgid "%<-msse5%> was removed"
+msgstr ""
+
+#: config/i386/i386.opt:643
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2 and AVX built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:647
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:651
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:655
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512PF built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:659
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512ER built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:663
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512CD built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:667
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512DQ built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:671
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512BW built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:675
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512VL built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:679
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512IFMA built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:683
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512VBMI built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:687
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:691
+msgid "Support MMX, SSE, SSE2, SSE3 and SSE4A built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:695
+msgid "Support FMA4 built-in functions and code generation "
+msgstr ""
+
+#: config/i386/i386.opt:699
+msgid "Support XOP built-in functions and code generation "
+msgstr ""
+
+#: config/i386/i386.opt:703
+msgid "Support LWP built-in functions and code generation "
+msgstr ""
+
+#: config/i386/i386.opt:707
+msgid "Support code generation of Advanced Bit Manipulation (ABM) instructions."
+msgstr ""
+
+#: config/i386/i386.opt:711
+msgid "Support code generation of popcnt instruction."
+msgstr ""
+
+#: config/i386/i386.opt:715
+msgid "Support BMI built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:719
+msgid "Support BMI2 built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:723
+msgid "Support LZCNT built-in function and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:727
+msgid "Support Hardware Lock Elision prefixes"
+msgstr ""
+
+#: config/i386/i386.opt:731
+msgid "Support RDSEED instruction"
+msgstr ""
+
+#: config/i386/i386.opt:735
+msgid "Support PREFETCHW instruction"
+msgstr ""
+
+#: config/i386/i386.opt:739
+msgid "Support flag-preserving add-carry instructions"
+msgstr ""
+
+#: config/i386/i386.opt:743
+msgid "Support CLFLUSHOPT instructions"
+msgstr ""
+
+#: config/i386/i386.opt:747
+msgid "Support CLWB instruction"
+msgstr ""
+
+#: config/i386/i386.opt:751
+msgid "Support PCOMMIT instruction"
+msgstr ""
+
+#: config/i386/i386.opt:755
+msgid "Support FXSAVE and FXRSTOR instructions"
+msgstr ""
+
+#: config/i386/i386.opt:759
+msgid "Support XSAVE and XRSTOR instructions"
+msgstr ""
+
+#: config/i386/i386.opt:763
+msgid "Support XSAVEOPT instruction"
+msgstr ""
+
+#: config/i386/i386.opt:767
+msgid "Support XSAVEC instructions"
+msgstr ""
+
+#: config/i386/i386.opt:771
+msgid "Support XSAVES and XRSTORS instructions"
+msgstr ""
+
+#: config/i386/i386.opt:775
+msgid "Support TBM built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:779
+msgid "Support code generation of cmpxchg16b instruction."
+msgstr ""
+
+#: config/i386/i386.opt:783
+msgid "Support code generation of sahf instruction in 64bit x86-64 code."
+msgstr ""
+
+#: config/i386/i386.opt:787
+msgid "Support code generation of movbe instruction."
+msgstr ""
+
+#: config/i386/i386.opt:791
+msgid "Support code generation of crc32 instruction."
+msgstr ""
+
+#: config/i386/i386.opt:795
+msgid "Support AES built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:799
+msgid "Support SHA1 and SHA256 built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:803
+msgid "Support PCLMUL built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:807
+msgid "Encode SSE instructions with VEX prefix"
+msgstr ""
+
+#: config/i386/i386.opt:811
+msgid "Support FSGSBASE built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:815
+msgid "Support RDRND built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:819
+msgid "Support F16C built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:823
+msgid "Support PREFETCHWT1 built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:827
+msgid "Emit profiling counter call at function entry before prologue."
+msgstr ""
+
+#: config/i386/i386.opt:831
+msgid "Generate __mcount_loc section with all mcount or __fentry__ calls."
+msgstr ""
+
+#: config/i386/i386.opt:835
+msgid "Generate mcount/__fentry__ calls as nops. To activate they need to be"
+msgstr ""
+
+#: config/i386/i386.opt:840
+msgid "Skip setting up RAX register when passing variable arguments."
+msgstr ""
+
+#: config/i386/i386.opt:844
+msgid "Expand 32bit/64bit integer divide into 8bit unsigned integer divide with run-time check"
+msgstr ""
+
+#: config/i386/i386.opt:848
+msgid "Split 32-byte AVX unaligned load"
+msgstr ""
+
+#: config/i386/i386.opt:852
+msgid "Split 32-byte AVX unaligned store"
+msgstr ""
+
+#: config/i386/i386.opt:856
+msgid "Support RTM built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:860
+msgid "Support MPX code generation"
+msgstr ""
+
+#: config/i386/i386.opt:864
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:868
+msgid "Use given stack-protector guard"
+msgstr ""
+
+#: config/i386/i386.opt:872
+msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
+msgstr ""
+
+#: config/i386/stringop.opt:8
+msgid "the Free Software Foundation; either version 3, or (at your option)"
+msgstr ""
+
+#: config/i386/stringop.opt:13
+msgid "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the"
+msgstr ""
+
+#: config/i386/stringop.opt:18
+msgid "see <http://www.gnu.org/licenses/>.  */"
+msgstr "див. <http://www.gnu.org/licenses/>.  */"
+
+#: config/pa/pa64-hpux.opt:23
+msgid "Assume code will be linked by GNU ld"
+msgstr ""
+
+#: config/pa/pa64-hpux.opt:27
+msgid "Assume code will be linked by HP ld"
+msgstr ""
+
+#: config/pa/pa-hpux1010.opt:23 config/pa/pa-hpux.opt:31
+#: config/pa/pa-hpux1131.opt:23 config/pa/pa-hpux1111.opt:23
+msgid "Specify UNIX standard for predefines and linking"
+msgstr ""
+
+#: config/pa/pa-hpux.opt:27
+msgid "Generate cpp defines for server IO"
+msgstr ""
+
+#: config/pa/pa-hpux.opt:35
+msgid "Generate cpp defines for workstation IO"
+msgstr ""
+
+#: config/pa/pa.opt:30 config/pa/pa.opt:83 config/pa/pa.opt:91
+msgid "Generate PA1.0 code"
+msgstr ""
+
+#: config/pa/pa.opt:34 config/pa/pa.opt:95 config/pa/pa.opt:136
+msgid "Generate PA1.1 code"
+msgstr ""
+
+#: config/pa/pa.opt:38 config/pa/pa.opt:99
+msgid "Generate PA2.0 code (requires binutils 2.10 or later)"
+msgstr ""
+
+#: config/pa/pa.opt:46
+msgid "Disable FP regs"
+msgstr ""
+
+#: config/pa/pa.opt:50
+msgid "Disable indexed addressing"
+msgstr ""
+
+#: config/pa/pa.opt:54
+msgid "Generate fast indirect calls"
+msgstr ""
+
+#: config/pa/pa.opt:62
+msgid "Assume code will be assembled by GAS"
+msgstr ""
+
+#: config/pa/pa.opt:71
+msgid "Enable linker optimizations"
+msgstr ""
+
+#: config/pa/pa.opt:75
+msgid "Always generate long calls"
+msgstr ""
+
+#: config/pa/pa.opt:79
+msgid "Emit long load/store sequences"
+msgstr ""
+
+#: config/pa/pa.opt:87
+msgid "Disable space regs"
+msgstr ""
+
+#: config/pa/pa.opt:103
+msgid "Use portable calling conventions"
+msgstr ""
+
+#: config/pa/pa.opt:107
+msgid "Specify CPU for scheduling purposes.  Valid arguments are 700, 7100, 7100LC, 7200, 7300, and 8000"
+msgstr ""
+
+#: config/pa/pa.opt:132 config/frv/frv.opt:215
+msgid "Use software floating point"
+msgstr ""
+
+#: config/pa/pa.opt:140
+msgid "Do not disable space regs"
+msgstr ""
+
+#: config/v850/v850.opt:29
+msgid "Use registers r2 and r5"
+msgstr ""
+
+#: config/v850/v850.opt:33
+msgid "Use 4 byte entries in switch tables"
+msgstr ""
+
+#: config/v850/v850.opt:37
+msgid "Enable backend debugging"
+msgstr ""
+
+#: config/v850/v850.opt:41
+msgid "Do not use the callt instruction (default)"
+msgstr ""
+
+#: config/v850/v850.opt:45
+msgid "Reuse r30 on a per function basis"
+msgstr ""
+
+#: config/v850/v850.opt:52
+msgid "Prohibit PC relative function calls"
+msgstr ""
+
+#: config/v850/v850.opt:56
+msgid "Use stubs for function prologues"
+msgstr ""
+
+#: config/v850/v850.opt:60
+msgid "Set the max size of data eligible for the SDA area"
+msgstr ""
+
+#: config/v850/v850.opt:67
+msgid "Enable the use of the short load instructions"
+msgstr ""
+
+#: config/v850/v850.opt:71
+msgid "Same as: -mep -mprolog-function"
+msgstr ""
+
+#: config/v850/v850.opt:75
+msgid "Set the max size of data eligible for the TDA area"
+msgstr ""
+
+#: config/v850/v850.opt:82
+msgid "Do not enforce strict alignment"
+msgstr ""
+
+#: config/v850/v850.opt:86
+msgid "Put jump tables for switch statements into the .data section rather than the .code section"
+msgstr ""
+
+#: config/v850/v850.opt:93
+msgid "Compile for the v850 processor"
+msgstr ""
+
+#: config/v850/v850.opt:97
+msgid "Compile for the v850e processor"
+msgstr ""
+
+#: config/v850/v850.opt:101
+msgid "Compile for the v850e1 processor"
+msgstr ""
+
+#: config/v850/v850.opt:105
+msgid "Compile for the v850es variant of the v850e1"
+msgstr ""
+
+#: config/v850/v850.opt:109
+msgid "Compile for the v850e2 processor"
+msgstr ""
+
+#: config/v850/v850.opt:113
+msgid "Compile for the v850e2v3 processor"
+msgstr ""
+
+#: config/v850/v850.opt:117
+msgid "Compile for the v850e3v5 processor"
+msgstr ""
+
+#: config/v850/v850.opt:124
+msgid "Enable v850e3v5 loop instructions"
+msgstr ""
+
+#: config/v850/v850.opt:128
+msgid "Set the max size of data eligible for the ZDA area"
+msgstr ""
+
+#: config/v850/v850.opt:135
+msgid "Enable relaxing in the assembler"
+msgstr ""
+
+#: config/v850/v850.opt:139
+msgid "Prohibit PC relative jumps"
+msgstr ""
+
+#: config/v850/v850.opt:143
+msgid "Inhibit the use of hardware floating point instructions"
+msgstr ""
+
+#: config/v850/v850.opt:147
+msgid "Allow the use of hardware floating point instructions for V850E2V3 and up"
+msgstr ""
+
+#: config/v850/v850.opt:151
+msgid "Enable support for the RH850 ABI.  This is the default"
+msgstr ""
+
+#: config/v850/v850.opt:155
+msgid "Enable support for the old GCC ABI"
+msgstr ""
+
+#: config/v850/v850.opt:159
+msgid "Support alignments of up to 64-bits"
+msgstr ""
+
+#: config/g.opt:27
+msgid "-G<number>\tPut global and static data smaller than <number> bytes into a special section (on some targets)"
+msgstr ""
+
+#: config/lynx.opt:23
+msgid "Support legacy multi-threading"
+msgstr ""
+
+#: config/lynx.opt:27
+msgid "Use shared libraries"
+msgstr ""
+
+#: config/lynx.opt:31
+msgid "Support multi-threading"
+msgstr ""
+
+#: config/nvptx/nvptx.opt:22
+msgid "Generate code for a 32-bit ABI"
+msgstr ""
+
+#: config/nvptx/nvptx.opt:26
+msgid "Generate code for a 64-bit ABI"
+msgstr ""
+
+#: config/nvptx/nvptx.opt:30
+msgid "Link in code for a __main kernel."
+msgstr ""
+
+#: config/vxworks.opt:36
+msgid "Assume the VxWorks RTP environment"
+msgstr ""
+
+#: config/vxworks.opt:43
+msgid "Assume the VxWorks vThreads environment"
+msgstr ""
+
+#: config/cr16/cr16.opt:23
+msgid "-msim   Use simulator runtime"
+msgstr ""
+
+#: config/cr16/cr16.opt:27
+msgid "Generate SBIT, CBIT instructions"
+msgstr ""
+
+#: config/cr16/cr16.opt:31
+msgid "Support multiply accumulate instructions"
+msgstr ""
+
+#: config/cr16/cr16.opt:38
+msgid "Treat data references as near, far or medium. medium is default"
+msgstr ""
+
+#: config/cr16/cr16.opt:42
+msgid "Generate code for CR16C architecture"
+msgstr ""
+
+#: config/cr16/cr16.opt:46
+msgid "Generate code for CR16C+ architecture (Default)"
+msgstr ""
+
+#: config/cr16/cr16.opt:50
+msgid "Treat integers as 32-bit."
+msgstr ""
+
+#: config/avr/avr.opt:23
+msgid "Use subroutines for function prologues and epilogues"
+msgstr ""
+
+#: config/avr/avr.opt:26
+#, c-format
+msgid "missing device or architecture after %qs"
+msgstr ""
+
+#: config/avr/avr.opt:27
+msgid "-mmcu=MCU\tSelect the target MCU"
+msgstr ""
+
+#: config/avr/avr.opt:31
+msgid "Set the number of 64 KiB flash segments"
+msgstr ""
+
+#: config/avr/avr.opt:35
+msgid "Indicate presence of a processor erratum"
+msgstr ""
+
+#: config/avr/avr.opt:39
+msgid "Enable Read-Modify-Write (RMW) instructions support/use"
+msgstr ""
+
+#: config/avr/avr.opt:49
+msgid "Use an 8-bit 'int' type"
+msgstr ""
+
+#: config/avr/avr.opt:53
+msgid "Change the stack pointer without disabling interrupts"
+msgstr ""
+
+#: config/avr/avr.opt:57
+msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 0."
+msgstr ""
+
+#: config/avr/avr.opt:67
+msgid "Change only the low 8 bits of the stack pointer"
+msgstr ""
+
+#: config/avr/avr.opt:71
+msgid "Relax branches"
+msgstr ""
+
+#: config/avr/avr.opt:75
+msgid "Make the linker relaxation machine assume that a program counter wrap-around occurs."
+msgstr ""
+
+#: config/avr/avr.opt:79
+msgid "Accumulate outgoing function arguments and acquire/release the needed stack space for outpoing function arguments in function prologue/epilogue.  Without this option, outgoing arguments are pushed before calling a function and popped afterwards.  This option can lead to reduced code size for functions that call many functions that get their arguments on the stack like, for example printf."
+msgstr ""
+
+#: config/avr/avr.opt:83
+msgid "When accessing RAM, use X as imposed by the hardware, i.e. just use pre-decrement, post-increment and indirect addressing with the X register.  Without this option, the compiler may assume that there is an addressing mode X+const similar to Y+const and Z+const and emit instructions to emulate such an addressing mode for X."
+msgstr ""
+
+#: config/avr/avr.opt:88
+msgid "The device has no SPH special function register. This option will be overridden by the compiler driver with the correct setting if presence/absence of SPH can be deduced from -mmcu=MCU."
+msgstr ""
+
+#: config/avr/avr.opt:92
+msgid "Warn if the address space of an address is changed."
+msgstr ""
+
+#: config/avr/avr.opt:96
+msgid "Allow to use truncation instead of rounding towards 0 for fractional int types"
+msgstr ""
+
+#: config/avr/avr.opt:100
+msgid "Do not link against the device-specific library lib<MCU>.a"
+msgstr ""
+
+#: config/m32r/m32r.opt:34
+msgid "Compile for the m32rx"
+msgstr ""
+
+#: config/m32r/m32r.opt:38
+msgid "Compile for the m32r2"
+msgstr ""
+
+#: config/m32r/m32r.opt:42
+msgid "Compile for the m32r"
+msgstr ""
+
+#: config/m32r/m32r.opt:46
+msgid "Align all loops to 32 byte boundary"
+msgstr ""
+
+#: config/m32r/m32r.opt:50
+msgid "Prefer branches over conditional execution"
+msgstr ""
+
+#: config/m32r/m32r.opt:54
+msgid "Give branches their default cost"
+msgstr ""
+
+#: config/m32r/m32r.opt:58
+msgid "Display compile time statistics"
+msgstr ""
+
+#: config/m32r/m32r.opt:62
+msgid "Specify cache flush function"
+msgstr ""
+
+#: config/m32r/m32r.opt:66
+msgid "Specify cache flush trap number"
+msgstr ""
+
+#: config/m32r/m32r.opt:70
+msgid "Only issue one instruction per cycle"
+msgstr ""
+
+#: config/m32r/m32r.opt:74
+msgid "Allow two instructions to be issued per cycle"
+msgstr ""
+
+#: config/m32r/m32r.opt:78
+msgid "Code size: small, medium or large"
+msgstr ""
+
+#: config/m32r/m32r.opt:94
+msgid "Don't call any cache flush functions"
+msgstr ""
+
+#: config/m32r/m32r.opt:98
+msgid "Don't call any cache flush trap"
+msgstr ""
+
+#: config/m32r/m32r.opt:105
+msgid "Small data area: none, sdata, use"
+msgstr ""
+
+#: config/s390/tpf.opt:23
+msgid "Enable TPF-OS tracing code"
+msgstr ""
+
+#: config/s390/tpf.opt:27
+msgid "Specify main object for TPF-OS"
+msgstr ""
+
+#: config/s390/s390.opt:39
+msgid "31 bit ABI"
+msgstr ""
+
+#: config/s390/s390.opt:43
+msgid "64 bit ABI"
+msgstr ""
+
+#: config/s390/s390.opt:81
+msgid "Maintain backchain pointer"
+msgstr ""
+
+#: config/s390/s390.opt:85
+msgid "Additional debug prints"
+msgstr ""
+
+#: config/s390/s390.opt:89
+msgid "ESA/390 architecture"
+msgstr ""
+
+#: config/s390/s390.opt:93
+msgid "Enable decimal floating point hardware support"
+msgstr ""
+
+#: config/s390/s390.opt:97
+msgid "Enable hardware floating point"
+msgstr ""
+
+#: config/s390/s390.opt:101
+msgid "Takes two non-negative integer numbers separated by a comma."
+msgstr ""
+
+#: config/s390/s390.opt:119
+msgid "Use hardware transactional execution instructions"
+msgstr ""
+
+#: config/s390/s390.opt:123
+msgid "Use packed stack layout"
+msgstr ""
+
+#: config/s390/s390.opt:127
+msgid "Use bras for executable < 64k"
+msgstr ""
+
+#: config/s390/s390.opt:131
+msgid "Disable hardware floating point"
+msgstr ""
+
+#: config/s390/s390.opt:135
+msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered"
+msgstr ""
+
+#: config/s390/s390.opt:139
+msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit"
+msgstr ""
+
+#: config/s390/s390.opt:147
+msgid "mvcle use"
+msgstr ""
+
+#: config/s390/s390.opt:151
+msgid "Warn if a function uses alloca or creates an array with dynamic size"
+msgstr ""
+
+#: config/s390/s390.opt:155
+msgid "Warn if a single function's framesize exceeds the given framesize"
+msgstr ""
+
+#: config/s390/s390.opt:159
+msgid "z/Architecture"
+msgstr ""
+
+#: config/s390/s390.opt:163
+msgid "Set the branch costs for conditional branch instructions.  Reasonable"
+msgstr ""
+
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
+#: config/mips/mips.opt:389
+msgid "Use LRA instead of reload"
+msgstr ""
+
+#: config/rl78/rl78.opt:27 config/rx/rx.opt:87
+msgid "Use the simulator runtime."
+msgstr ""
+
+#: config/rl78/rl78.opt:31
+msgid "Select hardware or software multiplication support."
+msgstr ""
+
+#: config/rl78/rl78.opt:47
+msgid "Use all registers, reserving none for interrupt handlers."
+msgstr ""
+
+#: config/rl78/rl78.opt:51
+msgid "Enable assembler and linker relaxation.  Enabled by default at -Os."
+msgstr ""
+
+#: config/rl78/rl78.opt:55
+msgid "Target the RL78/G10 series"
+msgstr ""
+
+#: config/rl78/rl78.opt:59
+msgid "Assume ES is zero throughout program execution, use ES: for read-only data."
+msgstr ""
+
+#: config/stormy16/stormy16.opt:24
+msgid "Provide libraries for the simulator"
+msgstr ""
+
+#: config/arm/arm-tables.opt:25
+msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
+msgstr ""
+
+#: config/arm/arm-tables.opt:329
+msgid "Known ARM architectures (for use with the -march= option):"
+msgstr ""
+
+#: config/arm/arm-tables.opt:417
+msgid "Known ARM FPUs (for use with the -mfpu= option):"
+msgstr ""
+
+#: config/arm/arm.opt:26
+msgid "TLS dialect to use:"
+msgstr ""
+
+#: config/arm/arm.opt:36
+msgid "Specify an ABI"
+msgstr ""
+
+#: config/arm/arm.opt:40
+msgid "Known ARM ABIs (for use with the -mabi= option):"
+msgstr ""
+
+#: config/arm/arm.opt:59
+msgid "Generate a call to abort if a noreturn function returns"
+msgstr ""
+
+#: config/arm/arm.opt:66
+msgid "Pass FP arguments in FP registers"
+msgstr ""
+
+#: config/arm/arm.opt:70
+msgid "Generate APCS conformant stack frames"
+msgstr ""
+
+#: config/arm/arm.opt:74
+msgid "Generate re-entrant, PIC code"
+msgstr ""
+
+#: config/arm/arm.opt:90
+msgid "Generate code in 32 bit ARM state."
+msgstr ""
+
+#: config/arm/arm.opt:98
+msgid "Thumb: Assume non-static functions may be called from ARM code"
+msgstr ""
+
+#: config/arm/arm.opt:102
+msgid "Thumb: Assume function pointers may go to non-Thumb aware code"
+msgstr ""
+
+#: config/arm/arm.opt:110
+msgid "Specify if floating point hardware should be used"
+msgstr ""
+
+#: config/arm/arm.opt:114
+msgid "Known floating-point ABIs (for use with the -mfloat-abi= option):"
+msgstr ""
+
+#: config/arm/arm.opt:127
+msgid "Specify the __fp16 floating-point format"
+msgstr ""
+
+#: config/arm/arm.opt:131
+msgid "Known __fp16 formats (for use with the -mfp16-format= option):"
+msgstr ""
+
+#: config/arm/arm.opt:144
+msgid "Specify the name of the target floating point hardware/format"
+msgstr ""
+
+#: config/arm/arm.opt:155
+msgid "Generate call insns as indirect calls, if necessary"
+msgstr ""
+
+#: config/arm/arm.opt:159
+msgid "Assume data segments are relative to text segment."
+msgstr ""
+
+#: config/arm/arm.opt:163
+msgid "Specify the register to be used for PIC addressing"
+msgstr ""
+
+#: config/arm/arm.opt:167
+msgid "Store function names in object code"
+msgstr ""
+
+#: config/arm/arm.opt:171
+msgid "Permit scheduling of a function's prologue sequence"
+msgstr ""
+
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
+msgid "Do not load the PIC register in function prologues"
+msgstr ""
+
+#: config/arm/arm.opt:182
+msgid "Specify the minimum bit alignment of structures"
+msgstr ""
+
+#: config/arm/arm.opt:186
+msgid "Generate code for Thumb state"
+msgstr ""
+
+#: config/arm/arm.opt:190
+msgid "Support calls between Thumb and ARM instruction sets"
+msgstr ""
+
+#: config/arm/arm.opt:194
+msgid "Specify thread local storage scheme"
+msgstr ""
+
+#: config/arm/arm.opt:198
+msgid "Specify how to access the thread pointer"
+msgstr ""
+
+#: config/arm/arm.opt:202
+msgid "Valid arguments to -mtp=:"
+msgstr ""
+
+#: config/arm/arm.opt:215
+msgid "Thumb: Generate (non-leaf) stack frames even if not needed"
+msgstr ""
+
+#: config/arm/arm.opt:219
+msgid "Thumb: Generate (leaf) stack frames even if not needed"
+msgstr ""
+
+#: config/arm/arm.opt:223 config/mn10300/mn10300.opt:42
+msgid "Tune code for the given processor"
+msgstr ""
+
+#: config/arm/arm.opt:227
+msgid "Print CPU tuning information as comment in assembler file.  This is"
+msgstr ""
+
+#: config/arm/arm.opt:238
+msgid "Use Neon quad-word (rather than double-word) registers for vectorization"
+msgstr ""
+
+#: config/arm/arm.opt:242
+msgid "Use Neon double-word (rather than quad-word) registers for vectorization"
+msgstr ""
+
+#: config/arm/arm.opt:246
+msgid "Only generate absolute relocations on word sized values."
+msgstr ""
+
+#: config/arm/arm.opt:250
+msgid "Generate IT blocks appropriate for ARMv8."
+msgstr ""
+
+#: config/arm/arm.opt:254
+msgid "Use the old RTX costing tables (transitional)."
+msgstr ""
+
+#: config/arm/arm.opt:258
+msgid "Use the new generic RTX cost tables if new core-specific cost table not available (transitional)."
+msgstr ""
+
+#: config/arm/arm.opt:262
+msgid "Avoid overlapping destination and address registers on LDRD instructions"
+msgstr ""
+
+#: config/arm/arm.opt:267
+msgid "Enable unaligned word and halfword accesses to packed data."
+msgstr ""
+
+#: config/arm/arm.opt:271
+msgid "Use Neon to perform 64-bits operations rather than core registers."
+msgstr ""
+
+#: config/arm/arm.opt:275
+msgid "Assume loading data from flash is slower than fetching instructions."
+msgstr ""
+
+#: config/arm/arm.opt:279
+msgid "Assume unified syntax for Thumb inline assembly code."
+msgstr ""
+
+#: config/sparc/sparc.opt:30 config/sparc/sparc.opt:34
+#: config/visium/visium.opt:37
+msgid "Use hardware FP"
+msgstr ""
+
+#: config/sparc/sparc.opt:38 config/visium/visium.opt:41
+msgid "Do not use hardware FP"
+msgstr ""
+
+#: config/sparc/sparc.opt:42
+msgid "Use flat register window model"
+msgstr ""
+
+#: config/sparc/sparc.opt:46
+msgid "Assume possible double misalignment"
+msgstr ""
+
+#: config/sparc/sparc.opt:50
+msgid "Use ABI reserved registers"
+msgstr ""
+
+#: config/sparc/sparc.opt:54
+msgid "Use hardware quad FP instructions"
+msgstr ""
+
+#: config/sparc/sparc.opt:58
+msgid "Do not use hardware quad fp instructions"
+msgstr ""
+
+#: config/sparc/sparc.opt:62
+msgid "Compile for V8+ ABI"
+msgstr ""
+
+#: config/sparc/sparc.opt:66
+msgid "Use UltraSPARC Visual Instruction Set version 1.0 extensions"
+msgstr ""
+
+#: config/sparc/sparc.opt:70
+msgid "Use UltraSPARC Visual Instruction Set version 2.0 extensions"
+msgstr ""
+
+#: config/sparc/sparc.opt:74
+msgid "Use UltraSPARC Visual Instruction Set version 3.0 extensions"
+msgstr ""
+
+#: config/sparc/sparc.opt:78
+msgid "Use UltraSPARC Compare-and-Branch extensions"
+msgstr ""
+
+#: config/sparc/sparc.opt:82
+msgid "Use UltraSPARC Fused Multiply-Add extensions"
+msgstr ""
+
+#: config/sparc/sparc.opt:86
+msgid "Use UltraSPARC Population-Count instruction"
+msgstr ""
+
+#: config/sparc/sparc.opt:90
+msgid "Pointers are 64-bit"
+msgstr ""
+
+#: config/sparc/sparc.opt:94
+msgid "Pointers are 32-bit"
+msgstr ""
+
+#: config/sparc/sparc.opt:98
+msgid "Use 64-bit ABI"
+msgstr ""
+
+#: config/sparc/sparc.opt:102
+msgid "Use 32-bit ABI"
+msgstr ""
+
+#: config/sparc/sparc.opt:106
+msgid "Use stack bias"
+msgstr ""
+
+#: config/sparc/sparc.opt:110
+msgid "Use structs on stronger alignment for double-word copies"
+msgstr ""
+
+#: config/sparc/sparc.opt:114
+msgid "Optimize tail call instructions in assembler and linker"
+msgstr ""
+
+#: config/sparc/sparc.opt:118
+msgid "Do not generate code that can only run in supervisor mode"
+msgstr ""
+
+#: config/sparc/sparc.opt:122 config/visium/visium.opt:45
+msgid "Use features of and schedule code for given CPU"
+msgstr ""
+
+#: config/sparc/sparc.opt:199
+msgid "Use given SPARC-V9 code model"
+msgstr ""
+
+#: config/sparc/sparc.opt:203
+msgid "Enable debug output"
+msgstr "Увімкнути вивід діагностичної інформації"
+
+#: config/sparc/sparc.opt:207
+msgid "Enable strict 32-bit psABI struct return checking."
+msgstr ""
+
+#: config/sparc/sparc.opt:211
+msgid "Enable workaround for single erratum of AT697F processor"
+msgstr ""
+
+#: config/sparc/sparc.opt:216
+msgid "Enable workarounds for the errata of the UT699 processor"
+msgstr ""
+
+#: config/sparc/sparc.opt:245
+msgid "Specify the memory model in effect for the program."
+msgstr ""
+
+#: config/rs6000/darwin.opt:38 config/rs6000/sysv4.opt:141
+msgid "Generate 64-bit code"
+msgstr ""
+
+#: config/rs6000/darwin.opt:42 config/rs6000/sysv4.opt:145
+msgid "Generate 32-bit code"
+msgstr ""
+
+#: config/rs6000/rs6000-tables.opt:24
+msgid "Known CPUs (for use with the -mcpu= and -mtune= options):"
+msgstr ""
+
+#: config/rs6000/476.opt:24
+msgid "Preserve the PowerPC 476's link stack by matching up a blr with the bcl/bl insns used for GOT accesses"
+msgstr ""
+
+#: config/rs6000/aix64.opt:24
+msgid "Compile for 64-bit pointers"
+msgstr ""
+
+#: config/rs6000/aix64.opt:28
+msgid "Compile for 32-bit pointers"
+msgstr ""
+
+#: config/rs6000/aix64.opt:32 config/rs6000/linux64.opt:28
+msgid "Select code model"
+msgstr ""
+
+#: config/rs6000/aix64.opt:49
+msgid "Support message passing with the Parallel Environment"
+msgstr ""
+
+#: config/rs6000/linux64.opt:24
+msgid "Call mcount for profiling before a function prologue"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:109
+msgid "Use PowerPC-64 instruction set"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:113
+msgid "Use PowerPC General Purpose group optional instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:117
+msgid "Use PowerPC Graphics group optional instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:121
+msgid "Use PowerPC V2.01 single field mfcr instruction"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:125
+msgid "Use PowerPC V2.02 popcntb instruction"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:129
+msgid "Use PowerPC V2.02 floating point rounding instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:133
+msgid "Use PowerPC V2.05 compare bytes instruction"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:137
+msgid "Use extended PowerPC V2.05 move floating point to/from GPR instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:141
+msgid "Use AltiVec instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:145
+msgid "Generate Altivec instructions using little-endian element order"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:149
+msgid "Generate Altivec instructions using big-endian element order"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:153
+msgid "Use decimal floating point instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:157
+msgid "Use 4xx half-word multiply instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:161
+msgid "Use 4xx string-search dlmzb instruction"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:165
+msgid "Generate load/store multiple instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:169
+msgid "Generate string instructions for block moves"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:181
+msgid "Use PowerPC V2.06 popcntd instruction"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:185
+msgid "Under -ffast-math, generate a FRIZ instruction for (double)(long long) conversions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:193
+msgid "Use vector/scalar (VSX) instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:240
+msgid "Do not generate load/store with update instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:244
+msgid "Generate load/store with update instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:252
+msgid "Avoid generation of indexed load/store instructions when possible"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:256
+msgid "Mark __tls_get_addr calls with argument info"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:263
+msgid "Schedule the start and end of the procedure"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:267
+msgid "Return all structures in memory (AIX default)"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:271
+msgid "Return small structures in registers (SVR4 default)"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:275
+msgid "Conform more closely to IBM XLC semantics"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
+msgid "Generate software reciprocal divide and square root for better throughput."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:287
+msgid "Assume that the reciprocal estimate instructions provide more accuracy."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:291
+msgid "Do not place floating point constants in TOC"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:295
+msgid "Place floating point constants in TOC"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:299
+msgid "Do not place symbol+offset constants in TOC"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:303
+msgid "Place symbol+offset constants in TOC"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:314
+msgid "Use only one TOC entry per procedure"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:318
+msgid "Put everything in the regular TOC"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:322
+msgid "Generate VRSAVE instructions when generating AltiVec code"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:326
+msgid "Deprecated option.  Use -mno-vrsave instead"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:330
+msgid "Deprecated option.  Use -mvrsave instead"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:334
+msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:338
+msgid "Generate isel instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:342
+msgid "Deprecated option.  Use -mno-isel instead"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:346
+msgid "Deprecated option.  Use -misel instead"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:350
+msgid "Generate SPE SIMD instructions on E500"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:354
+msgid "Generate PPC750CL paired-single instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:358
+msgid "Deprecated option.  Use -mno-spe instead"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:362
+msgid "Deprecated option.  Use -mspe instead"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:366
+msgid "-mdebug=\tEnable debug output"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:370
+msgid "Use the AltiVec ABI extensions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:374
+msgid "Do not use the AltiVec ABI extensions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:378
+msgid "Use the SPE ABI extensions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:382
+msgid "Do not use the SPE ABI extensions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:386
+msgid "Use the ELFv1 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:390
+msgid "Use the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:397
+msgid "using darwin64 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:400
+msgid "using old darwin ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:403
+msgid "using IEEE extended precision long double"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:406
+msgid "using IBM extended precision long double"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:410
+msgid "-mcpu=\tUse features of and schedule code for given CPU"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:414
+msgid "-mtune=\tSchedule code for given CPU"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:418
+msgid "-mtraceback=\tSelect full, part, or no traceback table"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:434
+msgid "Avoid all range limits on call instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:438
+msgid "Generate Cell microcode"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:442
+msgid "Warn when a Cell microcoded instruction is emitted"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:446
+msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:450
+msgid "-mfloat-gprs=\tSelect GPR floating point method"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:454
+msgid "Valid arguments to -mfloat-gprs=:"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:470
+msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:478
+msgid "Determine which dependences between insns are considered costly"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:482
+msgid "Specify which post scheduling nop insertion scheme to apply"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:486
+msgid "Specify alignment of structure fields default/natural"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:490
+msgid "Valid arguments to -malign-:"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:500
+msgid "Specify scheduling priority for dispatch slot restricted insns"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:504
+msgid "Single-precision floating point unit"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:508
+msgid "Double-precision floating point unit"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:512
+msgid "Floating point unit does not support divide & sqrt"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:516
+msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:538
+msgid "Specify Xilinx FPU."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:542
+msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:546
+msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:550
+msgid "Allow 128-bit integers in VSX registers"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:554
+msgid "Fuse certain integer operations together for better performance on power8"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:558
+msgid "Allow sign extension in fusion operations"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:562
+msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:566
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:570
+msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:574
+msgid "Use ISA 2.07 transactional memory (HTM) instructions"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:578
+msgid "Generate the quad word memory instructions (lq/stq)."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:582
+msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:586
+msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:590
+msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:594
+msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:598
+msgid "Allow float/double variables in upper registers if cpu allows it"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:602
+msgid "Analyze and remove doubleword swaps from VSX computations."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:24
+msgid "Select ABI calling convention"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:28 config/c6x/c6x.opt:42
+msgid "Select method for sdata handling"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:48 config/rs6000/sysv4.opt:52
+msgid "Align to the base type of the bit-field"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:57 config/rs6000/sysv4.opt:61
+msgid "Produce code relocatable at runtime"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:65 config/rs6000/sysv4.opt:69
+msgid "Produce little endian code"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:73 config/rs6000/sysv4.opt:77
+msgid "Produce big endian code"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:82 config/rs6000/sysv4.opt:86
+#: config/rs6000/sysv4.opt:95 config/rs6000/sysv4.opt:137
+#: config/rs6000/sysv4.opt:149
+msgid "no description yet"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:90
+msgid "Assume all variable arg functions are prototyped"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:99
+msgid "Use EABI"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:103
+msgid "Allow bit-fields to cross word boundaries"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:107
+msgid "Use alternate register names"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:113
+msgid "Use default method for sdata handling"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:117
+msgid "Link with libsim.a, libc.a and sim-crt0.o"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:121
+msgid "Link with libads.a, libc.a and crt0.o"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:125
+msgid "Link with libyk.a, libc.a and crt0.o"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:129
+msgid "Link with libmvme.a, libc.a and crt0.o"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:133
+msgid "Set the PPC_EMB bit in the ELF flags header"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:153
+msgid "Generate code to use a non-exec PLT and GOT"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:157
+msgid "Generate code for old exec BSS PLT"
+msgstr ""
+
+#: config/alpha/alpha.opt:27
+msgid "Use fp registers"
+msgstr ""
+
+#: config/alpha/alpha.opt:35
+msgid "Request IEEE-conformant math library routines (OSF/1)"
+msgstr ""
+
+#: config/alpha/alpha.opt:39
+msgid "Emit IEEE-conformant code, without inexact exceptions"
+msgstr ""
+
+#: config/alpha/alpha.opt:46
+msgid "Do not emit complex integer constants to read-only memory"
+msgstr ""
+
+#: config/alpha/alpha.opt:50
+msgid "Use VAX fp"
+msgstr ""
+
+#: config/alpha/alpha.opt:54
+msgid "Do not use VAX fp"
+msgstr ""
+
+#: config/alpha/alpha.opt:58
+msgid "Emit code for the byte/word ISA extension"
+msgstr ""
+
+#: config/alpha/alpha.opt:62
+msgid "Emit code for the motion video ISA extension"
+msgstr ""
+
+#: config/alpha/alpha.opt:66
+msgid "Emit code for the fp move and sqrt ISA extension"
+msgstr ""
+
+#: config/alpha/alpha.opt:70
+msgid "Emit code for the counting ISA extension"
+msgstr ""
+
+#: config/alpha/alpha.opt:74
+msgid "Emit code using explicit relocation directives"
+msgstr ""
+
+#: config/alpha/alpha.opt:78
+msgid "Emit 16-bit relocations to the small data areas"
+msgstr ""
+
+#: config/alpha/alpha.opt:82
+msgid "Emit 32-bit relocations to the small data areas"
+msgstr ""
+
+#: config/alpha/alpha.opt:86
+msgid "Emit direct branches to local functions"
+msgstr ""
+
+#: config/alpha/alpha.opt:90
+msgid "Emit indirect branches to local functions"
+msgstr ""
+
+#: config/alpha/alpha.opt:94
+msgid "Emit rdval instead of rduniq for thread pointer"
+msgstr ""
+
+#: config/alpha/alpha.opt:106
+msgid "Use features of and schedule given CPU"
+msgstr ""
+
+#: config/alpha/alpha.opt:110
+msgid "Schedule given CPU"
+msgstr ""
+
+#: config/alpha/alpha.opt:114
+msgid "Control the generated fp rounding mode"
+msgstr ""
+
+#: config/alpha/alpha.opt:118
+msgid "Control the IEEE trap mode"
+msgstr ""
+
+#: config/alpha/alpha.opt:122
+msgid "Control the precision given to fp exceptions"
+msgstr ""
+
+#: config/alpha/alpha.opt:126
+msgid "Tune expected memory latency"
+msgstr ""
+
+#: config/tilepro/tilepro.opt:23
+msgid "Compile with 32 bit longs and pointers, which is the only supported"
+msgstr ""
+
+#: config/tilepro/tilepro.opt:28 config/tilegx/tilegx.opt:26
+msgid "-mcpu=CPU\tUse features of and schedule code for given CPU"
+msgstr ""
+
+#: config/tilepro/tilepro.opt:32
+msgid "Known TILEPro CPUs (for use with the -mcpu= option):"
+msgstr ""
+
+#: config/lm32/lm32.opt:24
+msgid "Enable multiply instructions"
+msgstr ""
+
+#: config/lm32/lm32.opt:28
+msgid "Enable divide and modulus instructions"
+msgstr ""
+
+#: config/lm32/lm32.opt:32
+msgid "Enable barrel shift instructions"
+msgstr ""
+
+#: config/lm32/lm32.opt:36
+msgid "Enable sign extend instructions"
+msgstr ""
+
+#: config/lm32/lm32.opt:40
+msgid "Enable user-defined instructions"
+msgstr ""
+
+#: config/nios2/elf.opt:26
+msgid "Link with a limited version of the C library"
+msgstr ""
+
+#: config/nios2/elf.opt:30
+msgid "Name of system library to link against"
+msgstr ""
+
+#: config/nios2/elf.opt:34
+msgid "Name of the startfile"
+msgstr ""
+
+#: config/nios2/elf.opt:38
+msgid "Link with HAL BSP"
+msgstr ""
+
+#: config/nios2/nios2.opt:35
+msgid "Enable DIV, DIVU"
+msgstr ""
+
+#: config/nios2/nios2.opt:39
+msgid "Enable MUL instructions"
+msgstr ""
+
+#: config/nios2/nios2.opt:43
+msgid "Enable MULX instructions, assume fast shifter"
+msgstr ""
+
+#: config/nios2/nios2.opt:47
+msgid "Use table based fast divide (default at -O3)"
+msgstr ""
+
+#: config/nios2/nios2.opt:51
+msgid "All memory accesses use I/O load/store instructions"
+msgstr ""
+
+#: config/nios2/nios2.opt:55
+msgid "Volatile memory accesses use I/O load/store instructions"
+msgstr ""
+
+#: config/nios2/nios2.opt:59
+msgid "Volatile memory accesses do not use I/O load/store instructions"
+msgstr ""
+
+#: config/nios2/nios2.opt:63
+msgid "Enable/disable GP-relative addressing."
+msgstr ""
+
+#: config/nios2/nios2.opt:67
+msgid "Valid options for GP-relative addressing (for -mgpopt):"
+msgstr ""
+
+#: config/nios2/nios2.opt:86
+msgid "Equivalent to -mgpopt=local."
+msgstr ""
+
+#: config/nios2/nios2.opt:90
+msgid "Equivalent to -mgpopt=none."
+msgstr ""
+
+#: config/nios2/nios2.opt:94 config/c6x/c6x.opt:30 config/mep/mep.opt:82
+#: config/mips/mips.opt:134
+msgid "Use big-endian byte order"
+msgstr ""
+
+#: config/nios2/nios2.opt:98 config/c6x/c6x.opt:34 config/mep/mep.opt:86
+#: config/mips/mips.opt:138
+msgid "Use little-endian byte order"
+msgstr ""
+
+#: config/nios2/nios2.opt:102
+msgid "Floating point custom instruction configuration name"
+msgstr ""
+
+#: config/nios2/nios2.opt:106
+msgid "Do not use the ftruncds custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:110
+msgid "Integer id (N) of ftruncds custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:114
+msgid "Do not use the fextsd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:118
+msgid "Integer id (N) of fextsd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:122
+msgid "Do not use the fixdu custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:126
+msgid "Integer id (N) of fixdu custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:130
+msgid "Do not use the fixdi custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:134
+msgid "Integer id (N) of fixdi custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:138
+msgid "Do not use the fixsu custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:142
+msgid "Integer id (N) of fixsu custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:146
+msgid "Do not use the fixsi custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:150
+msgid "Integer id (N) of fixsi custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:154
+msgid "Do not use the floatud custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:158
+msgid "Integer id (N) of floatud custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:162
+msgid "Do not use the floatid custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:166
+msgid "Integer id (N) of floatid custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:170
+msgid "Do not use the floatus custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:174
+msgid "Integer id (N) of floatus custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:178
+msgid "Do not use the floatis custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:182
+msgid "Integer id (N) of floatis custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:186
+msgid "Do not use the fcmpned custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:190
+msgid "Integer id (N) of fcmpned custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:194
+msgid "Do not use the fcmpeqd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:198
+msgid "Integer id (N) of fcmpeqd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:202
+msgid "Do not use the fcmpged custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:206
+msgid "Integer id (N) of fcmpged custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:210
+msgid "Do not use the fcmpgtd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:214
+msgid "Integer id (N) of fcmpgtd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:218
+msgid "Do not use the fcmpled custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:222
+msgid "Integer id (N) of fcmpled custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:226
+msgid "Do not use the fcmpltd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:230
+msgid "Integer id (N) of fcmpltd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:234
+msgid "Do not use the flogd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:238
+msgid "Integer id (N) of flogd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:242
+msgid "Do not use the fexpd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:246
+msgid "Integer id (N) of fexpd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:250
+msgid "Do not use the fatand custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:254
+msgid "Integer id (N) of fatand custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:258
+msgid "Do not use the ftand custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:262
+msgid "Integer id (N) of ftand custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:266
+msgid "Do not use the fsind custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:270
+msgid "Integer id (N) of fsind custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:274
+msgid "Do not use the fcosd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:278
+msgid "Integer id (N) of fcosd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:282
+msgid "Do not use the fsqrtd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:286
+msgid "Integer id (N) of fsqrtd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:290
+msgid "Do not use the fabsd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:294
+msgid "Integer id (N) of fabsd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:298
+msgid "Do not use the fnegd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:302
+msgid "Integer id (N) of fnegd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:306
+msgid "Do not use the fmaxd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:310
+msgid "Integer id (N) of fmaxd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:314
+msgid "Do not use the fmind custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:318
+msgid "Integer id (N) of fmind custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:322
+msgid "Do not use the fdivd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:326
+msgid "Integer id (N) of fdivd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:330
+msgid "Do not use the fmuld custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:334
+msgid "Integer id (N) of fmuld custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:338
+msgid "Do not use the fsubd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:342
+msgid "Integer id (N) of fsubd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:346
+msgid "Do not use the faddd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:350
+msgid "Integer id (N) of faddd custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:354
+msgid "Do not use the fcmpnes custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:358
+msgid "Integer id (N) of fcmpnes custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:362
+msgid "Do not use the fcmpeqs custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:366
+msgid "Integer id (N) of fcmpeqs custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:370
+msgid "Do not use the fcmpges custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:374
+msgid "Integer id (N) of fcmpges custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:378
+msgid "Do not use the fcmpgts custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:382
+msgid "Integer id (N) of fcmpgts custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:386
+msgid "Do not use the fcmples custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:390
+msgid "Integer id (N) of fcmples custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:394
+msgid "Do not use the fcmplts custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:398
+msgid "Integer id (N) of fcmplts custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:402
+msgid "Do not use the flogs custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:406
+msgid "Integer id (N) of flogs custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:410
+msgid "Do not use the fexps custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:414
+msgid "Integer id (N) of fexps custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:418
+msgid "Do not use the fatans custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:422
+msgid "Integer id (N) of fatans custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:426
+msgid "Do not use the ftans custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:430
+msgid "Integer id (N) of ftans custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:434
+msgid "Do not use the fsins custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:438
+msgid "Integer id (N) of fsins custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:442
+msgid "Do not use the fcoss custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:446
+msgid "Integer id (N) of fcoss custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:450
+msgid "Do not use the fsqrts custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:454
+msgid "Integer id (N) of fsqrts custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:458
+msgid "Do not use the fabss custom instr"
+msgstr ""
+
+#: config/nios2/nios2.opt:462
+msgid "Integer id (N) of fabss custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:466
+msgid "Do not use the fnegs custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:470
+msgid "Integer id (N) of fnegs custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:474
+msgid "Do not use the fmaxs custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:478
+msgid "Integer id (N) of fmaxs custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:482
+msgid "Do not use the fmins custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:486
+msgid "Integer id (N) of fmins custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:490
+msgid "Do not use the fdivs custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:494
+msgid "Integer id (N) of fdivs custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:498
+msgid "Do not use the fmuls custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:502
+msgid "Integer id (N) of fmuls custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:506
+msgid "Do not use the fsubs custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:510
+msgid "Integer id (N) of fsubs custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:514
+msgid "Do not use the fadds custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:518
+msgid "Integer id (N) of fadds custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:522
+msgid "Do not use the frdy custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:526
+msgid "Integer id (N) of frdy custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:530
+msgid "Do not use the frdxhi custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:534
+msgid "Integer id (N) of frdxhi custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:538
+msgid "Do not use the frdxlo custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:542
+msgid "Integer id (N) of frdxlo custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:546
+msgid "Do not use the fwry custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:550
+msgid "Integer id (N) of fwry custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:554
+msgid "Do not use the fwrx custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:558
+msgid "Integer id (N) of fwrx custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:562
+msgid "Do not use the round custom instruction"
+msgstr ""
+
+#: config/nios2/nios2.opt:566
+msgid "Integer id (N) of round custom instruction"
+msgstr ""
+
+#: config/rx/rx.opt:29
+msgid "Store doubles in 64 bits."
+msgstr ""
+
+#: config/rx/rx.opt:33
+msgid "Stores doubles in 32 bits.  This is the default."
+msgstr ""
+
+#: config/rx/rx.opt:37
+msgid "Disable the use of RX FPU instructions.  "
+msgstr ""
+
+#: config/rx/rx.opt:44
+msgid "Enable the use of RX FPU instructions.  This is the default."
+msgstr ""
+
+#: config/rx/rx.opt:50
+msgid "Specify the target RX cpu type."
+msgstr ""
+
+#: config/rx/rx.opt:71
+msgid "Data is stored in big-endian format."
+msgstr ""
+
+#: config/rx/rx.opt:75
+msgid "Data is stored in little-endian format.  (Default)."
+msgstr ""
+
+#: config/rx/rx.opt:81
+msgid "Maximum size of global and static variables which can be placed into the small data area."
+msgstr ""
+
+#: config/rx/rx.opt:93
+msgid "Generate assembler output that is compatible with the Renesas AS100 assembler.  This may restrict some of the compiler's capabilities.  The default is to generate GAS compatible syntax."
+msgstr ""
+
+#: config/rx/rx.opt:99
+msgid "Enable linker relaxation."
+msgstr ""
+
+#: config/rx/rx.opt:105
+msgid "Maximum size in bytes of constant values allowed as operands."
+msgstr ""
+
+#: config/rx/rx.opt:111
+msgid "Specifies the number of registers to reserve for interrupt handlers."
+msgstr ""
+
+#: config/rx/rx.opt:117
+msgid "Specifies whether interrupt functions should save and restore the accumulator register."
+msgstr ""
+
+#: config/rx/rx.opt:123
+msgid "Enables Position-Independent-Data (PID) mode."
+msgstr ""
+
+#: config/rx/rx.opt:129
+msgid "Warn when multiple, different, fast interrupt handlers are in the compilation unit."
+msgstr ""
+
+#: config/rx/rx.opt:133
+msgid "Enable the use of the old, broken, ABI where all stacked function arguments are aligned to 32-bits."
+msgstr ""
+
+#: config/rx/rx.opt:137
+msgid "Enable the use the standard RX ABI where all stacked function arguments are naturally aligned.  This is the default."
+msgstr ""
+
+#: config/rx/rx.opt:141
+msgid "Enable the use of the LRA register allocator."
+msgstr ""
+
+#: config/visium/visium.opt:25
+msgid "Link with libc.a and libdebug.a"
+msgstr ""
+
+#: config/visium/visium.opt:29
+msgid "Link with libc.a and libsim.a"
+msgstr ""
+
+#: config/visium/visium.opt:33
+msgid "Use hardware FP (default)"
+msgstr ""
+
+#: config/visium/visium.opt:65
+msgid "Generate code for the supervisor mode (default)"
+msgstr ""
+
+#: config/visium/visium.opt:69
+msgid "Generate code for the user mode"
+msgstr ""
+
+#: config/visium/visium.opt:73
+msgid "Only retained for backward compatibility."
+msgstr ""
+
+#: config/fused-madd.opt:22
+msgid "%<-mfused-madd%> is deprecated; use %<-ffp-contract=%> instead"
+msgstr ""
+
+#: config/sol2.opt:32
+msgid "Clear hardware capabilities when linking"
+msgstr ""
+
+#: config/sol2.opt:36
+msgid "Pass -z text to linker"
+msgstr ""
+
+#: config/moxie/moxie.opt:31
+msgid "Enable MUL.X and UMUL.X instructions"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:40
+msgid "Use software emulation for floating point (default)"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:44
+msgid "Use hardware floating point instructions"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:48
+msgid "Use table lookup optimization for small signed integer divisions"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:52
+msgid "-mcpu=PROCESSOR\t\tUse features of and schedule code for given CPU"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:56
+msgid "Don't optimize block moves, use memcpy"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:68
+msgid "Use the soft multiply emulation (default)"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:72
+msgid "Use reorder instructions (swap and byte reversed load/store) (default)"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:76
+msgid "Use the software emulation for divides (default)"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:80
+msgid "Use the hardware barrel shifter instead of emulation"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:84
+msgid "Use pattern compare instructions"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:87
+#, c-format
+msgid "%qs is deprecated; use -fstack-check"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:88
+msgid "Check for stack overflow at runtime"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:92 config/iq2000/iq2000.opt:65
+msgid "Use GP relative sdata/sbss sections"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:95
+#, c-format
+msgid "%qs is deprecated; use -fno-zero-initialized-in-bss"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:96
+msgid "Clear the BSS to zero and place zero initialized in BSS"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:100
+msgid "Use multiply high instructions for high part of 32x32 multiply"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:104
+msgid "Use hardware floating point conversion instructions"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:108
+msgid "Use hardware floating point square root instruction"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:112
+msgid "Description for mxl-mode-executable"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:116
+msgid "Description for mxl-mode-xmdstub"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:120
+msgid "Description for mxl-mode-bootstrap"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:124
+msgid "Description for mxl-mode-novectors"
+msgstr ""
+
+#: config/vax/vax.opt:23 config/vax/vax.opt:27
+msgid "Target DFLOAT double precision code"
+msgstr ""
+
+#: config/vax/vax.opt:31 config/vax/vax.opt:35
+msgid "Generate GFLOAT double precision code"
+msgstr ""
+
+#: config/vax/vax.opt:39
+msgid "Generate code for GNU assembler (gas)"
+msgstr ""
+
+#: config/vax/vax.opt:43
+msgid "Generate code for UNIX assembler"
+msgstr ""
+
+#: config/vax/vax.opt:47
+msgid "Use VAXC structure conventions"
+msgstr ""
+
+#: config/vax/vax.opt:51
+msgid "Use new adddi3/subdi3 patterns"
+msgstr ""
+
+#: config/frv/frv.opt:30
+msgid "Use 4 media accumulators"
+msgstr ""
+
+#: config/frv/frv.opt:34
+msgid "Use 8 media accumulators"
+msgstr ""
+
+#: config/frv/frv.opt:38
+msgid "Enable label alignment optimizations"
+msgstr ""
+
+#: config/frv/frv.opt:42
+msgid "Dynamically allocate cc registers"
+msgstr ""
+
+#: config/frv/frv.opt:49
+msgid "Set the cost of branches"
+msgstr ""
+
+#: config/frv/frv.opt:53
+msgid "Enable conditional execution other than moves/scc"
+msgstr ""
+
+#: config/frv/frv.opt:57
+msgid "Change the maximum length of conditionally-executed sequences"
+msgstr ""
+
+#: config/frv/frv.opt:61
+msgid "Change the number of temporary registers that are available to conditionally-executed sequences"
+msgstr ""
+
+#: config/frv/frv.opt:65
+msgid "Enable conditional moves"
+msgstr ""
+
+#: config/frv/frv.opt:69
+msgid "Set the target CPU type"
+msgstr ""
+
+#: config/frv/frv.opt:73
+msgid "Known FR-V CPUs (for use with the -mcpu= option):"
+msgstr ""
+
+#: config/frv/frv.opt:122
+msgid "Use fp double instructions"
+msgstr ""
+
+#: config/frv/frv.opt:126
+msgid "Change the ABI to allow double word insns"
+msgstr ""
+
+#: config/frv/frv.opt:134
+msgid "Just use icc0/fcc0"
+msgstr ""
+
+#: config/frv/frv.opt:138
+msgid "Only use 32 FPRs"
+msgstr ""
+
+#: config/frv/frv.opt:142
+msgid "Use 64 FPRs"
+msgstr ""
+
+#: config/frv/frv.opt:146
+msgid "Only use 32 GPRs"
+msgstr ""
+
+#: config/frv/frv.opt:150
+msgid "Use 64 GPRs"
+msgstr ""
+
+#: config/frv/frv.opt:154
+msgid "Enable use of GPREL for read-only data in FDPIC"
+msgstr ""
+
+#: config/frv/frv.opt:166
+msgid "Enable PIC support for building libraries"
+msgstr ""
+
+#: config/frv/frv.opt:170
+msgid "Follow the EABI linkage requirements"
+msgstr ""
+
+#: config/frv/frv.opt:174
+msgid "Disallow direct calls to global functions"
+msgstr ""
+
+#: config/frv/frv.opt:178
+msgid "Use media instructions"
+msgstr ""
+
+#: config/frv/frv.opt:182
+msgid "Use multiply add/subtract instructions"
+msgstr ""
+
+#: config/frv/frv.opt:186
+msgid "Enable optimizing &&/|| in conditional execution"
+msgstr ""
+
+#: config/frv/frv.opt:190
+msgid "Enable nested conditional execution optimizations"
+msgstr ""
+
+#: config/frv/frv.opt:195
+msgid "Do not mark ABI switches in e_flags"
+msgstr ""
+
+#: config/frv/frv.opt:199
+msgid "Remove redundant membars"
+msgstr ""
+
+#: config/frv/frv.opt:203
+msgid "Pack VLIW instructions"
+msgstr ""
+
+#: config/frv/frv.opt:207
+msgid "Enable setting GPRs to the result of comparisons"
+msgstr ""
+
+#: config/frv/frv.opt:211
+msgid "Change the amount of scheduler lookahead"
+msgstr ""
+
+#: config/frv/frv.opt:219
+msgid "Assume a large TLS segment"
+msgstr ""
+
+#: config/frv/frv.opt:223
+msgid "Do not assume a large TLS segment"
+msgstr ""
+
+#: config/frv/frv.opt:228
+msgid "Cause gas to print tomcat statistics"
+msgstr ""
+
+#: config/frv/frv.opt:233
+msgid "Link with the library-pic libraries"
+msgstr ""
+
+#: config/frv/frv.opt:237
+msgid "Allow branches to be packed with other instructions"
+msgstr ""
+
+#: config/mn10300/mn10300.opt:30
+msgid "Target the AM33 processor"
+msgstr ""
+
+#: config/mn10300/mn10300.opt:34
+msgid "Target the AM33/2.0 processor"
+msgstr ""
+
+#: config/mn10300/mn10300.opt:38
+msgid "Target the AM34 processor"
+msgstr ""
+
+#: config/mn10300/mn10300.opt:46
+msgid "Work around hardware multiply bug"
+msgstr ""
+
+#: config/mn10300/mn10300.opt:55
+msgid "Enable linker relaxations"
+msgstr ""
+
+#: config/mn10300/mn10300.opt:59
+msgid "Return pointers in both a0 and d0"
+msgstr ""
+
+#: config/mn10300/mn10300.opt:63
+msgid "Allow gcc to generate LIW instructions"
+msgstr ""
+
+#: config/mn10300/mn10300.opt:67
+msgid "Allow gcc to generate the SETLB and Lcc instructions"
+msgstr ""
+
+#: config/nds32/nds32.opt:26
+msgid "Generate code in big-endian mode."
+msgstr ""
+
+#: config/nds32/nds32.opt:30
+msgid "Generate code in little-endian mode."
+msgstr ""
+
+#: config/nds32/nds32.opt:34
+msgid "Use reduced-set registers for register allocation."
+msgstr ""
+
+#: config/nds32/nds32.opt:38
+msgid "Use full-set registers for register allocation."
+msgstr ""
+
+#: config/nds32/nds32.opt:42
+msgid "Generate conditional move instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:46
+msgid "Generate performance extension instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:50
+msgid "Generate v3 push25/pop25 instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Generate 16-bit instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify the size of each interrupt vector, which must be 4 or 16."
+msgstr ""
+
+#: config/nds32/nds32.opt:62
+msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
+msgstr ""
+
+#: config/nds32/nds32.opt:66
+msgid "Specify the name of the target architecture."
+msgstr ""
+
+#: config/nds32/nds32.opt:70
+msgid "Known arch types (for use with the -march= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:83
+msgid "Specify the address generation strategy for code model."
+msgstr ""
+
+#: config/nds32/nds32.opt:87
+msgid "Known cmodel types (for use with the -mcmodel= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:100
+msgid "Enable constructor/destructor feature."
+msgstr ""
+
+#: config/nds32/nds32.opt:104
+msgid "Guide linker to relax instructions."
+msgstr ""
+
+#: config/iq2000/iq2000.opt:31
+msgid "Specify CPU for code generation purposes"
+msgstr ""
+
+#: config/iq2000/iq2000.opt:47
+msgid "Specify CPU for scheduling purposes"
+msgstr ""
+
+#: config/iq2000/iq2000.opt:51
+msgid "Known IQ2000 CPUs (for use with the -mcpu= option):"
+msgstr ""
+
+#: config/iq2000/iq2000.opt:61 config/mips/mips.opt:142
+msgid "Use ROM instead of RAM"
+msgstr ""
+
+#: config/iq2000/iq2000.opt:70
+msgid "No default crt0.o"
+msgstr ""
+
+#: config/iq2000/iq2000.opt:74 config/mips/mips.opt:397
+msgid "Put uninitialized constants in ROM (needs -membedded-data)"
+msgstr ""
+
+#: config/c6x/c6x-tables.opt:24
+msgid "Known C6X ISAs (for use with the -march= option):"
+msgstr ""
+
+#: config/c6x/c6x.opt:46
+msgid "Valid arguments for the -msdata= option"
+msgstr ""
+
+#: config/c6x/c6x.opt:59
+msgid "Compile for the DSBT shared library ABI"
+msgstr ""
+
+#: config/cris/linux.opt:27
+msgid "Together with -fpic and -fPIC, do not use GOTPLT references"
+msgstr ""
+
+#: config/cris/cris.opt:45
+msgid "Work around bug in multiplication instruction"
+msgstr ""
+
+#: config/cris/cris.opt:51
+msgid "Compile for ETRAX 4 (CRIS v3)"
+msgstr ""
+
+#: config/cris/cris.opt:56
+msgid "Compile for ETRAX 100 (CRIS v8)"
+msgstr ""
+
+#: config/cris/cris.opt:64
+msgid "Emit verbose debug information in assembly code"
+msgstr ""
+
+#: config/cris/cris.opt:71
+msgid "Do not use condition codes from normal instructions"
+msgstr ""
+
+#: config/cris/cris.opt:80
+msgid "Do not emit addressing modes with side-effect assignment"
+msgstr ""
+
+#: config/cris/cris.opt:89
+msgid "Do not tune stack alignment"
+msgstr ""
+
+#: config/cris/cris.opt:98
+msgid "Do not tune writable data alignment"
+msgstr ""
+
+#: config/cris/cris.opt:107
+msgid "Do not tune code and read-only data alignment"
+msgstr ""
+
+#: config/cris/cris.opt:116
+msgid "Align code and data to 32 bits"
+msgstr ""
+
+#: config/cris/cris.opt:133
+msgid "Don't align items in code or data"
+msgstr ""
+
+#: config/cris/cris.opt:142
+msgid "Do not emit function prologue or epilogue"
+msgstr ""
+
+#: config/cris/cris.opt:149
+msgid "Use the most feature-enabling options allowed by other options"
+msgstr ""
+
+#: config/cris/cris.opt:158
+msgid "Override -mbest-lib-options"
+msgstr ""
+
+#: config/cris/cris.opt:165
+msgid "-march=ARCH\tGenerate code for the specified chip or CPU version"
+msgstr ""
+
+#: config/cris/cris.opt:169
+msgid "-mtune=ARCH\tTune alignment for the specified chip or CPU version"
+msgstr ""
+
+#: config/cris/cris.opt:173
+msgid "-mmax-stackframe=SIZE\tWarn when a stackframe is larger than the specified size"
+msgstr ""
+
+#: config/cris/cris.opt:180
+msgid "Emit traps as \"break 8\", default for CRIS v3 and up.  If disabled, calls to abort() are used."
+msgstr ""
+
+#: config/cris/cris.opt:184
+msgid "Emit checks causing \"break 8\" instructions to execute when applying atomic builtins on misaligned memory"
+msgstr ""
+
+#: config/cris/cris.opt:188
+msgid "Handle atomic builtins that may be applied to unaligned data by calling library functions. Overrides -mtrap-unaligned-atomic."
+msgstr ""
+
+#: config/sh/superh.opt:6
+msgid "Board name [and memory region]."
+msgstr ""
+
+#: config/sh/superh.opt:10
+msgid "Runtime name."
+msgstr ""
+
+#: config/sh/sh.opt:48
+msgid "Generate SH1 code"
+msgstr ""
+
+#: config/sh/sh.opt:52
+msgid "Generate SH2 code"
+msgstr ""
+
+#: config/sh/sh.opt:56
+msgid "Generate default double-precision SH2a-FPU code"
+msgstr ""
+
+#: config/sh/sh.opt:60
+msgid "Generate SH2a FPU-less code"
+msgstr ""
+
+#: config/sh/sh.opt:64
+msgid "Generate default single-precision SH2a-FPU code"
+msgstr ""
+
+#: config/sh/sh.opt:68
+msgid "Generate only single-precision SH2a-FPU code"
+msgstr ""
+
+#: config/sh/sh.opt:72
+msgid "Generate SH2e code"
+msgstr ""
+
+#: config/sh/sh.opt:76
+msgid "Generate SH3 code"
+msgstr ""
+
+#: config/sh/sh.opt:80
+msgid "Generate SH3e code"
+msgstr ""
+
+#: config/sh/sh.opt:84
+msgid "Generate SH4 code"
+msgstr ""
+
+#: config/sh/sh.opt:88
+msgid "Generate SH4-100 code"
+msgstr ""
+
+#: config/sh/sh.opt:92
+msgid "Generate SH4-200 code"
+msgstr ""
+
+#: config/sh/sh.opt:98
+msgid "Generate SH4-300 code"
+msgstr ""
+
+#: config/sh/sh.opt:102
+msgid "Generate SH4 FPU-less code"
+msgstr ""
+
+#: config/sh/sh.opt:106
+msgid "Generate SH4-100 FPU-less code"
+msgstr ""
+
+#: config/sh/sh.opt:110
+msgid "Generate SH4-200 FPU-less code"
+msgstr ""
+
+#: config/sh/sh.opt:114
+msgid "Generate SH4-300 FPU-less code"
+msgstr ""
+
+#: config/sh/sh.opt:118
+msgid "Generate code for SH4 340 series (MMU/FPU-less)"
+msgstr ""
+
+#: config/sh/sh.opt:123
+msgid "Generate code for SH4 400 series (MMU/FPU-less)"
+msgstr ""
+
+#: config/sh/sh.opt:128
+msgid "Generate code for SH4 500 series (FPU-less)."
+msgstr ""
+
+#: config/sh/sh.opt:133
+msgid "Generate default single-precision SH4 code"
+msgstr ""
+
+#: config/sh/sh.opt:137
+msgid "Generate default single-precision SH4-100 code"
+msgstr ""
+
+#: config/sh/sh.opt:141
+msgid "Generate default single-precision SH4-200 code"
+msgstr ""
+
+#: config/sh/sh.opt:145
+msgid "Generate default single-precision SH4-300 code"
+msgstr ""
+
+#: config/sh/sh.opt:149
+msgid "Generate only single-precision SH4 code"
+msgstr ""
+
+#: config/sh/sh.opt:153
+msgid "Generate only single-precision SH4-100 code"
+msgstr ""
+
+#: config/sh/sh.opt:157
+msgid "Generate only single-precision SH4-200 code"
+msgstr ""
+
+#: config/sh/sh.opt:161
+msgid "Generate only single-precision SH4-300 code"
+msgstr ""
+
+#: config/sh/sh.opt:165
+msgid "Generate SH4a code"
+msgstr ""
+
+#: config/sh/sh.opt:169
+msgid "Generate SH4a FPU-less code"
+msgstr ""
+
+#: config/sh/sh.opt:173
+msgid "Generate default single-precision SH4a code"
+msgstr ""
+
+#: config/sh/sh.opt:177
+msgid "Generate only single-precision SH4a code"
+msgstr ""
+
+#: config/sh/sh.opt:181
+msgid "Generate SH4al-dsp code"
+msgstr ""
+
+#: config/sh/sh.opt:185
+msgid "Generate 32-bit SHmedia code"
+msgstr ""
+
+#: config/sh/sh.opt:189
+msgid "Generate 32-bit FPU-less SHmedia code"
+msgstr ""
+
+#: config/sh/sh.opt:193
+msgid "Generate 64-bit SHmedia code"
+msgstr ""
+
+#: config/sh/sh.opt:197
+msgid "Generate 64-bit FPU-less SHmedia code"
+msgstr ""
+
+#: config/sh/sh.opt:201
+msgid "Generate SHcompact code"
+msgstr ""
+
+#: config/sh/sh.opt:205
+msgid "Generate FPU-less SHcompact code"
+msgstr ""
+
+#: config/sh/sh.opt:217
+msgid "Generate code in big endian mode"
+msgstr ""
+
+#: config/sh/sh.opt:221
+msgid "Generate 32-bit offsets in switch tables"
+msgstr ""
+
+#: config/sh/sh.opt:225
+msgid "Generate bit instructions"
+msgstr ""
+
+#: config/sh/sh.opt:229
+msgid "Cost to assume for a branch insn"
+msgstr ""
+
+#: config/sh/sh.opt:233
+msgid "Assume that zero displacement conditional branches are fast"
+msgstr ""
+
+#: config/sh/sh.opt:236 config/sh/sh.opt:240
+#, c-format
+msgid "%qs is deprecated and has no effect"
+msgstr ""
+
+#: config/sh/sh.opt:237
+msgid "Enable cbranchdi4 pattern"
+msgstr ""
+
+#: config/sh/sh.opt:241
+msgid "Emit cmpeqdi_t pattern even when -mcbranchdi is in effect."
+msgstr ""
+
+#: config/sh/sh.opt:245
+msgid "Force the usage of delay slots for conditional branches."
+msgstr ""
+
+#: config/sh/sh.opt:249
+msgid "Enable SH5 cut2 workaround"
+msgstr ""
+
+#: config/sh/sh.opt:253
+msgid "Align doubles at 64-bit boundaries"
+msgstr ""
+
+#: config/sh/sh.opt:257
+msgid "Division strategy, one of: call, call2, fp, inv, inv:minlat, inv20u, inv20l, inv:call, inv:call2, inv:fp, call-div1, call-fp, call-table"
+msgstr ""
+
+#: config/sh/sh.opt:261
+msgid "Specify name for 32 bit signed division function"
+msgstr ""
+
+#: config/sh/sh.opt:265
+msgid "Enable the use of 64-bit floating point registers in fmov instructions.  See -mdalign if 64-bit alignment is required."
+msgstr ""
+
+#: config/sh/sh.opt:273
+msgid "Cost to assume for gettr insn"
+msgstr ""
+
+#: config/sh/sh.opt:277 config/sh/sh.opt:327
+msgid "Follow Renesas (formerly Hitachi) / SuperH calling conventions"
+msgstr ""
+
+#: config/sh/sh.opt:281
+msgid "Increase the IEEE compliance for floating-point comparisons"
+msgstr ""
+
+#: config/sh/sh.opt:285
+msgid "Enable the use of the indexed addressing mode for SHmedia32/SHcompact"
+msgstr ""
+
+#: config/sh/sh.opt:289
+msgid "inline code to invalidate instruction cache entries after setting up nested function trampolines"
+msgstr ""
+
+#: config/sh/sh.opt:293
+msgid "Assume symbols might be invalid"
+msgstr ""
+
+#: config/sh/sh.opt:297 config/arc/arc.opt:183
+msgid "Annotate assembler instructions with estimated addresses"
+msgstr ""
+
+#: config/sh/sh.opt:301
+msgid "Generate code in little endian mode"
+msgstr ""
+
+#: config/sh/sh.opt:305
+msgid "Mark MAC register as call-clobbered"
+msgstr ""
+
+#: config/sh/sh.opt:311
+msgid "Make structs a multiple of 4 bytes (warning: ABI altered)"
+msgstr ""
+
+#: config/sh/sh.opt:315
+msgid "Emit function-calls using global offset table when generating PIC"
+msgstr ""
+
+#: config/sh/sh.opt:319
+msgid "Assume pt* instructions won't trap"
+msgstr ""
+
+#: config/sh/sh.opt:323
+msgid "Shorten address references during linking"
+msgstr ""
+
+#: config/sh/sh.opt:331
+msgid "Deprecated.  Use -matomic= instead to select the atomic model"
+msgstr ""
+
+#: config/sh/sh.opt:335
+msgid "Specify the model for atomic operations"
+msgstr ""
+
+#: config/sh/sh.opt:339
+msgid "Use tas.b instruction for __atomic_test_and_set"
+msgstr ""
+
+#: config/sh/sh.opt:343
+msgid "Deprecated.  Use -Os instead"
+msgstr ""
+
+#: config/sh/sh.opt:347
+msgid "Cost to assume for a multiply insn"
+msgstr ""
+
+#: config/sh/sh.opt:351
+msgid "Don't generate privileged-mode only code; implies -mno-inline-ic_invalidate if the inline code would not work in user mode."
+msgstr ""
+
+#: config/sh/sh.opt:357
+msgid "Pretend a branch-around-a-move is a conditional move."
+msgstr ""
+
+#: config/sh/sh.opt:361
+msgid "Enable the use of the fsca instruction"
+msgstr ""
+
+#: config/sh/sh.opt:365
+msgid "Enable the use of the fsrra instruction"
+msgstr ""
+
+#: config/sh/sh.opt:369
+msgid "Use LRA instead of reload (transitional)"
+msgstr ""
+
+#: config/fr30/fr30.opt:23
+msgid "Assume small address space"
+msgstr ""
+
+#: config/mep/mep.opt:23
+msgid "Enable absolute difference instructions"
+msgstr ""
+
+#: config/mep/mep.opt:27
+msgid "Enable all optional instructions"
+msgstr ""
+
+#: config/mep/mep.opt:31
+msgid "Enable average instructions"
+msgstr ""
+
+#: config/mep/mep.opt:35
+msgid "Variables this size and smaller go in the based section. (default 0)"
+msgstr ""
+
+#: config/mep/mep.opt:39
+msgid "Enable bit manipulation instructions"
+msgstr ""
+
+#: config/mep/mep.opt:43
+msgid "Section to put all const variables in (tiny, near, far) (no default)"
+msgstr ""
+
+#: config/mep/mep.opt:47
+msgid "Enable clip instructions"
+msgstr ""
+
+#: config/mep/mep.opt:51
+msgid "Configuration name"
+msgstr ""
+
+#: config/mep/mep.opt:55
+msgid "Enable MeP Coprocessor"
+msgstr ""
+
+#: config/mep/mep.opt:59
+msgid "Enable MeP Coprocessor with 32-bit registers"
+msgstr ""
+
+#: config/mep/mep.opt:63
+msgid "Enable MeP Coprocessor with 64-bit registers"
+msgstr ""
+
+#: config/mep/mep.opt:67
+msgid "Enable IVC2 scheduling"
+msgstr ""
+
+#: config/mep/mep.opt:71
+msgid "Const variables default to the near section"
+msgstr ""
+
+#: config/mep/mep.opt:78
+msgid "Enable 32-bit divide instructions"
+msgstr ""
+
+#: config/mep/mep.opt:93
+msgid "__io vars are volatile by default"
+msgstr ""
+
+#: config/mep/mep.opt:97
+msgid "All variables default to the far section"
+msgstr ""
+
+#: config/mep/mep.opt:101
+msgid "Enable leading zero instructions"
+msgstr ""
+
+#: config/mep/mep.opt:108
+msgid "All variables default to the near section"
+msgstr ""
+
+#: config/mep/mep.opt:112
+msgid "Enable min/max instructions"
+msgstr ""
+
+#: config/mep/mep.opt:116
+msgid "Enable 32-bit multiply instructions"
+msgstr ""
+
+#: config/mep/mep.opt:120
+msgid "Disable all optional instructions"
+msgstr ""
+
+#: config/mep/mep.opt:127
+msgid "Allow gcc to use the repeat/erepeat instructions"
+msgstr ""
+
+#: config/mep/mep.opt:131
+msgid "All variables default to the tiny section"
+msgstr ""
+
+#: config/mep/mep.opt:135
+msgid "Enable saturation instructions"
+msgstr ""
+
+#: config/mep/mep.opt:139
+msgid "Use sdram version of runtime"
+msgstr ""
+
+#: config/mep/mep.opt:147
+msgid "Use simulator runtime without vectors"
+msgstr ""
+
+#: config/mep/mep.opt:151
+msgid "All functions default to the far section"
+msgstr ""
+
+#: config/mep/mep.opt:155
+msgid "Variables this size and smaller go in the tiny section. (default 4)"
+msgstr ""
+
+#: config/mips/mips.opt:32
+msgid "-mabi=ABI\tGenerate code that conforms to the given ABI"
+msgstr ""
+
+#: config/mips/mips.opt:36
+msgid "Known MIPS ABIs (for use with the -mabi= option):"
+msgstr ""
+
+#: config/mips/mips.opt:55
+msgid "Generate code that can be used in SVR4-style dynamic objects"
+msgstr ""
+
+#: config/mips/mips.opt:59
+msgid "Use PMC-style 'mad' instructions"
+msgstr ""
+
+#: config/mips/mips.opt:63
+msgid "Use integer madd/msub instructions"
+msgstr ""
+
+#: config/mips/mips.opt:67
+msgid "-march=ISA\tGenerate code for the given ISA"
+msgstr ""
+
+#: config/mips/mips.opt:71
+msgid "-mbranch-cost=COST\tSet the cost of branches to roughly COST instructions"
+msgstr ""
+
+#: config/mips/mips.opt:75
+msgid "Use Branch Likely instructions, overriding the architecture default"
+msgstr ""
+
+#: config/mips/mips.opt:79
+msgid "Switch on/off MIPS16 ASE on alternating functions for compiler testing"
+msgstr ""
+
+#: config/mips/mips.opt:83
+msgid "Trap on integer divide by zero"
+msgstr ""
+
+#: config/mips/mips.opt:87
+msgid "-mcode-readable=SETTING\tSpecify when instructions are allowed to access code"
+msgstr ""
+
+#: config/mips/mips.opt:91
+msgid "Valid arguments to -mcode-readable=:"
+msgstr ""
+
+#: config/mips/mips.opt:104
+msgid "Use branch-and-break sequences to check for integer divide by zero"
+msgstr ""
+
+#: config/mips/mips.opt:108
+msgid "Use trap instructions to check for integer divide by zero"
+msgstr ""
+
+#: config/mips/mips.opt:112
+msgid "Allow the use of MDMX instructions"
+msgstr ""
+
+#: config/mips/mips.opt:116
+msgid "Allow hardware floating-point instructions to cover both 32-bit and 64-bit operations"
+msgstr ""
+
+#: config/mips/mips.opt:120
+msgid "Use MIPS-DSP instructions"
+msgstr ""
+
+#: config/mips/mips.opt:124
+msgid "Use MIPS-DSP REV 2 instructions"
+msgstr ""
+
+#: config/mips/mips.opt:146
+msgid "Use Enhanced Virtual Addressing instructions"
+msgstr ""
+
+#: config/mips/mips.opt:150
+msgid "Use NewABI-style %reloc() assembly operators"
+msgstr ""
+
+#: config/mips/mips.opt:154
+msgid "Use -G for data that is not defined by the current object"
+msgstr ""
+
+#: config/mips/mips.opt:158
+msgid "Work around certain 24K errata"
+msgstr ""
+
+#: config/mips/mips.opt:162
+msgid "Work around certain R4000 errata"
+msgstr ""
+
+#: config/mips/mips.opt:166
+msgid "Work around certain R4400 errata"
+msgstr ""
+
+#: config/mips/mips.opt:170
+msgid "Work around certain RM7000 errata"
+msgstr ""
+
+#: config/mips/mips.opt:174
+msgid "Work around certain R10000 errata"
+msgstr ""
+
+#: config/mips/mips.opt:178
+msgid "Work around errata for early SB-1 revision 2 cores"
+msgstr ""
+
+#: config/mips/mips.opt:182
+msgid "Work around certain VR4120 errata"
+msgstr ""
+
+#: config/mips/mips.opt:186
+msgid "Work around VR4130 mflo/mfhi errata"
+msgstr ""
+
+#: config/mips/mips.opt:190
+msgid "Work around an early 4300 hardware bug"
+msgstr ""
+
+#: config/mips/mips.opt:194
+msgid "FP exceptions are enabled"
+msgstr ""
+
+#: config/mips/mips.opt:198
+msgid "Use 32-bit floating-point registers"
+msgstr ""
+
+#: config/mips/mips.opt:202
+msgid "Conform to the o32 FPXX ABI"
+msgstr ""
+
+#: config/mips/mips.opt:206
+msgid "Use 64-bit floating-point registers"
+msgstr ""
+
+#: config/mips/mips.opt:210
+msgid "-mflush-func=FUNC\tUse FUNC to flush the cache before calling stack trampolines"
+msgstr ""
+
+#: config/mips/mips.opt:214
+msgid "Generate floating-point multiply-add instructions"
+msgstr ""
+
+#: config/mips/mips.opt:218
+msgid "-mabs=MODE\tSelect the IEEE 754 ABS/NEG instruction execution mode"
+msgstr ""
+
+#: config/mips/mips.opt:222
+msgid "-mnan=ENCODING\tSelect the IEEE 754 NaN data encoding"
+msgstr ""
+
+#: config/mips/mips.opt:226
+msgid "Known MIPS IEEE 754 settings (for use with the -mabs= and -mnan= options):"
+msgstr ""
+
+#: config/mips/mips.opt:236
+msgid "Use 32-bit general registers"
+msgstr ""
+
+#: config/mips/mips.opt:240
+msgid "Use 64-bit general registers"
+msgstr ""
+
+#: config/mips/mips.opt:244
+msgid "Use GP-relative addressing to access small data"
+msgstr ""
+
+#: config/mips/mips.opt:248
+msgid "When generating -mabicalls code, allow executables to use PLTs and copy relocations"
+msgstr ""
+
+#: config/mips/mips.opt:252
+msgid "Allow the use of hardware floating-point ABI and instructions"
+msgstr ""
+
+#: config/mips/mips.opt:256
+msgid "Generate code that is link-compatible with MIPS16 and microMIPS code."
+msgstr ""
+
+#: config/mips/mips.opt:260
+msgid "An alias for minterlink-compressed provided for backward-compatibility."
+msgstr ""
+
+#: config/mips/mips.opt:264
+msgid "-mipsN\tGenerate code for ISA level N"
+msgstr ""
+
+#: config/mips/mips.opt:268
+msgid "Generate MIPS16 code"
+msgstr ""
+
+#: config/mips/mips.opt:272
+msgid "Use MIPS-3D instructions"
+msgstr ""
+
+#: config/mips/mips.opt:276
+msgid "Use ll, sc and sync instructions"
+msgstr ""
+
+#: config/mips/mips.opt:280
+msgid "Use -G for object-local data"
+msgstr ""
+
+#: config/mips/mips.opt:284
+msgid "Use indirect calls"
+msgstr ""
+
+#: config/mips/mips.opt:288
+msgid "Use a 32-bit long type"
+msgstr ""
+
+#: config/mips/mips.opt:292
+msgid "Use a 64-bit long type"
+msgstr ""
+
+#: config/mips/mips.opt:296
+msgid "Pass the address of the ra save location to _mcount in $12"
+msgstr ""
+
+#: config/mips/mips.opt:300
+msgid "Don't optimize block moves"
+msgstr ""
+
+#: config/mips/mips.opt:304
+msgid "Use microMIPS instructions"
+msgstr ""
+
+#: config/mips/mips.opt:308
+msgid "Allow the use of MT instructions"
+msgstr ""
+
+#: config/mips/mips.opt:312
+msgid "Prevent the use of all floating-point operations"
+msgstr ""
+
+#: config/mips/mips.opt:316
+msgid "Use MCU instructions"
+msgstr ""
+
+#: config/mips/mips.opt:320
+msgid "Do not use a cache-flushing function before calling stack trampolines"
+msgstr ""
+
+#: config/mips/mips.opt:324
+msgid "Do not use MDMX instructions"
+msgstr ""
+
+#: config/mips/mips.opt:328
+msgid "Generate normal-mode code"
+msgstr ""
+
+#: config/mips/mips.opt:332
+msgid "Do not use MIPS-3D instructions"
+msgstr ""
+
+#: config/mips/mips.opt:336
+msgid "Use paired-single floating-point instructions"
+msgstr ""
+
+#: config/mips/mips.opt:340
+msgid "-mr10k-cache-barrier=SETTING\tSpecify when r10k cache barriers should be inserted"
+msgstr ""
+
+#: config/mips/mips.opt:344
+msgid "Valid arguments to -mr10k-cache-barrier=:"
+msgstr ""
+
+#: config/mips/mips.opt:357
+msgid "Try to allow the linker to turn PIC calls into direct calls"
+msgstr ""
+
+#: config/mips/mips.opt:361
+msgid "When generating -mabicalls code, make the code suitable for use in shared libraries"
+msgstr ""
+
+#: config/mips/mips.opt:365
+msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
+msgstr ""
+
+#: config/mips/mips.opt:369
+msgid "Use SmartMIPS instructions"
+msgstr ""
+
+#: config/mips/mips.opt:373
+msgid "Prevent the use of all hardware floating-point instructions"
+msgstr ""
+
+#: config/mips/mips.opt:377
+msgid "Optimize lui/addiu address loads"
+msgstr ""
+
+#: config/mips/mips.opt:381
+msgid "Assume all symbols have 32-bit values"
+msgstr ""
+
+#: config/mips/mips.opt:385
+msgid "Use synci instruction to invalidate i-cache"
+msgstr ""
+
+#: config/mips/mips.opt:393
+msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR"
+msgstr ""
+
+#: config/mips/mips.opt:401
+msgid "Use Virtualization Application Specific instructions"
+msgstr ""
+
+#: config/mips/mips.opt:405
+msgid "Use eXtended Physical Address (XPA) instructions"
+msgstr ""
+
+#: config/mips/mips.opt:409
+msgid "Perform VR4130-specific alignment optimizations"
+msgstr ""
+
+#: config/mips/mips.opt:413
+msgid "Lift restrictions on GOT size"
+msgstr ""
+
+#: config/mips/mips.opt:417
+msgid "Enable use of odd-numbered single-precision registers"
+msgstr ""
+
+#: config/mips/mips-tables.opt:24
+msgid "Known MIPS CPUs (for use with the -march= and -mtune= options):"
+msgstr ""
+
+#: config/mips/mips-tables.opt:28
+msgid "Known MIPS ISA levels (for use with the -mips option):"
+msgstr ""
+
+#: config/tilegx/tilegx.opt:30
+msgid "Known TILE-Gx CPUs (for use with the -mcpu= option):"
+msgstr ""
+
+#: config/tilegx/tilegx.opt:37
+msgid "Compile with 32 bit longs and pointers."
+msgstr ""
+
+#: config/tilegx/tilegx.opt:41
+msgid "Compile with 64 bit longs and pointers."
+msgstr ""
+
+#: config/tilegx/tilegx.opt:45
+msgid "Use big-endian byte order."
+msgstr ""
+
+#: config/tilegx/tilegx.opt:49
+msgid "Use little-endian byte order."
+msgstr ""
+
+#: config/tilegx/tilegx.opt:53
+msgid "Use given TILE-Gx code model"
+msgstr ""
+
+#: config/arc/arc.opt:26
+msgid "Compile code for big endian mode"
+msgstr ""
+
+#: config/arc/arc.opt:30
+msgid "Compile code for little endian mode.  This is the default"
+msgstr ""
+
+#: config/arc/arc.opt:34
+msgid "Disable ARCompact specific pass to generate conditional execution instructions"
+msgstr ""
+
+#: config/arc/arc.opt:38
+msgid "Generate ARCompact 32-bit code for ARCtangent-A5 processor"
+msgstr ""
+
+#: config/arc/arc.opt:42
+msgid "Generate ARCompact 32-bit code for ARC600 processor"
+msgstr ""
+
+#: config/arc/arc.opt:46
+msgid "Same as -mA6"
+msgstr ""
+
+#: config/arc/arc.opt:50
+msgid "Generate ARCompact 32-bit code for ARC601 processor"
+msgstr ""
+
+#: config/arc/arc.opt:54
+msgid "Generate ARCompact 32-bit code for ARC700 processor"
+msgstr ""
+
+#: config/arc/arc.opt:58
+msgid "Same as -mA7"
+msgstr ""
+
+#: config/arc/arc.opt:62
+msgid "Tweak register allocation to help 16-bit instruction generation"
+msgstr ""
+
+#: config/arc/arc.opt:72
+msgid "Use ordinarily cached memory accesses for volatile references"
+msgstr ""
+
+#: config/arc/arc.opt:76
+msgid "Enable cache bypass for volatile references"
+msgstr ""
+
+#: config/arc/arc.opt:80
+msgid "Generate instructions supported by barrel shifter"
+msgstr ""
+
+#: config/arc/arc.opt:84
+msgid "Generate norm instruction"
+msgstr ""
+
+#: config/arc/arc.opt:88
+msgid "Generate swap instruction"
+msgstr ""
+
+#: config/arc/arc.opt:92
+msgid "Generate mul64 and mulu64 instructions"
+msgstr ""
+
+#: config/arc/arc.opt:96
+msgid "Do not generate mpy instructions for ARC700"
+msgstr ""
+
+#: config/arc/arc.opt:100
+msgid "Generate Extended arithmetic instructions.  Currently only divaw, adds, subs and sat16 are supported"
+msgstr ""
+
+#: config/arc/arc.opt:104
+msgid "Dummy flag. This is the default unless FPX switches are provided explicitly"
+msgstr ""
+
+#: config/arc/arc.opt:108
+msgid "Generate call insns as register indirect calls"
+msgstr ""
+
+#: config/arc/arc.opt:112
+msgid "Do no generate BRcc instructions in arc_reorg."
+msgstr ""
+
+#: config/arc/arc.opt:116
+msgid "Generate sdata references.  This is the default, unless you compile for PIC."
+msgstr ""
+
+#: config/arc/arc.opt:120
+msgid "Do not generate millicode thunks (needed only with -Os)"
+msgstr ""
+
+#: config/arc/arc.opt:124 config/arc/arc.opt:128
+msgid "FPX: Generate Single Precision FPX (compact) instructions."
+msgstr ""
+
+#: config/arc/arc.opt:132
+msgid "FPX: Generate Single Precision FPX (fast) instructions."
+msgstr ""
+
+#: config/arc/arc.opt:136
+msgid "FPX: Enable Argonaut ARC CPU Double Precision Floating Point extensions."
+msgstr ""
+
+#: config/arc/arc.opt:140 config/arc/arc.opt:144
+msgid "FPX: Generate Double Precision FPX (compact) instructions."
+msgstr ""
+
+#: config/arc/arc.opt:148
+msgid "FPX: Generate Double Precision FPX (fast) instructions."
+msgstr ""
+
+#: config/arc/arc.opt:152
+msgid "Disable LR and SR instructions from using FPX extension aux registers."
+msgstr ""
+
+#: config/arc/arc.opt:156
+msgid "Enable generation of ARC SIMD instructions via target-specific builtins."
+msgstr ""
+
+#: config/arc/arc.opt:160
+msgid "-mcpu=CPU\tCompile code for ARC variant CPU"
+msgstr ""
+
+#: config/arc/arc.opt:179
+msgid "size optimization level: 0:none 1:opportunistic 2: regalloc 3:drop align, -Os"
+msgstr ""
+
+#: config/arc/arc.opt:187
+msgid "Cost to assume for a multiply instruction, with 4 being equal to a normal insn."
+msgstr ""
+
+#: config/arc/arc.opt:191
+msgid "Tune for ARC600 cpu."
+msgstr ""
+
+#: config/arc/arc.opt:195
+msgid "Tune for ARC601 cpu."
+msgstr ""
+
+#: config/arc/arc.opt:199
+msgid "Tune for ARC700 R4.2 Cpu with standard multiplier block."
+msgstr ""
+
+#: config/arc/arc.opt:203 config/arc/arc.opt:207 config/arc/arc.opt:211
+msgid "Tune for ARC700 R4.2 Cpu with XMAC block."
+msgstr ""
+
+#: config/arc/arc.opt:215
+msgid "Enable the use of indexed loads"
+msgstr ""
+
+#: config/arc/arc.opt:219
+msgid "Enable the use of pre/post modify with register displacement."
+msgstr ""
+
+#: config/arc/arc.opt:223
+msgid "Generate 32x16 multiply and mac instructions"
+msgstr ""
+
+#: config/arc/arc.opt:229
+msgid "Set probability threshold for unaligning branches"
+msgstr ""
+
+#: config/arc/arc.opt:233
+msgid "Don't use less than 25 bit addressing range for calls."
+msgstr ""
+
+#: config/arc/arc.opt:237
+msgid "Explain what alignment considerations lead to the decision to make an insn short or long."
+msgstr ""
+
+#: config/arc/arc.opt:241
+msgid "Do alignment optimizations for call instructions."
+msgstr ""
+
+#: config/arc/arc.opt:245
+msgid "Enable Rcq constraint handling - most short code generation depends on this."
+msgstr ""
+
+#: config/arc/arc.opt:249
+msgid "Enable Rcw constraint handling - ccfsm condexec mostly depends on this."
+msgstr ""
+
+#: config/arc/arc.opt:253
+msgid "Enable pre-reload use of cbranchsi pattern"
+msgstr ""
+
+#: config/arc/arc.opt:257
+msgid "Enable bbit peephole2"
+msgstr ""
+
+#: config/arc/arc.opt:261
+msgid "Use pc-relative switch case tables - this enables case table shortening."
+msgstr ""
+
+#: config/arc/arc.opt:265
+msgid "Enable compact casesi pattern"
+msgstr ""
+
+#: config/arc/arc.opt:269
+msgid "Enable 'q' instruction alternatives."
+msgstr ""
+
+#: config/arc/arc.opt:273
+msgid "Expand adddi3 and subdi3 at rtl generation time into add.f / adc etc."
+msgstr ""
+
+#: config/arc/arc.opt:280
+msgid "Enable variable polynomial CRC extension"
+msgstr ""
+
+#: config/arc/arc.opt:284
+msgid "Enable DSP 3.1 Pack A extensions"
+msgstr ""
+
+#: config/arc/arc.opt:288
+msgid "Enable dual viterbi butterfly extension"
+msgstr ""
+
+#: config/arc/arc.opt:298
+msgid "Enable Dual and Single Operand Instructions for Telephony"
+msgstr ""
+
+#: config/arc/arc.opt:302
+msgid "Enable XY Memory extension (DSP version 3)"
+msgstr ""
+
+#: config/arc/arc.opt:307
+msgid "Enable Locked Load/Store Conditional extension"
+msgstr ""
+
+#: config/arc/arc.opt:311
+msgid "Enable swap byte ordering extension instruction"
+msgstr ""
+
+#: config/arc/arc.opt:315
+msgid "Enable 64-bit Time-Stamp Counter extension instruction"
+msgstr ""
+
+#: config/arc/arc.opt:319
+msgid "Disable generation of cfi for epilogues."
+msgstr ""
+
+#: config/arc/arc.opt:323
+msgid "Enable generation of cfi for epilogues."
+msgstr ""
+
+#: config/arc/arc.opt:327
+msgid "Pass -EB option through to linker."
+msgstr ""
+
+#: config/arc/arc.opt:331
+msgid "Pass -EL option through to linker."
+msgstr ""
+
+#: config/arc/arc.opt:335
+msgid "Pass -marclinux option through to linker."
+msgstr ""
+
+#: config/arc/arc.opt:339
+msgid "Pass -marclinux_prof option through to linker."
+msgstr ""
+
+#: config/arc/arc.opt:347
+msgid "Enable lra"
+msgstr ""
+
+#: config/arc/arc.opt:351
+msgid "Don't indicate any priority with TARGET_REGISTER_PRIORITY"
+msgstr ""
+
+#: config/arc/arc.opt:355
+msgid "Indicate priority for r0..r3 / r12..r15 with TARGET_REGISTER_PRIORITY"
+msgstr ""
+
+#: config/arc/arc.opt:359
+msgid "Reduce priority for r0..r3 / r12..r15 with TARGET_REGISTER_PRIORITY"
+msgstr ""
+
+#: config/arc/arc.opt:363
+msgid "instrument with mcount calls as in the ucb code"
+msgstr ""
+
+#: java/lang.opt:122
+msgid "Warn if deprecated empty statements are found"
+msgstr ""
+
+#: java/lang.opt:126
+msgid "Warn if .class files are out of date"
+msgstr ""
+
+#: java/lang.opt:130
+msgid "Warn if modifiers are specified when not necessary"
+msgstr ""
+
+#: java/lang.opt:150
+msgid "--CLASSPATH\tDeprecated; use --classpath instead"
+msgstr ""
+
+#: java/lang.opt:157
+msgid "Permit the use of the assert keyword"
+msgstr ""
+
+#: java/lang.opt:179
+msgid "--bootclasspath=<path>\tReplace system path"
+msgstr ""
+
+#: java/lang.opt:183
+msgid "Generate checks for references to NULL"
+msgstr ""
+
+#: java/lang.opt:187
+msgid "--classpath=<path>\tSet class path"
+msgstr ""
+
+#: java/lang.opt:194
+msgid "Output a class file"
+msgstr ""
+
+#: java/lang.opt:198
+msgid "Alias for -femit-class-file"
+msgstr ""
+
+#: java/lang.opt:202
+msgid "--encoding=<encoding>\tChoose input encoding (defaults from your locale)"
+msgstr ""
+
+#: java/lang.opt:206
+msgid "--extdirs=<path>\tSet the extension directory path"
+msgstr ""
+
+#: java/lang.opt:216
+msgid "Input file is a file with a list of filenames to compile"
+msgstr ""
+
+#: java/lang.opt:223
+msgid "Always check for non gcj generated classes archives"
+msgstr ""
+
+#: java/lang.opt:227
+msgid "Assume the runtime uses a hash table to map an object to its synchronization structure"
+msgstr ""
+
+#: java/lang.opt:231
+msgid "Generate instances of Class at runtime"
+msgstr ""
+
+#: java/lang.opt:235
+msgid "Use offset tables for virtual method calls"
+msgstr ""
+
+#: java/lang.opt:242
+msgid "Assume native functions are implemented using JNI"
+msgstr ""
+
+#: java/lang.opt:246
+msgid "Enable optimization of static class initialization code"
+msgstr ""
+
+#: java/lang.opt:253
+msgid "Reduce the amount of reflection meta-data generated"
+msgstr ""
+
+#: java/lang.opt:257
+msgid "Enable assignability checks for stores into object arrays"
+msgstr ""
+
+#: java/lang.opt:261
+msgid "Generate code for the Boehm GC"
+msgstr ""
+
+#: java/lang.opt:265
+msgid "Call a library routine to do integer divisions"
+msgstr ""
+
+#: java/lang.opt:269
+msgid "Generate code for built-in atomic operations"
+msgstr ""
+
+#: java/lang.opt:273
+msgid "Generated should be loaded by bootstrap loader"
+msgstr ""
+
+#: java/lang.opt:277
+msgid "Set the source language version"
+msgstr ""
+
+#: java/lang.opt:281
+msgid "Set the target VM version"
+msgstr ""
+
+#: lto/lang.opt:29
+msgid "Run the link-time optimizer in local transformation (LTRANS) mode."
+msgstr ""
+
+#: lto/lang.opt:33
+msgid "Specify a file to which a list of files output by LTRANS is written."
+msgstr ""
+
+#: lto/lang.opt:37
+msgid "Run the link-time optimizer in whole program analysis (WPA) mode."
+msgstr ""
+
+#: lto/lang.opt:41
+msgid "Whole program analysis (WPA) mode with number of parallel jobs specified."
+msgstr ""
+
+#: lto/lang.opt:45
+msgid "The resolution file"
+msgstr ""
+
+#: common.opt:282
+msgid "Display this information"
+msgstr ""
+
+#: common.opt:286
+msgid "--help=<class>\tDisplay descriptions of a specific class of options.  <class> is one or more of optimizers, target, warnings, undocumented, params"
+msgstr ""
+
+#: common.opt:404
+msgid "Alias for --help=target"
+msgstr ""
+
+#: common.opt:429
+msgid "--param <param>=<value>\tSet parameter <param> to value.  See below for a complete list of parameters"
+msgstr ""
+
+#: common.opt:457
+msgid "-O<number>\tSet optimization level to <number>"
+msgstr ""
+
+#: common.opt:461
+msgid "Optimize for space rather than speed"
+msgstr ""
+
+#: common.opt:465
+msgid "Optimize for speed disregarding exact standards compliance"
+msgstr ""
+
+#: common.opt:469
+msgid "Optimize for debugging experience rather than speed or size"
+msgstr ""
+
+#: common.opt:509
+msgid "This switch is deprecated; use -Wextra instead"
+msgstr ""
+
+#: common.opt:522
+msgid "Warn about returning structures, unions or arrays"
+msgstr ""
+
+#: common.opt:526
+msgid "Warn if a loop with constant number of iterations triggers undefined behavior"
+msgstr ""
+
+#: common.opt:530 common.opt:534
+msgid "Warn if an array is accessed out of bounds"
+msgstr ""
+
+#: common.opt:538
+msgid "Warn about inappropriate attribute usage"
+msgstr ""
+
+#: common.opt:542
+msgid "Warn about pointer casts which increase alignment"
+msgstr ""
+
+#: common.opt:546
+msgid "Warn when a #warning directive is encountered"
+msgstr ""
+
+#: common.opt:550
+msgid "Warn about uses of __attribute__((deprecated)) declarations"
+msgstr ""
+
+#: common.opt:554
+msgid "Warn when an optimization pass is disabled"
+msgstr ""
+
+#: common.opt:558
+msgid "Treat all warnings as errors"
+msgstr ""
+
+#: common.opt:562
+msgid "Treat specified warning as error"
+msgstr ""
+
+#: common.opt:566
+msgid "Print extra (possibly unwanted) warnings"
+msgstr ""
+
+#: common.opt:570
+msgid "Exit on the first error occurred"
+msgstr ""
+
+#: common.opt:574
+msgid "-Wframe-larger-than=<number>\tWarn if a function's stack frame requires more than <number> bytes"
+msgstr ""
+
+#: common.opt:578
+msgid "Warn when attempting to free a non-heap object"
+msgstr ""
+
+#: common.opt:582
+msgid "Warn when an inlined function cannot be inlined"
+msgstr ""
+
+#: common.opt:586
+msgid "Warn when an atomic memory model parameter is known to be outside the valid range."
+msgstr ""
+
+#: common.opt:593
+msgid "-Wlarger-than=<number>\tWarn if an object is larger than <number> bytes"
+msgstr ""
+
+#: common.opt:597
+msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
+msgstr ""
+
+#: common.opt:604
+msgid "Warn about some C++ One Definition Rule violations during link time optimization"
+msgstr ""
+
+#: common.opt:608
+msgid "Warn about overflow in arithmetic expressions"
+msgstr ""
+
+#: common.opt:612
+msgid "Warn when the packed attribute has no effect on struct layout"
+msgstr ""
+
+#: common.opt:616
+msgid "Warn when padding is required to align structure members"
+msgstr ""
+
+#: common.opt:620
+msgid "Issue warnings needed for strict compliance to the standard"
+msgstr ""
+
+#: common.opt:624
+msgid "Warn about returning a pointer/reference to a local or temporary variable."
+msgstr ""
+
+#: common.opt:628
+msgid "Warn when one local variable shadows another"
+msgstr ""
+
+#: common.opt:632
+msgid "Warn when not issuing stack smashing protection for some reason"
+msgstr ""
+
+#: common.opt:636
+msgid "Warn if stack usage might be larger than specified amount"
+msgstr ""
+
+#: common.opt:640 common.opt:644
+msgid "Warn about code which might break strict aliasing rules"
+msgstr ""
+
+#: common.opt:648 common.opt:652
+msgid "Warn about optimizations that assume that signed overflow is undefined"
+msgstr ""
+
+#: common.opt:656
+msgid "Warn about functions which might be candidates for __attribute__((const))"
+msgstr ""
+
+#: common.opt:660
+msgid "Warn about functions which might be candidates for __attribute__((pure))"
+msgstr ""
+
+#: common.opt:664
+msgid "Warn about functions which might be candidates for __attribute__((noreturn))"
+msgstr ""
+
+#: common.opt:668
+msgid "Warn about C++ polymorphic types where adding final keyword would improve code quality"
+msgstr ""
+
+#: common.opt:672
+msgid "Warn about C++ virtual methods where adding final keyword would improve code quality"
+msgstr ""
+
+#: common.opt:676
+msgid "Do not suppress warnings from system headers"
+msgstr ""
+
+#: common.opt:680
+msgid "Warn whenever a trampoline is generated"
+msgstr ""
+
+#: common.opt:684
+msgid "Warn if a comparison is always true or always false due to the limited range of the data type"
+msgstr ""
+
+#: common.opt:688
+msgid "Warn about uninitialized automatic variables"
+msgstr ""
+
+#: common.opt:692
+msgid "Warn about maybe uninitialized automatic variables"
+msgstr ""
+
+#: common.opt:700
+msgid "Enable all -Wunused- warnings"
+msgstr ""
+
+#: common.opt:704
+msgid "Warn when a function parameter is only set, otherwise unused"
+msgstr ""
+
+#: common.opt:708
+msgid "Warn when a variable is only set, otherwise unused"
+msgstr ""
+
+#: common.opt:712
+msgid "Warn when a function is unused"
+msgstr ""
+
+#: common.opt:716
+msgid "Warn when a label is unused"
+msgstr ""
+
+#: common.opt:720
+msgid "Warn when a function parameter is unused"
+msgstr ""
+
+#: common.opt:724
+msgid "Warn when an expression value is unused"
+msgstr ""
+
+#: common.opt:728
+msgid "Warn when a variable is unused"
+msgstr ""
+
+#: common.opt:732
+msgid "Warn in case profiles in -fprofile-use do not match"
+msgstr ""
+
+#: common.opt:736
+msgid "Warn when a vector operation is compiled outside the SIMD"
+msgstr ""
+
+#: common.opt:752
+msgid "-aux-info <file>\tEmit declaration information into <file>"
+msgstr ""
+
+#: common.opt:771
+msgid "-d<letters>\tEnable dumps from specific passes of the compiler"
+msgstr ""
+
+#: common.opt:775
+msgid "-dumpbase <file>\tSet the file basename to be used for dumps"
+msgstr ""
+
+#: common.opt:779
+msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
+msgstr ""
+
+#: common.opt:845
+msgid "The version of the C++ ABI in use"
+msgstr ""
+
+#: common.opt:849
+msgid "Aggressively optimize loops using language constraints"
+msgstr ""
+
+#: common.opt:853
+msgid "Align the start of functions"
+msgstr ""
+
+#: common.opt:860
+msgid "Align labels which are only reached by jumping"
+msgstr ""
+
+#: common.opt:867
+msgid "Align all labels"
+msgstr ""
+
+#: common.opt:874
+msgid "Align the start of loops"
+msgstr ""
+
+#: common.opt:897
+msgid "Select what to sanitize"
+msgstr ""
+
+#: common.opt:901
+msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
+msgstr ""
+
+#: common.opt:905
+msgid "After diagnosing undefined behavior attempt to continue execution"
+msgstr ""
+
+#: common.opt:909
+msgid "This switch is deprecated; use -fsanitize-recover= instead"
+msgstr ""
+
+#: common.opt:913
+msgid "Use trap instead of a library function for undefined behavior sanitization"
+msgstr ""
+
+#: common.opt:917
+msgid "Generate unwind tables that are exact at each instruction boundary"
+msgstr ""
+
+#: common.opt:921
+msgid "Generate auto-inc/dec instructions"
+msgstr ""
+
+#: common.opt:925
+msgid "Use sample profile information for call graph node weights. The default"
+msgstr ""
+
+#: common.opt:930
+msgid "Use sample profile information for call graph node weights. The profile"
+msgstr ""
+
+#: common.opt:939
+msgid "Generate code to check bounds before indexing arrays"
+msgstr ""
+
+#: common.opt:943
+msgid "Replace add, compare, branch with branch on count register"
+msgstr ""
+
+#: common.opt:947
+msgid "Use profiling information for branch probabilities"
+msgstr ""
+
+#: common.opt:951
+msgid "Perform branch target load optimization before prologue / epilogue threading"
+msgstr ""
+
+#: common.opt:955
+msgid "Perform branch target load optimization after prologue / epilogue threading"
+msgstr ""
+
+#: common.opt:959
+msgid "Restrict target load migration not to re-use registers in any basic block"
+msgstr ""
+
+#: common.opt:963
+msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
+msgstr ""
+
+#: common.opt:967
+msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
+msgstr ""
+
+#: common.opt:974
+msgid "Save registers around function calls"
+msgstr ""
+
+#: common.opt:978
+msgid "Compare the results of several data dependence analyzers."
+msgstr ""
+
+#: common.opt:982
+msgid "Check the return value of new in C++"
+msgstr ""
+
+#: common.opt:986
+msgid "Looks for opportunities to reduce stack adjustments and stack references."
+msgstr ""
+
+#: common.opt:990
+msgid "Do not put uninitialized globals in the common section"
+msgstr ""
+
+#: common.opt:998
+msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
+msgstr ""
+
+#: common.opt:1002
+msgid "Run only the second compilation of -fcompare-debug"
+msgstr ""
+
+#: common.opt:1006
+msgid "Perform comparison elimination after register allocation has finished"
+msgstr ""
+
+#: common.opt:1010
+msgid "Do not perform optimizations increasing noticeably stack usage"
+msgstr ""
+
+#: common.opt:1014
+msgid "Perform a register copy-propagation optimization pass"
+msgstr ""
+
+#: common.opt:1018
+msgid "Perform cross-jumping optimization"
+msgstr ""
+
+#: common.opt:1022
+msgid "When running CSE, follow jumps to their targets"
+msgstr ""
+
+#: common.opt:1030
+msgid "Omit range reduction step when performing complex division"
+msgstr ""
+
+#: common.opt:1034
+msgid "Complex multiplication and division follow Fortran rules"
+msgstr ""
+
+#: common.opt:1038
+msgid "Place data items into their own section"
+msgstr ""
+
+#: common.opt:1042
+msgid "List all available debugging counters with their limits and counts."
+msgstr ""
+
+#: common.opt:1046
+msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
+msgstr ""
+
+#: common.opt:1050
+msgid "Map one directory name to another in debug information"
+msgstr ""
+
+#: common.opt:1054
+msgid "Output .debug_types section when using DWARF v4 debuginfo."
+msgstr ""
+
+#: common.opt:1060
+msgid "Defer popping functions args from stack until later"
+msgstr ""
+
+#: common.opt:1064
+msgid "Attempt to fill delay slots of branch instructions"
+msgstr ""
+
+#: common.opt:1068
+msgid "Delete dead instructions that may throw exceptions"
+msgstr ""
+
+#: common.opt:1072
+msgid "Delete useless null pointer checks"
+msgstr ""
+
+#: common.opt:1076
+msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
+msgstr ""
+
+#: common.opt:1080
+msgid "Perform speculative devirtualization"
+msgstr ""
+
+#: common.opt:1084
+msgid "Try to convert virtual calls to direct ones."
+msgstr ""
+
+#: common.opt:1088
+msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
+msgstr ""
+
+#: common.opt:1105
+msgid "Show the source line with a caret indicating the column"
+msgstr ""
+
+#: common.opt:1113
+msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
+msgstr ""
+
+#: common.opt:1133
+msgid "Amend appropriate diagnostic messages with the command line option that controls them"
+msgstr ""
+
+#: common.opt:1137
+msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
+msgstr ""
+
+#: common.opt:1141
+msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
+msgstr ""
+
+#: common.opt:1145
+msgid "-fdump-<type>\tDump various compiler internals to a file"
+msgstr ""
+
+#: common.opt:1152
+msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
+msgstr ""
+
+#: common.opt:1156
+msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
+msgstr ""
+
+#: common.opt:1160
+msgid "Suppress output of addresses in debugging dumps"
+msgstr ""
+
+#: common.opt:1164
+msgid "Collect and dump debug information into temporary file if ICE in C/C++"
+msgstr ""
+
+#: common.opt:1169
+msgid "Dump optimization passes"
+msgstr ""
+
+#: common.opt:1173
+msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
+msgstr ""
+
+#: common.opt:1177
+msgid "Suppress output of previous and next insn numbers in debugging dumps"
+msgstr ""
+
+#: common.opt:1181
+msgid "Enable CFI tables via GAS assembler directives."
+msgstr ""
+
+#: common.opt:1185
+msgid "Perform early inlining"
+msgstr ""
+
+#: common.opt:1189
+msgid "Perform DWARF2 duplicate elimination"
+msgstr ""
+
+#: common.opt:1193
+msgid "Perform interprocedural reduction of aggregates"
+msgstr ""
+
+#: common.opt:1197
+msgid "Perform unused symbol elimination in debug info"
+msgstr ""
+
+#: common.opt:1201
+msgid "Perform unused type elimination in debug info"
+msgstr ""
+
+#: common.opt:1205
+msgid "Do not suppress C++ class debug information."
+msgstr ""
+
+#: common.opt:1209
+msgid "Enable exception handling"
+msgstr ""
+
+#: common.opt:1213
+msgid "Perform a number of minor, expensive optimizations"
+msgstr ""
+
+#: common.opt:1217
+msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
+msgstr ""
+
+#: common.opt:1220
+#, c-format
+msgid "unknown excess precision style %qs"
+msgstr ""
+
+#: common.opt:1233
+msgid "Output lto objects containing both the intermediate language and binary output."
+msgstr ""
+
+#: common.opt:1237
+msgid "Assume no NaNs or infinities are generated"
+msgstr ""
+
+#: common.opt:1241
+msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
+msgstr ""
+
+#: common.opt:1245
+msgid "Don't allocate floats and doubles in extended-precision registers"
+msgstr ""
+
+#: common.opt:1253
+msgid "Perform a forward propagation pass on RTL"
+msgstr ""
+
+#: common.opt:1257
+msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
+msgstr ""
+
+#: common.opt:1260
+#, c-format
+msgid "unknown floating point contraction style %qs"
+msgstr ""
+
+#: common.opt:1277
+msgid "Allow function addresses to be held in registers"
+msgstr ""
+
+#: common.opt:1281
+msgid "Place each function into its own section"
+msgstr ""
+
+#: common.opt:1285
+msgid "Perform global common subexpression elimination"
+msgstr ""
+
+#: common.opt:1289
+msgid "Perform enhanced load motion during global common subexpression elimination"
+msgstr ""
+
+#: common.opt:1293
+msgid "Perform store motion after global common subexpression elimination"
+msgstr ""
+
+#: common.opt:1297
+msgid "Perform redundant load after store elimination in global common subexpression"
+msgstr ""
+
+#: common.opt:1302
+msgid "Perform global common subexpression elimination after register allocation"
+msgstr ""
+
+#: common.opt:1308
+msgid "Enable in and out of Graphite representation"
+msgstr ""
+
+#: common.opt:1312
+msgid "Enable Graphite Identity transformation"
+msgstr ""
+
+#: common.opt:1316
+msgid "Enable hoisting adjacent loads to encourage generating conditional move"
+msgstr ""
+
+#: common.opt:1321
+msgid "Mark all loops as parallel"
+msgstr ""
+
+#: common.opt:1325
+msgid "Enable Loop Strip Mining transformation"
+msgstr ""
+
+#: common.opt:1329
+msgid "Enable Loop Interchange transformation"
+msgstr ""
+
+#: common.opt:1333
+msgid "Enable Loop Blocking transformation"
+msgstr ""
+
+#: common.opt:1337
+msgid "Enable Loop Unroll Jam transformation"
+msgstr ""
+
+#: common.opt:1341
+msgid "Enable support for GNU transactional memory"
+msgstr ""
+
+#: common.opt:1345
+msgid "Use STB_GNU_UNIQUE if supported by the assembler"
+msgstr ""
+
+#: common.opt:1353
+msgid "Enable the ISL based loop nest optimizer"
+msgstr ""
+
+#: common.opt:1357
+msgid "Force bitfield accesses to match their type width"
+msgstr ""
+
+#: common.opt:1361
+msgid "Enable guessing of branch probabilities"
+msgstr ""
+
+#: common.opt:1369
+msgid "Process #ident directives"
+msgstr ""
+
+#: common.opt:1373
+msgid "Perform conversion of conditional jumps to branchless equivalents"
+msgstr ""
+
+#: common.opt:1377
+msgid "Perform conversion of conditional jumps to conditional execution"
+msgstr ""
+
+#: common.opt:1381
+msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
+msgstr ""
+
+#: common.opt:1384
+#, c-format
+msgid "unknown Stack Reuse Level %qs"
+msgstr ""
+
+#: common.opt:1397
+msgid "Convert conditional jumps in innermost loops to branchless equivalents"
+msgstr ""
+
+#: common.opt:1401
+msgid "Also if-convert conditional jumps containing memory writes"
+msgstr ""
+
+#: common.opt:1409
+msgid "Do not generate .size directives"
+msgstr ""
+
+#: common.opt:1413
+msgid "Perform indirect inlining"
+msgstr ""
+
+#: common.opt:1419
+msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
+msgstr ""
+
+#: common.opt:1423
+msgid "Integrate functions into their callers when code size is known not to grow"
+msgstr ""
+
+#: common.opt:1427
+msgid "Integrate functions not declared \"inline\" into their callers when profitable"
+msgstr ""
+
+#: common.opt:1431
+msgid "Integrate functions only required by their single caller"
+msgstr ""
+
+#: common.opt:1438
+msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
+msgstr ""
+
+#: common.opt:1442
+msgid "Inline __atomic operations when a lock free instruction sequence is available."
+msgstr ""
+
+#: common.opt:1446
+msgid "Instrument function entry and exit with profiling calls"
+msgstr ""
+
+#: common.opt:1450
+msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
+msgstr ""
+
+#: common.opt:1454
+msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
+msgstr ""
+
+#: common.opt:1458
+msgid "Perform interprocedural constant propagation"
+msgstr ""
+
+#: common.opt:1462
+msgid "Perform cloning to make Interprocedural constant propagation stronger"
+msgstr ""
+
+#: common.opt:1466
+msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
+msgstr ""
+
+#: common.opt:1470
+msgid "Perform interprocedural profile propagation"
+msgstr ""
+
+#: common.opt:1474
+msgid "Perform interprocedural points-to analysis"
+msgstr ""
+
+#: common.opt:1478
+msgid "Discover pure and const functions"
+msgstr ""
+
+#: common.opt:1482
+msgid "Perform Identical Code Folding for functions and read-only variables"
+msgstr ""
+
+#: common.opt:1486
+msgid "Perform Identical Code Folding for functions"
+msgstr ""
+
+#: common.opt:1490
+msgid "Perform Identical Code Folding for variables"
+msgstr ""
+
+#: common.opt:1494
+msgid "Discover readonly and non addressable static variables"
+msgstr ""
+
+#: common.opt:1506
+msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
+msgstr ""
+
+#: common.opt:1509
+#, c-format
+msgid "unknown IRA algorithm %qs"
+msgstr ""
+
+#: common.opt:1519
+msgid "-fira-region=[one|all|mixed] Set regions for IRA"
+msgstr ""
+
+#: common.opt:1522
+#, c-format
+msgid "unknown IRA region %qs"
+msgstr ""
+
+#: common.opt:1535 common.opt:1540
+msgid "Use IRA based register pressure calculation"
+msgstr ""
+
+#: common.opt:1545
+msgid "Share slots for saving different hard registers."
+msgstr ""
+
+#: common.opt:1549
+msgid "Share stack slots for spilled pseudo-registers."
+msgstr ""
+
+#: common.opt:1553
+msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
+msgstr ""
+
+#: common.opt:1557
+msgid "Optimize induction variables on trees"
+msgstr ""
+
+#: common.opt:1561
+msgid "Use jump tables for sufficiently large switch statements"
+msgstr ""
+
+#: common.opt:1565
+msgid "Generate code for functions even if they are fully inlined"
+msgstr ""
+
+#: common.opt:1569
+msgid "Emit static const variables even if they are not used"
+msgstr ""
+
+#: common.opt:1573
+msgid "Give external symbols a leading underscore"
+msgstr ""
+
+#: common.opt:1581
+msgid "Do CFG-sensitive rematerialization in LRA"
+msgstr ""
+
+#: common.opt:1585
+msgid "Enable link-time optimization."
+msgstr ""
+
+#: common.opt:1589
+msgid "Link-time optimization with number of parallel jobs or jobserver."
+msgstr ""
+
+#: common.opt:1592
+#, c-format
+msgid "unknown LTO partitioning model %qs"
+msgstr ""
+
+#: common.opt:1611
+msgid "Specify the algorithm to partition symbols and vars at linktime"
+msgstr ""
+
+#: common.opt:1616
+msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
+msgstr ""
+
+#: common.opt:1620
+msgid "Merge C++ types using One Definition Rule"
+msgstr ""
+
+#: common.opt:1624
+msgid "Report various link-time optimization statistics"
+msgstr ""
+
+#: common.opt:1628
+msgid "Report various link-time optimization statistics for WPA only"
+msgstr ""
+
+#: common.opt:1632
+msgid "Set errno after built-in math functions"
+msgstr ""
+
+#: common.opt:1636
+msgid "-fmax-errors=<number>\tMaximum number of errors to report"
+msgstr ""
+
+#: common.opt:1640
+msgid "Report on permanent memory allocation"
+msgstr ""
+
+#: common.opt:1644
+msgid "Report on permanent memory allocation in WPA only"
+msgstr ""
+
+#: common.opt:1651
+msgid "Attempt to merge identical constants and constant variables"
+msgstr ""
+
+#: common.opt:1655
+msgid "Attempt to merge identical constants across compilation units"
+msgstr ""
+
+#: common.opt:1659
+msgid "Attempt to merge identical debug strings across compilation units"
+msgstr ""
+
+#: common.opt:1663
+msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
+msgstr ""
+
+#: common.opt:1667
+msgid "Perform SMS based modulo scheduling before the first scheduling pass"
+msgstr ""
+
+#: common.opt:1671
+msgid "Perform SMS based modulo scheduling with register moves allowed"
+msgstr ""
+
+#: common.opt:1675
+msgid "Move loop invariant computations out of loops"
+msgstr ""
+
+#: common.opt:1679
+msgid "Use the RTL dead code elimination pass"
+msgstr ""
+
+#: common.opt:1683
+msgid "Use the RTL dead store elimination pass"
+msgstr ""
+
+#: common.opt:1687
+msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
+msgstr ""
+
+#: common.opt:1691
+msgid "Support synchronous non-call exceptions"
+msgstr ""
+
+#: common.opt:1694
+#, c-format
+msgid "options or targets missing after %qs"
+msgstr ""
+
+#: common.opt:1695
+msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
+msgstr ""
+
+#: common.opt:1699
+msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
+msgstr ""
+
+#: common.opt:1702
+#, c-format
+msgid "unknown offload ABI %qs"
+msgstr ""
+
+#: common.opt:1712
+msgid "When possible do not generate stack frames"
+msgstr ""
+
+#: common.opt:1716
+msgid "Enable all optimization info dumps on stderr"
+msgstr ""
+
+#: common.opt:1720
+msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
+msgstr ""
+
+#: common.opt:1728
+msgid "Optimize sibling and tail recursive calls"
+msgstr ""
+
+#: common.opt:1732
+msgid "Perform partial inlining"
+msgstr ""
+
+#: common.opt:1736 common.opt:1740
+msgid "Report on memory allocation before interprocedural optimization"
+msgstr ""
+
+#: common.opt:1744
+msgid "Pack structure members together without holes"
+msgstr ""
+
+#: common.opt:1748
+msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
+msgstr ""
+
+#: common.opt:1752
+msgid "Return small aggregates in memory, not registers"
+msgstr ""
+
+#: common.opt:1756
+msgid "Perform loop peeling"
+msgstr ""
+
+#: common.opt:1760
+msgid "Enable machine specific peephole optimizations"
+msgstr ""
+
+#: common.opt:1764
+msgid "Enable an RTL peephole pass before sched2"
+msgstr ""
+
+#: common.opt:1768
+msgid "Generate position-independent code if possible (large mode)"
+msgstr ""
+
+#: common.opt:1772
+msgid "Generate position-independent code for executables if possible (large mode)"
+msgstr ""
+
+#: common.opt:1776
+msgid "Generate position-independent code if possible (small mode)"
+msgstr ""
+
+#: common.opt:1780
+msgid "Generate position-independent code for executables if possible (small mode)"
+msgstr ""
+
+#: common.opt:1784
+msgid "Specify a plugin to load"
+msgstr ""
+
+#: common.opt:1788
+msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
+msgstr ""
+
+#: common.opt:1792
+msgid "Run predictive commoning optimization."
+msgstr ""
+
+#: common.opt:1796
+msgid "Generate prefetch instructions, if available, for arrays in loops"
+msgstr ""
+
+#: common.opt:1800
+msgid "Enable basic program profiling code"
+msgstr ""
+
+#: common.opt:1804
+msgid "Insert arc-based program profiling code"
+msgstr ""
+
+#: common.opt:1808
+msgid "Set the top-level directory for storing the profile data."
+msgstr ""
+
+#: common.opt:1813
+msgid "Enable correction of flow inconsistent profile data input"
+msgstr ""
+
+#: common.opt:1817
+msgid "Enable common options for generating profile info for profile feedback directed optimizations"
+msgstr ""
+
+#: common.opt:1821
+msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
+msgstr ""
+
+#: common.opt:1825
+msgid "Enable common options for performing profile feedback directed optimizations"
+msgstr ""
+
+#: common.opt:1829
+msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
+msgstr ""
+
+#: common.opt:1833
+msgid "Insert code to profile values of expressions"
+msgstr ""
+
+#: common.opt:1837
+msgid "Report on consistency of profile"
+msgstr ""
+
+#: common.opt:1841
+msgid "Enable function reordering that improves code placement"
+msgstr ""
+
+#: common.opt:1848
+msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
+msgstr ""
+
+#: common.opt:1858
+msgid "Record gcc command line switches in the object file."
+msgstr ""
+
+#: common.opt:1862
+msgid "Return small aggregates in registers"
+msgstr ""
+
+#: common.opt:1870
+msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
+msgstr ""
+
+#: common.opt:1875
+msgid "Relief of register pressure through live range shrinkage"
+msgstr ""
+
+#: common.opt:1879
+msgid "Perform a register renaming optimization pass"
+msgstr ""
+
+#: common.opt:1883
+msgid "Perform a target dependent instruction fusion optimization pass"
+msgstr ""
+
+#: common.opt:1887
+msgid "Reorder basic blocks to improve code placement"
+msgstr ""
+
+#: common.opt:1891
+msgid "Reorder basic blocks and partition into hot and cold sections"
+msgstr ""
+
+#: common.opt:1895
+msgid "Reorder functions to improve code placement"
+msgstr ""
+
+#: common.opt:1899
+msgid "Add a common subexpression elimination pass after loop optimizations"
+msgstr ""
+
+#: common.opt:1907
+msgid "Disable optimizations that assume default FP rounding behavior"
+msgstr ""
+
+#: common.opt:1911
+msgid "Enable scheduling across basic blocks"
+msgstr ""
+
+#: common.opt:1915
+msgid "Enable register pressure sensitive insn scheduling"
+msgstr ""
+
+#: common.opt:1919
+msgid "Allow speculative motion of non-loads"
+msgstr ""
+
+#: common.opt:1923
+msgid "Allow speculative motion of some loads"
+msgstr ""
+
+#: common.opt:1927
+msgid "Allow speculative motion of more loads"
+msgstr ""
+
+#: common.opt:1931
+msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
+msgstr ""
+
+#: common.opt:1935
+msgid "If scheduling post reload, do superblock scheduling"
+msgstr ""
+
+#: common.opt:1943
+msgid "Reschedule instructions before register allocation"
+msgstr ""
+
+#: common.opt:1947
+msgid "Reschedule instructions after register allocation"
+msgstr ""
+
+#: common.opt:1954
+msgid "Schedule instructions using selective scheduling algorithm"
+msgstr ""
+
+#: common.opt:1958
+msgid "Run selective scheduling after reload"
+msgstr ""
+
+#: common.opt:1962
+msgid "Perform software pipelining of inner loops during selective scheduling"
+msgstr ""
+
+#: common.opt:1966
+msgid "Perform software pipelining of outer loops during selective scheduling"
+msgstr ""
+
+#: common.opt:1970
+msgid "Reschedule pipelined regions without pipelining"
+msgstr ""
+
+#: common.opt:1974
+msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
+msgstr ""
+
+#: common.opt:1980
+msgid "Allow premature scheduling of queued insns"
+msgstr ""
+
+#: common.opt:1984
+msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
+msgstr ""
+
+#: common.opt:1992
+msgid "Set dependence distance checking in premature scheduling of queued insns"
+msgstr ""
+
+#: common.opt:1996
+msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
+msgstr ""
+
+#: common.opt:2000
+msgid "Enable the group heuristic in the scheduler"
+msgstr ""
+
+#: common.opt:2004
+msgid "Enable the critical path heuristic in the scheduler"
+msgstr ""
+
+#: common.opt:2008
+msgid "Enable the speculative instruction heuristic in the scheduler"
+msgstr ""
+
+#: common.opt:2012
+msgid "Enable the rank heuristic in the scheduler"
+msgstr ""
+
+#: common.opt:2016
+msgid "Enable the last instruction heuristic in the scheduler"
+msgstr ""
+
+#: common.opt:2020
+msgid "Enable the dependent count heuristic in the scheduler"
+msgstr ""
+
+#: common.opt:2024
+msgid "Access data in the same section from shared anchor points"
+msgstr ""
+
+#: common.opt:2036
+msgid "Turn on Redundant Extensions Elimination pass."
+msgstr ""
+
+#: common.opt:2040
+msgid "Show column numbers in diagnostics, when available.  Default on"
+msgstr ""
+
+#: common.opt:2044
+msgid "Emit function prologues only before parts of the function that need it,"
+msgstr ""
+
+#: common.opt:2049
+msgid "Disable optimizations observable by IEEE signaling NaNs"
+msgstr ""
+
+#: common.opt:2053
+msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
+msgstr ""
+
+#: common.opt:2057
+msgid "Convert floating point constants to single precision constants"
+msgstr ""
+
+#: common.opt:2061
+msgid "Split lifetimes of induction variables when loops are unrolled"
+msgstr ""
+
+#: common.opt:2065
+msgid "Generate discontiguous stack frames"
+msgstr ""
+
+#: common.opt:2069
+msgid "Split wide types into independent registers"
+msgstr ""
+
+#: common.opt:2073
+msgid "Optimize conditional patterns using SSA PHI nodes"
+msgstr ""
+
+#: common.opt:2077
+msgid "Optimize amount of stdarg registers saved to stack at start of function"
+msgstr ""
+
+#: common.opt:2081
+msgid "Apply variable expansion when loops are unrolled"
+msgstr ""
+
+#: common.opt:2085
+msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
+msgstr ""
+
+#: common.opt:2089
+msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
+msgstr ""
+
+#: common.opt:2096
+msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
+msgstr ""
+
+#: common.opt:2100
+msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
+msgstr ""
+
+#: common.opt:2104
+msgid "Use propolice as a stack protection method"
+msgstr ""
+
+#: common.opt:2108
+msgid "Use a stack protection method for every function"
+msgstr ""
+
+#: common.opt:2112
+msgid "Use a smart stack protection method for certain functions"
+msgstr ""
+
+#: common.opt:2116
+msgid "Use stack protection method only for functions with the stack_protect attribute"
+msgstr ""
+
+#: common.opt:2120
+msgid "Output stack usage information on a per-function basis"
+msgstr ""
+
+#: common.opt:2132
+msgid "Assume strict aliasing rules apply"
+msgstr ""
+
+#: common.opt:2136
+msgid "Treat signed overflow as undefined"
+msgstr ""
+
+#: common.opt:2140
+msgid "Implement __atomic operations via libcalls to legacy __sync functions"
+msgstr ""
+
+#: common.opt:2144
+msgid "Check for syntax errors, then stop"
+msgstr ""
+
+#: common.opt:2148
+msgid "Create data files needed by \"gcov\""
+msgstr ""
+
+#: common.opt:2152
+msgid "Perform jump threading optimizations"
+msgstr ""
+
+#: common.opt:2156
+msgid "Report the time taken by each compiler pass"
+msgstr ""
+
+#: common.opt:2160
+msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
+msgstr ""
+
+#: common.opt:2163
+#, c-format
+msgid "unknown TLS model %qs"
+msgstr ""
+
+#: common.opt:2179
+msgid "Reorder top level functions, variables, and asms"
+msgstr ""
+
+#: common.opt:2183
+msgid "Perform superblock formation via tail duplication"
+msgstr ""
+
+#: common.opt:2190
+msgid "Assume floating-point operations can trap"
+msgstr ""
+
+#: common.opt:2194
+msgid "Trap for signed overflow in addition, subtraction and multiplication"
+msgstr ""
+
+#: common.opt:2198
+msgid "Enable SSA-CCP optimization on trees"
+msgstr ""
+
+#: common.opt:2202
+msgid "Enable SSA-BIT-CCP optimization on trees"
+msgstr ""
+
+#: common.opt:2210
+msgid "Enable loop header copying on trees"
+msgstr ""
+
+#: common.opt:2214
+msgid "Enable coalescing of copy-related user variables that are inlined"
+msgstr ""
+
+#: common.opt:2218
+msgid "Enable coalescing of all copy-related user variables"
+msgstr ""
+
+#: common.opt:2222
+msgid "Replace SSA temporaries with better names in copies"
+msgstr ""
+
+#: common.opt:2226
+msgid "Enable copy propagation on trees"
+msgstr ""
+
+#: common.opt:2234
+msgid "Transform condition stores into unconditional ones"
+msgstr ""
+
+#: common.opt:2238
+msgid "Perform conversions of switch initializations."
+msgstr ""
+
+#: common.opt:2242
+msgid "Enable SSA dead code elimination optimization on trees"
+msgstr ""
+
+#: common.opt:2246
+msgid "Enable dominator optimizations"
+msgstr ""
+
+#: common.opt:2250
+msgid "Enable tail merging on trees"
+msgstr ""
+
+#: common.opt:2254
+msgid "Enable dead store elimination"
+msgstr ""
+
+#: common.opt:2258
+msgid "Enable forward propagation on trees"
+msgstr ""
+
+#: common.opt:2262
+msgid "Enable Full Redundancy Elimination (FRE) on trees"
+msgstr ""
+
+#: common.opt:2266
+msgid "Enable string length optimizations on trees"
+msgstr ""
+
+#: common.opt:2270
+msgid "Detect paths that trigger erroneous or undefined behavior due to"
+msgstr ""
+
+#: common.opt:2276
+msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
+msgstr ""
+
+#: common.opt:2283
+msgid "Enable loop distribution on trees"
+msgstr ""
+
+#: common.opt:2287
+msgid "Enable loop distribution for patterns transformed into a library call"
+msgstr ""
+
+#: common.opt:2291
+msgid "Enable loop invariant motion on trees"
+msgstr ""
+
+#: common.opt:2295
+msgid "Enable loop interchange transforms.  Same as -floop-interchange"
+msgstr ""
+
+#: common.opt:2299
+msgid "Create canonical induction variables in loops"
+msgstr ""
+
+#: common.opt:2303
+msgid "Enable loop optimizations on tree level"
+msgstr ""
+
+#: common.opt:2307
+msgid "Enable automatic parallelization of loops"
+msgstr ""
+
+#: common.opt:2311
+msgid "Enable hoisting loads from conditional pointers."
+msgstr ""
+
+#: common.opt:2315
+msgid "Enable SSA-PRE optimization on trees"
+msgstr ""
+
+#: common.opt:2319
+msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
+msgstr ""
+
+#: common.opt:2323
+msgid "Perform function-local points-to analysis on trees."
+msgstr ""
+
+#: common.opt:2327
+msgid "Enable reassociation on tree level"
+msgstr ""
+
+#: common.opt:2335
+msgid "Enable SSA code sinking on trees"
+msgstr ""
+
+#: common.opt:2339
+msgid "Perform straight-line strength reduction"
+msgstr ""
+
+#: common.opt:2343
+msgid "Perform scalar replacement of aggregates"
+msgstr ""
+
+#: common.opt:2347
+msgid "Replace temporary expressions in the SSA->normal pass"
+msgstr ""
+
+#: common.opt:2351
+msgid "Perform live range splitting during the SSA->normal pass"
+msgstr ""
+
+#: common.opt:2355
+msgid "Perform Value Range Propagation on trees"
+msgstr ""
+
+#: common.opt:2359
+msgid "Compile whole compilation unit at a time"
+msgstr ""
+
+#: common.opt:2363
+msgid "Perform loop unrolling when iteration count is known"
+msgstr ""
+
+#: common.opt:2367
+msgid "Perform loop unrolling for all loops"
+msgstr ""
+
+#: common.opt:2374
+msgid "Allow loop optimizations to assume that the loops behave in normal way"
+msgstr ""
+
+#: common.opt:2378
+msgid "Allow optimization for floating-point arithmetic which may change the"
+msgstr ""
+
+#: common.opt:2383
+msgid "Same as -fassociative-math for expressions which include division."
+msgstr ""
+
+#: common.opt:2391
+msgid "Allow math optimizations that may violate IEEE or ISO standards"
+msgstr ""
+
+#: common.opt:2395
+msgid "Perform loop unswitching"
+msgstr ""
+
+#: common.opt:2399
+msgid "Just generate unwind tables for exception handling"
+msgstr ""
+
+#: common.opt:2403
+msgid "Use the bfd linker instead of the default linker"
+msgstr ""
+
+#: common.opt:2407
+msgid "Use the gold linker instead of the default linker"
+msgstr ""
+
+#: common.opt:2419
+msgid "Perform variable tracking"
+msgstr ""
+
+#: common.opt:2427
+msgid "Perform variable tracking by annotating assignments"
+msgstr ""
+
+#: common.opt:2433
+msgid "Toggle -fvar-tracking-assignments"
+msgstr ""
+
+#: common.opt:2441
+msgid "Perform variable tracking and also tag variables that are uninitialized"
+msgstr ""
+
+#: common.opt:2445
+msgid "Enable vectorization on trees"
+msgstr ""
+
+#: common.opt:2453
+msgid "Enable loop vectorization on trees"
+msgstr ""
+
+#: common.opt:2457
+msgid "Enable basic block vectorization (SLP) on trees"
+msgstr ""
+
+#: common.opt:2461
+msgid "Specifies the cost model for vectorization"
+msgstr ""
+
+#: common.opt:2465
+msgid "Specifies the vectorization cost model for code marked with a simd directive"
+msgstr ""
+
+#: common.opt:2468
+#, c-format
+msgid "unknown vectorizer cost model %qs"
+msgstr ""
+
+#: common.opt:2481
+msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
+msgstr ""
+
+#: common.opt:2485
+msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
+msgstr ""
+
+#: common.opt:2493
+msgid "Enable copy propagation of scalar-evolution information."
+msgstr ""
+
+#: common.opt:2503
+msgid "Add extra commentary to assembler output"
+msgstr ""
+
+#: common.opt:2507
+msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
+msgstr ""
+
+#: common.opt:2510
+#, c-format
+msgid "unrecognized visibility value %qs"
+msgstr ""
+
+#: common.opt:2526
+msgid "Validate vtable pointers before using them."
+msgstr ""
+
+#: common.opt:2529
+#, c-format
+msgid "unknown vtable verify initialization priority %qs"
+msgstr ""
+
+#: common.opt:2542
+msgid "Output vtable verification counters."
+msgstr ""
+
+#: common.opt:2546
+msgid "Output vtable verification pointer sets information."
+msgstr ""
+
+#: common.opt:2550
+msgid "Use expression value profiles in optimizations"
+msgstr ""
+
+#: common.opt:2554
+msgid "Construct webs and split unrelated uses of single variable"
+msgstr ""
+
+#: common.opt:2558
+msgid "Enable conditional dead code elimination for builtin calls"
+msgstr ""
+
+#: common.opt:2562
+msgid "Perform whole program optimizations"
+msgstr ""
+
+#: common.opt:2566
+msgid "Assume signed arithmetic overflow wraps around"
+msgstr ""
+
+#: common.opt:2570
+msgid "Put zero initialized data in the bss section"
+msgstr ""
+
+#: common.opt:2574
+msgid "Generate debug information in default format"
+msgstr ""
+
+#: common.opt:2578
+msgid "Generate debug information in COFF format"
+msgstr ""
+
+#: common.opt:2582
+msgid "Generate debug information in default version of DWARF format"
+msgstr ""
+
+#: common.opt:2586
+msgid "Generate debug information in DWARF v2 (or later) format"
+msgstr ""
+
+#: common.opt:2590
+msgid "Generate debug information in default extended format"
+msgstr ""
+
+#: common.opt:2594
+msgid "Don't generate DWARF pubnames and pubtypes sections."
+msgstr ""
+
+#: common.opt:2598
+msgid "Generate DWARF pubnames and pubtypes sections."
+msgstr ""
+
+#: common.opt:2602
+msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
+msgstr ""
+
+#: common.opt:2606
+msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
+msgstr ""
+
+#: common.opt:2610
+msgid "Record gcc command line switches in DWARF DW_AT_producer."
+msgstr ""
+
+#: common.opt:2614
+msgid "Don't generate debug information in separate .dwo files"
+msgstr ""
+
+#: common.opt:2618
+msgid "Generate debug information in separate .dwo files"
+msgstr ""
+
+#: common.opt:2622
+msgid "Generate debug information in STABS format"
+msgstr ""
+
+#: common.opt:2626
+msgid "Generate debug information in extended STABS format"
+msgstr ""
+
+#: common.opt:2630
+msgid "Emit DWARF additions beyond selected version"
+msgstr ""
+
+#: common.opt:2634
+msgid "Don't emit DWARF additions beyond selected version"
+msgstr ""
+
+#: common.opt:2638
+msgid "Toggle debug information generation"
+msgstr ""
+
+#: common.opt:2642
+msgid "Generate debug information in VMS format"
+msgstr ""
+
+#: common.opt:2646
+msgid "Generate debug information in XCOFF format"
+msgstr ""
+
+#: common.opt:2650
+msgid "Generate debug information in extended XCOFF format"
+msgstr ""
+
+#: common.opt:2668
+msgid "Generate compressed debug sections"
+msgstr ""
+
+#: common.opt:2672
+msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
+msgstr ""
+
+#: common.opt:2679
+msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
+msgstr ""
+
+#: common.opt:2683
+msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
+msgstr ""
+
+#: common.opt:2705
+msgid "-o <file>\tPlace output into <file>"
+msgstr ""
+
+#: common.opt:2709
+msgid "Enable function profiling"
+msgstr ""
+
+#: common.opt:2719
+msgid "Like -pedantic but issue them as errors"
+msgstr ""
+
+#: common.opt:2759
+msgid "Do not display functions compiled or elapsed time"
+msgstr ""
+
+#: common.opt:2791
+msgid "Enable verbose output"
+msgstr ""
+
+#: common.opt:2795
+msgid "Display the compiler's version"
+msgstr ""
+
+#: common.opt:2799
+msgid "Suppress warnings"
+msgstr "Придушити попередження"
+
+#: common.opt:2809
+msgid "Create a shared library"
+msgstr "створити бібліотеку спільного використання"
+
+#: common.opt:2854
+msgid "Create a position independent executable"
+msgstr "створити виконуваний файл з незалежним позиціюванням"
+
+#: common.opt:2861
+msgid "Use caller save register across calls if possible"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
+#, gcc-internal-format
+msgid "value computed is not used"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:628
+msgid "invalid use of type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:2725 go/gofrontend/expressions.cc:2791
+#: go/gofrontend/expressions.cc:2807
+msgid "constant refers to itself"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:3704 go/gofrontend/expressions.cc:4082
+msgid "expected pointer"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:4049
+msgid "expected numeric type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:4054
+msgid "expected boolean type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:4060
+msgid "expected integer or boolean type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:5565
+msgid "invalid comparison of nil with nil"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
+msgid "incompatible types in binary expression"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:5609
+msgid "integer division by zero"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:5617
+msgid "shift of non-integer operand"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
+msgid "shift count not unsigned integer"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:5635
+msgid "negative shift count"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:6286
+msgid "object is not a method"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:6303
+msgid "method type does not match object type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:6777
+msgid "invalid use of %<...%> with builtin function"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:6788
+msgid "invalid use of method value as argument of Offsetof"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:6802
+msgid "argument of Offsetof implies indirection of an embedded field"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
+msgid "not enough arguments"
+msgstr "недостатньо аргументів"
+
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
+msgid "too many arguments"
+msgstr "забагато аргументів"
+
+#: go/gofrontend/expressions.cc:6892
+msgid "argument 1 must be a map"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7016
+msgid "invalid type for make function"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7032
+msgid "length required when allocating a slice"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7067
+msgid "len larger than cap"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7079
+msgid "too many arguments to make"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7853
+msgid "argument must be array or slice or channel"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7863
+msgid "argument must be string or array or slice or map or channel"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7909
+msgid "unsupported argument type to builtin function"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7920
+msgid "argument must be channel"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7922
+msgid "cannot close receive-only channel"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7944
+msgid "argument must be a field reference"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7974
+msgid "left argument must be a slice"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7982
+msgid "element types must be the same"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7987
+msgid "first argument must be []byte"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7990
+msgid "second argument must be slice or string"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:8034
+msgid "argument 2 has invalid type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:8050
+msgid "argument must have complex type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:8068
+msgid "complex arguments must have identical types"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:8070
+msgid "complex arguments must have floating-point type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
+msgid "expected function"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:8647
+msgid "multiple-value argument in single-value context"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:8812
+msgid "invalid use of %<...%> with non-slice"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:9164
+msgid "function result count mismatch"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:9182
+msgid "incompatible type for receiver"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:9200
+msgid "invalid use of %<...%> calling non-variadic function"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
+msgid "number of results does not match number of values"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
+msgid "index must be integer"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
+msgid "slice end must be integer"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:9987
+msgid "slice capacity must be integer"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
+msgid "inverted slice range"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:10080
+msgid "slice of unaddressable value"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:10741
+msgid "incompatible type for map index"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11120
+msgid "expected interface or pointer to interface"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11859
+msgid "too many expressions for struct"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11872
+msgid "too few expressions for struct"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
+msgid "type assertion only valid for interface types"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:13632
+msgid "impossible type assertion: type does not implement interface"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
+msgid "expected channel"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
+msgid "invalid receive on send-only channel"
+msgstr ""
+
+#: go/gofrontend/parse.cc:2981
+msgid "parentheses required around this composite literal to avoid parsing ambiguity"
+msgstr ""
+
+#: go/gofrontend/parse.cc:4558
+msgid "cannot fallthrough final case in switch"
+msgstr ""
+
+#: go/gofrontend/statements.cc:605
+msgid "invalid left hand side of assignment"
+msgstr ""
+
+#: go/gofrontend/statements.cc:616 go/gofrontend/statements.cc:1024
+msgid "use of untyped nil"
+msgstr ""
+
+#: go/gofrontend/statements.cc:1146
+msgid "expected map index on right hand side"
+msgstr ""
+
+#: go/gofrontend/statements.cc:1297
+msgid "expected map index on left hand side"
+msgstr ""
+
+#: go/gofrontend/statements.cc:2710 go/gofrontend/statements.cc:2740
+msgid "not enough arguments to return"
+msgstr ""
+
+#: go/gofrontend/statements.cc:2718
+msgid "return with value in function with no return type"
+msgstr ""
+
+#: go/gofrontend/statements.cc:2746
+msgid "too many values in return statement"
+msgstr ""
+
+#: go/gofrontend/statements.cc:3224
+msgid "expected boolean expression"
+msgstr ""
+
+#: go/gofrontend/statements.cc:4310
+msgid "cannot type switch on non-interface value"
+msgstr ""
+
+#: go/gofrontend/statements.cc:4445
+msgid "incompatible types in send"
+msgstr ""
+
+#: go/gofrontend/statements.cc:4450
+msgid "invalid send on receive-only channel"
+msgstr ""
+
+#: go/gofrontend/statements.cc:5388
+msgid "too many variables for range clause with channel"
+msgstr ""
+
+#: go/gofrontend/statements.cc:5395
+msgid "range clause must have array, slice, string, map, or channel type"
+msgstr ""
+
+#: go/gofrontend/types.cc:509
+msgid "invalid comparison of non-ordered type"
+msgstr ""
+
+#: go/gofrontend/types.cc:525
+msgid "slice can only be compared to nil"
+msgstr ""
+
+#: go/gofrontend/types.cc:527
+msgid "map can only be compared to nil"
+msgstr ""
+
+#: go/gofrontend/types.cc:529
+msgid "func can only be compared to nil"
+msgstr ""
+
+#: go/gofrontend/types.cc:535
+#, c-format
+msgid "invalid operation (%s)"
+msgstr "некоректна операція (%s)"
+
+#: go/gofrontend/types.cc:558
+msgid "invalid comparison of non-comparable type"
+msgstr ""
+
+#: go/gofrontend/types.cc:576
+msgid "invalid comparison of non-comparable struct"
+msgstr ""
+
+#: go/gofrontend/types.cc:587
+msgid "invalid comparison of non-comparable array"
+msgstr ""
+
+#: go/gofrontend/types.cc:615
+msgid "multiple-value function call in single-value context"
+msgstr ""
+
+#: go/gofrontend/types.cc:692
+msgid "need explicit conversion"
+msgstr ""
+
+#: go/gofrontend/types.cc:699
+#, c-format
+msgid "cannot use type %s as type %s"
+msgstr ""
+
+#: go/gofrontend/types.cc:3479
+msgid "different receiver types"
+msgstr ""
+
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
+msgid "different number of parameters"
+msgstr ""
+
+#: go/gofrontend/types.cc:3520
+msgid "different parameter types"
+msgstr ""
+
+#: go/gofrontend/types.cc:3535
+msgid "different varargs"
+msgstr ""
+
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
+msgid "different number of results"
+msgstr ""
+
+#: go/gofrontend/types.cc:3565
+msgid "different result types"
+msgstr ""
+
+#: go/gofrontend/types.cc:7359
+#, c-format
+msgid "need explicit conversion; missing method %s%s%s"
+msgstr ""
+
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
+#, c-format
+msgid "incompatible type for method %s%s%s"
+msgstr ""
+
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
+#, c-format
+msgid "incompatible type for method %s%s%s (%s)"
+msgstr ""
+
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
+msgid "pointer to interface type has no methods"
+msgstr ""
+
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
+msgid "type has no methods"
+msgstr ""
+
+#: go/gofrontend/types.cc:7495
+#, c-format
+msgid "ambiguous method %s%s%s"
+msgstr ""
+
+#: go/gofrontend/types.cc:7498
+#, c-format
+msgid "missing method %s%s%s"
+msgstr ""
+
+#: go/gofrontend/types.cc:7539
+#, c-format
+msgid "method %s%s%s requires a pointer receiver"
+msgstr ""
+
+#: go/gofrontend/types.cc:7557
+#, c-format
+msgid "method %s%s%s is marked go:nointerface"
+msgstr ""
+
+#. Warn about and ignore all others for now, but store them.
+#: attribs.c:455 c-family/c-common.c:8544 objc/objc-act.c:4985
+#: objc/objc-act.c:6954 objc/objc-act.c:8143 objc/objc-act.c:8194
+#, gcc-internal-format
+msgid "%qE attribute directive ignored"
+msgstr ""
+
+#: attribs.c:459
+#, gcc-internal-format
+msgid "%<%E::%E%> scoped attribute directive ignored"
+msgstr ""
+
+#: attribs.c:468
+#, gcc-internal-format
+msgid "wrong number of arguments specified for %qE attribute"
+msgstr ""
+
+#. This is a c++11 attribute that appertains to a
+#. type-specifier, outside of the definition of, a class
+#. type.  Ignore it.
+#: attribs.c:481
+#, gcc-internal-format
+msgid "attribute ignored"
+msgstr ""
+
+#: attribs.c:483
+#, gcc-internal-format
+msgid "an attribute that appertains to a type-specifier is ignored"
+msgstr ""
+
+#: attribs.c:500
+#, gcc-internal-format
+msgid "%qE attribute does not apply to types"
+msgstr ""
+
+#: attribs.c:548
+#, gcc-internal-format
+msgid "%qE attribute only applies to function types"
+msgstr ""
+
+#: attribs.c:558
+#, gcc-internal-format
+msgid "type attributes ignored after type is already defined"
+msgstr ""
+
+#: auto-profile.c:382
+#, gcc-internal-format
+msgid "Offset exceeds 16 bytes."
+msgstr ""
+
+#: auto-profile.c:859
+#, gcc-internal-format
+msgid "Not expected TAG."
+msgstr ""
+
+#: auto-profile.c:924
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot open profile file %s."
+msgstr ""
+
+#: auto-profile.c:927
+#, gcc-internal-format
+msgid "AutoFDO profile magic number does not mathch."
+msgstr ""
+
+#: auto-profile.c:932
+#, gcc-internal-format, gfc-internal-format
+msgid "AutoFDO profile version %u does match %u."
+msgstr ""
+
+#: auto-profile.c:941
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot read string table from %s."
+msgstr ""
+
+#: auto-profile.c:946
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot read function profile from %s."
+msgstr ""
+
+#: auto-profile.c:953
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot read working set from %s."
+msgstr ""
+
+#: bt-load.c:1593
+#, gcc-internal-format
+msgid "branch target register load optimization is not intended to be run twice"
+msgstr ""
+
+#: builtins.c:639
+#, gcc-internal-format
+msgid "offset outside bounds of constant string"
+msgstr ""
+
+#: builtins.c:1268
+#, gcc-internal-format
+msgid "second argument to %<__builtin_prefetch%> must be a constant"
+msgstr ""
+
+#: builtins.c:1275
+#, gcc-internal-format
+msgid "invalid second argument to %<__builtin_prefetch%>; using zero"
+msgstr ""
+
+#: builtins.c:1283
+#, gcc-internal-format
+msgid "third argument to %<__builtin_prefetch%> must be a constant"
+msgstr ""
+
+#: builtins.c:1290
+#, gcc-internal-format
+msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
+msgstr ""
+
+#: builtins.c:4486 gimplify.c:2351
+#, gcc-internal-format
+msgid "too few arguments to function %<va_start%>"
+msgstr ""
+
+#: builtins.c:4586
+#, gcc-internal-format
+msgid "invalid argument to %<__builtin_frame_address%>"
+msgstr "некоректний аргумент %<__builtin_frame_address%>"
+
+#: builtins.c:4588
+#, gcc-internal-format
+msgid "invalid argument to %<__builtin_return_address%>"
+msgstr "некоректний аргумент %<__builtin_return_address%>"
+
+#: builtins.c:4601
+#, gcc-internal-format
+msgid "unsupported argument to %<__builtin_frame_address%>"
+msgstr ""
+
+#: builtins.c:4603
+#, gcc-internal-format
+msgid "unsupported argument to %<__builtin_return_address%>"
+msgstr ""
+
+#: builtins.c:4853
+#, gcc-internal-format
+msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
+msgstr ""
+
+#: builtins.c:4952
+#, gcc-internal-format
+msgid "trampoline generated for nested function %qD"
+msgstr ""
+
+#: builtins.c:5248 builtins.c:5261
+#, gcc-internal-format
+msgid "%qD changed semantics in GCC 4.4"
+msgstr ""
+
+#: builtins.c:5365
+#, gcc-internal-format
+msgid "Unknown architecture specifier in memory model to builtin."
+msgstr ""
+
+#: builtins.c:5372
+#, gcc-internal-format
+msgid "invalid memory model argument to builtin"
+msgstr ""
+
+#: builtins.c:5431
+#, gcc-internal-format
+msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
+msgstr ""
+
+#: builtins.c:5440
+#, gcc-internal-format
+msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
+msgstr ""
+
+#: builtins.c:5503
+#, gcc-internal-format
+msgid "invalid memory model for %<__atomic_load%>"
+msgstr ""
+
+#: builtins.c:5534 builtins.c:5643
+#, gcc-internal-format
+msgid "invalid memory model for %<__atomic_store%>"
+msgstr ""
+
+#: builtins.c:5752
+#, gcc-internal-format
+msgid "non-constant argument 1 to __atomic_always_lock_free"
+msgstr ""
+
+#: builtins.c:5794
+#, gcc-internal-format
+msgid "non-integer argument 1 to __atomic_is_lock_free"
+msgstr ""
+
+#: builtins.c:5858
+#, gcc-internal-format
+msgid "__builtin_thread_pointer is not supported on this target"
+msgstr ""
+
+#: builtins.c:5878
+#, gcc-internal-format
+msgid "__builtin_set_thread_pointer is not supported on this target"
+msgstr ""
+
+#. All valid uses of __builtin_va_arg_pack () are removed during
+#. inlining.
+#: builtins.c:6222 expr.c:10463
+#, gcc-internal-format
+msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
+msgstr ""
+
+#. All valid uses of __builtin_va_arg_pack_len () are removed during
+#. inlining.
+#: builtins.c:6228
+#, gcc-internal-format
+msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
+msgstr ""
+
+#: builtins.c:6447
+#, gcc-internal-format
+msgid "%<__builtin_longjmp%> second argument must be 1"
+msgstr ""
+
+#. Software implementation of Pointer Bounds Checker is NYI.
+#. Target support is required.
+#: builtins.c:7086
+#, gcc-internal-format
+msgid "Your target platform does not support -fcheck-pointer-bounds"
+msgstr ""
+
+#: builtins.c:7408
+#, gcc-internal-format
+msgid "target format does not support infinity"
+msgstr ""
+
+#: builtins.c:11228
+#, gcc-internal-format
+msgid "%<va_start%> used in function with fixed args"
+msgstr ""
+
+#: builtins.c:11236
+#, gcc-internal-format
+msgid "wrong number of arguments to function %<va_start%>"
+msgstr ""
+
+#: builtins.c:11251
+#, gcc-internal-format
+msgid "%<__builtin_next_arg%> called without an argument"
+msgstr ""
+
+#: builtins.c:11256
+#, gcc-internal-format
+msgid "wrong number of arguments to function %<__builtin_next_arg%>"
+msgstr ""
+
+#: builtins.c:11288
+#, gcc-internal-format
+msgid "second parameter of %<va_start%> not last named argument"
+msgstr ""
+
+#: builtins.c:11301
+#, gcc-internal-format
+msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
+msgstr ""
+
+#: builtins.c:11330
+#, gcc-internal-format
+msgid "%Kfirst argument of %D must be a pointer, second integer constant"
+msgstr ""
+
+#: builtins.c:11343
+#, gcc-internal-format
+msgid "%Klast argument of %D is not integer constant between 0 and 3"
+msgstr ""
+
+#: builtins.c:11388 builtins.c:11539 builtins.c:11596
+#, gcc-internal-format
+msgid "%Kcall to %D will always overflow destination buffer"
+msgstr ""
+
+#: builtins.c:11529
+#, gcc-internal-format
+msgid "%Kcall to %D might overflow destination buffer"
+msgstr ""
+
+#: builtins.c:11617
+#, gcc-internal-format
+msgid "%Kattempt to free a non-heap object %qD"
+msgstr ""
+
+#: builtins.c:11620
+#, gcc-internal-format
+msgid "%Kattempt to free a non-heap object"
+msgstr ""
+
+#: calls.c:2503
+#, gcc-internal-format
+msgid "function call has aggregate value"
+msgstr ""
+
+#: calls.c:3195
+#, gcc-internal-format
+msgid "passing too large argument on stack"
+msgstr ""
+
+#: cfgexpand.c:1376 function.c:1002 varasm.c:2163
+#, gcc-internal-format
+msgid "size of variable %q+D is too large"
+msgstr ""
+
+#: cfgexpand.c:2452
+#, gcc-internal-format
+msgid "too many alternatives in %<asm%>"
+msgstr ""
+
+#: cfgexpand.c:2464
+#, gcc-internal-format
+msgid "operand constraints for %<asm%> differ in number of alternatives"
+msgstr ""
+
+#: cfgexpand.c:2492
+#, gcc-internal-format
+msgid "asm-specifier for variable %qE conflicts with asm clobber list"
+msgstr ""
+
+#: cfgexpand.c:2589
+#, gcc-internal-format
+msgid "unknown register name %qs in %<asm%>"
+msgstr ""
+
+#: cfgexpand.c:2603
+#, gcc-internal-format
+msgid "PIC register clobbered by %qs in %<asm%>"
+msgstr ""
+
+#: cfgexpand.c:2651
+#, gcc-internal-format
+msgid "more than %d operands in %<asm%>"
+msgstr ""
+
+#: cfgexpand.c:2719
+#, gcc-internal-format, gfc-internal-format
+msgid "output number %d not directly addressable"
+msgstr ""
+
+#: cfgexpand.c:2805
+#, gcc-internal-format
+msgid "asm operand %d probably doesn%'t match constraints"
+msgstr ""
+
+#: cfgexpand.c:2970
+#, gcc-internal-format
+msgid "asm clobber conflict with output operand"
+msgstr ""
+
+#: cfgexpand.c:2977
+#, gcc-internal-format
+msgid "asm clobber conflict with input operand"
+msgstr ""
+
+#: cfgexpand.c:6011
+#, gcc-internal-format
+msgid "stack protector not protecting local variables: variable length buffer"
+msgstr ""
+
+#: cfgexpand.c:6015
+#, gcc-internal-format, gfc-internal-format
+msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
+msgstr ""
+
+#: cfghooks.c:131
+#, gcc-internal-format, gfc-internal-format
+msgid "bb %d on wrong place"
+msgstr ""
+
+#: cfghooks.c:137
+#, gcc-internal-format, gfc-internal-format
+msgid "prev_bb of %d should be %d, not %d"
+msgstr ""
+
+#: cfghooks.c:154
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Block %i has loop_father, but there are no loops"
+msgstr ""
+
+#: cfghooks.c:160
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Block %i lacks loop_father"
+msgstr ""
+
+#: cfghooks.c:166
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Wrong count of block %i %i"
+msgstr ""
+
+#: cfghooks.c:172
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Wrong frequency of block %i %i"
+msgstr ""
+
+#: cfghooks.c:180
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Duplicate edge %i->%i"
+msgstr ""
+
+#: cfghooks.c:186
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Wrong probability of edge %i->%i %i"
+msgstr ""
+
+#: cfghooks.c:192
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Wrong count of edge %i->%i %i"
+msgstr ""
+
+#: cfghooks.c:204
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Basic block %d succ edge is corrupted"
+msgstr ""
+
+#: cfghooks.c:218
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong amount of branch edges after unconditional jump %i"
+msgstr ""
+
+#: cfghooks.c:226 cfghooks.c:237
+#, gcc-internal-format, gfc-internal-format
+msgid "basic block %d pred edge is corrupted"
+msgstr ""
+
+#: cfghooks.c:238
+#, gcc-internal-format, gfc-internal-format
+msgid "its dest_idx should be %d, not %d"
+msgstr ""
+
+#: cfghooks.c:267
+#, gcc-internal-format, gfc-internal-format
+msgid "basic block %i edge lists are corrupted"
+msgstr ""
+
+#: cfghooks.c:280
+#, gcc-internal-format
+msgid "verify_flow_info failed"
+msgstr ""
+
+#: cfghooks.c:330
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support dump_bb_for_graph"
+msgstr ""
+
+#: cfghooks.c:373
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support redirect_edge_and_branch"
+msgstr ""
+
+#: cfghooks.c:393
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support can_remove_branch_p"
+msgstr ""
+
+#: cfghooks.c:477
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support redirect_edge_and_branch_force"
+msgstr ""
+
+#: cfghooks.c:515
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support split_block"
+msgstr ""
+
+#: cfghooks.c:570
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support move_block_after"
+msgstr ""
+
+#: cfghooks.c:583
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support delete_basic_block"
+msgstr ""
+
+#: cfghooks.c:630
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support split_edge"
+msgstr ""
+
+#: cfghooks.c:705
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support create_basic_block"
+msgstr ""
+
+#: cfghooks.c:733
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support can_merge_blocks_p"
+msgstr ""
+
+#: cfghooks.c:744
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support predict_edge"
+msgstr ""
+
+#: cfghooks.c:753
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support predicted_by_p"
+msgstr ""
+
+#: cfghooks.c:767
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support merge_blocks"
+msgstr ""
+
+#: cfghooks.c:848
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support make_forwarder_block"
+msgstr ""
+
+#: cfghooks.c:1004
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support force_nonfallthru"
+msgstr ""
+
+#: cfghooks.c:1032
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support can_duplicate_block_p"
+msgstr ""
+
+#: cfghooks.c:1054
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support duplicate_block"
+msgstr ""
+
+#: cfghooks.c:1148
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support block_ends_with_call_p"
+msgstr ""
+
+#: cfghooks.c:1159
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support block_ends_with_condjump_p"
+msgstr ""
+
+#: cfghooks.c:1177
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support flow_call_edges_add"
+msgstr ""
+
+#: cfgloop.c:1340
+#, gcc-internal-format
+msgid "loop verification on loop tree that needs fixup"
+msgstr ""
+
+#: cfgloop.c:1356
+#, gcc-internal-format, gfc-internal-format
+msgid "loop with header %d marked for removal"
+msgstr ""
+
+#: cfgloop.c:1361
+#, gcc-internal-format, gfc-internal-format
+msgid "loop with header %d not in loop tree"
+msgstr ""
+
+#: cfgloop.c:1367
+#, gcc-internal-format, gfc-internal-format
+msgid "non-loop with header %d not marked for removal"
+msgstr ""
+
+#: cfgloop.c:1381
+#, gcc-internal-format, gfc-internal-format
+msgid "removed loop %d in loop tree"
+msgstr ""
+
+#: cfgloop.c:1389
+#, gcc-internal-format, gfc-internal-format
+msgid "size of loop %d should be %d, not %d"
+msgstr ""
+
+#: cfgloop.c:1400
+#, gcc-internal-format, gfc-internal-format
+msgid "bb %d does not belong to loop %d"
+msgstr ""
+
+#: cfgloop.c:1412
+#, gcc-internal-format, gfc-internal-format
+msgid "bb %d has father loop %d, should be loop %d"
+msgstr ""
+
+#: cfgloop.c:1429
+#, gcc-internal-format
+msgid "loop %d%'s header is not a loop header"
+msgstr ""
+
+#: cfgloop.c:1435
+#, gcc-internal-format
+msgid "loop %d%'s header does not have exactly 2 entries"
+msgstr ""
+
+#: cfgloop.c:1442
+#, gcc-internal-format
+msgid "loop %d%'s latch does not have an edge to its header"
+msgstr ""
+
+#: cfgloop.c:1447
+#, gcc-internal-format
+msgid "loop %d%'s latch is not dominated by its header"
+msgstr ""
+
+#: cfgloop.c:1455
+#, gcc-internal-format
+msgid "loop %d%'s latch does not have exactly 1 successor"
+msgstr ""
+
+#: cfgloop.c:1460
+#, gcc-internal-format
+msgid "loop %d%'s latch does not have header as successor"
+msgstr ""
+
+#: cfgloop.c:1465
+#, gcc-internal-format
+msgid "loop %d%'s latch does not belong directly to it"
+msgstr ""
+
+#: cfgloop.c:1471
+#, gcc-internal-format
+msgid "loop %d%'s header does not belong directly to it"
+msgstr ""
+
+#: cfgloop.c:1477
+#, gcc-internal-format
+msgid "loop %d%'s latch is marked as part of irreducible region"
+msgstr ""
+
+#: cfgloop.c:1510
+#, gcc-internal-format, gfc-internal-format
+msgid "basic block %d should be marked irreducible"
+msgstr ""
+
+#: cfgloop.c:1516
+#, gcc-internal-format, gfc-internal-format
+msgid "basic block %d should not be marked irreducible"
+msgstr ""
+
+#: cfgloop.c:1524
+#, gcc-internal-format, gfc-internal-format
+msgid "edge from %d to %d should be marked irreducible"
+msgstr ""
+
+#: cfgloop.c:1531
+#, gcc-internal-format, gfc-internal-format
+msgid "edge from %d to %d should not be marked irreducible"
+msgstr ""
+
+#: cfgloop.c:1546
+#, gcc-internal-format, gfc-internal-format
+msgid "corrupted head of the exits list of loop %d"
+msgstr ""
+
+#: cfgloop.c:1564
+#, gcc-internal-format, gfc-internal-format
+msgid "corrupted exits list of loop %d"
+msgstr ""
+
+#: cfgloop.c:1573
+#, gcc-internal-format, gfc-internal-format
+msgid "nonempty exits list of loop %d, but exits are not recorded"
+msgstr ""
+
+#: cfgloop.c:1600
+#, gcc-internal-format, gfc-internal-format
+msgid "exit %d->%d not recorded"
+msgstr ""
+
+#: cfgloop.c:1623
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong list of exited loops for edge  %d->%d"
+msgstr ""
+
+#: cfgloop.c:1632
+#, gcc-internal-format
+msgid "too many loop exits recorded"
+msgstr ""
+
+#: cfgloop.c:1643
+#, gcc-internal-format, gfc-internal-format
+msgid "%d exits recorded for loop %d (having %d exits)"
+msgstr ""
+
+#: cfgrtl.c:2370
+#, gcc-internal-format, gfc-internal-format
+msgid "non-cold basic block %d dominated by a block in the cold partition (%d)"
+msgstr ""
+
+#: cfgrtl.c:2447
+#, gcc-internal-format, gfc-internal-format
+msgid "multiple hot/cold transitions found (bb %i)"
+msgstr ""
+
+#: cfgrtl.c:2455
+#, gcc-internal-format
+msgid "partition found but function partition flag not set"
+msgstr ""
+
+#: cfgrtl.c:2493
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: REG_BR_PROB does not match cfg %i %i"
+msgstr ""
+
+#: cfgrtl.c:2514
+#, gcc-internal-format
+msgid "EDGE_CROSSING incorrectly set across same section"
+msgstr ""
+
+#: cfgrtl.c:2519
+#, gcc-internal-format, gfc-internal-format
+msgid "fallthru edge crosses section boundary in bb %i"
+msgstr ""
+
+#: cfgrtl.c:2525
+#, gcc-internal-format, gfc-internal-format
+msgid "EH edge crosses section boundary in bb %i"
+msgstr ""
+
+#: cfgrtl.c:2531
+#, gcc-internal-format, gfc-internal-format
+msgid "No region crossing jump at section boundary in bb %i"
+msgstr ""
+
+#: cfgrtl.c:2538
+#, gcc-internal-format
+msgid "EDGE_CROSSING missing across section boundary"
+msgstr ""
+
+#: cfgrtl.c:2568
+#, gcc-internal-format, gfc-internal-format
+msgid "Region crossing jump across same section in bb %i"
+msgstr ""
+
+#: cfgrtl.c:2575
+#, gcc-internal-format, gfc-internal-format
+msgid "missing REG_EH_REGION note at the end of bb %i"
+msgstr ""
+
+#: cfgrtl.c:2580
+#, gcc-internal-format, gfc-internal-format
+msgid "too many exception handling edges in bb %i"
+msgstr ""
+
+#: cfgrtl.c:2588
+#, gcc-internal-format, gfc-internal-format
+msgid "too many outgoing branch edges from bb %i"
+msgstr ""
+
+#: cfgrtl.c:2593
+#, gcc-internal-format, gfc-internal-format
+msgid "fallthru edge after unconditional jump in bb %i"
+msgstr ""
+
+#: cfgrtl.c:2598
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong number of branch edges after unconditional jump in bb %i"
+msgstr ""
+
+#: cfgrtl.c:2605
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong amount of branch edges after conditional jump in bb %i"
+msgstr ""
+
+#: cfgrtl.c:2611
+#, gcc-internal-format, gfc-internal-format
+msgid "abnormal call edges for non-call insn in bb %i"
+msgstr ""
+
+#: cfgrtl.c:2616
+#, gcc-internal-format, gfc-internal-format
+msgid "sibcall edges for non-call insn in bb %i"
+msgstr ""
+
+#: cfgrtl.c:2626
+#, gcc-internal-format, gfc-internal-format
+msgid "abnormal edges for no purpose in bb %i"
+msgstr ""
+
+#: cfgrtl.c:2664 cfgrtl.c:2674
+#, gcc-internal-format, gfc-internal-format
+msgid "NOTE_INSN_BASIC_BLOCK is missing for block %d"
+msgstr ""
+
+#: cfgrtl.c:2687
+#, gcc-internal-format, gfc-internal-format
+msgid "NOTE_INSN_BASIC_BLOCK %d in middle of basic block %d"
+msgstr ""
+
+#: cfgrtl.c:2697
+#, gcc-internal-format, gfc-internal-format
+msgid "in basic block %d:"
+msgstr ""
+
+#: cfgrtl.c:2723
+#, gcc-internal-format, gfc-internal-format
+msgid "BB_RTL flag not set for block %d"
+msgstr ""
+
+#: cfgrtl.c:2730
+#, gcc-internal-format, gfc-internal-format
+msgid "insn %d basic block pointer is %d, should be %d"
+msgstr ""
+
+#: cfgrtl.c:2741
+#, gcc-internal-format, gfc-internal-format
+msgid "insn %d in header of bb %d has non-NULL basic block"
+msgstr ""
+
+#: cfgrtl.c:2749
+#, gcc-internal-format, gfc-internal-format
+msgid "insn %d in footer of bb %d has non-NULL basic block"
+msgstr ""
+
+#: cfgrtl.c:2822 cfgrtl.c:2870
+#, gcc-internal-format, gfc-internal-format
+msgid "insn %d outside of basic blocks has non-NULL bb field"
+msgstr ""
+
+#: cfgrtl.c:2830
+#, gcc-internal-format, gfc-internal-format
+msgid "end insn %d for block %d not found in the insn stream"
+msgstr ""
+
+#: cfgrtl.c:2843
+#, gcc-internal-format, gfc-internal-format
+msgid "insn %d is in multiple basic blocks (%d and %d)"
+msgstr ""
+
+#: cfgrtl.c:2855
+#, gcc-internal-format, gfc-internal-format
+msgid "head insn %d for block %d not found in the insn stream"
+msgstr ""
+
+#: cfgrtl.c:2903
+#, gcc-internal-format, gfc-internal-format
+msgid "missing barrier after block %i"
+msgstr ""
+
+#: cfgrtl.c:2919
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Incorrect blocks for fallthru %i->%i"
+msgstr ""
+
+#: cfgrtl.c:2928
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Incorrect fallthru %i->%i"
+msgstr ""
+
+#: cfgrtl.c:2964
+#, gcc-internal-format
+msgid "basic blocks not laid down consecutively"
+msgstr ""
+
+#: cfgrtl.c:3002
+#, gcc-internal-format, gfc-internal-format
+msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
+msgstr ""
+
+#: cgraph.c:2675
+#, gcc-internal-format
+msgid "caller edge count is negative"
+msgstr ""
+
+#: cgraph.c:2680
+#, gcc-internal-format
+msgid "caller edge frequency is negative"
+msgstr ""
+
+#: cgraph.c:2685
+#, gcc-internal-format
+msgid "caller edge frequency is too large"
+msgstr ""
+
+#: cgraph.c:2769
+#, gcc-internal-format, gfc-internal-format
+msgid "aux field set for edge %s->%s"
+msgstr ""
+
+#: cgraph.c:2776
+#, gcc-internal-format
+msgid "execution count is negative"
+msgstr ""
+
+#: cgraph.c:2781
+#, gcc-internal-format
+msgid "inline clone in same comdat group list"
+msgstr ""
+
+#: cgraph.c:2786
+#, gcc-internal-format
+msgid "local symbols must be defined"
+msgstr ""
+
+#: cgraph.c:2791
+#, gcc-internal-format
+msgid "externally visible inline clone"
+msgstr ""
+
+#: cgraph.c:2796
+#, gcc-internal-format
+msgid "inline clone with address taken"
+msgstr ""
+
+#: cgraph.c:2801
+#, gcc-internal-format
+msgid "inline clone is forced to output"
+msgstr ""
+
+#: cgraph.c:2808
+#, gcc-internal-format, gfc-internal-format
+msgid "aux field set for indirect edge from %s"
+msgstr ""
+
+#: cgraph.c:2815
+#, gcc-internal-format, gfc-internal-format
+msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
+msgstr ""
+
+#: cgraph.c:2830
+#, gcc-internal-format, gfc-internal-format
+msgid "comdat-local function called by %s outside its comdat"
+msgstr ""
+
+#: cgraph.c:2840
+#, gcc-internal-format
+msgid "inlined_to pointer is wrong"
+msgstr ""
+
+#: cgraph.c:2845
+#, gcc-internal-format
+msgid "multiple inline callers"
+msgstr ""
+
+#: cgraph.c:2852
+#, gcc-internal-format
+msgid "inlined_to pointer set for noninline callers"
+msgstr ""
+
+#: cgraph.c:2871
+#, gcc-internal-format, gfc-internal-format
+msgid "caller edge frequency %i does not match BB frequency %i"
+msgstr ""
+
+#: cgraph.c:2889
+#, gcc-internal-format, gfc-internal-format
+msgid "indirect call frequency %i does not match BB frequency %i"
+msgstr ""
+
+#: cgraph.c:2898
+#, gcc-internal-format
+msgid "inlined_to pointer is set but no predecessors found"
+msgstr ""
+
+#: cgraph.c:2903
+#, gcc-internal-format
+msgid "inlined_to pointer refers to itself"
+msgstr ""
+
+#: cgraph.c:2915
+#, gcc-internal-format
+msgid "cgraph_node has wrong clone_of"
+msgstr ""
+
+#: cgraph.c:2927
+#, gcc-internal-format
+msgid "cgraph_node has wrong clone list"
+msgstr ""
+
+#: cgraph.c:2933
+#, gcc-internal-format
+msgid "cgraph_node is in clone list but it is not clone"
+msgstr ""
+
+#: cgraph.c:2938
+#, gcc-internal-format
+msgid "cgraph_node has wrong prev_clone pointer"
+msgstr ""
+
+#: cgraph.c:2943
+#, gcc-internal-format
+msgid "double linked list of clones corrupted"
+msgstr ""
+
+#: cgraph.c:2955
+#, gcc-internal-format
+msgid "Alias has call edges"
+msgstr ""
+
+#: cgraph.c:2963
+#, gcc-internal-format
+msgid "Alias has non-alias reference"
+msgstr ""
+
+#: cgraph.c:2968
+#, gcc-internal-format
+msgid "Alias has more than one alias reference"
+msgstr ""
+
+#: cgraph.c:2975
+#, gcc-internal-format
+msgid "Analyzed alias has no reference"
+msgstr ""
+
+#: cgraph.c:2984
+#, gcc-internal-format
+msgid "Instrumentation clone does not reference original node"
+msgstr ""
+
+#: cgraph.c:2991
+#, gcc-internal-format
+msgid "Not instrumented node has non-NULL original declaration"
+msgstr ""
+
+#: cgraph.c:3001
+#, gcc-internal-format
+msgid "Instrumented node has wrong original declaration"
+msgstr ""
+
+#: cgraph.c:3019
+#, gcc-internal-format
+msgid "Node has more than one chkp reference"
+msgstr ""
+
+#: cgraph.c:3024
+#, gcc-internal-format
+msgid "Wrong node is referenced with chkp reference"
+msgstr ""
+
+#: cgraph.c:3032
+#, gcc-internal-format
+msgid "Analyzed node has no reference to instrumented version"
+msgstr ""
+
+#: cgraph.c:3046
+#, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
+msgid "No edge out of thunk node"
+msgstr ""
+
+#: cgraph.c:3060
+#, gcc-internal-format
+msgid "More than one edge out of thunk node"
+msgstr ""
+
+#: cgraph.c:3065
+#, gcc-internal-format
+msgid "Thunk is not supposed to have body"
+msgstr ""
+
+#: cgraph.c:3071
+#, gcc-internal-format
+msgid "Instrumentation thunk has wrong edge callee"
+msgstr ""
+
+#: cgraph.c:3107
+#, gcc-internal-format
+msgid "shared call_stmt:"
+msgstr ""
+
+#: cgraph.c:3115
+#, gcc-internal-format
+msgid "edge points to wrong declaration:"
+msgstr ""
+
+#: cgraph.c:3124
+#, gcc-internal-format
+msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
+msgstr ""
+
+#: cgraph.c:3134
+#, gcc-internal-format
+msgid "missing callgraph edge for call stmt:"
+msgstr ""
+
+#: cgraph.c:3144
+#, gcc-internal-format
+msgid "reference to dead statement"
+msgstr ""
+
+#: cgraph.c:3157
+#, gcc-internal-format, gfc-internal-format
+msgid "edge %s->%s has no corresponding call_stmt"
+msgstr ""
+
+#: cgraph.c:3169
+#, gcc-internal-format, gfc-internal-format
+msgid "an indirect edge from %s has no corresponding call_stmt"
+msgstr ""
+
+#: cgraph.c:3180
+#, gcc-internal-format
+msgid "verify_cgraph_node failed"
+msgstr ""
+
+#: cgraph.c:3275 varpool.c:326
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: section %s is missing"
+msgstr ""
+
+#: cgraphunit.c:689
+#, gcc-internal-format
+msgid "%<weakref%> attribute should be accompanied with an %<alias%> attribute"
+msgstr ""
+
+#: cgraphunit.c:741 cgraphunit.c:777
+#, gcc-internal-format
+msgid "%<externally_visible%> attribute have effect only on public objects"
+msgstr ""
+
+#: cgraphunit.c:748
+#, gcc-internal-format
+msgid "%<weakref%> attribute ignored because function is defined"
+msgstr ""
+
+#: cgraphunit.c:760
+#, gcc-internal-format
+msgid "always_inline function might not be inlinable"
+msgstr ""
+
+#: cgraphunit.c:785
+#, gcc-internal-format
+msgid "%<weakref%> attribute ignored because variable is initialized"
+msgstr ""
+
+#: cgraphunit.c:1187 c-family/c-pragma.c:362
+#, gcc-internal-format
+msgid "%q+D aliased to undefined symbol %qE"
+msgstr ""
+
+#: cgraphunit.c:1203
+#, gcc-internal-format
+msgid "%q+D aliased to external symbol %qE"
+msgstr ""
+
+#: cgraphunit.c:1224
+#, gcc-internal-format
+msgid "%q+D alias in between function and variable is not supported"
+msgstr ""
+
+#: cgraphunit.c:1226
+#, gcc-internal-format
+msgid "%q+D aliased declaration"
+msgstr ""
+
+#: cgraphunit.c:1299
+#, gcc-internal-format
+msgid "failed to reclaim unneeded function"
+msgstr ""
+
+#: cgraphunit.c:1329
+#, gcc-internal-format
+msgid "failed to reclaim unneeded function in same comdat group"
+msgstr ""
+
+#: cgraphunit.c:1572
+#, gcc-internal-format
+msgid "generic thunk code fails for method %qD which uses %<...%>"
+msgstr ""
+
+#: cgraphunit.c:1921
+#, gcc-internal-format
+msgid "size of return value of %q+D is %u bytes"
+msgstr ""
+
+#: cgraphunit.c:1924
+#, gcc-internal-format
+msgid "size of return value of %q+D is larger than %wd bytes"
+msgstr ""
+
+#: cgraphunit.c:2414
+#, gcc-internal-format
+msgid "nodes with unreleased memory found"
+msgstr ""
+
+#: collect-utils.c:68
+#, gcc-internal-format
+msgid "can't get program status: %m"
+msgstr ""
+
+#: collect-utils.c:76
+#, gcc-internal-format, gfc-internal-format
+msgid "%s terminated with signal %d [%s]%s"
+msgstr ""
+
+#: collect-utils.c:92
+#, gcc-internal-format, gfc-internal-format
+msgid "%s returned %d exit status"
+msgstr ""
+
+#: collect-utils.c:133
+#, gcc-internal-format, gfc-internal-format
+msgid "could not open response file %s"
+msgstr ""
+
+#: collect-utils.c:139
+#, gcc-internal-format, gfc-internal-format
+msgid "could not write to response file %s"
+msgstr ""
+
+#: collect-utils.c:145
+#, gcc-internal-format, gfc-internal-format
+msgid "could not close response file %s"
+msgstr ""
+
+#: collect-utils.c:179
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot find '%s'"
+msgstr "не вдалося знайти «%s»"
+
+#: collect-utils.c:183 collect2.c:2350 collect2.c:2549 gcc.c:2860 gcc.c:6483
+#, gcc-internal-format
+msgid "pex_init failed: %m"
+msgstr ""
+
+#: collect-utils.c:192 collect2.c:2359 collect2.c:2557 gcc.c:7986
+#, gcc-internal-format
+msgid "%s: %m"
+msgstr ""
+
+#: collect2.c:702
+#, gcc-internal-format
+msgid "COLLECT_LTO_WRAPPER must be set"
+msgstr ""
+
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
+#: config/i386/intelmic-mkoffload.c:504
+#, gcc-internal-format
+msgid "atexit failed"
+msgstr ""
+
+#: collect2.c:1064
+#, gcc-internal-format
+msgid "no arguments"
+msgstr "немає аргументів"
+
+#: collect2.c:1303 opts.c:840
+#, gcc-internal-format
+msgid "LTO support has not been enabled in this configuration"
+msgstr ""
+
+#: collect2.c:1344
+#, gcc-internal-format
+msgid "can't open %s: %m"
+msgstr ""
+
+#: collect2.c:1450
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown demangling style '%s'"
+msgstr "невідомий стиль декодування '%s'"
+
+#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#, gcc-internal-format
+msgid "fopen %s: %m"
+msgstr ""
+
+#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#, gcc-internal-format
+msgid "fclose %s: %m"
+msgstr ""
+
+#: collect2.c:2324
+#, gcc-internal-format
+msgid "cannot find 'nm'"
+msgstr ""
+
+#: collect2.c:2372
+#, gcc-internal-format
+msgid "can't open nm output: %m"
+msgstr ""
+
+#: collect2.c:2456
+#, gcc-internal-format, gfc-internal-format
+msgid "init function found in object %s"
+msgstr ""
+
+#: collect2.c:2467
+#, gcc-internal-format, gfc-internal-format
+msgid "fini function found in object %s"
+msgstr ""
+
+#: collect2.c:2524
+#, gcc-internal-format
+msgid "cannot find 'ldd'"
+msgstr ""
+
+#: collect2.c:2570
+#, gcc-internal-format
+msgid "can't open ldd output: %m"
+msgstr ""
+
+#: collect2.c:2588
+#, gcc-internal-format, gfc-internal-format
+msgid "dynamic dependency %s not found"
+msgstr ""
+
+#: collect2.c:2600
+#, gcc-internal-format, gfc-internal-format
+msgid "unable to open dynamic dependency '%s'"
+msgstr ""
+
+#: collect2.c:2764
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: not a COFF file"
+msgstr ""
+
+#: collect2.c:2913
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: cannot open as COFF file"
+msgstr ""
+
+#: collect2.c:2972
+#, gcc-internal-format, gfc-internal-format
+msgid "library lib%s not found"
+msgstr ""
+
+#: convert.c:97
+#, gcc-internal-format
+msgid "cannot convert to a pointer type"
+msgstr ""
+
+#: convert.c:396
+#, gcc-internal-format
+msgid "pointer value used where a floating point value was expected"
+msgstr ""
+
+#: convert.c:400
+#, gcc-internal-format
+msgid "aggregate value used where a float was expected"
+msgstr ""
+
+#: convert.c:426
+#, gcc-internal-format
+msgid "conversion to incomplete type"
+msgstr ""
+
+#: convert.c:923 convert.c:1007
+#, gcc-internal-format
+msgid "can%'t convert between vector values of different size"
+msgstr ""
+
+#: convert.c:929
+#, gcc-internal-format
+msgid "aggregate value used where an integer was expected"
+msgstr ""
+
+#: convert.c:987
+#, gcc-internal-format
+msgid "pointer value used where a complex was expected"
+msgstr ""
+
+#: convert.c:991
+#, gcc-internal-format
+msgid "aggregate value used where a complex was expected"
+msgstr ""
+
+#: convert.c:1013
+#, gcc-internal-format
+msgid "can%'t convert value to a vector"
+msgstr ""
+
+#: convert.c:1052
+#, gcc-internal-format
+msgid "aggregate value used where a fixed-point was expected"
+msgstr ""
+
+#: coverage.c:240
+#, gcc-internal-format
+msgid "%qs is not a gcov data file"
+msgstr ""
+
+#: coverage.c:251
+#, gcc-internal-format
+msgid "%qs is version %q.*s, expected version %q.*s"
+msgstr ""
+
+#: coverage.c:333 coverage.c:343
+#, gcc-internal-format, gfc-internal-format
+msgid "Profile data for function %u is corrupted"
+msgstr ""
+
+#: coverage.c:334
+#, gcc-internal-format
+msgid "checksum is (%x,%x) instead of (%x,%x)"
+msgstr ""
+
+#: coverage.c:344
+#, gcc-internal-format, gfc-internal-format
+msgid "number of counters is %d instead of %d"
+msgstr ""
+
+#: coverage.c:351
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot merge separate %s counters for function %u"
+msgstr ""
+
+#: coverage.c:370
+#, gcc-internal-format
+msgid "%qs has overflowed"
+msgstr ""
+
+#: coverage.c:428
+#, gcc-internal-format
+msgid "the control flow of function %qE does not match its profile data (counter %qs)"
+msgstr ""
+
+#: coverage.c:444
+#, gcc-internal-format
+msgid "execution counts estimated\n"
+msgstr ""
+
+#: coverage.c:445
+#, gcc-internal-format
+msgid "execution counts assumed to be zero\n"
+msgstr ""
+
+#: coverage.c:457
+#, gcc-internal-format
+msgid "source locations for function %qE have changed, the profile data may be out of date"
+msgstr ""
+
+#: coverage.c:719
+#, gcc-internal-format
+msgid "error writing %qs"
+msgstr ""
+
+#: coverage.c:1256
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot open %s"
+msgstr "не вдалося відкрити %s"
+
+#: cprop.c:1760 gcse.c:4009
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: %d basic blocks and %d edges/basic block"
+msgstr ""
+
+#: cprop.c:1774 gcse.c:4023
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: %d basic blocks and %d registers"
+msgstr ""
+
+#: data-streamer-in.c:78
+#, gcc-internal-format
+msgid "bytecode stream: string too long for the string table"
+msgstr ""
+
+#: data-streamer-in.c:109 data-streamer-in.c:138
+#, gcc-internal-format
+msgid "bytecode stream: found non-null terminated string"
+msgstr ""
+
+#: dbgcnt.c:133
+#, gcc-internal-format
+msgid "cannot find a valid counter:value pair:"
+msgstr ""
+
+#: dbgcnt.c:134
+#, gcc-internal-format, gfc-internal-format
+msgid "-fdbg-cnt=%s"
+msgstr ""
+
+#: dbgcnt.c:135
+#, gcc-internal-format, gfc-internal-format
+msgid "          %s"
+msgstr "          %s"
+
+#: dbxout.c:3346
+#, gcc-internal-format
+msgid "common symbol debug info is not structured as symbol+offset"
+msgstr ""
+
+#: dbxout.c:3818
+#, gcc-internal-format
+msgid "global destructors not supported on this target"
+msgstr ""
+
+#: dbxout.c:3835
+#, gcc-internal-format
+msgid "global constructors not supported on this target"
+msgstr ""
+
+#: diagnostic.c:1291
+#, gcc-internal-format, gfc-internal-format
+msgid "in %s, at %s:%d"
+msgstr ""
+
+#: dominance.c:1049
+#, gcc-internal-format, gfc-internal-format
+msgid "dominator of %d status unknown"
+msgstr ""
+
+#: dominance.c:1056
+#, gcc-internal-format, gfc-internal-format
+msgid "dominator of %d should be %d, not %d"
+msgstr ""
+
+#: dumpfile.c:326 dumpfile.c:490 dumpfile.c:583
+#, gcc-internal-format
+msgid "could not open dump file %qs: %m"
+msgstr ""
+
+#: dumpfile.c:825
+#, gcc-internal-format
+msgid "ignoring unknown option %q.*s in %<-fdump-%s%>"
+msgstr ""
+
+#: dumpfile.c:933
+#, gcc-internal-format
+msgid "unknown option %q.*s in %<-fopt-info-%s%>"
+msgstr ""
+
+#: dumpfile.c:965
+#, gcc-internal-format
+msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
+msgstr ""
+
+#: dwarf2out.c:1113
+#, gcc-internal-format
+msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
+msgstr ""
+
+#: dwarf2out.c:11638
+#, gcc-internal-format, gfc-internal-format
+msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
+msgstr ""
+
+#: dwarf2out.c:22674
+#, gcc-internal-format
+msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
+msgstr ""
+
+#: emit-rtl.c:2732
+#, gcc-internal-format
+msgid "invalid rtl sharing found in the insn"
+msgstr ""
+
+#: emit-rtl.c:2734
+#, gcc-internal-format
+msgid "shared rtx"
+msgstr ""
+
+#: emit-rtl.c:2736
+#, gcc-internal-format
+msgid "internal consistency failure"
+msgstr ""
+
+#: emit-rtl.c:3868
+#, gcc-internal-format
+msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
+msgstr ""
+
+#: errors.c:133
+#, gcc-internal-format, gfc-internal-format
+msgid "abort in %s, at %s:%d"
+msgstr ""
+
+#: except.c:2156
+#, gcc-internal-format
+msgid "argument of %<__builtin_eh_return_regno%> must be constant"
+msgstr ""
+
+#: except.c:2293
+#, gcc-internal-format
+msgid "__builtin_eh_return not supported on this target"
+msgstr ""
+
+#: except.c:3350 except.c:3375
+#, gcc-internal-format, gfc-internal-format
+msgid "region_array is corrupted for region %i"
+msgstr ""
+
+#: except.c:3363 except.c:3394
+#, gcc-internal-format, gfc-internal-format
+msgid "lp_array is corrupted for lp %i"
+msgstr ""
+
+#: except.c:3380
+#, gcc-internal-format, gfc-internal-format
+msgid "outer block of region %i is wrong"
+msgstr ""
+
+#: except.c:3385
+#, gcc-internal-format, gfc-internal-format
+msgid "negative nesting depth of region %i"
+msgstr ""
+
+#: except.c:3399
+#, gcc-internal-format, gfc-internal-format
+msgid "region of lp %i is wrong"
+msgstr ""
+
+#: except.c:3426
+#, gcc-internal-format, gfc-internal-format
+msgid "tree list ends on depth %i"
+msgstr ""
+
+#: except.c:3431
+#, gcc-internal-format
+msgid "region_array does not match region_tree"
+msgstr ""
+
+#: except.c:3436
+#, gcc-internal-format
+msgid "lp_array does not match region_tree"
+msgstr ""
+
+#: except.c:3443
+#, gcc-internal-format
+msgid "verify_eh_tree failed"
+msgstr ""
+
+#: explow.c:1427
+#, gcc-internal-format
+msgid "stack limits not supported on this target"
+msgstr ""
+
+#: expmed.c:573
+#, gcc-internal-format
+msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
+msgstr ""
+
+#: expr.c:7732
+#, gcc-internal-format
+msgid "local frame unavailable (naked function?)"
+msgstr ""
+
+#: expr.c:10470
+#, gcc-internal-format
+msgid "%Kcall to %qs declared with attribute error: %s"
+msgstr ""
+
+#: expr.c:10477
+#, gcc-internal-format
+msgid "%Kcall to %qs declared with attribute warning: %s"
+msgstr ""
+
+#: final.c:1570
+#, gcc-internal-format
+msgid "invalid argument %qs to -fdebug-prefix-map"
+msgstr ""
+
+#: final.c:1876
+#, gcc-internal-format
+msgid "the frame size of %wd bytes is larger than %wd bytes"
+msgstr ""
+
+#: final.c:4636 toplev.c:1481 tree-cfgcleanup.c:1120
+#, gcc-internal-format
+msgid "could not open final insn dump file %qs: %m"
+msgstr ""
+
+#: final.c:4689 tree-cfgcleanup.c:1136
+#, gcc-internal-format
+msgid "could not close final insn dump file %qs: %m"
+msgstr ""
+
+#: fixed-value.c:139
+#, gcc-internal-format
+msgid "large fixed-point constant implicitly truncated to fixed-point type"
+msgstr ""
+
+#: fold-const.c:697
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when negating a division"
+msgstr ""
+
+#: fold-const.c:3811 fold-const.c:3821
+#, gcc-internal-format, gfc-internal-format
+msgid "comparison is always %d due to width of bit-field"
+msgstr ""
+
+#: fold-const.c:5185 tree-ssa-reassoc.c:2144
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when simplifying range test"
+msgstr ""
+
+#: fold-const.c:5626 fold-const.c:5640
+#, gcc-internal-format, gfc-internal-format
+msgid "comparison is always %d"
+msgstr ""
+
+#: fold-const.c:5773
+#, gcc-internal-format
+msgid "%<or%> of unmatched not-equal tests is always 1"
+msgstr ""
+
+#: fold-const.c:5778
+#, gcc-internal-format
+msgid "%<and%> of mutually exclusive equal-tests is always 0"
+msgstr ""
+
+#: fold-const.c:8641
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when reducing constant in comparison"
+msgstr ""
+
+#: fold-const.c:8811
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when changing X +- C1 cmp C2 to X cmp C2 -+ C1"
+msgstr ""
+
+#: fold-const.c:8829
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when changing X - Y cmp 0 to X cmp Y"
+msgstr ""
+
+#: fold-const.c:9087
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when combining constants around a comparison"
+msgstr ""
+
+#: fold-const.c:14075
+#, gcc-internal-format
+msgid "fold check: original tree changed by fold"
+msgstr ""
+
+#: function.c:261
+#, gcc-internal-format
+msgid "total size of local objects too large"
+msgstr ""
+
+#: function.c:1774 gimplify.c:5192
+#, gcc-internal-format
+msgid "impossible constraint in %<asm%>"
+msgstr ""
+
+#: function.c:4266
+#, gcc-internal-format
+msgid "variable %q+D might be clobbered by %<longjmp%> or %<vfork%>"
+msgstr ""
+
+#: function.c:4287
+#, gcc-internal-format
+msgid "argument %q+D might be clobbered by %<longjmp%> or %<vfork%>"
+msgstr ""
+
+#: function.c:4900
+#, gcc-internal-format
+msgid "function returns an aggregate"
+msgstr ""
+
+#: function.c:5246
+#, gcc-internal-format
+msgid "unused parameter %q+D"
+msgstr ""
+
+#: gcc.c:1905 gcc.c:1926
+#, gcc-internal-format, gfc-internal-format
+msgid "specs %%include syntax malformed after %ld characters"
+msgstr ""
+
+#: gcc.c:1953 gcc.c:1963 gcc.c:1974 gcc.c:1985
+#, gcc-internal-format, gfc-internal-format
+msgid "specs %%rename syntax malformed after %ld characters"
+msgstr ""
+
+#: gcc.c:1996
+#, gcc-internal-format, gfc-internal-format
+msgid "specs %s spec was not found to be renamed"
+msgstr ""
+
+#: gcc.c:2004
+#, gcc-internal-format
+msgid "%s: attempt to rename spec %qs to already defined spec %qs"
+msgstr ""
+
+#: gcc.c:2026
+#, gcc-internal-format, gfc-internal-format
+msgid "specs unknown %% command after %ld characters"
+msgstr ""
+
+#: gcc.c:2038 gcc.c:2052
+#, gcc-internal-format, gfc-internal-format
+msgid "specs file malformed after %ld characters"
+msgstr ""
+
+#: gcc.c:2104
+#, gcc-internal-format
+msgid "spec file has no spec for linking"
+msgstr ""
+
+#: gcc.c:2649
+#, gcc-internal-format
+msgid "system path %qs is not absolute"
+msgstr ""
+
+#: gcc.c:2737
+#, gcc-internal-format
+msgid "-pipe not supported"
+msgstr ""
+
+#: gcc.c:2899
+#, gcc-internal-format
+msgid "failed to get exit status: %m"
+msgstr ""
+
+#: gcc.c:2905
+#, gcc-internal-format
+msgid "failed to get process times: %m"
+msgstr ""
+
+#: gcc.c:2931
+#, gcc-internal-format, gfc-internal-format
+msgid "%s (program %s)"
+msgstr ""
+
+#: gcc.c:3375 opts-common.c:1030 opts-common.c:1102 opts-global.c:161
+#, gcc-internal-format
+msgid "unrecognized command line option %qs"
+msgstr ""
+
+#: gcc.c:3440
+#, gcc-internal-format, gfc-internal-format
+msgid "GCC is not configured to support %s as offload target"
+msgstr ""
+
+#: gcc.c:3739
+#, gcc-internal-format
+msgid "%qs is an unknown -save-temps option"
+msgstr ""
+
+#: gcc.c:4195 toplev.c:992
+#, gcc-internal-format
+msgid "input file %qs is the same as output file"
+msgstr ""
+
+#: gcc.c:4222
+#, gcc-internal-format
+msgid "-pipe ignored because -save-temps specified"
+msgstr ""
+
+#: gcc.c:4310
+#, gcc-internal-format
+msgid "%<-x %s%> after last input file has no effect"
+msgstr ""
+
+#: gcc.c:4472
+#, gcc-internal-format
+msgid "unable to locate default linker script %qs in the library search paths"
+msgstr ""
+
+#: gcc.c:4677
+#, gcc-internal-format
+msgid "switch %qs does not start with %<-%>"
+msgstr ""
+
+#: gcc.c:4681
+#, gcc-internal-format
+msgid "spec-generated switch is just %<-%>"
+msgstr ""
+
+#: gcc.c:4774
+#, gcc-internal-format, gfc-internal-format
+msgid "could not open temporary response file %s"
+msgstr ""
+
+#: gcc.c:4781
+#, gcc-internal-format, gfc-internal-format
+msgid "could not write to temporary response file %s"
+msgstr ""
+
+#: gcc.c:4787
+#, gcc-internal-format, gfc-internal-format
+msgid "could not close temporary response file %s"
+msgstr ""
+
+#: gcc.c:4910
+#, gcc-internal-format
+msgid "spec %qs invalid"
+msgstr ""
+
+#: gcc.c:5060
+#, gcc-internal-format
+msgid "spec %qs has invalid %<%%0%c%>"
+msgstr ""
+
+#: gcc.c:5380
+#, gcc-internal-format
+msgid "spec %qs has invalid %<%%W%c%>"
+msgstr ""
+
+#: gcc.c:5403
+#, gcc-internal-format
+msgid "spec %qs has invalid %<%%x%c%>"
+msgstr ""
+
+#. Catch the case where a spec string contains something like
+#. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
+#. hand side of the :.
+#: gcc.c:5614
+#, gcc-internal-format
+msgid "spec failure: %<%%*%> has not been initialized by pattern match"
+msgstr ""
+
+#: gcc.c:5657
+#, gcc-internal-format
+msgid "spec failure: unrecognized spec option %qc"
+msgstr ""
+
+#: gcc.c:5719
+#, gcc-internal-format
+msgid "unknown spec function %qs"
+msgstr ""
+
+#: gcc.c:5749
+#, gcc-internal-format
+msgid "error in args to spec function %qs"
+msgstr ""
+
+#: gcc.c:5803
+#, gcc-internal-format
+msgid "malformed spec function name"
+msgstr ""
+
+#. )
+#: gcc.c:5806
+#, gcc-internal-format
+msgid "no arguments for spec function"
+msgstr ""
+
+#: gcc.c:5825
+#, gcc-internal-format
+msgid "malformed spec function arguments"
+msgstr ""
+
+#: gcc.c:6099
+#, gcc-internal-format
+msgid "braced spec %qs is invalid at %qc"
+msgstr ""
+
+#: gcc.c:6187
+#, gcc-internal-format
+msgid "braced spec body %qs is invalid"
+msgstr ""
+
+#: gcc.c:6793
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: could not determine length of compare-debug file %s"
+msgstr ""
+
+#: gcc.c:6804
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: -fcompare-debug failure (length)"
+msgstr ""
+
+#: gcc.c:6814 gcc.c:6855
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: could not open compare-debug file %s"
+msgstr ""
+
+#: gcc.c:6834 gcc.c:6871
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: -fcompare-debug failure"
+msgstr ""
+
+#: gcc.c:7156
+#, gcc-internal-format
+msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
+msgstr ""
+
+#: gcc.c:7180
+#, gcc-internal-format
+msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
+msgstr ""
+
+#: gcc.c:7387
+#, gcc-internal-format
+msgid "unrecognized command line option %<-%s%>"
+msgstr ""
+
+#: gcc.c:7511
+#, gcc-internal-format
+msgid "not configured with sysroot headers suffix"
+msgstr ""
+
+#: gcc.c:7572
+#, gcc-internal-format
+msgid "no input files"
+msgstr "немає вхідних даних"
+
+#: gcc.c:7623
+#, gcc-internal-format
+msgid "cannot specify -o with -c, -S or -E with multiple files"
+msgstr ""
+
+#: gcc.c:7664
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: %s compiler not installed on this system"
+msgstr ""
+
+#: gcc.c:7688
+#, gcc-internal-format
+msgid "recompiling with -fcompare-debug"
+msgstr ""
+
+#: gcc.c:7704
+#, gcc-internal-format
+msgid "during -fcompare-debug recompilation"
+msgstr ""
+
+#: gcc.c:7713
+#, gcc-internal-format
+msgid "comparing final insns dumps"
+msgstr ""
+
+#: gcc.c:7830
+#, gcc-internal-format, gfc-internal-format
+msgid "-fuse-linker-plugin, but %s not found"
+msgstr ""
+
+#: gcc.c:7863
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: linker input file unused because linking not done"
+msgstr ""
+
+#: gcc.c:7915
+#, gcc-internal-format, gfc-internal-format
+msgid "language %s not recognized"
+msgstr ""
+
+#: gcc.c:8142
+#, gcc-internal-format
+msgid "multilib spec %qs is invalid"
+msgstr ""
+
+#: gcc.c:8336
+#, gcc-internal-format
+msgid "multilib exclusions %qs is invalid"
+msgstr ""
+
+#: gcc.c:8400
+#, gcc-internal-format
+msgid "multilib select %qs %qs is invalid"
+msgstr ""
+
+#: gcc.c:8562
+#, gcc-internal-format
+msgid "multilib select %qs is invalid"
+msgstr ""
+
+#: gcc.c:8602
+#, gcc-internal-format
+msgid "multilib exclusion %qs is invalid"
+msgstr ""
+
+#: gcc.c:8809
+#, gcc-internal-format
+msgid "environment variable %qs not defined"
+msgstr ""
+
+#: gcc.c:8948 gcc.c:8953
+#, gcc-internal-format
+msgid "invalid version number %qs"
+msgstr ""
+
+#: gcc.c:8996
+#, gcc-internal-format, gfc-internal-format
+msgid "too few arguments to %%:version-compare"
+msgstr ""
+
+#: gcc.c:9002
+#, gcc-internal-format, gfc-internal-format
+msgid "too many arguments to %%:version-compare"
+msgstr ""
+
+#: gcc.c:9044
+#, gcc-internal-format
+msgid "unknown operator %qs in %%:version-compare"
+msgstr ""
+
+#: gcc.c:9168
+#, gcc-internal-format, gfc-internal-format
+msgid "too many arguments to %%:compare-debug-dump-opt"
+msgstr ""
+
+#: gcc.c:9241
+#, gcc-internal-format, gfc-internal-format
+msgid "too many arguments to %%:compare-debug-self-opt"
+msgstr ""
+
+#: gcc.c:9277
+#, gcc-internal-format, gfc-internal-format
+msgid "too few arguments to %%:compare-debug-auxbase-opt"
+msgstr ""
+
+#: gcc.c:9281
+#, gcc-internal-format, gfc-internal-format
+msgid "too many arguments to %%:compare-debug-auxbase-opt"
+msgstr ""
+
+#: gcc.c:9288
+#, gcc-internal-format, gfc-internal-format
+msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
+msgstr ""
+
+#: gcc.c:9362
+#, gcc-internal-format, gfc-internal-format
+msgid "too few arguments to %%:replace-extension"
+msgstr ""
+
+#: gcov-tool.c:72
+#, gcc-internal-format, gfc-internal-format
+msgid "error in removing %s\n"
+msgstr ""
+
+#: gcov-tool.c:103
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot make directory %s"
+msgstr "Не вдалося створити каталог %s"
+
+#: gcov-tool.c:111
+#, gcc-internal-format
+msgid "Cannot get current directory name"
+msgstr "Не вдалося визначити назву поточного каталогу"
+
+#: gcov-tool.c:115 gcov-tool.c:121
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot change directory to %s"
+msgstr "Не вдалося змінити каталог на %s"
+
+#: gcov-tool.c:215
+#, gcc-internal-format
+msgid "weights need to be non-negative\n"
+msgstr ""
+
+#: gcov-tool.c:358
+#, gcc-internal-format
+msgid "scale needs to be non-negative\n"
+msgstr ""
+
+#: ggc-common.c:398 ggc-common.c:406 ggc-common.c:475 ggc-common.c:493
+#: ggc-page.c:2452 ggc-page.c:2483 ggc-page.c:2490
+#, gcc-internal-format
+msgid "can%'t write PCH file: %m"
+msgstr ""
+
+#: ggc-common.c:486 config/i386/host-cygwin.c:55
+#, gcc-internal-format
+msgid "can%'t get position in PCH file: %m"
+msgstr ""
+
+#: ggc-common.c:496
+#, gcc-internal-format
+msgid "can%'t write padding to PCH file: %m"
+msgstr ""
+
+#: ggc-common.c:618 ggc-common.c:626 ggc-common.c:629 ggc-common.c:639
+#: ggc-common.c:642 ggc-page.c:2580
+#, gcc-internal-format
+msgid "can%'t read PCH file: %m"
+msgstr ""
+
+#: ggc-common.c:634
+#, gcc-internal-format
+msgid "had to relocate PCH"
+msgstr ""
+
+#: ggc-page.c:1734
+#, gcc-internal-format
+msgid "open /dev/zero: %m"
+msgstr ""
+
+#: ggc-page.c:2468 ggc-page.c:2474
+#, gcc-internal-format
+msgid "can%'t write PCH file"
+msgstr ""
+
+#: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
+#, gcc-internal-format
+msgid "declared here"
+msgstr ""
+
+#: gimple-streamer-in.c:236
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: unknown GIMPLE statement tag %s"
+msgstr ""
+
+#: gimple.c:1184
+#, gcc-internal-format, gfc-internal-format
+msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
+msgstr ""
+
+#: gimplify.c:2503
+#, gcc-internal-format
+msgid "using result of function returning %<void%>"
+msgstr ""
+
+#: gimplify.c:5077
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid lvalue in asm output %d"
+msgstr ""
+
+#: gimplify.c:5193
+#, gcc-internal-format, gfc-internal-format
+msgid "non-memory input %d must stay in memory"
+msgstr ""
+
+#: gimplify.c:5215
+#, gcc-internal-format, gfc-internal-format
+msgid "memory input %d is not directly addressable"
+msgstr ""
+
+#: gimplify.c:5736
+#, gcc-internal-format
+msgid "threadprivate variable %qE used in target region"
+msgstr ""
+
+#: gimplify.c:5738
+#, gcc-internal-format
+msgid "enclosing target region"
+msgstr ""
+
+#: gimplify.c:5750
+#, gcc-internal-format
+msgid "threadprivate variable %qE used in untied task"
+msgstr ""
+
+#: gimplify.c:5752 gimplify.c:5847
+#, gcc-internal-format
+msgid "enclosing task"
+msgstr ""
+
+#: gimplify.c:5799
+#, gcc-internal-format
+msgid "%qD referenced in target region does not have a mappable type"
+msgstr ""
+
+#: gimplify.c:5839
+#, gcc-internal-format
+msgid "%qE not specified in enclosing parallel"
+msgstr ""
+
+#: gimplify.c:5841
+#, gcc-internal-format
+msgid "enclosing parallel"
+msgstr ""
+
+#: gimplify.c:5845
+#, gcc-internal-format
+msgid "%qE not specified in enclosing task"
+msgstr ""
+
+#: gimplify.c:5851
+#, gcc-internal-format
+msgid "%qE not specified in enclosing teams construct"
+msgstr ""
+
+#: gimplify.c:5853
+#, gcc-internal-format
+msgid "enclosing teams construct"
+msgstr ""
+
+#: gimplify.c:5971 gimplify.c:6000
+#, gcc-internal-format
+msgid "iteration variable %qE is predetermined linear"
+msgstr ""
+
+#: gimplify.c:5974
+#, gcc-internal-format
+msgid "iteration variable %qE should be private"
+msgstr ""
+
+#: gimplify.c:5988
+#, gcc-internal-format
+msgid "iteration variable %qE should not be firstprivate"
+msgstr ""
+
+#: gimplify.c:5991
+#, gcc-internal-format
+msgid "iteration variable %qE should not be reduction"
+msgstr ""
+
+#: gimplify.c:5994
+#, gcc-internal-format
+msgid "iteration variable %qE should not be lastprivate"
+msgstr ""
+
+#: gimplify.c:5997
+#, gcc-internal-format
+msgid "iteration variable %qE should not be private"
+msgstr ""
+
+#: gimplify.c:6416
+#, gcc-internal-format
+msgid "copyprivate variable %qE is not threadprivate or private in outer context"
+msgstr ""
+
+#: gimplify.c:6426
+#, gcc-internal-format
+msgid "%s variable %qE is private in outer context"
+msgstr ""
+
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
+#, gcc-internal-format
+msgid "directive not yet implemented"
+msgstr ""
+
+#: gimplify.c:8691
+#, gcc-internal-format
+msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
+msgstr ""
+
+#: gimplify.c:8987
+#, gcc-internal-format
+msgid "gimplification failed"
+msgstr ""
+
+#: gimplify.c:9452
+#, gcc-internal-format
+msgid "first argument to %<va_arg%> not of type %<va_list%>"
+msgstr ""
+
+#: gimplify.c:9468
+#, gcc-internal-format
+msgid "%qT is promoted to %qT when passed through %<...%>"
+msgstr ""
+
+#: gimplify.c:9473
+#, gcc-internal-format
+msgid "(so you should pass %qT not %qT to %<va_arg%>)"
+msgstr ""
+
+#: gimplify.c:9480
+#, gcc-internal-format
+msgid "if this code is reached, the program will abort"
+msgstr ""
+
+#: godump.c:1440
+#, gcc-internal-format
+msgid "could not close Go dump file: %m"
+msgstr ""
+
+#: godump.c:1452
+#, gcc-internal-format
+msgid "could not open Go dump file %qs: %m"
+msgstr ""
+
+#: graph.c:66 toplev.c:1589 java/jcf-parse.c:1774 java/jcf-parse.c:1913
+#: objc/objc-act.c:488
+#, gcc-internal-format
+msgid "can%'t open %s: %m"
+msgstr ""
+
+#: graphite.c:326
+#, gcc-internal-format
+msgid "Graphite loop optimizations cannot be used (ISL is not available)."
+msgstr ""
+
+#: ipa-chkp.c:666
+#, gcc-internal-format
+msgid "function cannot be instrumented"
+msgstr ""
+
+#: ipa-devirt.c:712 ipa-devirt.c:865
+#, gcc-internal-format
+msgid "virtual table of type %qD violates one definition rule"
+msgstr ""
+
+#: ipa-devirt.c:715
+#, gcc-internal-format
+msgid "variable of same assembler name as the virtual table is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:754
+#, gcc-internal-format
+msgid "virtual table of type %qD contains RTTI information"
+msgstr ""
+
+#: ipa-devirt.c:760
+#, gcc-internal-format
+msgid "but is prevailed by one without from other translation unit"
+msgstr ""
+
+#: ipa-devirt.c:764
+#, gcc-internal-format
+msgid "RTTI will not work on this type"
+msgstr ""
+
+#: ipa-devirt.c:795 ipa-devirt.c:824 ipa-devirt.c:895
+#, gcc-internal-format
+msgid "virtual table of type %qD violates one definition rule  "
+msgstr ""
+
+#: ipa-devirt.c:801
+#, gcc-internal-format
+msgid "the conflicting type defined in another translation unit has virtual table of different size"
+msgstr ""
+
+#: ipa-devirt.c:830
+#, gcc-internal-format
+msgid "the conflicting type defined in another translation unit with different RTTI information"
+msgstr ""
+
+#: ipa-devirt.c:873 ipa-devirt.c:903
+#, gcc-internal-format
+msgid "the conflicting type defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:877
+#, gcc-internal-format
+msgid "contains additional virtual method %qD"
+msgstr ""
+
+#: ipa-devirt.c:884
+#, gcc-internal-format
+msgid "the conflicting type defined in another translation unit has virtual table table with more entries"
+msgstr ""
+
+#: ipa-devirt.c:908
+#, gcc-internal-format
+msgid "virtual method %qD"
+msgstr ""
+
+#: ipa-devirt.c:910
+#, gcc-internal-format
+msgid "ought to match virtual method %qD but does not"
+msgstr ""
+
+#: ipa-devirt.c:916
+#, gcc-internal-format
+msgid "the conflicting type defined in another translation unit has virtual table table with different contents"
+msgstr ""
+
+#: ipa-devirt.c:946
+#, gcc-internal-format
+msgid "type %qT violates one definition rule"
+msgstr ""
+
+#: ipa-devirt.c:957 ipa-devirt.c:972 ipa-devirt.c:1167 ipa-devirt.c:1249
+#: ipa-devirt.c:1285 ipa-devirt.c:1302
+#, gcc-internal-format
+msgid "a different type is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:964
+#, gcc-internal-format
+msgid "the first difference of corresponding definitions is field %qD"
+msgstr ""
+
+#: ipa-devirt.c:974
+#, gcc-internal-format
+msgid "the first difference of corresponding definitions is method %qD"
+msgstr ""
+
+#: ipa-devirt.c:1010
+#, gcc-internal-format
+msgid "type name %<%s%> should match type name %<%s%>"
+msgstr ""
+
+#: ipa-devirt.c:1013 ipa-devirt.c:1145
+#, gcc-internal-format
+msgid "the incompatible type is defined here"
+msgstr ""
+
+#: ipa-devirt.c:1033
+#, gcc-internal-format
+msgid "type %qT defined in anonymous namespace can not match type %qT"
+msgstr ""
+
+#: ipa-devirt.c:1037
+#, gcc-internal-format
+msgid "the incompatible type defined in anonymous namespace in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1042
+#, gcc-internal-format
+msgid "types in anonymous namespace does not match across translation unit boundary"
+msgstr ""
+
+#: ipa-devirt.c:1069
+#, gcc-internal-format
+msgid "array types have different bounds"
+msgstr ""
+
+#: ipa-devirt.c:1087
+#, gcc-internal-format
+msgid "return value type mismatch"
+msgstr ""
+
+#: ipa-devirt.c:1100
+#, gcc-internal-format, gfc-internal-format
+msgid "type mismatch in parameter %i"
+msgstr ""
+
+#: ipa-devirt.c:1109
+#, gcc-internal-format
+msgid "types have different parameter counts"
+msgstr ""
+
+#: ipa-devirt.c:1130
+#, gcc-internal-format
+msgid "type %qT should match type %qT but is defined in different namespace  "
+msgstr ""
+
+#: ipa-devirt.c:1136
+#, gcc-internal-format
+msgid "type %qT should match type %qT that itself violate one definition rule"
+msgstr ""
+
+#: ipa-devirt.c:1141
+#, gcc-internal-format
+msgid "type %qT should match type %qT"
+msgstr ""
+
+#: ipa-devirt.c:1174
+#, gcc-internal-format
+msgid "a type with different qualifiers is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1182
+#, gcc-internal-format
+msgid "a type with attributes is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1197
+#, gcc-internal-format
+msgid "an enum with different value name is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1206
+#, gcc-internal-format
+msgid "an enum with different values is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1214
+#, gcc-internal-format
+msgid "an enum with mismatching number of values is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1232
+#, gcc-internal-format
+msgid "a type with different precision is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1239
+#, gcc-internal-format
+msgid "a type with different signedness is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1264
+#, gcc-internal-format
+msgid "it is defined as a pointer in different address space in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1272
+#, gcc-internal-format
+msgid "it is defined as a pointer to different type in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1329
+#, gcc-internal-format
+msgid "an array of different size is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1343
+#, gcc-internal-format
+msgid "has different return value in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1364 ipa-devirt.c:1376
+#, gcc-internal-format
+msgid "has different parameters in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1399
+#, gcc-internal-format
+msgid "a type defined in another translation unit is not polymorphic"
+msgstr ""
+
+#: ipa-devirt.c:1403
+#, gcc-internal-format
+msgid "a type defined in another translation unit is polymorphic"
+msgstr ""
+
+#: ipa-devirt.c:1421 ipa-devirt.c:1476
+#, gcc-internal-format
+msgid "a type with different virtual table pointers is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1428 ipa-devirt.c:1481
+#, gcc-internal-format
+msgid "a type with different bases is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1436
+#, gcc-internal-format
+msgid "a field with different name is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1449
+#, gcc-internal-format
+msgid "a field of same name but different type is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1462
+#, gcc-internal-format
+msgid "fields has different layout in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1485
+#, gcc-internal-format
+msgid "a type with different number of fields is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1501
+#, gcc-internal-format
+msgid "a different method of same type is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1508
+#, gcc-internal-format
+msgid "s definition that differs by virtual keyword in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1515
+#, gcc-internal-format
+msgid "virtual table layout differs in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1522
+#, gcc-internal-format
+msgid "method with incompatible type is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1530
+#, gcc-internal-format
+msgid "a type with different number of methods is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1551
+#, gcc-internal-format
+msgid "a type with different size is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1559
+#, gcc-internal-format
+msgid "a type with different alignment is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.c:1674
+#, gcc-internal-format
+msgid "the extra base is defined here"
+msgstr ""
+
+#: ipa-devirt.c:3629
+#, gcc-internal-format
+msgid "Declaring type %qD final would enable devirtualization of %i call"
+msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: ipa-devirt.c:3638
+#, gcc-internal-format
+msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
+msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: ipa-devirt.c:3667
+#, gcc-internal-format
+msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
+msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: ipa-devirt.c:3675
+#, gcc-internal-format
+msgid "Declaring method %qD final would enable devirtualization of %i call"
+msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: ipa-devirt.c:3683
+#, gcc-internal-format
+msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
+msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: ipa-devirt.c:3693
+#, gcc-internal-format
+msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
+msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: ipa-inline-analysis.c:4311
+#, gcc-internal-format
+msgid "ipa inline summary is missing in input file"
+msgstr ""
+
+#: ipa-reference.c:1176
+#, gcc-internal-format
+msgid "ipa reference summary is missing in ltrans unit"
+msgstr ""
+
+#: ira.c:2339 ira.c:2352 ira.c:2366
+#, gcc-internal-format, gfc-internal-format
+msgid "%s cannot be used in asm here"
+msgstr ""
+
+#: ira.c:5505
+#, gcc-internal-format
+msgid "frame pointer required, but reserved"
+msgstr ""
+
+#: ira.c:5506
+#, gcc-internal-format
+msgid "for %qD"
+msgstr ""
+
+#: lra-assigns.c:1406 reload1.c:1288
+#, gcc-internal-format
+msgid "%<asm%> operand has impossible constraints"
+msgstr ""
+
+#: lra-assigns.c:1427
+#, gcc-internal-format
+msgid "unable to find a register to spill"
+msgstr ""
+
+#: lra-assigns.c:1638
+#, gcc-internal-format, gfc-internal-format
+msgid "Maximum number of LRA assignment passes is achieved (%d)\n"
+msgstr ""
+
+#: lra-constraints.c:3497 reload.c:3863 reload.c:4118
+#, gcc-internal-format
+msgid "inconsistent operand constraints in an %<asm%>"
+msgstr ""
+
+#: lra-constraints.c:4366
+#, gcc-internal-format, gfc-internal-format
+msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
+msgstr ""
+
+#: lto-cgraph.c:1332
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
+msgstr ""
+
+#: lto-cgraph.c:1509
+#, gcc-internal-format
+msgid "bytecode stream: no caller found while reading edge"
+msgstr ""
+
+#: lto-cgraph.c:1515
+#, gcc-internal-format
+msgid "bytecode stream: no callee found while reading edge"
+msgstr ""
+
+#: lto-cgraph.c:1590
+#, gcc-internal-format
+msgid "bytecode stream: found empty cgraph node"
+msgstr ""
+
+#: lto-cgraph.c:1764
+#, gcc-internal-format, gfc-internal-format
+msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
+msgstr ""
+
+#: lto-cgraph.c:1851
+#, gcc-internal-format, gfc-internal-format
+msgid "Profile information in %s corrupted"
+msgstr ""
+
+#: lto-cgraph.c:1884
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot find LTO cgraph in %s"
+msgstr ""
+
+#: lto-cgraph.c:1894
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot find LTO section refs in %s"
+msgstr ""
+
+#: lto-cgraph.c:1962
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid offload table in %s"
+msgstr ""
+
+#: lto-compress.c:215 lto-compress.c:223 lto-compress.c:244 lto-compress.c:305
+#: lto-compress.c:313 lto-compress.c:334
+#, gcc-internal-format, gfc-internal-format
+msgid "compressed stream: %s"
+msgstr ""
+
+#: lto-section-in.c:462
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: trying to read %d bytes after the end of the input buffer"
+msgstr ""
+
+#: lto-section-in.c:473
+#, gcc-internal-format, gfc-internal-format
+msgid "%s out of range: Range is %i to %i, value is %i"
+msgstr ""
+
+#: lto-streamer-in.c:124
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: unexpected tag %s"
+msgstr ""
+
+#: lto-streamer-in.c:946 lto-streamer-in.c:956
+#, gcc-internal-format
+msgid "Cgraph edge statement index out of range"
+msgstr ""
+
+#: lto-streamer-in.c:950 lto-streamer-in.c:959
+#, gcc-internal-format
+msgid "Cgraph edge statement index not found"
+msgstr ""
+
+#: lto-streamer-in.c:966
+#, gcc-internal-format
+msgid "Reference statement index out of range"
+msgstr ""
+
+#: lto-streamer-in.c:969
+#, gcc-internal-format
+msgid "Reference statement index not found"
+msgstr ""
+
+#: lto-streamer-in.c:1547
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot read LTO mode table from %s"
+msgstr ""
+
+#: lto-streamer-in.c:1643
+#, gcc-internal-format, gfc-internal-format
+msgid "unsupported mode %s\n"
+msgstr ""
+
+#: lto-streamer-out.c:414 lto-streamer-out.c:670
+#, gcc-internal-format
+msgid "tree code %qs is not supported in LTO streams"
+msgstr ""
+
+#: lto-streamer.c:188
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: unexpected LTO section %s"
+msgstr ""
+
+#: lto-streamer.c:412
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream generated with LTO version %d.%d instead of the expected %d.%d"
+msgstr ""
+
+#: lto-wrapper.c:112
+#, gcc-internal-format
+msgid "deleting LTRANS file %s: %m"
+msgstr ""
+
+#: lto-wrapper.c:149
+#, gcc-internal-format
+msgid "malformed COLLECT_GCC_OPTIONS"
+msgstr ""
+
+#: lto-wrapper.c:299 lto-wrapper.c:311
+#, gcc-internal-format, gfc-internal-format
+msgid "Option %s not used consistently in all LTO input files"
+msgstr ""
+
+#: lto-wrapper.c:738
+#, gcc-internal-format, gfc-internal-format
+msgid "problem with building target image for %s\n"
+msgstr ""
+
+#: lto-wrapper.c:757
+#, gcc-internal-format
+msgid "reading input file"
+msgstr ""
+
+#: lto-wrapper.c:762
+#, gcc-internal-format
+msgid "writing output file"
+msgstr ""
+
+#: lto-wrapper.c:788
+#, gcc-internal-format
+msgid "installation error, can't find crtoffloadend.o"
+msgstr ""
+
+#: lto-wrapper.c:800
+#, gcc-internal-format
+msgid "installation error, can't find crtoffloadbegin.o"
+msgstr ""
+
+#: lto-wrapper.c:904
+#, gcc-internal-format
+msgid "environment variable COLLECT_GCC must be set"
+msgstr ""
+
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
+#, gcc-internal-format
+msgid "environment variable COLLECT_GCC_OPTIONS must be set"
+msgstr ""
+
+#: lto-wrapper.c:1174
+#, gcc-internal-format
+msgid "fopen: %s: %m"
+msgstr ""
+
+#: omp-low.c:1731 omp-low.c:1955
+#, gcc-internal-format
+msgid "clause not supported yet"
+msgstr ""
+
+#: omp-low.c:1931 omp-low.c:2058
+#, gcc-internal-format
+msgid "Clause not supported yet"
+msgstr ""
+
+#: omp-low.c:2589
+#, gcc-internal-format
+msgid "no arguments allowed to gang, worker and vector clauses inside parallel"
+msgstr ""
+
+#: omp-low.c:2610
+#, gcc-internal-format
+msgid "gang, worker and vector may occur only once in a loop nest"
+msgstr ""
+
+#: omp-low.c:2614
+#, gcc-internal-format
+msgid "gang, worker and vector must occur in this order in a loop nest"
+msgstr ""
+
+#: omp-low.c:2748
+#, gcc-internal-format
+msgid "non-OpenACC construct inside of OpenACC region"
+msgstr ""
+
+#: omp-low.c:2759
+#, gcc-internal-format
+msgid "OpenMP constructs may not be nested inside simd region"
+msgstr ""
+
+#: omp-low.c:2770
+#, gcc-internal-format
+msgid "only distribute or parallel constructs are allowed to be closely nested inside teams construct"
+msgstr ""
+
+#: omp-low.c:2786
+#, gcc-internal-format
+msgid "distribute construct must be closely nested inside teams construct"
+msgstr ""
+
+#: omp-low.c:2804
+#, gcc-internal-format
+msgid "orphaned %qs construct"
+msgstr ""
+
+#: omp-low.c:2836
+#, gcc-internal-format
+msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
+msgstr ""
+
+#: omp-low.c:2841
+#, gcc-internal-format
+msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
+msgstr ""
+
+#: omp-low.c:2861 omp-low.c:2874
+#, gcc-internal-format
+msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
+msgstr ""
+
+#: omp-low.c:2888
+#, gcc-internal-format
+msgid "invalid arguments"
+msgstr "некоректні аргументи"
+
+#: omp-low.c:2894
+#, gcc-internal-format
+msgid "%<%s %s%> construct not closely nested inside of %qs"
+msgstr ""
+
+#: omp-low.c:2921
+#, gcc-internal-format
+msgid "barrier region may not be closely nested inside of work-sharing, critical, ordered, master or explicit task region"
+msgstr ""
+
+#: omp-low.c:2927
+#, gcc-internal-format
+msgid "work-sharing region may not be closely nested inside of work-sharing, critical, ordered, master or explicit task region"
+msgstr ""
+
+#: omp-low.c:2946
+#, gcc-internal-format
+msgid "master region may not be closely nested inside of work-sharing or explicit task region"
+msgstr ""
+
+#: omp-low.c:2962
+#, gcc-internal-format
+msgid "ordered region may not be closely nested inside of critical or explicit task region"
+msgstr ""
+
+#: omp-low.c:2970 omp-low.c:2977
+#, gcc-internal-format
+msgid "ordered region must be closely nested inside a loop region with an ordered clause"
+msgstr ""
+
+#: omp-low.c:2994
+#, gcc-internal-format
+msgid "critical region may not be nested inside a critical region with the same name"
+msgstr ""
+
+#: omp-low.c:3006
+#, gcc-internal-format
+msgid "teams construct not closely nested inside of target region"
+msgstr ""
+
+#: omp-low.c:3021
+#, gcc-internal-format
+msgid "OpenACC construct inside of non-OpenACC region"
+msgstr ""
+
+#: omp-low.c:3055
+#, gcc-internal-format, gfc-internal-format
+msgid "%s %s construct inside of %s %s region"
+msgstr ""
+
+#: omp-low.c:3068 omp-low.c:3076
+#, gcc-internal-format, gfc-internal-format
+msgid "%s construct inside of %s region"
+msgstr ""
+
+#: omp-low.c:3184
+#, gcc-internal-format
+msgid "setjmp/longjmp inside simd construct"
+msgstr ""
+
+#: omp-low.c:12080
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid exit from %s structured block"
+msgstr ""
+
+#: omp-low.c:12082 omp-low.c:12087
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid entry to %s structured block"
+msgstr ""
+
+#. Otherwise, be vague and lazy, but efficient.
+#: omp-low.c:12091
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid branch to/from %s structured block"
+msgstr ""
+
+#: omp-low.c:12590
+#, gcc-internal-format
+msgid "ignoring large linear step"
+msgstr ""
+
+#: omp-low.c:12597
+#, gcc-internal-format
+msgid "ignoring zero linear step"
+msgstr ""
+
+#: optabs.c:4526
+#, gcc-internal-format
+msgid "indirect jumps are not available on this target"
+msgstr ""
+
+#: opts-common.c:1041
+#, gcc-internal-format
+msgid "command line option %qs is not supported by this configuration"
+msgstr ""
+
+#: opts-common.c:1051
+#, gcc-internal-format
+msgid "missing argument to %qs"
+msgstr ""
+
+#: opts-common.c:1057
+#, gcc-internal-format
+msgid "argument to %qs should be a non-negative integer"
+msgstr ""
+
+#: opts-common.c:1072
+#, gcc-internal-format
+msgid "unrecognized argument in option %qs"
+msgstr ""
+
+#: opts-common.c:1088
+#, gcc-internal-format
+msgid "valid arguments to %qs are: %s"
+msgstr ""
+
+#: opts-global.c:124
+#, gcc-internal-format
+msgid "command line option %qs is valid for the driver but not for %s"
+msgstr ""
+
+#. Eventually this should become a hard error IMO.
+#: opts-global.c:130
+#, gcc-internal-format
+msgid "command line option %qs is valid for %s but not for %s"
+msgstr ""
+
+#: opts-global.c:385
+#, gcc-internal-format
+msgid "unrecognized command line option %<-fdump-%s%>"
+msgstr ""
+
+#: opts-global.c:390
+#, gcc-internal-format
+msgid "unrecognized command line option %<-fopt-info-%s%>"
+msgstr ""
+
+#: opts-global.c:411 opts-global.c:419
+#, gcc-internal-format
+msgid "plugin support is disabled; configure with --enable-plugin"
+msgstr ""
+
+#: opts-global.c:443
+#, gcc-internal-format
+msgid "unrecognized register name %qs"
+msgstr ""
+
+#: opts-global.c:455
+#, gcc-internal-format
+msgid "-fasan-shadow-offset should only be used with -fsanitize=kernel-address"
+msgstr ""
+
+#: opts-global.c:458
+#, gcc-internal-format
+msgid "unrecognized shadow offset %qs"
+msgstr ""
+
+#: opts.c:92
+#, gcc-internal-format
+msgid "argument %qs to %<-femit-struct-debug-detailed%> not recognized"
+msgstr ""
+
+#: opts.c:128
+#, gcc-internal-format
+msgid "argument %qs to %<-femit-struct-debug-detailed%> unknown"
+msgstr ""
+
+#: opts.c:135
+#, gcc-internal-format
+msgid "%<-femit-struct-debug-detailed=dir:...%> must allow at least as much as %<-femit-struct-debug-detailed=ind:...%>"
+msgstr ""
+
+#: opts.c:568
+#, gcc-internal-format
+msgid "argument to %<-O%> should be a non-negative integer, %<g%>, %<s%> or %<fast%>"
+msgstr ""
+
+#: opts.c:712
+#, gcc-internal-format
+msgid "section anchors must be disabled when unit-at-a-time is disabled"
+msgstr ""
+
+#: opts.c:716
+#, gcc-internal-format
+msgid "toplevel reorder must be disabled when unit-at-a-time is disabled"
+msgstr ""
+
+#: opts.c:722
+#, gcc-internal-format
+msgid "transactional memory is not supported with non-call exceptions"
+msgstr ""
+
+#: opts.c:737
+#, gcc-internal-format
+msgid "section anchors must be disabled when toplevel reorder is disabled"
+msgstr ""
+
+#: opts.c:773 config/darwin.c:3161
+#, gcc-internal-format
+msgid "-freorder-blocks-and-partition does not work with exceptions on this architecture"
+msgstr ""
+
+#: opts.c:789
+#, gcc-internal-format
+msgid "-freorder-blocks-and-partition does not support unwind info on this architecture"
+msgstr ""
+
+#: opts.c:807 config/pa/pa.c:555
+#, gcc-internal-format
+msgid "-freorder-blocks-and-partition does not work on this architecture"
+msgstr ""
+
+#: opts.c:848
+#, gcc-internal-format
+msgid "-fno-fat-lto-objects are supported only with linker plugin"
+msgstr ""
+
+#: opts.c:861
+#, gcc-internal-format
+msgid "%<-fsplit-stack%> is not supported by this compiler configuration"
+msgstr ""
+
+#: opts.c:894
+#, gcc-internal-format
+msgid "-fsanitize=address is incompatible with -fsanitize=kernel-address"
+msgstr ""
+
+#: opts.c:902
+#, gcc-internal-format
+msgid "-fsanitize=address and -fsanitize=kernel-address are incompatible with -fsanitize=thread"
+msgstr ""
+
+#: opts.c:908
+#, gcc-internal-format
+msgid "-fsanitize-recover=address is not supported"
+msgstr ""
+
+#: opts.c:911
+#, gcc-internal-format
+msgid "-fsanitize-recover=thread is not supported"
+msgstr ""
+
+#: opts.c:914
+#, gcc-internal-format
+msgid "-fsanitize-recover=leak is not supported"
+msgstr ""
+
+#: opts.c:1289
+#, gcc-internal-format
+msgid "unrecognized include_flags 0x%x passed to print_specific_help"
+msgstr ""
+
+#: opts.c:1516
+#, gcc-internal-format
+msgid "--help argument %q.*s is ambiguous, please be more specific"
+msgstr ""
+
+#: opts.c:1525
+#, gcc-internal-format
+msgid "unrecognized argument to --help= option: %q.*s"
+msgstr ""
+
+#: opts.c:1623
+#, gcc-internal-format
+msgid "-fsanitize=all option is not valid"
+msgstr ""
+
+#: opts.c:1638
+#, gcc-internal-format
+msgid "unrecognized argument to -fsanitize%s= option: %q.*s"
+msgstr ""
+
+#: opts.c:1833
+#, gcc-internal-format
+msgid "-foffload-abi option can be specified only for offload compiler"
+msgstr ""
+
+#: opts.c:1841
+#, gcc-internal-format, gfc-internal-format
+msgid "structure alignment must be a small power of two, not %d"
+msgstr ""
+
+#: opts.c:1955
+#, gcc-internal-format
+msgid "unknown stack check parameter %qs"
+msgstr ""
+
+#: opts.c:1987
+#, gcc-internal-format
+msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
+msgstr ""
+
+#: opts.c:1998
+#, gcc-internal-format, gfc-internal-format
+msgid "dwarf version %d is not supported"
+msgstr ""
+
+#: opts.c:2098
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: --param arguments should be of the form NAME=VALUE"
+msgstr ""
+
+#: opts.c:2104
+#, gcc-internal-format
+msgid "invalid --param value %qs"
+msgstr ""
+
+#: opts.c:2222
+#, gcc-internal-format
+msgid "target system does not support debug output"
+msgstr ""
+
+#: opts.c:2231
+#, gcc-internal-format
+msgid "debug format %qs conflicts with prior selection"
+msgstr ""
+
+#: opts.c:2249
+#, gcc-internal-format
+msgid "unrecognised debug output level %qs"
+msgstr ""
+
+#: opts.c:2251
+#, gcc-internal-format
+msgid "debug output level %qs is too high"
+msgstr ""
+
+#: opts.c:2271
+#, gcc-internal-format
+msgid "getting core file size maximum limit: %m"
+msgstr ""
+
+#: opts.c:2275
+#, gcc-internal-format
+msgid "setting core file size limit to maximum: %m"
+msgstr ""
+
+#: opts.c:2320
+#, gcc-internal-format, gfc-internal-format
+msgid "unrecognized gcc debugging option: %c"
+msgstr ""
+
+#: opts.c:2346
+#, gcc-internal-format, gfc-internal-format
+msgid "-Werror=%s: no option -%s"
+msgstr ""
+
+#: params.c:134
+#, gcc-internal-format
+msgid "minimum value of parameter %qs is %u"
+msgstr ""
+
+#: params.c:139
+#, gcc-internal-format
+msgid "maximum value of parameter %qs is %u"
+msgstr ""
+
+#. If we didn't find this parameter, issue an error message.
+#: params.c:149
+#, gcc-internal-format
+msgid "invalid parameter %qs"
+msgstr ""
+
+#: passes.c:130
+#, gcc-internal-format, gfc-internal-format
+msgid "pass %s does not support cloning"
+msgstr ""
+
+#: passes.c:1036
+#, gcc-internal-format
+msgid "unrecognized option -fenable"
+msgstr ""
+
+#: passes.c:1038
+#, gcc-internal-format
+msgid "unrecognized option -fdisable"
+msgstr ""
+
+#: passes.c:1046
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown pass %s specified in -fenable"
+msgstr ""
+
+#: passes.c:1048
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown pass %s specified in -fdisable"
+msgstr ""
+
+#: passes.c:1073 passes.c:1162
+#, gcc-internal-format, gfc-internal-format
+msgid "enable pass %s for functions in the range of [%u, %u]"
+msgstr ""
+
+#: passes.c:1076 passes.c:1173
+#, gcc-internal-format, gfc-internal-format
+msgid "disable pass %s for functions in the range of [%u, %u]"
+msgstr ""
+
+#: passes.c:1112 passes.c:1140
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid range %s in option %s"
+msgstr ""
+
+#: passes.c:1158
+#, gcc-internal-format, gfc-internal-format
+msgid "enable pass %s for function %s"
+msgstr ""
+
+#: passes.c:1169
+#, gcc-internal-format, gfc-internal-format
+msgid "disable pass %s for function %s"
+msgstr ""
+
+#: passes.c:1398
+#, gcc-internal-format
+msgid "invalid pass positioning operation"
+msgstr ""
+
+#: passes.c:1460
+#, gcc-internal-format
+msgid "plugin cannot register a missing pass"
+msgstr ""
+
+#: passes.c:1463
+#, gcc-internal-format
+msgid "plugin cannot register an unnamed pass"
+msgstr ""
+
+#: passes.c:1468
+#, gcc-internal-format
+msgid "plugin cannot register pass %qs without reference pass name"
+msgstr ""
+
+#: passes.c:1487
+#, gcc-internal-format
+msgid "pass %qs not found but is referenced by new pass %qs"
+msgstr ""
+
+#: plugin.c:191
+#, gcc-internal-format
+msgid "inaccessible plugin file %s expanded from short plugin name %s: %m"
+msgstr ""
+
+#: plugin.c:212
+#, gcc-internal-format, gfc-internal-format
+msgid ""
+"plugin %s was specified with different paths:\n"
+"%s\n"
+"%s"
+msgstr ""
+
+#: plugin.c:271
+#, gcc-internal-format, gfc-internal-format
+msgid "malformed option -fplugin-arg-%s (missing -<key>[=<value>])"
+msgstr ""
+
+#: plugin.c:333
+#, gcc-internal-format, gfc-internal-format
+msgid "plugin %s should be specified before -fplugin-arg-%s in the command line"
+msgstr ""
+
+#: plugin.c:439
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown callback event registered by plugin %s"
+msgstr ""
+
+#: plugin.c:469
+#, gcc-internal-format, gfc-internal-format
+msgid "plugin %s registered a null callback function for event %s"
+msgstr ""
+
+#: plugin.c:590
+#, gcc-internal-format, gfc-internal-format
+msgid ""
+"cannot load plugin %s\n"
+"%s"
+msgstr ""
+
+#: plugin.c:600
+#, gcc-internal-format, gfc-internal-format
+msgid ""
+"plugin %s is not licensed under a GPL-compatible license\n"
+"%s"
+msgstr ""
+
+#: plugin.c:609
+#, gcc-internal-format, gfc-internal-format
+msgid ""
+"cannot find %s in plugin %s\n"
+"%s"
+msgstr ""
+
+#: plugin.c:617
+#, gcc-internal-format, gfc-internal-format
+msgid "fail to initialize plugin %s"
+msgstr ""
+
+#: plugin.c:899
+#, gcc-internal-format
+msgid "-iplugindir <dir> option not passed from the gcc driver"
+msgstr ""
+
+#: predict.c:2732
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing counts for called function %s/%i"
+msgstr ""
+
+#: profile.c:499
+#, gcc-internal-format, gfc-internal-format
+msgid "corrupted profile info: edge from %i to %i exceeds maximal count"
+msgstr ""
+
+#: profile.c:579
+#, gcc-internal-format
+msgid "corrupted profile info: sum_all is smaller than sum_max"
+msgstr ""
+
+#: profile.c:762
+#, gcc-internal-format
+msgid "corrupted profile info: profile data is not flow-consistent"
+msgstr ""
+
+#: profile.c:779
+#, gcc-internal-format, gfc-internal-format
+msgid "corrupted profile info: number of iterations for basic block %d thought to be %i"
+msgstr ""
+
+#: profile.c:800
+#, gcc-internal-format, gfc-internal-format
+msgid "corrupted profile info: number of executions for edge %d-%d thought to be %i"
+msgstr ""
+
+#: reg-stack.c:548
+#, gcc-internal-format, gfc-internal-format
+msgid "output constraint %d must specify a single register"
+msgstr ""
+
+#: reg-stack.c:558
+#, gcc-internal-format, gfc-internal-format
+msgid "output constraint %d cannot be specified together with \"%s\" clobber"
+msgstr ""
+
+#: reg-stack.c:581
+#, gcc-internal-format
+msgid "output regs must be grouped at top of stack"
+msgstr ""
+
+#: reg-stack.c:618
+#, gcc-internal-format
+msgid "implicitly popped regs must be grouped at top of stack"
+msgstr ""
+
+#: reg-stack.c:637
+#, gcc-internal-format
+msgid "output operand %d must use %<&%> constraint"
+msgstr ""
+
+#: regcprop.c:1175
+#, gcc-internal-format, gfc-internal-format
+msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
+msgstr ""
+
+#: regcprop.c:1187
+#, gcc-internal-format, gfc-internal-format
+msgid "validate_value_data: Loop in regno chain (%u)"
+msgstr ""
+
+#: regcprop.c:1190
+#, gcc-internal-format, gfc-internal-format
+msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
+msgstr ""
+
+#: regcprop.c:1202
+#, gcc-internal-format, gfc-internal-format
+msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
+msgstr ""
+
+#: reginfo.c:748
+#, gcc-internal-format
+msgid "can%'t use %qs as a call-saved register"
+msgstr ""
+
+#: reginfo.c:752
+#, gcc-internal-format
+msgid "can%'t use %qs as a call-used register"
+msgstr ""
+
+#: reginfo.c:764
+#, gcc-internal-format
+msgid "can%'t use %qs as a fixed register"
+msgstr ""
+
+#: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown register name: %s"
+msgstr ""
+
+#: reginfo.c:803
+#, gcc-internal-format
+msgid "stack register used for global register variable"
+msgstr ""
+
+#: reginfo.c:809
+#, gcc-internal-format
+msgid "global register variable follows a function definition"
+msgstr ""
+
+#: reginfo.c:814
+#, gcc-internal-format
+msgid "register of %qD used for multiple global register variables"
+msgstr ""
+
+#: reginfo.c:817
+#, gcc-internal-format
+msgid "conflicts with %qD"
+msgstr ""
+
+#: reginfo.c:822
+#, gcc-internal-format
+msgid "call-clobbered register used for global register variable"
+msgstr ""
+
+#: reload.c:1344
+#, gcc-internal-format
+msgid "cannot reload integer constant operand in %<asm%>"
+msgstr ""
+
+#: reload.c:1358
+#, gcc-internal-format
+msgid "impossible register constraint in %<asm%>"
+msgstr ""
+
+#: reload.c:3712
+#, gcc-internal-format
+msgid "%<&%> constraint used with no register class"
+msgstr ""
+
+#: reload1.c:1308
+#, gcc-internal-format
+msgid "frame size too large for reliable stack checking"
+msgstr ""
+
+#: reload1.c:1311
+#, gcc-internal-format
+msgid "try reducing the number of local variables"
+msgstr ""
+
+#: reload1.c:2130
+#, gcc-internal-format
+msgid "can%'t find a register in class %qs while reloading %<asm%>"
+msgstr ""
+
+#: reload1.c:2135
+#, gcc-internal-format
+msgid "unable to find a register to spill in class %qs"
+msgstr ""
+
+#: reload1.c:4747
+#, gcc-internal-format
+msgid "%<asm%> operand requires impossible reload"
+msgstr ""
+
+#: reload1.c:6175
+#, gcc-internal-format
+msgid "%<asm%> operand constraint incompatible with operand size"
+msgstr ""
+
+#: reload1.c:8068
+#, gcc-internal-format
+msgid "output operand is constant in %<asm%>"
+msgstr ""
+
+#: rtl.c:700
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
+msgstr ""
+
+#: rtl.c:710
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
+msgstr ""
+
+#: rtl.c:720
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
+msgstr ""
+
+#: rtl.c:729
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
+msgstr ""
+
+#: rtl.c:739
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
+msgstr ""
+
+#: rtl.c:766
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
+msgstr ""
+
+#: rtl.c:776
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
+msgstr ""
+
+#: rtl.c:786
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
+msgstr ""
+
+#: rtl.c:797
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
+msgstr ""
+
+#: stmt.c:259
+#, gcc-internal-format
+msgid "output operand constraint lacks %<=%>"
+msgstr ""
+
+#: stmt.c:274
+#, gcc-internal-format
+msgid "output constraint %qc for operand %d is not at the beginning"
+msgstr ""
+
+#: stmt.c:297
+#, gcc-internal-format
+msgid "operand constraint contains incorrectly positioned %<+%> or %<=%>"
+msgstr ""
+
+#: stmt.c:304 stmt.c:394
+#, gcc-internal-format
+msgid "%<%%%> constraint used with last operand"
+msgstr ""
+
+#: stmt.c:320
+#, gcc-internal-format
+msgid "matching constraint not valid in output operand"
+msgstr ""
+
+#: stmt.c:385
+#, gcc-internal-format
+msgid "input operand constraint contains %qc"
+msgstr ""
+
+#: stmt.c:424
+#, gcc-internal-format
+msgid "matching constraint references invalid operand number"
+msgstr ""
+
+#: stmt.c:458
+#, gcc-internal-format
+msgid "invalid punctuation %qc in constraint"
+msgstr ""
+
+#: stmt.c:479
+#, gcc-internal-format
+msgid "matching constraint does not allow a register"
+msgstr ""
+
+#: stmt.c:573
+#, gcc-internal-format
+msgid "duplicate asm operand name %qs"
+msgstr ""
+
+#: stmt.c:669
+#, gcc-internal-format
+msgid "missing close brace for named operand"
+msgstr ""
+
+#: stmt.c:694
+#, gcc-internal-format
+msgid "undefined named operand %qs"
+msgstr ""
+
+#: stor-layout.c:802
+#, gcc-internal-format
+msgid "size of %q+D is %d bytes"
+msgstr ""
+
+#: stor-layout.c:804
+#, gcc-internal-format
+msgid "size of %q+D is larger than %wd bytes"
+msgstr ""
+
+#: stor-layout.c:1245
+#, gcc-internal-format
+msgid "packed attribute causes inefficient alignment for %q+D"
+msgstr ""
+
+#: stor-layout.c:1249
+#, gcc-internal-format
+msgid "packed attribute is unnecessary for %q+D"
+msgstr ""
+
+#: stor-layout.c:1266
+#, gcc-internal-format
+msgid "padding struct to align %q+D"
+msgstr ""
+
+#: stor-layout.c:1328
+#, gcc-internal-format
+msgid "offset of packed bit-field %qD has changed in GCC 4.4"
+msgstr ""
+
+#: stor-layout.c:1638
+#, gcc-internal-format
+msgid "padding struct size to alignment boundary"
+msgstr ""
+
+#: stor-layout.c:1666
+#, gcc-internal-format
+msgid "packed attribute causes inefficient alignment for %qE"
+msgstr ""
+
+#: stor-layout.c:1670
+#, gcc-internal-format
+msgid "packed attribute is unnecessary for %qE"
+msgstr ""
+
+#: stor-layout.c:1676
+#, gcc-internal-format
+msgid "packed attribute causes inefficient alignment"
+msgstr ""
+
+#: stor-layout.c:1678
+#, gcc-internal-format
+msgid "packed attribute is unnecessary"
+msgstr ""
+
+#: stor-layout.c:2388
+#, gcc-internal-format
+msgid "alignment of array elements is greater than element size"
+msgstr ""
+
+#: symtab.c:303
+#, gcc-internal-format
+msgid "%D renamed after being referenced in assembly"
+msgstr ""
+
+#: symtab.c:918
+#, gcc-internal-format
+msgid "function symbol is not function"
+msgstr ""
+
+#: symtab.c:926
+#, gcc-internal-format
+msgid "variable symbol is not variable"
+msgstr ""
+
+#: symtab.c:932
+#, gcc-internal-format
+msgid "node has unknown type"
+msgstr ""
+
+#: symtab.c:941
+#, gcc-internal-format
+msgid "node not found node->decl->decl_with_vis.symtab_node"
+msgstr ""
+
+#: symtab.c:949
+#, gcc-internal-format
+msgid "node differs from node->decl->decl_with_vis.symtab_node"
+msgstr ""
+
+#: symtab.c:958
+#, gcc-internal-format
+msgid "assembler name hash list corrupted"
+msgstr ""
+
+#: symtab.c:971
+#, gcc-internal-format
+msgid "node not found in symtab assembler name hash"
+msgstr ""
+
+#: symtab.c:978
+#, gcc-internal-format
+msgid "double linked list of assembler names corrupted"
+msgstr ""
+
+#: symtab.c:983
+#, gcc-internal-format
+msgid "node has body_removed but is definition"
+msgstr ""
+
+#: symtab.c:988
+#, gcc-internal-format
+msgid "node is analyzed byt it is not a definition"
+msgstr ""
+
+#: symtab.c:993
+#, gcc-internal-format
+msgid "node is alias but not implicit alias"
+msgstr ""
+
+#: symtab.c:998
+#, gcc-internal-format
+msgid "node is alias but not definition"
+msgstr ""
+
+#: symtab.c:1003
+#, gcc-internal-format
+msgid "node is weakref but not an alias"
+msgstr ""
+
+#: symtab.c:1012
+#, gcc-internal-format
+msgid "node is in same_comdat_group list but has no comdat_group"
+msgstr ""
+
+#: symtab.c:1017
+#, gcc-internal-format
+msgid "same_comdat_group list across different groups"
+msgstr ""
+
+#: symtab.c:1022
+#, gcc-internal-format
+msgid "mixing different types of symbol in same comdat groups is not supported"
+msgstr ""
+
+#: symtab.c:1027
+#, gcc-internal-format
+msgid "node is alone in a comdat group"
+msgstr ""
+
+#: symtab.c:1034
+#, gcc-internal-format
+msgid "same_comdat_group is not a circular list"
+msgstr ""
+
+#: symtab.c:1049
+#, gcc-internal-format, gfc-internal-format
+msgid "comdat-local symbol referred to by %s outside its comdat"
+msgstr ""
+
+#: symtab.c:1059
+#, gcc-internal-format
+msgid "implicit_section flag is set but section isn't"
+msgstr ""
+
+#: symtab.c:1066
+#, gcc-internal-format
+msgid "Both section and comdat group is set"
+msgstr ""
+
+#: symtab.c:1078
+#, gcc-internal-format
+msgid "Alias and target's section differs"
+msgstr ""
+
+#: symtab.c:1085
+#, gcc-internal-format
+msgid "Alias and target's comdat groups differs"
+msgstr ""
+
+#: symtab.c:1108 symtab.c:1145
+#, gcc-internal-format
+msgid "symtab_node::verify failed"
+msgstr ""
+
+#: symtab.c:1141
+#, gcc-internal-format
+msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
+msgstr ""
+
+#: symtab.c:1483
+#, gcc-internal-format
+msgid "function %q+D part of alias cycle"
+msgstr ""
+
+#: symtab.c:1485
+#, gcc-internal-format
+msgid "variable %q+D part of alias cycle"
+msgstr ""
+
+#: symtab.c:1508
+#, gcc-internal-format
+msgid "section of alias %q+D must match section of its target"
+msgstr ""
+
+#: targhooks.c:198
+#, gcc-internal-format
+msgid "__builtin_saveregs not supported by this target"
+msgstr ""
+
+#: targhooks.c:887
+#, gcc-internal-format
+msgid "nested functions not supported on this target"
+msgstr ""
+
+#: targhooks.c:900
+#, gcc-internal-format
+msgid "nested function trampolines not supported on this target"
+msgstr ""
+
+#: targhooks.c:1306
+#, gcc-internal-format
+msgid "target attribute is not supported on this machine"
+msgstr ""
+
+#: targhooks.c:1316
+#, gcc-internal-format
+msgid "#pragma GCC target is not supported for this machine"
+msgstr ""
+
+#: tlink.c:489
+#, gcc-internal-format
+msgid "removing .rpo file: %m"
+msgstr ""
+
+#: tlink.c:491
+#, gcc-internal-format
+msgid "renaming .rpo file: %m"
+msgstr ""
+
+#: tlink.c:495
+#, gcc-internal-format, gfc-internal-format
+msgid "repository file '%s' does not contain command-line arguments"
+msgstr ""
+
+#: tlink.c:621
+#, gcc-internal-format, gfc-internal-format
+msgid "'%s' was assigned to '%s', but was not defined during recompilation, or vice versa"
+msgstr ""
+
+#: tlink.c:858
+#, gcc-internal-format, gfc-internal-format
+msgid "ld returned %d exit status"
+msgstr ""
+
+#: toplev.c:522 c/c-decl.c:10662
+#, gcc-internal-format
+msgid "%q+F used but never defined"
+msgstr ""
+
+#: toplev.c:524
+#, gcc-internal-format
+msgid "%q+F declared %<static%> but never defined"
+msgstr ""
+
+#: toplev.c:551
+#, gcc-internal-format
+msgid "%q+D defined but not used"
+msgstr ""
+
+#: toplev.c:996
+#, gcc-internal-format
+msgid "can%'t open %qs for writing: %m"
+msgstr ""
+
+#: toplev.c:1017
+#, gcc-internal-format
+msgid "-frecord-gcc-switches is not supported by the current target"
+msgstr ""
+
+#: toplev.c:1065
+#, gcc-internal-format
+msgid "stack usage computation not supported for this target"
+msgstr ""
+
+#: toplev.c:1134
+#, gcc-internal-format
+msgid "stack usage might be unbounded"
+msgstr ""
+
+#: toplev.c:1139
+#, gcc-internal-format
+msgid "stack usage might be %wd bytes"
+msgstr ""
+
+#: toplev.c:1142
+#, gcc-internal-format
+msgid "stack usage is %wd bytes"
+msgstr ""
+
+#: toplev.c:1158
+#, gcc-internal-format
+msgid "can%'t open %s for writing: %m"
+msgstr ""
+
+#: toplev.c:1341
+#, gcc-internal-format
+msgid "this target does not support %qs"
+msgstr ""
+
+#: toplev.c:1369
+#, gcc-internal-format
+msgid "Graphite loop optimizations cannot be used (ISL is not available)(-fgraphite, -fgraphite-identity, -floop-block, -floop-interchange, -floop-strip-mine, -floop-parallelize-all, -floop-unroll-and-jam, and -ftree-loop-linear)"
+msgstr ""
+
+#: toplev.c:1379
+#, gcc-internal-format
+msgid "-fcheck-pointer-bounds is not supported for this target"
+msgstr ""
+
+#: toplev.c:1385
+#, gcc-internal-format
+msgid "-fcheck-pointer-bounds is not supported with Address Sanitizer"
+msgstr ""
+
+#. -fabi-version=1 support was removed after GCC 4.9.
+#: toplev.c:1399
+#, gcc-internal-format
+msgid "%<-fabi-version=1%> is no longer supported"
+msgstr ""
+
+#: toplev.c:1426
+#, gcc-internal-format
+msgid "instruction scheduling not supported on this target machine"
+msgstr ""
+
+#: toplev.c:1430
+#, gcc-internal-format
+msgid "this target machine does not have delayed branches"
+msgstr ""
+
+#: toplev.c:1444
+#, gcc-internal-format, gfc-internal-format
+msgid "-f%sleading-underscore not supported on this target machine"
+msgstr ""
+
+#: toplev.c:1487
+#, gcc-internal-format
+msgid "could not close zeroed insn dump file %qs: %m"
+msgstr ""
+
+#: toplev.c:1521
+#, gcc-internal-format
+msgid "target system does not support the %qs debug format"
+msgstr ""
+
+#: toplev.c:1533
+#, gcc-internal-format
+msgid "variable tracking requested, but useless unless producing debug info"
+msgstr ""
+
+#: toplev.c:1536
+#, gcc-internal-format
+msgid "variable tracking requested, but not supported by this debug format"
+msgstr ""
+
+#: toplev.c:1573
+#, gcc-internal-format
+msgid "var-tracking-assignments changes selective scheduling"
+msgstr ""
+
+#: toplev.c:1596
+#, gcc-internal-format
+msgid "-ffunction-sections not supported for this target"
+msgstr ""
+
+#: toplev.c:1601
+#, gcc-internal-format
+msgid "-fdata-sections not supported for this target"
+msgstr ""
+
+#: toplev.c:1609
+#, gcc-internal-format
+msgid "-fprefetch-loop-arrays not supported for this target"
+msgstr ""
+
+#: toplev.c:1615
+#, gcc-internal-format
+msgid "-fprefetch-loop-arrays not supported for this target (try -march switches)"
+msgstr ""
+
+#: toplev.c:1624
+#, gcc-internal-format
+msgid "-fprefetch-loop-arrays is not supported with -Os"
+msgstr ""
+
+#: toplev.c:1635
+#, gcc-internal-format
+msgid "-fassociative-math disabled; other options take precedence"
+msgstr ""
+
+#: toplev.c:1651
+#, gcc-internal-format
+msgid "-fstack-protector not supported for this target"
+msgstr ""
+
+#: toplev.c:1663
+#, gcc-internal-format
+msgid "-fsanitize=address and -fsanitize=kernel-address are not supported for this target"
+msgstr ""
+
+#: toplev.c:1671
+#, gcc-internal-format
+msgid "-fsanitize=address not supported for this target"
+msgstr ""
+
+#: toplev.c:1986
+#, gcc-internal-format
+msgid "error writing to %s: %m"
+msgstr ""
+
+#: toplev.c:1988 java/jcf-parse.c:1793
+#, gcc-internal-format
+msgid "error closing %s: %m"
+msgstr ""
+
+#: trans-mem.c:648
+#, gcc-internal-format
+msgid "invalid volatile use of %qD inside transaction"
+msgstr ""
+
+#: trans-mem.c:680
+#, gcc-internal-format
+msgid "%<transaction_may_cancel_outer%> function call not within outer transaction or %<transaction_may_cancel_outer%>"
+msgstr ""
+
+#: trans-mem.c:749 trans-mem.c:4793
+#, gcc-internal-format
+msgid "unsafe function call %qD within atomic transaction"
+msgstr ""
+
+#: trans-mem.c:755
+#, gcc-internal-format
+msgid "unsafe function call %qE within atomic transaction"
+msgstr ""
+
+#: trans-mem.c:759
+#, gcc-internal-format
+msgid "unsafe indirect function call within atomic transaction"
+msgstr ""
+
+#: trans-mem.c:767 trans-mem.c:4725
+#, gcc-internal-format
+msgid "unsafe function call %qD within %<transaction_safe%> function"
+msgstr ""
+
+#: trans-mem.c:773
+#, gcc-internal-format
+msgid "unsafe function call %qE within %<transaction_safe%> function"
+msgstr ""
+
+#: trans-mem.c:777
+#, gcc-internal-format
+msgid "unsafe indirect function call within %<transaction_safe%> function"
+msgstr ""
+
+#: trans-mem.c:792 trans-mem.c:4765
+#, gcc-internal-format
+msgid "asm not allowed in atomic transaction"
+msgstr ""
+
+#: trans-mem.c:795
+#, gcc-internal-format
+msgid "asm not allowed in %<transaction_safe%> function"
+msgstr ""
+
+#: trans-mem.c:807
+#, gcc-internal-format
+msgid "relaxed transaction in atomic transaction"
+msgstr ""
+
+#: trans-mem.c:810
+#, gcc-internal-format
+msgid "relaxed transaction in %<transaction_safe%> function"
+msgstr ""
+
+#: trans-mem.c:817
+#, gcc-internal-format
+msgid "outer transaction in transaction"
+msgstr ""
+
+#: trans-mem.c:820
+#, gcc-internal-format
+msgid "outer transaction in %<transaction_may_cancel_outer%> function"
+msgstr ""
+
+#: trans-mem.c:824
+#, gcc-internal-format
+msgid "outer transaction in %<transaction_safe%> function"
+msgstr ""
+
+#: trans-mem.c:4391
+#, gcc-internal-format
+msgid "%Kasm not allowed in %<transaction_safe%> function"
+msgstr ""
+
+#: tree-cfg.c:373
+#, gcc-internal-format
+msgid "ignoring loop annotation"
+msgstr ""
+
+#: tree-cfg.c:2755
+#, gcc-internal-format
+msgid "constant not recomputed when ADDR_EXPR changed"
+msgstr ""
+
+#: tree-cfg.c:2760
+#, gcc-internal-format
+msgid "side effects not recomputed when ADDR_EXPR changed"
+msgstr ""
+
+#: tree-cfg.c:2771
+#, gcc-internal-format
+msgid "DECL_GIMPLE_REG_P set on a variable with address taken"
+msgstr ""
+
+#: tree-cfg.c:2800
+#, gcc-internal-format
+msgid "SSA name in freelist but still referenced"
+msgstr ""
+
+#: tree-cfg.c:2806 tree-cfg.c:4131
+#, gcc-internal-format
+msgid "INDIRECT_REF in gimple IL"
+msgstr ""
+
+#: tree-cfg.c:2814
+#, gcc-internal-format
+msgid "invalid first operand of MEM_REF"
+msgstr ""
+
+#: tree-cfg.c:2820
+#, gcc-internal-format
+msgid "invalid offset operand of MEM_REF"
+msgstr ""
+
+#: tree-cfg.c:2833
+#, gcc-internal-format
+msgid "ASSERT_EXPR with an always-false condition"
+msgstr ""
+
+#: tree-cfg.c:2839
+#, gcc-internal-format
+msgid "MODIFY_EXPR not expected while having tuples"
+msgstr ""
+
+#: tree-cfg.c:2866 tree-ssa.c:899
+#, gcc-internal-format
+msgid "address taken, but ADDRESSABLE bit not set"
+msgstr ""
+
+#: tree-cfg.c:2877
+#, gcc-internal-format
+msgid "non-integral used in condition"
+msgstr ""
+
+#: tree-cfg.c:2882
+#, gcc-internal-format
+msgid "invalid conditional operand"
+msgstr ""
+
+#: tree-cfg.c:2905
+#, gcc-internal-format
+msgid "non-scalar BIT_FIELD_REF, IMAGPART_EXPR or REALPART_EXPR"
+msgstr ""
+
+#: tree-cfg.c:2917
+#, gcc-internal-format
+msgid "invalid position or size operand to BIT_FIELD_REF"
+msgstr ""
+
+#: tree-cfg.c:2924
+#, gcc-internal-format
+msgid "integral result type precision does not match field size of BIT_FIELD_REF"
+msgstr ""
+
+#: tree-cfg.c:2933
+#, gcc-internal-format
+msgid "mode precision of non-integral result does not match field size of BIT_FIELD_REF"
+msgstr ""
+
+#: tree-cfg.c:2941
+#, gcc-internal-format
+msgid "position plus size exceeds size of referenced object in BIT_FIELD_REF"
+msgstr ""
+
+#: tree-cfg.c:2974
+#, gcc-internal-format
+msgid "non-top-level BIT_FIELD_REF, IMAGPART_EXPR or REALPART_EXPR"
+msgstr ""
+
+#: tree-cfg.c:2984
+#, gcc-internal-format
+msgid "invalid reference prefix"
+msgstr ""
+
+#: tree-cfg.c:2995
+#, gcc-internal-format
+msgid "invalid operand to plus/minus, type is a pointer"
+msgstr ""
+
+#: tree-cfg.c:3006
+#, gcc-internal-format
+msgid "invalid operand to pointer plus, first operand is not a pointer"
+msgstr ""
+
+#: tree-cfg.c:3012
+#, gcc-internal-format
+msgid "invalid operand to pointer plus, second operand is not an integer type of appropriate width"
+msgstr ""
+
+#: tree-cfg.c:3063
+#, gcc-internal-format
+msgid "invalid CASE_CHAIN"
+msgstr ""
+
+#: tree-cfg.c:3091
+#, gcc-internal-format
+msgid "invalid expression for min lvalue"
+msgstr ""
+
+#: tree-cfg.c:3102
+#, gcc-internal-format
+msgid "invalid operand in indirect reference"
+msgstr ""
+
+#: tree-cfg.c:3131
+#, gcc-internal-format
+msgid "invalid operands to array reference"
+msgstr ""
+
+#: tree-cfg.c:3142
+#, gcc-internal-format
+msgid "type mismatch in array reference"
+msgstr ""
+
+#: tree-cfg.c:3151
+#, gcc-internal-format
+msgid "type mismatch in array range reference"
+msgstr ""
+
+#: tree-cfg.c:3162
+#, gcc-internal-format
+msgid "type mismatch in real/imagpart reference"
+msgstr ""
+
+#: tree-cfg.c:3172
+#, gcc-internal-format
+msgid "type mismatch in component reference"
+msgstr ""
+
+#: tree-cfg.c:3189
+#, gcc-internal-format
+msgid "conversion of an SSA_NAME on the left hand side"
+msgstr ""
+
+#: tree-cfg.c:3196
+#, gcc-internal-format
+msgid "conversion of register to a different size"
+msgstr ""
+
+#: tree-cfg.c:3211
+#, gcc-internal-format
+msgid "invalid address operand in MEM_REF"
+msgstr ""
+
+#: tree-cfg.c:3218
+#, gcc-internal-format
+msgid "invalid offset operand in MEM_REF"
+msgstr ""
+
+#: tree-cfg.c:3228
+#, gcc-internal-format
+msgid "invalid address operand in TARGET_MEM_REF"
+msgstr ""
+
+#: tree-cfg.c:3235
+#, gcc-internal-format
+msgid "invalid offset operand in TARGET_MEM_REF"
+msgstr ""
+
+#: tree-cfg.c:3289
+#, gcc-internal-format
+msgid "gimple call has two targets"
+msgstr ""
+
+#: tree-cfg.c:3298
+#, gcc-internal-format
+msgid "gimple call has no target"
+msgstr ""
+
+#: tree-cfg.c:3305
+#, gcc-internal-format
+msgid "invalid function in gimple call"
+msgstr ""
+
+#: tree-cfg.c:3315
+#, gcc-internal-format
+msgid "non-function in gimple call"
+msgstr ""
+
+#: tree-cfg.c:3326
+#, gcc-internal-format
+msgid "invalid pure const state for function"
+msgstr ""
+
+#: tree-cfg.c:3334
+#, gcc-internal-format
+msgid "invalid LHS in gimple call"
+msgstr ""
+
+#: tree-cfg.c:3342
+#, gcc-internal-format
+msgid "LHS in noreturn call"
+msgstr ""
+
+#: tree-cfg.c:3359
+#, gcc-internal-format
+msgid "invalid conversion in gimple call"
+msgstr ""
+
+#: tree-cfg.c:3368
+#, gcc-internal-format
+msgid "invalid static chain in gimple call"
+msgstr ""
+
+#: tree-cfg.c:3379
+#, gcc-internal-format
+msgid "static chain with function that doesn%'t use one"
+msgstr ""
+
+#: tree-cfg.c:3396
+#, gcc-internal-format
+msgid "invalid argument to gimple call"
+msgstr ""
+
+#: tree-cfg.c:3416
+#, gcc-internal-format
+msgid "invalid operands in gimple comparison"
+msgstr ""
+
+#: tree-cfg.c:3432
+#, gcc-internal-format
+msgid "mismatching comparison operand types"
+msgstr ""
+
+#: tree-cfg.c:3446
+#, gcc-internal-format
+msgid "vector comparison returning a boolean"
+msgstr ""
+
+#: tree-cfg.c:3460
+#, gcc-internal-format
+msgid "non-vector operands in vector comparison"
+msgstr ""
+
+#: tree-cfg.c:3473
+#, gcc-internal-format
+msgid "invalid vector comparison resulting type"
+msgstr ""
+
+#: tree-cfg.c:3480
+#, gcc-internal-format
+msgid "bogus comparison result type"
+msgstr ""
+
+#: tree-cfg.c:3502
+#, gcc-internal-format
+msgid "non-register as LHS of unary operation"
+msgstr ""
+
+#: tree-cfg.c:3508
+#, gcc-internal-format
+msgid "invalid operand in unary operation"
+msgstr ""
+
+#: tree-cfg.c:3540
+#, gcc-internal-format
+msgid "invalid types in nop conversion"
+msgstr ""
+
+#: tree-cfg.c:3555
+#, gcc-internal-format
+msgid "invalid types in address space conversion"
+msgstr ""
+
+#: tree-cfg.c:3569
+#, gcc-internal-format
+msgid "invalid types in fixed-point conversion"
+msgstr ""
+
+#: tree-cfg.c:3584
+#, gcc-internal-format
+msgid "invalid types in conversion to floating point"
+msgstr ""
+
+#: tree-cfg.c:3599
+#, gcc-internal-format
+msgid "invalid types in conversion to integer"
+msgstr ""
+
+#: tree-cfg.c:3613
+#, gcc-internal-format
+msgid "reduction should convert from vector to element type"
+msgstr ""
+
+#: tree-cfg.c:3641
+#, gcc-internal-format
+msgid "non-trivial conversion in unary operation"
+msgstr ""
+
+#: tree-cfg.c:3666
+#, gcc-internal-format
+msgid "non-register as LHS of binary operation"
+msgstr ""
+
+#: tree-cfg.c:3673
+#, gcc-internal-format
+msgid "invalid operands in binary operation"
+msgstr ""
+
+#: tree-cfg.c:3688
+#, gcc-internal-format
+msgid "type mismatch in complex expression"
+msgstr ""
+
+#: tree-cfg.c:3717
+#, gcc-internal-format
+msgid "type mismatch in shift expression"
+msgstr ""
+
+#: tree-cfg.c:3734 tree-cfg.c:3755
+#, gcc-internal-format
+msgid "type mismatch in widening vector shift expression"
+msgstr ""
+
+#: tree-cfg.c:3776
+#, gcc-internal-format
+msgid "invalid non-vector operands to vector valued plus"
+msgstr ""
+
+#: tree-cfg.c:3787
+#, gcc-internal-format
+msgid "invalid (pointer) operands to plus/minus"
+msgstr ""
+
+#: tree-cfg.c:3801
+#, gcc-internal-format
+msgid "type mismatch in pointer plus expression"
+msgstr ""
+
+#: tree-cfg.c:3881
+#, gcc-internal-format
+msgid "type mismatch in binary expression"
+msgstr ""
+
+#: tree-cfg.c:3909
+#, gcc-internal-format
+msgid "non-register as LHS of ternary operation"
+msgstr ""
+
+#: tree-cfg.c:3918
+#, gcc-internal-format
+msgid "invalid operands in ternary operation"
+msgstr ""
+
+#: tree-cfg.c:3934
+#, gcc-internal-format
+msgid "type mismatch in widening multiply-accumulate expression"
+msgstr ""
+
+#: tree-cfg.c:3948
+#, gcc-internal-format
+msgid "type mismatch in fused multiply-add expression"
+msgstr ""
+
+#: tree-cfg.c:3962 c/c-typeck.c:4739
+#, gcc-internal-format
+msgid "type mismatch in conditional expression"
+msgstr ""
+
+#: tree-cfg.c:3974
+#, gcc-internal-format
+msgid "type mismatch in vector permute expression"
+msgstr ""
+
+#: tree-cfg.c:3986
+#, gcc-internal-format
+msgid "vector types expected in vector permute expression"
+msgstr ""
+
+#: tree-cfg.c:4000
+#, gcc-internal-format
+msgid "vectors with different element number found in vector permute expression"
+msgstr ""
+
+#: tree-cfg.c:4013
+#, gcc-internal-format
+msgid "invalid mask type in vector permute expression"
+msgstr ""
+
+#: tree-cfg.c:4031
+#, gcc-internal-format
+msgid "type mismatch in sad expression"
+msgstr ""
+
+#: tree-cfg.c:4043
+#, gcc-internal-format
+msgid "vector types expected in sad expression"
+msgstr ""
+
+#: tree-cfg.c:4079
+#, gcc-internal-format
+msgid "non-trivial conversion at assignment"
+msgstr ""
+
+#: tree-cfg.c:4088
+#, gcc-internal-format
+msgid "non-decl/MEM_REF LHS in clobber statement"
+msgstr ""
+
+#: tree-cfg.c:4106
+#, gcc-internal-format
+msgid "invalid operand in unary expression"
+msgstr ""
+
+#: tree-cfg.c:4120
+#, gcc-internal-format
+msgid "type mismatch in address expression"
+msgstr ""
+
+#: tree-cfg.c:4146 tree-cfg.c:4172
+#, gcc-internal-format
+msgid "invalid rhs for gimple memory store"
+msgstr ""
+
+#: tree-cfg.c:4206 tree-cfg.c:4224 tree-cfg.c:4238
+#, gcc-internal-format
+msgid "incorrect type of vector CONSTRUCTOR elements"
+msgstr ""
+
+#: tree-cfg.c:4215 tree-cfg.c:4231
+#, gcc-internal-format
+msgid "incorrect number of vector CONSTRUCTOR elements"
+msgstr ""
+
+#: tree-cfg.c:4247
+#, gcc-internal-format
+msgid "vector CONSTRUCTOR with non-NULL element index"
+msgstr ""
+
+#: tree-cfg.c:4253
+#, gcc-internal-format
+msgid "vector CONSTRUCTOR element is not a GIMPLE value"
+msgstr ""
+
+#: tree-cfg.c:4261
+#, gcc-internal-format
+msgid "non-vector CONSTRUCTOR with elements"
+msgstr ""
+
+#: tree-cfg.c:4320
+#, gcc-internal-format
+msgid "invalid operand in return statement"
+msgstr ""
+
+#: tree-cfg.c:4335
+#, gcc-internal-format
+msgid "invalid conversion in return statement"
+msgstr ""
+
+#: tree-cfg.c:4359
+#, gcc-internal-format
+msgid "goto destination is neither a label nor a pointer"
+msgstr ""
+
+#: tree-cfg.c:4378
+#, gcc-internal-format
+msgid "invalid operand to switch statement"
+msgstr ""
+
+#: tree-cfg.c:4386
+#, gcc-internal-format
+msgid "non-integral type switch statement"
+msgstr ""
+
+#: tree-cfg.c:4394
+#, gcc-internal-format
+msgid "invalid default case label in switch statement"
+msgstr ""
+
+#: tree-cfg.c:4406
+#, gcc-internal-format
+msgid "invalid case label in switch statement"
+msgstr ""
+
+#: tree-cfg.c:4413
+#, gcc-internal-format
+msgid "invalid case range in switch statement"
+msgstr ""
+
+#: tree-cfg.c:4423
+#, gcc-internal-format
+msgid "type mismatch for case label in switch statement"
+msgstr ""
+
+#: tree-cfg.c:4433
+#, gcc-internal-format
+msgid "type precision mismatch in switch statement"
+msgstr ""
+
+#: tree-cfg.c:4442
+#, gcc-internal-format
+msgid "case labels not sorted in switch statement"
+msgstr ""
+
+#: tree-cfg.c:4485
+#, gcc-internal-format
+msgid "label's context is not the current function decl"
+msgstr ""
+
+#: tree-cfg.c:4494
+#, gcc-internal-format
+msgid "incorrect entry in label_to_block_map"
+msgstr ""
+
+#: tree-cfg.c:4504
+#, gcc-internal-format
+msgid "incorrect setting of landing pad number"
+msgstr ""
+
+#: tree-cfg.c:4520
+#, gcc-internal-format
+msgid "invalid comparison code in gimple cond"
+msgstr ""
+
+#: tree-cfg.c:4528
+#, gcc-internal-format
+msgid "invalid labels in gimple cond"
+msgstr ""
+
+#: tree-cfg.c:4610 tree-cfg.c:4619
+#, gcc-internal-format
+msgid "invalid PHI result"
+msgstr ""
+
+#: tree-cfg.c:4629
+#, gcc-internal-format
+msgid "missing PHI def"
+msgstr ""
+
+#: tree-cfg.c:4643
+#, gcc-internal-format
+msgid "invalid PHI argument"
+msgstr ""
+
+#: tree-cfg.c:4650
+#, gcc-internal-format, gfc-internal-format
+msgid "incompatible types in PHI argument %u"
+msgstr ""
+
+#: tree-cfg.c:4739 tree-cfg.c:5072
+#, gcc-internal-format
+msgid "verify_gimple failed"
+msgstr ""
+
+#: tree-cfg.c:4799
+#, gcc-internal-format
+msgid "dead STMT in EH table"
+msgstr ""
+
+#: tree-cfg.c:4815
+#, gcc-internal-format
+msgid "location references block not in block tree"
+msgstr ""
+
+#: tree-cfg.c:4938
+#, gcc-internal-format
+msgid "gimple_bb (phi) is set to a wrong basic block"
+msgstr ""
+
+#: tree-cfg.c:4947
+#, gcc-internal-format
+msgid "PHI node with location"
+msgstr ""
+
+#: tree-cfg.c:4958 tree-cfg.c:5007
+#, gcc-internal-format
+msgid "incorrect sharing of tree nodes"
+msgstr ""
+
+#: tree-cfg.c:4966
+#, gcc-internal-format
+msgid "virtual PHI with argument locations"
+msgstr ""
+
+#: tree-cfg.c:4995
+#, gcc-internal-format
+msgid "gimple_bb (stmt) is set to a wrong basic block"
+msgstr ""
+
+#: tree-cfg.c:5031
+#, gcc-internal-format
+msgid "in statement"
+msgstr ""
+
+#: tree-cfg.c:5048
+#, gcc-internal-format
+msgid "statement marked for throw, but doesn%'t"
+msgstr ""
+
+#: tree-cfg.c:5054
+#, gcc-internal-format
+msgid "statement marked for throw in middle of block"
+msgstr ""
+
+#: tree-cfg.c:5094
+#, gcc-internal-format
+msgid "ENTRY_BLOCK has IL associated with it"
+msgstr ""
+
+#: tree-cfg.c:5101
+#, gcc-internal-format
+msgid "EXIT_BLOCK has IL associated with it"
+msgstr ""
+
+#: tree-cfg.c:5108
+#, gcc-internal-format, gfc-internal-format
+msgid "fallthru to exit from bb %d"
+msgstr ""
+
+#: tree-cfg.c:5132
+#, gcc-internal-format
+msgid "nonlocal label "
+msgstr ""
+
+#: tree-cfg.c:5141
+#, gcc-internal-format
+msgid "EH landing pad label "
+msgstr ""
+
+#: tree-cfg.c:5150 tree-cfg.c:5159 tree-cfg.c:5184
+#, gcc-internal-format
+msgid "label "
+msgstr "мітка "
+
+#: tree-cfg.c:5174
+#, gcc-internal-format, gfc-internal-format
+msgid "control flow in the middle of basic block %d"
+msgstr ""
+
+#: tree-cfg.c:5207
+#, gcc-internal-format, gfc-internal-format
+msgid "fallthru edge after a control statement in bb %d"
+msgstr ""
+
+#: tree-cfg.c:5220
+#, gcc-internal-format, gfc-internal-format
+msgid "true/false edge after a non-GIMPLE_COND in bb %d"
+msgstr ""
+
+#: tree-cfg.c:5243 tree-cfg.c:5265 tree-cfg.c:5282 tree-cfg.c:5352
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong outgoing edge flags at end of bb %d"
+msgstr ""
+
+#: tree-cfg.c:5253
+#, gcc-internal-format, gfc-internal-format
+msgid "explicit goto at end of bb %d"
+msgstr ""
+
+#: tree-cfg.c:5287
+#, gcc-internal-format, gfc-internal-format
+msgid "return edge does not point to exit in bb %d"
+msgstr ""
+
+#: tree-cfg.c:5318
+#, gcc-internal-format
+msgid "found default case not at the start of case vector"
+msgstr ""
+
+#: tree-cfg.c:5326
+#, gcc-internal-format
+msgid "case labels not sorted: "
+msgstr ""
+
+#: tree-cfg.c:5343
+#, gcc-internal-format, gfc-internal-format
+msgid "extra outgoing edge %d->%d"
+msgstr ""
+
+#: tree-cfg.c:5366
+#, gcc-internal-format, gfc-internal-format
+msgid "missing edge %i->%i"
+msgstr ""
+
+#: tree-cfg.c:8461
+#, gcc-internal-format
+msgid "%<noreturn%> function does return"
+msgstr ""
+
+#: tree-cfg.c:8482
+#, gcc-internal-format
+msgid "control reaches end of non-void function"
+msgstr ""
+
+#: tree-cfg.c:8548
+#, gcc-internal-format
+msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
+msgstr ""
+
+#: tree-cfg.c:8553
+#, gcc-internal-format
+msgid "ignoring return value of function declared with attribute warn_unused_result"
+msgstr ""
+
+#: tree-chkp-opt.c:761
+#, gcc-internal-format
+msgid "memory access check always fail"
+msgstr ""
+
+#: tree-chkp.c:1994
+#, gcc-internal-format, gfc-internal-format
+msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
+msgstr ""
+
+#: tree-chkp.c:2701
+#, gcc-internal-format, gfc-internal-format
+msgid "pointer bounds were lost due to unexpected expression %s"
+msgstr ""
+
+#: tree-chkp.c:2776
+#, gcc-internal-format, gfc-internal-format
+msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
+msgstr ""
+
+#: tree-chkp.c:2819
+#, gcc-internal-format, gfc-internal-format
+msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
+msgstr ""
+
+#: tree-chkp.c:3440
+#, gcc-internal-format, gfc-internal-format
+msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
+msgstr ""
+
+#: tree-chkp.c:3592
+#, gcc-internal-format, gfc-internal-format
+msgid "chkp_find_bounds: Unexpected tree code %s"
+msgstr ""
+
+#: tree-chkp.c:3603
+#, gcc-internal-format
+msgid "chkp_find_bounds: Cannot find bounds for pointer"
+msgstr ""
+
+#: tree-chkp.c:3719
+#, gcc-internal-format, gfc-internal-format
+msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
+msgstr ""
+
+#: tree-diagnostic.c:213
+#, gcc-internal-format
+msgid "in definition of macro %qs"
+msgstr ""
+
+#: tree-diagnostic.c:230
+#, gcc-internal-format
+msgid "in expansion of macro %qs"
+msgstr ""
+
+#: tree-eh.c:4682
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i has multiple EH edges"
+msgstr ""
+
+#: tree-eh.c:4694
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i can not throw but has an EH edge"
+msgstr ""
+
+#: tree-eh.c:4702
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i last statement has incorrectly set lp"
+msgstr ""
+
+#: tree-eh.c:4708
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i is missing an EH edge"
+msgstr ""
+
+#: tree-eh.c:4714
+#, gcc-internal-format, gfc-internal-format
+msgid "Incorrect EH edge %i->%i"
+msgstr ""
+
+#: tree-eh.c:4748 tree-eh.c:4767
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i is missing an edge"
+msgstr ""
+
+#: tree-eh.c:4784
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i too many fallthru edges"
+msgstr ""
+
+#: tree-eh.c:4793
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i has incorrect edge"
+msgstr ""
+
+#: tree-eh.c:4799
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i has incorrect fallthru edge"
+msgstr ""
+
+#: tree-inline.c:3566
+#, gcc-internal-format
+msgid "function %q+F can never be copied because it receives a non-local goto"
+msgstr ""
+
+#: tree-inline.c:3580
+#, gcc-internal-format
+msgid "function %q+F can never be copied because it saves address of local label in a static variable"
+msgstr ""
+
+#: tree-inline.c:3620
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
+msgstr ""
+
+#: tree-inline.c:3634
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses setjmp"
+msgstr ""
+
+#: tree-inline.c:3648
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses variable argument lists"
+msgstr ""
+
+#: tree-inline.c:3660
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
+msgstr ""
+
+#: tree-inline.c:3668
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses non-local goto"
+msgstr ""
+
+#: tree-inline.c:3680
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses __builtin_return or __builtin_apply_args"
+msgstr ""
+
+#: tree-inline.c:3700
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it contains a computed goto"
+msgstr ""
+
+#: tree-inline.c:3801
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it is suppressed using -fno-inline"
+msgstr ""
+
+#: tree-inline.c:3809
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
+msgstr ""
+
+#: tree-inline.c:4430
+#, gcc-internal-format
+msgid "inlining failed in call to always_inline %q+F: %s"
+msgstr ""
+
+#: tree-inline.c:4432 tree-inline.c:4447
+#, gcc-internal-format
+msgid "called from here"
+msgstr ""
+
+#: tree-inline.c:4445
+#, gcc-internal-format
+msgid "inlining failed in call to %q+F: %s"
+msgstr ""
+
+#: tree-into-ssa.c:3233
+#, gcc-internal-format
+msgid "statement uses released SSA name:"
+msgstr ""
+
+#: tree-into-ssa.c:3245
+#, gcc-internal-format
+msgid "cannot update SSA form"
+msgstr ""
+
+#: tree-into-ssa.c:3332 tree-outof-ssa.c:891 tree-outof-ssa.c:948
+#: tree-ssa-coalesce.c:927 tree-ssa-live.c:1417
+#, gcc-internal-format
+msgid "SSA corruption"
+msgstr ""
+
+#: tree-profile.c:488
+#, gcc-internal-format
+msgid "unimplemented functionality"
+msgstr ""
+
+#: tree-ssa-loop-niter.c:2665
+#, gcc-internal-format
+msgid "iteration %E invokes undefined behavior"
+msgstr ""
+
+#: tree-ssa-loop-niter.c:2668
+#, gcc-internal-format
+msgid "containing loop"
+msgstr ""
+
+#: tree-ssa-operands.c:1002
+#, gcc-internal-format
+msgid "virtual definition of statement not up-to-date"
+msgstr ""
+
+#: tree-ssa-operands.c:1009
+#, gcc-internal-format
+msgid "virtual def operand missing for stmt"
+msgstr ""
+
+#: tree-ssa-operands.c:1019
+#, gcc-internal-format
+msgid "virtual use of statement not up-to-date"
+msgstr ""
+
+#: tree-ssa-operands.c:1026
+#, gcc-internal-format
+msgid "virtual use operand missing for stmt"
+msgstr ""
+
+#: tree-ssa-operands.c:1042
+#, gcc-internal-format
+msgid "excess use operand for stmt"
+msgstr ""
+
+#: tree-ssa-operands.c:1050
+#, gcc-internal-format
+msgid "use operand missing for stmt"
+msgstr ""
+
+#: tree-ssa-operands.c:1057
+#, gcc-internal-format
+msgid "stmt volatile flag not up-to-date"
+msgstr ""
+
+#: tree-ssa-uninit.c:195 varasm.c:350
+#, gcc-internal-format
+msgid "%qD was declared here"
+msgstr ""
+
+#: tree-ssa-uninit.c:227
+#, gcc-internal-format
+msgid "%qD is used uninitialized in this function"
+msgstr ""
+
+#: tree-ssa-uninit.c:232 tree-ssa-uninit.c:2368
+#, gcc-internal-format
+msgid "%qD may be used uninitialized in this function"
+msgstr ""
+
+#: tree-ssa-uninit.c:263
+#, gcc-internal-format
+msgid "%qE is used uninitialized in this function"
+msgstr ""
+
+#: tree-ssa-uninit.c:268
+#, gcc-internal-format
+msgid "%qE may be used uninitialized in this function"
+msgstr ""
+
+#: tree-ssa.c:645
+#, gcc-internal-format
+msgid "expected an SSA_NAME object"
+msgstr ""
+
+#: tree-ssa.c:651
+#, gcc-internal-format
+msgid "found an SSA_NAME that had been released into the free pool"
+msgstr ""
+
+#: tree-ssa.c:658
+#, gcc-internal-format
+msgid "type mismatch between an SSA_NAME and its symbol"
+msgstr ""
+
+#: tree-ssa.c:664
+#, gcc-internal-format
+msgid "found a virtual definition for a GIMPLE register"
+msgstr ""
+
+#: tree-ssa.c:670
+#, gcc-internal-format
+msgid "virtual SSA name for non-VOP decl"
+msgstr ""
+
+#: tree-ssa.c:676
+#, gcc-internal-format
+msgid "found a real definition for a non-register"
+msgstr ""
+
+#: tree-ssa.c:683
+#, gcc-internal-format
+msgid "found a default name with a non-empty defining statement"
+msgstr ""
+
+#: tree-ssa.c:713
+#, gcc-internal-format
+msgid "RESULT_DECL should be read only when DECL_BY_REFERENCE is set"
+msgstr ""
+
+#: tree-ssa.c:719
+#, gcc-internal-format, gfc-internal-format
+msgid "SSA_NAME created in two different blocks %i and %i"
+msgstr ""
+
+#: tree-ssa.c:728 tree-ssa.c:1039
+#, gcc-internal-format
+msgid "SSA_NAME_DEF_STMT is wrong"
+msgstr ""
+
+#: tree-ssa.c:780
+#, gcc-internal-format
+msgid "missing definition"
+msgstr ""
+
+#: tree-ssa.c:786
+#, gcc-internal-format, gfc-internal-format
+msgid "definition in block %i does not dominate use in block %i"
+msgstr ""
+
+#: tree-ssa.c:794
+#, gcc-internal-format, gfc-internal-format
+msgid "definition in block %i follows the use"
+msgstr ""
+
+#: tree-ssa.c:801
+#, gcc-internal-format
+msgid "SSA_NAME_OCCURS_IN_ABNORMAL_PHI should be set"
+msgstr ""
+
+#: tree-ssa.c:809
+#, gcc-internal-format
+msgid "no immediate_use list"
+msgstr ""
+
+#: tree-ssa.c:821
+#, gcc-internal-format
+msgid "wrong immediate use list"
+msgstr ""
+
+#: tree-ssa.c:855
+#, gcc-internal-format
+msgid "incoming edge count does not match number of PHI arguments"
+msgstr ""
+
+#: tree-ssa.c:869
+#, gcc-internal-format, gfc-internal-format
+msgid "PHI argument is missing for edge %d->%d"
+msgstr ""
+
+#: tree-ssa.c:878
+#, gcc-internal-format
+msgid "PHI argument is not SSA_NAME, or invariant"
+msgstr ""
+
+#: tree-ssa.c:906
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong edge %d->%d for PHI argument"
+msgstr ""
+
+#: tree-ssa.c:985
+#, gcc-internal-format, gfc-internal-format
+msgid "AUX pointer initialized for edge %d->%d"
+msgstr ""
+
+#: tree-ssa.c:1011
+#, gcc-internal-format
+msgid "stmt (%p) marked modified after optimization pass: "
+msgstr ""
+
+#: tree-ssa.c:1068
+#, gcc-internal-format
+msgid "verify_ssa failed"
+msgstr ""
+
+#: tree-streamer-in.c:359 tree-streamer-in.c:1154
+#, gcc-internal-format
+msgid "machine independent builtin code out of range"
+msgstr ""
+
+#: tree-streamer-in.c:365 tree-streamer-in.c:1170
+#, gcc-internal-format
+msgid "target specific builtin not available"
+msgstr ""
+
+#: tree-streamer-out.c:512
+#, gcc-internal-format
+msgid "tree bytecode streams do not support machine specific builtin functions on this target"
+msgstr ""
+
+#: tree-vect-generic.c:282
+#, gcc-internal-format
+msgid "vector operation will be expanded piecewise"
+msgstr ""
+
+#: tree-vect-generic.c:285
+#, gcc-internal-format
+msgid "vector operation will be expanded in parallel"
+msgstr ""
+
+#: tree-vect-generic.c:336
+#, gcc-internal-format
+msgid "vector operation will be expanded with a single scalar operation"
+msgstr ""
+
+#: tree-vect-generic.c:902
+#, gcc-internal-format
+msgid "vector condition will be expanded piecewise"
+msgstr ""
+
+#: tree-vect-generic.c:1295
+#, gcc-internal-format
+msgid "vector shuffling operation will be expanded piecewise"
+msgstr ""
+
+#: tree-vect-loop.c:3072
+#, gcc-internal-format
+msgid "vectorization did not happen for a simd loop"
+msgstr ""
+
+#: tree-vrp.c:6576
+#, gcc-internal-format
+msgid "array subscript is outside array bounds"
+msgstr ""
+
+#: tree-vrp.c:6594 tree-vrp.c:6694
+#, gcc-internal-format
+msgid "array subscript is above array bounds"
+msgstr ""
+
+#: tree-vrp.c:6607 tree-vrp.c:6681
+#, gcc-internal-format
+msgid "array subscript is below array bounds"
+msgstr ""
+
+#: tree-vrp.c:7547
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when simplifying conditional to constant"
+msgstr ""
+
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when simplifying conditional"
+msgstr ""
+
+#: tree-vrp.c:7597
+#, gcc-internal-format
+msgid "comparison always false due to limited range of data type"
+msgstr ""
+
+#: tree-vrp.c:7599
+#, gcc-internal-format
+msgid "comparison always true due to limited range of data type"
+msgstr ""
+
+#: tree-vrp.c:9098
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
+msgstr ""
+
+#: tree-vrp.c:9180
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
+msgstr ""
+
+#: tree.c:4753
+#, gcc-internal-format
+msgid "ignoring attributes applied to %qT after definition"
+msgstr ""
+
+#: tree.c:6149
+#, gcc-internal-format
+msgid "%q+D already declared with dllexport attribute: dllimport ignored"
+msgstr ""
+
+#: tree.c:6161
+#, gcc-internal-format
+msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
+msgstr ""
+
+#: tree.c:6176
+#, gcc-internal-format
+msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
+msgstr ""
+
+#: tree.c:6219 tree.c:6231 tree.c:6241 c-family/c-common.c:6623
+#: c-family/c-common.c:6642 c-family/c-common.c:6660 c-family/c-common.c:6690
+#: c-family/c-common.c:6718 c-family/c-common.c:6746 c-family/c-common.c:6762
+#: c-family/c-common.c:6777 c-family/c-common.c:6795 c-family/c-common.c:6810
+#: c-family/c-common.c:6842 c-family/c-common.c:6859 c-family/c-common.c:6876
+#: c-family/c-common.c:6908 c-family/c-common.c:6931 c-family/c-common.c:6948
+#: c-family/c-common.c:6976 c-family/c-common.c:6997 c-family/c-common.c:7018
+#: c-family/c-common.c:7045 c-family/c-common.c:7076 c-family/c-common.c:7113
+#: c-family/c-common.c:7166 c-family/c-common.c:7226 c-family/c-common.c:7315
+#: c-family/c-common.c:7345 c-family/c-common.c:7399 c-family/c-common.c:7875
+#: c-family/c-common.c:7893 c-family/c-common.c:7949 c-family/c-common.c:8005
+#: c-family/c-common.c:8083 c-family/c-common.c:8211 c-family/c-common.c:8273
+#: c-family/c-common.c:8380 c-family/c-common.c:8396 c-family/c-common.c:8412
+#: c-family/c-common.c:8433 c-family/c-common.c:8469 c-family/c-common.c:8517
+#: c-family/c-common.c:8680 c-family/c-common.c:8701 c-family/c-common.c:8815
+#: c-family/c-common.c:8842 c-family/c-common.c:9155 c-family/c-common.c:9178
+#: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
+#: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
+#: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
+#: lto/lto-lang.c:260
+#, gcc-internal-format
+msgid "%qE attribute ignored"
+msgstr ""
+
+#: tree.c:6259
+#, gcc-internal-format
+msgid "inline function %q+D declared as  dllimport: attribute ignored"
+msgstr ""
+
+#: tree.c:6267
+#, gcc-internal-format
+msgid "function %q+D definition is marked dllimport"
+msgstr ""
+
+#: tree.c:6275
+#, gcc-internal-format
+msgid "variable %q+D definition is marked dllimport"
+msgstr ""
+
+#: tree.c:6303
+#, gcc-internal-format
+msgid "external linkage required for symbol %q+D because of %qE attribute"
+msgstr ""
+
+#: tree.c:6317
+#, gcc-internal-format
+msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
+msgstr ""
+
+#: tree.c:7960
+#, gcc-internal-format
+msgid "arrays of functions are not meaningful"
+msgstr ""
+
+#: tree.c:8128
+#, gcc-internal-format
+msgid "function return type cannot be function"
+msgstr ""
+
+#: tree.c:9295 tree.c:9380 tree.c:9441
+#, gcc-internal-format, gfc-internal-format
+msgid "tree check: %s, have %s in %s, at %s:%d"
+msgstr ""
+
+#: tree.c:9332
+#, gcc-internal-format, gfc-internal-format
+msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
+msgstr ""
+
+#: tree.c:9345
+#, gcc-internal-format
+msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
+msgstr ""
+
+#: tree.c:9394
+#, gcc-internal-format
+msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
+msgstr ""
+
+#: tree.c:9407
+#, gcc-internal-format, gfc-internal-format
+msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
+msgstr ""
+
+#: tree.c:9467
+#, gcc-internal-format
+msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
+msgstr ""
+
+#: tree.c:9481
+#, gcc-internal-format, gfc-internal-format
+msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
+msgstr ""
+
+#: tree.c:9493
+#, gcc-internal-format, gfc-internal-format
+msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
+msgstr ""
+
+#: tree.c:9506
+#, gcc-internal-format, gfc-internal-format
+msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
+msgstr ""
+
+#: tree.c:9519
+#, gcc-internal-format, gfc-internal-format
+msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
+msgstr ""
+
+#: tree.c:12131
+#, gcc-internal-format
+msgid "%qD is deprecated: %s"
+msgstr ""
+
+#: tree.c:12134
+#, gcc-internal-format
+msgid "%qD is deprecated"
+msgstr ""
+
+#: tree.c:12158 tree.c:12180
+#, gcc-internal-format
+msgid "%qE is deprecated: %s"
+msgstr ""
+
+#: tree.c:12161 tree.c:12183
+#, gcc-internal-format
+msgid "%qE is deprecated"
+msgstr ""
+
+#: tree.c:12167 tree.c:12188
+#, gcc-internal-format, gfc-internal-format
+msgid "type is deprecated: %s"
+msgstr ""
+
+#: tree.c:12170 tree.c:12191
+#, gcc-internal-format
+msgid "type is deprecated"
+msgstr ""
+
+#: value-prof.c:575
+#, gcc-internal-format
+msgid "dead histogram"
+msgstr ""
+
+#: value-prof.c:605
+#, gcc-internal-format
+msgid "Histogram value statement does not correspond to the statement it is associated with"
+msgstr ""
+
+#: value-prof.c:617
+#, gcc-internal-format
+msgid "verify_histograms failed"
+msgstr ""
+
+#: value-prof.c:676
+#, gcc-internal-format, gfc-internal-format
+msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
+msgstr ""
+
+#: var-tracking.c:7115
+#, gcc-internal-format
+msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
+msgstr ""
+
+#: var-tracking.c:7119
+#, gcc-internal-format
+msgid "variable tracking size limit exceeded"
+msgstr ""
+
+#: varasm.c:345
+#, gcc-internal-format
+msgid "%+D causes a section type conflict with %D"
+msgstr ""
+
+#: varasm.c:348
+#, gcc-internal-format
+msgid "section type conflict with %D"
+msgstr ""
+
+#: varasm.c:353
+#, gcc-internal-format
+msgid "%+D causes a section type conflict"
+msgstr ""
+
+#: varasm.c:355
+#, gcc-internal-format
+msgid "section type conflict"
+msgstr ""
+
+#: varasm.c:1017
+#, gcc-internal-format
+msgid "alignment of %q+D is greater than maximum object file alignment %d"
+msgstr ""
+
+#: varasm.c:1369 varasm.c:1378
+#, gcc-internal-format
+msgid "register name not specified for %q+D"
+msgstr ""
+
+#: varasm.c:1380
+#, gcc-internal-format
+msgid "invalid register name for %q+D"
+msgstr ""
+
+#: varasm.c:1382
+#, gcc-internal-format
+msgid "data type of %q+D isn%'t suitable for a register"
+msgstr ""
+
+#: varasm.c:1385
+#, gcc-internal-format
+msgid "the register specified for %q+D cannot be accessed by the current target"
+msgstr ""
+
+#: varasm.c:1388
+#, gcc-internal-format
+msgid "the register specified for %q+D is not general enough to be used as a register variable"
+msgstr ""
+
+#: varasm.c:1391
+#, gcc-internal-format
+msgid "register specified for %q+D isn%'t suitable for data type"
+msgstr ""
+
+#: varasm.c:1401
+#, gcc-internal-format
+msgid "global register variable has initial value"
+msgstr ""
+
+#: varasm.c:1405
+#, gcc-internal-format
+msgid "optimization may eliminate reads and/or writes to register variables"
+msgstr ""
+
+#: varasm.c:1448
+#, gcc-internal-format
+msgid "register name given for non-register variable %q+D"
+msgstr ""
+
+#: varasm.c:2002
+#, gcc-internal-format
+msgid "thread-local COMMON data not implemented"
+msgstr ""
+
+#: varasm.c:2035
+#, gcc-internal-format
+msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
+msgstr ""
+
+#: varasm.c:2137 c/c-decl.c:4805
+#, gcc-internal-format
+msgid "storage size of %q+D isn%'t known"
+msgstr ""
+
+#: varasm.c:4770
+#, gcc-internal-format
+msgid "initializer for integer/fixed-point value is too complicated"
+msgstr ""
+
+#: varasm.c:4775
+#, gcc-internal-format
+msgid "initializer for floating value is not a floating constant"
+msgstr ""
+
+#: varasm.c:5071
+#, gcc-internal-format
+msgid "invalid initial value for member %qE"
+msgstr ""
+
+#: varasm.c:5327 c-family/c-common.c:7871
+#, gcc-internal-format
+msgid "%+D declared weak after being used"
+msgstr ""
+
+#: varasm.c:5409
+#, gcc-internal-format
+msgid "weak declaration of %q+D must be public"
+msgstr ""
+
+#: varasm.c:5411
+#, gcc-internal-format
+msgid "weak declaration of %q+D not supported"
+msgstr ""
+
+#: varasm.c:5440 varasm.c:5744
+#, gcc-internal-format
+msgid "only weak aliases are supported in this configuration"
+msgstr ""
+
+#: varasm.c:5634
+#, gcc-internal-format
+msgid "weakref is not supported in this configuration"
+msgstr ""
+
+#: varasm.c:5666
+#, gcc-internal-format
+msgid "ifunc is not supported on this target"
+msgstr ""
+
+#: varasm.c:5724
+#, gcc-internal-format
+msgid "weakref %q+D ultimately targets itself"
+msgstr ""
+
+#: varasm.c:5726
+#, gcc-internal-format
+msgid "weakref %q+D must have static linkage"
+msgstr ""
+
+#: varasm.c:5733
+#, gcc-internal-format
+msgid "alias definitions not supported in this configuration"
+msgstr ""
+
+#: varasm.c:5741
+#, gcc-internal-format
+msgid "ifunc is not supported in this configuration"
+msgstr ""
+
+#: varasm.c:5966 config/sol2.c:167 config/i386/winnt.c:293
+#, gcc-internal-format
+msgid "visibility attribute not supported in this configuration; ignored"
+msgstr ""
+
+#. Print an error message for unrecognized stab codes.
+#: xcoffout.c:205
+#, gcc-internal-format
+msgid "no sclass for %s stab (0x%x)"
+msgstr ""
+
+#: lto-streamer.h:1013
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: expected tag %s instead of %s"
+msgstr ""
+
+#: lto-streamer.h:1023
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
+msgstr ""
+
+#: c-family/array-notation-common.c:83
+#, gcc-internal-format
+msgid "__sec_implicit_index parameter must be an integer constant expression"
+msgstr ""
+
+#: c-family/array-notation-common.c:119
+#, gcc-internal-format
+msgid "length mismatch in expression"
+msgstr ""
+
+#: c-family/array-notation-common.c:294 c-family/array-notation-common.c:322
+#: c/c-array-notation.c:744 cp/cp-array-notation.c:625
+#, gcc-internal-format
+msgid "rank mismatch between %qE and %qE"
+msgstr ""
+
+#. Here the original expression is printed as a "heads-up"
+#. to the programmer.  This is because since there is no
+#. location information for the offending argument, the
+#. error could be in some internally generated code that is
+#. not visible for the programmer.  Thus, the correct fix
+#. may lie in the original expression.
+#: c-family/array-notation-common.c:303
+#, gcc-internal-format
+msgid "rank mismatch in expression %qE"
+msgstr ""
+
+#: c-family/array-notation-common.c:677
+#, gcc-internal-format
+msgid "__sec_implicit_index argument %d must be less than the rank of %qE"
+msgstr ""
+
+#: c-family/c-cilkplus.c:49
+#, gcc-internal-format
+msgid "iteration variable cannot be volatile"
+msgstr ""
+
+#: c-family/c-cilkplus.c:92
+#, gcc-internal-format
+msgid "variable appears in more than one clause"
+msgstr ""
+
+#: c-family/c-cilkplus.c:94
+#, gcc-internal-format
+msgid "other clause defined here"
+msgstr ""
+
+#: c-family/c-common.c:1005
+#, gcc-internal-format
+msgid "%qD is not defined outside of function scope"
+msgstr ""
+
+#: c-family/c-common.c:1055
+#, gcc-internal-format
+msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
+msgstr ""
+
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
+#, gcc-internal-format
+msgid "left shift count is negative"
+msgstr ""
+
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
+#, gcc-internal-format
+msgid "right shift count is negative"
+msgstr ""
+
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
+#, gcc-internal-format
+msgid "left shift count >= width of type"
+msgstr ""
+
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
+#, gcc-internal-format
+msgid "right shift count >= width of type"
+msgstr ""
+
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
+#, gcc-internal-format
+msgid "overflow in constant expression"
+msgstr ""
+
+#: c-family/c-common.c:1649
+#, gcc-internal-format
+msgid "integer overflow in expression"
+msgstr ""
+
+#: c-family/c-common.c:1654
+#, gcc-internal-format
+msgid "floating point overflow in expression"
+msgstr ""
+
+#: c-family/c-common.c:1658
+#, gcc-internal-format
+msgid "fixed-point overflow in expression"
+msgstr ""
+
+#: c-family/c-common.c:1662
+#, gcc-internal-format
+msgid "vector overflow in expression"
+msgstr ""
+
+#: c-family/c-common.c:1668
+#, gcc-internal-format
+msgid "complex integer overflow in expression"
+msgstr ""
+
+#: c-family/c-common.c:1671
+#, gcc-internal-format
+msgid "complex floating point overflow in expression"
+msgstr ""
+
+#: c-family/c-common.c:1714
+#, gcc-internal-format
+msgid "logical %<or%> applied to non-boolean constant"
+msgstr ""
+
+#: c-family/c-common.c:1717
+#, gcc-internal-format
+msgid "logical %<and%> applied to non-boolean constant"
+msgstr ""
+
+#: c-family/c-common.c:1785
+#, gcc-internal-format
+msgid "logical %<or%> of collectively exhaustive tests is always true"
+msgstr ""
+
+#: c-family/c-common.c:1789
+#, gcc-internal-format
+msgid "logical %<and%> of mutually exclusive tests is always false"
+msgstr ""
+
+#: c-family/c-common.c:1814
+#, gcc-internal-format
+msgid "logical not is only applied to the left hand side of comparison"
+msgstr ""
+
+#: c-family/c-common.c:1944
+#, gcc-internal-format
+msgid "type-punning to incomplete type might break strict-aliasing rules"
+msgstr ""
+
+#: c-family/c-common.c:1959
+#, gcc-internal-format
+msgid "dereferencing type-punned pointer will break strict-aliasing rules"
+msgstr ""
+
+#: c-family/c-common.c:1966 c-family/c-common.c:1984
+#, gcc-internal-format
+msgid "dereferencing type-punned pointer might break strict-aliasing rules"
+msgstr ""
+
+#: c-family/c-common.c:2118
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
+msgstr ""
+
+#: c-family/c-common.c:2125
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
+msgstr ""
+
+#: c-family/c-common.c:2130
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
+msgstr ""
+
+#: c-family/c-common.c:2142
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
+msgstr ""
+
+#: c-family/c-common.c:2158
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
+msgstr ""
+
+#: c-family/c-common.c:2165
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
+msgstr ""
+
+#: c-family/c-common.c:2170
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
+msgstr ""
+
+#: c-family/c-common.c:2182
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
+msgstr ""
+
+#: c-family/c-common.c:2198
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
+msgstr ""
+
+#: c-family/c-common.c:2205
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
+msgstr ""
+
+#: c-family/c-common.c:2210
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
+msgstr ""
+
+#: c-family/c-common.c:2222
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
+msgstr ""
+
+#: c-family/c-common.c:2238
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
+msgstr ""
+
+#: c-family/c-common.c:2245
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
+msgstr ""
+
+#: c-family/c-common.c:2250
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
+msgstr ""
+
+#: c-family/c-common.c:2262
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
+msgstr ""
+
+#: c-family/c-common.c:2291 c-family/c-common.c:2298
+#, gcc-internal-format
+msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
+msgstr ""
+
+#: c-family/c-common.c:2308
+#, gcc-internal-format
+msgid "first argument of %q+D should be %<int%>"
+msgstr ""
+
+#: c-family/c-common.c:2317
+#, gcc-internal-format
+msgid "second argument of %q+D should be %<char **%>"
+msgstr ""
+
+#: c-family/c-common.c:2326
+#, gcc-internal-format
+msgid "third argument of %q+D should probably be %<char **%>"
+msgstr ""
+
+#: c-family/c-common.c:2337
+#, gcc-internal-format
+msgid "%q+D takes only zero or two arguments"
+msgstr ""
+
+#: c-family/c-common.c:2341
+#, gcc-internal-format
+msgid "%q+D declared as variadic function"
+msgstr ""
+
+#: c-family/c-common.c:2409
+#, gcc-internal-format
+msgid "use -flax-vector-conversions to permit conversions between vectors with differing element types or numbers of subparts"
+msgstr ""
+
+#: c-family/c-common.c:2450
+#, gcc-internal-format
+msgid "__builtin_shuffle last argument must be an integer vector"
+msgstr ""
+
+#: c-family/c-common.c:2459
+#, gcc-internal-format
+msgid "__builtin_shuffle arguments must be vectors"
+msgstr ""
+
+#: c-family/c-common.c:2466
+#, gcc-internal-format
+msgid "__builtin_shuffle argument vectors must be of the same type"
+msgstr ""
+
+#: c-family/c-common.c:2477
+#, gcc-internal-format
+msgid "__builtin_shuffle number of elements of the argument vector(s) and the mask vector should be the same"
+msgstr ""
+
+#: c-family/c-common.c:2487
+#, gcc-internal-format
+msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
+msgstr ""
+
+#: c-family/c-common.c:2684
+#, gcc-internal-format
+msgid "negative integer implicitly converted to unsigned type"
+msgstr ""
+
+#: c-family/c-common.c:2690
+#, gcc-internal-format
+msgid "conversion of unsigned constant value to negative integer"
+msgstr ""
+
+#: c-family/c-common.c:2784
+#, gcc-internal-format
+msgid "conversion to %qT from %qT may change the sign of the result"
+msgstr ""
+
+#: c-family/c-common.c:2861
+#, gcc-internal-format
+msgid "conversion to %qT from boolean expression"
+msgstr ""
+
+#: c-family/c-common.c:2869 c-family/c-common.c:2873
+#, gcc-internal-format
+msgid "conversion to %qT alters %qT constant value"
+msgstr ""
+
+#: c-family/c-common.c:2893 c-family/c-common.c:2897
+#, gcc-internal-format
+msgid "conversion to %qT from %qT may alter its value"
+msgstr ""
+
+#: c-family/c-common.c:2928
+#, gcc-internal-format
+msgid "large integer implicitly truncated to unsigned type"
+msgstr ""
+
+#: c-family/c-common.c:2934 c-family/c-common.c:2941 c-family/c-common.c:2949
+#, gcc-internal-format
+msgid "overflow in implicit constant conversion"
+msgstr ""
+
+#: c-family/c-common.c:3121
+#, gcc-internal-format
+msgid "operation on %qE may be undefined"
+msgstr ""
+
+#: c-family/c-common.c:3428
+#, gcc-internal-format
+msgid "case label does not reduce to an integer constant"
+msgstr ""
+
+#: c-family/c-common.c:3468
+#, gcc-internal-format
+msgid "case label value is less than minimum value for type"
+msgstr ""
+
+#: c-family/c-common.c:3477
+#, gcc-internal-format
+msgid "case label value exceeds maximum value for type"
+msgstr ""
+
+#: c-family/c-common.c:3485
+#, gcc-internal-format
+msgid "lower value in case label range less than minimum value for type"
+msgstr ""
+
+#: c-family/c-common.c:3494
+#, gcc-internal-format
+msgid "upper value in case label range exceeds maximum value for type"
+msgstr ""
+
+#: c-family/c-common.c:3576
+#, gcc-internal-format
+msgid "GCC cannot support operators with integer types and fixed-point types that have too many integral and fractional bits together"
+msgstr ""
+
+#: c-family/c-common.c:4095
+#, gcc-internal-format
+msgid "invalid operands to binary %s (have %qT and %qT)"
+msgstr ""
+
+#: c-family/c-common.c:4349
+#, gcc-internal-format
+msgid "comparison is always false due to limited range of data type"
+msgstr ""
+
+#: c-family/c-common.c:4352
+#, gcc-internal-format
+msgid "comparison is always true due to limited range of data type"
+msgstr ""
+
+#: c-family/c-common.c:4442
+#, gcc-internal-format
+msgid "comparison of unsigned expression >= 0 is always true"
+msgstr ""
+
+#: c-family/c-common.c:4449
+#, gcc-internal-format
+msgid "comparison of unsigned expression < 0 is always false"
+msgstr ""
+
+#: c-family/c-common.c:4492
+#, gcc-internal-format
+msgid "pointer of type %<void *%> used in arithmetic"
+msgstr ""
+
+#: c-family/c-common.c:4501
+#, gcc-internal-format
+msgid "pointer to a function used in arithmetic"
+msgstr ""
+
+#: c-family/c-common.c:4714
+#, gcc-internal-format
+msgid "the address of %qD will always evaluate as %<true%>"
+msgstr ""
+
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
+#, gcc-internal-format
+msgid "suggest parentheses around assignment used as truth value"
+msgstr ""
+
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
+#, gcc-internal-format
+msgid "invalid use of %<restrict%>"
+msgstr ""
+
+#: c-family/c-common.c:5092
+#, gcc-internal-format
+msgid "invalid application of %<sizeof%> to a function type"
+msgstr ""
+
+#: c-family/c-common.c:5102
+#, gcc-internal-format
+msgid "ISO C++ does not permit %<alignof%> applied to a function type"
+msgstr ""
+
+#: c-family/c-common.c:5105
+#, gcc-internal-format
+msgid "ISO C does not permit %<_Alignof%> applied to a function type"
+msgstr ""
+
+#: c-family/c-common.c:5116
+#, gcc-internal-format
+msgid "invalid application of %qs to a void type"
+msgstr ""
+
+#: c-family/c-common.c:5125
+#, gcc-internal-format
+msgid "invalid application of %qs to incomplete type %qT"
+msgstr ""
+
+#: c-family/c-common.c:5133
+#, gcc-internal-format
+msgid "invalid application of %qs to array type %qT of incomplete element type"
+msgstr ""
+
+#: c-family/c-common.c:5175
+#, gcc-internal-format
+msgid "%<__alignof%> applied to a bit-field"
+msgstr ""
+
+#: c-family/c-common.c:5915
+#, gcc-internal-format
+msgid "cannot disable built-in function %qs"
+msgstr ""
+
+#: c-family/c-common.c:6106
+#, gcc-internal-format
+msgid "pointers are not permitted as case values"
+msgstr ""
+
+#: c-family/c-common.c:6113
+#, gcc-internal-format
+msgid "range expressions in switch statements are non-standard"
+msgstr ""
+
+#: c-family/c-common.c:6139
+#, gcc-internal-format
+msgid "empty range specified"
+msgstr ""
+
+#: c-family/c-common.c:6199
+#, gcc-internal-format
+msgid "duplicate (or overlapping) case value"
+msgstr ""
+
+#: c-family/c-common.c:6201
+#, gcc-internal-format
+msgid "this is the first entry overlapping that value"
+msgstr ""
+
+#: c-family/c-common.c:6205
+#, gcc-internal-format
+msgid "duplicate case value"
+msgstr ""
+
+#: c-family/c-common.c:6206
+#, gcc-internal-format
+msgid "previously used here"
+msgstr ""
+
+#: c-family/c-common.c:6210
+#, gcc-internal-format
+msgid "multiple default labels in one switch"
+msgstr ""
+
+#: c-family/c-common.c:6212
+#, gcc-internal-format
+msgid "this is the first default label"
+msgstr ""
+
+#: c-family/c-common.c:6256
+#, gcc-internal-format
+msgid "case value %qs not in enumerated type"
+msgstr ""
+
+#: c-family/c-common.c:6261
+#, gcc-internal-format
+msgid "case value %qs not in enumerated type %qT"
+msgstr ""
+
+#: c-family/c-common.c:6320
+#, gcc-internal-format
+msgid "switch missing default case"
+msgstr ""
+
+#: c-family/c-common.c:6392
+#, gcc-internal-format
+msgid "enumeration value %qE not handled in switch"
+msgstr ""
+
+#: c-family/c-common.c:6418
+#, gcc-internal-format
+msgid "taking the address of a label is non-standard"
+msgstr ""
+
+#: c-family/c-common.c:6612
+#, gcc-internal-format
+msgid "%qE attribute ignored for field of type %qT"
+msgstr ""
+
+#: c-family/c-common.c:6709 c-family/c-common.c:6737 c-family/c-common.c:6833
+#, gcc-internal-format
+msgid "%qE attribute ignored due to conflict with attribute %qs"
+msgstr ""
+
+#: c-family/c-common.c:6897
+#, gcc-internal-format
+msgid "%qE attribute ignored due to conflict with %qs attribute"
+msgstr ""
+
+#: c-family/c-common.c:6953 lto/lto-lang.c:265
+#, gcc-internal-format
+msgid "%qE attribute has no effect on unit local functions"
+msgstr ""
+
+#: c-family/c-common.c:7107
+#, gcc-internal-format
+msgid "%qE attribute have effect only on public objects"
+msgstr ""
+
+#: c-family/c-common.c:7136
+#, gcc-internal-format
+msgid "%qE attribute only affects top level objects"
+msgstr ""
+
+#: c-family/c-common.c:7247
+#, gcc-internal-format
+msgid "destructor priorities are not supported"
+msgstr ""
+
+#: c-family/c-common.c:7249
+#, gcc-internal-format
+msgid "constructor priorities are not supported"
+msgstr ""
+
+#: c-family/c-common.c:7271
+#, gcc-internal-format, gfc-internal-format
+msgid "destructor priorities from 0 to %d are reserved for the implementation"
+msgstr ""
+
+#: c-family/c-common.c:7276
+#, gcc-internal-format, gfc-internal-format
+msgid "constructor priorities from 0 to %d are reserved for the implementation"
+msgstr ""
+
+#: c-family/c-common.c:7284
+#, gcc-internal-format, gfc-internal-format
+msgid "destructor priorities must be integers from 0 to %d inclusive"
+msgstr ""
+
+#: c-family/c-common.c:7287
+#, gcc-internal-format, gfc-internal-format
+msgid "constructor priorities must be integers from 0 to %d inclusive"
+msgstr ""
+
+#: c-family/c-common.c:7443
+#, gcc-internal-format
+msgid "unknown machine mode %qE"
+msgstr ""
+
+#: c-family/c-common.c:7472
+#, gcc-internal-format
+msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
+msgstr ""
+
+#: c-family/c-common.c:7475
+#, gcc-internal-format
+msgid "use __attribute__ ((vector_size)) instead"
+msgstr ""
+
+#: c-family/c-common.c:7484
+#, gcc-internal-format
+msgid "unable to emulate %qs"
+msgstr ""
+
+#: c-family/c-common.c:7495
+#, gcc-internal-format
+msgid "invalid pointer mode %qs"
+msgstr ""
+
+#: c-family/c-common.c:7512
+#, gcc-internal-format
+msgid "signedness of type and machine mode %qs don%'t match"
+msgstr ""
+
+#: c-family/c-common.c:7523
+#, gcc-internal-format
+msgid "no data type for mode %qs"
+msgstr ""
+
+#: c-family/c-common.c:7533
+#, gcc-internal-format
+msgid "cannot use mode %qs for enumeral types"
+msgstr ""
+
+#: c-family/c-common.c:7560
+#, gcc-internal-format
+msgid "mode %qs applied to inappropriate type"
+msgstr ""
+
+#: c-family/c-common.c:7592
+#, gcc-internal-format
+msgid "section attribute cannot be specified for local variables"
+msgstr ""
+
+#: c-family/c-common.c:7603 config/bfin/bfin.c:4800 config/bfin/bfin.c:4851
+#: config/bfin/bfin.c:4877 config/bfin/bfin.c:4890
+#, gcc-internal-format
+msgid "section of %q+D conflicts with previous declaration"
+msgstr ""
+
+#: c-family/c-common.c:7611
+#, gcc-internal-format
+msgid "section of %q+D cannot be overridden"
+msgstr ""
+
+#: c-family/c-common.c:7620
+#, gcc-internal-format
+msgid "section attribute not allowed for %q+D"
+msgstr ""
+
+#: c-family/c-common.c:7627
+#, gcc-internal-format
+msgid "section attributes are not supported for this target"
+msgstr ""
+
+#: c-family/c-common.c:7648
+#, gcc-internal-format
+msgid "requested alignment is not an integer constant"
+msgstr ""
+
+#: c-family/c-common.c:7656
+#, gcc-internal-format
+msgid "requested alignment is not a positive power of 2"
+msgstr ""
+
+#: c-family/c-common.c:7661
+#, gcc-internal-format
+msgid "requested alignment is too large"
+msgstr ""
+
+#: c-family/c-common.c:7744
+#, gcc-internal-format, gfc-internal-format
+msgid "requested alignment %d is larger than %d"
+msgstr ""
+
+#: c-family/c-common.c:7810
+#, gcc-internal-format
+msgid "alignment may not be specified for %q+D"
+msgstr ""
+
+#: c-family/c-common.c:7828
+#, gcc-internal-format
+msgid "alignment for %q+D was previously specified as %d and may not be decreased"
+msgstr ""
+
+#: c-family/c-common.c:7832
+#, gcc-internal-format
+msgid "alignment for %q+D must be at least %d"
+msgstr ""
+
+#: c-family/c-common.c:7857
+#, gcc-internal-format
+msgid "inline function %q+D declared weak"
+msgstr ""
+
+#: c-family/c-common.c:7862
+#, gcc-internal-format
+msgid "indirect function %q+D cannot be declared weak"
+msgstr ""
+
+#: c-family/c-common.c:7904
+#, gcc-internal-format
+msgid "%q+D defined both normally and as %qE attribute"
+msgstr ""
+
+#: c-family/c-common.c:7912
+#, gcc-internal-format
+msgid "weak %q+D cannot be defined %qE"
+msgstr ""
+
+#: c-family/c-common.c:7929
+#, gcc-internal-format
+msgid "attribute %qE argument not a string"
+msgstr ""
+
+#: c-family/c-common.c:7959
+#, gcc-internal-format
+msgid "%+D declared alias after being used"
+msgstr ""
+
+#: c-family/c-common.c:7961
+#, gcc-internal-format
+msgid "%+D declared ifunc after being used"
+msgstr ""
+
+#: c-family/c-common.c:8012
+#, gcc-internal-format
+msgid "indirect function %q+D cannot be declared weakref"
+msgstr ""
+
+#: c-family/c-common.c:8034
+#, gcc-internal-format
+msgid "weakref attribute must appear before alias attribute"
+msgstr ""
+
+#: c-family/c-common.c:8046
+#, gcc-internal-format
+msgid "%+D declared weakref after being used"
+msgstr ""
+
+#: c-family/c-common.c:8070
+#, gcc-internal-format
+msgid "%qE attribute ignored on non-class types"
+msgstr ""
+
+#: c-family/c-common.c:8076
+#, gcc-internal-format
+msgid "%qE attribute ignored because %qT is already defined"
+msgstr ""
+
+#: c-family/c-common.c:8089
+#, gcc-internal-format
+msgid "visibility argument not a string"
+msgstr ""
+
+#: c-family/c-common.c:8101
+#, gcc-internal-format
+msgid "%qE attribute ignored on types"
+msgstr ""
+
+#: c-family/c-common.c:8117
+#, gcc-internal-format
+msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
+msgstr ""
+
+#: c-family/c-common.c:8128
+#, gcc-internal-format
+msgid "%qD redeclared with different visibility"
+msgstr ""
+
+#: c-family/c-common.c:8131 c-family/c-common.c:8135
+#, gcc-internal-format
+msgid "%qD was declared %qs which implies default visibility"
+msgstr ""
+
+#: c-family/c-common.c:8219
+#, gcc-internal-format
+msgid "tls_model argument not a string"
+msgstr ""
+
+#: c-family/c-common.c:8232
+#, gcc-internal-format
+msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
+msgstr ""
+
+#: c-family/c-common.c:8252 c-family/c-common.c:8490 c-family/c-common.c:9488
+#: config/m32c/m32c.c:2974
+#, gcc-internal-format
+msgid "%qE attribute applies only to functions"
+msgstr ""
+
+#: c-family/c-common.c:8300
+#, gcc-internal-format
+msgid "alloc_size parameter outside range"
+msgstr ""
+
+#: c-family/c-common.c:8325
+#, gcc-internal-format
+msgid "alloc_align parameter outside range"
+msgstr ""
+
+#: c-family/c-common.c:8349
+#, gcc-internal-format
+msgid "assume_aligned parameter not integer constant"
+msgstr ""
+
+#: c-family/c-common.c:8496 c-family/c-common.c:9494
+#, gcc-internal-format
+msgid "can%'t set %qE attribute after definition"
+msgstr ""
+
+#: c-family/c-common.c:8554
+#, gcc-internal-format
+msgid "%qE attribute duplicated"
+msgstr ""
+
+#: c-family/c-common.c:8556
+#, gcc-internal-format
+msgid "%qE attribute follows %qE"
+msgstr ""
+
+#: c-family/c-common.c:8655
+#, gcc-internal-format
+msgid "type was previously declared %qE"
+msgstr ""
+
+#: c-family/c-common.c:8710
+#, gcc-internal-format
+msgid "%qE argument not an identifier"
+msgstr ""
+
+#: c-family/c-common.c:8721
+#, gcc-internal-format
+msgid "%qD is not compatible with %qD"
+msgstr ""
+
+#: c-family/c-common.c:8724
+#, gcc-internal-format
+msgid "%qE argument is not a function"
+msgstr ""
+
+#: c-family/c-common.c:8772
+#, gcc-internal-format
+msgid "deprecated message is not a string"
+msgstr ""
+
+#: c-family/c-common.c:8813
+#, gcc-internal-format
+msgid "%qE attribute ignored for %qE"
+msgstr ""
+
+#: c-family/c-common.c:8876
+#, gcc-internal-format
+msgid "invalid vector type for attribute %qE"
+msgstr ""
+
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
+#, gcc-internal-format
+msgid "vector size not an integral multiple of component size"
+msgstr ""
+
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
+#, gcc-internal-format
+msgid "zero vector size"
+msgstr ""
+
+#: c-family/c-common.c:8896
+#, gcc-internal-format
+msgid "number of components of the vector not a power of two"
+msgstr ""
+
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
+#, gcc-internal-format
+msgid "nonnull attribute without arguments on a non-prototype"
+msgstr ""
+
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
+#, gcc-internal-format, gfc-internal-format
+msgid "nonnull argument has invalid operand number (argument %lu)"
+msgstr ""
+
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
+#, gcc-internal-format, gfc-internal-format
+msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
+msgstr ""
+
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
+#, gcc-internal-format, gfc-internal-format
+msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
+msgstr ""
+
+#: c-family/c-common.c:9068
+#, gcc-internal-format
+msgid "not enough variable arguments to fit a sentinel"
+msgstr ""
+
+#: c-family/c-common.c:9082
+#, gcc-internal-format
+msgid "missing sentinel in function call"
+msgstr ""
+
+#: c-family/c-common.c:9123
+#, gcc-internal-format, gfc-internal-format
+msgid "null argument where non-null required (argument %lu)"
+msgstr ""
+
+#: c-family/c-common.c:9189
+#, gcc-internal-format
+msgid "cleanup argument not an identifier"
+msgstr ""
+
+#: c-family/c-common.c:9196
+#, gcc-internal-format
+msgid "cleanup argument not a function"
+msgstr ""
+
+#: c-family/c-common.c:9233
+#, gcc-internal-format
+msgid "%qE attribute requires prototypes with named arguments"
+msgstr ""
+
+#: c-family/c-common.c:9241
+#, gcc-internal-format
+msgid "%qE attribute only applies to variadic functions"
+msgstr ""
+
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
+#, gcc-internal-format
+msgid "requested position is not an integer constant"
+msgstr ""
+
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
+#, gcc-internal-format
+msgid "requested position is less than zero"
+msgstr ""
+
+#: c-family/c-common.c:9383
+#, gcc-internal-format, gfc-internal-format
+msgid "bad option %s to optimize attribute"
+msgstr ""
+
+#: c-family/c-common.c:9386
+#, gcc-internal-format, gfc-internal-format
+msgid "bad option %s to pragma attribute"
+msgstr ""
+
+#: c-family/c-common.c:9511
+#, gcc-internal-format
+msgid "returns_nonnull attribute on a function not returning a pointer"
+msgstr ""
+
+#: c-family/c-common.c:9526
+#, gcc-internal-format
+msgid "%qE attribute is only valid on %<struct%> type"
+msgstr ""
+
+#: c-family/c-common.c:9642
+#, gcc-internal-format
+msgid "not enough arguments to function %qE"
+msgstr ""
+
+#: c-family/c-common.c:9648 c-family/c-common.c:10606 c/c-typeck.c:3144
+#, gcc-internal-format
+msgid "too many arguments to function %qE"
+msgstr ""
+
+#: c-family/c-common.c:9678 c-family/c-common.c:9724
+#, gcc-internal-format
+msgid "non-floating-point argument in call to function %qE"
+msgstr ""
+
+#: c-family/c-common.c:9701
+#, gcc-internal-format
+msgid "non-floating-point arguments in call to function %qE"
+msgstr ""
+
+#: c-family/c-common.c:9717
+#, gcc-internal-format
+msgid "non-const integer argument %u in call to function %qE"
+msgstr ""
+
+#: c-family/c-common.c:9737
+#, gcc-internal-format
+msgid "non-integer argument 3 in call to function %qE"
+msgstr ""
+
+#: c-family/c-common.c:9753
+#, gcc-internal-format
+msgid "argument %u in call to function %qE does not have integral type"
+msgstr ""
+
+#: c-family/c-common.c:9760
+#, gcc-internal-format
+msgid "argument 3 in call to function %qE does not have pointer to integer type"
+msgstr ""
+
+#: c-family/c-common.c:10071
+#, gcc-internal-format
+msgid "cannot apply %<offsetof%> to static data member %qD"
+msgstr ""
+
+#: c-family/c-common.c:10076
+#, gcc-internal-format
+msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
+msgstr ""
+
+#: c-family/c-common.c:10083
+#, gcc-internal-format
+msgid "cannot apply %<offsetof%> to a non constant address"
+msgstr ""
+
+#: c-family/c-common.c:10096 cp/typeck.c:5567
+#, gcc-internal-format
+msgid "attempt to take address of bit-field structure member %qD"
+msgstr ""
+
+#: c-family/c-common.c:10147
+#, gcc-internal-format
+msgid "index %E denotes an offset greater than size of %qT"
+msgstr ""
+
+#: c-family/c-common.c:10187
+#, gcc-internal-format
+msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
+msgstr ""
+
+#: c-family/c-common.c:10208
+#, gcc-internal-format
+msgid "assignment of member %qD in read-only object"
+msgstr ""
+
+#: c-family/c-common.c:10210
+#, gcc-internal-format
+msgid "increment of member %qD in read-only object"
+msgstr ""
+
+#: c-family/c-common.c:10212
+#, gcc-internal-format
+msgid "decrement of member %qD in read-only object"
+msgstr ""
+
+#: c-family/c-common.c:10214
+#, gcc-internal-format
+msgid "member %qD in read-only object used as %<asm%> output"
+msgstr ""
+
+#: c-family/c-common.c:10218
+#, gcc-internal-format
+msgid "assignment of read-only member %qD"
+msgstr ""
+
+#: c-family/c-common.c:10219
+#, gcc-internal-format
+msgid "increment of read-only member %qD"
+msgstr ""
+
+#: c-family/c-common.c:10220
+#, gcc-internal-format
+msgid "decrement of read-only member %qD"
+msgstr ""
+
+#: c-family/c-common.c:10221
+#, gcc-internal-format
+msgid "read-only member %qD used as %<asm%> output"
+msgstr ""
+
+#: c-family/c-common.c:10225
+#, gcc-internal-format
+msgid "assignment of read-only variable %qD"
+msgstr ""
+
+#: c-family/c-common.c:10226
+#, gcc-internal-format
+msgid "increment of read-only variable %qD"
+msgstr ""
+
+#: c-family/c-common.c:10227
+#, gcc-internal-format
+msgid "decrement of read-only variable %qD"
+msgstr ""
+
+#: c-family/c-common.c:10228
+#, gcc-internal-format
+msgid "read-only variable %qD used as %<asm%> output"
+msgstr ""
+
+#: c-family/c-common.c:10231
+#, gcc-internal-format
+msgid "assignment of read-only parameter %qD"
+msgstr ""
+
+#: c-family/c-common.c:10232
+#, gcc-internal-format
+msgid "increment of read-only parameter %qD"
+msgstr ""
+
+#: c-family/c-common.c:10233
+#, gcc-internal-format
+msgid "decrement of read-only parameter %qD"
+msgstr ""
+
+#: c-family/c-common.c:10234
+#, gcc-internal-format
+msgid "read-only parameter %qD use as %<asm%> output"
+msgstr ""
+
+#: c-family/c-common.c:10239
+#, gcc-internal-format
+msgid "assignment of read-only named return value %qD"
+msgstr ""
+
+#: c-family/c-common.c:10241
+#, gcc-internal-format
+msgid "increment of read-only named return value %qD"
+msgstr ""
+
+#: c-family/c-common.c:10243
+#, gcc-internal-format
+msgid "decrement of read-only named return value %qD"
+msgstr ""
+
+#: c-family/c-common.c:10245
+#, gcc-internal-format
+msgid "read-only named return value %qD used as %<asm%>output"
+msgstr ""
+
+#: c-family/c-common.c:10250
+#, gcc-internal-format
+msgid "assignment of function %qD"
+msgstr ""
+
+#: c-family/c-common.c:10251
+#, gcc-internal-format
+msgid "increment of function %qD"
+msgstr ""
+
+#: c-family/c-common.c:10252
+#, gcc-internal-format
+msgid "decrement of function %qD"
+msgstr ""
+
+#: c-family/c-common.c:10253
+#, gcc-internal-format
+msgid "function %qD used as %<asm%> output"
+msgstr ""
+
+#: c-family/c-common.c:10256 c/c-typeck.c:4332
+#, gcc-internal-format
+msgid "assignment of read-only location %qE"
+msgstr ""
+
+#: c-family/c-common.c:10257 c/c-typeck.c:4335
+#, gcc-internal-format
+msgid "increment of read-only location %qE"
+msgstr ""
+
+#: c-family/c-common.c:10258 c/c-typeck.c:4338
+#, gcc-internal-format
+msgid "decrement of read-only location %qE"
+msgstr ""
+
+#: c-family/c-common.c:10259
+#, gcc-internal-format
+msgid "read-only location %qE used as %<asm%> output"
+msgstr ""
+
+#: c-family/c-common.c:10273
+#, gcc-internal-format
+msgid "lvalue required as left operand of assignment"
+msgstr ""
+
+#: c-family/c-common.c:10276
+#, gcc-internal-format
+msgid "lvalue required as increment operand"
+msgstr ""
+
+#: c-family/c-common.c:10279
+#, gcc-internal-format
+msgid "lvalue required as decrement operand"
+msgstr ""
+
+#: c-family/c-common.c:10282
+#, gcc-internal-format
+msgid "lvalue required as unary %<&%> operand"
+msgstr ""
+
+#: c-family/c-common.c:10285
+#, gcc-internal-format
+msgid "lvalue required in asm statement"
+msgstr ""
+
+#: c-family/c-common.c:10302
+#, gcc-internal-format
+msgid "invalid type argument (have %qT)"
+msgstr ""
+
+#: c-family/c-common.c:10306
+#, gcc-internal-format
+msgid "invalid type argument of array indexing (have %qT)"
+msgstr ""
+
+#: c-family/c-common.c:10311
+#, gcc-internal-format
+msgid "invalid type argument of unary %<*%> (have %qT)"
+msgstr ""
+
+#: c-family/c-common.c:10316
+#, gcc-internal-format
+msgid "invalid type argument of %<->%> (have %qT)"
+msgstr ""
+
+#: c-family/c-common.c:10321
+#, gcc-internal-format
+msgid "invalid type argument of %<->*%> (have %qT)"
+msgstr ""
+
+#: c-family/c-common.c:10326
+#, gcc-internal-format
+msgid "invalid type argument of implicit conversion (have %qT)"
+msgstr ""
+
+#: c-family/c-common.c:10468 cp/init.c:2472
+#, gcc-internal-format
+msgid "size of array is too large"
+msgstr ""
+
+#: c-family/c-common.c:10516 c-family/c-common.c:10580 c/c-typeck.c:3386
+#, gcc-internal-format
+msgid "too few arguments to function %qE"
+msgstr ""
+
+#: c-family/c-common.c:10540 config/mep/mep.c:6201 c/c-typeck.c:6368
+#, gcc-internal-format
+msgid "incompatible type for argument %d of %qE"
+msgstr ""
+
+#: c-family/c-common.c:10673
+#, gcc-internal-format
+msgid "incorrect number of arguments to function %qE"
+msgstr ""
+
+#: c-family/c-common.c:10688
+#, gcc-internal-format
+msgid "argument 1 of %qE must be a non-void pointer type"
+msgstr ""
+
+#: c-family/c-common.c:10697
+#, gcc-internal-format
+msgid "argument 1 of %qE must be a pointer to a constant size type"
+msgstr ""
+
+#: c-family/c-common.c:10708
+#, gcc-internal-format
+msgid "argument 1 of %qE must be a pointer to a nonzero size object"
+msgstr ""
+
+#: c-family/c-common.c:10723
+#, gcc-internal-format
+msgid "argument %d of %qE must be a pointer type"
+msgstr ""
+
+#: c-family/c-common.c:10731
+#, gcc-internal-format
+msgid "size mismatch in argument %d of %qE"
+msgstr ""
+
+#: c-family/c-common.c:10747
+#, gcc-internal-format
+msgid "invalid memory model argument %d of %qE"
+msgstr ""
+
+#: c-family/c-common.c:10754
+#, gcc-internal-format
+msgid "non-integer memory model argument %d of %qE"
+msgstr ""
+
+#: c-family/c-common.c:11330
+#, gcc-internal-format
+msgid "array subscript has type %<char%>"
+msgstr ""
+
+#: c-family/c-common.c:11365 c-family/c-common.c:11368
+#, gcc-internal-format
+msgid "suggest parentheses around %<+%> inside %<<<%>"
+msgstr ""
+
+#: c-family/c-common.c:11371 c-family/c-common.c:11374
+#, gcc-internal-format
+msgid "suggest parentheses around %<-%> inside %<<<%>"
+msgstr ""
+
+#: c-family/c-common.c:11380 c-family/c-common.c:11383
+#, gcc-internal-format
+msgid "suggest parentheses around %<+%> inside %<>>%>"
+msgstr ""
+
+#: c-family/c-common.c:11386 c-family/c-common.c:11389
+#, gcc-internal-format
+msgid "suggest parentheses around %<-%> inside %<>>%>"
+msgstr ""
+
+#: c-family/c-common.c:11395 c-family/c-common.c:11398
+#, gcc-internal-format
+msgid "suggest parentheses around %<&&%> within %<||%>"
+msgstr ""
+
+#: c-family/c-common.c:11405 c-family/c-common.c:11409
+#, gcc-internal-format
+msgid "suggest parentheses around arithmetic in operand of %<|%>"
+msgstr ""
+
+#: c-family/c-common.c:11413 c-family/c-common.c:11416
+#, gcc-internal-format
+msgid "suggest parentheses around comparison in operand of %<|%>"
+msgstr ""
+
+#: c-family/c-common.c:11421
+#, gcc-internal-format
+msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
+msgstr ""
+
+#: c-family/c-common.c:11429 c-family/c-common.c:11433
+#, gcc-internal-format
+msgid "suggest parentheses around arithmetic in operand of %<^%>"
+msgstr ""
+
+#: c-family/c-common.c:11437 c-family/c-common.c:11440
+#, gcc-internal-format
+msgid "suggest parentheses around comparison in operand of %<^%>"
+msgstr ""
+
+#: c-family/c-common.c:11446 c-family/c-common.c:11449
+#, gcc-internal-format
+msgid "suggest parentheses around %<+%> in operand of %<&%>"
+msgstr ""
+
+#: c-family/c-common.c:11452 c-family/c-common.c:11455
+#, gcc-internal-format
+msgid "suggest parentheses around %<-%> in operand of %<&%>"
+msgstr ""
+
+#: c-family/c-common.c:11459 c-family/c-common.c:11462
+#, gcc-internal-format
+msgid "suggest parentheses around comparison in operand of %<&%>"
+msgstr ""
+
+#: c-family/c-common.c:11467
+#, gcc-internal-format
+msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
+msgstr ""
+
+#: c-family/c-common.c:11474 c-family/c-common.c:11477
+#, gcc-internal-format
+msgid "suggest parentheses around comparison in operand of %<==%>"
+msgstr ""
+
+#: c-family/c-common.c:11482 c-family/c-common.c:11485
+#, gcc-internal-format
+msgid "suggest parentheses around comparison in operand of %<!=%>"
+msgstr ""
+
+#: c-family/c-common.c:11495 c-family/c-common.c:11501
+#, gcc-internal-format
+msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
+msgstr ""
+
+#: c-family/c-common.c:11517
+#, gcc-internal-format
+msgid "label %q+D defined but not used"
+msgstr ""
+
+#: c-family/c-common.c:11519
+#, gcc-internal-format
+msgid "label %q+D declared but not defined"
+msgstr ""
+
+#: c-family/c-common.c:11535
+#, gcc-internal-format
+msgid "division by zero"
+msgstr "ділення на нуль"
+
+#: c-family/c-common.c:11567
+#, gcc-internal-format
+msgid "comparison between types %qT and %qT"
+msgstr ""
+
+#: c-family/c-common.c:11618
+#, gcc-internal-format
+msgid "comparison between signed and unsigned integer expressions"
+msgstr ""
+
+#: c-family/c-common.c:11669
+#, gcc-internal-format
+msgid "promoted ~unsigned is always non-zero"
+msgstr ""
+
+#: c-family/c-common.c:11672
+#, gcc-internal-format
+msgid "comparison of promoted ~unsigned with constant"
+msgstr ""
+
+#: c-family/c-common.c:11682
+#, gcc-internal-format
+msgid "comparison of promoted ~unsigned with unsigned"
+msgstr ""
+
+#: c-family/c-common.c:11860
+#, gcc-internal-format
+msgid "typedef %qD locally defined but not used"
+msgstr ""
+
+#: c-family/c-common.c:11892
+#, gcc-internal-format
+msgid "comparison of constant %qE with boolean expression is always false"
+msgstr ""
+
+#: c-family/c-common.c:11895
+#, gcc-internal-format
+msgid "comparison of constant %qE with boolean expression is always true"
+msgstr ""
+
+#: c-family/c-common.c:12141
+#, gcc-internal-format
+msgid "index value is out of bound"
+msgstr ""
+
+#: c-family/c-common.c:12214 c-family/c-common.c:12264
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
+#, gcc-internal-format
+msgid "conversion of scalar %qT to vector %qT involves truncation"
+msgstr ""
+
+#: c-family/c-format.c:114 c-family/c-format.c:301
+#, gcc-internal-format
+msgid "format string has invalid operand number"
+msgstr ""
+
+#: c-family/c-format.c:130
+#, gcc-internal-format
+msgid "function does not return string type"
+msgstr ""
+
+#: c-family/c-format.c:164
+#, gcc-internal-format
+msgid "format string argument is not a string type"
+msgstr ""
+
+#: c-family/c-format.c:190
+#, gcc-internal-format
+msgid "found a %<%s%> reference but the format argument should be a string"
+msgstr ""
+
+#: c-family/c-format.c:193
+#, gcc-internal-format
+msgid "found a %qT but the format argument should be a string"
+msgstr ""
+
+#: c-family/c-format.c:203
+#, gcc-internal-format
+msgid "format argument should be a %<%s%> reference but a string was found"
+msgstr ""
+
+#: c-family/c-format.c:225
+#, gcc-internal-format
+msgid "format argument should be a %<%s%> reference"
+msgstr ""
+
+#: c-family/c-format.c:269
+#, gcc-internal-format
+msgid "unrecognized format specifier"
+msgstr ""
+
+#: c-family/c-format.c:284
+#, gcc-internal-format
+msgid "%qE is only allowed in Objective-C dialects"
+msgstr ""
+
+#: c-family/c-format.c:293
+#, gcc-internal-format
+msgid "%qE is an unrecognized format function type"
+msgstr ""
+
+#: c-family/c-format.c:307
+#, gcc-internal-format
+msgid "%<...%> has invalid operand number"
+msgstr ""
+
+#: c-family/c-format.c:314
+#, gcc-internal-format
+msgid "format string argument follows the args to be formatted"
+msgstr ""
+
+#: c-family/c-format.c:1060
+#, gcc-internal-format
+msgid "function might be possible candidate for %qs format attribute"
+msgstr ""
+
+#: c-family/c-format.c:1150 c-family/c-format.c:1171 c-family/c-format.c:2263
+#, gcc-internal-format
+msgid "missing $ operand number in format"
+msgstr ""
+
+#: c-family/c-format.c:1180
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support %%n$ operand number formats"
+msgstr ""
+
+#: c-family/c-format.c:1187
+#, gcc-internal-format
+msgid "operand number out of range in format"
+msgstr ""
+
+#: c-family/c-format.c:1210
+#, gcc-internal-format, gfc-internal-format
+msgid "format argument %d used more than once in %s format"
+msgstr ""
+
+#: c-family/c-format.c:1242
+#, gcc-internal-format
+msgid "$ operand number used after format without operand number"
+msgstr ""
+
+#: c-family/c-format.c:1273
+#, gcc-internal-format, gfc-internal-format
+msgid "format argument %d unused before used argument %d in $-style format"
+msgstr ""
+
+#: c-family/c-format.c:1374
+#, gcc-internal-format
+msgid "format not a string literal, format string not checked"
+msgstr ""
+
+#: c-family/c-format.c:1389 c-family/c-format.c:1392
+#, gcc-internal-format
+msgid "format not a string literal and no format arguments"
+msgstr ""
+
+#: c-family/c-format.c:1395
+#, gcc-internal-format
+msgid "format not a string literal, argument types not checked"
+msgstr ""
+
+#: c-family/c-format.c:1409
+#, gcc-internal-format
+msgid "too many arguments for format"
+msgstr ""
+
+#: c-family/c-format.c:1412
+#, gcc-internal-format
+msgid "unused arguments in $-style format"
+msgstr ""
+
+#: c-family/c-format.c:1415
+#, gcc-internal-format, gfc-internal-format
+msgid "zero-length %s format string"
+msgstr ""
+
+#: c-family/c-format.c:1419
+#, gcc-internal-format
+msgid "format is a wide character string"
+msgstr ""
+
+#: c-family/c-format.c:1422
+#, gcc-internal-format
+msgid "unterminated format string"
+msgstr ""
+
+#: c-family/c-format.c:1686
+#, gcc-internal-format
+msgid "spurious trailing %<%%%> in format"
+msgstr ""
+
+#: c-family/c-format.c:1731 c-family/c-format.c:2016
+#, gcc-internal-format, gfc-internal-format
+msgid "repeated %s in format"
+msgstr ""
+
+#: c-family/c-format.c:1745
+#, gcc-internal-format
+msgid "missing fill character at end of strfmon format"
+msgstr ""
+
+#: c-family/c-format.c:1834
+#, gcc-internal-format, gfc-internal-format
+msgid "zero width in %s format"
+msgstr ""
+
+#: c-family/c-format.c:1853
+#, gcc-internal-format, gfc-internal-format
+msgid "empty left precision in %s format"
+msgstr ""
+
+#: c-family/c-format.c:1930
+#, gcc-internal-format, gfc-internal-format
+msgid "empty precision in %s format"
+msgstr ""
+
+#: c-family/c-format.c:1999
+#, gcc-internal-format
+msgid "%s does not support the %qs %s length modifier"
+msgstr ""
+
+#: c-family/c-format.c:2034
+#, gcc-internal-format
+msgid "conversion lacks type at end of format"
+msgstr ""
+
+#: c-family/c-format.c:2046
+#, gcc-internal-format
+msgid "unknown conversion type character %qc in format"
+msgstr ""
+
+#: c-family/c-format.c:2050
+#, gcc-internal-format
+msgid "unknown conversion type character 0x%x in format"
+msgstr ""
+
+#: c-family/c-format.c:2058
+#, gcc-internal-format
+msgid "%s does not support the %<%%%c%> %s format"
+msgstr ""
+
+#: c-family/c-format.c:2075
+#, gcc-internal-format
+msgid "%s used with %<%%%c%> %s format"
+msgstr ""
+
+#: c-family/c-format.c:2085
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support %s"
+msgstr ""
+
+#: c-family/c-format.c:2095
+#, gcc-internal-format
+msgid "%s does not support %s with the %<%%%c%> %s format"
+msgstr ""
+
+#: c-family/c-format.c:2131
+#, gcc-internal-format
+msgid "%s ignored with %s and %<%%%c%> %s format"
+msgstr ""
+
+#: c-family/c-format.c:2136
+#, gcc-internal-format, gfc-internal-format
+msgid "%s ignored with %s in %s format"
+msgstr ""
+
+#: c-family/c-format.c:2143
+#, gcc-internal-format
+msgid "use of %s and %s together with %<%%%c%> %s format"
+msgstr ""
+
+#: c-family/c-format.c:2148
+#, gcc-internal-format, gfc-internal-format
+msgid "use of %s and %s together in %s format"
+msgstr ""
+
+#: c-family/c-format.c:2168
+#, gcc-internal-format
+msgid "%<%%%c%> yields only last 2 digits of year in some locales"
+msgstr ""
+
+#: c-family/c-format.c:2172
+#, gcc-internal-format
+msgid "%<%%%c%> yields only last 2 digits of year"
+msgstr ""
+
+#: c-family/c-format.c:2190
+#, gcc-internal-format
+msgid "no closing %<]%> for %<%%[%> format"
+msgstr ""
+
+#: c-family/c-format.c:2204
+#, gcc-internal-format
+msgid "use of %qs length modifier with %qc type character"
+msgstr ""
+
+#: c-family/c-format.c:2222
+#, gcc-internal-format
+msgid "%s does not support the %<%%%s%c%> %s format"
+msgstr ""
+
+#: c-family/c-format.c:2240
+#, gcc-internal-format
+msgid "operand number specified with suppressed assignment"
+msgstr ""
+
+#: c-family/c-format.c:2244
+#, gcc-internal-format
+msgid "operand number specified for format taking no argument"
+msgstr ""
+
+#: c-family/c-format.c:2331
+#, gcc-internal-format
+msgid "embedded %<\\0%> in format"
+msgstr ""
+
+#: c-family/c-format.c:2401
+#, gcc-internal-format, gfc-internal-format
+msgid "writing through null pointer (argument %d)"
+msgstr ""
+
+#: c-family/c-format.c:2409
+#, gcc-internal-format, gfc-internal-format
+msgid "reading through null pointer (argument %d)"
+msgstr ""
+
+#: c-family/c-format.c:2429
+#, gcc-internal-format, gfc-internal-format
+msgid "writing into constant object (argument %d)"
+msgstr ""
+
+#: c-family/c-format.c:2441
+#, gcc-internal-format, gfc-internal-format
+msgid "extra type qualifiers in format argument (argument %d)"
+msgstr ""
+
+#: c-family/c-format.c:2575
+#, gcc-internal-format
+msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
+msgstr ""
+
+#: c-family/c-format.c:2583
+#, gcc-internal-format
+msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
+msgstr ""
+
+#: c-family/c-format.c:2592
+#, gcc-internal-format
+msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
+msgstr ""
+
+#: c-family/c-format.c:2600
+#, gcc-internal-format
+msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
+msgstr ""
+
+#: c-family/c-format.c:2660 c-family/c-format.c:2666 c-family/c-format.c:2817
+#, gcc-internal-format
+msgid "%<__gcc_host_wide_int__%> is not defined as a type"
+msgstr ""
+
+#: c-family/c-format.c:2673 c-family/c-format.c:2827
+#, gcc-internal-format
+msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
+msgstr ""
+
+#: c-family/c-format.c:2723
+#, gcc-internal-format
+msgid "%<locus%> is not defined as a type"
+msgstr ""
+
+#: c-family/c-format.c:2776
+#, gcc-internal-format
+msgid "%<location_t%> is not defined as a type"
+msgstr ""
+
+#: c-family/c-format.c:2793
+#, gcc-internal-format
+msgid "%<tree%> is not defined as a type"
+msgstr ""
+
+#: c-family/c-format.c:2798
+#, gcc-internal-format
+msgid "%<tree%> is not defined as a pointer type"
+msgstr ""
+
+#: c-family/c-format.c:3071
+#, gcc-internal-format
+msgid "args to be formatted is not %<...%>"
+msgstr ""
+
+#: c-family/c-format.c:3083
+#, gcc-internal-format
+msgid "strftime formats cannot format arguments"
+msgstr ""
+
+#: c-family/c-lex.c:239
+#, gcc-internal-format
+msgid "badly nested C headers from preprocessor"
+msgstr ""
+
+#: c-family/c-lex.c:274
+#, gcc-internal-format, gfc-internal-format
+msgid "ignoring #pragma %s %s"
+msgstr ""
+
+#. ... or not.
+#: c-family/c-lex.c:511 c-family/c-lex.c:1171
+#, gcc-internal-format
+msgid "stray %<@%> in program"
+msgstr ""
+
+#: c-family/c-lex.c:526
+#, gcc-internal-format
+msgid "stray %qs in program"
+msgstr ""
+
+#: c-family/c-lex.c:536
+#, gcc-internal-format, gfc-internal-format
+msgid "missing terminating %c character"
+msgstr "відсутній завершальний символ %c"
+
+#: c-family/c-lex.c:538
+#, gcc-internal-format
+msgid "stray %qc in program"
+msgstr ""
+
+#: c-family/c-lex.c:540
+#, gcc-internal-format
+msgid "stray %<\\%o%> in program"
+msgstr ""
+
+#: c-family/c-lex.c:746
+#, gcc-internal-format
+msgid "this decimal constant is unsigned only in ISO C90"
+msgstr ""
+
+#: c-family/c-lex.c:750
+#, gcc-internal-format
+msgid "this decimal constant would be unsigned in ISO C90"
+msgstr ""
+
+#: c-family/c-lex.c:770
+#, gcc-internal-format
+msgid "integer constant is too large for %<unsigned long%> type"
+msgstr ""
+
+#: c-family/c-lex.c:810
+#, gcc-internal-format
+msgid "unsuffixed float constant"
+msgstr ""
+
+#: c-family/c-lex.c:842
+#, gcc-internal-format
+msgid "unsupported non-standard suffix on floating constant"
+msgstr ""
+
+#: c-family/c-lex.c:847
+#, gcc-internal-format
+msgid "non-standard suffix on floating constant"
+msgstr ""
+
+#: c-family/c-lex.c:918 c-family/c-lex.c:921
+#, gcc-internal-format
+msgid "floating constant exceeds range of %qT"
+msgstr ""
+
+#: c-family/c-lex.c:936
+#, gcc-internal-format
+msgid "floating constant truncated to zero"
+msgstr ""
+
+#: c-family/c-lex.c:1133
+#, gcc-internal-format
+msgid "repeated %<@%> before Objective-C string"
+msgstr ""
+
+#: c-family/c-lex.c:1152 cp/parser.c:3716
+#, gcc-internal-format
+msgid "unsupported non-standard concatenation of string literals"
+msgstr ""
+
+#: c-family/c-lex.c:1180
+#, gcc-internal-format
+msgid "traditional C rejects string constant concatenation"
+msgstr ""
+
+#: c-family/c-omp.c:205
+#, gcc-internal-format
+msgid "invalid expression type for %<#pragma omp atomic%>"
+msgstr ""
+
+#: c-family/c-omp.c:279
+#, gcc-internal-format
+msgid "%<#pragma omp atomic update%> uses two different variables for memory"
+msgstr ""
+
+#: c-family/c-omp.c:281 c-family/c-omp.c:293
+#, gcc-internal-format
+msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
+msgstr ""
+
+#: c-family/c-omp.c:474 cp/semantics.c:6635
+#, gcc-internal-format
+msgid "invalid type for iteration variable %qE"
+msgstr ""
+
+#: c-family/c-omp.c:487
+#, gcc-internal-format
+msgid "%qE is not initialized"
+msgstr ""
+
+#: c-family/c-omp.c:507 cp/semantics.c:6541
+#, gcc-internal-format
+msgid "missing controlling predicate"
+msgstr ""
+
+#: c-family/c-omp.c:592 cp/semantics.c:6285
+#, gcc-internal-format
+msgid "invalid controlling predicate"
+msgstr ""
+
+#: c-family/c-omp.c:599 cp/semantics.c:6547
+#, gcc-internal-format
+msgid "missing increment expression"
+msgstr ""
+
+#: c-family/c-omp.c:663 cp/semantics.c:6395
+#, gcc-internal-format
+msgid "invalid increment expression"
+msgstr ""
+
+#: c-family/c-omp.c:1036
+#, gcc-internal-format
+msgid "%qD is not an function argument"
+msgstr ""
+
+#: c-family/c-opts.c:329
+#, gcc-internal-format
+msgid "-I- specified twice"
+msgstr ""
+
+#: c-family/c-opts.c:332
+#, gcc-internal-format
+msgid "obsolete option -I- used, please use -iquote instead"
+msgstr ""
+
+#: c-family/c-opts.c:410
+#, gcc-internal-format
+msgid "%<-Wabi=1%> is not supported, using =2"
+msgstr "Підтримки %<-Wabi=1%> не передбачено, використовуємо =2"
+
+#: c-family/c-opts.c:600 fortran/cpp.c:365
+#, gcc-internal-format
+msgid "output filename specified twice"
+msgstr ""
+
+#: c-family/c-opts.c:779
+#, gcc-internal-format
+msgid "-fexcess-precision=standard for C++"
+msgstr ""
+
+#: c-family/c-opts.c:802
+#, gcc-internal-format
+msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
+msgstr ""
+
+#: c-family/c-opts.c:848
+#, gcc-internal-format
+msgid "-Wformat-y2k ignored without -Wformat"
+msgstr ""
+
+#: c-family/c-opts.c:850
+#, gcc-internal-format
+msgid "-Wformat-extra-args ignored without -Wformat"
+msgstr ""
+
+#: c-family/c-opts.c:852
+#, gcc-internal-format
+msgid "-Wformat-zero-length ignored without -Wformat"
+msgstr ""
+
+#: c-family/c-opts.c:854
+#, gcc-internal-format
+msgid "-Wformat-nonliteral ignored without -Wformat"
+msgstr ""
+
+#: c-family/c-opts.c:856
+#, gcc-internal-format
+msgid "-Wformat-contains-nul ignored without -Wformat"
+msgstr ""
+
+#: c-family/c-opts.c:858
+#, gcc-internal-format
+msgid "-Wformat-security ignored without -Wformat"
+msgstr ""
+
+#: c-family/c-opts.c:875
+#, gcc-internal-format
+msgid "%<-fabi-compat-version=1%> is not supported, using =2"
+msgstr "Підтримки %<-fabi-compat-version=1%> не передбачено, використовуємо =2"
+
+#: c-family/c-opts.c:916
+#, gcc-internal-format
+msgid "external TLS initialization functions not supported on this target"
+msgstr ""
+
+#: c-family/c-opts.c:936
+#, gcc-internal-format
+msgid "opening output file %s: %m"
+msgstr ""
+
+#: c-family/c-opts.c:941
+#, gcc-internal-format, gfc-internal-format
+msgid "too many filenames given.  Type %s --help for usage"
+msgstr ""
+
+#: c-family/c-opts.c:960
+#, gcc-internal-format, gfc-internal-format
+msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
+msgstr ""
+
+#: c-family/c-opts.c:1119
+#, gcc-internal-format
+msgid "opening dependency file %s: %m"
+msgstr ""
+
+#: c-family/c-opts.c:1130
+#, gcc-internal-format
+msgid "closing dependency file %s: %m"
+msgstr ""
+
+#: c-family/c-opts.c:1133
+#, gcc-internal-format
+msgid "when writing output to %s: %m"
+msgstr ""
+
+#: c-family/c-opts.c:1213
+#, gcc-internal-format
+msgid "to generate dependencies you must specify either -M or -MM"
+msgstr ""
+
+#: c-family/c-opts.c:1236
+#, gcc-internal-format
+msgid "-MG may only be used with -M or -MM"
+msgstr ""
+
+#: c-family/c-opts.c:1264
+#, gcc-internal-format
+msgid "-fdirectives-only is incompatible with -Wunused_macros"
+msgstr ""
+
+#: c-family/c-opts.c:1266
+#, gcc-internal-format
+msgid "-fdirectives-only is incompatible with -traditional"
+msgstr ""
+
+#: c-family/c-opts.c:1456
+#, gcc-internal-format
+msgid "too late for # directive to set debug directory"
+msgstr ""
+
+#: c-family/c-pch.c:125
+#, gcc-internal-format
+msgid "can%'t create precompiled header %s: %m"
+msgstr ""
+
+#: c-family/c-pch.c:148
+#, gcc-internal-format
+msgid "can%'t write to %s: %m"
+msgstr ""
+
+#: c-family/c-pch.c:206
+#, gcc-internal-format
+msgid "can%'t write %s: %m"
+msgstr ""
+
+#: c-family/c-pch.c:234 c-family/c-pch.c:275 c-family/c-pch.c:326
+#, gcc-internal-format
+msgid "can%'t read %s: %m"
+msgstr ""
+
+#: c-family/c-pch.c:432
+#, gcc-internal-format
+msgid "pch_preprocess pragma should only be used with -fpreprocessed"
+msgstr ""
+
+#: c-family/c-pch.c:433
+#, gcc-internal-format
+msgid "use #include instead"
+msgstr ""
+
+#: c-family/c-pch.c:439
+#, gcc-internal-format
+msgid "%s: couldn%'t open PCH file: %m"
+msgstr ""
+
+#: c-family/c-pch.c:444
+#, gcc-internal-format
+msgid "use -Winvalid-pch for more information"
+msgstr "докладніша інформація виводиться, якщо вказати -Winvalid-pch"
+
+#: c-family/c-pch.c:445
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: PCH file was invalid"
+msgstr ""
+
+#: c-family/c-pragma.c:119
+#, gcc-internal-format
+msgid "#pragma pack (pop) encountered without matching #pragma pack (push)"
+msgstr ""
+
+#: c-family/c-pragma.c:132
+#, gcc-internal-format
+msgid "#pragma pack(pop, %E) encountered without matching #pragma pack(push, %E)"
+msgstr ""
+
+#: c-family/c-pragma.c:162
+#, gcc-internal-format
+msgid "missing %<(%> after %<#pragma pack%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:173 c-family/c-pragma.c:205
+#, gcc-internal-format
+msgid "invalid constant in %<#pragma pack%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:177 c-family/c-pragma.c:219
+#, gcc-internal-format
+msgid "malformed %<#pragma pack%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:182
+#, gcc-internal-format
+msgid "malformed %<#pragma pack(push[, id][, <n>])%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:184
+#, gcc-internal-format
+msgid "malformed %<#pragma pack(pop[, id])%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:193
+#, gcc-internal-format
+msgid "unknown action %qE for %<#pragma pack%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:222
+#, gcc-internal-format
+msgid "junk at end of %<#pragma pack%>"
+msgstr ""
+
+#: c-family/c-pragma.c:225
+#, gcc-internal-format
+msgid "#pragma pack has no effect with -fpack-struct - ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:245
+#, gcc-internal-format, gfc-internal-format
+msgid "alignment must be a small power of two, not %d"
+msgstr ""
+
+#: c-family/c-pragma.c:284
+#, gcc-internal-format
+msgid "applying #pragma weak %q+D after first use results in unspecified behavior"
+msgstr ""
+
+#: c-family/c-pragma.c:381 c-family/c-pragma.c:386
+#, gcc-internal-format
+msgid "malformed #pragma weak, ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:390
+#, gcc-internal-format
+msgid "junk at end of %<#pragma weak%>"
+msgstr ""
+
+#: c-family/c-pragma.c:396
+#, gcc-internal-format
+msgid "%<#pragma weak%> declaration of %q+D not allowed, ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:465 c-family/c-pragma.c:467
+#, gcc-internal-format
+msgid "malformed #pragma redefine_extname, ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:470
+#, gcc-internal-format
+msgid "junk at end of %<#pragma redefine_extname%>"
+msgstr ""
+
+#: c-family/c-pragma.c:499 c-family/c-pragma.c:572
+#, gcc-internal-format
+msgid "#pragma redefine_extname ignored due to conflict with previous rename"
+msgstr ""
+
+#: c-family/c-pragma.c:527
+#, gcc-internal-format
+msgid "#pragma redefine_extname ignored due to conflict with previous #pragma redefine_extname"
+msgstr ""
+
+#: c-family/c-pragma.c:563
+#, gcc-internal-format
+msgid "asm declaration ignored due to conflict with previous rename"
+msgstr ""
+
+#: c-family/c-pragma.c:594
+#, gcc-internal-format
+msgid "#pragma redefine_extname ignored due to conflict with __asm__ declaration"
+msgstr ""
+
+#: c-family/c-pragma.c:655
+#, gcc-internal-format
+msgid "#pragma GCC visibility push() must specify default, internal, hidden or protected"
+msgstr ""
+
+#: c-family/c-pragma.c:697
+#, gcc-internal-format
+msgid "#pragma GCC visibility must be followed by push or pop"
+msgstr ""
+
+#: c-family/c-pragma.c:703
+#, gcc-internal-format
+msgid "no matching push for %<#pragma GCC visibility pop%>"
+msgstr ""
+
+#: c-family/c-pragma.c:708 c-family/c-pragma.c:715
+#, gcc-internal-format
+msgid "missing %<(%> after %<#pragma GCC visibility push%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:711
+#, gcc-internal-format
+msgid "malformed #pragma GCC visibility push"
+msgstr ""
+
+#: c-family/c-pragma.c:719
+#, gcc-internal-format
+msgid "junk at end of %<#pragma GCC visibility%>"
+msgstr ""
+
+#: c-family/c-pragma.c:734
+#, gcc-internal-format
+msgid "missing [error|warning|ignored] after %<#pragma GCC diagnostic%>"
+msgstr ""
+
+#: c-family/c-pragma.c:753
+#, gcc-internal-format
+msgid "expected [error|warning|ignored|push|pop] after %<#pragma GCC diagnostic%>"
+msgstr ""
+
+#: c-family/c-pragma.c:757
+#, gcc-internal-format
+msgid "missing option after %<#pragma GCC diagnostic%> kind"
+msgstr ""
+
+#: c-family/c-pragma.c:769
+#, gcc-internal-format
+msgid "unknown option after %<#pragma GCC diagnostic%> kind"
+msgstr ""
+
+#: c-family/c-pragma.c:782
+#, gcc-internal-format
+msgid "#pragma GCC option is not allowed inside functions"
+msgstr ""
+
+#: c-family/c-pragma.c:795
+#, gcc-internal-format
+msgid "%<#pragma GCC option%> is not a string"
+msgstr ""
+
+#: c-family/c-pragma.c:822
+#, gcc-internal-format
+msgid "%<#pragma GCC target (string [,string]...)%> does not have a final %<)%>"
+msgstr ""
+
+#: c-family/c-pragma.c:828
+#, gcc-internal-format
+msgid "#pragma GCC target string... is badly formed"
+msgstr ""
+
+#: c-family/c-pragma.c:851
+#, gcc-internal-format
+msgid "#pragma GCC optimize is not allowed inside functions"
+msgstr ""
+
+#: c-family/c-pragma.c:864
+#, gcc-internal-format
+msgid "%<#pragma GCC optimize%> is not a string or number"
+msgstr ""
+
+#: c-family/c-pragma.c:890
+#, gcc-internal-format
+msgid "%<#pragma GCC optimize (string [,string]...)%> does not have a final %<)%>"
+msgstr ""
+
+#: c-family/c-pragma.c:896
+#, gcc-internal-format
+msgid "#pragma GCC optimize string... is badly formed"
+msgstr ""
+
+#: c-family/c-pragma.c:937
+#, gcc-internal-format
+msgid "junk at end of %<#pragma push_options%>"
+msgstr ""
+
+#: c-family/c-pragma.c:967
+#, gcc-internal-format
+msgid "junk at end of %<#pragma pop_options%>"
+msgstr ""
+
+#: c-family/c-pragma.c:974
+#, gcc-internal-format
+msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
+msgstr ""
+
+#: c-family/c-pragma.c:1016
+#, gcc-internal-format
+msgid "junk at end of %<#pragma reset_options%>"
+msgstr ""
+
+#: c-family/c-pragma.c:1054 c-family/c-pragma.c:1061
+#, gcc-internal-format
+msgid "expected a string after %<#pragma message%>"
+msgstr ""
+
+#: c-family/c-pragma.c:1056
+#, gcc-internal-format
+msgid "malformed %<#pragma message%>, ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:1066
+#, gcc-internal-format
+msgid "junk at end of %<#pragma message%>"
+msgstr ""
+
+#: c-family/c-pragma.c:1069
+#, gcc-internal-format, gfc-internal-format
+msgid "#pragma message: %s"
+msgstr ""
+
+#: c-family/c-pragma.c:1106
+#, gcc-internal-format
+msgid "invalid location for %<pragma %s%>, ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:1113 c-family/c-pragma.c:1127
+#, gcc-internal-format
+msgid "malformed %<#pragma %s%>, ignored"
+msgstr ""
+
+#: c-family/c-pragma.c:1133
+#, gcc-internal-format
+msgid "junk at end of %<#pragma %s%>"
+msgstr ""
+
+#: c-family/c-pragma.c:1151
+#, gcc-internal-format
+msgid "%<#pragma STDC FLOAT_CONST_DECIMAL64%> is not supported for C++"
+msgstr ""
+
+#: c-family/c-pragma.c:1160
+#, gcc-internal-format
+msgid "%<#pragma STDC FLOAT_CONST_DECIMAL64%> is not supported on this target"
+msgstr ""
+
+#: c-family/c-pragma.c:1166
+#, gcc-internal-format
+msgid "ISO C does not support %<#pragma STDC FLOAT_CONST_DECIMAL64%>"
+msgstr ""
+
+#: c-family/c-pretty-print.c:362
+#, gcc-internal-format
+msgid "<type-error>"
+msgstr ""
+
+#: c-family/c-pretty-print.c:401
+#, gcc-internal-format
+msgid "<unnamed-unsigned:"
+msgstr ""
+
+#: c-family/c-pretty-print.c:405
+#, gcc-internal-format
+msgid "<unnamed-float:"
+msgstr ""
+
+#: c-family/c-pretty-print.c:408
+#, gcc-internal-format
+msgid "<unnamed-fixed:"
+msgstr ""
+
+#: c-family/c-pretty-print.c:423
+#, gcc-internal-format
+msgid "<typedef-error>"
+msgstr ""
+
+#: c-family/c-pretty-print.c:438
+#, gcc-internal-format
+msgid "<tag-error>"
+msgstr ""
+
+#: c-family/c-pretty-print.c:1272
+#, gcc-internal-format
+msgid "<erroneous-expression>"
+msgstr ""
+
+#: c-family/c-pretty-print.c:1276 cp/cxx-pretty-print.c:139
+#, gcc-internal-format
+msgid "<return-value>"
+msgstr ""
+
+#: c-family/c-semantics.c:168
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong type argument to %s"
+msgstr ""
+
+#: c-family/cilk.c:116 cp/parser.c:5997
+#, gcc-internal-format
+msgid "%<_Cilk_spawn%> may only be used inside a function"
+msgstr ""
+
+#: c-family/cilk.c:129
+#, gcc-internal-format
+msgid "only function calls can be spawned"
+msgstr ""
+
+#: c-family/cilk.c:262
+#, gcc-internal-format
+msgid "invalid use of %<_Cilk_spawn%>"
+msgstr ""
+
+#: c-family/cilk.c:403
+#, gcc-internal-format
+msgid "explicit register variable %qD may not be modified in spawn"
+msgstr ""
+
+#: c-family/cilk.c:484
+#, gcc-internal-format
+msgid "cannot spawn call to function that returns twice"
+msgstr ""
+
+#: c-family/cilk.c:505
+#, gcc-internal-format
+msgid "invalid use of label %q+D in %<_Cilk_spawn%>"
+msgstr ""
+
+#: c-family/cilk.c:975
+#, gcc-internal-format
+msgid "register assignment ignored for %qD used in Cilk block"
+msgstr ""
+
+#: c-family/cppspec.c:93
+#, gcc-internal-format
+msgid "%qs is not a valid option to the preprocessor"
+msgstr ""
+
+#: c-family/cppspec.c:112
+#, gcc-internal-format
+msgid "too many input files"
+msgstr ""
+
+#: common/config/aarch64/aarch64-common.c:116
+#, gcc-internal-format
+msgid "-mcpu string too large"
+msgstr ""
+
+#: common/config/alpha/alpha-common.c:76
+#, gcc-internal-format
+msgid "bad value %qs for -mtls-size switch"
+msgstr ""
+
+#: common/config/arc/arc-common.c:80
+#, gcc-internal-format
+msgid "multiple -mcpu= options specified."
+msgstr ""
+
+#: common/config/bfin/bfin-common.c:304 common/config/m68k/m68k-common.c:60
+#, gcc-internal-format, gfc-internal-format
+msgid "-mshared-library-id=%s is not between 0 and %d"
+msgstr ""
+
+#: common/config/bfin/bfin-common.c:323
+#, gcc-internal-format, gfc-internal-format
+msgid "-mcpu=%s is not valid"
+msgstr ""
+
+#: common/config/bfin/bfin-common.c:359
+#, gcc-internal-format, gfc-internal-format
+msgid "-mcpu=%s has invalid silicon revision"
+msgstr ""
+
+#: common/config/i386/i386-common.c:954
+#, gcc-internal-format
+msgid "-malign-loops is obsolete, use -falign-loops"
+msgstr ""
+
+#: common/config/i386/i386-common.c:956
+#, gcc-internal-format, gfc-internal-format
+msgid "-malign-loops=%d is not between 0 and %d"
+msgstr ""
+
+#: common/config/i386/i386-common.c:963
+#, gcc-internal-format
+msgid "-malign-jumps is obsolete, use -falign-jumps"
+msgstr ""
+
+#: common/config/i386/i386-common.c:965
+#, gcc-internal-format, gfc-internal-format
+msgid "-malign-jumps=%d is not between 0 and %d"
+msgstr ""
+
+#: common/config/i386/i386-common.c:973
+#, gcc-internal-format
+msgid "-malign-functions is obsolete, use -falign-functions"
+msgstr ""
+
+#: common/config/i386/i386-common.c:975
+#, gcc-internal-format, gfc-internal-format
+msgid "-malign-functions=%d is not between 0 and %d"
+msgstr ""
+
+#: common/config/i386/i386-common.c:984
+#, gcc-internal-format, gfc-internal-format
+msgid "-mbranch-cost=%d is not between 0 and 5"
+msgstr ""
+
+#: common/config/i386/i386-common.c:1035
+#, gcc-internal-format
+msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
+msgstr ""
+
+#: common/config/i386/i386-common.c:1041
+#, gcc-internal-format
+msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
+msgstr ""
+
+#: common/config/ia64/ia64-common.c:58
+#, gcc-internal-format
+msgid "bad value %<%s%> for -mtls-size= switch"
+msgstr ""
+
+#: common/config/msp430/msp430-common.c:59
+#, gcc-internal-format, gfc-internal-format
+msgid "unrecognised argument of -mcpu: %s"
+msgstr ""
+
+#: common/config/nds32/nds32-common.c:49
+#, gcc-internal-format
+msgid "for the option -misr-vector-size=X, the valid X must be: 4 or 16"
+msgstr ""
+
+#: common/config/nds32/nds32-common.c:60
+#, gcc-internal-format
+msgid "for the option -mcache-block-size=X, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
+msgstr ""
+
+#: common/config/rs6000/rs6000-common.c:172 config/sparc/sparc.c:1362
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown -mdebug-%s switch"
+msgstr ""
+
+#: common/config/rs6000/rs6000-common.c:220
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown switch -mlong-double-%s"
+msgstr ""
+
+#: common/config/rs6000/rs6000-common.c:230
+#, gcc-internal-format
+msgid "-msingle-float option equivalent to -mhard-float"
+msgstr ""
+
+#: common/config/rs6000/rs6000-common.c:246
+#, gcc-internal-format
+msgid "-msimple-fpu option ignored"
+msgstr ""
+
+#: common/config/rx/rx-common.c:61
+#, gcc-internal-format
+msgid "the RX200 cpu does not have FPU hardware"
+msgstr ""
+
+#: common/config/rx/rx-common.c:63
+#, gcc-internal-format
+msgid "the RX100 cpu does not have FPU hardware"
+msgstr ""
+
+#: common/config/s390/s390-common.c:98
+#, gcc-internal-format
+msgid "stack guard value must be an exact power of 2"
+msgstr ""
+
+#: common/config/s390/s390-common.c:103
+#, gcc-internal-format
+msgid "stack size must be an exact power of 2"
+msgstr ""
+
+#: common/config/v850/v850-common.c:47
+#, gcc-internal-format
+msgid "value passed in %qs is too large"
+msgstr ""
+
+#: config/darwin-c.c:116
+#, gcc-internal-format
+msgid "too many #pragma options align=reset"
+msgstr ""
+
+#: config/darwin-c.c:136 config/darwin-c.c:139 config/darwin-c.c:141
+#: config/darwin-c.c:143
+#, gcc-internal-format
+msgid "malformed '#pragma options', ignoring"
+msgstr ""
+
+#: config/darwin-c.c:146
+#, gcc-internal-format
+msgid "junk at end of '#pragma options'"
+msgstr ""
+
+#: config/darwin-c.c:156
+#, gcc-internal-format
+msgid "malformed '#pragma options align={mac68k|power|reset}', ignoring"
+msgstr ""
+
+#: config/darwin-c.c:168
+#, gcc-internal-format
+msgid "missing '(' after '#pragma unused', ignoring"
+msgstr ""
+
+#: config/darwin-c.c:189
+#, gcc-internal-format
+msgid "missing ')' after '#pragma unused', ignoring"
+msgstr ""
+
+#: config/darwin-c.c:192
+#, gcc-internal-format
+msgid "junk at end of '#pragma unused'"
+msgstr ""
+
+#: config/darwin-c.c:203
+#, gcc-internal-format
+msgid "malformed '#pragma ms_struct', ignoring"
+msgstr ""
+
+#: config/darwin-c.c:211
+#, gcc-internal-format
+msgid "malformed '#pragma ms_struct {on|off|reset}', ignoring"
+msgstr ""
+
+#: config/darwin-c.c:214
+#, gcc-internal-format
+msgid "junk at end of '#pragma ms_struct'"
+msgstr ""
+
+#: config/darwin-c.c:440
+#, gcc-internal-format, gfc-internal-format
+msgid "subframework include %s conflicts with framework include"
+msgstr ""
+
+#: config/darwin-c.c:636
+#, gcc-internal-format
+msgid "unknown value %qs of -mmacosx-version-min"
+msgstr ""
+
+#: config/darwin-driver.c:49
+#, gcc-internal-format
+msgid "sysctl for kern.osversion failed: %m"
+msgstr ""
+
+#: config/darwin-driver.c:83
+#, gcc-internal-format
+msgid "couldn%'t understand kern.osversion %q.*s"
+msgstr ""
+
+#: config/darwin.c:1698
+#, gcc-internal-format
+msgid "the use of _OBJC_-prefixed variable names to select meta-data sections is deprecated at 4.6 and will be removed in 4.7"
+msgstr ""
+
+#: config/darwin.c:1953
+#, gcc-internal-format, gfc-internal-format
+msgid "failed to open temporary file %s for LTO output"
+msgstr ""
+
+#: config/darwin.c:2042
+#, gcc-internal-format
+msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
+msgstr ""
+
+#: config/darwin.c:2049
+#, gcc-internal-format
+msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
+msgstr ""
+
+#: config/darwin.c:2761
+#, gcc-internal-format
+msgid "protected visibility attribute not supported in this configuration; ignored"
+msgstr ""
+
+#: config/darwin.c:2947
+#, gcc-internal-format, gfc-internal-format
+msgid "failed to open temporary file %s with LTO output"
+msgstr ""
+
+#: config/darwin.c:3120
+#, gcc-internal-format
+msgid "%<-fobjc-abi-version%> >= 2 must be used for %<-m64%> targets with %<-fnext-runtime%>"
+msgstr ""
+
+#: config/darwin.c:3124
+#, gcc-internal-format
+msgid "%<-fobjc-abi-version%> >= 2 is not supported on %<-m32%> targets with %<-fnext-runtime%>"
+msgstr ""
+
+#: config/darwin.c:3209
+#, gcc-internal-format
+msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
+msgstr ""
+
+#: config/darwin.c:3397
+#, gcc-internal-format
+msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
+msgstr ""
+
+#: config/darwin.c:3404
+#, gcc-internal-format
+msgid "built-in function %qD takes one argument only"
+msgstr ""
+
+#: config/darwin.c:3490
+#, gcc-internal-format
+msgid "CFString literal is missing"
+msgstr ""
+
+#: config/darwin.c:3501
+#, gcc-internal-format
+msgid "CFString literal expression is not a string constant"
+msgstr ""
+
+#: config/darwin.c:3524
+#, gcc-internal-format, gfc-internal-format
+msgid "%s in CFString literal"
+msgstr ""
+
+#: config/host-darwin.c:61
+#, gcc-internal-format
+msgid "couldn%'t unmap pch_address_space: %m"
+msgstr ""
+
+#: config/sol2-c.c:104 config/sol2-c.c:120
+#, gcc-internal-format
+msgid "malformed %<#pragma align%>, ignoring"
+msgstr ""
+
+#: config/sol2-c.c:113
+#, gcc-internal-format
+msgid "invalid alignment for %<#pragma align%>, ignoring"
+msgstr ""
+
+#: config/sol2-c.c:128
+#, gcc-internal-format
+msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
+msgstr ""
+
+#: config/sol2-c.c:140 config/sol2-c.c:152
+#, gcc-internal-format
+msgid "malformed %<#pragma align%>"
+msgstr ""
+
+#: config/sol2-c.c:147
+#, gcc-internal-format
+msgid "junk at end of %<#pragma align%>"
+msgstr ""
+
+#: config/sol2-c.c:168 config/sol2-c.c:175
+#, gcc-internal-format
+msgid "malformed %<#pragma init%>, ignoring"
+msgstr ""
+
+#: config/sol2-c.c:199 config/sol2-c.c:211
+#, gcc-internal-format
+msgid "malformed %<#pragma init%>"
+msgstr ""
+
+#: config/sol2-c.c:206
+#, gcc-internal-format
+msgid "junk at end of %<#pragma init%>"
+msgstr ""
+
+#: config/sol2-c.c:227 config/sol2-c.c:234
+#, gcc-internal-format
+msgid "malformed %<#pragma fini%>, ignoring"
+msgstr ""
+
+#: config/sol2-c.c:258 config/sol2-c.c:270
+#, gcc-internal-format
+msgid "malformed %<#pragma fini%>"
+msgstr ""
+
+#: config/sol2-c.c:265
+#, gcc-internal-format
+msgid "junk at end of %<#pragma fini%>"
+msgstr ""
+
+#: config/sol2.c:68
+#, gcc-internal-format
+msgid "ignoring %<#pragma align%> for explicitly aligned %q+D"
+msgstr ""
+
+#: config/vxworks.c:155
+#, gcc-internal-format
+msgid "PIC is only supported for RTPs"
+msgstr ""
+
+#. Mach-O supports 'weak imports', and 'weak definitions' in coalesced
+#. sections.  machopic_select_section ensures that weak variables go in
+#. coalesced sections.  Weak aliases (or any other kind of aliases) are
+#. not supported.  Weak symbols that aren't visible outside the .s file
+#. are not supported.
+#: config/darwin.h:444
+#, gcc-internal-format
+msgid "alias definitions not supported in Mach-O; ignored"
+msgstr ""
+
+#. No profiling.
+#: config/vx-common.h:89
+#, gcc-internal-format
+msgid "profiler support for VxWorks"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.c:947
+#, gcc-internal-format
+msgid "%Kargument %d must be a constant immediate"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.c:1018
+#, gcc-internal-format
+msgid "%Klane index must be a constant immediate"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.c:1021
+#, gcc-internal-format
+msgid "%Ktotal size and element size must be a non-zero constant immediate"
+msgstr ""
+
+#: config/aarch64/aarch64.c:6643
+#, gcc-internal-format
+msgid "missing feature modifier after %qs"
+msgstr ""
+
+#. Extension not found in list.
+#: config/aarch64/aarch64.c:6665
+#, gcc-internal-format
+msgid "unknown feature modifier %qs"
+msgstr ""
+
+#: config/aarch64/aarch64.c:6696
+#, gcc-internal-format
+msgid "missing arch name in -march=%qs"
+msgstr ""
+
+#: config/aarch64/aarch64.c:6719 config/arm/arm.c:2660
+#, gcc-internal-format, gfc-internal-format
+msgid "switch -mcpu=%s conflicts with -march=%s switch"
+msgstr ""
+
+#. ARCH name not found in list.
+#: config/aarch64/aarch64.c:6728
+#, gcc-internal-format
+msgid "unknown value %qs for -march"
+msgstr ""
+
+#: config/aarch64/aarch64.c:6753
+#, gcc-internal-format
+msgid "missing cpu name in -mcpu=%qs"
+msgstr ""
+
+#. CPU name not found in list.
+#: config/aarch64/aarch64.c:6776
+#, gcc-internal-format
+msgid "unknown value %qs for -mcpu"
+msgstr ""
+
+#. CPU name not found in list.
+#: config/aarch64/aarch64.c:6800
+#, gcc-internal-format
+msgid "unknown value %qs for -mtune"
+msgstr ""
+
+#: config/aarch64/aarch64.c:6836
+#, gcc-internal-format
+msgid "Assembler does not support -mabi=ilp32"
+msgstr ""
+
+#: config/aarch64/aarch64.c:6930
+#, gcc-internal-format
+msgid "code model %qs with -f%s"
+msgstr ""
+
+#: config/aarch64/aarch64.c:7239 config/aarch64/aarch64.c:7347
+#: config/aarch64/aarch64.c:7586
+#, gcc-internal-format
+msgid "%qs and floating point or vector arguments"
+msgstr ""
+
+#: config/aarch64/aarch64.c:8566
+#, gcc-internal-format
+msgid "%Klane %ld out of range %ld - %ld"
+msgstr ""
+
+#: config/aarch64/aarch64.c:8568
+#, gcc-internal-format, gfc-internal-format
+msgid "lane %ld out of range %ld - %ld"
+msgstr ""
+
+#: config/alpha/alpha.c:465
+#, gcc-internal-format
+msgid "bad value %qs for -mtrap-precision switch"
+msgstr ""
+
+#: config/alpha/alpha.c:479
+#, gcc-internal-format
+msgid "bad value %qs for -mfp-rounding-mode switch"
+msgstr ""
+
+#: config/alpha/alpha.c:494
+#, gcc-internal-format
+msgid "bad value %qs for -mfp-trap-mode switch"
+msgstr ""
+
+#: config/alpha/alpha.c:511
+#, gcc-internal-format
+msgid "bad value %qs for -mcpu switch"
+msgstr ""
+
+#: config/alpha/alpha.c:526
+#, gcc-internal-format
+msgid "bad value %qs for -mtune switch"
+msgstr ""
+
+#: config/alpha/alpha.c:547
+#, gcc-internal-format
+msgid "fp software completion requires -mtrap-precision=i"
+msgstr ""
+
+#: config/alpha/alpha.c:563
+#, gcc-internal-format
+msgid "rounding mode not supported for VAX floats"
+msgstr ""
+
+#: config/alpha/alpha.c:568
+#, gcc-internal-format
+msgid "trap mode not supported for VAX floats"
+msgstr ""
+
+#: config/alpha/alpha.c:572
+#, gcc-internal-format
+msgid "128-bit long double not supported for VAX floats"
+msgstr ""
+
+#: config/alpha/alpha.c:600
+#, gcc-internal-format, gfc-internal-format
+msgid "L%d cache latency unknown for %s"
+msgstr ""
+
+#: config/alpha/alpha.c:615
+#, gcc-internal-format
+msgid "bad value %qs for -mmemory-latency"
+msgstr ""
+
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
+#: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
+#, gcc-internal-format
+msgid "bad builtin fcode"
+msgstr ""
+
+#: config/arc/arc.c:778
+#, gcc-internal-format
+msgid "-mmul64 not supported for ARC700"
+msgstr ""
+
+#: config/arc/arc.c:782
+#, gcc-internal-format
+msgid "-mno-mpy supported only for ARC700"
+msgstr ""
+
+#: config/arc/arc.c:786
+#, gcc-internal-format
+msgid "-mmul32x16 supported only for ARC600 or ARC601"
+msgstr ""
+
+#: config/arc/arc.c:789
+#, gcc-internal-format
+msgid "-mno-dpfp-lrsr supported only with -mdpfp"
+msgstr ""
+
+#: config/arc/arc.c:794
+#, gcc-internal-format
+msgid "FPX fast and compact options cannot be specified together"
+msgstr ""
+
+#: config/arc/arc.c:798
+#, gcc-internal-format
+msgid "-mspfp_fast not available on ARC600 or ARC601"
+msgstr ""
+
+#: config/arc/arc.c:803
+#, gcc-internal-format
+msgid "FPX extensions not available on pre-ARC600 cores"
+msgstr ""
+
+#: config/arc/arc.c:808
+#, gcc-internal-format, gfc-internal-format
+msgid "PIC is not supported for %s. Generating non-PIC code only.."
+msgstr ""
+
+#: config/arc/arc.c:1272
+#, gcc-internal-format, gfc-internal-format
+msgid "multiply option implies r%d is fixed"
+msgstr ""
+
+#: config/arc/arc.c:1448 config/epiphany/epiphany.c:524
+#: config/epiphany/epiphany.c:564
+#, gcc-internal-format
+msgid "argument of %qE attribute is not a string constant"
+msgstr ""
+
+#: config/arc/arc.c:1456
+#, gcc-internal-format
+msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
+msgstr ""
+
+#. Keep this message in sync with the one in arc.md:trap_s,
+#. because *.md files don't get scanned by exgettext.
+#: config/arc/arc.c:5392
+#, gcc-internal-format
+msgid "operand to trap_s should be an unsigned 6-bit value"
+msgstr ""
+
+#: config/arc/arc.c:5416
+#, gcc-internal-format
+msgid "__builtin_arc_aligned with non-constant alignment"
+msgstr ""
+
+#: config/arc/arc.c:5424
+#, gcc-internal-format
+msgid "invalid alignment value for __builtin_arc_aligned"
+msgstr ""
+
+#: config/arc/arc.c:5476
+#, gcc-internal-format
+msgid "register number must be a compile-time constant. Try giving higher optimization levels"
+msgstr ""
+
+#: config/arc/arc.c:5496
+#, gcc-internal-format
+msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
+msgstr ""
+
+#: config/arc/arc.c:6048
+#, gcc-internal-format
+msgid "Insn addresses not set after shorten_branches"
+msgstr ""
+
+#: config/arc/arc.c:6252
+#, gcc-internal-format
+msgid "insn addresses not freed"
+msgstr ""
+
+#: config/arc/arc.c:6930
+#, gcc-internal-format, gfc-internal-format
+msgid "operand 2 of %s instruction should be an unsigned %d-bit value"
+msgstr ""
+
+#: config/arc/arc.c:6957 config/arc/arc.c:7170 config/arc/arc.c:7241
+#, gcc-internal-format, gfc-internal-format
+msgid "operand 2 of %s instruction should be an unsigned 8-bit value"
+msgstr ""
+
+#: config/arc/arc.c:6984 config/arc/arc.c:7199
+#, gcc-internal-format, gfc-internal-format
+msgid "operand 2 of %s instruction should be an unsigned 3-bit value (I0-I7)"
+msgstr ""
+
+#: config/arc/arc.c:7078
+#, gcc-internal-format, gfc-internal-format
+msgid "operand 1 of %s instruction should be an unsigned 3-bit value (DR0-DR7)"
+msgstr ""
+
+#: config/arc/arc.c:7114
+#, gcc-internal-format, gfc-internal-format
+msgid "operand of %s instruction should be an unsigned 6-bit value"
+msgstr ""
+
+#: config/arc/arc.c:7165 config/arc/arc.c:7236
+#, gcc-internal-format, gfc-internal-format
+msgid "operand 1 of %s instruction should be an unsigned 3-bit value (I0-I7)"
+msgstr ""
+
+#: config/arc/arc.c:7204
+#, gcc-internal-format, gfc-internal-format
+msgid "operand 3 of %s instruction should be an unsigned 8-bit value"
+msgstr ""
+
+#: config/arc/arc.c:7272
+#, gcc-internal-format, gfc-internal-format
+msgid "operand 4 of %s instruction should be an unsigned 8-bit value (0-255)"
+msgstr ""
+
+#: config/arc/arc.c:7277
+#, gcc-internal-format, gfc-internal-format
+msgid "operand 3 of %s instruction should be an unsigned 3-bit value (I0-I7)"
+msgstr ""
+
+#: config/arc/arc.c:7285
+#, gcc-internal-format, gfc-internal-format
+msgid "operand 2 of %s instruction should be an unsigned 3-bit value (subreg 0-7)"
+msgstr ""
+
+#: config/arc/arc.c:7289
+#, gcc-internal-format, gfc-internal-format
+msgid "operand 2 of %s instruction should be an even 3-bit value (subreg 0,2,4,6)"
+msgstr ""
+
+#: config/arm/arm-builtins.c:2061
+#, gcc-internal-format
+msgid "incompatible type for argument %d, expected %<const int%>"
+msgstr ""
+
+#. @@@ better error message
+#: config/arm/arm-builtins.c:2300 config/arm/arm-builtins.c:2404
+#, gcc-internal-format
+msgid "selector must be an immediate"
+msgstr ""
+
+#: config/arm/arm-builtins.c:2308 config/arm/arm-builtins.c:2353
+#: config/arm/arm-builtins.c:2411 config/arm/arm-builtins.c:2420
+#, gcc-internal-format
+msgid "the range of selector should be in 0 to 7"
+msgstr ""
+
+#: config/arm/arm-builtins.c:2313 config/arm/arm-builtins.c:2422
+#, gcc-internal-format
+msgid "the range of selector should be in 0 to 3"
+msgstr ""
+
+#: config/arm/arm-builtins.c:2318 config/arm/arm-builtins.c:2424
+#, gcc-internal-format
+msgid "the range of selector should be in 0 to 1"
+msgstr ""
+
+#: config/arm/arm-builtins.c:2490
+#, gcc-internal-format
+msgid "mask must be an immediate"
+msgstr ""
+
+#: config/arm/arm-builtins.c:2495
+#, gcc-internal-format
+msgid "the range of mask should be in 0 to 255"
+msgstr ""
+
+#: config/arm/arm-builtins.c:2683
+#, gcc-internal-format
+msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2685
+#, gcc-internal-format
+msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2687
+#, gcc-internal-format
+msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2689
+#, gcc-internal-format
+msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2695
+#, gcc-internal-format
+msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2697
+#, gcc-internal-format
+msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2702
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2704
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2706
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2708
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2710
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2712
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2714
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2716
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2718
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2720
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2722
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2724
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2726
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2728
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2730
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2732
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2734
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
+msgstr ""
+
+#: config/arm/arm-builtins.c:2736
+#, gcc-internal-format
+msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
+msgstr ""
+
+#: config/arm/arm.c:2778
+#, gcc-internal-format
+msgid "target CPU does not support ARM mode"
+msgstr ""
+
+#: config/arm/arm.c:2784
+#, gcc-internal-format
+msgid "target CPU does not support interworking"
+msgstr ""
+
+#: config/arm/arm.c:2790
+#, gcc-internal-format
+msgid "target CPU does not support THUMB instructions"
+msgstr ""
+
+#: config/arm/arm.c:2808
+#, gcc-internal-format
+msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
+msgstr ""
+
+#: config/arm/arm.c:2811
+#, gcc-internal-format
+msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
+msgstr ""
+
+#: config/arm/arm.c:2815
+#, gcc-internal-format
+msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
+msgstr ""
+
+#: config/arm/arm.c:2823
+#, gcc-internal-format
+msgid "-fpic and -mapcs-reent are incompatible"
+msgstr ""
+
+#: config/arm/arm.c:2826
+#, gcc-internal-format
+msgid "APCS reentrant code not supported.  Ignored"
+msgstr ""
+
+#: config/arm/arm.c:2834
+#, gcc-internal-format
+msgid "-g with -mno-apcs-frame may not give sensible debugging"
+msgstr ""
+
+#: config/arm/arm.c:2837
+#, gcc-internal-format
+msgid "passing floating point arguments in fp regs not yet supported"
+msgstr ""
+
+#: config/arm/arm.c:2908
+#, gcc-internal-format
+msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
+msgstr ""
+
+#: config/arm/arm.c:2911
+#, gcc-internal-format
+msgid "iwmmxt abi requires an iwmmxt capable cpu"
+msgstr ""
+
+#: config/arm/arm.c:2944
+#, gcc-internal-format
+msgid "AAPCS does not support -mcaller-super-interworking"
+msgstr ""
+
+#: config/arm/arm.c:2947
+#, gcc-internal-format
+msgid "AAPCS does not support -mcallee-super-interworking"
+msgstr ""
+
+#: config/arm/arm.c:2952
+#, gcc-internal-format
+msgid "iWMMXt and NEON are incompatible"
+msgstr ""
+
+#: config/arm/arm.c:2956
+#, gcc-internal-format
+msgid "iWMMXt unsupported under Thumb mode"
+msgstr ""
+
+#: config/arm/arm.c:2960
+#, gcc-internal-format
+msgid "__fp16 and no ldrh"
+msgstr ""
+
+#: config/arm/arm.c:2980
+#, gcc-internal-format
+msgid "-mfloat-abi=hard and VFP"
+msgstr ""
+
+#: config/arm/arm.c:3003
+#, gcc-internal-format
+msgid "can not use -mtp=cp15 with 16-bit Thumb"
+msgstr ""
+
+#: config/arm/arm.c:3019
+#, gcc-internal-format
+msgid "structure size boundary can only be set to 8, 32 or 64"
+msgstr ""
+
+#: config/arm/arm.c:3021
+#, gcc-internal-format
+msgid "structure size boundary can only be set to 8 or 32"
+msgstr ""
+
+#: config/arm/arm.c:3029
+#, gcc-internal-format
+msgid "RTP PIC is incompatible with Thumb"
+msgstr ""
+
+#: config/arm/arm.c:3038
+#, gcc-internal-format
+msgid "RTP PIC is incompatible with -msingle-pic-base"
+msgstr ""
+
+#: config/arm/arm.c:3050
+#, gcc-internal-format
+msgid "-mpic-register= is useless without -fpic"
+msgstr ""
+
+#: config/arm/arm.c:3059
+#, gcc-internal-format, gfc-internal-format
+msgid "unable to use '%s' for PIC register"
+msgstr ""
+
+#: config/arm/arm.c:3096
+#, gcc-internal-format
+msgid "target CPU does not support unaligned accesses"
+msgstr ""
+
+#: config/arm/arm.c:3124
+#, gcc-internal-format
+msgid "-freorder-blocks-and-partition not supported on this architecture"
+msgstr ""
+
+#: config/arm/arm.c:3208
+#, gcc-internal-format
+msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
+msgstr ""
+
+#: config/arm/arm.c:5278
+#, gcc-internal-format
+msgid "non-AAPCS derived PCS variant"
+msgstr ""
+
+#: config/arm/arm.c:5280
+#, gcc-internal-format
+msgid "variadic functions must use the base AAPCS variant"
+msgstr ""
+
+#: config/arm/arm.c:5299
+#, gcc-internal-format
+msgid "PCS variant"
+msgstr ""
+
+#: config/arm/arm.c:5494
+#, gcc-internal-format
+msgid "Thumb-1 hard-float VFP ABI"
+msgstr ""
+
+#: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
+#: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
+#: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
+#: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
+#: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/v850/v850.c:2117 config/visium/visium.c:653
+#, gcc-internal-format
+msgid "%qE attribute only applies to functions"
+msgstr ""
+
+#: config/arm/arm.c:23326
+#, gcc-internal-format
+msgid "unable to compute real location of stacked parameter"
+msgstr ""
+
+#: config/arm/arm.c:23944
+#, gcc-internal-format
+msgid "Unexpected thumb1 far jump"
+msgstr ""
+
+#: config/arm/arm.c:24211
+#, gcc-internal-format
+msgid "no low registers available for popping high registers"
+msgstr ""
+
+#: config/arm/arm.c:24436
+#, gcc-internal-format
+msgid "interrupt Service Routines cannot be coded in Thumb mode"
+msgstr ""
+
+#: config/avr/avr-c.c:75 config/avr/avr-c.c:200
+#, gcc-internal-format
+msgid "%qs expects 1 argument but %d given"
+msgstr ""
+
+#: config/avr/avr-c.c:86
+#, gcc-internal-format
+msgid "%qs expects a fixed-point value as argument"
+msgstr ""
+
+#: config/avr/avr-c.c:112
+#, gcc-internal-format
+msgid "using %qs with unsigned type has no effect"
+msgstr ""
+
+#: config/avr/avr-c.c:117 config/avr/avr-c.c:183 config/avr/avr-c.c:240
+#, gcc-internal-format
+msgid "no matching fixed-point overload found for %qs"
+msgstr ""
+
+#: config/avr/avr-c.c:134
+#, gcc-internal-format
+msgid "%qs expects 2 arguments but %d given"
+msgstr ""
+
+#: config/avr/avr-c.c:146 config/avr/avr-c.c:211
+#, gcc-internal-format
+msgid "%qs expects a fixed-point value as first argument"
+msgstr ""
+
+#: config/avr/avr-c.c:154
+#, gcc-internal-format
+msgid "%qs expects an integer value as second argument"
+msgstr ""
+
+#: config/avr/avr-devices.c:203
+#, gcc-internal-format, gfc-internal-format
+msgid "devices natively supported:%s"
+msgstr ""
+
+#: config/avr/avr-devices.c:212
+#, gcc-internal-format, gfc-internal-format
+msgid "supported core architectures:%s"
+msgstr ""
+
+#. Reached the end of `avr_mcu_types'.  This should actually never
+#. happen as options are provided by device-specs.  It could be a
+#. typo in a device-specs or calling the compiler proper directly
+#. with -mmcu=<device>.
+#: config/avr/avr.c:402
+#, gcc-internal-format
+msgid "unknown core architecture %qs specified with %qs"
+msgstr ""
+
+#: config/avr/avr.c:459 config/mep/mep.c:394 config/visium/visium.c:354
+#, gcc-internal-format
+msgid "-fpic is not supported"
+msgstr ""
+
+#: config/avr/avr.c:461 config/mep/mep.c:396 config/visium/visium.c:356
+#, gcc-internal-format
+msgid "-fPIC is not supported"
+msgstr ""
+
+#: config/avr/avr.c:463
+#, gcc-internal-format
+msgid "-fpie is not supported"
+msgstr ""
+
+#: config/avr/avr.c:465
+#, gcc-internal-format
+msgid "-fPIE is not supported"
+msgstr ""
+
+#: config/avr/avr.c:737
+#, gcc-internal-format
+msgid "function attributes %qs, %qs and %qs are mutually exclusive"
+msgstr ""
+
+#: config/avr/avr.c:744
+#, gcc-internal-format
+msgid "function attributes %qs and %qs have no effect on %qs function"
+msgstr ""
+
+#: config/avr/avr.c:771
+#, gcc-internal-format
+msgid "%qs function cannot have arguments"
+msgstr ""
+
+#: config/avr/avr.c:774
+#, gcc-internal-format
+msgid "%qs function cannot return a value"
+msgstr ""
+
+#: config/avr/avr.c:781
+#, gcc-internal-format
+msgid "%qs appears to be a misspelled %s handler"
+msgstr ""
+
+#: config/avr/avr.c:1008
+#, gcc-internal-format
+msgid "%<builtin_return_address%> contains only 2 bytes of address"
+msgstr ""
+
+#: config/avr/avr.c:2233
+#, gcc-internal-format
+msgid "pointer offset from symbol maybe incorrect"
+msgstr ""
+
+#: config/avr/avr.c:2372
+#, gcc-internal-format
+msgid "accessing data memory with program memory address"
+msgstr ""
+
+#: config/avr/avr.c:2432
+#, gcc-internal-format
+msgid "accessing program memory with data memory address"
+msgstr ""
+
+#: config/avr/avr.c:2857
+#, gcc-internal-format, gfc-internal-format
+msgid "fixed register %s used to pass parameter to function"
+msgstr ""
+
+#: config/avr/avr.c:3128
+#, gcc-internal-format
+msgid "writing to address space %qs not supported"
+msgstr ""
+
+#: config/avr/avr.c:9028 config/bfin/bfin.c:4821 config/i386/winnt.c:97
+#: config/mep/mep.c:3833 config/mep/mep.c:3971
+#, gcc-internal-format
+msgid "%qE attribute only applies to variables"
+msgstr ""
+
+#: config/avr/avr.c:9039 config/mep/mep.c:3981
+#, gcc-internal-format
+msgid "%qE attribute allows only an integer constant argument"
+msgstr ""
+
+#: config/avr/avr.c:9049
+#, gcc-internal-format
+msgid "%qE attribute address out of range"
+msgstr ""
+
+#: config/avr/avr.c:9062
+#, gcc-internal-format
+msgid "both %s and %qE attribute provide address"
+msgstr ""
+
+#: config/avr/avr.c:9072
+#, gcc-internal-format
+msgid "%qE attribute on non-volatile variable"
+msgstr ""
+
+#: config/avr/avr.c:9274
+#, gcc-internal-format
+msgid "%qT uses address space %qs beyond flash of %d KiB"
+msgstr ""
+
+#: config/avr/avr.c:9277
+#, gcc-internal-format
+msgid "%s %q+D uses address space %qs beyond flash of %d KiB"
+msgstr ""
+
+#: config/avr/avr.c:9283
+#, gcc-internal-format
+msgid "pointer targeting address space %qs must be const in %qT"
+msgstr ""
+
+#: config/avr/avr.c:9286
+#, gcc-internal-format
+msgid "pointer targeting address space %qs must be const in %s %q+D"
+msgstr ""
+
+#: config/avr/avr.c:9324
+#, gcc-internal-format
+msgid "variable %q+D located in address space %qs beyond flash of %d KiB"
+msgstr ""
+
+#: config/avr/avr.c:9329
+#, gcc-internal-format
+msgid "variable %q+D located in address space %qs which is not supported for architecture %qs"
+msgstr ""
+
+#: config/avr/avr.c:9345
+#, gcc-internal-format
+msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
+msgstr ""
+
+#: config/avr/avr.c:9385
+#, gcc-internal-format
+msgid "static IO declaration for %q+D needs an address"
+msgstr ""
+
+#: config/avr/avr.c:9417
+#, gcc-internal-format
+msgid "IO definition for %q+D needs an address"
+msgstr ""
+
+#: config/avr/avr.c:9601
+#, gcc-internal-format
+msgid "only uninitialized variables can be placed in the .noinit section"
+msgstr ""
+
+#: config/avr/avr.c:9642
+#, gcc-internal-format
+msgid "uninitialized variable %q+D put into program memory area"
+msgstr ""
+
+#: config/avr/avr.c:9752
+#, gcc-internal-format
+msgid "architecture %qs supported for assembler only"
+msgstr ""
+
+#: config/avr/avr.c:12265
+#, gcc-internal-format
+msgid "conversion from address space %qs to address space %qs"
+msgstr ""
+
+#: config/avr/avr.c:13321
+#, gcc-internal-format, gfc-internal-format
+msgid "%s expects a compile time integer constant"
+msgstr ""
+
+#: config/avr/avr.c:13335
+#, gcc-internal-format, gfc-internal-format
+msgid "%s expects a compile time long integer constant as first argument"
+msgstr ""
+
+#: config/avr/avr.c:13363
+#, gcc-internal-format, gfc-internal-format
+msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
+msgstr ""
+
+#: config/avr/avr.c:13372
+#, gcc-internal-format
+msgid "rounding result will always be 0"
+msgstr ""
+
+#: config/avr/driver-avr.c:39
+#, gcc-internal-format
+msgid "cannot access device-specs for %qs expected at %qs"
+msgstr ""
+
+#: config/avr/driver-avr.c:49
+#, gcc-internal-format, gfc-internal-format
+msgid "you can provide your own specs files, see <%s> for details"
+msgstr ""
+
+#: config/avr/driver-avr.c:79
+#, gcc-internal-format
+msgid "bad usage of spec function %qs"
+msgstr ""
+
+#: config/avr/driver-avr.c:107
+#, gcc-internal-format
+msgid "specified option %qs more than once"
+msgstr ""
+
+#: config/avr/driver-avr.c:129
+#, gcc-internal-format
+msgid "strange device name %qs after %qs: bad character %qc"
+msgstr ""
+
+#: config/bfin/bfin.c:2387
+#, gcc-internal-format
+msgid "-mfdpic is not supported, please use a bfin-linux-uclibc target"
+msgstr ""
+
+#: config/bfin/bfin.c:2392
+#, gcc-internal-format
+msgid "-mshared-library-id= specified without -mid-shared-library"
+msgstr ""
+
+#: config/bfin/bfin.c:2396
+#, gcc-internal-format
+msgid "-fstack-limit- options are ignored with -mfdpic; use -mstack-check-l1"
+msgstr ""
+
+#: config/bfin/bfin.c:2401
+#, gcc-internal-format
+msgid "can%'t use multiple stack checking methods together"
+msgstr ""
+
+#: config/bfin/bfin.c:2404
+#, gcc-internal-format
+msgid "ID shared libraries and FD-PIC mode can%'t be used together"
+msgstr ""
+
+#: config/bfin/bfin.c:2409 config/m68k/m68k.c:568
+#, gcc-internal-format
+msgid "cannot specify both -msep-data and -mid-shared-library"
+msgstr ""
+
+#: config/bfin/bfin.c:2429
+#, gcc-internal-format
+msgid "-mmulticore can only be used with BF561"
+msgstr ""
+
+#: config/bfin/bfin.c:2432
+#, gcc-internal-format
+msgid "-mcorea should be used with -mmulticore"
+msgstr ""
+
+#: config/bfin/bfin.c:2435
+#, gcc-internal-format
+msgid "-mcoreb should be used with -mmulticore"
+msgstr ""
+
+#: config/bfin/bfin.c:2438
+#, gcc-internal-format
+msgid "-mcorea and -mcoreb can%'t be used together"
+msgstr ""
+
+#: config/bfin/bfin.c:4704
+#, gcc-internal-format
+msgid "multiple function type attributes specified"
+msgstr ""
+
+#: config/bfin/bfin.c:4771
+#, gcc-internal-format
+msgid "can%'t apply both longcall and shortcall attributes to the same function"
+msgstr ""
+
+#: config/bfin/bfin.c:4828
+#, gcc-internal-format
+msgid "%qE attribute cannot be specified for local variables"
+msgstr ""
+
+#: config/c6x/c6x.c:274
+#, gcc-internal-format
+msgid "-fpic and -fPIC not supported without -mdsbt on this target"
+msgstr ""
+
+#: config/c6x/c6x.h:363 config/nvptx/nvptx.h:193
+#, gcc-internal-format
+msgid "profiling is not yet implemented for this architecture"
+msgstr ""
+
+#: config/cr16/cr16.c:325
+#, gcc-internal-format
+msgid "data-model=far not valid for cr16c architecture"
+msgstr ""
+
+#: config/cr16/cr16.c:328
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid data model option -mdata-model=%s"
+msgstr ""
+
+#: config/cr16/cr16.h:431
+#, gcc-internal-format
+msgid "profiler support for CR16"
+msgstr ""
+
+#. This function is for retrieving a part of an instruction name for
+#. an operator, for immediate output.  If that ever happens for
+#. MULT, we need to apply TARGET_MUL_BUG in the caller.  Make sure
+#. we notice.
+#: config/cris/cris.c:588
+#, gcc-internal-format
+msgid "MULT case in cris_op_str"
+msgstr ""
+
+#: config/cris/cris.c:926
+#, gcc-internal-format
+msgid "invalid use of ':' modifier"
+msgstr ""
+
+#: config/cris/cris.c:1160 config/moxie/moxie.c:221
+#, gcc-internal-format, gfc-internal-format
+msgid "internal error: bad register: %d"
+msgstr ""
+
+#: config/cris/cris.c:1915
+#, gcc-internal-format
+msgid "internal error: sideeffect-insn affecting main effect"
+msgstr ""
+
+#: config/cris/cris.c:2012
+#, gcc-internal-format
+msgid "unknown cc_attr value"
+msgstr ""
+
+#. If we get here, the caller got its initial tests wrong.
+#: config/cris/cris.c:2436
+#, gcc-internal-format
+msgid "internal error: cris_side_effect_mode_ok with bad operands"
+msgstr ""
+
+#: config/cris/cris.c:2675
+#, gcc-internal-format, gfc-internal-format
+msgid "-max-stackframe=%d is not usable, not between 0 and %d"
+msgstr ""
+
+#: config/cris/cris.c:2703
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown CRIS version specification in -march= or -mcpu= : %s"
+msgstr ""
+
+#: config/cris/cris.c:2739
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown CRIS cpu version specification in -mtune= : %s"
+msgstr ""
+
+#: config/cris/cris.c:2760
+#, gcc-internal-format
+msgid "-fPIC and -fpic are not supported in this configuration"
+msgstr ""
+
+#: config/cris/cris.c:3017
+#, gcc-internal-format
+msgid "unknown src"
+msgstr ""
+
+#: config/cris/cris.c:3078
+#, gcc-internal-format
+msgid "unknown dest"
+msgstr ""
+
+#: config/cris/cris.c:3367
+#, gcc-internal-format, gfc-internal-format
+msgid "stackframe too big: %d bytes"
+msgstr ""
+
+#: config/cris/cris.c:3865 config/cris/cris.c:3893
+#, gcc-internal-format
+msgid "expand_binop failed in movsi got"
+msgstr ""
+
+#: config/cris/cris.c:3988
+#, gcc-internal-format
+msgid "emitting PIC operand, but PIC register isn%'t set up"
+msgstr ""
+
+#. Definitions for GCC.  Part of the machine description for CRIS.
+#. Copyright (C) 1998-2015 Free Software Foundation, Inc.
+#. Contributed by Axis Communications.  Written by Hans-Peter Nilsson.
+#.
+#. This file is part of GCC.
+#.
+#. GCC is free software; you can redistribute it and/or modify
+#. it under the terms of the GNU General Public License as published by
+#. the Free Software Foundation; either version 3, or (at your option)
+#. any later version.
+#.
+#. GCC is distributed in the hope that it will be useful,
+#. but WITHOUT ANY WARRANTY; without even the implied warranty of
+#. MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#. GNU General Public License for more details.
+#.
+#. You should have received a copy of the GNU General Public License
+#. along with GCC; see the file COPYING3.  If not see
+#. <http://www.gnu.org/licenses/>.
+#. After the first "Node:" comment comes all preprocessor directives and
+#. attached declarations described in the info files, the "Using and
+#. Porting GCC" manual (uapgcc), in the same order as found in the "Target
+#. macros" section in the gcc-2.9x CVS edition of 2000-03-17.  FIXME: Not
+#. really, but needs an update anyway.
+#.
+#. There is no generic copy-of-uapgcc comment, you'll have to see uapgcc
+#. for that.  If applicable, there is a CRIS-specific comment.  The order
+#. of macro definitions follow the order in the manual.  Every section in
+#. the manual (node in the info pages) has an introductory `Node:
+#. <subchapter>' comment.  If no macros are defined for a section, only
+#. the section-comment is present.
+#. Note that other header files (e.g. config/elfos.h, config/linux.h,
+#. and config/cris/linux.h) are responsible for lots of settings not
+#. repeated below.  This file contains general CRIS definitions
+#. and definitions for the cris-*-elf subtarget.
+#. We don't want to use gcc_assert for everything, as that can be
+#. compiled out.
+#: config/cris/cris.h:42
+#, gcc-internal-format
+msgid "CRIS-port assertion failed: "
+msgstr ""
+
+#. Node: Caller Saves
+#. (no definitions)
+#. Node: Function entry
+#. See cris.c for TARGET_ASM_FUNCTION_PROLOGUE and
+#. TARGET_ASM_FUNCTION_EPILOGUE.
+#. Node: Profiling
+#: config/cris/cris.h:749
+#, gcc-internal-format
+msgid "no FUNCTION_PROFILER for CRIS"
+msgstr ""
+
+#: config/epiphany/epiphany.c:515
+#, gcc-internal-format
+msgid "interrupt handlers cannot have arguments"
+msgstr ""
+
+#: config/epiphany/epiphany.c:539
+#, gcc-internal-format
+msgid "argument of %qE attribute is not \"reset\", \"software_exception\", \"page_miss\", \"timer0\", \"timer1\", \"message\", \"dma0\", \"dma1\", \"wand\" or \"swi\""
+msgstr ""
+
+#: config/epiphany/epiphany.c:1553
+#, gcc-internal-format
+msgid "stack_offset must be at least 4"
+msgstr ""
+
+#: config/epiphany/epiphany.c:1555
+#, gcc-internal-format
+msgid "stack_offset must be a multiple of 4"
+msgstr ""
+
+#: config/frv/frv.c:8644
+#, gcc-internal-format
+msgid "accumulator is not a constant integer"
+msgstr ""
+
+#: config/frv/frv.c:8649
+#, gcc-internal-format
+msgid "accumulator number is out of bounds"
+msgstr ""
+
+#: config/frv/frv.c:8660
+#, gcc-internal-format
+msgid "inappropriate accumulator for %qs"
+msgstr ""
+
+#: config/frv/frv.c:8736
+#, gcc-internal-format
+msgid "invalid IACC argument"
+msgstr ""
+
+#: config/frv/frv.c:8759
+#, gcc-internal-format
+msgid "%qs expects a constant argument"
+msgstr ""
+
+#: config/frv/frv.c:8764
+#, gcc-internal-format
+msgid "constant argument out of range for %qs"
+msgstr ""
+
+#: config/frv/frv.c:9245
+#, gcc-internal-format
+msgid "media functions are not available unless -mmedia is used"
+msgstr ""
+
+#: config/frv/frv.c:9257
+#, gcc-internal-format
+msgid "this media function is only available on the fr500"
+msgstr ""
+
+#: config/frv/frv.c:9285
+#, gcc-internal-format
+msgid "this media function is only available on the fr400 and fr550"
+msgstr ""
+
+#: config/frv/frv.c:9304
+#, gcc-internal-format
+msgid "this builtin function is only available on the fr405 and fr450"
+msgstr ""
+
+#: config/frv/frv.c:9313
+#, gcc-internal-format
+msgid "this builtin function is only available on the fr500 and fr550"
+msgstr ""
+
+#: config/frv/frv.c:9325
+#, gcc-internal-format
+msgid "this builtin function is only available on the fr450"
+msgstr ""
+
+#: config/h8300/h8300.c:353
+#, gcc-internal-format
+msgid "-msx is not supported in coff"
+msgstr ""
+
+#: config/h8300/h8300.c:375
+#, gcc-internal-format
+msgid "-ms2600 is used without -ms"
+msgstr ""
+
+#: config/h8300/h8300.c:381
+#, gcc-internal-format
+msgid "-mn is used without -mh or -ms or -msx"
+msgstr ""
+
+#: config/h8300/h8300.c:387
+#, gcc-internal-format
+msgid "-mexr is used without -ms"
+msgstr ""
+
+#: config/h8300/h8300.c:393
+#, gcc-internal-format
+msgid "-mint32 is not supported for H8300 and H8300L targets"
+msgstr ""
+
+#: config/h8300/h8300.c:399
+#, gcc-internal-format
+msgid "-mexr is used without -ms or -msx"
+msgstr ""
+
+#: config/h8300/h8300.c:405
+#, gcc-internal-format
+msgid "-mno-exr valid only with -ms or -msx                   - Option ignored!"
+msgstr ""
+
+#: config/i386/host-cygwin.c:62
+#, gcc-internal-format
+msgid "can%'t extend PCH file: %m"
+msgstr ""
+
+#: config/i386/host-cygwin.c:73
+#, gcc-internal-format
+msgid "can%'t set position in PCH file: %m"
+msgstr ""
+
+#: config/i386/i386.c:2969
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong arg %s to option %s"
+msgstr ""
+
+#: config/i386/i386.c:2976
+#, gcc-internal-format, gfc-internal-format
+msgid "size ranges of option %s should be increasing"
+msgstr ""
+
+#: config/i386/i386.c:2987
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong stringop strategy name %s specified for option %s"
+msgstr ""
+
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
+#, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386.c:3012
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown alignment %s specified for option %s"
+msgstr ""
+
+#: config/i386/i386.c:3023
+#, gcc-internal-format, gfc-internal-format
+msgid "the max value for the last size range should be -1 for option %s"
+msgstr ""
+
+#: config/i386/i386.c:3031
+#, gcc-internal-format, gfc-internal-format
+msgid "too many size ranges specified in option %s"
+msgstr ""
+
+#: config/i386/i386.c:3085
+#, gcc-internal-format, gfc-internal-format
+msgid "Unknown parameter to option -mtune-ctrl: %s"
+msgstr ""
+
+#: config/i386/i386.c:3467
+#, gcc-internal-format, gfc-internal-format
+msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
+msgstr ""
+
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:3494
+#, gcc-internal-format
+msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386.c:3511
+#, gcc-internal-format
+msgid "address mode %qs not supported in the %s bit mode"
+msgstr ""
+
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
+#, gcc-internal-format
+msgid "code model %qs not supported in the %s bit mode"
+msgstr ""
+
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
+#, gcc-internal-format
+msgid "code model %qs not supported in x32 mode"
+msgstr ""
+
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
+#, gcc-internal-format, gfc-internal-format
+msgid "code model %s does not support PIC mode"
+msgstr ""
+
+#: config/i386/i386.c:3604
+#, gcc-internal-format
+msgid "-masm=intel not supported in this configuration"
+msgstr ""
+
+#: config/i386/i386.c:3609
+#, gcc-internal-format, gfc-internal-format
+msgid "%i-bit mode not compiled in"
+msgstr ""
+
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
+#, gcc-internal-format
+msgid "CPU you selected does not support x86-64 instruction set"
+msgstr ""
+
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
+#, gcc-internal-format
+msgid "Intel MPX does not support x32"
+msgstr ""
+
+#: config/i386/i386.c:3807
+#, gcc-internal-format, gfc-internal-format
+msgid "generic CPU can be used only for %stune=%s %s"
+msgstr ""
+
+#: config/i386/i386.c:3810
+#, gcc-internal-format, gfc-internal-format
+msgid "intel CPU can be used only for %stune=%s %s"
+msgstr ""
+
+#: config/i386/i386.c:3813
+#, gcc-internal-format, gfc-internal-format
+msgid "bad value (%s) for %sarch=%s %s"
+msgstr ""
+
+#: config/i386/i386.c:3856
+#, gcc-internal-format, gfc-internal-format
+msgid "bad value (%s) for %stune=%s %s"
+msgstr ""
+
+#: config/i386/i386.c:3911
+#, gcc-internal-format
+msgid "-mregparm is ignored in 64-bit mode"
+msgstr ""
+
+#: config/i386/i386.c:3914
+#, gcc-internal-format, gfc-internal-format
+msgid "-mregparm=%d is not between 0 and %d"
+msgstr ""
+
+#: config/i386/i386.c:3957
+#, gcc-internal-format, gfc-internal-format
+msgid "%srtd%s is ignored in 64bit mode"
+msgstr ""
+
+#: config/i386/i386.c:4035
+#, gcc-internal-format
+msgid "-mpreferred-stack-boundary is not supported for this target"
+msgstr ""
+
+#: config/i386/i386.c:4038
+#, gcc-internal-format, gfc-internal-format
+msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
+msgstr ""
+
+#: config/i386/i386.c:4060
+#, gcc-internal-format, gfc-internal-format
+msgid "-mincoming-stack-boundary=%d is not between %d and 12"
+msgstr ""
+
+#: config/i386/i386.c:4074
+#, gcc-internal-format
+msgid "-mnop-mcount is not compatible with this target"
+msgstr ""
+
+#: config/i386/i386.c:4077
+#, gcc-internal-format
+msgid "-mnop-mcount is not implemented for -fPIC"
+msgstr ""
+
+#: config/i386/i386.c:4082
+#, gcc-internal-format, gfc-internal-format
+msgid "%ssseregparm%s used without SSE enabled"
+msgstr ""
+
+#: config/i386/i386.c:4090
+#, gcc-internal-format
+msgid "SSE instruction set disabled, using 387 arithmetics"
+msgstr ""
+
+#: config/i386/i386.c:4096
+#, gcc-internal-format
+msgid "387 instruction set disabled, using SSE arithmetics"
+msgstr ""
+
+#: config/i386/i386.c:4148
+#, gcc-internal-format, gfc-internal-format
+msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
+msgstr ""
+
+#: config/i386/i386.c:4251
+#, gcc-internal-format
+msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
+msgstr ""
+
+#: config/i386/i386.c:4258
+#, gcc-internal-format
+msgid "-mno-fentry isn%'t compatible with SEH"
+msgstr ""
+
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown option for -mrecip=%s"
+msgstr ""
+
+#: config/i386/i386.c:4821
+#, gcc-internal-format
+msgid "attribute %<target%> argument not a string"
+msgstr ""
+
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
+#, gcc-internal-format, gfc-internal-format
+msgid "attribute(target(\"%s\")) is unknown"
+msgstr ""
+
+#: config/i386/i386.c:4915
+#, gcc-internal-format, gfc-internal-format
+msgid "option(\"%s\") was already specified"
+msgstr ""
+
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
+#, gcc-internal-format
+msgid "fastcall and regparm attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386.c:5581
+#, gcc-internal-format
+msgid "regparam and thiscall attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
+#, gcc-internal-format
+msgid "%qE attribute requires an integer constant argument"
+msgstr ""
+
+#: config/i386/i386.c:5594
+#, gcc-internal-format
+msgid "argument to %qE attribute larger than %d"
+msgstr ""
+
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
+#, gcc-internal-format
+msgid "fastcall and cdecl attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386.c:5623
+#, gcc-internal-format
+msgid "fastcall and stdcall attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
+#, gcc-internal-format
+msgid "fastcall and thiscall attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
+#, gcc-internal-format
+msgid "stdcall and cdecl attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386.c:5645
+#, gcc-internal-format
+msgid "stdcall and fastcall attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
+#, gcc-internal-format
+msgid "stdcall and thiscall attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
+#, gcc-internal-format
+msgid "cdecl and thiscall attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386.c:5672
+#, gcc-internal-format
+msgid "%qE attribute is used for non-class method"
+msgstr ""
+
+#: config/i386/i386.c:5910
+#, gcc-internal-format
+msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:5913
+#, gcc-internal-format
+msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:6235
+#, gcc-internal-format
+msgid "X32 does not support ms_abi attribute"
+msgstr ""
+
+#: config/i386/i386.c:6264
+#, gcc-internal-format
+msgid "ms_hook_prologue is not compatible with nested function"
+msgstr ""
+
+#: config/i386/i386.c:6599
+#, gcc-internal-format
+msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.c:6605
+#, gcc-internal-format
+msgid "AVX512F vector return without AVX512F enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.c:6619
+#, gcc-internal-format
+msgid "AVX vector argument without AVX enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.c:6625
+#, gcc-internal-format
+msgid "AVX vector return without AVX enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.c:6640
+#, gcc-internal-format
+msgid "SSE vector argument without SSE enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.c:6646
+#, gcc-internal-format
+msgid "SSE vector return without SSE enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.c:6658
+#, gcc-internal-format
+msgid "MMX vector argument without MMX enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.c:6664
+#, gcc-internal-format
+msgid "MMX vector return without MMX enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.c:6847
+#, gcc-internal-format
+msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
+msgstr ""
+
+#: config/i386/i386.c:6964
+#, gcc-internal-format
+msgid "the ABI of passing union with long double has changed in GCC 4.4"
+msgstr ""
+
+#: config/i386/i386.c:7082
+#, gcc-internal-format
+msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
+msgstr ""
+
+#: config/i386/i386.c:7245
+#, gcc-internal-format
+msgid "SSE register return with SSE disabled"
+msgstr ""
+
+#: config/i386/i386.c:7251
+#, gcc-internal-format
+msgid "SSE register argument with SSE disabled"
+msgstr ""
+
+#: config/i386/i386.c:7267
+#, gcc-internal-format
+msgid "x87 register return with x87 disabled"
+msgstr ""
+
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, gcc-internal-format
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
+#, gcc-internal-format, gfc-internal-format
+msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
+msgstr ""
+
+#: config/i386/i386.c:8287
+#, gcc-internal-format
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:11378
+#, gcc-internal-format
+msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
+msgstr ""
+
+#: config/i386/i386.c:12416
+#, gcc-internal-format
+msgid "-fsplit-stack does not support fastcall with nested function"
+msgstr ""
+
+#: config/i386/i386.c:12436
+#, gcc-internal-format
+msgid "-fsplit-stack does not support 2 register parameters for a nested function"
+msgstr ""
+
+#. FIXME: We could make this work by pushing a register
+#. around the addition and comparison.
+#: config/i386/i386.c:12447
+#, gcc-internal-format
+msgid "-fsplit-stack does not support 3 register parameters"
+msgstr ""
+
+#: config/i386/i386.c:15303
+#, gcc-internal-format
+msgid "extended registers have no high halves"
+msgstr ""
+
+#: config/i386/i386.c:15318
+#, gcc-internal-format
+msgid "unsupported operand size for extended register"
+msgstr ""
+
+#: config/i386/i386.c:15563
+#, gcc-internal-format
+msgid "non-integer operand used with operand code 'z'"
+msgstr ""
+
+#: config/i386/i386.c:34694
+#, gcc-internal-format
+msgid "No dispatcher found for the versioning attributes"
+msgstr ""
+
+#: config/i386/i386.c:34744
+#, gcc-internal-format, gfc-internal-format
+msgid "No dispatcher found for %s"
+msgstr ""
+
+#: config/i386/i386.c:34754
+#, gcc-internal-format, gfc-internal-format
+msgid "No dispatcher found for the versioning attributes : %s"
+msgstr ""
+
+#: config/i386/i386.c:35002
+#, gcc-internal-format
+msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
+msgstr ""
+
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
+#, gcc-internal-format
+msgid "Virtual function multiversioning not supported"
+msgstr ""
+
+#: config/i386/i386.c:35072
+#, gcc-internal-format
+msgid "missing %<target%> attribute for multi-versioned %D"
+msgstr ""
+
+#: config/i386/i386.c:35075
+#, gcc-internal-format
+msgid "previous declaration of %D"
+msgstr ""
+
+#: config/i386/i386.c:35294
+#, gcc-internal-format
+msgid "multiversioning needs ifunc which is not supported on this target"
+msgstr ""
+
+#: config/i386/i386.c:35672
+#, gcc-internal-format
+msgid "Parameter to builtin must be a string constant or literal"
+msgstr ""
+
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
+#, gcc-internal-format, gfc-internal-format
+msgid "Parameter to builtin not valid: %s"
+msgstr ""
+
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
+#, gcc-internal-format
+msgid "the last argument must be a 2-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:36555
+#, gcc-internal-format
+msgid "the fifth argument must be an 8-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:36650
+#, gcc-internal-format
+msgid "the third argument must be an 8-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:37497
+#, gcc-internal-format
+msgid "the last argument must be an 1-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:37512
+#, gcc-internal-format
+msgid "the last argument must be a 3-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:37545
+#, gcc-internal-format
+msgid "the last argument must be a 4-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:37585
+#, gcc-internal-format
+msgid "the last argument must be a 1-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:37598
+#, gcc-internal-format
+msgid "the last argument must be a 5-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:37608
+#, gcc-internal-format
+msgid "the next to last argument must be an 8-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
+#, gcc-internal-format
+msgid "the last argument must be an 8-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:37779
+#, gcc-internal-format
+msgid "the third argument must be comparison constant"
+msgstr ""
+
+#: config/i386/i386.c:37784
+#, gcc-internal-format
+msgid "incorrect comparison mode"
+msgstr ""
+
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
+#, gcc-internal-format
+msgid "incorrect rounding operand"
+msgstr ""
+
+#: config/i386/i386.c:37974
+#, gcc-internal-format
+msgid "the immediate argument must be a 4-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:37980
+#, gcc-internal-format
+msgid "the immediate argument must be a 5-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:37983
+#, gcc-internal-format
+msgid "the immediate argument must be an 8-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:38383
+#, gcc-internal-format
+msgid "the last argument must be a 32-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
+#, gcc-internal-format
+msgid "selector must be an integer constant in the range 0..%wi"
+msgstr ""
+
+#: config/i386/i386.c:38660
+#, gcc-internal-format
+msgid "%qE needs unknown isa option"
+msgstr ""
+
+#: config/i386/i386.c:38664
+#, gcc-internal-format
+msgid "%qE needs isa option %s"
+msgstr ""
+
+#: config/i386/i386.c:39418
+#, gcc-internal-format
+msgid "last argument must be an immediate"
+msgstr ""
+
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
+#, gcc-internal-format
+msgid "the last argument must be scale 1, 2, 4, 8"
+msgstr ""
+
+#: config/i386/i386.c:40220
+#, gcc-internal-format
+msgid "the forth argument must be scale 1, 2, 4, 8"
+msgstr ""
+
+#: config/i386/i386.c:40226
+#, gcc-internal-format
+msgid "incorrect hint operand"
+msgstr ""
+
+#: config/i386/i386.c:40245
+#, gcc-internal-format
+msgid "the xabort's argument must be an 8-bit immediate"
+msgstr ""
+
+#: config/i386/i386.c:42857
+#, gcc-internal-format
+msgid "%qE attribute only available for 32-bit"
+msgstr ""
+
+#: config/i386/i386.c:42878
+#, gcc-internal-format
+msgid "argument to %qE attribute is neither zero, nor one"
+msgstr ""
+
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
+#, gcc-internal-format
+msgid "ms_abi and sysv_abi attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
+#, gcc-internal-format
+msgid "%qE incompatible attribute ignored"
+msgstr ""
+
+#: config/i386/i386.c:51527
+#, gcc-internal-format
+msgid "Unknown architecture specific memory model"
+msgstr ""
+
+#: config/i386/i386.c:51534
+#, gcc-internal-format
+msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
+msgstr ""
+
+#: config/i386/i386.c:51540
+#, gcc-internal-format
+msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
+msgstr ""
+
+#: config/i386/i386.c:51564
+#, gcc-internal-format, gfc-internal-format
+msgid "unsupported simdlen %d"
+msgstr ""
+
+#: config/i386/i386.c:51583
+#, gcc-internal-format
+msgid "unsupported return type %qT for simd\n"
+msgstr ""
+
+#: config/i386/i386.c:51605
+#, gcc-internal-format
+msgid "unsupported argument type %qT for simd\n"
+msgstr ""
+
+#: config/i386/i386.c:51889
+#, gcc-internal-format
+msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
+msgstr ""
+
+#: config/i386/intelmic-mkoffload.c:241 config/i386/intelmic-mkoffload.c:301
+#: config/i386/intelmic-mkoffload.c:338 config/nvptx/mkoffload.c:1008
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot open '%s'"
+msgstr "не вдалося відкрити «%s»"
+
+#: config/i386/intelmic-mkoffload.c:428
+#, gcc-internal-format
+msgid "output file not specified"
+msgstr ""
+
+#: config/i386/intelmic-mkoffload.c:508
+#, gcc-internal-format
+msgid "COLLECT_GCC must be set"
+msgstr ""
+
+#: config/i386/intelmic-mkoffload.c:513 config/nvptx/mkoffload.c:959
+#, gcc-internal-format, gfc-internal-format
+msgid "offload compiler %s not found"
+msgstr ""
+
+#: config/i386/intelmic-mkoffload.c:528
+#, gcc-internal-format
+msgid "unrecognizable argument of option -foffload-abi"
+msgstr ""
+
+#: config/i386/winnt.c:117
+#, gcc-internal-format
+msgid "%qE attribute applies only to initialized variables with external linkage"
+msgstr ""
+
+#: config/i386/winnt.c:184
+#, gcc-internal-format
+msgid "definition of static data member %q+D of dllimport%'d class"
+msgstr ""
+
+#: config/i386/winnt.c:370
+#, gcc-internal-format
+msgid "%q+D:'selectany' attribute applies only to initialized objects"
+msgstr ""
+
+#: config/i386/cygming.h:205
+#, gcc-internal-format
+msgid "-fPIC ignored for target (all code is position independent)"
+msgstr ""
+
+#: config/i386/cygming.h:211
+#, gcc-internal-format, gfc-internal-format
+msgid "-f%s ignored for target (all code is position independent)"
+msgstr ""
+
+#: config/i386/djgpp.h:172
+#, gcc-internal-format
+msgid "-mbnu210 is ignored (option is obsolete)"
+msgstr ""
+
+#: config/ia64/ia64-c.c:61
+#, gcc-internal-format
+msgid "malformed #pragma builtin"
+msgstr ""
+
+#: config/ia64/ia64.c:763
+#, gcc-internal-format
+msgid "invalid argument of %qE attribute"
+msgstr ""
+
+#: config/ia64/ia64.c:776
+#, gcc-internal-format
+msgid "an address area attribute cannot be specified for local variables"
+msgstr ""
+
+#: config/ia64/ia64.c:783
+#, gcc-internal-format
+msgid "address area of %q+D conflicts with previous declaration"
+msgstr ""
+
+#: config/ia64/ia64.c:791
+#, gcc-internal-format
+msgid "address area attribute cannot be specified for functions"
+msgstr ""
+
+#: config/ia64/ia64.c:824
+#, gcc-internal-format
+msgid "%qE attribute requires a string constant argument"
+msgstr ""
+
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
+#: config/spu/spu.c:4945
+#, gcc-internal-format
+msgid "value of -mfixed-range must have form REG1-REG2"
+msgstr ""
+
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
+#: config/spu/spu.c:4971
+#, gcc-internal-format, gfc-internal-format
+msgid "%s-%s is an empty range"
+msgstr ""
+
+#: config/ia64/ia64.c:11203
+#, gcc-internal-format
+msgid "version attribute is not a string"
+msgstr ""
+
+#: config/iq2000/iq2000.c:1866
+#, gcc-internal-format, gfc-internal-format
+msgid "gp_offset (%ld) or end_offset (%ld) is less than zero"
+msgstr ""
+
+#: config/iq2000/iq2000.c:2630
+#, gcc-internal-format
+msgid "argument %qd is not a constant"
+msgstr ""
+
+#: config/iq2000/iq2000.c:2933 config/xtensa/xtensa.c:2473
+#, gcc-internal-format
+msgid "PRINT_OPERAND_ADDRESS, null pointer"
+msgstr ""
+
+#: config/iq2000/iq2000.c:3088
+#, gcc-internal-format, gfc-internal-format
+msgid "PRINT_OPERAND: Unknown punctuation '%c'"
+msgstr ""
+
+#: config/iq2000/iq2000.c:3097 config/xtensa/xtensa.c:2327
+#, gcc-internal-format
+msgid "PRINT_OPERAND null pointer"
+msgstr ""
+
+#: config/m32c/m32c-pragma.c:64
+#, gcc-internal-format
+msgid "junk at end of #pragma GCC memregs [0..16]"
+msgstr ""
+
+#: config/m32c/m32c-pragma.c:71
+#, gcc-internal-format
+msgid "#pragma GCC memregs must precede any function decls"
+msgstr ""
+
+#: config/m32c/m32c-pragma.c:79 config/m32c/m32c-pragma.c:86
+#, gcc-internal-format
+msgid "#pragma GCC memregs takes a number [0..16]"
+msgstr ""
+
+#: config/m32c/m32c-pragma.c:114
+#, gcc-internal-format
+msgid "junk at end of #pragma ADDRESS"
+msgstr ""
+
+#: config/m32c/m32c-pragma.c:119
+#, gcc-internal-format
+msgid "malformed #pragma ADDRESS variable address"
+msgstr ""
+
+#: config/m32c/m32c.c:454
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid target memregs value '%d'"
+msgstr ""
+
+#: config/m32c/m32c.c:2966
+#, gcc-internal-format
+msgid "%qE attribute is not supported for R8C target"
+msgstr ""
+
+#. The argument must be a constant integer.
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
+#, gcc-internal-format
+msgid "%qE attribute argument not an integer constant"
+msgstr ""
+
+#: config/m32c/m32c.c:2991
+#, gcc-internal-format
+msgid "%qE attribute argument should be between 18 to 255"
+msgstr ""
+
+#: config/m32c/m32c.c:4143
+#, gcc-internal-format
+msgid "%<bank_switch%> has no effect on non-interrupt functions"
+msgstr ""
+
+#: config/m32c/m32c.c:4247
+#, gcc-internal-format
+msgid "%<fast_interrupt%> attribute directive ignored"
+msgstr ""
+
+#: config/m32r/m32r.c:416
+#, gcc-internal-format
+msgid "invalid argument of %qs attribute"
+msgstr ""
+
+#: config/m68k/m68k.c:509
+#, gcc-internal-format, gfc-internal-format
+msgid "-mcpu=%s conflicts with -march=%s"
+msgstr ""
+
+#: config/m68k/m68k.c:580
+#, gcc-internal-format
+msgid "-mpcrel -fPIC is not currently supported on selected cpu"
+msgstr ""
+
+#: config/m68k/m68k.c:642
+#, gcc-internal-format, gfc-internal-format
+msgid "-falign-labels=%d is not supported"
+msgstr ""
+
+#: config/m68k/m68k.c:647
+#, gcc-internal-format, gfc-internal-format
+msgid "-falign-loops=%d is not supported"
+msgstr ""
+
+#: config/m68k/m68k.c:654
+#, gcc-internal-format
+msgid "-fstack-limit- options are not supported on this cpu"
+msgstr ""
+
+#: config/m68k/m68k.c:771
+#, gcc-internal-format
+msgid "multiple interrupt attributes not allowed"
+msgstr ""
+
+#: config/m68k/m68k.c:778
+#, gcc-internal-format
+msgid "interrupt_thread is available only on fido"
+msgstr ""
+
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
+#, gcc-internal-format
+msgid "stack limit expression is not supported"
+msgstr ""
+
+#: config/mcore/mcore.c:2972
+#, gcc-internal-format
+msgid "initialized variable %q+D is marked dllimport"
+msgstr ""
+
+#: config/mep/mep-pragma.c:81
+#, gcc-internal-format
+msgid "junk at end of #pragma io_volatile"
+msgstr ""
+
+#: config/mep/mep-pragma.c:95
+#, gcc-internal-format
+msgid "#pragma io_volatile takes only on or off"
+msgstr ""
+
+#: config/mep/mep-pragma.c:134
+#, gcc-internal-format
+msgid "invalid coprocessor register range"
+msgstr ""
+
+#: config/mep/mep-pragma.c:154
+#, gcc-internal-format
+msgid "invalid coprocessor register %qE"
+msgstr ""
+
+#: config/mep/mep-pragma.c:177
+#, gcc-internal-format
+msgid "malformed coprocessor register"
+msgstr ""
+
+#: config/mep/mep-pragma.c:264
+#, gcc-internal-format
+msgid "junk at end of #pragma GCC coprocessor width"
+msgstr ""
+
+#: config/mep/mep-pragma.c:271
+#, gcc-internal-format
+msgid "#pragma GCC coprocessor width takes only 32 or 64"
+msgstr ""
+
+#: config/mep/mep-pragma.c:302
+#, gcc-internal-format
+msgid "#pragma GCC coprocessor subclass letter must be in [ABCD]"
+msgstr ""
+
+#: config/mep/mep-pragma.c:307
+#, gcc-internal-format, gfc-internal-format
+msgid "#pragma GCC coprocessor subclass '%c' already defined"
+msgstr ""
+
+#: config/mep/mep-pragma.c:325
+#, gcc-internal-format
+msgid "malformed #pragma GCC coprocessor subclass"
+msgstr ""
+
+#: config/mep/mep-pragma.c:347
+#, gcc-internal-format
+msgid "malformed #pragma disinterrupt"
+msgstr ""
+
+#: config/mep/mep-pragma.c:361
+#, gcc-internal-format
+msgid "malformed #pragma GCC coprocessor"
+msgstr ""
+
+#: config/mep/mep-pragma.c:366
+#, gcc-internal-format
+msgid "coprocessor not enabled"
+msgstr ""
+
+#: config/mep/mep-pragma.c:377
+#, gcc-internal-format
+msgid "unknown #pragma GCC coprocessor %E"
+msgstr ""
+
+#: config/mep/mep-pragma.c:399
+#, gcc-internal-format
+msgid "malformed #pragma call"
+msgstr ""
+
+#: config/mep/mep.c:398
+#, gcc-internal-format
+msgid "only one of -ms and -mm may be given"
+msgstr ""
+
+#: config/mep/mep.c:400
+#, gcc-internal-format
+msgid "only one of -ms and -ml may be given"
+msgstr ""
+
+#: config/mep/mep.c:402
+#, gcc-internal-format
+msgid "only one of -mm and -ml may be given"
+msgstr ""
+
+#: config/mep/mep.c:404
+#, gcc-internal-format
+msgid "only one of -ms and -mtiny= may be given"
+msgstr ""
+
+#: config/mep/mep.c:406
+#, gcc-internal-format
+msgid "only one of -mm and -mtiny= may be given"
+msgstr ""
+
+#: config/mep/mep.c:408
+#, gcc-internal-format
+msgid "-mclip currently has no effect without -mminmax"
+msgstr ""
+
+#: config/mep/mep.c:415
+#, gcc-internal-format
+msgid "-mc= must be -mc=tiny, -mc=near, or -mc=far"
+msgstr ""
+
+#: config/mep/mep.c:1417
+#, gcc-internal-format
+msgid "unusual TP-relative address"
+msgstr ""
+
+#: config/mep/mep.c:3394
+#, gcc-internal-format
+msgid "unconvertible operand %c %qs"
+msgstr ""
+
+#: config/mep/mep.c:3840 config/mep/mep.c:3903
+#, gcc-internal-format
+msgid "address region attributes not allowed with auto storage class"
+msgstr ""
+
+#: config/mep/mep.c:3846 config/mep/mep.c:3909
+#, gcc-internal-format
+msgid "address region attributes on pointed-to types ignored"
+msgstr ""
+
+#: config/mep/mep.c:3895
+#, gcc-internal-format
+msgid "%qE attribute only applies to variables and functions"
+msgstr ""
+
+#: config/mep/mep.c:3915 config/mep/mep.c:4214
+#, gcc-internal-format
+msgid "duplicate address region attribute %qE in declaration of %qE on line %d"
+msgstr ""
+
+#: config/mep/mep.c:3949
+#, gcc-internal-format
+msgid "cannot inline interrupt function %qE"
+msgstr ""
+
+#: config/mep/mep.c:3955
+#, gcc-internal-format
+msgid "interrupt function must have return type of void"
+msgstr ""
+
+#: config/mep/mep.c:3960
+#, gcc-internal-format
+msgid "interrupt function must have no arguments"
+msgstr ""
+
+#: config/mep/mep.c:4014
+#, gcc-internal-format
+msgid "%qE attribute only applies to functions, not %s"
+msgstr ""
+
+#: config/mep/mep.c:4025
+#, gcc-internal-format, gfc-internal-format
+msgid ""
+"to describe a pointer to a VLIW function, use syntax like this:\n"
+"%s"
+msgstr ""
+
+#: config/mep/mep.c:4034
+#, gcc-internal-format, gfc-internal-format
+msgid ""
+"to describe an array of VLIW function pointers, use syntax like this:\n"
+"%s"
+msgstr ""
+
+#: config/mep/mep.c:4040
+#, gcc-internal-format
+msgid "VLIW functions are not allowed without a VLIW configuration"
+msgstr ""
+
+#: config/mep/mep.c:4173
+#, gcc-internal-format, gfc-internal-format
+msgid "\"#pragma disinterrupt %s\" not used"
+msgstr ""
+
+#: config/mep/mep.c:4339
+#, gcc-internal-format
+msgid "__io address 0x%x is the same for %qE and %qE"
+msgstr ""
+
+#: config/mep/mep.c:4487
+#, gcc-internal-format, gfc-internal-format
+msgid "variable %s (%ld bytes) is too large for the %s section (%d bytes)"
+msgstr ""
+
+#: config/mep/mep.c:4585
+#, gcc-internal-format
+msgid "variable %D of type %<io%> must be uninitialized"
+msgstr ""
+
+#: config/mep/mep.c:4590
+#, gcc-internal-format
+msgid "variable %D of type %<cb%> must be uninitialized"
+msgstr ""
+
+#: config/mep/mep.c:6025
+#, gcc-internal-format
+msgid "coprocessor intrinsic %qs is not available in this configuration"
+msgstr ""
+
+#: config/mep/mep.c:6028
+#, gcc-internal-format
+msgid "%qs is not available in VLIW functions"
+msgstr ""
+
+#: config/mep/mep.c:6031
+#, gcc-internal-format
+msgid "%qs is not available in non-VLIW functions"
+msgstr ""
+
+#: config/mep/mep.c:6193 config/mep/mep.c:6310
+#, gcc-internal-format
+msgid "argument %d of %qE must be in the range %d...%d"
+msgstr ""
+
+#: config/mep/mep.c:6196
+#, gcc-internal-format
+msgid "argument %d of %qE must be a multiple of %d"
+msgstr ""
+
+#: config/mep/mep.c:6249
+#, gcc-internal-format
+msgid "too few arguments to %qE"
+msgstr ""
+
+#: config/mep/mep.c:6254
+#, gcc-internal-format
+msgid "too many arguments to %qE"
+msgstr ""
+
+#: config/mep/mep.c:6272
+#, gcc-internal-format
+msgid "argument %d of %qE must be an address"
+msgstr ""
+
+#: config/mep/mep.c:7068
+#, gcc-internal-format
+msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
+msgstr ""
+
+#: config/mep/mep.c:7074
+#, gcc-internal-format, gfc-internal-format
+msgid "unexpected %d byte cop instruction"
+msgstr ""
+
+#: config/microblaze/microblaze.c:1723
+#, gcc-internal-format
+msgid "-fPIC/-fpic not supported for this target"
+msgstr ""
+
+#: config/microblaze/microblaze.c:1735
+#, gcc-internal-format
+msgid "%qs is an invalid argument to -mcpu="
+msgstr ""
+
+#: config/microblaze/microblaze.c:1784
+#, gcc-internal-format
+msgid "-mxl-multiply-high can be used only with -mcpu=v6.00.a or greater"
+msgstr ""
+
+#: config/microblaze/microblaze.c:1800
+#, gcc-internal-format
+msgid "-mxl-reorder can be used only with -mcpu=v8.30.a or greater"
+msgstr ""
+
+#: config/microblaze/microblaze.c:1806
+#, gcc-internal-format
+msgid "-mxl-reorder requires -mxl-pattern-compare for -mcpu=v8.30.a"
+msgstr ""
+
+#: config/microblaze/microblaze.c:1811
+#, gcc-internal-format
+msgid "-mxl-multiply-high requires -mno-xl-soft-mul"
+msgstr ""
+
+#: config/mips/mips.c:1493 config/mips/mips.c:1497
+#, gcc-internal-format
+msgid "%qs attribute only applies to functions"
+msgstr ""
+
+#: config/mips/mips.c:1507 config/mips/mips.c:1513
+#, gcc-internal-format
+msgid "%qE cannot have both %qs and %qs attributes"
+msgstr ""
+
+#: config/mips/mips.c:1542 config/mips/mips.c:1548 config/nios2/nios2.c:3339
+#, gcc-internal-format
+msgid "%qE redeclared with conflicting %qs attributes"
+msgstr ""
+
+#: config/mips/mips.c:7239
+#, gcc-internal-format
+msgid "cannot handle inconsistent calls to %qs"
+msgstr ""
+
+#: config/mips/mips.c:10332
+#, gcc-internal-format
+msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
+msgstr ""
+
+#: config/mips/mips.c:10334
+#, gcc-internal-format
+msgid "the %<interrupt%> attribute requires %<-msoft-float%>"
+msgstr ""
+
+#: config/mips/mips.c:10336
+#, gcc-internal-format
+msgid "interrupt handlers cannot be MIPS16 functions"
+msgstr ""
+
+#: config/mips/mips.c:11279
+#, gcc-internal-format
+msgid "-fstack-check=specific not implemented for MIPS16"
+msgstr ""
+
+#: config/mips/mips.c:14782 config/nds32/nds32-intrinsic.c:106
+#: config/nds32/nds32-intrinsic.c:134 config/nds32/nds32-intrinsic.c:164
+#: config/nios2/nios2.c:2608
+#, gcc-internal-format
+msgid "invalid argument to built-in function"
+msgstr ""
+
+#: config/mips/mips.c:14983
+#, gcc-internal-format
+msgid "built-in function %qE not supported for MIPS16"
+msgstr ""
+
+#: config/mips/mips.c:15579
+#, gcc-internal-format
+msgid "%qs does not support MIPS16 code"
+msgstr ""
+
+#: config/mips/mips.c:17142
+#, gcc-internal-format
+msgid "MIPS16 PIC for ABIs other than o32 and o64"
+msgstr ""
+
+#: config/mips/mips.c:17145
+#, gcc-internal-format
+msgid "MIPS16 -mxgot code"
+msgstr ""
+
+#: config/mips/mips.c:17148
+#, gcc-internal-format
+msgid "hard-float MIPS16 code for ABIs other than o32 and o64"
+msgstr ""
+
+#: config/mips/mips.c:17316 config/mips/mips.c:17398 config/mips/mips.c:17400
+#: config/mips/mips.c:17428 config/mips/mips.c:17438 config/mips/mips.c:17537
+#: config/mips/mips.c:17546
+#, gcc-internal-format, gfc-internal-format
+msgid "unsupported combination: %s"
+msgstr ""
+
+#: config/mips/mips.c:17350
+#, gcc-internal-format
+msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
+msgstr ""
+
+#: config/mips/mips.c:17360
+#, gcc-internal-format
+msgid "%<-march=%s%> is not compatible with the selected ABI"
+msgstr ""
+
+#: config/mips/mips.c:17375
+#, gcc-internal-format
+msgid "%<-mgp64%> used with a 32-bit processor"
+msgstr ""
+
+#: config/mips/mips.c:17377
+#, gcc-internal-format
+msgid "%<-mgp32%> used with a 64-bit ABI"
+msgstr ""
+
+#: config/mips/mips.c:17379
+#, gcc-internal-format
+msgid "%<-mgp64%> used with a 32-bit ABI"
+msgstr ""
+
+#: config/mips/mips.c:17395
+#, gcc-internal-format
+msgid "the %qs architecture does not support %<-mfp32%>"
+msgstr ""
+
+#: config/mips/mips.c:17404
+#, gcc-internal-format
+msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
+msgstr ""
+
+#: config/mips/mips.c:17407
+#, gcc-internal-format
+msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
+msgstr ""
+
+#: config/mips/mips.c:17426
+#, gcc-internal-format
+msgid "%<-mfpxx%> can only be used with the o32 ABI"
+msgstr ""
+
+#: config/mips/mips.c:17430
+#, gcc-internal-format
+msgid "%<-march=%s%> requires %<-mfp32%>"
+msgstr "%<-march=%s%> потребує %<-mfp32%>"
+
+#: config/mips/mips.c:17432
+#, gcc-internal-format
+msgid "%<-mfpxx%> requires %<-mlra%>"
+msgstr "%<-mfpxx%> потребує %<-mlra%>"
+
+#: config/mips/mips.c:17448 config/mips/mips.c:17450 config/mips/mips.c:17463
+#, gcc-internal-format
+msgid "%qs is incompatible with %qs"
+msgstr ""
+
+#. We have traditionally allowed non-abicalls code to use
+#. an LP64 form of o64.  However, it would take a bit more
+#. effort to support the combination of 32-bit GOT entries
+#. and 64-bit pointers, so we treat the abicalls case as
+#. an error.
+#: config/mips/mips.c:17457
+#, gcc-internal-format
+msgid "the combination of %qs and %qs is incompatible with %qs"
+msgstr ""
+
+#: config/mips/mips.c:17503
+#, gcc-internal-format
+msgid "the %qs architecture does not support branch-likely instructions"
+msgstr ""
+
+#: config/mips/mips.c:17518
+#, gcc-internal-format
+msgid "the %qs architecture does not support madd or msub instructions"
+msgstr ""
+
+#: config/mips/mips.c:17532
+#, gcc-internal-format
+msgid "the %qs architecture does not support odd single-precision registers"
+msgstr ""
+
+#: config/mips/mips.c:17554
+#, gcc-internal-format
+msgid "cannot generate position-independent code for %qs"
+msgstr ""
+
+#: config/mips/mips.c:17557
+#, gcc-internal-format
+msgid "position-independent code requires %qs"
+msgstr ""
+
+#: config/mips/mips.c:17590
+#, gcc-internal-format
+msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
+msgstr ""
+
+#: config/mips/mips.c:17598 config/mips/mips.c:17601
+#, gcc-internal-format
+msgid "cannot use small-data accesses for %qs"
+msgstr ""
+
+#: config/mips/mips.c:17616
+#, gcc-internal-format
+msgid "the %qs architecture does not support %<-m%s=legacy%>"
+msgstr ""
+
+#: config/mips/mips.c:17623
+#, gcc-internal-format
+msgid "the %qs architecture does not support %<-m%s=2008%>"
+msgstr ""
+
+#: config/mips/mips.c:17641
+#, gcc-internal-format
+msgid "%<-mips3d%> requires %<-mpaired-single%>"
+msgstr "%<-mips3d%> потребує %<-mpaired-single%>"
+
+#: config/mips/mips.c:17651
+#, gcc-internal-format
+msgid "%qs must be used with %qs"
+msgstr ""
+
+#: config/mips/mips.c:17663
+#, gcc-internal-format
+msgid "the %qs architecture does not support paired-single instructions"
+msgstr ""
+
+#: config/mips/mips.c:17672
+#, gcc-internal-format
+msgid "%qs requires a target that provides the %qs instruction"
+msgstr ""
+
+#: config/mips/mips.c:17683
+#, gcc-internal-format
+msgid "the %qs architecture does not support DSP instructions"
+msgstr ""
+
+#: config/mips/mips.c:17785
+#, gcc-internal-format
+msgid "%qs requires branch-likely instructions"
+msgstr ""
+
+#: config/mips/mips.c:17789
+#, gcc-internal-format
+msgid "the %qs architecture does not support the synci instruction"
+msgstr ""
+
+#: config/mips/mips.c:18527
+#, gcc-internal-format
+msgid "mips16 function profiling"
+msgstr ""
+
+#: config/mmix/mmix.c:324
+#, gcc-internal-format, gfc-internal-format
+msgid "-f%s not supported: ignored"
+msgstr ""
+
+#: config/mmix/mmix.c:754
+#, gcc-internal-format
+msgid "support for mode %qs"
+msgstr ""
+
+#: config/mmix/mmix.c:768
+#, gcc-internal-format, gfc-internal-format
+msgid "too large function value type, needs %d registers, have only %d registers for this"
+msgstr ""
+
+#: config/mmix/mmix.c:947
+#, gcc-internal-format
+msgid "function_profiler support for MMIX"
+msgstr ""
+
+#: config/mmix/mmix.c:971
+#, gcc-internal-format
+msgid "MMIX Internal: Last named vararg would not fit in a register"
+msgstr ""
+
+#: config/mmix/mmix.c:1583 config/mmix/mmix.c:1607 config/mmix/mmix.c:1723
+#, gcc-internal-format, gfc-internal-format
+msgid "MMIX Internal: Bad register: %d"
+msgstr ""
+
+#. Presumably there's a missing case above if we get here.
+#: config/mmix/mmix.c:1715
+#, gcc-internal-format
+msgid "MMIX Internal: Missing %qc case in mmix_print_operand"
+msgstr ""
+
+#: config/mmix/mmix.c:2000
+#, gcc-internal-format
+msgid "stack frame not a multiple of 8 bytes: %wd"
+msgstr ""
+
+#: config/mmix/mmix.c:2239
+#, gcc-internal-format
+msgid "stack frame not a multiple of octabyte: %wd"
+msgstr ""
+
+#: config/mmix/mmix.c:2525 config/mmix/mmix.c:2584
+#, gcc-internal-format, gfc-internal-format
+msgid "MMIX Internal: %s is not a shiftable int"
+msgstr ""
+
+#: config/mn10300/mn10300.c:130
+#, gcc-internal-format
+msgid "-mtune= expects mn10300, am33, am33-2, or am34"
+msgstr ""
+
+#: config/msp430/msp430.c:245
+#, gcc-internal-format
+msgid "-mlarge requires a 430X-compatible -mmcu="
+msgstr ""
+
+#: config/msp430/msp430.c:1287
+#, gcc-internal-format
+msgid "unrecognised interrupt vector argument of %qE attribute"
+msgstr ""
+
+#: config/msp430/msp430.c:1296
+#, gcc-internal-format
+msgid "numeric argument of %qE attribute must be in range 0..63"
+msgstr ""
+
+#: config/msp430/msp430.c:1302
+#, gcc-internal-format
+msgid "argument of %qE attribute is not a string constant or number"
+msgstr ""
+
+#: config/msp430/msp430.c:1469
+#, gcc-internal-format
+msgid "__delay_cycles() only takes constant arguments"
+msgstr ""
+
+#: config/msp430/msp430.c:1479
+#, gcc-internal-format
+msgid "__delay_cycles only takes non-negative cycle counts."
+msgstr ""
+
+#: config/msp430/msp430.c:1499
+#, gcc-internal-format
+msgid "__delay_cycles is limited to 32-bit loop counts."
+msgstr ""
+
+#: config/msp430/msp430.c:1569
+#, gcc-internal-format
+msgid "MSP430 builtin functions only work inside interrupt handlers"
+msgstr ""
+
+#: config/msp430/msp430.c:1581 config/rx/rx.c:2635 config/xtensa/xtensa.c:3371
+#: config/xtensa/xtensa.c:3397
+#, gcc-internal-format
+msgid "bad builtin code"
+msgstr ""
+
+#: config/nds32/nds32-isr.c:387
+#, gcc-internal-format
+msgid "multiple save reg attributes to function %qD"
+msgstr ""
+
+#: config/nds32/nds32-isr.c:398
+#, gcc-internal-format
+msgid "multiple nested types attributes to function %qD"
+msgstr ""
+
+#: config/nds32/nds32-isr.c:410
+#, gcc-internal-format
+msgid "multiple interrupt attributes to function %qD"
+msgstr ""
+
+#. Trampoline is not supported on reduced-set registers yet.
+#: config/nds32/nds32.c:1779 config/nds32/nds32.c:1833
+#: config/nds32/nds32.c:2345 config/nds32/nds32.c:2392
+#: config/nds32/nds32.c:2407 config/nds32/nds32.c:2413
+#: config/nds32/nds32.c:2473 config/nds32/nds32.c:2479
+#: config/nds32/nds32.c:2511
+#, gcc-internal-format
+msgid "a nested function is not supported for reduced registers"
+msgstr ""
+
+#. The enum index value for array size is out of range.
+#: config/nds32/nds32.c:2314
+#, gcc-internal-format
+msgid "intrinsic register index is out of range"
+msgstr ""
+
+#: config/nds32/nds32.c:2619
+#, gcc-internal-format
+msgid "invalid id value for interrupt/exception attribute"
+msgstr ""
+
+#: config/nds32/nds32.c:2647
+#, gcc-internal-format
+msgid "invalid id value for reset attribute"
+msgstr ""
+
+#: config/nds32/nds32.c:2663
+#, gcc-internal-format
+msgid "invalid nmi function for reset attribute"
+msgstr ""
+
+#: config/nds32/nds32.c:2676
+#, gcc-internal-format
+msgid "invalid warm function for reset attribute"
+msgstr ""
+
+#: config/nds32/nds32.c:2744
+#, gcc-internal-format
+msgid "not support -fpic"
+msgstr ""
+
+#: config/nios2/nios2.c:486
+#, gcc-internal-format
+msgid "only register based stack limit is supported"
+msgstr ""
+
+#: config/nios2/nios2.c:868
+#, gcc-internal-format
+msgid "switch %<-mcustom-%s%> is required for double precision floating point"
+msgstr ""
+
+#: config/nios2/nios2.c:881
+#, gcc-internal-format
+msgid "switch %<-mcustom-%s%> has no effect unless -funsafe-math-optimizations is specified"
+msgstr ""
+
+#: config/nios2/nios2.c:890
+#, gcc-internal-format
+msgid "switch %<-mcustom-%s%> has no effect unless -ffinite-math-only is specified"
+msgstr ""
+
+#: config/nios2/nios2.c:899
+#, gcc-internal-format
+msgid "switch %<-mcustom-%s%> has no effect unless -fno-math-errno is specified"
+msgstr ""
+
+#: config/nios2/nios2.c:904
+#, gcc-internal-format
+msgid "conflicting use of -mcustom switches, target attributes, and/or __builtin_custom_ functions"
+msgstr ""
+
+#: config/nios2/nios2.c:1006
+#, gcc-internal-format
+msgid "ignoring unrecognized switch %<-mcustom-fpu-cfg%> value %<%s%>"
+msgstr ""
+
+#: config/nios2/nios2.c:1025
+#, gcc-internal-format
+msgid "switch %<-mcustom-%s%> value %d must be between 0 and 255"
+msgstr ""
+
+#: config/nios2/nios2.c:1048
+#, gcc-internal-format
+msgid "position-independent code requires the Linux ABI"
+msgstr ""
+
+#: config/nios2/nios2.c:2592
+#, gcc-internal-format
+msgid "Cannot call %<__builtin_custom_%s%> without specifying switch %<-mcustom-%s%>"
+msgstr ""
+
+#: config/nios2/nios2.c:2700
+#, gcc-internal-format, gfc-internal-format
+msgid "custom instruction opcode must be compile time constant in the range 0-255 for __builtin_custom_%s"
+msgstr ""
+
+#: config/nios2/nios2.c:2836
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid argument to built-in function %s"
+msgstr ""
+
+#: config/nios2/nios2.c:2886
+#, gcc-internal-format, gfc-internal-format
+msgid "Control register number must be in range 0-31 for %s"
+msgstr ""
+
+#: config/nios2/nios2.c:2981
+#, gcc-internal-format
+msgid "switch %<-mcustom-%s%> conflicts with switch %<-mcustom-%s%>"
+msgstr ""
+
+#: config/nios2/nios2.c:2987 config/nios2/nios2.c:2997
+#, gcc-internal-format
+msgid "call to %<__builtin_custom_%s%> conflicts with switch %<-mcustom-%s%>"
+msgstr ""
+
+#: config/nios2/nios2.c:3103
+#, gcc-internal-format
+msgid "custom-fpu-cfg option does not support %<no-%>"
+msgstr ""
+
+#: config/nios2/nios2.c:3108
+#, gcc-internal-format
+msgid "custom-fpu-cfg option requires configuration argument"
+msgstr ""
+
+#: config/nios2/nios2.c:3137
+#, gcc-internal-format
+msgid "%<no-custom-%s%> does not accept arguments"
+msgstr ""
+
+#: config/nios2/nios2.c:3152
+#, gcc-internal-format
+msgid "%<custom-%s=%> requires argument"
+msgstr ""
+
+#: config/nios2/nios2.c:3162
+#, gcc-internal-format, gfc-internal-format
+msgid "`custom-%s=' argument requires numeric digits"
+msgstr ""
+
+#: config/nios2/nios2.c:3174
+#, gcc-internal-format
+msgid "%<custom-%s=%> is not recognised as FPU instruction"
+msgstr ""
+
+#: config/nios2/nios2.c:3181
+#, gcc-internal-format
+msgid "%<%s%> is unknown"
+msgstr ""
+
+#: config/nvptx/mkoffload.c:140
+#, gcc-internal-format
+msgid "deleting file %s: %m"
+msgstr ""
+
+#: config/nvptx/mkoffload.c:167
+#, gcc-internal-format
+msgid "malformed ptx file"
+msgstr ""
+
+#: config/nvptx/mkoffload.c:911
+#, gcc-internal-format
+msgid "COLLECT_GCC must be set."
+msgstr ""
+
+#: config/nvptx/mkoffload.c:1002
+#, gcc-internal-format
+msgid "cannot open intermediate ptx file"
+msgstr ""
+
+#: config/nvptx/nvptx.c:1287
+#, gcc-internal-format
+msgid "cannot emit unaligned pointers in ptx assembly"
+msgstr ""
+
+#: config/nvptx/nvptx.c:2007
+#, gcc-internal-format
+msgid "%qE attribute requires a void return type"
+msgstr ""
+
+#: config/pa/pa.c:530
+#, gcc-internal-format
+msgid "PIC code generation is not supported in the portable runtime model"
+msgstr ""
+
+#: config/pa/pa.c:535
+#, gcc-internal-format
+msgid "PIC code generation is not compatible with fast indirect calls"
+msgstr ""
+
+#: config/pa/pa.c:540
+#, gcc-internal-format
+msgid "-g is only supported when using GAS on this processor,"
+msgstr ""
+
+#: config/pa/pa.c:541
+#, gcc-internal-format
+msgid "-g option disabled"
+msgstr ""
+
+#: config/pa/pa.c:8648
+#, gcc-internal-format, gfc-internal-format
+msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
+msgstr ""
+
+#. Address spaces are currently only supported by C.
+#: config/rl78/rl78.c:379
+#, gcc-internal-format
+msgid "-mes0 can only be used with C"
+msgstr ""
+
+#: config/rl78/rl78.c:757
+#, gcc-internal-format
+msgid "naked attribute only applies to functions"
+msgstr ""
+
+#: config/rl78/rl78.c:781
+#, gcc-internal-format
+msgid "%qE attribute doesn't apply to functions"
+msgstr ""
+
+#. This is unpredictable, as we're truncating off usable address
+#. bits.
+#: config/rl78/rl78.c:1120
+#, gcc-internal-format
+msgid "converting far pointer to near pointer"
+msgstr ""
+
+#: config/rs6000/host-darwin.c:59
+#, gcc-internal-format
+msgid "Segmentation Fault (code)"
+msgstr ""
+
+#: config/rs6000/host-darwin.c:129
+#, gcc-internal-format
+msgid "Segmentation Fault"
+msgstr "Помилка адресування"
+
+#: config/rs6000/host-darwin.c:143
+#, gcc-internal-format
+msgid "While setting up signal stack: %m"
+msgstr ""
+
+#: config/rs6000/host-darwin.c:149
+#, gcc-internal-format
+msgid "While setting up signal handler: %m"
+msgstr ""
+
+#. Handle the machine specific pragma longcall.  Its syntax is
+#.
+#. # pragma longcall ( TOGGLE )
+#.
+#. where TOGGLE is either 0 or 1.
+#.
+#. rs6000_default_long_calls is set to the value of TOGGLE, changing
+#. whether or not new function declarations receive a longcall
+#. attribute by default.
+#: config/rs6000/rs6000-c.c:63
+#, gcc-internal-format
+msgid "ignoring malformed #pragma longcall"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:76
+#, gcc-internal-format
+msgid "missing open paren"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:78
+#, gcc-internal-format
+msgid "missing number"
+msgstr "не вказано числа"
+
+#: config/rs6000/rs6000-c.c:80
+#, gcc-internal-format
+msgid "missing close paren"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:83
+#, gcc-internal-format
+msgid "number must be 0 or 1"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:86
+#, gcc-internal-format
+msgid "junk at end of #pragma longcall"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:4367
+#, gcc-internal-format
+msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:4370
+#, gcc-internal-format
+msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:4386
+#, gcc-internal-format, gfc-internal-format
+msgid "%s only accepts %d arguments"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:4391
+#, gcc-internal-format, gfc-internal-format
+msgid "%s only accepts 1 argument"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:4396
+#, gcc-internal-format, gfc-internal-format
+msgid "%s only accepts 2 arguments"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:4462
+#, gcc-internal-format
+msgid "vec_extract only accepts 2 arguments"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:4564
+#, gcc-internal-format
+msgid "vec_insert only accepts 3 arguments"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:4696
+#, gcc-internal-format
+msgid "passing arg %d of %qE discards qualifiers frompointer target type"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:4740
+#, gcc-internal-format
+msgid "invalid parameter combination for AltiVec intrinsic"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3046
+#, gcc-internal-format
+msgid "-mrecip requires -ffinite-math or -ffast-math"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3048
+#, gcc-internal-format
+msgid "-mrecip requires -fno-trapping-math or -ffast-math"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3050
+#, gcc-internal-format
+msgid "-mrecip requires -freciprocal-math or -ffast-math"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3150
+#, gcc-internal-format
+msgid "-m64 requires PowerPC64 architecture, enabling"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3260
+#, gcc-internal-format
+msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3407
+#, gcc-internal-format
+msgid "not configured for SPE ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3412
+#, gcc-internal-format
+msgid "not configured for SPE instruction set"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3418
+#, gcc-internal-format
+msgid "target attribute or pragma changes SPE ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3425
+#, gcc-internal-format
+msgid "AltiVec not supported in this target"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3427 config/rs6000/rs6000.c:3432
+#, gcc-internal-format
+msgid "SPE not supported in this target"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3460
+#, gcc-internal-format
+msgid "-mmultiple is not supported on little endian systems"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3467
+#, gcc-internal-format
+msgid "-mstring is not supported on little endian systems"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3560
+#, gcc-internal-format
+msgid "-mcrypto requires -maltivec"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3567
+#, gcc-internal-format
+msgid "-mdirect-move requires -mvsx"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3574
+#, gcc-internal-format
+msgid "-mpower8-vector requires -maltivec"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3581
+#, gcc-internal-format
+msgid "-mpower8-vector requires -mvsx"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3588
+#, gcc-internal-format
+msgid "-mvsx-timode requires -mvsx"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3595
+#, gcc-internal-format
+msgid "-mhard-dfp requires -mhard-float"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3636
+#, gcc-internal-format
+msgid "-mupper-regs-df requires -mvsx"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3643
+#, gcc-internal-format
+msgid "-mupper-regs-sf requires -mpower8-vector"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3748
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3760
+#, gcc-internal-format
+msgid "target attribute or pragma changes long double size"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3782 config/rs6000/rs6000.c:3797
+#, gcc-internal-format
+msgid "target attribute or pragma changes AltiVec ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3810
+#, gcc-internal-format
+msgid "target attribute or pragma changes darwin64 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3876
+#, gcc-internal-format
+msgid "target attribute or pragma changes single precision floating point"
+msgstr ""
+
+#: config/rs6000/rs6000.c:3879
+#, gcc-internal-format
+msgid "target attribute or pragma changes double precision floating point"
+msgstr ""
+
+#: config/rs6000/rs6000.c:6189
+#, gcc-internal-format, gfc-internal-format
+msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
+msgstr ""
+
+#: config/rs6000/rs6000.c:9264
+#, gcc-internal-format
+msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
+msgstr ""
+
+#: config/rs6000/rs6000.c:9415
+#, gcc-internal-format
+msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
+msgstr ""
+
+#: config/rs6000/rs6000.c:9573
+#, gcc-internal-format, gfc-internal-format
+msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
+msgstr ""
+
+#: config/rs6000/rs6000.c:9835
+#, gcc-internal-format
+msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
+msgstr ""
+
+#: config/rs6000/rs6000.c:10694
+#, gcc-internal-format
+msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
+msgstr ""
+
+#: config/rs6000/rs6000.c:10865
+#, gcc-internal-format
+msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
+msgstr ""
+
+#: config/rs6000/rs6000.c:11657
+#, gcc-internal-format, gfc-internal-format
+msgid "internal error: builtin function %s already processed"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12099
+#, gcc-internal-format
+msgid "argument 1 must be an 8-bit field value"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12146
+#, gcc-internal-format
+msgid "argument 1 must be a 5-bit signed literal"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
+#, gcc-internal-format
+msgid "argument 2 must be a 5-bit unsigned literal"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12288
+#, gcc-internal-format
+msgid "argument 1 of __builtin_altivec_predicate must be a constant"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12340
+#, gcc-internal-format
+msgid "argument 1 of __builtin_altivec_predicate is out of range"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12714
+#, gcc-internal-format, gfc-internal-format
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12763
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %d must be an unsigned literal"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12765
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %d is an unsigned literal that is out of range"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12928
+#, gcc-internal-format
+msgid "argument 3 must be a 4-bit unsigned literal"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12946
+#, gcc-internal-format
+msgid "argument 3 must be a 2-bit unsigned literal"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12966
+#, gcc-internal-format
+msgid "argument 3 must be a 1-bit unsigned literal"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12978
+#, gcc-internal-format
+msgid "argument 1 must be 0 or 2"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12990
+#, gcc-internal-format
+msgid "argument 1 must be a 1-bit unsigned literal"
+msgstr ""
+
+#: config/rs6000/rs6000.c:13004
+#, gcc-internal-format
+msgid "argument 2 must be a 6-bit unsigned literal"
+msgstr ""
+
+#: config/rs6000/rs6000.c:13016
+#, gcc-internal-format
+msgid "argument 2 must be 0 or 1"
+msgstr ""
+
+#: config/rs6000/rs6000.c:13023
+#, gcc-internal-format
+msgid "argument 3 must be in the range 0..15"
+msgstr ""
+
+#: config/rs6000/rs6000.c:13210
+#, gcc-internal-format
+msgid "argument to %qs must be a 2-bit unsigned literal"
+msgstr ""
+
+#: config/rs6000/rs6000.c:13363
+#, gcc-internal-format
+msgid "unresolved overload for Altivec builtin %qF"
+msgstr ""
+
+#: config/rs6000/rs6000.c:13493
+#, gcc-internal-format
+msgid "argument to dss must be a 2-bit unsigned literal"
+msgstr ""
+
+#: config/rs6000/rs6000.c:13860
+#, gcc-internal-format
+msgid "argument 1 of __builtin_paired_predicate must be a constant"
+msgstr ""
+
+#: config/rs6000/rs6000.c:13907
+#, gcc-internal-format
+msgid "argument 1 of __builtin_paired_predicate is out of range"
+msgstr ""
+
+#: config/rs6000/rs6000.c:13932
+#, gcc-internal-format
+msgid "argument 1 of __builtin_spe_predicate must be a constant"
+msgstr ""
+
+#: config/rs6000/rs6000.c:14004
+#, gcc-internal-format
+msgid "argument 1 of __builtin_spe_predicate is out of range"
+msgstr ""
+
+#: config/rs6000/rs6000.c:14086
+#, gcc-internal-format, gfc-internal-format
+msgid "Builtin function %s is only valid for the cell processor"
+msgstr ""
+
+#: config/rs6000/rs6000.c:14088
+#, gcc-internal-format, gfc-internal-format
+msgid "Builtin function %s requires the -mvsx option"
+msgstr ""
+
+#: config/rs6000/rs6000.c:14090
+#, gcc-internal-format, gfc-internal-format
+msgid "Builtin function %s requires the -mhtm option"
+msgstr ""
+
+#: config/rs6000/rs6000.c:14092
+#, gcc-internal-format, gfc-internal-format
+msgid "Builtin function %s requires the -maltivec option"
+msgstr ""
+
+#: config/rs6000/rs6000.c:14094
+#, gcc-internal-format, gfc-internal-format
+msgid "Builtin function %s requires the -mpaired option"
+msgstr ""
+
+#: config/rs6000/rs6000.c:14096
+#, gcc-internal-format, gfc-internal-format
+msgid "Builtin function %s requires the -mspe option"
+msgstr ""
+
+#: config/rs6000/rs6000.c:14099
+#, gcc-internal-format, gfc-internal-format
+msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
+msgstr ""
+
+#: config/rs6000/rs6000.c:14102
+#, gcc-internal-format, gfc-internal-format
+msgid "Builtin function %s requires the -mhard-dfp option"
+msgstr ""
+
+#: config/rs6000/rs6000.c:14104
+#, gcc-internal-format, gfc-internal-format
+msgid "Builtin function %s requires the -mpower8-vector option"
+msgstr ""
+
+#: config/rs6000/rs6000.c:14107
+#, gcc-internal-format, gfc-internal-format
+msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
+msgstr ""
+
+#: config/rs6000/rs6000.c:14110
+#, gcc-internal-format, gfc-internal-format
+msgid "Builtin function %s requires the -mhard-float option"
+msgstr ""
+
+#: config/rs6000/rs6000.c:14112
+#, gcc-internal-format, gfc-internal-format
+msgid "Builtin function %s is not supported with the current options"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15628
+#, gcc-internal-format, gfc-internal-format
+msgid "internal error: builtin function %s had no type"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15636
+#, gcc-internal-format, gfc-internal-format
+msgid "internal error: builtin function %s had an unexpected return type %s"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15653
+#, gcc-internal-format, gfc-internal-format
+msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
+msgstr ""
+
+#: config/rs6000/rs6000.c:22653
+#, gcc-internal-format
+msgid "stack frame too large"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26723
+#, gcc-internal-format
+msgid "no profiling of 64-bit code for this ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.c:28801
+#, gcc-internal-format
+msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
+msgstr ""
+
+#: config/rs6000/rs6000.c:28883
+#, gcc-internal-format
+msgid "use of %<long double%> in AltiVec types is invalid"
+msgstr ""
+
+#: config/rs6000/rs6000.c:28885
+#, gcc-internal-format
+msgid "use of boolean types in AltiVec types is invalid"
+msgstr ""
+
+#: config/rs6000/rs6000.c:28887
+#, gcc-internal-format
+msgid "use of %<complex%> in AltiVec types is invalid"
+msgstr ""
+
+#: config/rs6000/rs6000.c:28889
+#, gcc-internal-format
+msgid "use of decimal floating point types in AltiVec types is invalid"
+msgstr ""
+
+#: config/rs6000/rs6000.c:28895
+#, gcc-internal-format
+msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
+msgstr ""
+
+#: config/rs6000/rs6000.c:28898
+#, gcc-internal-format
+msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:28903
+#, gcc-internal-format
+msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
+msgstr ""
+
+#: config/rs6000/rs6000.c:28906
+#, gcc-internal-format
+msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
+msgstr ""
+
+#: config/rs6000/rs6000.c:32239
+#, gcc-internal-format, gfc-internal-format
+msgid "emitting microcode insn %s\t[%s] #%d"
+msgstr ""
+
+#: config/rs6000/rs6000.c:32243
+#, gcc-internal-format, gfc-internal-format
+msgid "emitting conditional microcode insn %s\t[%s] #%d"
+msgstr ""
+
+#: config/rs6000/rs6000.c:32533
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid cpu \"%s\" for %s\"%s\"%s"
+msgstr ""
+
+#: config/rs6000/rs6000.c:32536
+#, gcc-internal-format, gfc-internal-format
+msgid "%s\"%s\"%s is not allowed"
+msgstr ""
+
+#: config/rs6000/rs6000.c:32538
+#, gcc-internal-format, gfc-internal-format
+msgid "%s\"%s\"%s is invalid"
+msgstr ""
+
+#. Definitions of target machine for GNU compiler,
+#. for IBM RS/6000 POWER running AIX version 4.3.
+#. Copyright (C) 1998-2015 Free Software Foundation, Inc.
+#. Contributed by David Edelsohn (edelsohn@gnu.org).
+#.
+#. This file is part of GCC.
+#.
+#. GCC is free software; you can redistribute it and/or modify it
+#. under the terms of the GNU General Public License as published
+#. by the Free Software Foundation; either version 3, or (at your
+#. option) any later version.
+#.
+#. GCC is distributed in the hope that it will be useful, but WITHOUT
+#. ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+#. or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
+#. License for more details.
+#.
+#. You should have received a copy of the GNU General Public License
+#. along with GCC; see the file COPYING3.  If not see
+#. <http://www.gnu.org/licenses/>.
+#. The macro SUBTARGET_OVERRIDE_OPTIONS is provided for subtargets, to
+#. get control in TARGET_OPTION_OVERRIDE.
+#. Definitions of target machine for GNU compiler,
+#. for IBM RS/6000 POWER running AIX V5.
+#. Copyright (C) 2001-2015 Free Software Foundation, Inc.
+#. Contributed by David Edelsohn (edelsohn@gnu.org).
+#.
+#. This file is part of GCC.
+#.
+#. GCC is free software; you can redistribute it and/or modify it
+#. under the terms of the GNU General Public License as published
+#. by the Free Software Foundation; either version 3, or (at your
+#. option) any later version.
+#.
+#. GCC is distributed in the hope that it will be useful, but WITHOUT
+#. ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+#. or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
+#. License for more details.
+#.
+#. You should have received a copy of the GNU General Public License
+#. along with GCC; see the file COPYING3.  If not see
+#. <http://www.gnu.org/licenses/>.
+#. The macro SUBTARGET_OVERRIDE_OPTIONS is provided for subtargets, to
+#. get control in TARGET_OPTION_OVERRIDE.
+#. Definitions of target machine for GNU compiler,
+#. for IBM RS/6000 POWER running AIX V5.2.
+#. Copyright (C) 2002-2015 Free Software Foundation, Inc.
+#. Contributed by David Edelsohn (edelsohn@gnu.org).
+#.
+#. This file is part of GCC.
+#.
+#. GCC is free software; you can redistribute it and/or modify it
+#. under the terms of the GNU General Public License as published
+#. by the Free Software Foundation; either version 3, or (at your
+#. option) any later version.
+#.
+#. GCC is distributed in the hope that it will be useful, but WITHOUT
+#. ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+#. or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
+#. License for more details.
+#.
+#. You should have received a copy of the GNU General Public License
+#. along with GCC; see the file COPYING3.  If not see
+#. <http://www.gnu.org/licenses/>.
+#. The macro SUBTARGET_OVERRIDE_OPTIONS is provided for subtargets, to
+#. get control in TARGET_OPTION_OVERRIDE.
+#. Definitions of target machine for GNU compiler,
+#. for IBM RS/6000 POWER running AIX V5.3.
+#. Copyright (C) 2002-2015 Free Software Foundation, Inc.
+#. Contributed by David Edelsohn (edelsohn@gnu.org).
+#.
+#. This file is part of GCC.
+#.
+#. GCC is free software; you can redistribute it and/or modify it
+#. under the terms of the GNU General Public License as published
+#. by the Free Software Foundation; either version 3, or (at your
+#. option) any later version.
+#.
+#. GCC is distributed in the hope that it will be useful, but WITHOUT
+#. ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+#. or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
+#. License for more details.
+#.
+#. You should have received a copy of the GNU General Public License
+#. along with GCC; see the file COPYING3.  If not see
+#. <http://www.gnu.org/licenses/>.
+#. The macro SUBTARGET_OVERRIDE_OPTIONS is provided for subtargets, to
+#. get control in TARGET_OPTION_OVERRIDE.
+#. Definitions of target machine for GNU compiler,
+#. for IBM RS/6000 POWER running AIX V6.1.
+#. Copyright (C) 2002-2015 Free Software Foundation, Inc.
+#. Contributed by David Edelsohn (edelsohn@gnu.org).
+#.
+#. This file is part of GCC.
+#.
+#. GCC is free software; you can redistribute it and/or modify it
+#. under the terms of the GNU General Public License as published
+#. by the Free Software Foundation; either version 3, or (at your
+#. option) any later version.
+#.
+#. GCC is distributed in the hope that it will be useful, but WITHOUT
+#. ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+#. or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
+#. License for more details.
+#.
+#. You should have received a copy of the GNU General Public License
+#. along with GCC; see the file COPYING3.  If not see
+#. <http://www.gnu.org/licenses/>.
+#. The macro SUBTARGET_OVERRIDE_OPTIONS is provided for subtargets, to
+#. get control in TARGET_OPTION_OVERRIDE.
+#: config/rs6000/aix43.h:30 config/rs6000/aix51.h:30 config/rs6000/aix52.h:30
+#: config/rs6000/aix53.h:30 config/rs6000/aix61.h:30
+#, gcc-internal-format
+msgid "-maix64 requires PowerPC64 architecture remain enabled"
+msgstr ""
+
+#: config/rs6000/aix43.h:36 config/rs6000/aix52.h:36 config/rs6000/aix53.h:36
+#: config/rs6000/aix61.h:36
+#, gcc-internal-format
+msgid "soft-float and long-double-128 are incompatible"
+msgstr ""
+
+#: config/rs6000/aix43.h:40 config/rs6000/aix51.h:34 config/rs6000/aix52.h:40
+#: config/rs6000/aix53.h:40 config/rs6000/aix61.h:40
+#, gcc-internal-format
+msgid "-maix64 required: 64-bit computation with 32-bit addressing not yet supported"
+msgstr ""
+
+#: config/rs6000/aix61.h:47 config/rs6000/freebsd64.h:107
+#: config/rs6000/linux64.h:139
+#, gcc-internal-format
+msgid "-mcmodel incompatible with other toc options"
+msgstr ""
+
+#: config/rs6000/e500.h:37
+#, gcc-internal-format
+msgid "AltiVec and SPE instructions cannot coexist"
+msgstr ""
+
+#: config/rs6000/e500.h:39
+#, gcc-internal-format
+msgid "VSX and SPE instructions cannot coexist"
+msgstr ""
+
+#: config/rs6000/e500.h:41
+#, gcc-internal-format
+msgid "64-bit SPE not supported"
+msgstr ""
+
+#: config/rs6000/e500.h:43
+#, gcc-internal-format
+msgid "E500 and FPRs not supported"
+msgstr ""
+
+#: config/rs6000/freebsd64.h:100 config/rs6000/linux64.h:132
+#, gcc-internal-format
+msgid "-m64 requires a PowerPC64 cpu"
+msgstr ""
+
+#: config/rs6000/linux64.h:112
+#, gcc-internal-format
+msgid "-mcall-aixdesc incompatible with -mabi=elfv2"
+msgstr ""
+
+#. The macro SUBTARGET_OVERRIDE_OPTIONS is provided for subtargets, to
+#. get control in TARGET_OPTION_OVERRIDE.
+#: config/rs6000/sysv4.h:113
+#, gcc-internal-format, gfc-internal-format
+msgid "bad value for -mcall-%s"
+msgstr ""
+
+#: config/rs6000/sysv4.h:129
+#, gcc-internal-format, gfc-internal-format
+msgid "bad value for -msdata=%s"
+msgstr ""
+
+#: config/rs6000/sysv4.h:146
+#, gcc-internal-format, gfc-internal-format
+msgid "-mrelocatable and -msdata=%s are incompatible"
+msgstr ""
+
+#: config/rs6000/sysv4.h:155
+#, gcc-internal-format, gfc-internal-format
+msgid "-f%s and -msdata=%s are incompatible"
+msgstr ""
+
+#: config/rs6000/sysv4.h:164
+#, gcc-internal-format, gfc-internal-format
+msgid "-msdata=%s and -mcall-%s are incompatible"
+msgstr ""
+
+#: config/rs6000/sysv4.h:173
+#, gcc-internal-format
+msgid "-mrelocatable and -mno-minimal-toc are incompatible"
+msgstr ""
+
+#: config/rs6000/sysv4.h:179
+#, gcc-internal-format, gfc-internal-format
+msgid "-mrelocatable and -mcall-%s are incompatible"
+msgstr ""
+
+#: config/rs6000/sysv4.h:186
+#, gcc-internal-format, gfc-internal-format
+msgid "-fPIC and -mcall-%s are incompatible"
+msgstr ""
+
+#: config/rs6000/sysv4.h:192
+#, gcc-internal-format
+msgid "-msecure-plt not supported by your assembler"
+msgstr ""
+
+#: config/rs6000/sysv4.h:211
+#, gcc-internal-format, gfc-internal-format
+msgid "-m%s not supported in this configuration"
+msgstr ""
+
+#: config/rx/rx.c:677
+#, gcc-internal-format, gfc-internal-format
+msgid "unrecognized control register number: %d - using 'psw'"
+msgstr ""
+
+#: config/rx/rx.c:1413
+#, gcc-internal-format
+msgid "multiple fast interrupt routines seen: %qE and %qE"
+msgstr ""
+
+#: config/rx/rx.c:2578
+#, gcc-internal-format, gfc-internal-format
+msgid "__builtin_rx_%s takes 'C', 'Z', 'S', 'O', 'I', or 'U'"
+msgstr ""
+
+#: config/rx/rx.c:2580
+#, gcc-internal-format
+msgid "use __builtin_rx_mvtc (0, ... ) to write arbitrary values to PSW"
+msgstr ""
+
+#: config/rx/rx.c:2769
+#, gcc-internal-format
+msgid "RX FPU instructions do not support NaNs and infinities"
+msgstr ""
+
+#: config/s390/s390.c:503
+#, gcc-internal-format
+msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
+msgstr ""
+
+#: config/s390/s390.c:7794
+#, gcc-internal-format
+msgid "total size of local variables exceeds architecture limit"
+msgstr ""
+
+#: config/s390/s390.c:8794
+#, gcc-internal-format
+msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
+msgstr ""
+
+#: config/s390/s390.c:8809
+#, gcc-internal-format
+msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
+msgstr ""
+
+#: config/s390/s390.c:8837
+#, gcc-internal-format
+msgid "frame size of %qs is %wd bytes"
+msgstr ""
+
+#: config/s390/s390.c:8841
+#, gcc-internal-format
+msgid "%qs uses dynamic stack allocation"
+msgstr ""
+
+#: config/s390/s390.c:10106
+#, gcc-internal-format
+msgid "Transactional execution builtins not enabled (-mhtm)\n"
+msgstr ""
+
+#. argument is not a plain number
+#: config/s390/s390.c:11945
+#, gcc-internal-format
+msgid "arguments to %qs should be non-negative integers"
+msgstr ""
+
+#: config/s390/s390.c:11952
+#, gcc-internal-format
+msgid "argument to %qs is too large (max. %d)"
+msgstr ""
+
+#: config/s390/s390.c:11995
+#, gcc-internal-format, gfc-internal-format
+msgid "z/Architecture mode not supported on %s"
+msgstr ""
+
+#: config/s390/s390.c:11997
+#, gcc-internal-format
+msgid "64-bit ABI not supported in ESA/390 mode"
+msgstr ""
+
+#: config/s390/s390.c:12014
+#, gcc-internal-format, gfc-internal-format
+msgid "hardware decimal floating point instructions not available on %s"
+msgstr ""
+
+#: config/s390/s390.c:12017
+#, gcc-internal-format
+msgid "hardware decimal floating point instructions not available in ESA/390 mode"
+msgstr ""
+
+#: config/s390/s390.c:12027
+#, gcc-internal-format
+msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
+msgstr ""
+
+#: config/s390/s390.c:12055
+#, gcc-internal-format
+msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
+msgstr ""
+
+#: config/s390/s390.c:12061
+#, gcc-internal-format
+msgid "stack size must be greater than the stack guard value"
+msgstr ""
+
+#: config/s390/s390.c:12063
+#, gcc-internal-format
+msgid "stack size must not be greater than 64k"
+msgstr ""
+
+#: config/s390/s390.c:12066
+#, gcc-internal-format
+msgid "-mstack-guard implies use of -mstack-size"
+msgstr ""
+
+#: config/sh/sh.c:1046
+#, gcc-internal-format
+msgid "ignoring -fschedule-insns because of exception handling bug"
+msgstr ""
+
+#: config/sh/sh.c:1063
+#, gcc-internal-format
+msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
+msgstr ""
+
+#: config/sh/sh.c:8418
+#, gcc-internal-format
+msgid "__builtin_saveregs not supported by this subtarget"
+msgstr ""
+
+#: config/sh/sh.c:9621
+#, gcc-internal-format
+msgid "%qE attribute only applies to interrupt functions"
+msgstr ""
+
+#: config/sh/sh.c:9691
+#, gcc-internal-format
+msgid "%qE attribute is supported only for SH2A"
+msgstr ""
+
+#: config/sh/sh.c:9721
+#, gcc-internal-format
+msgid "attribute interrupt_handler is not compatible with -m5-compact"
+msgstr ""
+
+#: config/sh/sh.c:9738
+#, gcc-internal-format
+msgid "%qE attribute only applies to SH2A"
+msgstr ""
+
+#: config/sh/sh.c:9760
+#, gcc-internal-format
+msgid "%qE attribute argument should be between 0 to 255"
+msgstr ""
+
+#. The argument must be a constant string.
+#: config/sh/sh.c:9833
+#, gcc-internal-format
+msgid "%qE attribute argument not a string constant"
+msgstr ""
+
+#: config/sh/sh.c:12596
+#, gcc-internal-format
+msgid "r0 needs to be available as a call-clobbered register"
+msgstr ""
+
+#: config/sh/sh.c:12617
+#, gcc-internal-format
+msgid "need a second call-clobbered general purpose register"
+msgstr ""
+
+#: config/sh/sh.c:12625
+#, gcc-internal-format
+msgid "need a call-clobbered target register"
+msgstr ""
+
+#. FIXME
+#: config/sh/netbsd-elf.h:73
+#, gcc-internal-format
+msgid "unimplemented-shmedia profiling"
+msgstr ""
+
+#. The kernel loader cannot handle the relaxation			 relocations, so it cannot load kernel modules			 (which are ET_REL) or RTP executables (which are		 linked with --emit-relocs).  No relaxation relocations		 appear in shared libraries, so relaxation is OK		 for RTP PIC.
+#: config/sh/vxworks.h:43
+#, gcc-internal-format
+msgid "-mrelax is only supported for RTP PIC"
+msgstr ""
+
+#: config/sparc/sparc.c:1384
+#, gcc-internal-format, gfc-internal-format
+msgid "%s is not supported by this configuration"
+msgstr ""
+
+#: config/sparc/sparc.c:1391
+#, gcc-internal-format
+msgid "-mlong-double-64 not allowed with -m64"
+msgstr ""
+
+#: config/sparc/sparc.c:1411
+#, gcc-internal-format, gfc-internal-format
+msgid "bad value (%s) for -mcmodel= switch"
+msgstr ""
+
+#: config/sparc/sparc.c:1416
+#, gcc-internal-format
+msgid "-mcmodel= is not supported on 32 bit systems"
+msgstr ""
+
+#: config/sparc/sparc.c:1423
+#, gcc-internal-format
+msgid "-fcall-saved-REG is not supported for out registers"
+msgstr ""
+
+#: config/spu/spu-c.c:145
+#, gcc-internal-format, gfc-internal-format
+msgid "insufficient arguments to overloaded function %s"
+msgstr ""
+
+#: config/spu/spu-c.c:176
+#, gcc-internal-format, gfc-internal-format
+msgid "too many arguments to overloaded function %s"
+msgstr ""
+
+#: config/spu/spu-c.c:188
+#, gcc-internal-format, gfc-internal-format
+msgid "parameter list does not match a valid signature for %s()"
+msgstr ""
+
+#: config/spu/spu.c:291
+#, gcc-internal-format, gfc-internal-format
+msgid "bad value (%s) for -march= switch"
+msgstr ""
+
+#: config/spu/spu.c:302
+#, gcc-internal-format, gfc-internal-format
+msgid "bad value (%s) for -mtune= switch"
+msgstr ""
+
+#: config/spu/spu.c:5225 config/spu/spu.c:5228
+#, gcc-internal-format
+msgid "creating run-time relocation for %qD"
+msgstr ""
+
+#: config/spu/spu.c:5233 config/spu/spu.c:5235
+#, gcc-internal-format
+msgid "creating run-time relocation"
+msgstr ""
+
+#: config/spu/spu.c:6370
+#, gcc-internal-format, gfc-internal-format
+msgid "%s expects an integer literal in the range [%d, %d]"
+msgstr ""
+
+#: config/spu/spu.c:6390
+#, gcc-internal-format
+msgid "%s expects an integer literal in the range [%d, %d]. (%wd)"
+msgstr ""
+
+#: config/spu/spu.c:6419
+#, gcc-internal-format, gfc-internal-format
+msgid "%d least significant bits of %s are ignored"
+msgstr ""
+
+#: config/stormy16/stormy16.c:1082
+#, gcc-internal-format
+msgid "local variable memory requirements exceed capacity"
+msgstr ""
+
+#: config/stormy16/stormy16.c:1241
+#, gcc-internal-format
+msgid "function_profiler support"
+msgstr ""
+
+#: config/stormy16/stormy16.c:1335
+#, gcc-internal-format
+msgid "cannot use va_start in interrupt function"
+msgstr ""
+
+#: config/stormy16/stormy16.c:1902
+#, gcc-internal-format, gfc-internal-format
+msgid "switch statement of size %lu entries too large"
+msgstr ""
+
+#: config/stormy16/stormy16.c:2274
+#, gcc-internal-format
+msgid "%<__BELOW100__%> attribute only applies to variables"
+msgstr ""
+
+#: config/stormy16/stormy16.c:2281
+#, gcc-internal-format
+msgid "__BELOW100__ attribute not allowed with auto storage class"
+msgstr ""
+
+#: config/tilegx/tilegx.c:3582 config/tilepro/tilepro.c:3150
+#, gcc-internal-format
+msgid "bad builtin icode"
+msgstr ""
+
+#: config/tilegx/tilegx.c:3623 config/tilepro/tilepro.c:3176
+#, gcc-internal-format
+msgid "operand must be an immediate of the right size"
+msgstr ""
+
+#: config/v850/v850-c.c:77
+#, gcc-internal-format
+msgid "#pragma GHS endXXXX found without previous startXXX"
+msgstr ""
+
+#: config/v850/v850-c.c:80
+#, gcc-internal-format
+msgid "#pragma GHS endXXX does not match previous startXXX"
+msgstr ""
+
+#: config/v850/v850-c.c:106
+#, gcc-internal-format
+msgid "cannot set interrupt attribute: no current function"
+msgstr ""
+
+#: config/v850/v850-c.c:114
+#, gcc-internal-format
+msgid "cannot set interrupt attribute: no such identifier"
+msgstr ""
+
+#: config/v850/v850-c.c:163
+#, gcc-internal-format
+msgid "junk at end of #pragma ghs section"
+msgstr ""
+
+#: config/v850/v850-c.c:180
+#, gcc-internal-format
+msgid "unrecognized section name %qE"
+msgstr ""
+
+#: config/v850/v850-c.c:194
+#, gcc-internal-format
+msgid "malformed #pragma ghs section"
+msgstr ""
+
+#: config/v850/v850-c.c:213
+#, gcc-internal-format
+msgid "junk at end of #pragma ghs interrupt"
+msgstr ""
+
+#: config/v850/v850-c.c:224
+#, gcc-internal-format
+msgid "junk at end of #pragma ghs starttda"
+msgstr ""
+
+#: config/v850/v850-c.c:235
+#, gcc-internal-format
+msgid "junk at end of #pragma ghs startsda"
+msgstr ""
+
+#: config/v850/v850-c.c:246
+#, gcc-internal-format
+msgid "junk at end of #pragma ghs startzda"
+msgstr ""
+
+#: config/v850/v850-c.c:257
+#, gcc-internal-format
+msgid "junk at end of #pragma ghs endtda"
+msgstr ""
+
+#: config/v850/v850-c.c:268
+#, gcc-internal-format
+msgid "junk at end of #pragma ghs endsda"
+msgstr ""
+
+#: config/v850/v850-c.c:279
+#, gcc-internal-format
+msgid "junk at end of #pragma ghs endzda"
+msgstr ""
+
+#: config/v850/v850.c:2154
+#, gcc-internal-format
+msgid "data area attributes cannot be specified for local variables"
+msgstr ""
+
+#: config/v850/v850.c:2165
+#, gcc-internal-format
+msgid "data area of %q+D conflicts with previous declaration"
+msgstr ""
+
+#: config/v850/v850.c:2296
+#, gcc-internal-format, gfc-internal-format
+msgid "bogus JR construction: %d"
+msgstr ""
+
+#: config/v850/v850.c:2314 config/v850/v850.c:2421
+#, gcc-internal-format, gfc-internal-format
+msgid "bad amount of stack space removal: %d"
+msgstr ""
+
+#: config/v850/v850.c:2401
+#, gcc-internal-format, gfc-internal-format
+msgid "bogus JARL construction: %d"
+msgstr ""
+
+#: config/v850/v850.c:2698
+#, gcc-internal-format, gfc-internal-format
+msgid "bogus DISPOSE construction: %d"
+msgstr ""
+
+#: config/v850/v850.c:2717
+#, gcc-internal-format, gfc-internal-format
+msgid "too much stack space to dispose of: %d"
+msgstr ""
+
+#: config/v850/v850.c:2819
+#, gcc-internal-format, gfc-internal-format
+msgid "bogus PREPEARE construction: %d"
+msgstr ""
+
+#: config/v850/v850.c:2836
+#, gcc-internal-format, gfc-internal-format
+msgid "too much stack space to prepare: %d"
+msgstr ""
+
+#: config/visium/visium.c:659
+#, gcc-internal-format
+msgid "an interrupt handler cannot be compiled with -muser-mode"
+msgstr ""
+
+#: config/vms/vms-c.c:53
+#, gcc-internal-format
+msgid "junk at end of #pragma __nostandard"
+msgstr ""
+
+#: config/vms/vms-c.c:64
+#, gcc-internal-format
+msgid "junk at end of #pragma __standard"
+msgstr ""
+
+#: config/vms/vms-c.c:89
+#, gcc-internal-format
+msgid "malformed '#pragma member_alignment', ignoring"
+msgstr ""
+
+#: config/vms/vms-c.c:104
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown '#pragma member_alignment' name %s"
+msgstr ""
+
+#: config/vms/vms-c.c:109
+#, gcc-internal-format
+msgid "malformed '#pragma member_alignment'"
+msgstr ""
+
+#: config/vms/vms-c.c:143
+#, gcc-internal-format
+msgid "unhandled alignment for '#pragma nomember_alignment'"
+msgstr ""
+
+#: config/vms/vms-c.c:156
+#, gcc-internal-format
+msgid "garbage at end of '#pragma nomember_alignment'"
+msgstr ""
+
+#: config/vms/vms-c.c:211
+#, gcc-internal-format
+msgid "malformed '#pragma extern_model', ignoring"
+msgstr ""
+
+#: config/vms/vms-c.c:232
+#, gcc-internal-format
+msgid "extern model globalvalue"
+msgstr ""
+
+#: config/vms/vms-c.c:237
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown '#pragma extern_model' model '%s'"
+msgstr ""
+
+#: config/vms/vms-c.c:243
+#, gcc-internal-format
+msgid "junk at end of '#pragma extern_model'"
+msgstr ""
+
+#: config/vms/vms-c.c:257
+#, gcc-internal-format
+msgid "vms '#pragma __message' is ignored"
+msgstr ""
+
+#: config/vms/vms-c.c:282 config/vms/vms-c.c:288
+#, gcc-internal-format
+msgid "malformed '#pragma __extern_prefix', ignoring"
+msgstr ""
+
+#: config/vms/vms-c.c:321 config/vms/vms-c.c:341
+#, gcc-internal-format
+msgid "malformed %<#pragma %s%>, ignoring"
+msgstr ""
+
+#: config/vms/vms-c.c:337
+#, gcc-internal-format
+msgid "invalid constant in %<#pragma %s%>"
+msgstr ""
+
+#: config/xtensa/xtensa.c:2213
+#, gcc-internal-format
+msgid "boolean registers required for the floating-point option"
+msgstr ""
+
+#: config/xtensa/xtensa.c:2248
+#, gcc-internal-format, gfc-internal-format
+msgid "-f%s is not supported with CONST16 instructions"
+msgstr ""
+
+#: config/xtensa/xtensa.c:2255
+#, gcc-internal-format
+msgid "PIC is required but not supported with CONST16 instructions"
+msgstr ""
+
+#: config/xtensa/xtensa.c:3539
+#, gcc-internal-format
+msgid "only uninitialized variables can be placed in a .bss section"
+msgstr ""
+
+#: ada/gcc-interface/decl.c:2219 ada/gcc-interface/decl.c:2955
+#, gcc-internal-format
+msgid "non-default Scalar_Storage_Order"
+msgstr ""
+
+#: ada/gcc-interface/misc.c:158
+#, gcc-internal-format
+msgid "%<-gnat%> misspelled as %<-gant%>"
+msgstr ""
+
+#: ada/gcc-interface/misc.c:269
+#, gcc-internal-format
+msgid "-fexcess-precision=standard for Ada"
+msgstr ""
+
+#: ada/gcc-interface/trans.c:1529
+#, gcc-internal-format
+msgid "subprogram %q+F not marked Inline_Always"
+msgstr ""
+
+#: ada/gcc-interface/trans.c:1530 ada/gcc-interface/trans.c:1536
+#, gcc-internal-format
+msgid "parent subprogram cannot be inlined"
+msgstr ""
+
+#: ada/gcc-interface/trans.c:1534
+#, gcc-internal-format
+msgid "subprogram %q+F not marked Inline"
+msgstr ""
+
+#: ada/gcc-interface/utils.c:3634
+#, gcc-internal-format
+msgid "invalid element type for attribute %qs"
+msgstr ""
+
+#: ada/gcc-interface/utils.c:3658
+#, gcc-internal-format
+msgid "number of components of vector not a power of two"
+msgstr ""
+
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
+#, gcc-internal-format
+msgid "%qs attribute ignored"
+msgstr ""
+
+#: ada/gcc-interface/utils.c:5740
+#, gcc-internal-format
+msgid "%qs attribute requires prototypes with named arguments"
+msgstr ""
+
+#: ada/gcc-interface/utils.c:5749
+#, gcc-internal-format
+msgid "%qs attribute only applies to variadic functions"
+msgstr ""
+
+#: ada/gcc-interface/utils.c:5819
+#, gcc-internal-format
+msgid "%qE attribute has no effect"
+msgstr ""
+
+#: ada/gcc-interface/utils.c:5943
+#, gcc-internal-format
+msgid "attribute %qs applies to array types only"
+msgstr ""
+
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
+#: cp/cp-array-notation.c:264
+#, gcc-internal-format
+msgid "Invalid builtin arguments"
+msgstr ""
+
+#: c/c-array-notation.c:265 cp/cp-array-notation.c:271
+#, gcc-internal-format
+msgid "__sec_reduce_min_ind or __sec_reduce_max_ind cannot have arrays with dimension greater than 1"
+msgstr ""
+
+#: c/c-array-notation.c:731 c/c-array-notation.c:737
+#: cp/cp-array-notation.c:620
+#, gcc-internal-format
+msgid "%qE cannot be scalar when %qE is not"
+msgstr ""
+
+#: c/c-array-notation.c:799 cp/cp-array-notation.c:673
+#, gcc-internal-format
+msgid "length mismatch between LHS and RHS"
+msgstr ""
+
+#: c/c-array-notation.c:1360 cp/cp-array-notation.c:1437
+#, gcc-internal-format
+msgid "start-index of array notation triplet is not an integer"
+msgstr ""
+
+#: c/c-array-notation.c:1365 cp/cp-array-notation.c:1442
+#, gcc-internal-format
+msgid "length of array notation triplet is not an integer"
+msgstr ""
+
+#: c/c-array-notation.c:1372 cp/cp-array-notation.c:1447
+#, gcc-internal-format
+msgid "stride of array notation triplet is not an integer"
+msgstr ""
+
+#: c/c-array-notation.c:1393
+#, gcc-internal-format
+msgid "rank of an array notation triplet's start-index is not zero"
+msgstr ""
+
+#: c/c-array-notation.c:1399
+#, gcc-internal-format
+msgid "rank of an array notation triplet's length is not zero"
+msgstr ""
+
+#: c/c-array-notation.c:1404
+#, gcc-internal-format
+msgid "rank of array notation triplet's stride is not zero"
+msgstr ""
+
+#. Except for passing an argument to an unprototyped function,
+#. this is a constraint violation.  When passing an argument to
+#. an unprototyped function, it is compile-time undefined;
+#. making it a constraint in that case was rejected in
+#. DR#252.
+#: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
+#, gcc-internal-format
+msgid "void value not ignored as it ought to be"
+msgstr ""
+
+#: c/c-convert.c:211 java/typeck.c:161
+#, gcc-internal-format
+msgid "conversion to non-scalar type requested"
+msgstr ""
+
+#: c/c-decl.c:843
+#, gcc-internal-format
+msgid "array %q+D assumed to have one element"
+msgstr ""
+
+#: c/c-decl.c:884
+#, gcc-internal-format
+msgid "%qD is static but used in inline function %qD which is not static"
+msgstr ""
+
+#: c/c-decl.c:889
+#, gcc-internal-format
+msgid "%q+D is static but declared in inline function %qD which is not static"
+msgstr ""
+
+#: c/c-decl.c:1074
+#, gcc-internal-format, gfc-internal-format
+msgid "GCC supports only %u nested scopes"
+msgstr ""
+
+#: c/c-decl.c:1225 cp/decl.c:391
+#, gcc-internal-format
+msgid "label %q+D used but not defined"
+msgstr ""
+
+#: c/c-decl.c:1270
+#, gcc-internal-format
+msgid "nested function %q+D declared but never defined"
+msgstr ""
+
+#: c/c-decl.c:1284
+#, gcc-internal-format
+msgid "inline function %q+D declared but never defined"
+msgstr ""
+
+#: c/c-decl.c:1301 cp/decl.c:658
+#, gcc-internal-format
+msgid "unused variable %q+D"
+msgstr ""
+
+#: c/c-decl.c:1305
+#, gcc-internal-format
+msgid "variable %qD set but not used"
+msgstr ""
+
+#: c/c-decl.c:1310
+#, gcc-internal-format
+msgid "type of array %q+D completed incompatibly with implicit initialization"
+msgstr ""
+
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
+#, gcc-internal-format
+msgid "originally defined here"
+msgstr ""
+
+#: c/c-decl.c:1707
+#, gcc-internal-format
+msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
+msgstr ""
+
+#: c/c-decl.c:1714
+#, gcc-internal-format
+msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
+msgstr ""
+
+#: c/c-decl.c:1761
+#, gcc-internal-format
+msgid "prototype for %q+D declares more arguments than previous old-style definition"
+msgstr ""
+
+#: c/c-decl.c:1767
+#, gcc-internal-format
+msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
+msgstr ""
+
+#: c/c-decl.c:1776
+#, gcc-internal-format
+msgid "prototype for %q+D declares argument %d with incompatible type"
+msgstr ""
+
+#. If we get here, no errors were found, but do issue a warning
+#. for this poor-style construct.
+#: c/c-decl.c:1789
+#, gcc-internal-format
+msgid "prototype for %q+D follows non-prototype definition"
+msgstr ""
+
+#: c/c-decl.c:1805
+#, gcc-internal-format
+msgid "previous definition of %q+D was here"
+msgstr ""
+
+#: c/c-decl.c:1807
+#, gcc-internal-format
+msgid "previous implicit declaration of %q+D was here"
+msgstr ""
+
+#: c/c-decl.c:1809
+#, gcc-internal-format
+msgid "previous declaration of %q+D was here"
+msgstr ""
+
+#: c/c-decl.c:1849
+#, gcc-internal-format
+msgid "%q+D redeclared as different kind of symbol"
+msgstr ""
+
+#: c/c-decl.c:1853
+#, gcc-internal-format
+msgid "built-in function %q+D declared as non-function"
+msgstr ""
+
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
+#, gcc-internal-format
+msgid "declaration of %q+D shadows a built-in function"
+msgstr ""
+
+#: c/c-decl.c:1865
+#, gcc-internal-format
+msgid "redeclaration of enumerator %q+D"
+msgstr ""
+
+#. If types don't match for a built-in, throw away the
+#. built-in.  No point in calling locate_old_decl here, it
+#. won't print anything.
+#: c/c-decl.c:1886
+#, gcc-internal-format
+msgid "conflicting types for built-in function %q+D"
+msgstr ""
+
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
+#, gcc-internal-format
+msgid "conflicting types for %q+D"
+msgstr ""
+
+#: c/c-decl.c:1940
+#, gcc-internal-format
+msgid "conflicting named address spaces (generic vs %s) for %q+D"
+msgstr ""
+
+#: c/c-decl.c:1944
+#, gcc-internal-format
+msgid "conflicting named address spaces (%s vs generic) for %q+D"
+msgstr ""
+
+#: c/c-decl.c:1948
+#, gcc-internal-format
+msgid "conflicting named address spaces (%s vs %s) for %q+D"
+msgstr ""
+
+#: c/c-decl.c:1957
+#, gcc-internal-format
+msgid "conflicting type qualifiers for %q+D"
+msgstr ""
+
+#: c/c-decl.c:1982
+#, gcc-internal-format
+msgid "redefinition of typedef %q+D with different type"
+msgstr ""
+
+#: c/c-decl.c:1995
+#, gcc-internal-format
+msgid "redefinition of typedef %q+D with variably modified type"
+msgstr ""
+
+#: c/c-decl.c:2000
+#, gcc-internal-format
+msgid "redefinition of typedef %q+D"
+msgstr ""
+
+#: c/c-decl.c:2052 c/c-decl.c:2155
+#, gcc-internal-format
+msgid "redefinition of %q+D"
+msgstr ""
+
+#: c/c-decl.c:2087 c/c-decl.c:2193
+#, gcc-internal-format
+msgid "static declaration of %q+D follows non-static declaration"
+msgstr ""
+
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
+#, gcc-internal-format
+msgid "non-static declaration of %q+D follows static declaration"
+msgstr ""
+
+#: c/c-decl.c:2121
+#, gcc-internal-format
+msgid "%<gnu_inline%> attribute present on %q+D"
+msgstr ""
+
+#: c/c-decl.c:2124
+#, gcc-internal-format
+msgid "but not here"
+msgstr ""
+
+#: c/c-decl.c:2142
+#, gcc-internal-format
+msgid "thread-local declaration of %q+D follows non-thread-local declaration"
+msgstr ""
+
+#: c/c-decl.c:2145
+#, gcc-internal-format
+msgid "non-thread-local declaration of %q+D follows thread-local declaration"
+msgstr ""
+
+#: c/c-decl.c:2175
+#, gcc-internal-format
+msgid "extern declaration of %q+D follows declaration with no linkage"
+msgstr ""
+
+#: c/c-decl.c:2211
+#, gcc-internal-format
+msgid "declaration of %q+D with no linkage follows extern declaration"
+msgstr ""
+
+#: c/c-decl.c:2217
+#, gcc-internal-format
+msgid "redeclaration of %q+D with no linkage"
+msgstr ""
+
+#: c/c-decl.c:2243
+#, gcc-internal-format
+msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
+msgstr ""
+
+#: c/c-decl.c:2253
+#, gcc-internal-format
+msgid "inline declaration of %qD follows declaration with attribute noinline"
+msgstr ""
+
+#: c/c-decl.c:2258
+#, gcc-internal-format
+msgid "declaration of %q+D with attribute noinline follows inline declaration "
+msgstr ""
+
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
+#, gcc-internal-format
+msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
+msgstr ""
+
+#: c/c-decl.c:2299
+#, gcc-internal-format
+msgid "redefinition of parameter %q+D"
+msgstr ""
+
+#: c/c-decl.c:2326
+#, gcc-internal-format
+msgid "redundant redeclaration of %q+D"
+msgstr ""
+
+#: c/c-decl.c:2777
+#, gcc-internal-format
+msgid "declaration of %q+D shadows previous non-variable"
+msgstr ""
+
+#: c/c-decl.c:2783
+#, gcc-internal-format
+msgid "declaration of %q+D shadows a parameter"
+msgstr ""
+
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
+#, gcc-internal-format
+msgid "declaration of %qD shadows a global declaration"
+msgstr ""
+
+#: c/c-decl.c:2807
+#, gcc-internal-format
+msgid "declaration of %q+D shadows a previous local"
+msgstr ""
+
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: cp/name-lookup.c:1287
+#, gcc-internal-format
+msgid "shadowed declaration is here"
+msgstr ""
+
+#: c/c-decl.c:2939
+#, gcc-internal-format
+msgid "nested extern declaration of %qD"
+msgstr ""
+
+#: c/c-decl.c:3115 c/c-decl.c:3118
+#, gcc-internal-format
+msgid "implicit declaration of function %qE"
+msgstr ""
+
+#: c/c-decl.c:3364
+#, gcc-internal-format
+msgid "incompatible implicit declaration of built-in function %qD"
+msgstr ""
+
+#: c/c-decl.c:3371
+#, gcc-internal-format
+msgid "include %qs or provide a declaration of %qD"
+msgstr ""
+
+#: c/c-decl.c:3380
+#, gcc-internal-format
+msgid "incompatible implicit declaration of function %qD"
+msgstr ""
+
+#: c/c-decl.c:3434
+#, gcc-internal-format
+msgid "%qE undeclared here (not in a function)"
+msgstr ""
+
+#: c/c-decl.c:3440
+#, gcc-internal-format
+msgid "%qE undeclared (first use in this function)"
+msgstr ""
+
+#: c/c-decl.c:3443
+#, gcc-internal-format
+msgid "each undeclared identifier is reported only once for each function it appears in"
+msgstr ""
+
+#: c/c-decl.c:3491 cp/decl.c:2838
+#, gcc-internal-format
+msgid "label %qE referenced outside of any function"
+msgstr ""
+
+#: c/c-decl.c:3527
+#, gcc-internal-format
+msgid "jump into scope of identifier with variably modified type"
+msgstr ""
+
+#: c/c-decl.c:3530
+#, gcc-internal-format
+msgid "jump skips variable initialization"
+msgstr ""
+
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
+#, gcc-internal-format
+msgid "label %qD defined here"
+msgstr ""
+
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
+#: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
+#, gcc-internal-format
+msgid "%qD declared here"
+msgstr ""
+
+#: c/c-decl.c:3585 c/c-decl.c:3674
+#, gcc-internal-format
+msgid "jump into statement expression"
+msgstr ""
+
+#: c/c-decl.c:3607
+#, gcc-internal-format
+msgid "duplicate label declaration %qE"
+msgstr ""
+
+#: c/c-decl.c:3705 cp/decl.c:3182
+#, gcc-internal-format
+msgid "duplicate label %qD"
+msgstr ""
+
+#: c/c-decl.c:3736
+#, gcc-internal-format
+msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
+msgstr ""
+
+#: c/c-decl.c:3801
+#, gcc-internal-format
+msgid "switch jumps over variable initialization"
+msgstr ""
+
+#: c/c-decl.c:3802 c/c-decl.c:3813
+#, gcc-internal-format
+msgid "switch starts here"
+msgstr ""
+
+#: c/c-decl.c:3812
+#, gcc-internal-format
+msgid "switch jumps into statement expression"
+msgstr ""
+
+#: c/c-decl.c:3883
+#, gcc-internal-format
+msgid "%qE defined as wrong kind of tag"
+msgstr ""
+
+#: c/c-decl.c:4112
+#, gcc-internal-format
+msgid "unnamed struct/union that defines no instances"
+msgstr ""
+
+#: c/c-decl.c:4122
+#, gcc-internal-format
+msgid "empty declaration with storage class specifier does not redeclare tag"
+msgstr ""
+
+#: c/c-decl.c:4137
+#, gcc-internal-format
+msgid "empty declaration with type qualifier does not redeclare tag"
+msgstr ""
+
+#: c/c-decl.c:4148
+#, gcc-internal-format
+msgid "empty declaration with %<_Alignas%> does not redeclare tag"
+msgstr ""
+
+#: c/c-decl.c:4170 c/c-decl.c:4178
+#, gcc-internal-format
+msgid "useless type name in empty declaration"
+msgstr ""
+
+#: c/c-decl.c:4186
+#, gcc-internal-format
+msgid "%<inline%> in empty declaration"
+msgstr ""
+
+#: c/c-decl.c:4192
+#, gcc-internal-format
+msgid "%<_Noreturn%> in empty declaration"
+msgstr ""
+
+#: c/c-decl.c:4198
+#, gcc-internal-format
+msgid "%<auto%> in file-scope empty declaration"
+msgstr ""
+
+#: c/c-decl.c:4204
+#, gcc-internal-format
+msgid "%<register%> in file-scope empty declaration"
+msgstr ""
+
+#: c/c-decl.c:4211
+#, gcc-internal-format
+msgid "useless storage class specifier in empty declaration"
+msgstr ""
+
+#: c/c-decl.c:4217
+#, gcc-internal-format
+msgid "useless %qs in empty declaration"
+msgstr ""
+
+#: c/c-decl.c:4230
+#, gcc-internal-format
+msgid "useless type qualifier in empty declaration"
+msgstr ""
+
+#: c/c-decl.c:4237
+#, gcc-internal-format
+msgid "useless %<_Alignas%> in empty declaration"
+msgstr ""
+
+#: c/c-decl.c:4244 c/c-parser.c:1594
+#, gcc-internal-format
+msgid "empty declaration"
+msgstr ""
+
+#: c/c-decl.c:4315
+#, gcc-internal-format
+msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
+msgstr ""
+
+#: c/c-decl.c:4319
+#, gcc-internal-format
+msgid "ISO C90 does not support %<[*]%> array declarators"
+msgstr ""
+
+#. C99 6.7.5.2p4
+#. A function definition isn't function prototype scope C99 6.2.1p4.
+#. C99 6.7.5.2p4
+#: c/c-decl.c:4325 c/c-decl.c:6789
+#, gcc-internal-format
+msgid "%<[*]%> not allowed in other than function prototype scope"
+msgstr ""
+
+#: c/c-decl.c:4415 cp/decl2.c:1458
+#, gcc-internal-format
+msgid "%q+D in block scope inside of declare target directive"
+msgstr ""
+
+#: c/c-decl.c:4419 cp/decl2.c:1463
+#, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:4468
+#, gcc-internal-format
+msgid "%q+D is usually a function"
+msgstr ""
+
+#: c/c-decl.c:4477
+#, gcc-internal-format
+msgid "typedef %qD is initialized (use __typeof__ instead)"
+msgstr ""
+
+#: c/c-decl.c:4482
+#, gcc-internal-format
+msgid "function %qD is initialized like a variable"
+msgstr ""
+
+#. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
+#: c/c-decl.c:4488
+#, gcc-internal-format
+msgid "parameter %qD is initialized"
+msgstr ""
+
+#. Although C99 is unclear about whether incomplete arrays
+#. of VLAs themselves count as VLAs, it does not make
+#. sense to permit them to be initialized given that
+#. ordinary VLAs may not be initialized.
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
+#, gcc-internal-format
+msgid "variable-sized object may not be initialized"
+msgstr ""
+
+#: c/c-decl.c:4513
+#, gcc-internal-format
+msgid "variable %qD has initializer but incomplete type"
+msgstr ""
+
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
+#, gcc-internal-format
+msgid "inline function %q+D given attribute noinline"
+msgstr ""
+
+#: c/c-decl.c:4653
+#, gcc-internal-format
+msgid "uninitialized const member in %qT is invalid in C++"
+msgstr ""
+
+#: c/c-decl.c:4655
+#, gcc-internal-format
+msgid "%qD should be initialized"
+msgstr ""
+
+#: c/c-decl.c:4733
+#, gcc-internal-format
+msgid "initializer fails to determine size of %q+D"
+msgstr ""
+
+#: c/c-decl.c:4738
+#, gcc-internal-format
+msgid "array size missing in %q+D"
+msgstr ""
+
+#: c/c-decl.c:4750
+#, gcc-internal-format
+msgid "zero or negative size array %q+D"
+msgstr ""
+
+#: c/c-decl.c:4816
+#, gcc-internal-format
+msgid "storage size of %q+D isn%'t constant"
+msgstr ""
+
+#: c/c-decl.c:4866
+#, gcc-internal-format
+msgid "ignoring asm-specifier for non-static local variable %q+D"
+msgstr ""
+
+#: c/c-decl.c:4896
+#, gcc-internal-format
+msgid "cannot put object with volatile field into register"
+msgstr ""
+
+#: c/c-decl.c:4983
+#, gcc-internal-format
+msgid "uninitialized const %qD is invalid in C++"
+msgstr ""
+
+#: c/c-decl.c:5041
+#, gcc-internal-format
+msgid "ISO C forbids forward parameter declarations"
+msgstr ""
+
+#: c/c-decl.c:5138
+#, gcc-internal-format
+msgid "defining a type in a compound literal is invalid in C++"
+msgstr ""
+
+#: c/c-decl.c:5190 c/c-decl.c:5205
+#, gcc-internal-format
+msgid "bit-field %qs width not an integer constant"
+msgstr ""
+
+#: c/c-decl.c:5200
+#, gcc-internal-format
+msgid "bit-field %qs width not an integer constant expression"
+msgstr ""
+
+#: c/c-decl.c:5211
+#, gcc-internal-format
+msgid "negative width in bit-field %qs"
+msgstr ""
+
+#: c/c-decl.c:5216
+#, gcc-internal-format
+msgid "zero width for bit-field %qs"
+msgstr ""
+
+#: c/c-decl.c:5226
+#, gcc-internal-format
+msgid "bit-field %qs has invalid type"
+msgstr ""
+
+#: c/c-decl.c:5236
+#, gcc-internal-format
+msgid "type of bit-field %qs is a GCC extension"
+msgstr ""
+
+#: c/c-decl.c:5242
+#, gcc-internal-format
+msgid "width of %qs exceeds its type"
+msgstr ""
+
+#: c/c-decl.c:5255
+#, gcc-internal-format
+msgid "%qs is narrower than values of its type"
+msgstr ""
+
+#: c/c-decl.c:5270
+#, gcc-internal-format
+msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
+msgstr ""
+
+#: c/c-decl.c:5273
+#, gcc-internal-format
+msgid "ISO C90 forbids array whose size can%'t be evaluated"
+msgstr ""
+
+#: c/c-decl.c:5280
+#, gcc-internal-format
+msgid "ISO C90 forbids variable length array %qE"
+msgstr ""
+
+#: c/c-decl.c:5282
+#, gcc-internal-format
+msgid "ISO C90 forbids variable length array"
+msgstr ""
+
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
+#, gcc-internal-format
+msgid "variably modified %qE at file scope"
+msgstr ""
+
+#: c/c-decl.c:5460
+#, gcc-internal-format
+msgid "variably modified field at file scope"
+msgstr ""
+
+#: c/c-decl.c:5480
+#, gcc-internal-format
+msgid "type defaults to %<int%> in declaration of %qE"
+msgstr ""
+
+#: c/c-decl.c:5484
+#, gcc-internal-format
+msgid "type defaults to %<int%> in type name"
+msgstr ""
+
+#: c/c-decl.c:5516
+#, gcc-internal-format
+msgid "duplicate %<const%>"
+msgstr "дублювання %<const%>"
+
+#: c/c-decl.c:5518
+#, gcc-internal-format
+msgid "duplicate %<restrict%>"
+msgstr "дублювання %<restrict%>"
+
+#: c/c-decl.c:5520
+#, gcc-internal-format
+msgid "duplicate %<volatile%>"
+msgstr "дублювання %<volatile%>"
+
+#: c/c-decl.c:5522
+#, gcc-internal-format
+msgid "duplicate %<_Atomic%>"
+msgstr "дублювання %<_Atomic%>"
+
+#: c/c-decl.c:5525
+#, gcc-internal-format, gfc-internal-format
+msgid "conflicting named address spaces (%s vs %s)"
+msgstr ""
+
+#: c/c-decl.c:5543 c/c-parser.c:2460
+#, gcc-internal-format
+msgid "%<_Atomic%>-qualified array type"
+msgstr ""
+
+#: c/c-decl.c:5557
+#, gcc-internal-format
+msgid "function definition declared %<auto%>"
+msgstr ""
+
+#: c/c-decl.c:5559
+#, gcc-internal-format
+msgid "function definition declared %<register%>"
+msgstr ""
+
+#: c/c-decl.c:5561
+#, gcc-internal-format
+msgid "function definition declared %<typedef%>"
+msgstr ""
+
+#: c/c-decl.c:5563
+#, gcc-internal-format
+msgid "function definition declared %qs"
+msgstr ""
+
+#: c/c-decl.c:5581
+#, gcc-internal-format
+msgid "storage class specified for structure field %qE"
+msgstr ""
+
+#: c/c-decl.c:5584
+#, gcc-internal-format
+msgid "storage class specified for structure field"
+msgstr ""
+
+#: c/c-decl.c:5588
+#, gcc-internal-format
+msgid "storage class specified for parameter %qE"
+msgstr ""
+
+#: c/c-decl.c:5591
+#, gcc-internal-format
+msgid "storage class specified for unnamed parameter"
+msgstr ""
+
+#: c/c-decl.c:5594 cp/decl.c:9593
+#, gcc-internal-format
+msgid "storage class specified for typename"
+msgstr ""
+
+#: c/c-decl.c:5611
+#, gcc-internal-format
+msgid "%qE initialized and declared %<extern%>"
+msgstr ""
+
+#: c/c-decl.c:5615
+#, gcc-internal-format
+msgid "%qE has both %<extern%> and initializer"
+msgstr ""
+
+#: c/c-decl.c:5620
+#, gcc-internal-format
+msgid "file-scope declaration of %qE specifies %<auto%>"
+msgstr ""
+
+#: c/c-decl.c:5624
+#, gcc-internal-format
+msgid "file-scope declaration of %qE specifies %<register%>"
+msgstr ""
+
+#: c/c-decl.c:5629
+#, gcc-internal-format
+msgid "nested function %qE declared %<extern%>"
+msgstr ""
+
+#: c/c-decl.c:5632
+#, gcc-internal-format
+msgid "function-scope %qE implicitly auto and declared %qs"
+msgstr ""
+
+#. Only the innermost declarator (making a parameter be of
+#. array type which is converted to pointer type)
+#. may have static or type qualifiers.
+#: c/c-decl.c:5679 c/c-decl.c:6022
+#, gcc-internal-format
+msgid "static or type qualifiers in non-parameter array declarator"
+msgstr ""
+
+#: c/c-decl.c:5727
+#, gcc-internal-format
+msgid "declaration of %qE as array of voids"
+msgstr ""
+
+#: c/c-decl.c:5729
+#, gcc-internal-format
+msgid "declaration of type name as array of voids"
+msgstr ""
+
+#: c/c-decl.c:5736
+#, gcc-internal-format
+msgid "declaration of %qE as array of functions"
+msgstr ""
+
+#: c/c-decl.c:5739
+#, gcc-internal-format
+msgid "declaration of type name as array of functions"
+msgstr ""
+
+#: c/c-decl.c:5747 c/c-decl.c:7710
+#, gcc-internal-format
+msgid "invalid use of structure with flexible array member"
+msgstr ""
+
+#: c/c-decl.c:5773
+#, gcc-internal-format
+msgid "size of array %qE has non-integer type"
+msgstr ""
+
+#: c/c-decl.c:5777
+#, gcc-internal-format
+msgid "size of unnamed array has non-integer type"
+msgstr ""
+
+#: c/c-decl.c:5787
+#, gcc-internal-format
+msgid "ISO C forbids zero-size array %qE"
+msgstr ""
+
+#: c/c-decl.c:5790
+#, gcc-internal-format
+msgid "ISO C forbids zero-size array"
+msgstr ""
+
+#: c/c-decl.c:5799
+#, gcc-internal-format
+msgid "size of array %qE is negative"
+msgstr ""
+
+#: c/c-decl.c:5801
+#, gcc-internal-format
+msgid "size of unnamed array is negative"
+msgstr ""
+
+#: c/c-decl.c:5886 c/c-decl.c:6309
+#, gcc-internal-format
+msgid "size of array %qE is too large"
+msgstr ""
+
+#: c/c-decl.c:5889 c/c-decl.c:6311
+#, gcc-internal-format
+msgid "size of unnamed array is too large"
+msgstr ""
+
+#: c/c-decl.c:5925 c/c-decl.c:6520
+#, gcc-internal-format
+msgid "ISO C90 does not support flexible array members"
+msgstr ""
+
+#. C99 6.7.5.2p4
+#: c/c-decl.c:5947
+#, gcc-internal-format
+msgid "%<[*]%> not in a declaration"
+msgstr ""
+
+#: c/c-decl.c:5960
+#, gcc-internal-format
+msgid "array type has incomplete element type %qT"
+msgstr ""
+
+#: c/c-decl.c:6055
+#, gcc-internal-format
+msgid "%qE declared as function returning a function"
+msgstr ""
+
+#: c/c-decl.c:6058
+#, gcc-internal-format
+msgid "type name declared as function returning a function"
+msgstr ""
+
+#: c/c-decl.c:6065
+#, gcc-internal-format
+msgid "%qE declared as function returning an array"
+msgstr ""
+
+#: c/c-decl.c:6068
+#, gcc-internal-format
+msgid "type name declared as function returning an array"
+msgstr ""
+
+#: c/c-decl.c:6096
+#, gcc-internal-format
+msgid "function definition has qualified void return type"
+msgstr ""
+
+#: c/c-decl.c:6099 cp/decl.c:9720
+#, gcc-internal-format
+msgid "type qualifiers ignored on function return type"
+msgstr ""
+
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
+#, gcc-internal-format
+msgid "%<_Atomic%>-qualified function type"
+msgstr ""
+
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
+#, gcc-internal-format
+msgid "ISO C forbids qualified function types"
+msgstr ""
+
+#: c/c-decl.c:6201
+#, gcc-internal-format
+msgid "%qs combined with %<auto%> qualifier for %qE"
+msgstr ""
+
+#: c/c-decl.c:6205
+#, gcc-internal-format
+msgid "%qs combined with %<register%> qualifier for %qE"
+msgstr ""
+
+#: c/c-decl.c:6211
+#, gcc-internal-format
+msgid "%qs specified for auto variable %qE"
+msgstr ""
+
+#: c/c-decl.c:6227
+#, gcc-internal-format
+msgid "%qs specified for parameter %qE"
+msgstr ""
+
+#: c/c-decl.c:6230
+#, gcc-internal-format
+msgid "%qs specified for unnamed parameter"
+msgstr ""
+
+#: c/c-decl.c:6236
+#, gcc-internal-format
+msgid "%qs specified for structure field %qE"
+msgstr ""
+
+#: c/c-decl.c:6239
+#, gcc-internal-format
+msgid "%qs specified for structure field"
+msgstr ""
+
+#: c/c-decl.c:6254
+#, gcc-internal-format
+msgid "bit-field %qE has atomic type"
+msgstr ""
+
+#: c/c-decl.c:6256
+#, gcc-internal-format
+msgid "bit-field has atomic type"
+msgstr ""
+
+#: c/c-decl.c:6265
+#, gcc-internal-format
+msgid "alignment specified for typedef %qE"
+msgstr ""
+
+#: c/c-decl.c:6267
+#, gcc-internal-format
+msgid "alignment specified for %<register%> object %qE"
+msgstr ""
+
+#: c/c-decl.c:6272
+#, gcc-internal-format
+msgid "alignment specified for parameter %qE"
+msgstr ""
+
+#: c/c-decl.c:6274
+#, gcc-internal-format
+msgid "alignment specified for unnamed parameter"
+msgstr ""
+
+#: c/c-decl.c:6279
+#, gcc-internal-format
+msgid "alignment specified for bit-field %qE"
+msgstr ""
+
+#: c/c-decl.c:6281
+#, gcc-internal-format
+msgid "alignment specified for unnamed bit-field"
+msgstr ""
+
+#: c/c-decl.c:6284
+#, gcc-internal-format
+msgid "alignment specified for function %qE"
+msgstr ""
+
+#: c/c-decl.c:6291
+#, gcc-internal-format
+msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
+msgstr ""
+
+#: c/c-decl.c:6294
+#, gcc-internal-format
+msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
+msgstr ""
+
+#: c/c-decl.c:6340
+#, gcc-internal-format
+msgid "typedef %q+D declared %<inline%>"
+msgstr ""
+
+#: c/c-decl.c:6342
+#, gcc-internal-format
+msgid "typedef %q+D declared %<_Noreturn%>"
+msgstr ""
+
+#: c/c-decl.c:6385
+#, gcc-internal-format
+msgid "ISO C forbids const or volatile function types"
+msgstr ""
+
+#. C99 6.7.2.1p8
+#: c/c-decl.c:6395
+#, gcc-internal-format
+msgid "a member of a structure or union cannot have a variably modified type"
+msgstr ""
+
+#: c/c-decl.c:6412 cp/decl.c:8828
+#, gcc-internal-format
+msgid "variable or field %qE declared void"
+msgstr ""
+
+#: c/c-decl.c:6444
+#, gcc-internal-format
+msgid "attributes in parameter array declarator ignored"
+msgstr ""
+
+#: c/c-decl.c:6486
+#, gcc-internal-format
+msgid "parameter %q+D declared %<inline%>"
+msgstr ""
+
+#: c/c-decl.c:6488
+#, gcc-internal-format
+msgid "parameter %q+D declared %<_Noreturn%>"
+msgstr ""
+
+#: c/c-decl.c:6501
+#, gcc-internal-format
+msgid "field %qE declared as a function"
+msgstr ""
+
+#: c/c-decl.c:6508
+#, gcc-internal-format
+msgid "field %qE has incomplete type"
+msgstr ""
+
+#: c/c-decl.c:6510
+#, gcc-internal-format
+msgid "unnamed field has incomplete type"
+msgstr ""
+
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
+#, gcc-internal-format
+msgid "invalid storage class for function %qE"
+msgstr ""
+
+#: c/c-decl.c:6611
+#, gcc-internal-format
+msgid "cannot inline function %<main%>"
+msgstr ""
+
+#: c/c-decl.c:6613
+#, gcc-internal-format
+msgid "%<main%> declared %<_Noreturn%>"
+msgstr ""
+
+#: c/c-decl.c:6624
+#, gcc-internal-format
+msgid "ISO C99 does not support %<_Noreturn%>"
+msgstr ""
+
+#: c/c-decl.c:6627
+#, gcc-internal-format
+msgid "ISO C90 does not support %<_Noreturn%>"
+msgstr ""
+
+#: c/c-decl.c:6655
+#, gcc-internal-format
+msgid "variable previously declared %<static%> redeclared %<extern%>"
+msgstr ""
+
+#: c/c-decl.c:6665
+#, gcc-internal-format
+msgid "variable %q+D declared %<inline%>"
+msgstr ""
+
+#: c/c-decl.c:6667
+#, gcc-internal-format
+msgid "variable %q+D declared %<_Noreturn%>"
+msgstr ""
+
+#: c/c-decl.c:6702
+#, gcc-internal-format
+msgid "non-nested function with variably modified type"
+msgstr ""
+
+#: c/c-decl.c:6704
+#, gcc-internal-format
+msgid "object with variably modified type must have no linkage"
+msgstr ""
+
+#: c/c-decl.c:6795 c/c-decl.c:8353
+#, gcc-internal-format
+msgid "function declaration isn%'t a prototype"
+msgstr ""
+
+#: c/c-decl.c:6804
+#, gcc-internal-format
+msgid "parameter names (without types) in function declaration"
+msgstr ""
+
+#: c/c-decl.c:6842
+#, gcc-internal-format
+msgid "parameter %u (%q+D) has incomplete type"
+msgstr ""
+
+#: c/c-decl.c:6846
+#, gcc-internal-format, gfc-internal-format
+msgid "parameter %u has incomplete type"
+msgstr ""
+
+#: c/c-decl.c:6857
+#, gcc-internal-format
+msgid "parameter %u (%q+D) has void type"
+msgstr ""
+
+#: c/c-decl.c:6861
+#, gcc-internal-format, gfc-internal-format
+msgid "parameter %u has void type"
+msgstr ""
+
+#: c/c-decl.c:6945
+#, gcc-internal-format
+msgid "%<void%> as only parameter may not be qualified"
+msgstr ""
+
+#: c/c-decl.c:6949 c/c-decl.c:6984
+#, gcc-internal-format
+msgid "%<void%> must be the only parameter"
+msgstr ""
+
+#: c/c-decl.c:6978
+#, gcc-internal-format
+msgid "parameter %q+D has just a forward declaration"
+msgstr ""
+
+#. The %s will be one of 'struct', 'union', or 'enum'.
+#: c/c-decl.c:7023
+#, gcc-internal-format
+msgid "%<%s %E%> declared inside parameter list"
+msgstr ""
+
+#. The %s will be one of 'struct', 'union', or 'enum'.
+#: c/c-decl.c:7027
+#, gcc-internal-format, gfc-internal-format
+msgid "anonymous %s declared inside parameter list"
+msgstr ""
+
+#: c/c-decl.c:7032
+#, gcc-internal-format
+msgid "its scope is only this definition or declaration, which is probably not what you want"
+msgstr ""
+
+#: c/c-decl.c:7132
+#, gcc-internal-format
+msgid "enum type defined here"
+msgstr ""
+
+#: c/c-decl.c:7138
+#, gcc-internal-format
+msgid "struct defined here"
+msgstr ""
+
+#: c/c-decl.c:7144
+#, gcc-internal-format
+msgid "union defined here"
+msgstr ""
+
+#: c/c-decl.c:7217
+#, gcc-internal-format
+msgid "redefinition of %<union %E%>"
+msgstr ""
+
+#: c/c-decl.c:7219
+#, gcc-internal-format
+msgid "redefinition of %<struct %E%>"
+msgstr ""
+
+#: c/c-decl.c:7228
+#, gcc-internal-format
+msgid "nested redefinition of %<union %E%>"
+msgstr ""
+
+#: c/c-decl.c:7230
+#, gcc-internal-format
+msgid "nested redefinition of %<struct %E%>"
+msgstr ""
+
+#: c/c-decl.c:7262 c/c-decl.c:7948
+#, gcc-internal-format
+msgid "defining type in %qs expression is invalid in C++"
+msgstr ""
+
+#: c/c-decl.c:7331 cp/decl.c:4448
+#, gcc-internal-format
+msgid "declaration does not declare anything"
+msgstr ""
+
+#: c/c-decl.c:7336
+#, gcc-internal-format
+msgid "ISO C99 doesn%'t support unnamed structs/unions"
+msgstr ""
+
+#: c/c-decl.c:7339
+#, gcc-internal-format
+msgid "ISO C90 doesn%'t support unnamed structs/unions"
+msgstr ""
+
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
+#, gcc-internal-format
+msgid "duplicate member %q+D"
+msgstr ""
+
+#: c/c-decl.c:7618
+#, gcc-internal-format
+msgid "union has no named members"
+msgstr ""
+
+#: c/c-decl.c:7620
+#, gcc-internal-format
+msgid "union has no members"
+msgstr ""
+
+#: c/c-decl.c:7625
+#, gcc-internal-format
+msgid "struct has no named members"
+msgstr ""
+
+#: c/c-decl.c:7627
+#, gcc-internal-format
+msgid "struct has no members"
+msgstr ""
+
+#: c/c-decl.c:7690
+#, gcc-internal-format
+msgid "flexible array member in union"
+msgstr ""
+
+#: c/c-decl.c:7696
+#, gcc-internal-format
+msgid "flexible array member not at end of struct"
+msgstr ""
+
+#: c/c-decl.c:7702
+#, gcc-internal-format
+msgid "flexible array member in otherwise empty struct"
+msgstr ""
+
+#: c/c-decl.c:7731 cp/class.c:6493
+#, gcc-internal-format
+msgid "type %qT is too large"
+msgstr ""
+
+#: c/c-decl.c:7827
+#, gcc-internal-format
+msgid "union cannot be made transparent"
+msgstr ""
+
+#: c/c-decl.c:7921
+#, gcc-internal-format
+msgid "nested redefinition of %<enum %E%>"
+msgstr ""
+
+#. This enum is a named one that has been declared already.
+#: c/c-decl.c:7928
+#, gcc-internal-format
+msgid "redeclaration of %<enum %E%>"
+msgstr ""
+
+#: c/c-decl.c:8004
+#, gcc-internal-format
+msgid "enumeration values exceed range of largest integer"
+msgstr ""
+
+#: c/c-decl.c:8021
+#, gcc-internal-format
+msgid "specified mode too small for enumeral values"
+msgstr ""
+
+#: c/c-decl.c:8126 c/c-decl.c:8142
+#, gcc-internal-format
+msgid "enumerator value for %qE is not an integer constant"
+msgstr ""
+
+#: c/c-decl.c:8137
+#, gcc-internal-format
+msgid "enumerator value for %qE is not an integer constant expression"
+msgstr ""
+
+#: c/c-decl.c:8161
+#, gcc-internal-format
+msgid "overflow in enumeration values"
+msgstr ""
+
+#: c/c-decl.c:8169
+#, gcc-internal-format
+msgid "ISO C restricts enumerator values to range of %<int%>"
+msgstr ""
+
+#: c/c-decl.c:8254
+#, gcc-internal-format
+msgid "inline function %qD given attribute noinline"
+msgstr ""
+
+#: c/c-decl.c:8272
+#, gcc-internal-format
+msgid "return type is an incomplete type"
+msgstr ""
+
+#: c/c-decl.c:8283
+#, gcc-internal-format
+msgid "return type defaults to %<int%>"
+msgstr ""
+
+#: c/c-decl.c:8362
+#, gcc-internal-format
+msgid "no previous prototype for %qD"
+msgstr ""
+
+#: c/c-decl.c:8371
+#, gcc-internal-format
+msgid "%qD was used with no prototype before its definition"
+msgstr ""
+
+#: c/c-decl.c:8379
+#, gcc-internal-format
+msgid "no previous declaration for %qD"
+msgstr ""
+
+#: c/c-decl.c:8389
+#, gcc-internal-format
+msgid "%qD was used with no declaration before its definition"
+msgstr ""
+
+#: c/c-decl.c:8408
+#, gcc-internal-format
+msgid "return type of %qD is not %<int%>"
+msgstr ""
+
+#: c/c-decl.c:8410
+#, gcc-internal-format
+msgid "%<_Atomic%>-qualified return type of %qD"
+msgstr ""
+
+#: c/c-decl.c:8417
+#, gcc-internal-format
+msgid "%qD is normally a non-static function"
+msgstr ""
+
+#: c/c-decl.c:8454
+#, gcc-internal-format
+msgid "old-style parameter declarations in prototyped function definition"
+msgstr ""
+
+#: c/c-decl.c:8469
+#, gcc-internal-format
+msgid "traditional C rejects ISO C style function definitions"
+msgstr ""
+
+#: c/c-decl.c:8485
+#, gcc-internal-format
+msgid "parameter name omitted"
+msgstr ""
+
+#: c/c-decl.c:8522
+#, gcc-internal-format
+msgid "old-style function definition"
+msgstr ""
+
+#: c/c-decl.c:8531
+#, gcc-internal-format
+msgid "parameter name missing from parameter list"
+msgstr ""
+
+#: c/c-decl.c:8546
+#, gcc-internal-format
+msgid "%qD declared as a non-parameter"
+msgstr ""
+
+#: c/c-decl.c:8552
+#, gcc-internal-format
+msgid "multiple parameters named %qD"
+msgstr ""
+
+#: c/c-decl.c:8561
+#, gcc-internal-format
+msgid "parameter %qD declared with void type"
+msgstr ""
+
+#: c/c-decl.c:8590 c/c-decl.c:8595
+#, gcc-internal-format
+msgid "type of %qD defaults to %<int%>"
+msgstr ""
+
+#: c/c-decl.c:8615
+#, gcc-internal-format
+msgid "parameter %qD has incomplete type"
+msgstr ""
+
+#: c/c-decl.c:8622
+#, gcc-internal-format
+msgid "declaration for parameter %qD but no such parameter"
+msgstr ""
+
+#: c/c-decl.c:8672
+#, gcc-internal-format
+msgid "number of arguments doesn%'t match built-in prototype"
+msgstr ""
+
+#: c/c-decl.c:8683
+#, gcc-internal-format
+msgid "number of arguments doesn%'t match prototype"
+msgstr ""
+
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
+#, gcc-internal-format
+msgid "prototype declaration"
+msgstr ""
+
+#: c/c-decl.c:8725
+#, gcc-internal-format
+msgid "promoted argument %qD doesn%'t match built-in prototype"
+msgstr ""
+
+#: c/c-decl.c:8730
+#, gcc-internal-format
+msgid "promoted argument %qD doesn%'t match prototype"
+msgstr ""
+
+#: c/c-decl.c:8740
+#, gcc-internal-format
+msgid "argument %qD doesn%'t match built-in prototype"
+msgstr ""
+
+#: c/c-decl.c:8745
+#, gcc-internal-format
+msgid "argument %qD doesn%'t match prototype"
+msgstr ""
+
+#: c/c-decl.c:8972 cp/decl.c:14284
+#, gcc-internal-format
+msgid "no return statement in function returning non-void"
+msgstr ""
+
+#: c/c-decl.c:8992
+#, gcc-internal-format
+msgid "parameter %qD set but not used"
+msgstr ""
+
+#. If we get here, declarations have been used in a for loop without
+#. the C99 for loop scope.  This doesn't make much sense, so don't
+#. allow it.
+#: c/c-decl.c:9081
+#, gcc-internal-format
+msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
+msgstr ""
+
+#: c/c-decl.c:9086
+#, gcc-internal-format
+msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
+msgstr ""
+
+#: c/c-decl.c:9121
+#, gcc-internal-format
+msgid "declaration of static variable %qD in %<for%> loop initial declaration"
+msgstr ""
+
+#: c/c-decl.c:9125
+#, gcc-internal-format
+msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
+msgstr ""
+
+#: c/c-decl.c:9132
+#, gcc-internal-format
+msgid "%<struct %E%> declared in %<for%> loop initial declaration"
+msgstr ""
+
+#: c/c-decl.c:9137
+#, gcc-internal-format
+msgid "%<union %E%> declared in %<for%> loop initial declaration"
+msgstr ""
+
+#: c/c-decl.c:9141
+#, gcc-internal-format
+msgid "%<enum %E%> declared in %<for%> loop initial declaration"
+msgstr ""
+
+#: c/c-decl.c:9145
+#, gcc-internal-format
+msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
+msgstr ""
+
+#: c/c-decl.c:9419
+#, gcc-internal-format
+msgid "incompatible address space qualifiers %qs and %qs"
+msgstr ""
+
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
+#, gcc-internal-format
+msgid "duplicate %qE"
+msgstr ""
+
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
+#, gcc-internal-format
+msgid "two or more data types in declaration specifiers"
+msgstr ""
+
+#: c/c-decl.c:9507 cp/parser.c:24713
+#, gcc-internal-format
+msgid "%<long long long%> is too long for GCC"
+msgstr ""
+
+#: c/c-decl.c:9520
+#, gcc-internal-format
+msgid "ISO C90 does not support %<long long%>"
+msgstr ""
+
+#: c/c-decl.c:9717 c/c-parser.c:7557
+#, gcc-internal-format
+msgid "ISO C90 does not support complex types"
+msgstr ""
+
+#: c/c-decl.c:9763
+#, gcc-internal-format
+msgid "ISO C does not support saturating types"
+msgstr ""
+
+#: c/c-decl.c:9881
+#, gcc-internal-format
+msgid "ISO C does not support %<__int%d%> types"
+msgstr ""
+
+#: c/c-decl.c:9901
+#, gcc-internal-format
+msgid "%<__int%d%> is not supported on this target"
+msgstr ""
+
+#: c/c-decl.c:9943
+#, gcc-internal-format
+msgid "ISO C90 does not support boolean types"
+msgstr ""
+
+#: c/c-decl.c:10117
+#, gcc-internal-format
+msgid "ISO C does not support decimal floating point"
+msgstr ""
+
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
+#, gcc-internal-format
+msgid "fixed-point types not supported for this target"
+msgstr ""
+
+#: c/c-decl.c:10142
+#, gcc-internal-format
+msgid "ISO C does not support fixed-point types"
+msgstr ""
+
+#: c/c-decl.c:10177
+#, gcc-internal-format
+msgid "C++ lookup of %qD would return a field, not a type"
+msgstr ""
+
+#: c/c-decl.c:10190
+#, gcc-internal-format
+msgid "%qE fails to be a typedef or built in type"
+msgstr ""
+
+#: c/c-decl.c:10238
+#, gcc-internal-format
+msgid "%qE is not at beginning of declaration"
+msgstr ""
+
+#: c/c-decl.c:10259
+#, gcc-internal-format
+msgid "%qE used with %<auto%>"
+msgstr ""
+
+#: c/c-decl.c:10261
+#, gcc-internal-format
+msgid "%qE used with %<register%>"
+msgstr ""
+
+#: c/c-decl.c:10263
+#, gcc-internal-format
+msgid "%qE used with %<typedef%>"
+msgstr ""
+
+#: c/c-decl.c:10277 c/c-parser.c:6681
+#, gcc-internal-format
+msgid "ISO C99 does not support %qE"
+msgstr ""
+
+#: c/c-decl.c:10280 c/c-parser.c:6684
+#, gcc-internal-format
+msgid "ISO C90 does not support %qE"
+msgstr ""
+
+#: c/c-decl.c:10292
+#, gcc-internal-format
+msgid "%<__thread%> before %<extern%>"
+msgstr "%<__thread%> до %<extern%>"
+
+#: c/c-decl.c:10301
+#, gcc-internal-format
+msgid "%<__thread%> before %<static%>"
+msgstr "%<__thread%> до %<static%>"
+
+#: c/c-decl.c:10314
+#, gcc-internal-format
+msgid "duplicate %<_Thread_local%> or %<__thread%>"
+msgstr ""
+
+#: c/c-decl.c:10322
+#, gcc-internal-format
+msgid "multiple storage classes in declaration specifiers"
+msgstr ""
+
+#: c/c-decl.c:10330
+#, gcc-internal-format
+msgid "%qs used with %qE"
+msgstr ""
+
+#: c/c-decl.c:10403
+#, gcc-internal-format
+msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
+msgstr ""
+
+#: c/c-decl.c:10418
+#, gcc-internal-format
+msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
+msgstr ""
+
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
+#, gcc-internal-format
+msgid "ISO C does not support complex integer types"
+msgstr ""
+
+#: c/c-decl.c:10926 cp/semantics.c:4936
+#, gcc-internal-format
+msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
+msgstr ""
+
+#: c/c-decl.c:10930 cp/semantics.c:4940
+#, gcc-internal-format
+msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
+msgstr ""
+
+#: c/c-parser.c:283
+#, gcc-internal-format
+msgid "identifier %qE conflicts with C++ keyword"
+msgstr ""
+
+#: c/c-parser.c:1000 cp/parser.c:24920
+#, gcc-internal-format
+msgid "expected end of line"
+msgstr ""
+
+#: c/c-parser.c:1330
+#, gcc-internal-format
+msgid "ISO C forbids an empty translation unit"
+msgstr ""
+
+#: c/c-parser.c:1428 c/c-parser.c:8633
+#, gcc-internal-format
+msgid "ISO C does not allow extra %<;%> outside of a function"
+msgstr ""
+
+#: c/c-parser.c:1558 c/c-parser.c:2286 c/c-parser.c:3665
+#, gcc-internal-format
+msgid "unknown type name %qE"
+msgstr ""
+
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
+#, gcc-internal-format
+msgid "expected declaration specifiers"
+msgstr ""
+
+#: c/c-parser.c:1588
+#, gcc-internal-format
+msgid "%<__auto_type%> in empty declaration"
+msgstr ""
+
+#: c/c-parser.c:1607 c/c-parser.c:2944
+#, gcc-internal-format
+msgid "expected %<;%>, identifier or %<(%>"
+msgstr ""
+
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
+#, gcc-internal-format
+msgid "prefix attributes are ignored for methods"
+msgstr ""
+
+#: c/c-parser.c:1660
+#, gcc-internal-format
+msgid "prefix attributes are ignored for implementations"
+msgstr ""
+
+#: c/c-parser.c:1681
+#, gcc-internal-format
+msgid "unexpected attribute"
+msgstr ""
+
+#: c/c-parser.c:1719
+#, gcc-internal-format
+msgid "%<__auto_type%> requires a plain identifier as declarator"
+msgstr ""
+
+#: c/c-parser.c:1736
+#, gcc-internal-format
+msgid "data definition has no type or storage class"
+msgstr ""
+
+#. This means there is an attribute specifier after
+#. the declarator in a function definition.  Provide
+#. some more information for the user.
+#: c/c-parser.c:1751
+#, gcc-internal-format
+msgid "attributes should be specified before the declarator in a function definition"
+msgstr ""
+
+#: c/c-parser.c:1771
+#, gcc-internal-format
+msgid "%<__auto_type%> used with a bit-field initializer"
+msgstr ""
+
+#: c/c-parser.c:1839 c/c-parser.c:1924
+#, gcc-internal-format
+msgid "%<__auto_type%> requires an initialized data declaration"
+msgstr ""
+
+#: c/c-parser.c:1887
+#, gcc-internal-format
+msgid "%<__auto_type%> may only be used with a single declarator"
+msgstr ""
+
+#: c/c-parser.c:1916 cp/parser.c:11654
+#, gcc-internal-format
+msgid "expected %<,%> or %<;%>"
+msgstr "мало бути %<,%> або %<;%>"
+
+#. This can appear in many cases looking nothing like a
+#. function definition, so we don't give a more specific
+#. error suggesting there was one.
+#: c/c-parser.c:1930 c/c-parser.c:1946
+#, gcc-internal-format
+msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
+msgstr "мало бути %<=%>, %<,%>, %<;%>, %<asm%> або %<__attribute__%>"
+
+#: c/c-parser.c:1938
+#, gcc-internal-format
+msgid "ISO C forbids nested functions"
+msgstr "У стандарті ISO C заборонено вкладеність функцій"
+
+#: c/c-parser.c:2058
+#, gcc-internal-format
+msgid "ISO C99 does not support %<_Static_assert%>"
+msgstr ""
+
+#: c/c-parser.c:2061
+#, gcc-internal-format
+msgid "ISO C90 does not support %<_Static_assert%>"
+msgstr ""
+
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
+#, gcc-internal-format
+msgid "expected string literal"
+msgstr ""
+
+#: c/c-parser.c:2093
+#, gcc-internal-format
+msgid "expression in static assertion is not an integer"
+msgstr ""
+
+#: c/c-parser.c:2102
+#, gcc-internal-format
+msgid "expression in static assertion is not an integer constant expression"
+msgstr ""
+
+#: c/c-parser.c:2107
+#, gcc-internal-format
+msgid "expression in static assertion is not constant"
+msgstr ""
+
+#: c/c-parser.c:2112
+#, gcc-internal-format
+msgid "static assertion failed: %E"
+msgstr ""
+
+#: c/c-parser.c:2427
+#, gcc-internal-format
+msgid "%<_Atomic%> in Objective-C"
+msgstr ""
+
+#: c/c-parser.c:2431
+#, gcc-internal-format
+msgid "%<_Atomic%> with OpenMP"
+msgstr ""
+
+#: c/c-parser.c:2434
+#, gcc-internal-format
+msgid "ISO C99 does not support the %<_Atomic%> qualifier"
+msgstr ""
+
+#: c/c-parser.c:2437
+#, gcc-internal-format
+msgid "ISO C90 does not support the %<_Atomic%> qualifier"
+msgstr ""
+
+#: c/c-parser.c:2464
+#, gcc-internal-format
+msgid "%<_Atomic%> applied to a qualified type"
+msgstr ""
+
+#: c/c-parser.c:2567 c/c-parser.c:3505 c/c-parser.c:4283 c/c-parser.c:4579
+#: c/c-parser.c:5824 c/c-parser.c:5911 c/c-parser.c:6565 c/c-parser.c:7146
+#: c/c-parser.c:7351 c/c-parser.c:7376 c/c-parser.c:7628 c/c-parser.c:7918
+#: c/c-parser.c:7947 c/c-parser.c:8217 c/c-parser.c:8266 c/c-parser.c:8426
+#: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
+#: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
+#: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
+#, gcc-internal-format
+msgid "expected identifier"
+msgstr ""
+
+#: c/c-parser.c:2601 cp/parser.c:16088
+#, gcc-internal-format
+msgid "comma at end of enumerator list"
+msgstr ""
+
+#: c/c-parser.c:2607
+#, gcc-internal-format
+msgid "expected %<,%> or %<}%>"
+msgstr "мало бути %<,%> або %<}%>"
+
+#: c/c-parser.c:2638
+#, gcc-internal-format
+msgid "ISO C forbids forward references to %<enum%> types"
+msgstr ""
+
+#: c/c-parser.c:2754
+#, gcc-internal-format
+msgid "expected class name"
+msgstr ""
+
+#: c/c-parser.c:2773
+#, gcc-internal-format
+msgid "extra semicolon in struct or union specified"
+msgstr ""
+
+#: c/c-parser.c:2802
+#, gcc-internal-format
+msgid "no semicolon at end of struct or union"
+msgstr ""
+
+#: c/c-parser.c:2906 c/c-parser.c:4096
+#, gcc-internal-format
+msgid "expected specifier-qualifier-list"
+msgstr ""
+
+#: c/c-parser.c:2917
+#, gcc-internal-format
+msgid "ISO C forbids member declarations with no members"
+msgstr ""
+
+#: c/c-parser.c:3007
+#, gcc-internal-format
+msgid "expected %<,%>, %<;%> or %<}%>"
+msgstr "мало бути %<,%>, %<;%> або %<}%>"
+
+#: c/c-parser.c:3014
+#, gcc-internal-format
+msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
+msgstr "мало бути %<:%>, %<,%>, %<;%>, %<}%> або %<__attribute__%>"
+
+#: c/c-parser.c:3067
+#, gcc-internal-format
+msgid "%<typeof%> applied to a bit-field"
+msgstr ""
+
+#: c/c-parser.c:3104
+#, gcc-internal-format
+msgid "ISO C99 does not support %<_Alignas%>"
+msgstr ""
+
+#: c/c-parser.c:3107
+#, gcc-internal-format
+msgid "ISO C90 does not support %<_Alignas%>"
+msgstr ""
+
+#: c/c-parser.c:3342
+#, gcc-internal-format
+msgid "expected identifier or %<(%>"
+msgstr ""
+
+#: c/c-parser.c:3403 c/c-parser.c:3432
+#, gcc-internal-format
+msgid "array notations cannot be used in declaration"
+msgstr ""
+
+#: c/c-parser.c:3571
+#, gcc-internal-format
+msgid "ISO C requires a named argument before %<...%>"
+msgstr ""
+
+#: c/c-parser.c:3672
+#, gcc-internal-format
+msgid "expected declaration specifiers or %<...%>"
+msgstr ""
+
+#: c/c-parser.c:3727
+#, gcc-internal-format
+msgid "wide string literal in %<asm%>"
+msgstr ""
+
+#: c/c-parser.c:4196
+#, gcc-internal-format
+msgid "ISO C forbids empty initializer braces"
+msgstr ""
+
+#: c/c-parser.c:4248
+#, gcc-internal-format
+msgid "obsolete use of designated initializer with %<:%>"
+msgstr ""
+
+#: c/c-parser.c:4392
+#, gcc-internal-format
+msgid "ISO C forbids specifying range of elements to initialize"
+msgstr ""
+
+#: c/c-parser.c:4404
+#, gcc-internal-format
+msgid "ISO C90 forbids specifying subobject to initialize"
+msgstr ""
+
+#: c/c-parser.c:4412
+#, gcc-internal-format
+msgid "obsolete use of designated initializer without %<=%>"
+msgstr ""
+
+#: c/c-parser.c:4594
+#, gcc-internal-format
+msgid "ISO C forbids label declarations"
+msgstr ""
+
+#: c/c-parser.c:4600 c/c-parser.c:4677
+#, gcc-internal-format
+msgid "expected declaration or statement"
+msgstr ""
+
+#: c/c-parser.c:4630 c/c-parser.c:4658
+#, gcc-internal-format
+msgid "ISO C90 forbids mixed declarations and code"
+msgstr ""
+
+#: c/c-parser.c:4685
+#, gcc-internal-format
+msgid "expected %<}%> before %<else%>"
+msgstr ""
+
+#: c/c-parser.c:4690 cp/parser.c:10109
+#, gcc-internal-format
+msgid "%<else%> without a previous %<if%>"
+msgstr ""
+
+#: c/c-parser.c:4707
+#, gcc-internal-format
+msgid "label at end of compound statement"
+msgstr ""
+
+#: c/c-parser.c:4764
+#, gcc-internal-format
+msgid "expected %<:%> or %<...%>"
+msgstr "мало бути %<:%> або %<...%>"
+
+#: c/c-parser.c:4795
+#, gcc-internal-format
+msgid "a label can only be part of a statement and a declaration is not a statement"
+msgstr ""
+
+#: c/c-parser.c:4988 cp/parser.c:9714
+#, gcc-internal-format
+msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
+msgstr ""
+
+#: c/c-parser.c:4998 cp/parser.c:9740
+#, gcc-internal-format
+msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
+msgstr ""
+
+#: c/c-parser.c:5025
+#, gcc-internal-format
+msgid "expected identifier or %<*%>"
+msgstr ""
+
+#. Avoid infinite loop in error recovery:
+#. c_parser_skip_until_found stops at a closing nesting
+#. delimiter without consuming it, but here we need to consume
+#. it to proceed further.
+#: c/c-parser.c:5107 cp/parser.c:9814
+#, gcc-internal-format
+msgid "expected statement"
+msgstr ""
+
+#: c/c-parser.c:5201 cp/parser.c:10191
+#, gcc-internal-format
+msgid "suggest braces around empty body in an %<if%> statement"
+msgstr ""
+
+#: c/c-parser.c:5225 cp/parser.c:10214
+#, gcc-internal-format
+msgid "suggest braces around empty body in an %<else%> statement"
+msgstr ""
+
+#: c/c-parser.c:5259
+#, gcc-internal-format
+msgid "if statement cannot contain %<Cilk_spawn%>"
+msgstr ""
+
+#: c/c-parser.c:5388
+#, gcc-internal-format
+msgid "suggest braces around empty body in %<do%> statement"
+msgstr ""
+
+#: c/c-parser.c:5512 c/c-parser.c:5542
+#, gcc-internal-format
+msgid "multiple iterating variables in fast enumeration"
+msgstr ""
+
+#: c/c-parser.c:5566
+#, gcc-internal-format
+msgid "invalid iterating variable in fast enumeration"
+msgstr ""
+
+#: c/c-parser.c:5587 cp/parser.c:10434
+#, gcc-internal-format
+msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
+msgstr ""
+
+#: c/c-parser.c:5619
+#, gcc-internal-format
+msgid "missing collection in fast enumeration"
+msgstr ""
+
+#: c/c-parser.c:5694
+#, gcc-internal-format
+msgid "%E qualifier ignored on asm"
+msgstr ""
+
+#: c/c-parser.c:6044
+#, gcc-internal-format
+msgid "ISO C forbids omitting the middle term of a ?: expression"
+msgstr ""
+
+#: c/c-parser.c:6530
+#, gcc-internal-format
+msgid "traditional C rejects the unary plus operator"
+msgstr "у традиційній мові C не допускається унарний оператор плюс"
+
+#: c/c-parser.c:6659
+#, gcc-internal-format
+msgid "%<sizeof%> applied to a bit-field"
+msgstr ""
+
+#: c/c-parser.c:6737
+#, gcc-internal-format
+msgid "ISO C does not allow %<%E (expression)%>"
+msgstr ""
+
+#: c/c-parser.c:6764
+#, gcc-internal-format
+msgid "cannot take address of %qs"
+msgstr ""
+
+#: c/c-parser.c:6846
+#, gcc-internal-format
+msgid "ISO C99 does not support %<_Generic%>"
+msgstr ""
+
+#: c/c-parser.c:6849
+#, gcc-internal-format
+msgid "ISO C90 does not support %<_Generic%>"
+msgstr ""
+
+#: c/c-parser.c:6915
+#, gcc-internal-format
+msgid "%<_Generic%> association has function type"
+msgstr ""
+
+#: c/c-parser.c:6918
+#, gcc-internal-format
+msgid "%<_Generic%> association has incomplete type"
+msgstr ""
+
+#: c/c-parser.c:6922
+#, gcc-internal-format
+msgid "%<_Generic%> association has variable length type"
+msgstr ""
+
+#: c/c-parser.c:6946
+#, gcc-internal-format
+msgid "duplicate %<default%> case in %<_Generic%>"
+msgstr ""
+
+#: c/c-parser.c:6947
+#, gcc-internal-format
+msgid "original %<default%> is here"
+msgstr ""
+
+#: c/c-parser.c:6955
+#, gcc-internal-format
+msgid "%<_Generic%> specifies two compatible types"
+msgstr ""
+
+#: c/c-parser.c:6956
+#, gcc-internal-format
+msgid "compatible type is here"
+msgstr ""
+
+#: c/c-parser.c:6979
+#, gcc-internal-format
+msgid "%<_Generic> selector matches multiple associations"
+msgstr ""
+
+#: c/c-parser.c:6981
+#, gcc-internal-format
+msgid "other match is here"
+msgstr ""
+
+#: c/c-parser.c:7002
+#, gcc-internal-format
+msgid "%<_Generic%> selector of type %qT is not compatible with any association"
+msgstr ""
+
+#: c/c-parser.c:7157 c/c-parser.c:7692 c/c-parser.c:7711
+#, gcc-internal-format
+msgid "expected expression"
+msgstr "мало бути вказано вираз"
+
+#: c/c-parser.c:7175
+#, gcc-internal-format
+msgid "braced-group within expression allowed only inside a function"
+msgstr ""
+
+#: c/c-parser.c:7188
+#, gcc-internal-format
+msgid "ISO C forbids braced-groups within expressions"
+msgstr ""
+
+#: c/c-parser.c:7232
+#, gcc-internal-format
+msgid "ISO C does not support %<__FUNCTION__%> predefined identifier"
+msgstr ""
+
+#: c/c-parser.c:7240
+#, gcc-internal-format
+msgid "ISO C does not support %<__PRETTY_FUNCTION__%> predefined identifier"
+msgstr ""
+
+#: c/c-parser.c:7248
+#, gcc-internal-format
+msgid "ISO C90 does not support %<__func__%> predefined identifier"
+msgstr ""
+
+#: c/c-parser.c:7399
+#, gcc-internal-format
+msgid "wrong number of arguments to %<__builtin_choose_expr%>"
+msgstr ""
+
+#: c/c-parser.c:7415
+#, gcc-internal-format
+msgid "first argument to %<__builtin_choose_expr%> not a constant"
+msgstr ""
+
+#: c/c-parser.c:7481
+#, gcc-internal-format
+msgid "wrong number of arguments to %<__builtin_call_with_static_chain%>"
+msgstr ""
+
+#: c/c-parser.c:7494
+#, gcc-internal-format
+msgid "first argument to %<__builtin_call_with_static_chain%> must be a call expression"
+msgstr ""
+
+#: c/c-parser.c:7498
+#, gcc-internal-format
+msgid "second argument to %<__builtin_call_with_static_chain%> must be a pointer type"
+msgstr ""
+
+#: c/c-parser.c:7521
+#, gcc-internal-format
+msgid "wrong number of arguments to %<__builtin_complex%>"
+msgstr ""
+
+#: c/c-parser.c:7543
+#, gcc-internal-format
+msgid "%<__builtin_complex%> operand not of real binary floating-point type"
+msgstr ""
+
+#: c/c-parser.c:7552
+#, gcc-internal-format
+msgid "%<__builtin_complex%> operands of different types"
+msgstr ""
+
+#: c/c-parser.c:7597 cp/parser.c:6060
+#, gcc-internal-format
+msgid "wrong number of arguments to %<__builtin_shuffle%>"
+msgstr ""
+
+#: c/c-parser.c:7671 cp/parser.c:6014
+#, gcc-internal-format
+msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
+msgstr ""
+
+#: c/c-parser.c:7678 cp/parser.c:6020
+#, gcc-internal-format
+msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
+msgstr ""
+
+#: c/c-parser.c:7746
+#, gcc-internal-format
+msgid "compound literal has variable size"
+msgstr ""
+
+#: c/c-parser.c:7757
+#, gcc-internal-format
+msgid "compound literal qualified by address-space qualifier"
+msgstr ""
+
+#: c/c-parser.c:7761
+#, gcc-internal-format
+msgid "ISO C90 forbids compound literals"
+msgstr ""
+
+#: c/c-parser.c:7890 cp/parser.c:6306
+#, gcc-internal-format
+msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
+msgstr ""
+
+#: c/c-parser.c:8237
+#, gcc-internal-format
+msgid "expected identifier or %<)%>"
+msgstr ""
+
+#: c/c-parser.c:8333
+#, gcc-internal-format
+msgid "extra semicolon"
+msgstr ""
+
+#: c/c-parser.c:8581
+#, gcc-internal-format
+msgid "extra semicolon in method definition specified"
+msgstr ""
+
+#: c/c-parser.c:8713
+#, gcc-internal-format
+msgid "method attributes must be specified at the end only"
+msgstr ""
+
+#: c/c-parser.c:8733
+#, gcc-internal-format
+msgid "expected %<;%> or %<{%> after method attribute definition"
+msgstr ""
+
+#: c/c-parser.c:8854
+#, gcc-internal-format
+msgid "objective-c method declaration is expected"
+msgstr ""
+
+#: c/c-parser.c:9289
+#, gcc-internal-format
+msgid "no type or storage class may be specified here,"
+msgstr ""
+
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
+#, gcc-internal-format
+msgid "unknown property attribute"
+msgstr ""
+
+#: c/c-parser.c:9400 cp/parser.c:27381
+#, gcc-internal-format
+msgid "missing %<=%> (after %<getter%> attribute)"
+msgstr ""
+
+#: c/c-parser.c:9403 cp/parser.c:27384
+#, gcc-internal-format
+msgid "missing %<=%> (after %<setter%> attribute)"
+msgstr ""
+
+#: c/c-parser.c:9417 cp/parser.c:27399
+#, gcc-internal-format
+msgid "the %<setter%> attribute may only be specified once"
+msgstr ""
+
+#: c/c-parser.c:9422 cp/parser.c:27405
+#, gcc-internal-format
+msgid "setter name must terminate with %<:%>"
+msgstr ""
+
+#: c/c-parser.c:9429 cp/parser.c:27413
+#, gcc-internal-format
+msgid "the %<getter%> attribute may only be specified once"
+msgstr ""
+
+#: c/c-parser.c:9623
+#, gcc-internal-format
+msgid "%<#pragma acc update%> may only be used in compound statements"
+msgstr ""
+
+#: c/c-parser.c:9634 cp/parser.c:32980
+#, gcc-internal-format
+msgid "%<#pragma omp barrier%> may only be used in compound statements"
+msgstr ""
+
+#: c/c-parser.c:9645 cp/parser.c:32995
+#, gcc-internal-format
+msgid "%<#pragma omp flush%> may only be used in compound statements"
+msgstr ""
+
+#: c/c-parser.c:9656 cp/parser.c:33011
+#, gcc-internal-format
+msgid "%<#pragma omp taskwait%> may only be used in compound statements"
+msgstr ""
+
+#: c/c-parser.c:9667 cp/parser.c:33027
+#, gcc-internal-format
+msgid "%<#pragma omp taskyield%> may only be used in compound statements"
+msgstr ""
+
+#: c/c-parser.c:9678 cp/parser.c:33043
+#, gcc-internal-format
+msgid "%<#pragma omp cancel%> may only be used in compound statements"
+msgstr ""
+
+#: c/c-parser.c:9689 cp/parser.c:33059
+#, gcc-internal-format
+msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
+msgstr ""
+
+#: c/c-parser.c:9709 cp/parser.c:33111
+#, gcc-internal-format
+msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
+msgstr ""
+
+#: c/c-parser.c:9724 cp/parser.c:33130
+#, gcc-internal-format
+msgid "for, while or do statement expected"
+msgstr ""
+
+#: c/c-parser.c:9736 cp/parser.c:32970
+#, gcc-internal-format
+msgid "%<#pragma GCC pch_preprocess%> must be first"
+msgstr ""
+
+#: c/c-parser.c:9749
+#, gcc-internal-format
+msgid "%<#pragma grainsize%> ignored because -fcilkplus is not enabled"
+msgstr ""
+
+#: c/c-parser.c:9757
+#, gcc-internal-format
+msgid "%<#pragma grainsize%> must be inside a function"
+msgstr ""
+
+#: c/c-parser.c:10035 cp/parser.c:27769
+#, gcc-internal-format
+msgid "too many %qs clauses"
+msgstr ""
+
+#: c/c-parser.c:10056 cp/parser.c:28111
+#, gcc-internal-format
+msgid "expected integer expression before ')'"
+msgstr ""
+
+#: c/c-parser.c:10071
+#, gcc-internal-format
+msgid "expression must be integral"
+msgstr ""
+
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
+#, gcc-internal-format
+msgid "%qD is not a constant"
+msgstr "%qD не є сталою"
+
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
+#, gcc-internal-format
+msgid "%qD is not a variable"
+msgstr ""
+
+#: c/c-parser.c:10342 cp/parser.c:28044
+#, gcc-internal-format
+msgid "%qD is not a pointer variable"
+msgstr ""
+
+#: c/c-parser.c:10382 cp/parser.c:28189
+#, gcc-internal-format
+msgid "collapse argument needs positive constant integer expression"
+msgstr ""
+
+#: c/c-parser.c:10448 cp/parser.c:28240
+#, gcc-internal-format
+msgid "expected %<none%> or %<shared%>"
+msgstr "мало бути %<none%> або %<shared%>"
+
+#: c/c-parser.c:10583 c/c-parser.c:10628 c/c-parser.c:10673 c/c-parser.c:10717
+#: c/c-parser.c:10955 c/c-parser.c:11018 c/c-parser.c:11095 c/c-parser.c:11139
+#: c/c-parser.c:11441
+#, gcc-internal-format
+msgid "expected integer expression"
+msgstr ""
+
+#: c/c-parser.c:10595
+#, gcc-internal-format
+msgid "%<num_gangs%> value must be positive"
+msgstr ""
+
+#: c/c-parser.c:10640
+#, gcc-internal-format
+msgid "%<num_threads%> value must be positive"
+msgstr ""
+
+#: c/c-parser.c:10685
+#, gcc-internal-format
+msgid "%<num_workers%> value must be positive"
+msgstr "Значення %<num_workers%> має бути додатним"
+
+#: c/c-parser.c:10846
+#, gcc-internal-format
+msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
+msgstr "мало бути %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> або %<max%>"
+
+#: c/c-parser.c:10946 cp/parser.c:28642
+#, gcc-internal-format
+msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
+msgstr ""
+
+#: c/c-parser.c:10950 cp/parser.c:28645
+#, gcc-internal-format
+msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
+msgstr ""
+
+#: c/c-parser.c:10968 cp/parser.c:28661
+#, gcc-internal-format
+msgid "invalid schedule kind"
+msgstr ""
+
+#: c/c-parser.c:11030
+#, gcc-internal-format
+msgid "%<vector_length%> value must be positive"
+msgstr ""
+
+#: c/c-parser.c:11106
+#, gcc-internal-format
+msgid "%<num_teams%> value must be positive"
+msgstr ""
+
+#: c/c-parser.c:11150
+#, gcc-internal-format
+msgid "%<thread_limit%> value must be positive"
+msgstr ""
+
+#: c/c-parser.c:11192 cp/semantics.c:5731
+#, gcc-internal-format
+msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
+msgstr ""
+
+#: c/c-parser.c:11229 cp/parser.c:28833
+#, gcc-internal-format
+msgid "using parameters for %<linear%> step is not supported yet"
+msgstr ""
+
+#: c/c-parser.c:11234
+#, gcc-internal-format
+msgid "%<linear%> clause step expression must be integral"
+msgstr ""
+
+#: c/c-parser.c:11271
+#, gcc-internal-format
+msgid "%<safelen%> clause expression must be positive constant integer expression"
+msgstr ""
+
+#: c/c-parser.c:11307
+#, gcc-internal-format
+msgid "%<simdlen%> clause expression must be positive constant integer expression"
+msgstr ""
+
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
+#, gcc-internal-format
+msgid "invalid depend kind"
+msgstr ""
+
+#: c/c-parser.c:11406 cp/parser.c:28994
+#, gcc-internal-format
+msgid "invalid map kind"
+msgstr ""
+
+#: c/c-parser.c:11471 cp/parser.c:29084
+#, gcc-internal-format
+msgid "invalid dist_schedule kind"
+msgstr ""
+
+#: c/c-parser.c:11540
+#, gcc-internal-format
+msgid "invalid proc_bind kind"
+msgstr ""
+
+#: c/c-parser.c:11703 cp/parser.c:29293
+#, gcc-internal-format
+msgid "expected %<#pragma acc%> clause"
+msgstr ""
+
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
+#, gcc-internal-format
+msgid "%qs is not valid for %qs"
+msgstr ""
+
+#: c/c-parser.c:11840 cp/parser.c:29445
+#, gcc-internal-format
+msgid "%qs must be the first clause of %qs"
+msgstr ""
+
+#: c/c-parser.c:11932 cp/parser.c:29544
+#, gcc-internal-format
+msgid "expected %<#pragma omp%> clause"
+msgstr ""
+
+#: c/c-parser.c:12125 cp/parser.c:31627
+#, gcc-internal-format
+msgid "expected %<data%> in %<#pragma acc enter data%>"
+msgstr ""
+
+#: c/c-parser.c:12134 cp/parser.c:31637
+#, gcc-internal-format
+msgid "invalid pragma"
+msgstr ""
+
+#: c/c-parser.c:12151 cp/parser.c:31654
+#, gcc-internal-format
+msgid "%<#pragma acc enter data%> has no data movement clause"
+msgstr ""
+
+#: c/c-parser.c:12278 cp/parser.c:31793
+#, gcc-internal-format
+msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
+msgstr ""
+
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
+#, gcc-internal-format
+msgid "invalid form of %<#pragma omp atomic%>"
+msgstr ""
+
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
+#, gcc-internal-format
+msgid "invalid operator for %<#pragma omp atomic%>"
+msgstr ""
+
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
+#, gcc-internal-format
+msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
+msgstr ""
+
+#: c/c-parser.c:12767 c/c-parser.c:12788
+#, gcc-internal-format
+msgid "expected %<(%> or end of line"
+msgstr ""
+
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
+#, gcc-internal-format
+msgid "for statement expected"
+msgstr ""
+
+#: c/c-parser.c:12831 cp/parser.c:30457
+#, gcc-internal-format
+msgid "_Cilk_for statement expected"
+msgstr ""
+
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
+#, gcc-internal-format
+msgid "expected iteration declaration or initialization"
+msgstr ""
+
+#: c/c-parser.c:12970
+#, gcc-internal-format
+msgid "not enough perfectly nested loops"
+msgstr ""
+
+#: c/c-parser.c:13026 cp/parser.c:30666
+#, gcc-internal-format
+msgid "collapsed loops not perfectly nested"
+msgstr ""
+
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
+#, gcc-internal-format
+msgid "iteration variable %qD should not be firstprivate"
+msgstr ""
+
+#: c/c-parser.c:13441 cp/parser.c:31010
+#, gcc-internal-format
+msgid "expected %<for%> after %qs"
+msgstr "мало бути %<for%> після %qs"
+
+#: c/c-parser.c:13633 cp/parser.c:31197
+#, gcc-internal-format
+msgid "expected %<point%>"
+msgstr "мало бути %<point%>"
+
+#: c/c-parser.c:13838 cp/parser.c:31420
+#, gcc-internal-format
+msgid "%<#pragma omp target update%> may only be used in compound statements"
+msgstr ""
+
+#: c/c-parser.c:13851 cp/parser.c:31433
+#, gcc-internal-format
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
+msgstr ""
+
+#: c/c-parser.c:13993
+#, gcc-internal-format
+msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
+msgstr ""
+
+#: c/c-parser.c:14044 c/c-parser.c:14072
+#, gcc-internal-format
+msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
+msgstr ""
+
+#: c/c-parser.c:14091 cp/parser.c:31908
+#, gcc-internal-format
+msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
+msgstr ""
+
+#: c/c-parser.c:14104
+#, gcc-internal-format
+msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
+msgstr ""
+
+#: c/c-parser.c:14112 cp/parser.c:31964
+#, gcc-internal-format
+msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
+msgstr ""
+
+#: c/c-parser.c:14210 cp/parser.c:32032
+#, gcc-internal-format
+msgid "expected %<target%>"
+msgstr "мало бути %<target%>"
+
+#: c/c-parser.c:14217 cp/parser.c:32039
+#, gcc-internal-format
+msgid "expected %<declare%>"
+msgstr "мало бути %<declare%>"
+
+#: c/c-parser.c:14223 cp/parser.c:32046
+#, gcc-internal-format
+msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
+msgstr ""
+
+#: c/c-parser.c:14251
+#, gcc-internal-format
+msgid "%<#pragma omp declare reduction%> not at file or block scope"
+msgstr ""
+
+#: c/c-parser.c:14301
+#, gcc-internal-format
+msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
+msgstr ""
+
+#: c/c-parser.c:14328
+#, gcc-internal-format
+msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: c/c-parser.c:14332
+#, gcc-internal-format
+msgid "function or array type in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: c/c-parser.c:14335
+#, gcc-internal-format
+msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: c/c-parser.c:14343
+#, gcc-internal-format
+msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
+msgstr ""
+
+#: c/c-parser.c:14352
+#, gcc-internal-format
+msgid "previous %<#pragma omp declare reduction%>"
+msgstr "попереднє %<#pragma omp declare reduction%>"
+
+#: c/c-parser.c:14469
+#, gcc-internal-format
+msgid "expected %<omp_priv%> or function-name"
+msgstr ""
+
+#: c/c-parser.c:14480
+#, gcc-internal-format
+msgid "expected function-name %<(%>"
+msgstr ""
+
+#: c/c-parser.c:14495
+#, gcc-internal-format
+msgid "one of the initializer call arguments should be %<&omp_priv%>"
+msgstr ""
+
+#: c/c-parser.c:14615 cp/parser.c:32490
+#, gcc-internal-format
+msgid "expected %<simd%> or %<reduction%> or %<target%>"
+msgstr ""
+
+#: c/c-parser.c:14743 cp/semantics.c:6086
+#, gcc-internal-format
+msgid "%qE declared %<threadprivate%> after first use"
+msgstr ""
+
+#: c/c-parser.c:14745 cp/semantics.c:6088
+#, gcc-internal-format
+msgid "automatic variable %qE cannot be %<threadprivate%>"
+msgstr ""
+
+#: c/c-parser.c:14749 cp/semantics.c:6090
+#, gcc-internal-format
+msgid "%<threadprivate%> %qE has incomplete type"
+msgstr ""
+
+#: c/c-parser.c:14780
+#, gcc-internal-format
+msgid "pragma simd ignored because -fcilkplus is not enabled"
+msgstr ""
+
+#: c/c-parser.c:14786
+#, gcc-internal-format
+msgid "pragma simd must be inside a function"
+msgstr ""
+
+#: c/c-parser.c:14830 cp/parser.c:33267
+#, gcc-internal-format
+msgid "vectorlength must be an integer constant"
+msgstr ""
+
+#: c/c-parser.c:14832 cp/parser.c:33270
+#, gcc-internal-format
+msgid "vectorlength must be a power of 2"
+msgstr ""
+
+#: c/c-parser.c:14915 cp/parser.c:33377
+#, gcc-internal-format
+msgid "step size must be an integer constant expression or an integer variable"
+msgstr ""
+
+#: c/c-parser.c:15014 cp/parser.c:33470
+#, gcc-internal-format
+msgid "expected %<#pragma simd%> clause"
+msgstr ""
+
+#: c/c-parser.c:15058 cp/parser.c:32943
+#, gcc-internal-format
+msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
+msgstr ""
+
+#: c/c-parser.c:15355 cp/parser.c:32835
+#, gcc-internal-format
+msgid "%<__transaction_cancel%> without transactional memory support enabled"
+msgstr ""
+
+#: c/c-parser.c:15361 cp/parser.c:32841
+#, gcc-internal-format
+msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
+msgstr ""
+
+#: c/c-parser.c:15370 cp/parser.c:32850
+#, gcc-internal-format
+msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
+msgstr ""
+
+#: c/c-parser.c:15372 cp/parser.c:32853
+#, gcc-internal-format
+msgid "  or a %<transaction_may_cancel_outer%> function"
+msgstr ""
+
+#: c/c-parser.c:15378 cp/parser.c:32859
+#, gcc-internal-format
+msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
+msgstr ""
+
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
+#, gcc-internal-format
+msgid "base of array section must be pointer or array type"
+msgstr ""
+
+#: c/c-parser.c:15455 cp/parser.c:6476
+#, gcc-internal-format
+msgid "expected %<:%> or numeral"
+msgstr ""
+
+#: c/c-parser.c:15466
+#, gcc-internal-format
+msgid "start-index and length fields necessary for using array notations in pointers"
+msgstr ""
+
+#: c/c-parser.c:15473 c/c-parser.c:15516
+#, gcc-internal-format
+msgid "array notations cannot be used with function type"
+msgstr ""
+
+#: c/c-parser.c:15482
+#, gcc-internal-format
+msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
+msgstr ""
+
+#: c/c-parser.c:15494
+#, gcc-internal-format
+msgid "start-index and length fields necessary for using array notations in variable-length arrays"
+msgstr ""
+
+#: c/c-parser.c:15544 c/c-parser.c:15547
+#, gcc-internal-format
+msgid "expected array notation expression"
+msgstr ""
+
+#: c/c-typeck.c:240
+#, gcc-internal-format
+msgid "%qD has an incomplete type"
+msgstr ""
+
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
+#, gcc-internal-format
+msgid "invalid use of void expression"
+msgstr ""
+
+#: c/c-typeck.c:269
+#, gcc-internal-format
+msgid "invalid use of flexible array member"
+msgstr ""
+
+#: c/c-typeck.c:275 cp/typeck2.c:517
+#, gcc-internal-format
+msgid "invalid use of array with unspecified bounds"
+msgstr ""
+
+#: c/c-typeck.c:283
+#, gcc-internal-format
+msgid "invalid use of undefined type %<%s %E%>"
+msgstr ""
+
+#. If this type has a typedef-name, the TYPE_NAME is a TYPE_DECL.
+#: c/c-typeck.c:287
+#, gcc-internal-format
+msgid "invalid use of incomplete typedef %qD"
+msgstr ""
+
+#: c/c-typeck.c:360
+#, gcc-internal-format
+msgid "%qT and %qT are in disjoint named address spaces"
+msgstr ""
+
+#: c/c-typeck.c:599 c/c-typeck.c:624
+#, gcc-internal-format
+msgid "function types not truly compatible in ISO C"
+msgstr ""
+
+#: c/c-typeck.c:768
+#, gcc-internal-format
+msgid "can%'t mix operands of decimal float and vector types"
+msgstr ""
+
+#: c/c-typeck.c:773
+#, gcc-internal-format
+msgid "can%'t mix operands of decimal float and complex types"
+msgstr ""
+
+#: c/c-typeck.c:778
+#, gcc-internal-format
+msgid "can%'t mix operands of decimal float and other float types"
+msgstr ""
+
+#: c/c-typeck.c:1275
+#, gcc-internal-format
+msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
+msgstr ""
+
+#: c/c-typeck.c:1279
+#, gcc-internal-format
+msgid "types are not quite compatible"
+msgstr ""
+
+#: c/c-typeck.c:1283
+#, gcc-internal-format
+msgid "pointer target types incompatible in C++"
+msgstr ""
+
+#: c/c-typeck.c:1615
+#, gcc-internal-format
+msgid "function return types not compatible due to %<volatile%>"
+msgstr ""
+
+#: c/c-typeck.c:1865
+#, gcc-internal-format
+msgid "converting an array compound literal to a pointer is ill-formed in C++"
+msgstr ""
+
+#: c/c-typeck.c:2312
+#, gcc-internal-format
+msgid "%qT has no member named %qE"
+msgstr ""
+
+#: c/c-typeck.c:2366
+#, gcc-internal-format
+msgid "request for member %qE in something not a structure or union"
+msgstr ""
+
+#: c/c-typeck.c:2417
+#, gcc-internal-format
+msgid "dereferencing pointer to incomplete type %qT"
+msgstr ""
+
+#: c/c-typeck.c:2424
+#, gcc-internal-format
+msgid "dereferencing %<void *%> pointer"
+msgstr ""
+
+#: c/c-typeck.c:2477
+#, gcc-internal-format
+msgid "rank of the array's index is greater than 1"
+msgstr ""
+
+#: c/c-typeck.c:2491
+#, gcc-internal-format
+msgid "subscripted value is neither array nor pointer nor vector"
+msgstr ""
+
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
+#, gcc-internal-format
+msgid "array subscript is not an integer"
+msgstr ""
+
+#: c/c-typeck.c:2509
+#, gcc-internal-format
+msgid "subscripted value is pointer to function"
+msgstr ""
+
+#: c/c-typeck.c:2562
+#, gcc-internal-format
+msgid "ISO C forbids subscripting %<register%> array"
+msgstr ""
+
+#: c/c-typeck.c:2565
+#, gcc-internal-format
+msgid "ISO C90 forbids subscripting non-lvalue array"
+msgstr ""
+
+#: c/c-typeck.c:2679
+#, gcc-internal-format
+msgid "enum constant defined here"
+msgstr ""
+
+#: c/c-typeck.c:2786 cp/typeck.c:1641
+#, gcc-internal-format
+msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
+msgstr ""
+
+#: c/c-typeck.c:2935
+#, gcc-internal-format
+msgid "called object %qE is not a function or function pointer"
+msgstr ""
+
+#: c/c-typeck.c:2940
+#, gcc-internal-format
+msgid "called object %qD is not a function or function pointer"
+msgstr ""
+
+#: c/c-typeck.c:2946
+#, gcc-internal-format
+msgid "called object is not a function or function pointer"
+msgstr ""
+
+#. This situation leads to run-time undefined behavior.  We can't,
+#. therefore, simply error unless we can prove that all possible
+#. executions of the program must execute the code.
+#: c/c-typeck.c:2976
+#, gcc-internal-format
+msgid "function called through a non-compatible type"
+msgstr ""
+
+#: c/c-typeck.c:2981 c/c-typeck.c:3018
+#, gcc-internal-format
+msgid "function with qualified void return type called"
+msgstr ""
+
+#: c/c-typeck.c:3142
+#, gcc-internal-format
+msgid "too many arguments to method %qE"
+msgstr ""
+
+#: c/c-typeck.c:3180
+#, gcc-internal-format, gfc-internal-format
+msgid "type of formal parameter %d is incomplete"
+msgstr ""
+
+#: c/c-typeck.c:3197
+#, gcc-internal-format
+msgid "passing argument %d of %qE as integer rather than floating due to prototype"
+msgstr ""
+
+#: c/c-typeck.c:3203
+#, gcc-internal-format
+msgid "passing argument %d of %qE as integer rather than complex due to prototype"
+msgstr ""
+
+#: c/c-typeck.c:3209
+#, gcc-internal-format
+msgid "passing argument %d of %qE as complex rather than floating due to prototype"
+msgstr ""
+
+#: c/c-typeck.c:3215
+#, gcc-internal-format
+msgid "passing argument %d of %qE as floating rather than integer due to prototype"
+msgstr ""
+
+#: c/c-typeck.c:3221
+#, gcc-internal-format
+msgid "passing argument %d of %qE as complex rather than integer due to prototype"
+msgstr ""
+
+#: c/c-typeck.c:3227
+#, gcc-internal-format
+msgid "passing argument %d of %qE as floating rather than complex due to prototype"
+msgstr ""
+
+#: c/c-typeck.c:3241
+#, gcc-internal-format
+msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
+msgstr ""
+
+#: c/c-typeck.c:3267
+#, gcc-internal-format
+msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
+msgstr ""
+
+#: c/c-typeck.c:3289
+#, gcc-internal-format
+msgid "passing argument %d of %qE with different width due to prototype"
+msgstr ""
+
+#: c/c-typeck.c:3313
+#, gcc-internal-format
+msgid "passing argument %d of %qE as unsigned due to prototype"
+msgstr ""
+
+#: c/c-typeck.c:3318
+#, gcc-internal-format
+msgid "passing argument %d of %qE as signed due to prototype"
+msgstr ""
+
+#: c/c-typeck.c:3354 cp/call.c:6627
+#, gcc-internal-format
+msgid "implicit conversion from %qT to %qT when passing argument to function"
+msgstr ""
+
+#: c/c-typeck.c:3500 c/c-typeck.c:3505
+#, gcc-internal-format
+msgid "comparison with string literal results in unspecified behavior"
+msgstr ""
+
+#: c/c-typeck.c:3519
+#, gcc-internal-format
+msgid "comparison between %qT and %qT"
+msgstr ""
+
+#: c/c-typeck.c:3568
+#, gcc-internal-format
+msgid "pointer of type %<void *%> used in subtraction"
+msgstr ""
+
+#: c/c-typeck.c:3571
+#, gcc-internal-format
+msgid "pointer to a function used in subtraction"
+msgstr ""
+
+#: c/c-typeck.c:3583
+#, gcc-internal-format
+msgid "arithmetic on pointer to an incomplete type"
+msgstr ""
+
+#: c/c-typeck.c:3588 cp/typeck.c:5137
+#, gcc-internal-format
+msgid "arithmetic on pointer to an empty aggregate"
+msgstr ""
+
+#: c/c-typeck.c:3904
+#, gcc-internal-format
+msgid "ISO C does not support %<~%> for complex conjugation"
+msgstr ""
+
+#: c/c-typeck.c:3943
+#, gcc-internal-format
+msgid "wrong type argument to unary exclamation mark"
+msgstr ""
+
+#: c/c-typeck.c:4000
+#, gcc-internal-format
+msgid "increment of enumeration value is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.c:4003
+#, gcc-internal-format
+msgid "decrement of enumeration value is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.c:4019
+#, gcc-internal-format
+msgid "ISO C does not support %<++%> and %<--%> on complex types"
+msgstr ""
+
+#: c/c-typeck.c:4042 c/c-typeck.c:4076
+#, gcc-internal-format
+msgid "wrong type argument to increment"
+msgstr ""
+
+#: c/c-typeck.c:4044 c/c-typeck.c:4079
+#, gcc-internal-format
+msgid "wrong type argument to decrement"
+msgstr ""
+
+#: c/c-typeck.c:4064
+#, gcc-internal-format
+msgid "increment of pointer to an incomplete type %qT"
+msgstr ""
+
+#: c/c-typeck.c:4068
+#, gcc-internal-format
+msgid "decrement of pointer to an incomplete type %qT"
+msgstr ""
+
+#: c/c-typeck.c:4173
+#, gcc-internal-format
+msgid "taking address of expression of type %<void%>"
+msgstr ""
+
+#: c/c-typeck.c:4379
+#, gcc-internal-format
+msgid "cannot take address of bit-field %qD"
+msgstr ""
+
+#: c/c-typeck.c:4407
+#, gcc-internal-format
+msgid "global register variable %qD used in nested function"
+msgstr ""
+
+#: c/c-typeck.c:4410
+#, gcc-internal-format
+msgid "register variable %qD used in nested function"
+msgstr ""
+
+#: c/c-typeck.c:4415
+#, gcc-internal-format
+msgid "address of global register variable %qD requested"
+msgstr ""
+
+#: c/c-typeck.c:4417
+#, gcc-internal-format
+msgid "address of register variable %qD requested"
+msgstr ""
+
+#: c/c-typeck.c:4512
+#, gcc-internal-format
+msgid "non-lvalue array in conditional expression"
+msgstr ""
+
+#: c/c-typeck.c:4568 cp/call.c:5037
+#, gcc-internal-format
+msgid "implicit conversion from %qT to %qT to match other result of conditional"
+msgstr ""
+
+#: c/c-typeck.c:4642
+#, gcc-internal-format
+msgid "ISO C forbids conditional expr with only one void side"
+msgstr ""
+
+#: c/c-typeck.c:4659
+#, gcc-internal-format
+msgid "pointers to disjoint address spaces used in conditional expression"
+msgstr ""
+
+#: c/c-typeck.c:4670 c/c-typeck.c:4687
+#, gcc-internal-format
+msgid "pointer to array loses qualifier in conditional expression"
+msgstr ""
+
+#: c/c-typeck.c:4675 c/c-typeck.c:4692
+#, gcc-internal-format
+msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
+msgstr ""
+
+#: c/c-typeck.c:4705
+#, gcc-internal-format
+msgid "pointer type mismatch in conditional expression"
+msgstr ""
+
+#: c/c-typeck.c:4714 c/c-typeck.c:4725
+#, gcc-internal-format
+msgid "pointer/integer type mismatch in conditional expression"
+msgstr ""
+
+#: c/c-typeck.c:4816 cp/typeck.c:6268
+#, gcc-internal-format
+msgid "spawned function call cannot be part of a comma expression"
+msgstr ""
+
+#: c/c-typeck.c:4850
+#, gcc-internal-format
+msgid "left-hand operand of comma expression has no effect"
+msgstr ""
+
+#: c/c-typeck.c:4868 c/c-typeck.c:9945
+#, gcc-internal-format
+msgid "right-hand operand of comma expression has no effect"
+msgstr ""
+
+#: c/c-typeck.c:4937
+msgid "cast adds %q#v qualifier to function type"
+msgstr ""
+
+#: c/c-typeck.c:4943
+msgid "cast discards %qv qualifier from pointer target type"
+msgstr ""
+
+#: c/c-typeck.c:4978
+#, gcc-internal-format
+msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
+msgstr ""
+
+#: c/c-typeck.c:5015
+#, gcc-internal-format
+msgid "cast specifies array type"
+msgstr ""
+
+#: c/c-typeck.c:5021
+#, gcc-internal-format
+msgid "cast specifies function type"
+msgstr ""
+
+#: c/c-typeck.c:5037
+#, gcc-internal-format
+msgid "ISO C forbids casting nonscalar to the same type"
+msgstr ""
+
+#: c/c-typeck.c:5057
+#, gcc-internal-format
+msgid "ISO C forbids casts to union type"
+msgstr ""
+
+#: c/c-typeck.c:5067
+#, gcc-internal-format
+msgid "cast to union type from type not present in union"
+msgstr ""
+
+#: c/c-typeck.c:5102
+#, gcc-internal-format, gfc-internal-format
+msgid "cast to %s address space pointer from disjoint generic address space pointer"
+msgstr ""
+
+#: c/c-typeck.c:5107
+#, gcc-internal-format, gfc-internal-format
+msgid "cast to generic address space pointer from disjoint %s address space pointer"
+msgstr ""
+
+#: c/c-typeck.c:5112
+#, gcc-internal-format, gfc-internal-format
+msgid "cast to %s address space pointer from disjoint %s address space pointer"
+msgstr ""
+
+#: c/c-typeck.c:5132
+#, gcc-internal-format
+msgid "cast increases required alignment of target type"
+msgstr ""
+
+#: c/c-typeck.c:5143
+#, gcc-internal-format
+msgid "cast from pointer to integer of different size"
+msgstr ""
+
+#: c/c-typeck.c:5148
+#, gcc-internal-format
+msgid "cast from function call of type %qT to non-matching type %qT"
+msgstr ""
+
+#: c/c-typeck.c:5157 cp/typeck.c:7223
+#, gcc-internal-format
+msgid "cast to pointer from integer of different size"
+msgstr ""
+
+#: c/c-typeck.c:5171
+#, gcc-internal-format
+msgid "ISO C forbids conversion of function pointer to object pointer type"
+msgstr ""
+
+#: c/c-typeck.c:5180
+#, gcc-internal-format
+msgid "ISO C forbids conversion of object pointer to function pointer type"
+msgstr ""
+
+#: c/c-typeck.c:5264
+#, gcc-internal-format
+msgid "defining a type in a cast is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.c:5306
+#, gcc-internal-format
+msgid "assignment to expression with array type"
+msgstr ""
+
+#: c/c-typeck.c:5430 c/c-typeck.c:5860
+#, gcc-internal-format
+msgid "enum conversion in assignment is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.c:5626 c/c-typeck.c:5644 c/c-typeck.c:5663
+#, gcc-internal-format
+msgid "(near initialization for %qs)"
+msgstr ""
+
+#: c/c-typeck.c:5678
+#, gcc-internal-format
+msgid "array initialized from parenthesized string constant"
+msgstr ""
+
+#. This macro is used to emit diagnostics to ensure that all format
+#. strings are complete sentences, visible to gettext and checked at
+#. compile time.
+#. This macro is used to emit diagnostics to ensure that all format
+#. strings are complete sentences, visible to gettext and checked at
+#. compile time.  It is the same as PEDWARN_FOR_ASSIGNMENT but with an
+#. extra parameter to enumerate qualifiers.
+#. This macro is used to emit diagnostics to ensure that all format
+#. strings are complete sentences, visible to gettext and checked at
+#. compile time.  It is the same as PEDWARN_FOR_QUALIFIERS but uses
+#. warning_at instead of pedwarn.
+#: c/c-typeck.c:5740 c/c-typeck.c:5769 c/c-typeck.c:5798 c/c-typeck.c:6372
+#, gcc-internal-format
+msgid "expected %qT but argument is of type %qT"
+msgstr ""
+
+#: c/c-typeck.c:5858
+#, gcc-internal-format
+msgid "enum conversion when passing argument %d of %qE is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.c:5862 c/c-typeck.c:8465
+#, gcc-internal-format
+msgid "enum conversion in initialization is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.c:5864
+#, gcc-internal-format
+msgid "enum conversion in return is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.c:5891
+#, gcc-internal-format
+msgid "cannot pass rvalue to reference parameter"
+msgstr ""
+
+#: c/c-typeck.c:6024 c/c-typeck.c:6289
+msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
+msgstr ""
+
+#: c/c-typeck.c:6027 c/c-typeck.c:6292
+msgid "assignment makes %q#v qualified function pointer from unqualified"
+msgstr ""
+
+#: c/c-typeck.c:6030 c/c-typeck.c:6294
+msgid "initialization makes %q#v qualified function pointer from unqualified"
+msgstr ""
+
+#: c/c-typeck.c:6033 c/c-typeck.c:6296
+msgid "return makes %q#v qualified function pointer from unqualified"
+msgstr ""
+
+#: c/c-typeck.c:6041 c/c-typeck.c:6208 c/c-typeck.c:6251
+msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
+msgstr ""
+
+#: c/c-typeck.c:6043 c/c-typeck.c:6210 c/c-typeck.c:6253
+msgid "assignment discards %qv qualifier from pointer target type"
+msgstr ""
+
+#: c/c-typeck.c:6045 c/c-typeck.c:6212 c/c-typeck.c:6255
+msgid "initialization discards %qv qualifier from pointer target type"
+msgstr ""
+
+#: c/c-typeck.c:6047 c/c-typeck.c:6214 c/c-typeck.c:6257
+msgid "return discards %qv qualifier from pointer target type"
+msgstr ""
+
+#: c/c-typeck.c:6056
+#, gcc-internal-format
+msgid "ISO C prohibits argument conversion to union type"
+msgstr ""
+
+#: c/c-typeck.c:6118
+#, gcc-internal-format
+msgid "request for implicit conversion from %qT to %qT not permitted in C++"
+msgstr ""
+
+#: c/c-typeck.c:6130
+#, gcc-internal-format
+msgid "passing argument %d of %qE from pointer to non-enclosed address space"
+msgstr ""
+
+#: c/c-typeck.c:6134
+#, gcc-internal-format
+msgid "assignment from pointer to non-enclosed address space"
+msgstr ""
+
+#: c/c-typeck.c:6138
+#, gcc-internal-format
+msgid "initialization from pointer to non-enclosed address space"
+msgstr ""
+
+#: c/c-typeck.c:6142
+#, gcc-internal-format
+msgid "return from pointer to non-enclosed address space"
+msgstr ""
+
+#: c/c-typeck.c:6160
+#, gcc-internal-format
+msgid "argument %d of %qE might be a candidate for a format attribute"
+msgstr ""
+
+#: c/c-typeck.c:6166
+#, gcc-internal-format
+msgid "assignment left-hand side might be a candidate for a format attribute"
+msgstr ""
+
+#: c/c-typeck.c:6171
+#, gcc-internal-format
+msgid "initialization left-hand side might be a candidate for a format attribute"
+msgstr ""
+
+#: c/c-typeck.c:6176 cp/typeck.c:8223
+#, gcc-internal-format
+msgid "return type might be a candidate for a format attribute"
+msgstr ""
+
+#: c/c-typeck.c:6225
+#, gcc-internal-format
+msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
+msgstr ""
+
+#: c/c-typeck.c:6228
+#, gcc-internal-format
+msgid "ISO C forbids assignment between function pointer and %<void *%>"
+msgstr ""
+
+#: c/c-typeck.c:6230
+#, gcc-internal-format
+msgid "ISO C forbids initialization between function pointer and %<void *%>"
+msgstr ""
+
+#: c/c-typeck.c:6232
+#, gcc-internal-format
+msgid "ISO C forbids return between function pointer and %<void *%>"
+msgstr ""
+
+#: c/c-typeck.c:6269
+#, gcc-internal-format
+msgid "pointer targets in passing argument %d of %qE differ in signedness"
+msgstr ""
+
+#: c/c-typeck.c:6271
+#, gcc-internal-format
+msgid "pointer targets in assignment differ in signedness"
+msgstr ""
+
+#: c/c-typeck.c:6273
+#, gcc-internal-format
+msgid "pointer targets in initialization differ in signedness"
+msgstr ""
+
+#: c/c-typeck.c:6275
+#, gcc-internal-format
+msgid "pointer targets in return differ in signedness"
+msgstr ""
+
+#: c/c-typeck.c:6306
+#, gcc-internal-format
+msgid "passing argument %d of %qE from incompatible pointer type"
+msgstr ""
+
+#: c/c-typeck.c:6308
+#, gcc-internal-format
+msgid "assignment from incompatible pointer type"
+msgstr ""
+
+#: c/c-typeck.c:6309
+#, gcc-internal-format
+msgid "initialization from incompatible pointer type"
+msgstr ""
+
+#: c/c-typeck.c:6311
+#, gcc-internal-format
+msgid "return from incompatible pointer type"
+msgstr ""
+
+#. ??? This should not be an error when inlining calls to
+#. unprototyped functions.
+#: c/c-typeck.c:6319 c/c-typeck.c:6813 cp/typeck.c:1981
+#, gcc-internal-format
+msgid "invalid use of non-lvalue array"
+msgstr ""
+
+#: c/c-typeck.c:6330
+#, gcc-internal-format
+msgid "passing argument %d of %qE makes pointer from integer without a cast"
+msgstr ""
+
+#: c/c-typeck.c:6332
+#, gcc-internal-format
+msgid "assignment makes pointer from integer without a cast"
+msgstr ""
+
+#: c/c-typeck.c:6334
+#, gcc-internal-format
+msgid "initialization makes pointer from integer without a cast"
+msgstr ""
+
+#: c/c-typeck.c:6336
+#, gcc-internal-format
+msgid "return makes pointer from integer without a cast"
+msgstr ""
+
+#: c/c-typeck.c:6345
+#, gcc-internal-format
+msgid "passing argument %d of %qE makes integer from pointer without a cast"
+msgstr ""
+
+#: c/c-typeck.c:6347
+#, gcc-internal-format
+msgid "assignment makes integer from pointer without a cast"
+msgstr ""
+
+#: c/c-typeck.c:6349
+#, gcc-internal-format
+msgid "initialization makes integer from pointer without a cast"
+msgstr ""
+
+#: c/c-typeck.c:6351
+#, gcc-internal-format
+msgid "return makes integer from pointer without a cast"
+msgstr ""
+
+#: c/c-typeck.c:6375
+#, gcc-internal-format
+msgid "incompatible types when assigning to type %qT from type %qT"
+msgstr ""
+
+#: c/c-typeck.c:6380
+#, gcc-internal-format
+msgid "incompatible types when initializing type %qT using type %qT"
+msgstr ""
+
+#: c/c-typeck.c:6385
+#, gcc-internal-format
+msgid "incompatible types when returning type %qT but %qT was expected"
+msgstr ""
+
+#: c/c-typeck.c:6449
+#, gcc-internal-format
+msgid "traditional C rejects automatic aggregate initialization"
+msgstr ""
+
+#: c/c-typeck.c:6686 c/c-typeck.c:7577
+#, gcc-internal-format
+msgid "initialization of a flexible array member"
+msgstr ""
+
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
+#, gcc-internal-format
+msgid "char-array initialized from wide string"
+msgstr ""
+
+#: c/c-typeck.c:6705
+#, gcc-internal-format
+msgid "wide character array initialized from non-wide string"
+msgstr ""
+
+#: c/c-typeck.c:6711
+#, gcc-internal-format
+msgid "wide character array initialized from incompatible wide string"
+msgstr ""
+
+#: c/c-typeck.c:6745
+#, gcc-internal-format
+msgid "array of inappropriate type initialized from string constant"
+msgstr ""
+
+#: c/c-typeck.c:6832 c/c-typeck.c:6856 c/c-typeck.c:6859 c/c-typeck.c:6867
+#: c/c-typeck.c:6907 c/c-typeck.c:8407 c/c-typeck.c:8438
+#, gcc-internal-format
+msgid "initializer element is not constant"
+msgstr ""
+
+#: c/c-typeck.c:6841
+#, gcc-internal-format
+msgid "array initialized from non-constant array expression"
+msgstr ""
+
+#: c/c-typeck.c:6872 c/c-typeck.c:6920 c/c-typeck.c:8448
+#, gcc-internal-format
+msgid "initializer element is not a constant expression"
+msgstr ""
+
+#: c/c-typeck.c:6914 c/c-typeck.c:8443
+#, gcc-internal-format
+msgid "initializer element is not computable at load time"
+msgstr ""
+
+#: c/c-typeck.c:6933
+#, gcc-internal-format
+msgid "invalid initializer"
+msgstr ""
+
+#: c/c-typeck.c:7211 cp/decl.c:5929
+#, gcc-internal-format
+msgid "opaque vector types cannot be initialized"
+msgstr ""
+
+#: c/c-typeck.c:7435
+#, gcc-internal-format
+msgid "extra brace group at end of initializer"
+msgstr ""
+
+#: c/c-typeck.c:7514
+#, gcc-internal-format
+msgid "braces around scalar initializer"
+msgstr ""
+
+#: c/c-typeck.c:7574 c/c-typeck.c:8880
+#, gcc-internal-format
+msgid "initialization of flexible array member in a nested context"
+msgstr ""
+
+#: c/c-typeck.c:7608
+#, gcc-internal-format
+msgid "missing braces around initializer"
+msgstr ""
+
+#: c/c-typeck.c:7630
+#, gcc-internal-format
+msgid "missing initializer for field %qD of %qT"
+msgstr ""
+
+#: c/c-typeck.c:7655
+#, gcc-internal-format
+msgid "empty scalar initializer"
+msgstr ""
+
+#: c/c-typeck.c:7660
+#, gcc-internal-format
+msgid "extra elements in scalar initializer"
+msgstr ""
+
+#: c/c-typeck.c:7772 c/c-typeck.c:7853
+#, gcc-internal-format
+msgid "array index in non-array initializer"
+msgstr ""
+
+#: c/c-typeck.c:7777 c/c-typeck.c:7916
+#, gcc-internal-format
+msgid "field name not in record or union initializer"
+msgstr ""
+
+#: c/c-typeck.c:7826
+#, gcc-internal-format
+msgid "array index in initializer not of integer type"
+msgstr ""
+
+#: c/c-typeck.c:7835 c/c-typeck.c:7844
+#, gcc-internal-format
+msgid "array index in initializer is not an integer constant expression"
+msgstr ""
+
+#: c/c-typeck.c:7849 c/c-typeck.c:7851
+#, gcc-internal-format
+msgid "nonconstant array index in initializer"
+msgstr ""
+
+#: c/c-typeck.c:7855 c/c-typeck.c:7858
+#, gcc-internal-format
+msgid "array index in initializer exceeds array bounds"
+msgstr ""
+
+#: c/c-typeck.c:7877
+#, gcc-internal-format
+msgid "empty index range in initializer"
+msgstr ""
+
+#: c/c-typeck.c:7886
+#, gcc-internal-format
+msgid "array index range in initializer exceeds array bounds"
+msgstr ""
+
+#: c/c-typeck.c:7923
+#, gcc-internal-format
+msgid "unknown field %qE specified in initializer"
+msgstr ""
+
+#: c/c-typeck.c:7976 c/c-typeck.c:8006 c/c-typeck.c:8538
+#, gcc-internal-format
+msgid "initialized field with side-effects overwritten"
+msgstr ""
+
+#: c/c-typeck.c:7980 c/c-typeck.c:8010 c/c-typeck.c:8541
+#, gcc-internal-format
+msgid "initialized field overwritten"
+msgstr ""
+
+#: c/c-typeck.c:8762
+#, gcc-internal-format
+msgid "excess elements in char array initializer"
+msgstr ""
+
+#: c/c-typeck.c:8769 c/c-typeck.c:8839
+#, gcc-internal-format
+msgid "excess elements in struct initializer"
+msgstr ""
+
+#: c/c-typeck.c:8784
+#, gcc-internal-format
+msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
+msgstr ""
+
+#: c/c-typeck.c:8854
+#, gcc-internal-format
+msgid "non-static initialization of a flexible array member"
+msgstr ""
+
+#: c/c-typeck.c:8953
+#, gcc-internal-format
+msgid "excess elements in union initializer"
+msgstr ""
+
+#: c/c-typeck.c:8975
+#, gcc-internal-format
+msgid "traditional C rejects initialization of unions"
+msgstr ""
+
+#: c/c-typeck.c:9043
+#, gcc-internal-format
+msgid "excess elements in array initializer"
+msgstr ""
+
+#: c/c-typeck.c:9077
+#, gcc-internal-format
+msgid "excess elements in vector initializer"
+msgstr ""
+
+#: c/c-typeck.c:9109
+#, gcc-internal-format
+msgid "excess elements in scalar initializer"
+msgstr ""
+
+#: c/c-typeck.c:9349
+#, gcc-internal-format
+msgid "ISO C forbids %<goto *expr;%>"
+msgstr ""
+
+#: c/c-typeck.c:9373 cp/typeck.c:8446
+#, gcc-internal-format
+msgid "function declared %<noreturn%> has a %<return%> statement"
+msgstr ""
+
+#: c/c-typeck.c:9383 cp/cp-array-notation.c:1103
+#, gcc-internal-format
+msgid "array notation expression cannot be used as a return value"
+msgstr ""
+
+#: c/c-typeck.c:9390 cp/typeck.c:8437
+#, gcc-internal-format
+msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
+msgstr ""
+
+#: c/c-typeck.c:9415 c/c-typeck.c:9418
+#, gcc-internal-format
+msgid "%<return%> with no value, in function returning non-void"
+msgstr ""
+
+#: c/c-typeck.c:9428
+#, gcc-internal-format
+msgid "%<return%> with a value, in function returning void"
+msgstr ""
+
+#: c/c-typeck.c:9430
+#, gcc-internal-format
+msgid "ISO C forbids %<return%> with expression, in function returning void"
+msgstr ""
+
+#: c/c-typeck.c:9503
+#, gcc-internal-format
+msgid "function returns address of label"
+msgstr ""
+
+#: c/c-typeck.c:9585 cp/semantics.c:1163
+#, gcc-internal-format
+msgid "switch quantity not an integer"
+msgstr ""
+
+#: c/c-typeck.c:9605
+#, gcc-internal-format
+msgid "switch condition has boolean value"
+msgstr ""
+
+#: c/c-typeck.c:9611
+#, gcc-internal-format
+msgid "%<long%> switch expression not converted to %<int%> in ISO C"
+msgstr ""
+
+#: c/c-typeck.c:9647 c/c-typeck.c:9655
+#, gcc-internal-format
+msgid "case label is not an integer constant expression"
+msgstr ""
+
+#: c/c-typeck.c:9661 cp/parser.c:9932
+#, gcc-internal-format
+msgid "case label not within a switch statement"
+msgstr ""
+
+#: c/c-typeck.c:9663
+#, gcc-internal-format
+msgid "%<default%> label not within a switch statement"
+msgstr ""
+
+#: c/c-typeck.c:9733
+#, gcc-internal-format
+msgid "rank-mismatch between if-statement%'s condition and the then-block"
+msgstr ""
+
+#: c/c-typeck.c:9739
+#, gcc-internal-format
+msgid "rank-mismatch between if-statement%'s condition and the else-block"
+msgstr ""
+
+#: c/c-typeck.c:9775 cp/parser.c:10240
+#, gcc-internal-format
+msgid "suggest explicit braces to avoid ambiguous %<else%>"
+msgstr ""
+
+#: c/c-typeck.c:9887 cp/parser.c:11013
+#, gcc-internal-format
+msgid "break statement not within loop or switch"
+msgstr ""
+
+#: c/c-typeck.c:9889 cp/parser.c:11039
+#, gcc-internal-format
+msgid "continue statement not within a loop"
+msgstr ""
+
+#: c/c-typeck.c:9894 cp/parser.c:11026
+#, gcc-internal-format
+msgid "break statement used with OpenMP for loop"
+msgstr ""
+
+#: c/c-typeck.c:9899
+#, gcc-internal-format
+msgid "break statement within %<#pragma simd%> loop body"
+msgstr ""
+
+#: c/c-typeck.c:9901 cp/parser.c:11043
+#, gcc-internal-format
+msgid "continue statement within %<#pragma simd%> loop body"
+msgstr ""
+
+#: c/c-typeck.c:9927 cp/cp-gimplify.c:439
+#, gcc-internal-format
+msgid "statement with no effect"
+msgstr ""
+
+#: c/c-typeck.c:9971
+#, gcc-internal-format
+msgid "expression statement has incomplete type"
+msgstr ""
+
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
+#, gcc-internal-format
+msgid "comparing vectors with different element types"
+msgstr ""
+
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
+#, gcc-internal-format
+msgid "comparing vectors with different number of elements"
+msgstr ""
+
+#: c/c-typeck.c:10760 cp/typeck.c:4383
+#, gcc-internal-format
+msgid "comparing floating point with == or != is unsafe"
+msgstr ""
+
+#: c/c-typeck.c:10777 c/c-typeck.c:10797
+#, gcc-internal-format
+msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
+msgstr ""
+
+#: c/c-typeck.c:10783 c/c-typeck.c:10803
+#, gcc-internal-format
+msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
+msgstr ""
+
+#: c/c-typeck.c:10824 c/c-typeck.c:10929
+#, gcc-internal-format
+msgid "comparison of pointers to disjoint address spaces"
+msgstr ""
+
+#: c/c-typeck.c:10831 c/c-typeck.c:10837
+#, gcc-internal-format
+msgid "ISO C forbids comparison of %<void *%> with function pointer"
+msgstr ""
+
+#: c/c-typeck.c:10844 c/c-typeck.c:10939
+#, gcc-internal-format
+msgid "comparison of distinct pointer types lacks a cast"
+msgstr ""
+
+#: c/c-typeck.c:10856 c/c-typeck.c:10861 c/c-typeck.c:10965 c/c-typeck.c:10970
+#, gcc-internal-format
+msgid "comparison between pointer and integer"
+msgstr ""
+
+#: c/c-typeck.c:10917
+#, gcc-internal-format
+msgid "comparison of complete and incomplete pointers"
+msgstr ""
+
+#: c/c-typeck.c:10919
+#, gcc-internal-format
+msgid "ISO C forbids ordered comparisons of pointers to functions"
+msgstr ""
+
+#: c/c-typeck.c:10924
+#, gcc-internal-format
+msgid "ordered comparison of pointer with null pointer"
+msgstr ""
+
+#: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
+#: cp/typeck.c:4704 cp/typeck.c:4711
+#, gcc-internal-format
+msgid "ordered comparison of pointer with integer zero"
+msgstr ""
+
+#: c/c-typeck.c:11008 cp/typeck.c:4784
+#, gcc-internal-format
+msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
+msgstr ""
+
+#: c/c-typeck.c:11317
+#, gcc-internal-format
+msgid "used array that cannot be converted to pointer where scalar is required"
+msgstr ""
+
+#: c/c-typeck.c:11321
+#, gcc-internal-format
+msgid "used struct type value where scalar is required"
+msgstr ""
+
+#: c/c-typeck.c:11325
+#, gcc-internal-format
+msgid "used union type value where scalar is required"
+msgstr ""
+
+#: c/c-typeck.c:11336
+#, gcc-internal-format
+msgid "used vector type where scalar is required"
+msgstr ""
+
+#: c/c-typeck.c:11527 cp/semantics.c:7003
+#, gcc-internal-format
+msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
+msgstr ""
+
+#: c/c-typeck.c:11566 cp/semantics.c:7040
+#, gcc-internal-format
+msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
+msgstr ""
+
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
+#, gcc-internal-format
+msgid "%qD is not a variable in %qs clause"
+msgstr ""
+
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
+#, gcc-internal-format
+msgid "%qE is not a variable in %qs clause"
+msgstr ""
+
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
+#, gcc-internal-format
+msgid "%qD is threadprivate variable in %qs clause"
+msgstr ""
+
+#: c/c-typeck.c:11643 cp/semantics.c:4343
+#, gcc-internal-format
+msgid "low bound %qE of array section does not have integral type"
+msgstr ""
+
+#: c/c-typeck.c:11650 cp/semantics.c:4350
+#, gcc-internal-format
+msgid "length %qE of array section does not have integral type"
+msgstr ""
+
+#: c/c-typeck.c:11682 cp/semantics.c:4386
+#, gcc-internal-format
+msgid "for unknown bound array type length expression must be specified"
+msgstr ""
+
+#: c/c-typeck.c:11690 cp/semantics.c:4394
+#, gcc-internal-format
+msgid "negative low bound in array section in %qs clause"
+msgstr ""
+
+#: c/c-typeck.c:11699 cp/semantics.c:4403
+#, gcc-internal-format
+msgid "negative length in array section in %qs clause"
+msgstr ""
+
+#: c/c-typeck.c:11716 cp/semantics.c:4420
+#, gcc-internal-format
+msgid "low bound %qE above array section size in %qs clause"
+msgstr ""
+
+#: c/c-typeck.c:11741 cp/semantics.c:4445
+#, gcc-internal-format
+msgid "length %qE above array section size in %qs clause"
+msgstr ""
+
+#: c/c-typeck.c:11756 cp/semantics.c:4460
+#, gcc-internal-format
+msgid "high bound %qE above array section size in %qs clause"
+msgstr ""
+
+#: c/c-typeck.c:11787 cp/semantics.c:4491
+#, gcc-internal-format
+msgid "for pointer type length expression must be specified"
+msgstr ""
+
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
+#, gcc-internal-format
+msgid "array section is not contiguous in %qs clause"
+msgstr ""
+
+#: c/c-typeck.c:11804 cp/semantics.c:4508
+#, gcc-internal-format
+msgid "%qE does not have pointer or array type"
+msgstr ""
+
+#: c/c-typeck.c:12124
+#, gcc-internal-format
+msgid "%qE has invalid type for %<reduction(%s)%>"
+msgstr ""
+
+#: c/c-typeck.c:12133 cp/semantics.c:5292
+#, gcc-internal-format
+msgid "user defined reduction not found for %qD"
+msgstr ""
+
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
+#, gcc-internal-format
+msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
+msgstr ""
+
+#: c/c-typeck.c:12217 cp/semantics.c:5979
+#, gcc-internal-format
+msgid "%qE must be %<threadprivate%> for %<copyin%>"
+msgstr ""
+
+#: c/c-typeck.c:12229
+#, gcc-internal-format
+msgid "linear clause applied to non-integral non-pointer variable with type %qT"
+msgstr ""
+
+#: c/c-typeck.c:12255 cp/semantics.c:5397
+#, gcc-internal-format
+msgid "%qE is not a variable in clause %qs"
+msgstr ""
+
+#: c/c-typeck.c:12264 c/c-typeck.c:12285 c/c-typeck.c:12306
+#, gcc-internal-format
+msgid "%qE appears more than once in data clauses"
+msgstr ""
+
+#: c/c-typeck.c:12278 cp/semantics.c:5421
+#, gcc-internal-format
+msgid "%qE is not a variable in clause %<firstprivate%>"
+msgstr ""
+
+#: c/c-typeck.c:12299 cp/semantics.c:5443
+#, gcc-internal-format
+msgid "%qE is not a variable in clause %<lastprivate%>"
+msgstr ""
+
+#: c/c-typeck.c:12318 cp/semantics.c:5687
+#, gcc-internal-format
+msgid "%qE is not a variable in %<aligned%> clause"
+msgstr ""
+
+#: c/c-typeck.c:12325
+#, gcc-internal-format
+msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
+msgstr ""
+
+#: c/c-typeck.c:12332
+#, gcc-internal-format
+msgid "%qE appears more than once in %<aligned%> clauses"
+msgstr ""
+
+#: c/c-typeck.c:12353 cp/semantics.c:5757
+#, gcc-internal-format
+msgid "%qE is not a variable in %<depend%> clause"
+msgstr ""
+
+#: c/c-typeck.c:12375 cp/semantics.c:5782
+#, gcc-internal-format
+msgid "array section does not have mappable type in %qs clause"
+msgstr ""
+
+#: c/c-typeck.c:12408 cp/semantics.c:5826
+#, gcc-internal-format
+msgid "%qD does not have a mappable type in %qs clause"
+msgstr ""
+
+#: c/c-typeck.c:12415 cp/semantics.c:5833
+#, gcc-internal-format
+msgid "%qD appears more than once in motion clauses"
+msgstr ""
+
+#: c/c-typeck.c:12417 cp/semantics.c:5835
+#, gcc-internal-format
+msgid "%qD appears more than once in map clauses"
+msgstr ""
+
+#: c/c-typeck.c:12430 cp/semantics.c:5849
+#, gcc-internal-format
+msgid "%qD is not an argument in %<uniform%> clause"
+msgstr ""
+
+#: c/c-typeck.c:12433 cp/semantics.c:5851
+#, gcc-internal-format
+msgid "%qE is not an argument in %<uniform%> clause"
+msgstr ""
+
+#: c/c-typeck.c:12491 cp/semantics.c:5875
+#, gcc-internal-format
+msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
+msgstr ""
+
+#: c/c-typeck.c:12541 cp/semantics.c:6026
+#, gcc-internal-format
+msgid "%qE is predetermined %qs for %qs"
+msgstr ""
+
+#: c/c-typeck.c:12644
+#, gcc-internal-format
+msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
+msgstr ""
+
+#. A bad conversion for 'this' must be discarding cv-quals.
+#: cp/call.c:3301
+#, gcc-internal-format
+msgid "  passing %qT as %<this%> argument discards qualifiers"
+msgstr ""
+
+#: cp/call.c:3305
+#, gcc-internal-format
+msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
+msgstr ""
+
+#: cp/call.c:3312
+#, gcc-internal-format, gfc-internal-format
+msgid "  conversion of argument %d would be ill-formed:"
+msgstr ""
+
+#. Conversion of conversion function return value failed.
+#: cp/call.c:3319
+#, gcc-internal-format
+msgid "  no known conversion from %qT to %qT"
+msgstr ""
+
+#: cp/call.c:3322
+#, gcc-internal-format
+msgid "  no known conversion for argument %d from %qT to %qT"
+msgstr ""
+
+#: cp/call.c:3333 cp/pt.c:5714
+#, gcc-internal-format, gfc-internal-format
+msgid "  candidate expects %d argument, %d provided"
+msgid_plural "  candidate expects %d arguments, %d provided"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: cp/call.c:3358
+#, gcc-internal-format
+msgid "%s%D(%T, %T, %T) <built-in>"
+msgstr ""
+
+#: cp/call.c:3363
+#, gcc-internal-format
+msgid "%s%D(%T, %T) <built-in>"
+msgstr ""
+
+#: cp/call.c:3367
+#, gcc-internal-format
+msgid "%s%D(%T) <built-in>"
+msgstr ""
+
+#: cp/call.c:3371
+#, gcc-internal-format
+msgid "%s%T <conversion>"
+msgstr ""
+
+#: cp/call.c:3373
+#, gcc-internal-format
+msgid "%s%#D <near match>"
+msgstr "%s%#D <близький відповідник>"
+
+#: cp/call.c:3375
+#, gcc-internal-format
+msgid "%s%#D <deleted>"
+msgstr "%s%#D <вилучено>"
+
+#: cp/call.c:3377
+#, gcc-internal-format
+msgid "%s%#D"
+msgstr "%s%#D"
+
+#: cp/call.c:3396
+#, gcc-internal-format
+msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
+msgstr ""
+
+#: cp/call.c:3402
+#, gcc-internal-format
+msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
+msgstr ""
+
+#: cp/call.c:3413
+#, gcc-internal-format
+msgid "  substitution of deduced template arguments resulted in errors seen above"
+msgstr ""
+
+#. Re-run template unification with diagnostics.
+#: cp/call.c:3418
+#, gcc-internal-format
+msgid "  template argument deduction/substitution failed:"
+msgstr ""
+
+#: cp/call.c:3432
+#, gcc-internal-format
+msgid "  a constructor taking a single argument of its own class type is invalid"
+msgstr ""
+
+#: cp/call.c:3793
+#, gcc-internal-format
+msgid "conversion from %qT to %qT is ambiguous"
+msgstr ""
+
+#: cp/call.c:3920
+#, gcc-internal-format
+msgid "conversion from %qT to %qT not considered for non-type template argument"
+msgstr ""
+
+#: cp/call.c:4038
+#, gcc-internal-format
+msgid "no matching function for call to %<%D(%A)%>"
+msgstr ""
+
+#: cp/call.c:4041
+#, gcc-internal-format
+msgid "call of overloaded %<%D(%A)%> is ambiguous"
+msgstr ""
+
+#. It's no good looking for an overloaded operator() on a
+#. pointer-to-member-function.
+#: cp/call.c:4250
+#, gcc-internal-format
+msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
+msgstr ""
+
+#: cp/call.c:4321
+#, gcc-internal-format
+msgid "no match for call to %<(%T) (%A)%>"
+msgstr ""
+
+#: cp/call.c:4334
+#, gcc-internal-format
+msgid "call of %<(%T) (%A)%> is ambiguous"
+msgstr ""
+
+#: cp/call.c:4382
+#, gcc-internal-format
+msgid "ambiguous overload for "
+msgstr ""
+
+#: cp/call.c:4383
+#, gcc-internal-format
+msgid "no match for "
+msgstr "немає відповідників "
+
+#: cp/call.c:4386
+#, gcc-internal-format
+msgid " (operand types are %qT, %qT, and %qT)"
+msgstr ""
+
+#: cp/call.c:4388
+#, gcc-internal-format
+msgid " (operand types are %qT and %qT)"
+msgstr ""
+
+#: cp/call.c:4390
+#, gcc-internal-format
+msgid " (operand type is %qT)"
+msgstr ""
+
+#: cp/call.c:4410
+#, gcc-internal-format
+msgid "ternary %<operator?:%>"
+msgstr ""
+
+#: cp/call.c:4414
+#, gcc-internal-format
+msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
+msgstr ""
+
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
+#, gcc-internal-format
+msgid "%<operator%s%>"
+msgstr ""
+
+#: cp/call.c:4426
+#, gcc-internal-format
+msgid "%<operator%s%> in %<%E%s%>"
+msgstr "%<operator%s%> у %<%E%s%>"
+
+#: cp/call.c:4433
+#, gcc-internal-format
+msgid "%<operator[]%>"
+msgstr ""
+
+#: cp/call.c:4436
+#, gcc-internal-format
+msgid "%<operator[]%> in %<%E[%E]%>"
+msgstr "%<operator[]%> у %<%E[%E]%>"
+
+#: cp/call.c:4444
+#, gcc-internal-format
+msgid "%qs"
+msgstr "%qs"
+
+#: cp/call.c:4447
+#, gcc-internal-format
+msgid "%qs in %<%s %E%>"
+msgstr "%qs у %<%s %E%>"
+
+#: cp/call.c:4457
+#, gcc-internal-format
+msgid "%<operator%s%> in %<%E %s %E%>"
+msgstr "%<operator%s%> у %<%E %s %E%>"
+
+#: cp/call.c:4466
+#, gcc-internal-format
+msgid "%<operator%s%> in %<%s%E%>"
+msgstr "%<operator%s%> у %<%s%E%>"
+
+#: cp/call.c:4575
+#, gcc-internal-format
+msgid "ISO C++ forbids omitting the middle term of a ?: expression"
+msgstr ""
+
+#: cp/call.c:4624
+#, gcc-internal-format
+msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
+msgstr ""
+
+#: cp/call.c:4702
+#, gcc-internal-format
+msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
+msgstr ""
+
+#: cp/call.c:4790
+#, gcc-internal-format
+msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
+msgstr ""
+
+#: cp/call.c:4795
+#, gcc-internal-format
+msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
+msgstr ""
+
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
+#, gcc-internal-format
+msgid "operands to ?: have different types %qT and %qT"
+msgstr ""
+
+#: cp/call.c:4849
+#, gcc-internal-format
+msgid "  and each type can be converted to the other"
+msgstr ""
+
+#: cp/call.c:5050
+#, gcc-internal-format
+msgid "enumeral mismatch in conditional expression: %qT vs %qT"
+msgstr ""
+
+#: cp/call.c:5062
+#, gcc-internal-format
+msgid "enumeral and non-enumeral type in conditional expression"
+msgstr ""
+
+#: cp/call.c:5528
+#, gcc-internal-format
+msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
+msgstr ""
+
+#: cp/call.c:5530
+#, gcc-internal-format
+msgid "no %<%D(int)%> declared for postfix %qs"
+msgstr ""
+
+#: cp/call.c:5623
+#, gcc-internal-format
+msgid "comparison between %q#T and %q#T"
+msgstr ""
+
+#: cp/call.c:5893
+#, gcc-internal-format
+msgid "non-placement deallocation function %q+D"
+msgstr ""
+
+#: cp/call.c:5894
+#, gcc-internal-format
+msgid "selected for placement delete"
+msgstr ""
+
+#: cp/call.c:6008
+#, gcc-internal-format
+msgid "no corresponding deallocation function for %qD"
+msgstr ""
+
+#: cp/call.c:6014
+#, gcc-internal-format
+msgid "no suitable %<operator %s%> for %qT"
+msgstr ""
+
+#: cp/call.c:6035
+#, gcc-internal-format
+msgid "%q+#D is private"
+msgstr ""
+
+#: cp/call.c:6037
+#, gcc-internal-format
+msgid "%q+#D is protected"
+msgstr ""
+
+#: cp/call.c:6039
+#, gcc-internal-format
+msgid "%q+#D is inaccessible"
+msgstr ""
+
+#: cp/call.c:6040
+#, gcc-internal-format
+msgid "within this context"
+msgstr ""
+
+#: cp/call.c:6091
+#, gcc-internal-format
+msgid "passing NULL to non-pointer argument %P of %qD"
+msgstr ""
+
+#: cp/call.c:6095
+#, gcc-internal-format
+msgid "converting to non-pointer type %qT from NULL"
+msgstr ""
+
+#: cp/call.c:6104
+#, gcc-internal-format
+msgid "converting %<false%> to pointer type for argument %P of %qD"
+msgstr ""
+
+#: cp/call.c:6108
+#, gcc-internal-format
+msgid "converting %<false%> to pointer type %qT"
+msgstr ""
+
+#: cp/call.c:6171
+#, gcc-internal-format
+msgid "too many braces around initializer for %qT"
+msgstr ""
+
+#: cp/call.c:6182
+#, gcc-internal-format
+msgid "converting to %qT from %qT requires direct-initialization"
+msgstr ""
+
+#: cp/call.c:6190
+#, gcc-internal-format
+msgid "invalid user-defined conversion from %qT to %qT"
+msgstr ""
+
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
+#, gcc-internal-format
+msgid "  initializing argument %P of %qD"
+msgstr ""
+
+#: cp/call.c:6227 cp/cvt.c:236
+#, gcc-internal-format
+msgid "invalid conversion from %qT to %qT"
+msgstr ""
+
+#: cp/call.c:6255
+#, gcc-internal-format
+msgid "converting to %qT from initializer list would use explicit constructor %qD"
+msgstr ""
+
+#: cp/call.c:6335 cp/call.c:6487
+#, gcc-internal-format
+msgid "  initializing argument %P of %q+D"
+msgstr ""
+
+#: cp/call.c:6473
+#, gcc-internal-format
+msgid "cannot bind %qT lvalue to %qT"
+msgstr ""
+
+#: cp/call.c:6477 cp/call.c:9733
+#, gcc-internal-format
+msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
+msgstr ""
+
+#: cp/call.c:6480
+#, gcc-internal-format
+msgid "binding %qT to reference of type %qT discards qualifiers"
+msgstr ""
+
+#: cp/call.c:6516
+#, gcc-internal-format
+msgid "cannot bind bitfield %qE to %qT"
+msgstr ""
+
+#: cp/call.c:6519 cp/call.c:6536
+#, gcc-internal-format
+msgid "cannot bind packed field %qE to %qT"
+msgstr ""
+
+#: cp/call.c:6522
+#, gcc-internal-format
+msgid "cannot bind rvalue %qE to %qT"
+msgstr ""
+
+#: cp/call.c:6644 cp/cvt.c:1746
+#, gcc-internal-format
+msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
+msgstr ""
+
+#: cp/call.c:6685
+#, gcc-internal-format
+msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
+msgstr ""
+
+#: cp/call.c:6716
+#, gcc-internal-format
+msgid "cannot receive reference type %qT through %<...%>"
+msgstr ""
+
+#: cp/call.c:6726
+#, gcc-internal-format
+msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
+msgstr ""
+
+#: cp/call.c:6786
+#, gcc-internal-format
+msgid "recursive evaluation of default argument for %q#D"
+msgstr ""
+
+#: cp/call.c:6795
+#, gcc-internal-format
+msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
+msgstr ""
+
+#: cp/call.c:6897
+#, gcc-internal-format
+msgid "argument of function call might be a candidate for a format attribute"
+msgstr ""
+
+#: cp/call.c:6944
+#, gcc-internal-format
+msgid "use of multiversioned function without a default"
+msgstr ""
+
+#: cp/call.c:7189
+#, gcc-internal-format
+msgid "passing %qT as %<this%> argument discards qualifiers"
+msgstr ""
+
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
+#, gcc-internal-format
+msgid "  in call to %qD"
+msgstr ""
+
+#: cp/call.c:7222
+#, gcc-internal-format
+msgid "%qT is not an accessible base of %qT"
+msgstr ""
+
+#: cp/call.c:7304
+#, gcc-internal-format
+msgid "deducing %qT as %qT"
+msgstr ""
+
+#: cp/call.c:7307
+#, gcc-internal-format
+msgid "  in call to %q+D"
+msgstr ""
+
+#: cp/call.c:7309
+#, gcc-internal-format
+msgid "  (you can disable this with -fno-deduce-init-list)"
+msgstr ""
+
+#: cp/call.c:7663
+#, gcc-internal-format
+msgid "could not find class$ field in java interface type %qT"
+msgstr ""
+
+#: cp/call.c:7838
+#, gcc-internal-format
+msgid "constructor delegates to itself"
+msgstr ""
+
+#: cp/call.c:7928
+#, gcc-internal-format
+msgid "call to non-function %qD"
+msgstr ""
+
+#: cp/call.c:7974 cp/typeck.c:2750
+#, gcc-internal-format
+msgid "cannot call constructor %<%T::%D%> directly"
+msgstr ""
+
+#: cp/call.c:7976
+#, gcc-internal-format
+msgid "for a function-style cast, remove the redundant %<::%D%>"
+msgstr ""
+
+#: cp/call.c:8103
+#, gcc-internal-format
+msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
+msgstr ""
+
+#: cp/call.c:8116
+#, gcc-internal-format
+msgid "no matching function for call to %<%T::%s(%A)%#V%>"
+msgstr ""
+
+#: cp/call.c:8142
+#, gcc-internal-format
+msgid "no matching function for call to %<%s(%A)%>"
+msgstr ""
+
+#: cp/call.c:8145
+#, gcc-internal-format
+msgid "call of overloaded %<%s(%A)%> is ambiguous"
+msgstr ""
+
+#: cp/call.c:8166
+#, gcc-internal-format
+msgid "pure virtual %q#D called from non-static data member initializer"
+msgstr ""
+
+#: cp/call.c:8192
+#, gcc-internal-format
+msgid "cannot call member function %qD without object"
+msgstr ""
+
+#: cp/call.c:8971
+#, gcc-internal-format
+msgid "passing %qT chooses %qT over %qT"
+msgstr ""
+
+#: cp/call.c:9031
+#, gcc-internal-format
+msgid "choosing %qD over %qD"
+msgstr ""
+
+#: cp/call.c:9032
+#, gcc-internal-format
+msgid "  for conversion from %qT to %qT"
+msgstr ""
+
+#: cp/call.c:9035
+#, gcc-internal-format
+msgid "  because conversion sequence for the argument is better"
+msgstr ""
+
+#: cp/call.c:9188
+#, gcc-internal-format
+msgid "default argument mismatch in overload resolution"
+msgstr ""
+
+#: cp/call.c:9192
+#, gcc-internal-format
+msgid " candidate 1: %q+#F"
+msgstr ""
+
+#: cp/call.c:9194
+#, gcc-internal-format
+msgid " candidate 2: %q+#F"
+msgstr ""
+
+#: cp/call.c:9239
+#, gcc-internal-format
+msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
+msgstr ""
+
+#: cp/call.c:9417
+#, gcc-internal-format
+msgid "could not convert %qE from %qT to %qT"
+msgstr ""
+
+#: cp/call.c:9610
+#, gcc-internal-format
+msgid "a temporary bound to %qD only persists until the constructor exits"
+msgstr ""
+
+#: cp/call.c:9737
+#, gcc-internal-format
+msgid "invalid initialization of reference of type %qT from expression of type %qT"
+msgstr ""
+
+#: cp/class.c:320
+#, gcc-internal-format
+msgid "cannot convert from pointer to base class %qT to pointer to derived class %qT because the base is virtual"
+msgstr ""
+
+#: cp/class.c:324
+#, gcc-internal-format
+msgid "cannot convert from base class %qT to derived class %qT because the base is virtual"
+msgstr ""
+
+#: cp/class.c:331
+#, gcc-internal-format
+msgid "cannot convert from pointer to base class %qT to pointer to derived class %qT via virtual base %qT"
+msgstr ""
+
+#: cp/class.c:336
+#, gcc-internal-format
+msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
+msgstr ""
+
+#: cp/class.c:1053
+#, gcc-internal-format
+msgid "Java class %qT cannot have a destructor"
+msgstr ""
+
+#: cp/class.c:1055
+#, gcc-internal-format
+msgid "Java class %qT cannot have an implicit non-trivial destructor"
+msgstr ""
+
+#: cp/class.c:1190
+#, gcc-internal-format
+msgid "%q#D inherited from %qT"
+msgstr ""
+
+#: cp/class.c:1193
+#, gcc-internal-format
+msgid "conflicts with version inherited from %qT"
+msgstr ""
+
+#: cp/class.c:1207
+#, gcc-internal-format
+msgid "%q+#D cannot be overloaded"
+msgstr ""
+
+#: cp/class.c:1208
+#, gcc-internal-format
+msgid "with %q+#D"
+msgstr ""
+
+#: cp/class.c:1281
+#, gcc-internal-format
+msgid "conflicting access specifications for method %q+D, ignored"
+msgstr ""
+
+#: cp/class.c:1284
+#, gcc-internal-format
+msgid "conflicting access specifications for field %qE, ignored"
+msgstr ""
+
+#: cp/class.c:1347 cp/class.c:1355
+#, gcc-internal-format
+msgid "%q+D invalid in %q#T"
+msgstr ""
+
+#: cp/class.c:1348
+#, gcc-internal-format
+msgid "  because of local method %q+#D with same name"
+msgstr ""
+
+#: cp/class.c:1356
+#, gcc-internal-format
+msgid "  because of local member %q+#D with same name"
+msgstr ""
+
+#: cp/class.c:1411
+#, gcc-internal-format
+msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
+msgstr ""
+
+#: cp/class.c:1414 cp/class.c:1420 cp/class.c:1426 cp/class.c:1437
+#, gcc-internal-format
+msgid "%qT declared here"
+msgstr ""
+
+#: cp/class.c:1418
+#, gcc-internal-format
+msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
+msgstr ""
+
+#: cp/class.c:1424
+#, gcc-internal-format
+msgid "%qT does not have the %E ABI tag that base %qT has"
+msgstr ""
+
+#: cp/class.c:1431
+#, gcc-internal-format
+msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
+msgstr ""
+
+#: cp/class.c:1706
+#, gcc-internal-format
+msgid "cannot derive from %<final%> base %qT in derived type %qT"
+msgstr ""
+
+#: cp/class.c:2123
+#, gcc-internal-format
+msgid "all member functions in class %qT are private"
+msgstr ""
+
+#: cp/class.c:2135
+#, gcc-internal-format
+msgid "%q#T only defines a private destructor and has no friends"
+msgstr ""
+
+#: cp/class.c:2180
+#, gcc-internal-format
+msgid "%q#T only defines private constructors and has no friends"
+msgstr ""
+
+#: cp/class.c:2573
+#, gcc-internal-format
+msgid "no unique final overrider for %qD in %qT"
+msgstr ""
+
+#: cp/class.c:2936
+#, gcc-internal-format
+msgid "%q+D can be marked override"
+msgstr ""
+
+#: cp/class.c:2948
+#, gcc-internal-format
+msgid "%q+#D marked %<final%>, but is not virtual"
+msgstr ""
+
+#: cp/class.c:2950
+#, gcc-internal-format
+msgid "%q+#D marked %<override%>, but does not override"
+msgstr ""
+
+#. Here we know it is a hider, and no overrider exists.
+#: cp/class.c:3018
+#, gcc-internal-format
+msgid "%q+D was hidden"
+msgstr ""
+
+#: cp/class.c:3019
+#, gcc-internal-format
+msgid "  by %q+D"
+msgstr ""
+
+#: cp/class.c:3053 cp/decl2.c:1537
+#, gcc-internal-format
+msgid "%q+#D invalid; an anonymous union can only have non-static data members"
+msgstr ""
+
+#: cp/class.c:3057
+#, gcc-internal-format
+msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
+msgstr ""
+
+#: cp/class.c:3069 cp/decl2.c:1543
+#, gcc-internal-format
+msgid "private member %q+#D in anonymous union"
+msgstr ""
+
+#: cp/class.c:3072
+#, gcc-internal-format
+msgid "private member %q+#D in anonymous struct"
+msgstr ""
+
+#: cp/class.c:3078 cp/decl2.c:1545
+#, gcc-internal-format
+msgid "protected member %q+#D in anonymous union"
+msgstr ""
+
+#: cp/class.c:3081
+#, gcc-internal-format
+msgid "protected member %q+#D in anonymous struct"
+msgstr ""
+
+#: cp/class.c:3259
+#, gcc-internal-format
+msgid "the ellipsis in %qD is not inherited"
+msgstr ""
+
+#: cp/class.c:3434
+#, gcc-internal-format
+msgid "bit-field %q+#D with non-integral type"
+msgstr ""
+
+#: cp/class.c:3450
+#, gcc-internal-format
+msgid "bit-field %q+D width not an integer constant"
+msgstr ""
+
+#: cp/class.c:3455
+#, gcc-internal-format
+msgid "negative width in bit-field %q+D"
+msgstr ""
+
+#: cp/class.c:3460
+#, gcc-internal-format
+msgid "zero width for bit-field %q+D"
+msgstr ""
+
+#: cp/class.c:3469
+#, gcc-internal-format
+msgid "width of %q+D exceeds its type"
+msgstr ""
+
+#: cp/class.c:3473
+#, gcc-internal-format
+msgid "%q+D is too small to hold all values of %q#T"
+msgstr ""
+
+#: cp/class.c:3532
+#, gcc-internal-format
+msgid "member %q+#D with constructor not allowed in union"
+msgstr ""
+
+#: cp/class.c:3535
+#, gcc-internal-format
+msgid "member %q+#D with destructor not allowed in union"
+msgstr ""
+
+#: cp/class.c:3537
+#, gcc-internal-format
+msgid "member %q+#D with copy assignment operator not allowed in union"
+msgstr ""
+
+#: cp/class.c:3541
+#, gcc-internal-format
+msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/class.c:3578
+#, gcc-internal-format
+msgid "multiple fields in union %qT initialized"
+msgstr ""
+
+#: cp/class.c:3666
+#, gcc-internal-format
+msgid "in C++98 %q+D may not be static because it is a member of a union"
+msgstr ""
+
+#: cp/class.c:3672
+#, gcc-internal-format
+msgid "in C++98 %q+D may not have reference type %qT because it is a member of a union"
+msgstr ""
+
+#: cp/class.c:3682
+#, gcc-internal-format
+msgid "field %q+D invalidly declared function type"
+msgstr ""
+
+#: cp/class.c:3688
+#, gcc-internal-format
+msgid "field %q+D invalidly declared method type"
+msgstr ""
+
+#: cp/class.c:3748
+#, gcc-internal-format
+msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
+msgstr ""
+
+#: cp/class.c:3796
+#, gcc-internal-format
+msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
+msgstr ""
+
+#: cp/class.c:3802
+#, gcc-internal-format
+msgid "member %q+D cannot be declared as a %<mutable%> reference"
+msgstr ""
+
+#: cp/class.c:3863
+#, gcc-internal-format
+msgid "field %q+#D with same name as class"
+msgstr ""
+
+#: cp/class.c:3886
+#, gcc-internal-format
+msgid "%q#T has pointer data members"
+msgstr ""
+
+#: cp/class.c:3891
+#, gcc-internal-format
+msgid "  but does not override %<%T(const %T&)%>"
+msgstr ""
+
+#: cp/class.c:3893
+#, gcc-internal-format
+msgid "  or %<operator=(const %T&)%>"
+msgstr "  або %<operator=(const %T&)%>"
+
+#: cp/class.c:3897
+#, gcc-internal-format
+msgid "  but does not override %<operator=(const %T&)%>"
+msgstr ""
+
+#: cp/class.c:4300
+#, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, gcc-internal-format
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr ""
+
+#: cp/class.c:4557
+#, gcc-internal-format
+msgid "initializer specified for non-virtual method %q+D"
+msgstr ""
+
+#: cp/class.c:4978
+#, gcc-internal-format
+msgid "method overrides both %<transaction_pure%> and %qE methods"
+msgstr ""
+
+#: cp/class.c:4999
+#, gcc-internal-format
+msgid "method declared %qE overriding %qE method"
+msgstr ""
+
+#: cp/class.c:5551 cp/constexpr.c:228
+#, gcc-internal-format
+msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
+msgstr ""
+
+#: cp/class.c:5576
+#, gcc-internal-format
+msgid "%q+T is not literal because:"
+msgstr ""
+
+#: cp/class.c:5578
+#, gcc-internal-format
+msgid "  %q+T has a non-trivial destructor"
+msgstr ""
+
+#: cp/class.c:5583
+#, gcc-internal-format
+msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
+msgstr ""
+
+#: cp/class.c:5618
+#, gcc-internal-format
+msgid "  base class %qT of %q+T is non-literal"
+msgstr ""
+
+#: cp/class.c:5632
+#, gcc-internal-format
+msgid "  non-static data member %q+D has non-literal type"
+msgstr ""
+
+#: cp/class.c:5638
+#, gcc-internal-format
+msgid "  non-static data member %q+D has volatile type"
+msgstr ""
+
+#: cp/class.c:5756
+#, gcc-internal-format
+msgid "base class %q#T has accessible non-virtual destructor"
+msgstr ""
+
+#: cp/class.c:5784
+#, gcc-internal-format
+msgid "non-static reference %q+#D in class without a constructor"
+msgstr ""
+
+#: cp/class.c:5789
+#, gcc-internal-format
+msgid "non-static const member %q+#D in class without a constructor"
+msgstr ""
+
+#. If the function is defaulted outside the class, we just
+#. give the synthesis error.
+#: cp/class.c:5815
+#, gcc-internal-format
+msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
+msgstr ""
+
+#: cp/class.c:6092
+#, gcc-internal-format
+msgid "direct base %qT inaccessible in %qT due to ambiguity"
+msgstr ""
+
+#: cp/class.c:6104
+#, gcc-internal-format
+msgid "virtual base %qT inaccessible in %qT due to ambiguity"
+msgstr ""
+
+#: cp/class.c:6331
+#, gcc-internal-format
+msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
+msgstr ""
+
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
+#, gcc-internal-format
+msgid "redefinition of %q#T"
+msgstr ""
+
+#: cp/class.c:6712
+#, gcc-internal-format
+msgid "%q#T has virtual functions and accessible non-virtual destructor"
+msgstr ""
+
+#: cp/class.c:6740
+#, gcc-internal-format
+msgid "type transparent %q#T does not have any fields"
+msgstr ""
+
+#: cp/class.c:6746
+#, gcc-internal-format
+msgid "type transparent class %qT has base classes"
+msgstr ""
+
+#: cp/class.c:6750
+#, gcc-internal-format
+msgid "type transparent class %qT has virtual functions"
+msgstr ""
+
+#: cp/class.c:6756
+#, gcc-internal-format
+msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
+msgstr ""
+
+#: cp/class.c:6920
+#, gcc-internal-format
+msgid "definition of std::initializer_list does not match #include <initializer_list>"
+msgstr ""
+
+#: cp/class.c:6931
+#, gcc-internal-format
+msgid "trying to finish struct, but kicked out due to previous parse errors"
+msgstr ""
+
+#: cp/class.c:7465
+#, gcc-internal-format
+msgid "language string %<\"%E\"%> not recognized"
+msgstr ""
+
+#: cp/class.c:7555
+#, gcc-internal-format
+msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
+msgstr ""
+
+#: cp/class.c:7692
+#, gcc-internal-format
+msgid "no matches converting function %qD to type %q#T"
+msgstr ""
+
+#: cp/class.c:7720
+#, gcc-internal-format
+msgid "converting overloaded function %qD to type %q#T is ambiguous"
+msgstr ""
+
+#: cp/class.c:7747
+#, gcc-internal-format
+msgid "assuming pointer to member %qD"
+msgstr ""
+
+#: cp/class.c:7750
+#, gcc-internal-format
+msgid "(a pointer to member can only be formed with %<&%E%>)"
+msgstr ""
+
+#: cp/class.c:7825 cp/class.c:7860
+#, gcc-internal-format
+msgid "not enough type information"
+msgstr ""
+
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#, gcc-internal-format
+msgid "cannot convert %qE from type %qT to type %qT"
+msgstr ""
+
+#. [basic.scope.class]
+#.
+#. A name N used in a class S shall refer to the same declaration
+#. in its context and when re-evaluated in the completed scope of
+#. S.
+#: cp/class.c:8121
+#, gcc-internal-format
+msgid "declaration of %q#D"
+msgstr ""
+
+#: cp/class.c:8122
+#, gcc-internal-format
+msgid "changes meaning of %qD from %q+#D"
+msgstr ""
+
+#: cp/constexpr.c:106
+#, gcc-internal-format
+msgid "the type %qT of constexpr variable %qD is not literal"
+msgstr ""
+
+#: cp/constexpr.c:114
+#, gcc-internal-format
+msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
+msgstr ""
+
+#: cp/constexpr.c:189
+#, gcc-internal-format
+msgid "inherited constructor %qD is not constexpr"
+msgstr ""
+
+#: cp/constexpr.c:201
+#, gcc-internal-format
+msgid "invalid type for parameter %d of constexpr function %q+#D"
+msgstr ""
+
+#: cp/constexpr.c:216
+#, gcc-internal-format
+msgid "invalid return type %qT of constexpr function %q+D"
+msgstr ""
+
+#: cp/constexpr.c:238
+#, gcc-internal-format
+msgid "%q#T has virtual base classes"
+msgstr ""
+
+#: cp/constexpr.c:489
+#, gcc-internal-format
+msgid "constexpr constructor does not have empty body"
+msgstr ""
+
+#: cp/constexpr.c:584
+#, gcc-internal-format
+msgid "body of %<constexpr%> constructor cannot be a function-try-block"
+msgstr ""
+
+#: cp/constexpr.c:715
+#, gcc-internal-format
+msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
+msgstr ""
+
+#: cp/constexpr.c:755
+#, gcc-internal-format
+msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
+msgstr ""
+
+#: cp/constexpr.c:787
+#, gcc-internal-format
+msgid "body of constexpr function %qD not a return-statement"
+msgstr ""
+
+#: cp/constexpr.c:840
+#, gcc-internal-format
+msgid "%q+D is not usable as a constexpr function because:"
+msgstr ""
+
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
+#, gcc-internal-format
+msgid "call to internal function"
+msgstr ""
+
+#: cp/constexpr.c:1217
+#, gcc-internal-format
+msgid "expression %qE does not designate a constexpr function"
+msgstr ""
+
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
+#, gcc-internal-format
+msgid "call to non-constexpr function %qD"
+msgstr ""
+
+#. The definition of fun was somehow unsuitable.
+#: cp/constexpr.c:1279
+#, gcc-internal-format
+msgid "%qD called in a constant expression"
+msgstr ""
+
+#: cp/constexpr.c:1283
+#, gcc-internal-format
+msgid "%qD used before its definition"
+msgstr ""
+
+#: cp/constexpr.c:1336
+#, gcc-internal-format
+msgid "call has circular dependency"
+msgstr ""
+
+#: cp/constexpr.c:1347
+#, gcc-internal-format, gfc-internal-format
+msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
+msgstr ""
+
+#: cp/constexpr.c:1434
+#, gcc-internal-format
+msgid "constexpr call flows off the end of the function"
+msgstr ""
+
+#: cp/constexpr.c:1521
+#, gcc-internal-format
+msgid "%q+E is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.c:1561
+#, gcc-internal-format
+msgid "right operand of shift expression %q+E is negative"
+msgstr ""
+
+#: cp/constexpr.c:1568
+#, gcc-internal-format
+msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
+msgstr ""
+
+#: cp/constexpr.c:1585
+#, gcc-internal-format
+msgid "left operand of shift expression %q+E is negative"
+msgstr ""
+
+#: cp/constexpr.c:1604
+#, gcc-internal-format
+msgid "shift expression %q+E overflows"
+msgstr ""
+
+#: cp/constexpr.c:1766
+#, gcc-internal-format
+msgid "array subscript out of bound"
+msgstr ""
+
+#: cp/constexpr.c:1773
+#, gcc-internal-format
+msgid "negative array subscript"
+msgstr ""
+
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
+#, gcc-internal-format
+msgid "%qE is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.c:1825
+#, gcc-internal-format
+msgid "mutable %qD is not usable in a constant expression"
+msgstr ""
+
+#: cp/constexpr.c:1846
+#, gcc-internal-format
+msgid "accessing %qD member instead of initialized %qD member in constant expression"
+msgstr ""
+
+#: cp/constexpr.c:1858
+#, gcc-internal-format
+msgid "accessing uninitialized member %qD"
+msgstr ""
+
+#: cp/constexpr.c:2513
+#, gcc-internal-format
+msgid "accessing value of %qE through a %qT glvalue in a constant expression"
+msgstr ""
+
+#: cp/constexpr.c:2550
+#, gcc-internal-format
+msgid "the value of %qD is not usable in a constant expression"
+msgstr ""
+
+#: cp/constexpr.c:2557
+#, gcc-internal-format
+msgid "%qD used in its own initializer"
+msgstr ""
+
+#: cp/constexpr.c:2562
+#, gcc-internal-format
+msgid "%q#D is not const"
+msgstr ""
+
+#: cp/constexpr.c:2565
+#, gcc-internal-format
+msgid "%q#D is volatile"
+msgstr ""
+
+#: cp/constexpr.c:2569
+#, gcc-internal-format
+msgid "%qD was not initialized with a constant expression"
+msgstr ""
+
+#: cp/constexpr.c:2578
+#, gcc-internal-format
+msgid "%qD was not declared %<constexpr%>"
+msgstr ""
+
+#: cp/constexpr.c:2581
+#, gcc-internal-format
+msgid "%qD does not have integral or enumeration type"
+msgstr ""
+
+#: cp/constexpr.c:2686
+#, gcc-internal-format
+msgid "modification of %qE is not a constant-expression"
+msgstr ""
+
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
+#, gcc-internal-format
+msgid "temporary of non-literal type %qT in a constant expression"
+msgstr ""
+
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
+#, gcc-internal-format
+msgid "reinterpret_cast from integer to pointer"
+msgstr ""
+
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
+#, gcc-internal-format
+msgid "expression %qE is not a constant-expression"
+msgstr ""
+
+#: cp/constexpr.c:3594
+#, gcc-internal-format
+msgid "statement is not a constant-expression"
+msgstr ""
+
+#: cp/constexpr.c:3597
+#, gcc-internal-format
+msgid "unexpected expression %qE of kind %s"
+msgstr ""
+
+#: cp/constexpr.c:3664
+#, gcc-internal-format
+msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
+msgstr ""
+
+#: cp/constexpr.c:3677
+#, gcc-internal-format
+msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
+msgstr ""
+
+#: cp/constexpr.c:3925
+#, gcc-internal-format
+msgid "expression %qE has side-effects"
+msgstr ""
+
+#: cp/constexpr.c:4120
+#, gcc-internal-format
+msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.c:4150
+#, gcc-internal-format
+msgid "use of %<this%> in a constant expression"
+msgstr ""
+
+#: cp/constexpr.c:4263
+#, gcc-internal-format
+msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
+msgstr ""
+
+#: cp/constexpr.c:4276
+#, gcc-internal-format
+msgid "difference of two pointer expressions is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.c:4295
+#, gcc-internal-format
+msgid "pointer comparison expression is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.c:4342
+#, gcc-internal-format
+msgid "cast to non-integral type %qT in a constant expression"
+msgstr ""
+
+#: cp/constexpr.c:4427
+#, gcc-internal-format
+msgid "division by zero is not a constant-expression"
+msgstr ""
+
+#: cp/constexpr.c:4552
+#, gcc-internal-format
+msgid "non-constant array initialization"
+msgstr ""
+
+#: cp/constexpr.c:4566
+#, gcc-internal-format, gfc-internal-format
+msgid "unexpected AST of kind %s"
+msgstr ""
+
+#: cp/cp-array-notation.c:833 cp/cp-array-notation.c:839
+#: cp/cp-array-notation.c:864 cp/cp-array-notation.c:870
+#, gcc-internal-format
+msgid "rank mismatch with controlling expression of parent if-statement"
+msgstr ""
+
+#: cp/cp-array-notation.c:1277
+#, gcc-internal-format
+msgid "array notation cannot be used in a condition for a for-loop"
+msgstr ""
+
+#: cp/cp-array-notation.c:1310
+#, gcc-internal-format
+msgid "array notation cannot be used as a condition for switch statement"
+msgstr ""
+
+#: cp/cp-array-notation.c:1323
+#, gcc-internal-format
+msgid "array notation cannot be used as a condition for while statement"
+msgstr ""
+
+#: cp/cp-array-notation.c:1334
+#, gcc-internal-format
+msgid "array notation cannot be used as a condition for a do-while statement"
+msgstr ""
+
+#: cp/cp-array-notation.c:1379
+#, gcc-internal-format
+msgid "start-index and length fields necessary for using array notation in pointers or records"
+msgstr ""
+
+#: cp/cp-array-notation.c:1386
+#, gcc-internal-format
+msgid "start-index and length fields necessary for using array notation with array of unknown bound"
+msgstr ""
+
+#: cp/cp-array-notation.c:1452
+#, gcc-internal-format
+msgid "array notation cannot be used with function type"
+msgstr ""
+
+#: cp/cp-array-notation.c:1462
+#, gcc-internal-format
+msgid "rank of an array notation triplet%'s start-index is not zero"
+msgstr ""
+
+#: cp/cp-array-notation.c:1468
+#, gcc-internal-format
+msgid "rank of an array notation triplet%'s length is not zero"
+msgstr ""
+
+#: cp/cp-array-notation.c:1473
+#, gcc-internal-format
+msgid "rank of array notation triplet%'s stride is not zero"
+msgstr ""
+
+#: cp/cp-cilkplus.c:52
+#, gcc-internal-format
+msgid "throw expressions are not allowed inside loops marked with pragma simd"
+msgstr ""
+
+#: cp/cp-cilkplus.c:59
+#, gcc-internal-format
+msgid "try statements are not allowed inside loops marked with #pragma simd"
+msgstr ""
+
+#: cp/cp-gimplify.c:1690
+#, gcc-internal-format
+msgid "%qE implicitly determined as %<firstprivate%> has reference type"
+msgstr ""
+
+#: cp/cvt.c:101
+#, gcc-internal-format
+msgid "can%'t convert from incomplete type %qT to %qT"
+msgstr ""
+
+#: cp/cvt.c:111
+#, gcc-internal-format
+msgid "conversion of %qE from %qT to %qT is ambiguous"
+msgstr ""
+
+#: cp/cvt.c:394
+#, gcc-internal-format
+msgid "initialization of volatile reference type %q#T from rvalue of type %qT"
+msgstr ""
+
+#: cp/cvt.c:397
+#, gcc-internal-format
+msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
+msgstr ""
+
+#: cp/cvt.c:400
+#, gcc-internal-format
+msgid "initialization of non-const reference type %q#T from rvalue of type %qT"
+msgstr ""
+
+#: cp/cvt.c:403
+#, gcc-internal-format
+msgid "conversion to non-const reference type %q#T from rvalue of type %qT"
+msgstr ""
+
+#: cp/cvt.c:479
+#, gcc-internal-format
+msgid "conversion from %qT to %qT discards qualifiers"
+msgstr ""
+
+#: cp/cvt.c:501 cp/typeck.c:6814
+#, gcc-internal-format
+msgid "casting %qT to %qT does not dereference pointer"
+msgstr ""
+
+#: cp/cvt.c:529
+#, gcc-internal-format
+msgid "cannot convert type %qT to type %qT"
+msgstr ""
+
+#: cp/cvt.c:761
+#, gcc-internal-format
+msgid "conversion from %q#T to %q#T"
+msgstr ""
+
+#: cp/cvt.c:778
+#, gcc-internal-format
+msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
+msgstr ""
+
+#: cp/cvt.c:789 cp/cvt.c:833
+#, gcc-internal-format
+msgid "%q#T used where a %qT was expected"
+msgstr ""
+
+#: cp/cvt.c:798
+#, gcc-internal-format
+msgid "could not convert %qE from %<void%> to %<bool%>"
+msgstr ""
+
+#: cp/cvt.c:849
+#, gcc-internal-format
+msgid "%q#T used where a floating point value was expected"
+msgstr ""
+
+#: cp/cvt.c:908
+#, gcc-internal-format
+msgid "conversion from %qT to non-scalar type %qT requested"
+msgstr ""
+
+#: cp/cvt.c:968
+#, gcc-internal-format
+msgid "pseudo-destructor is not called"
+msgstr ""
+
+#: cp/cvt.c:1045
+#, gcc-internal-format
+msgid "conversion to void will not access object of incomplete type %qT"
+msgstr ""
+
+#: cp/cvt.c:1049
+#, gcc-internal-format
+msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.c:1054
+#, gcc-internal-format
+msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.c:1059
+#, gcc-internal-format
+msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
+msgstr ""
+
+#: cp/cvt.c:1064
+#, gcc-internal-format
+msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
+msgstr ""
+
+#: cp/cvt.c:1069
+#, gcc-internal-format
+msgid "indirection will not access object of incomplete type %qT in statement"
+msgstr ""
+
+#: cp/cvt.c:1073
+#, gcc-internal-format
+msgid "indirection will not access object of incomplete type %qT in for increment expression"
+msgstr ""
+
+#: cp/cvt.c:1089
+#, gcc-internal-format
+msgid "conversion to void will not access object of type %qT"
+msgstr ""
+
+#: cp/cvt.c:1093
+#, gcc-internal-format
+msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.c:1098
+#, gcc-internal-format
+msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.c:1103
+#, gcc-internal-format
+msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
+msgstr ""
+
+#: cp/cvt.c:1108
+#, gcc-internal-format
+msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
+msgstr ""
+
+#: cp/cvt.c:1113
+#, gcc-internal-format
+msgid "implicit dereference will not access object of type %qT in statement"
+msgstr ""
+
+#: cp/cvt.c:1117
+#, gcc-internal-format
+msgid "implicit dereference will not access object of type %qT in for increment expression"
+msgstr ""
+
+#: cp/cvt.c:1131
+#, gcc-internal-format
+msgid "conversion to void will not access object of non-trivially-copyable type %qT"
+msgstr ""
+
+#: cp/cvt.c:1136
+#, gcc-internal-format
+msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.c:1141
+#, gcc-internal-format
+msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.c:1146
+#, gcc-internal-format
+msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
+msgstr ""
+
+#: cp/cvt.c:1151
+#, gcc-internal-format
+msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
+msgstr ""
+
+#: cp/cvt.c:1156
+#, gcc-internal-format
+msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
+msgstr ""
+
+#: cp/cvt.c:1161
+#, gcc-internal-format
+msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
+msgstr ""
+
+#: cp/cvt.c:1199
+#, gcc-internal-format
+msgid "conversion to void will not access object %qE of incomplete type %qT"
+msgstr ""
+
+#: cp/cvt.c:1203
+#, gcc-internal-format
+msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.c:1208
+#, gcc-internal-format
+msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.c:1213
+#, gcc-internal-format
+msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
+msgstr ""
+
+#: cp/cvt.c:1218
+#, gcc-internal-format
+msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
+msgstr ""
+
+#: cp/cvt.c:1223
+#, gcc-internal-format
+msgid "variable %qE of incomplete type %qT will not be accessed in statement"
+msgstr ""
+
+#: cp/cvt.c:1227
+#, gcc-internal-format
+msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
+msgstr ""
+
+#: cp/cvt.c:1276
+#, gcc-internal-format
+msgid "conversion to void cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.c:1280
+#, gcc-internal-format
+msgid "second operand of conditional expression cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.c:1284
+#, gcc-internal-format
+msgid "third operand of conditional expression cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.c:1288
+#, gcc-internal-format
+msgid "right operand of comma operator cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.c:1292
+#, gcc-internal-format
+msgid "left operand of comma operator cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.c:1296
+#, gcc-internal-format
+msgid "statement cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.c:1300
+#, gcc-internal-format
+msgid "for increment expression cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.c:1316
+#, gcc-internal-format
+msgid "second operand of conditional expression is a reference, not call, to function %qE"
+msgstr ""
+
+#: cp/cvt.c:1321
+#, gcc-internal-format
+msgid "third operand of conditional expression is a reference, not call, to function %qE"
+msgstr ""
+
+#: cp/cvt.c:1326
+#, gcc-internal-format
+msgid "right operand of comma operator is a reference, not call, to function %qE"
+msgstr ""
+
+#: cp/cvt.c:1331
+#, gcc-internal-format
+msgid "left operand of comma operator is a reference, not call, to function %qE"
+msgstr ""
+
+#: cp/cvt.c:1336
+#, gcc-internal-format
+msgid "statement is a reference, not call, to function %qE"
+msgstr ""
+
+#: cp/cvt.c:1341
+#, gcc-internal-format
+msgid "for increment expression is a reference, not call, to function %qE"
+msgstr ""
+
+#: cp/cvt.c:1368
+#, gcc-internal-format
+msgid "second operand of conditional expression has no effect"
+msgstr ""
+
+#: cp/cvt.c:1373
+#, gcc-internal-format
+msgid "third operand of conditional expression has no effect"
+msgstr ""
+
+#: cp/cvt.c:1378
+#, gcc-internal-format
+msgid "right operand of comma operator has no effect"
+msgstr ""
+
+#: cp/cvt.c:1382
+#, gcc-internal-format
+msgid "left operand of comma operator has no effect"
+msgstr ""
+
+#: cp/cvt.c:1386
+#, gcc-internal-format
+msgid "statement has no effect"
+msgstr ""
+
+#: cp/cvt.c:1390
+#, gcc-internal-format
+msgid "for increment expression has no effect"
+msgstr ""
+
+#: cp/cvt.c:1547
+#, gcc-internal-format
+msgid "converting NULL to non-pointer type"
+msgstr ""
+
+#: cp/cvt.c:1662
+#, gcc-internal-format
+msgid "default type conversion can't deduce template argument for %qD"
+msgstr ""
+
+#: cp/cvt.c:1677
+#, gcc-internal-format
+msgid "ambiguous default type conversion from %qT"
+msgstr ""
+
+#: cp/cvt.c:1680
+#, gcc-internal-format
+msgid "  candidate conversions include %qD and %qD"
+msgstr ""
+
+#: cp/cxx-pretty-print.c:2148
+#, gcc-internal-format
+msgid "template-parameter-"
+msgstr ""
+
+#: cp/decl.c:665
+#, gcc-internal-format
+msgid "variable %q+D set but not used"
+msgstr ""
+
+#: cp/decl.c:1185
+#, gcc-internal-format
+msgid "%qD was declared %<extern%> and later %<static%>"
+msgstr ""
+
+#: cp/decl.c:1186 objc/objc-act.c:3421 objc/objc-act.c:4009
+#: objc/objc-act.c:4037 objc/objc-act.c:4092 objc/objc-act.c:6863
+#, gcc-internal-format
+msgid "previous declaration of %q+D"
+msgstr ""
+
+#: cp/decl.c:1221
+#, gcc-internal-format
+msgid "declaration of %qF has a different exception specifier"
+msgstr ""
+
+#: cp/decl.c:1223
+#, gcc-internal-format
+msgid "from previous declaration %q+F"
+msgstr ""
+
+#: cp/decl.c:1257
+#, gcc-internal-format
+msgid "redeclaration %qD differs in %<constexpr%>"
+msgstr ""
+
+#: cp/decl.c:1258
+#, gcc-internal-format
+msgid "from previous declaration %q+D"
+msgstr ""
+
+#: cp/decl.c:1279
+#, gcc-internal-format
+msgid "redeclaration of %q#D may not have default arguments"
+msgstr ""
+
+#: cp/decl.c:1326
+#, gcc-internal-format
+msgid "literal operator template %q+D conflicts with raw literal operator %qD"
+msgstr ""
+
+#: cp/decl.c:1331
+#, gcc-internal-format
+msgid "raw literal operator %q+D conflicts with literal operator template %qD"
+msgstr ""
+
+#: cp/decl.c:1352
+#, gcc-internal-format
+msgid "function %q+D redeclared as inline"
+msgstr ""
+
+#: cp/decl.c:1355
+#, gcc-internal-format
+msgid "previous declaration of %qD with attribute noinline"
+msgstr ""
+
+#: cp/decl.c:1362
+#, gcc-internal-format
+msgid "function %q+D redeclared with attribute noinline"
+msgstr ""
+
+#: cp/decl.c:1365
+#, gcc-internal-format
+msgid "previous declaration of %qD was inline"
+msgstr ""
+
+#: cp/decl.c:1389 cp/decl.c:1465
+#, gcc-internal-format
+msgid "shadowing built-in function %q#D"
+msgstr ""
+
+#: cp/decl.c:1390 cp/decl.c:1466
+#, gcc-internal-format
+msgid "shadowing library function %q#D"
+msgstr ""
+
+#: cp/decl.c:1397
+#, gcc-internal-format
+msgid "library function %q#D redeclared as non-function %q#D"
+msgstr ""
+
+#: cp/decl.c:1400
+#, gcc-internal-format
+msgid "declaration of %q#D conflicts with built-in declaration %q#D"
+msgstr ""
+
+#: cp/decl.c:1408
+#, gcc-internal-format
+msgid "redeclaration of %<pragma omp declare reduction%>"
+msgstr ""
+
+#: cp/decl.c:1410
+#, gcc-internal-format
+msgid "previous %<pragma omp declare reduction%> declaration"
+msgstr "попереднє оголошення %<pragma omp declare reduction%>"
+
+#: cp/decl.c:1460
+#, gcc-internal-format
+msgid "new declaration %q#D ambiguates built-in declaration %q#D"
+msgstr ""
+
+#: cp/decl.c:1551
+#, gcc-internal-format
+msgid "%q#D redeclared as different kind of symbol"
+msgstr ""
+
+#: cp/decl.c:1555 cp/decl.c:1576 cp/decl.c:1603
+#, gcc-internal-format
+msgid "previous declaration %q#D"
+msgstr ""
+
+#: cp/decl.c:1574
+#, gcc-internal-format
+msgid "conflicting declaration of template %q#D"
+msgstr ""
+
+#: cp/decl.c:1590
+#, gcc-internal-format
+msgid "ambiguating new declaration %q#D"
+msgstr ""
+
+#: cp/decl.c:1592 cp/decl.c:1615
+#, gcc-internal-format
+msgid "old declaration %q#D"
+msgstr ""
+
+#: cp/decl.c:1600
+#, gcc-internal-format
+msgid "conflicting declaration of C function %q#D"
+msgstr ""
+
+#: cp/decl.c:1613
+#, gcc-internal-format
+msgid "ambiguating new declaration of %q#D"
+msgstr ""
+
+#: cp/decl.c:1623
+#, gcc-internal-format
+msgid "conflicting declaration %q#D"
+msgstr ""
+
+#: cp/decl.c:1625
+#, gcc-internal-format
+msgid "previous declaration as %q#D"
+msgstr ""
+
+#. [namespace.alias]
+#.
+#. A namespace-name or namespace-alias shall not be declared as
+#. the name of any other entity in the same declarative region.
+#. A namespace-name defined at global scope shall not be
+#. declared as the name of any other entity in any global scope
+#. of the program.
+#: cp/decl.c:1677
+#, gcc-internal-format
+msgid "conflicting declaration of namespace %qD"
+msgstr ""
+
+#: cp/decl.c:1679
+#, gcc-internal-format
+msgid "previous declaration of namespace %qD here"
+msgstr ""
+
+#: cp/decl.c:1691
+#, gcc-internal-format
+msgid "%q+#D previously defined here"
+msgstr ""
+
+#: cp/decl.c:1692 cp/name-lookup.c:1181 cp/name-lookup.c:1204
+#, gcc-internal-format
+msgid "%q+#D previously declared here"
+msgstr ""
+
+#: cp/decl.c:1702
+#, gcc-internal-format
+msgid "prototype specified for %q#D"
+msgstr ""
+
+#: cp/decl.c:1704
+#, gcc-internal-format
+msgid "previous non-prototype definition here"
+msgstr ""
+
+#: cp/decl.c:1743
+#, gcc-internal-format
+msgid "conflicting declaration of %q#D with %qL linkage"
+msgstr ""
+
+#: cp/decl.c:1746
+#, gcc-internal-format
+msgid "previous declaration with %qL linkage"
+msgstr ""
+
+#: cp/decl.c:1780 cp/decl.c:1788
+#, gcc-internal-format
+msgid "default argument given for parameter %d of %q#D"
+msgstr ""
+
+#: cp/decl.c:1783 cp/decl.c:1791
+#, gcc-internal-format
+msgid "previous specification in %q#D here"
+msgstr ""
+
+#: cp/decl.c:1856
+#, gcc-internal-format
+msgid "redundant redeclaration of %qD in same scope"
+msgstr ""
+
+#: cp/decl.c:1859 cp/decl.c:1869 cp/decl.c:2371
+#, gcc-internal-format
+msgid "previous declaration of %qD"
+msgstr ""
+
+#: cp/decl.c:1867
+#, gcc-internal-format
+msgid "deleted definition of %qD"
+msgstr ""
+
+#. From [temp.expl.spec]:
+#.
+#. If a template, a member template or the member of a class
+#. template is explicitly specialized then that
+#. specialization shall be declared before the first use of
+#. that specialization that would cause an implicit
+#. instantiation to take place, in every translation unit in
+#. which such a use occurs.
+#: cp/decl.c:2237
+#, gcc-internal-format
+msgid "explicit specialization of %qD after first use"
+msgstr ""
+
+#: cp/decl.c:2368
+#, gcc-internal-format
+msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
+msgstr ""
+
+#. Reject two definitions.
+#: cp/decl.c:2609 cp/decl.c:2638 cp/decl.c:2671 cp/decl.c:2688 cp/decl.c:2761
+#, gcc-internal-format
+msgid "redefinition of %q#D"
+msgstr ""
+
+#: cp/decl.c:2625
+#, gcc-internal-format
+msgid "%qD conflicts with used function"
+msgstr ""
+
+#: cp/decl.c:2635
+#, gcc-internal-format
+msgid "%q#D not declared in class"
+msgstr ""
+
+#: cp/decl.c:2649 cp/decl.c:2698
+#, gcc-internal-format
+msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
+msgstr ""
+
+#: cp/decl.c:2652 cp/decl.c:2701
+#, gcc-internal-format
+msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
+msgstr ""
+
+#. is_primary=
+#. is_partial=
+#. is_friend_decl=
+#: cp/decl.c:2718
+#, gcc-internal-format
+msgid "redeclaration of friend %q#D may not have default template arguments"
+msgstr ""
+
+#: cp/decl.c:2732
+#, gcc-internal-format
+msgid "thread-local declaration of %q#D follows non-thread-local declaration"
+msgstr ""
+
+#: cp/decl.c:2735
+#, gcc-internal-format
+msgid "non-thread-local declaration of %q#D follows thread-local declaration"
+msgstr ""
+
+#: cp/decl.c:2750 cp/decl.c:2769 cp/name-lookup.c:597 cp/name-lookup.c:1180
+#: cp/name-lookup.c:1203
+#, gcc-internal-format
+msgid "redeclaration of %q#D"
+msgstr ""
+
+#: cp/decl.c:2916
+#, gcc-internal-format
+msgid "jump to label %qD"
+msgstr ""
+
+#: cp/decl.c:2917
+#, gcc-internal-format
+msgid "jump to case label"
+msgstr ""
+
+#: cp/decl.c:2919 cp/decl.c:3073 cp/decl.c:3125
+#, gcc-internal-format
+msgid "  from here"
+msgstr "  звідси"
+
+#: cp/decl.c:2941 cp/decl.c:3129
+#, gcc-internal-format
+msgid "  exits OpenMP structured block"
+msgstr ""
+
+#: cp/decl.c:2966
+#, gcc-internal-format
+msgid "  crosses initialization of %q+#D"
+msgstr ""
+
+#: cp/decl.c:2968 cp/decl.c:3093
+#, gcc-internal-format
+msgid "  enters scope of %q+#D which has non-trivial destructor"
+msgstr ""
+
+#: cp/decl.c:2985 cp/decl.c:3101
+#, gcc-internal-format
+msgid "  enters try block"
+msgstr ""
+
+#: cp/decl.c:2987 cp/decl.c:3085 cp/decl.c:3103
+#, gcc-internal-format
+msgid "  enters catch block"
+msgstr ""
+
+#: cp/decl.c:2999 cp/decl.c:3109
+#, gcc-internal-format
+msgid "  enters OpenMP structured block"
+msgstr ""
+
+#: cp/decl.c:3071 cp/decl.c:3123
+#, gcc-internal-format
+msgid "jump to label %q+D"
+msgstr ""
+
+#: cp/decl.c:3091
+#, gcc-internal-format
+msgid "  skips initialization of %q+#D"
+msgstr ""
+
+#: cp/decl.c:3146 cp/parser.c:11023 cp/parser.c:11050
+#, gcc-internal-format
+msgid "invalid exit from OpenMP structured block"
+msgstr ""
+
+#: cp/decl.c:3178
+#, gcc-internal-format
+msgid "label named wchar_t"
+msgstr ""
+
+#: cp/decl.c:3488
+#, gcc-internal-format
+msgid "%qD is not a type"
+msgstr ""
+
+#: cp/decl.c:3495 cp/parser.c:5503
+#, gcc-internal-format
+msgid "%qD used without template parameters"
+msgstr ""
+
+#: cp/decl.c:3504
+#, gcc-internal-format
+msgid "%q#T is not a class"
+msgstr ""
+
+#: cp/decl.c:3528 cp/decl.c:3620
+#, gcc-internal-format
+msgid "no class template named %q#T in %q#T"
+msgstr ""
+
+#: cp/decl.c:3529
+#, gcc-internal-format
+msgid "no type named %q#T in %q#T"
+msgstr ""
+
+#: cp/decl.c:3541
+#, gcc-internal-format
+msgid "lookup of %qT in %qT is ambiguous"
+msgstr ""
+
+#: cp/decl.c:3550
+#, gcc-internal-format
+msgid "%<typename %T::%D%> names %q#T, which is not a class template"
+msgstr ""
+
+#: cp/decl.c:3557
+#, gcc-internal-format
+msgid "%<typename %T::%D%> names %q#T, which is not a type"
+msgstr ""
+
+#: cp/decl.c:3629
+#, gcc-internal-format
+msgid "template parameters do not match template %qD"
+msgstr ""
+
+#: cp/decl.c:4358
+#, gcc-internal-format
+msgid "an anonymous struct cannot have function members"
+msgstr ""
+
+#: cp/decl.c:4361
+#, gcc-internal-format
+msgid "an anonymous union cannot have function members"
+msgstr ""
+
+#: cp/decl.c:4379
+#, gcc-internal-format
+msgid "member %q+#D with constructor not allowed in anonymous aggregate"
+msgstr ""
+
+#: cp/decl.c:4382
+#, gcc-internal-format
+msgid "member %q+#D with destructor not allowed in anonymous aggregate"
+msgstr ""
+
+#: cp/decl.c:4385
+#, gcc-internal-format
+msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
+msgstr ""
+
+#: cp/decl.c:4403
+#, gcc-internal-format
+msgid "attribute ignored in declaration of %q#T"
+msgstr ""
+
+#: cp/decl.c:4406
+#, gcc-internal-format
+msgid "attribute for %q#T must follow the %qs keyword"
+msgstr ""
+
+#: cp/decl.c:4429
+#, gcc-internal-format
+msgid "multiple types in one declaration"
+msgstr ""
+
+#: cp/decl.c:4434
+#, gcc-internal-format
+msgid "redeclaration of C++ built-in type %qT"
+msgstr ""
+
+#: cp/decl.c:4451
+#, gcc-internal-format
+msgid "%<auto%> can only be specified for variables or function declarations"
+msgstr ""
+
+#: cp/decl.c:4477
+#, gcc-internal-format
+msgid "missing type-name in typedef-declaration"
+msgstr ""
+
+#: cp/decl.c:4485
+#, gcc-internal-format
+msgid "ISO C++ prohibits anonymous structs"
+msgstr ""
+
+#: cp/decl.c:4492
+#, gcc-internal-format
+msgid "%qs can only be specified for functions"
+msgstr ""
+
+#: cp/decl.c:4498
+#, gcc-internal-format
+msgid "%<friend%> can only be specified inside a class"
+msgstr ""
+
+#: cp/decl.c:4500
+#, gcc-internal-format
+msgid "%<explicit%> can only be specified for constructors"
+msgstr ""
+
+#: cp/decl.c:4502
+#, gcc-internal-format
+msgid "a storage class can only be specified for objects and functions"
+msgstr ""
+
+#: cp/decl.c:4508
+#, gcc-internal-format
+msgid "qualifiers can only be specified for objects and functions"
+msgstr ""
+
+#: cp/decl.c:4511
+#, gcc-internal-format
+msgid "%<typedef%> was ignored in this declaration"
+msgstr ""
+
+#: cp/decl.c:4513
+#, gcc-internal-format
+msgid "%<constexpr%> cannot be used for type declarations"
+msgstr ""
+
+#: cp/decl.c:4535
+#, gcc-internal-format
+msgid "attribute ignored in explicit instantiation %q#T"
+msgstr ""
+
+#: cp/decl.c:4538
+#, gcc-internal-format
+msgid "no attribute can be applied to an explicit instantiation"
+msgstr ""
+
+#: cp/decl.c:4610
+#, gcc-internal-format
+msgid "ignoring attributes applied to class type %qT outside of definition"
+msgstr ""
+
+#. A template type parameter or other dependent type.
+#: cp/decl.c:4614
+#, gcc-internal-format
+msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
+msgstr ""
+
+#: cp/decl.c:4683 cp/decl2.c:889
+#, gcc-internal-format
+msgid "typedef %qD is initialized (use decltype instead)"
+msgstr ""
+
+#: cp/decl.c:4691
+#, gcc-internal-format
+msgid "declaration of %q#D has %<extern%> and is initialized"
+msgstr ""
+
+#: cp/decl.c:4720
+#, gcc-internal-format
+msgid "definition of %q#D is marked %<dllimport%>"
+msgstr ""
+
+#: cp/decl.c:4743
+#, gcc-internal-format
+msgid "%q+#D is not a static data member of %q#T"
+msgstr ""
+
+#: cp/decl.c:4752
+#, gcc-internal-format
+msgid "non-member-template declaration of %qD"
+msgstr ""
+
+#: cp/decl.c:4753
+#, gcc-internal-format
+msgid "does not match member template declaration here"
+msgstr ""
+
+#: cp/decl.c:4766
+#, gcc-internal-format
+msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
+msgstr ""
+
+#: cp/decl.c:4778
+#, gcc-internal-format
+msgid "duplicate initialization of %qD"
+msgstr ""
+
+#: cp/decl.c:4783
+#, gcc-internal-format
+msgid "%qD declared %<constexpr%> outside its class"
+msgstr ""
+
+#: cp/decl.c:4826
+#, gcc-internal-format
+msgid "declaration of %q#D outside of class is not definition"
+msgstr ""
+
+#: cp/decl.c:4859
+#, gcc-internal-format
+msgid "%qD declared %<thread_local%> in %<constexpr%> function"
+msgstr ""
+
+#: cp/decl.c:4862
+#, gcc-internal-format
+msgid "%qD declared %<static%> in %<constexpr%> function"
+msgstr ""
+
+#: cp/decl.c:4927
+#, gcc-internal-format
+msgid "variable %q#D has initializer but incomplete type"
+msgstr ""
+
+#: cp/decl.c:4933 cp/decl.c:5796
+#, gcc-internal-format
+msgid "elements of array %q#D have incomplete type"
+msgstr ""
+
+#: cp/decl.c:4940 cp/decl.c:6416
+#, gcc-internal-format
+msgid "declaration of %q#D has no initializer"
+msgstr ""
+
+#: cp/decl.c:4942
+#, gcc-internal-format
+msgid "aggregate %q#D has incomplete type and cannot be defined"
+msgstr ""
+
+#: cp/decl.c:4976
+#, gcc-internal-format
+msgid "%qD declared as reference but not initialized"
+msgstr ""
+
+#: cp/decl.c:5033
+#, gcc-internal-format
+msgid "name used in a GNU-style designated initializer for an array"
+msgstr ""
+
+#: cp/decl.c:5039
+#, gcc-internal-format
+msgid "name %qD used in a GNU-style designated initializer for an array"
+msgstr ""
+
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
+#, gcc-internal-format
+msgid "non-trivial designated initializers not supported"
+msgstr ""
+
+#: cp/decl.c:5058
+#, gcc-internal-format
+msgid "C99 designator %qE is not an integral constant-expression"
+msgstr ""
+
+#: cp/decl.c:5106
+#, gcc-internal-format
+msgid "initializer fails to determine size of %qD"
+msgstr ""
+
+#: cp/decl.c:5112
+#, gcc-internal-format
+msgid "array size missing in %qD"
+msgstr ""
+
+#: cp/decl.c:5123
+#, gcc-internal-format
+msgid "zero-size array %qD"
+msgstr ""
+
+#. An automatic variable with an incomplete type: that is an error.
+#. Don't talk about array types here, since we took care of that
+#. message in grokdeclarator.
+#: cp/decl.c:5165
+#, gcc-internal-format
+msgid "storage size of %qD isn%'t known"
+msgstr ""
+
+#: cp/decl.c:5188
+#, gcc-internal-format
+msgid "storage size of %qD isn%'t constant"
+msgstr ""
+
+#: cp/decl.c:5234
+#, gcc-internal-format
+msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
+msgstr ""
+
+#: cp/decl.c:5238
+#, gcc-internal-format
+msgid "you can work around this by removing the initializer"
+msgstr ""
+
+#: cp/decl.c:5265
+#, gcc-internal-format
+msgid "uninitialized const %qD"
+msgstr ""
+
+#: cp/decl.c:5269
+#, gcc-internal-format
+msgid "uninitialized variable %qD in %<constexpr%> function"
+msgstr ""
+
+#: cp/decl.c:5279
+#, gcc-internal-format
+msgid "%q#T has no user-provided default constructor"
+msgstr ""
+
+#: cp/decl.c:5283
+#, gcc-internal-format
+msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
+msgstr ""
+
+#: cp/decl.c:5285
+#, gcc-internal-format
+msgid "and the implicitly-defined constructor does not initialize %q+#D"
+msgstr ""
+
+#: cp/decl.c:5408
+#, gcc-internal-format
+msgid "invalid type %qT as initializer for a vector of type %qT"
+msgstr ""
+
+#: cp/decl.c:5449
+#, gcc-internal-format
+msgid "initializer for %qT must be brace-enclosed"
+msgstr ""
+
+#: cp/decl.c:5475
+#, gcc-internal-format
+msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
+msgstr ""
+
+#: cp/decl.c:5483
+#, gcc-internal-format
+msgid "%qT has no non-static data member named %qD"
+msgstr ""
+
+#: cp/decl.c:5503
+#, gcc-internal-format
+msgid "invalid initializer for %q#D"
+msgstr ""
+
+#: cp/decl.c:5533
+#, gcc-internal-format
+msgid "C99 designator %qE outside aggregate initializer"
+msgstr ""
+
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
+#, gcc-internal-format
+msgid "too many initializers for %qT"
+msgstr ""
+
+#: cp/decl.c:5609
+#, gcc-internal-format
+msgid "braces around scalar initializer for type %qT"
+msgstr ""
+
+#: cp/decl.c:5716
+#, gcc-internal-format
+msgid "missing braces around initializer for %qT"
+msgstr ""
+
+#: cp/decl.c:5798
+#, gcc-internal-format
+msgid "elements of array %q#T have incomplete type"
+msgstr ""
+
+#: cp/decl.c:5806
+#, gcc-internal-format
+msgid "variable-sized compound literal"
+msgstr ""
+
+#: cp/decl.c:5860
+#, gcc-internal-format
+msgid "%q#D has incomplete type"
+msgstr ""
+
+#: cp/decl.c:5880
+#, gcc-internal-format
+msgid "scalar object %qD requires one element in initializer"
+msgstr ""
+
+#: cp/decl.c:5923
+#, gcc-internal-format
+msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
+msgstr ""
+
+#: cp/decl.c:6017
+#, gcc-internal-format
+msgid "array %qD initialized by parenthesized string literal %qE"
+msgstr ""
+
+#: cp/decl.c:6048
+#, gcc-internal-format
+msgid "initializer invalid for static member with constructor"
+msgstr ""
+
+#: cp/decl.c:6050
+#, gcc-internal-format
+msgid "non-constant in-class initialization invalid for static member %qD"
+msgstr ""
+
+#: cp/decl.c:6055
+#, gcc-internal-format
+msgid "(an out of class initialization is required)"
+msgstr ""
+
+#: cp/decl.c:6229
+#, gcc-internal-format
+msgid "reference %qD is initialized with itself"
+msgstr ""
+
+#: cp/decl.c:6375
+#, gcc-internal-format
+msgid "assignment (not initialization) in declaration"
+msgstr ""
+
+#: cp/decl.c:6552
+#, gcc-internal-format
+msgid "shadowing previous type declaration of %q#D"
+msgstr ""
+
+#: cp/decl.c:6619
+#, gcc-internal-format
+msgid "Java object %qD not allocated with %<new%>"
+msgstr ""
+
+#: cp/decl.c:6667
+#, gcc-internal-format
+msgid "non-static data member %qD has Java class type"
+msgstr ""
+
+#: cp/decl.c:6748
+#, gcc-internal-format
+msgid "function %q#D is initialized like a variable"
+msgstr ""
+
+#: cp/decl.c:7182
+#, gcc-internal-format
+msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
+msgstr ""
+
+#: cp/decl.c:7185
+#, gcc-internal-format
+msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
+msgstr ""
+
+#: cp/decl.c:7191
+#, gcc-internal-format
+msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
+msgstr ""
+
+#: cp/decl.c:7425
+#, gcc-internal-format
+msgid "initializer fails to determine size of %qT"
+msgstr ""
+
+#: cp/decl.c:7429
+#, gcc-internal-format
+msgid "array size missing in %qT"
+msgstr ""
+
+#: cp/decl.c:7432
+#, gcc-internal-format
+msgid "zero-size array %qT"
+msgstr ""
+
+#: cp/decl.c:7448
+#, gcc-internal-format
+msgid "destructor for alien class %qT cannot be a member"
+msgstr ""
+
+#: cp/decl.c:7450
+#, gcc-internal-format
+msgid "constructor for alien class %qT cannot be a member"
+msgstr ""
+
+#: cp/decl.c:7474
+#, gcc-internal-format
+msgid "%qD declared as a %<virtual%> variable"
+msgstr ""
+
+#: cp/decl.c:7476
+#, gcc-internal-format
+msgid "%qD declared as an %<inline%> variable"
+msgstr ""
+
+#: cp/decl.c:7478
+#, gcc-internal-format
+msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
+msgstr ""
+
+#: cp/decl.c:7483
+#, gcc-internal-format
+msgid "%qD declared as a %<virtual%> parameter"
+msgstr ""
+
+#: cp/decl.c:7485
+#, gcc-internal-format
+msgid "%qD declared as an %<inline%> parameter"
+msgstr ""
+
+#: cp/decl.c:7487
+#, gcc-internal-format
+msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
+msgstr ""
+
+#: cp/decl.c:7492
+#, gcc-internal-format
+msgid "%qD declared as a %<virtual%> type"
+msgstr ""
+
+#: cp/decl.c:7494
+#, gcc-internal-format
+msgid "%qD declared as an %<inline%> type"
+msgstr ""
+
+#: cp/decl.c:7496
+#, gcc-internal-format
+msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
+msgstr ""
+
+#: cp/decl.c:7501
+#, gcc-internal-format
+msgid "%qD declared as a %<virtual%> field"
+msgstr ""
+
+#: cp/decl.c:7503
+#, gcc-internal-format
+msgid "%qD declared as an %<inline%> field"
+msgstr ""
+
+#: cp/decl.c:7505
+#, gcc-internal-format
+msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
+msgstr ""
+
+#: cp/decl.c:7512
+#, gcc-internal-format
+msgid "%q+D declared as a friend"
+msgstr ""
+
+#: cp/decl.c:7518
+#, gcc-internal-format
+msgid "%q+D declared with an exception specification"
+msgstr ""
+
+#: cp/decl.c:7551
+#, gcc-internal-format
+msgid "definition of %qD is not in namespace enclosing %qT"
+msgstr ""
+
+#: cp/decl.c:7591
+#, gcc-internal-format
+msgid "static member function %q#D declared with type qualifiers"
+msgstr ""
+
+#: cp/decl.c:7710
+#, gcc-internal-format
+msgid "defining explicit specialization %qD in friend declaration"
+msgstr ""
+
+#. Something like `template <class T> friend void f<T>()'.
+#: cp/decl.c:7720
+#, gcc-internal-format
+msgid "invalid use of template-id %qD in declaration of primary template"
+msgstr ""
+
+#: cp/decl.c:7738
+#, gcc-internal-format
+msgid "default arguments are not allowed in declaration of friend template specialization %qD"
+msgstr ""
+
+#: cp/decl.c:7745
+#, gcc-internal-format
+msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
+msgstr ""
+
+#: cp/decl.c:7749
+#, gcc-internal-format
+msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
+msgstr ""
+
+#: cp/decl.c:7796
+#, gcc-internal-format
+msgid "cannot declare %<::main%> to be a template"
+msgstr ""
+
+#: cp/decl.c:7798
+#, gcc-internal-format
+msgid "cannot declare %<::main%> to be inline"
+msgstr ""
+
+#: cp/decl.c:7800
+#, gcc-internal-format
+msgid "cannot declare %<::main%> to be constexpr"
+msgstr ""
+
+#: cp/decl.c:7802
+#, gcc-internal-format
+msgid "cannot declare %<::main%> to be static"
+msgstr ""
+
+#: cp/decl.c:7846
+#, gcc-internal-format
+msgid "static member function %qD cannot have cv-qualifier"
+msgstr ""
+
+#: cp/decl.c:7847
+#, gcc-internal-format
+msgid "non-member function %qD cannot have cv-qualifier"
+msgstr ""
+
+#: cp/decl.c:7855
+#, gcc-internal-format
+msgid "static member function %qD cannot have ref-qualifier"
+msgstr ""
+
+#: cp/decl.c:7856
+#, gcc-internal-format
+msgid "non-member function %qD cannot have ref-qualifier"
+msgstr ""
+
+#: cp/decl.c:7873
+#, gcc-internal-format
+msgid "literal operator with C linkage"
+msgstr ""
+
+#: cp/decl.c:7882
+#, gcc-internal-format
+msgid "%qD has invalid argument list"
+msgstr ""
+
+#: cp/decl.c:7890
+#, gcc-internal-format
+msgid "integer suffix %<%s%> shadowed by implementation"
+msgstr ""
+
+#: cp/decl.c:7896
+#, gcc-internal-format
+msgid "floating point suffix %<%s%> shadowed by implementation"
+msgstr ""
+
+#: cp/decl.c:7902
+#, gcc-internal-format
+msgid "%qD must be a non-member function"
+msgstr ""
+
+#: cp/decl.c:7980
+#, gcc-internal-format
+msgid "%<::main%> must return %<int%>"
+msgstr ""
+
+#: cp/decl.c:8022
+#, gcc-internal-format
+msgid "definition of implicitly-declared %qD"
+msgstr ""
+
+#: cp/decl.c:8027
+#, gcc-internal-format
+msgid "definition of explicitly-defaulted %q+D"
+msgstr ""
+
+#: cp/decl.c:8028
+#, gcc-internal-format
+msgid "%q+#D explicitly defaulted here"
+msgstr ""
+
+#: cp/decl.c:8045 cp/decl2.c:787
+#, gcc-internal-format
+msgid "no %q#D member function declared in class %qT"
+msgstr ""
+
+#: cp/decl.c:8324
+#, gcc-internal-format
+msgid "in-class initialization of static data member %q#D of incomplete type"
+msgstr ""
+
+#: cp/decl.c:8328
+#, gcc-internal-format
+msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
+msgstr ""
+
+#: cp/decl.c:8331
+#, gcc-internal-format
+msgid "in-class initialization of static data member %q#D of non-literal type"
+msgstr ""
+
+#: cp/decl.c:8344
+#, gcc-internal-format
+msgid "invalid in-class initialization of static data member of non-integral type %qT"
+msgstr ""
+
+#: cp/decl.c:8350
+#, gcc-internal-format
+msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
+msgstr ""
+
+#: cp/decl.c:8354
+#, gcc-internal-format
+msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
+msgstr ""
+
+#: cp/decl.c:8458 cp/decl.c:8485
+#, gcc-internal-format
+msgid "size of array %qD has non-integral type %qT"
+msgstr ""
+
+#: cp/decl.c:8461 cp/decl.c:8487
+#, gcc-internal-format
+msgid "size of array has non-integral type %qT"
+msgstr ""
+
+#: cp/decl.c:8526
+#, gcc-internal-format
+msgid "size of array %qD is negative"
+msgstr ""
+
+#: cp/decl.c:8528
+#, gcc-internal-format
+msgid "size of array is negative"
+msgstr ""
+
+#: cp/decl.c:8542
+#, gcc-internal-format
+msgid "ISO C++ forbids zero-size array %qD"
+msgstr ""
+
+#: cp/decl.c:8544
+#, gcc-internal-format
+msgid "ISO C++ forbids zero-size array"
+msgstr ""
+
+#: cp/decl.c:8557
+#, gcc-internal-format
+msgid "size of array %qD is not an integral constant-expression"
+msgstr ""
+
+#: cp/decl.c:8560
+#, gcc-internal-format
+msgid "size of array is not an integral constant-expression"
+msgstr ""
+
+#: cp/decl.c:8566
+#, gcc-internal-format
+msgid "ISO C++ forbids variable length array %qD"
+msgstr ""
+
+#: cp/decl.c:8568
+#, gcc-internal-format
+msgid "ISO C++ forbids variable length array"
+msgstr ""
+
+#: cp/decl.c:8574
+#, gcc-internal-format
+msgid "variable length array %qD is used"
+msgstr ""
+
+#: cp/decl.c:8577
+#, gcc-internal-format
+msgid "variable length array is used"
+msgstr ""
+
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "overflow in array dimension"
+msgstr ""
+
+#: cp/decl.c:8693
+#, gcc-internal-format
+msgid "%qD declared as array of %qT"
+msgstr ""
+
+#: cp/decl.c:8703
+#, gcc-internal-format
+msgid "declaration of %qD as array of void"
+msgstr ""
+
+#: cp/decl.c:8705
+#, gcc-internal-format
+msgid "creating array of void"
+msgstr ""
+
+#: cp/decl.c:8710
+#, gcc-internal-format
+msgid "declaration of %qD as array of functions"
+msgstr ""
+
+#: cp/decl.c:8712
+#, gcc-internal-format
+msgid "creating array of functions"
+msgstr ""
+
+#: cp/decl.c:8717
+#, gcc-internal-format
+msgid "declaration of %qD as array of references"
+msgstr ""
+
+#: cp/decl.c:8719
+#, gcc-internal-format
+msgid "creating array of references"
+msgstr ""
+
+#: cp/decl.c:8724
+#, gcc-internal-format
+msgid "declaration of %qD as array of function members"
+msgstr ""
+
+#: cp/decl.c:8726
+#, gcc-internal-format
+msgid "creating array of function members"
+msgstr ""
+
+#: cp/decl.c:8740
+#, gcc-internal-format
+msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
+msgstr ""
+
+#: cp/decl.c:8744
+#, gcc-internal-format
+msgid "multidimensional array must have bounds for all dimensions except the first"
+msgstr ""
+
+#: cp/decl.c:8779
+#, gcc-internal-format
+msgid "return type specification for constructor invalid"
+msgstr ""
+
+#: cp/decl.c:8789
+#, gcc-internal-format
+msgid "return type specification for destructor invalid"
+msgstr ""
+
+#: cp/decl.c:8802
+#, gcc-internal-format
+msgid "return type specified for %<operator %T%>"
+msgstr ""
+
+#: cp/decl.c:8824
+#, gcc-internal-format
+msgid "unnamed variable or field declared void"
+msgstr ""
+
+#: cp/decl.c:8831
+#, gcc-internal-format
+msgid "variable or field declared void"
+msgstr ""
+
+#: cp/decl.c:9021
+#, gcc-internal-format
+msgid "invalid use of qualified-name %<::%D%>"
+msgstr ""
+
+#: cp/decl.c:9024 cp/decl.c:9044
+#, gcc-internal-format
+msgid "invalid use of qualified-name %<%T::%D%>"
+msgstr ""
+
+#: cp/decl.c:9027
+#, gcc-internal-format
+msgid "invalid use of qualified-name %<%D::%D%>"
+msgstr ""
+
+#: cp/decl.c:9036
+#, gcc-internal-format
+msgid "%q#T is not a class or a namespace"
+msgstr ""
+
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
+#, gcc-internal-format
+msgid "declaration of %qD as non-function"
+msgstr ""
+
+#: cp/decl.c:9066
+#, gcc-internal-format
+msgid "declaration of %qD as non-member"
+msgstr ""
+
+#: cp/decl.c:9102
+#, gcc-internal-format
+msgid "declarator-id missing; using reserved word %qD"
+msgstr ""
+
+#: cp/decl.c:9149
+#, gcc-internal-format
+msgid "function definition does not declare parameters"
+msgstr ""
+
+#: cp/decl.c:9174
+#, gcc-internal-format
+msgid "declaration of %qD as %<typedef%>"
+msgstr ""
+
+#: cp/decl.c:9179
+#, gcc-internal-format
+msgid "declaration of %qD as parameter"
+msgstr ""
+
+#: cp/decl.c:9212
+#, gcc-internal-format
+msgid "%<constexpr%> cannot appear in a typedef declaration"
+msgstr ""
+
+#: cp/decl.c:9220
+#, gcc-internal-format
+msgid "two or more data types in declaration of %qs"
+msgstr ""
+
+#: cp/decl.c:9226
+#, gcc-internal-format
+msgid "conflicting specifiers in declaration of %qs"
+msgstr ""
+
+#: cp/decl.c:9267
+#, gcc-internal-format
+msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
+msgstr ""
+
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
+#, gcc-internal-format
+msgid "ISO C++ forbids declaration of %qs with no type"
+msgstr ""
+
+#: cp/decl.c:9327
+#, gcc-internal-format
+msgid "%<__int%d%> is not supported by this target"
+msgstr ""
+
+#: cp/decl.c:9333
+#, gcc-internal-format
+msgid "ISO C++ does not support %<__int%d%> for %qs"
+msgstr ""
+
+#: cp/decl.c:9355 cp/decl.c:9375
+#, gcc-internal-format
+msgid "%<signed%> or %<unsigned%> invalid for %qs"
+msgstr ""
+
+#: cp/decl.c:9357
+#, gcc-internal-format
+msgid "%<signed%> and %<unsigned%> specified together for %qs"
+msgstr ""
+
+#: cp/decl.c:9359
+#, gcc-internal-format
+msgid "%<long long%> invalid for %qs"
+msgstr ""
+
+#: cp/decl.c:9361
+#, gcc-internal-format
+msgid "%<long%> invalid for %qs"
+msgstr ""
+
+#: cp/decl.c:9363
+#, gcc-internal-format
+msgid "%<short%> invalid for %qs"
+msgstr ""
+
+#: cp/decl.c:9365
+#, gcc-internal-format
+msgid "%<long%> or %<short%> invalid for %qs"
+msgstr ""
+
+#: cp/decl.c:9367
+#, gcc-internal-format
+msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
+msgstr ""
+
+#: cp/decl.c:9369
+#, gcc-internal-format
+msgid "%<long%> or %<short%> specified with char for %qs"
+msgstr ""
+
+#: cp/decl.c:9371
+#, gcc-internal-format
+msgid "%<long%> and %<short%> specified together for %qs"
+msgstr ""
+
+#: cp/decl.c:9377
+#, gcc-internal-format
+msgid "%<short%> or %<long%> invalid for %qs"
+msgstr ""
+
+#: cp/decl.c:9385
+#, gcc-internal-format
+msgid "long, short, signed or unsigned used invalidly for %qs"
+msgstr ""
+
+#: cp/decl.c:9453
+#, gcc-internal-format
+msgid "complex invalid for %qs"
+msgstr ""
+
+#: cp/decl.c:9476
+#, gcc-internal-format
+msgid "qualifiers are not allowed on declaration of %<operator %T%>"
+msgstr ""
+
+#: cp/decl.c:9509
+#, gcc-internal-format
+msgid "member %qD cannot be declared both virtual and static"
+msgstr ""
+
+#: cp/decl.c:9520
+#, gcc-internal-format
+msgid "typedef declaration invalid in parameter declaration"
+msgstr ""
+
+#: cp/decl.c:9525
+#, gcc-internal-format
+msgid "storage class specified for template parameter %qs"
+msgstr ""
+
+#: cp/decl.c:9531
+#, gcc-internal-format
+msgid "storage class specifiers invalid in parameter declarations"
+msgstr ""
+
+#: cp/decl.c:9537
+#, gcc-internal-format
+msgid "a parameter cannot be declared %<constexpr%>"
+msgstr ""
+
+#: cp/decl.c:9546
+#, gcc-internal-format
+msgid "%<virtual%> outside class declaration"
+msgstr ""
+
+#: cp/decl.c:9564
+#, gcc-internal-format
+msgid "multiple storage classes in declaration of %qs"
+msgstr ""
+
+#: cp/decl.c:9587
+#, gcc-internal-format
+msgid "storage class specified for %qs"
+msgstr ""
+
+#: cp/decl.c:9591
+#, gcc-internal-format
+msgid "storage class specified for parameter %qs"
+msgstr ""
+
+#: cp/decl.c:9604
+#, gcc-internal-format
+msgid "nested function %qs declared %<extern%>"
+msgstr ""
+
+#: cp/decl.c:9608
+#, gcc-internal-format
+msgid "top-level declaration of %qs specifies %<auto%>"
+msgstr ""
+
+#: cp/decl.c:9615
+#, gcc-internal-format
+msgid "function-scope %qs implicitly auto and declared %<__thread%>"
+msgstr ""
+
+#: cp/decl.c:9627
+#, gcc-internal-format
+msgid "storage class specifiers invalid in friend function declarations"
+msgstr ""
+
+#: cp/decl.c:9736
+#, gcc-internal-format
+msgid "%qs declared as function returning a function"
+msgstr ""
+
+#: cp/decl.c:9741
+#, gcc-internal-format
+msgid "%qs declared as function returning an array"
+msgstr ""
+
+#: cp/decl.c:9778
+#, gcc-internal-format
+msgid "%qs function uses %<auto%> type specifier without trailing return type"
+msgstr ""
+
+#: cp/decl.c:9781
+#, gcc-internal-format
+msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
+msgstr ""
+
+#: cp/decl.c:9787
+#, gcc-internal-format
+msgid "virtual function cannot have deduced return type"
+msgstr ""
+
+#: cp/decl.c:9794
+#, gcc-internal-format
+msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
+msgstr ""
+
+#. Not using maybe_warn_cpp0x because this should
+#. always be an error.
+#: cp/decl.c:9805
+#, gcc-internal-format
+msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/decl.c:9808
+#, gcc-internal-format
+msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
+msgstr ""
+
+#: cp/decl.c:9845
+#, gcc-internal-format
+msgid "destructor cannot be static member function"
+msgstr ""
+
+#: cp/decl.c:9846
+#, gcc-internal-format
+msgid "constructor cannot be static member function"
+msgstr ""
+
+#: cp/decl.c:9850
+#, gcc-internal-format
+msgid "destructors may not be cv-qualified"
+msgstr ""
+
+#: cp/decl.c:9851
+#, gcc-internal-format
+msgid "constructors may not be cv-qualified"
+msgstr ""
+
+#: cp/decl.c:9859
+#, gcc-internal-format
+msgid "destructors may not be ref-qualified"
+msgstr ""
+
+#: cp/decl.c:9877
+#, gcc-internal-format
+msgid "constructors cannot be declared virtual"
+msgstr ""
+
+#. Cannot be both friend and virtual.
+#: cp/decl.c:9892
+#, gcc-internal-format
+msgid "virtual functions cannot be friends"
+msgstr ""
+
+#: cp/decl.c:9896
+#, gcc-internal-format
+msgid "friend declaration not in class definition"
+msgstr ""
+
+#: cp/decl.c:9898
+#, gcc-internal-format
+msgid "can%'t define friend function %qs in a local class definition"
+msgstr ""
+
+#: cp/decl.c:9919
+#, gcc-internal-format
+msgid "destructors may not have parameters"
+msgstr ""
+
+#: cp/decl.c:9945
+#, gcc-internal-format
+msgid "cannot declare pointer to %q#T"
+msgstr ""
+
+#: cp/decl.c:9958 cp/decl.c:9965
+#, gcc-internal-format
+msgid "cannot declare reference to %q#T"
+msgstr ""
+
+#: cp/decl.c:9967
+#, gcc-internal-format
+msgid "cannot declare pointer to %q#T member"
+msgstr ""
+
+#: cp/decl.c:9996
+#, gcc-internal-format
+msgid "cannot declare reference to qualified function type %qT"
+msgstr ""
+
+#: cp/decl.c:9997
+#, gcc-internal-format
+msgid "cannot declare pointer to qualified function type %qT"
+msgstr ""
+
+#: cp/decl.c:10067
+#, gcc-internal-format
+msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
+msgstr ""
+
+#: cp/decl.c:10137
+#, gcc-internal-format
+msgid "template-id %qD used as a declarator"
+msgstr ""
+
+#: cp/decl.c:10161
+#, gcc-internal-format
+msgid "member functions are implicitly friends of their class"
+msgstr ""
+
+#: cp/decl.c:10166
+#, gcc-internal-format
+msgid "extra qualification %<%T::%> on member %qs"
+msgstr ""
+
+#: cp/decl.c:10196
+#, gcc-internal-format
+msgid "cannot define member function %<%T::%s%> within %<%T%>"
+msgstr ""
+
+#: cp/decl.c:10198
+#, gcc-internal-format
+msgid "cannot declare member function %<%T::%s%> within %<%T%>"
+msgstr ""
+
+#: cp/decl.c:10206
+#, gcc-internal-format
+msgid "cannot declare member %<%T::%s%> within %qT"
+msgstr ""
+
+#: cp/decl.c:10239
+#, gcc-internal-format
+msgid "non-parameter %qs cannot be a parameter pack"
+msgstr ""
+
+#: cp/decl.c:10249
+#, gcc-internal-format
+msgid "size of array %qs is too large"
+msgstr ""
+
+#: cp/decl.c:10260
+#, gcc-internal-format
+msgid "data member may not have variably modified type %qT"
+msgstr ""
+
+#: cp/decl.c:10262
+#, gcc-internal-format
+msgid "parameter may not have variably modified type %qT"
+msgstr ""
+
+#: cp/decl.c:10272
+#, gcc-internal-format
+msgid "%<explicit%> outside class declaration"
+msgstr ""
+
+#: cp/decl.c:10274
+#, gcc-internal-format
+msgid "%<explicit%> in friend declaration"
+msgstr ""
+
+#: cp/decl.c:10276
+#, gcc-internal-format
+msgid "only declarations of constructors and conversion operators can be %<explicit%>"
+msgstr ""
+
+#: cp/decl.c:10285
+#, gcc-internal-format
+msgid "non-member %qs cannot be declared %<mutable%>"
+msgstr ""
+
+#: cp/decl.c:10290
+#, gcc-internal-format
+msgid "non-object member %qs cannot be declared %<mutable%>"
+msgstr ""
+
+#: cp/decl.c:10296
+#, gcc-internal-format
+msgid "function %qs cannot be declared %<mutable%>"
+msgstr ""
+
+#: cp/decl.c:10301
+#, gcc-internal-format
+msgid "static %qs cannot be declared %<mutable%>"
+msgstr ""
+
+#: cp/decl.c:10306
+#, gcc-internal-format
+msgid "const %qs cannot be declared %<mutable%>"
+msgstr ""
+
+#: cp/decl.c:10311
+#, gcc-internal-format
+msgid "reference %qs cannot be declared %<mutable%>"
+msgstr ""
+
+#: cp/decl.c:10347
+#, gcc-internal-format
+msgid "typedef declared %<auto%>"
+msgstr ""
+
+#: cp/decl.c:10357
+#, gcc-internal-format
+msgid "typedef name may not be a nested-name-specifier"
+msgstr ""
+
+#: cp/decl.c:10378
+#, gcc-internal-format
+msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
+msgstr ""
+
+#: cp/decl.c:10497
+#, gcc-internal-format
+msgid "type qualifiers specified for friend class declaration"
+msgstr ""
+
+#: cp/decl.c:10502
+#, gcc-internal-format
+msgid "%<inline%> specified for friend class declaration"
+msgstr ""
+
+#: cp/decl.c:10510
+#, gcc-internal-format
+msgid "template parameters cannot be friends"
+msgstr ""
+
+#: cp/decl.c:10512
+#, gcc-internal-format
+msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
+msgstr ""
+
+#: cp/decl.c:10516
+#, gcc-internal-format
+msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
+msgstr ""
+
+#: cp/decl.c:10529
+#, gcc-internal-format
+msgid "trying to make class %qT a friend of global scope"
+msgstr ""
+
+#: cp/decl.c:10549
+#, gcc-internal-format
+msgid "invalid qualifiers on non-member function type"
+msgstr ""
+
+#: cp/decl.c:10559
+#, gcc-internal-format
+msgid "abstract declarator %qT used as declaration"
+msgstr ""
+
+#: cp/decl.c:10588
+#, gcc-internal-format
+msgid "cannot use %<::%> in parameter declaration"
+msgstr ""
+
+#: cp/decl.c:10593
+#, gcc-internal-format
+msgid "%<auto%> parameter not permitted in this context"
+msgstr ""
+
+#: cp/decl.c:10595
+#, gcc-internal-format
+msgid "parameter declared %<auto%>"
+msgstr ""
+
+#: cp/decl.c:10641
+#, gcc-internal-format
+msgid "non-static data member declared %<auto%>"
+msgstr ""
+
+#. Something like struct S { int N::j; };
+#: cp/decl.c:10663
+#, gcc-internal-format
+msgid "invalid use of %<::%>"
+msgstr ""
+
+#: cp/decl.c:10685
+#, gcc-internal-format
+msgid "declaration of function %qD in invalid context"
+msgstr ""
+
+#: cp/decl.c:10694
+#, gcc-internal-format
+msgid "function %qD declared virtual inside a union"
+msgstr ""
+
+#: cp/decl.c:10703
+#, gcc-internal-format
+msgid "%qD cannot be declared virtual, since it is always static"
+msgstr ""
+
+#: cp/decl.c:10719
+#, gcc-internal-format
+msgid "expected qualified name in friend declaration for destructor %qD"
+msgstr ""
+
+#: cp/decl.c:10726
+#, gcc-internal-format
+msgid "declaration of %qD as member of %qT"
+msgstr ""
+
+#: cp/decl.c:10732
+#, gcc-internal-format
+msgid "a destructor cannot be %<constexpr%>"
+msgstr ""
+
+#: cp/decl.c:10738
+#, gcc-internal-format
+msgid "expected qualified name in friend declaration for constructor %qD"
+msgstr ""
+
+#: cp/decl.c:10749
+#, gcc-internal-format
+msgid "specialization of variable template %qD declared as function"
+msgstr ""
+
+#: cp/decl.c:10752
+#, gcc-internal-format
+msgid "variable template declared here"
+msgstr ""
+
+#: cp/decl.c:10804
+#, gcc-internal-format
+msgid "field %qD has incomplete type %qT"
+msgstr ""
+
+#: cp/decl.c:10809
+#, gcc-internal-format
+msgid "name %qT has incomplete type"
+msgstr ""
+
+#: cp/decl.c:10818
+#, gcc-internal-format
+msgid "%qE is neither function nor member function; cannot be declared friend"
+msgstr ""
+
+#: cp/decl.c:10877
+#, gcc-internal-format
+msgid "constexpr static data member %qD must have an initializer"
+msgstr ""
+
+#: cp/decl.c:10886
+#, gcc-internal-format
+msgid "non-static data member %qE declared %<constexpr%>"
+msgstr ""
+
+#: cp/decl.c:10936
+#, gcc-internal-format
+msgid "storage class %<auto%> invalid for function %qs"
+msgstr ""
+
+#: cp/decl.c:10938
+#, gcc-internal-format
+msgid "storage class %<register%> invalid for function %qs"
+msgstr ""
+
+#: cp/decl.c:10942
+#, gcc-internal-format
+msgid "storage class %<__thread%> invalid for function %qs"
+msgstr ""
+
+#: cp/decl.c:10945
+#, gcc-internal-format
+msgid "storage class %<thread_local%> invalid for function %qs"
+msgstr ""
+
+#: cp/decl.c:10950
+#, gcc-internal-format
+msgid "virt-specifiers in %qs not allowed outside a class definition"
+msgstr ""
+
+#: cp/decl.c:10961
+#, gcc-internal-format
+msgid "%<static%> specified invalid for function %qs declared out of global scope"
+msgstr ""
+
+#: cp/decl.c:10965
+#, gcc-internal-format
+msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
+msgstr ""
+
+#: cp/decl.c:10973
+#, gcc-internal-format
+msgid "virtual non-class function %qs"
+msgstr ""
+
+#: cp/decl.c:10980
+#, gcc-internal-format
+msgid "%qs defined in a non-class scope"
+msgstr ""
+
+#: cp/decl.c:10981
+#, gcc-internal-format
+msgid "%qs declared in a non-class scope"
+msgstr ""
+
+#: cp/decl.c:11012
+#, gcc-internal-format
+msgid "cannot declare member function %qD to have static linkage"
+msgstr ""
+
+#. FIXME need arm citation
+#: cp/decl.c:11019
+#, gcc-internal-format
+msgid "cannot declare static function inside another function"
+msgstr ""
+
+#: cp/decl.c:11053
+#, gcc-internal-format
+msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
+msgstr ""
+
+#: cp/decl.c:11060
+#, gcc-internal-format
+msgid "static member %qD declared %<register%>"
+msgstr ""
+
+#: cp/decl.c:11066
+#, gcc-internal-format
+msgid "cannot explicitly declare member %q#D to have extern linkage"
+msgstr ""
+
+#: cp/decl.c:11073
+#, gcc-internal-format
+msgid "declaration of constexpr variable %qD is not a definition"
+msgstr ""
+
+#: cp/decl.c:11086
+#, gcc-internal-format
+msgid "%qs initialized and declared %<extern%>"
+msgstr ""
+
+#: cp/decl.c:11090
+#, gcc-internal-format
+msgid "%qs has both %<extern%> and initializer"
+msgstr ""
+
+#: cp/decl.c:11237
+#, gcc-internal-format
+msgid "default argument %qE uses %qD"
+msgstr ""
+
+#: cp/decl.c:11240
+#, gcc-internal-format
+msgid "default argument %qE uses local variable %qD"
+msgstr ""
+
+#: cp/decl.c:11321
+#, gcc-internal-format
+msgid "invalid use of cv-qualified type %qT in parameter declaration"
+msgstr ""
+
+#: cp/decl.c:11325
+#, gcc-internal-format
+msgid "invalid use of type %<void%> in parameter declaration"
+msgstr ""
+
+#: cp/decl.c:11338
+#, gcc-internal-format
+msgid "parameter %qD has Java class type"
+msgstr ""
+
+#: cp/decl.c:11366
+#, gcc-internal-format
+msgid "parameter %qD invalidly declared method type"
+msgstr ""
+
+#: cp/decl.c:11391
+#, gcc-internal-format
+msgid "parameter %qD includes pointer to array of unknown bound %qT"
+msgstr ""
+
+#: cp/decl.c:11393
+#, gcc-internal-format
+msgid "parameter %qD includes reference to array of unknown bound %qT"
+msgstr ""
+
+#. [class.copy]
+#.
+#. A declaration of a constructor for a class X is ill-formed if
+#. its first parameter is of type (optionally cv-qualified) X
+#. and either there are no other parameters or else all other
+#. parameters have default arguments.
+#.
+#. We *don't* complain about member template instantiations that
+#. have this form, though; they can occur as we try to decide
+#. what constructor to use during overload resolution.  Since
+#. overload resolution will never prefer such a constructor to
+#. the non-template copy constructor (which is either explicitly
+#. or implicitly defined), there's no need to worry about their
+#. existence.  Theoretically, they should never even be
+#. instantiated, but that's hard to forestall.
+#: cp/decl.c:11643
+#, gcc-internal-format
+msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
+msgstr ""
+
+#: cp/decl.c:11765
+#, gcc-internal-format
+msgid "%qD may not be declared within a namespace"
+msgstr ""
+
+#: cp/decl.c:11770
+#, gcc-internal-format
+msgid "%qD may not be declared as static"
+msgstr ""
+
+#: cp/decl.c:11779
+#, gcc-internal-format
+msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
+msgstr ""
+
+#: cp/decl.c:11806
+#, gcc-internal-format
+msgid "%qD must be a nonstatic member function"
+msgstr ""
+
+#: cp/decl.c:11815
+#, gcc-internal-format
+msgid "%qD must be either a non-static member function or a non-member function"
+msgstr ""
+
+#: cp/decl.c:11837
+#, gcc-internal-format
+msgid "%qD must have an argument of class or enumerated type"
+msgstr ""
+
+#: cp/decl.c:11866
+#, gcc-internal-format
+msgid "conversion to a reference to void will never use a type conversion operator"
+msgstr ""
+
+#: cp/decl.c:11868
+#, gcc-internal-format
+msgid "conversion to void will never use a type conversion operator"
+msgstr ""
+
+#: cp/decl.c:11875
+#, gcc-internal-format
+msgid "conversion to a reference to the same type will never use a type conversion operator"
+msgstr ""
+
+#: cp/decl.c:11877
+#, gcc-internal-format
+msgid "conversion to the same type will never use a type conversion operator"
+msgstr ""
+
+#: cp/decl.c:11885
+#, gcc-internal-format
+msgid "conversion to a reference to a base class will never use a type conversion operator"
+msgstr ""
+
+#: cp/decl.c:11887
+#, gcc-internal-format
+msgid "conversion to a base class will never use a type conversion operator"
+msgstr ""
+
+#. 13.4.0.3
+#: cp/decl.c:11896
+#, gcc-internal-format
+msgid "ISO C++ prohibits overloading operator ?:"
+msgstr ""
+
+#: cp/decl.c:11901
+#, gcc-internal-format
+msgid "%qD must not have variable number of arguments"
+msgstr ""
+
+#: cp/decl.c:11952
+#, gcc-internal-format
+msgid "postfix %qD must take %<int%> as its argument"
+msgstr ""
+
+#: cp/decl.c:11955
+#, gcc-internal-format
+msgid "postfix %qD must take %<int%> as its second argument"
+msgstr ""
+
+#: cp/decl.c:11963
+#, gcc-internal-format
+msgid "%qD must take either zero or one argument"
+msgstr ""
+
+#: cp/decl.c:11965
+#, gcc-internal-format
+msgid "%qD must take either one or two arguments"
+msgstr ""
+
+#: cp/decl.c:11987
+#, gcc-internal-format
+msgid "prefix %qD should return %qT"
+msgstr ""
+
+#: cp/decl.c:11993
+#, gcc-internal-format
+msgid "postfix %qD should return %qT"
+msgstr ""
+
+#: cp/decl.c:12002
+#, gcc-internal-format
+msgid "%qD must take %<void%>"
+msgstr ""
+
+#: cp/decl.c:12004 cp/decl.c:12013
+#, gcc-internal-format
+msgid "%qD must take exactly one argument"
+msgstr ""
+
+#: cp/decl.c:12015
+#, gcc-internal-format
+msgid "%qD must take exactly two arguments"
+msgstr ""
+
+#: cp/decl.c:12024
+#, gcc-internal-format
+msgid "user-defined %qD always evaluates both arguments"
+msgstr ""
+
+#: cp/decl.c:12038
+#, gcc-internal-format
+msgid "%qD should return by value"
+msgstr ""
+
+#: cp/decl.c:12049 cp/decl.c:12054
+#, gcc-internal-format
+msgid "%qD cannot have default arguments"
+msgstr ""
+
+#: cp/decl.c:12112
+#, gcc-internal-format
+msgid "using template type parameter %qT after %qs"
+msgstr ""
+
+#: cp/decl.c:12135
+#, gcc-internal-format
+msgid "using alias template specialization %qT after %qs"
+msgstr ""
+
+#: cp/decl.c:12138
+#, gcc-internal-format
+msgid "using typedef-name %qD after %qs"
+msgstr ""
+
+#: cp/decl.c:12140
+#, gcc-internal-format
+msgid "%qD has a previous declaration here"
+msgstr ""
+
+#: cp/decl.c:12148
+#, gcc-internal-format
+msgid "%qT referred to as %qs"
+msgstr ""
+
+#: cp/decl.c:12149 cp/decl.c:12156
+#, gcc-internal-format
+msgid "%q+T has a previous declaration here"
+msgstr ""
+
+#: cp/decl.c:12155
+#, gcc-internal-format
+msgid "%qT referred to as enum"
+msgstr ""
+
+#. If a class template appears as elaborated type specifier
+#. without a template header such as:
+#.
+#. template <class T> class C {};
+#. void f(class C);		// No template header here
+#.
+#. then the required template argument is missing.
+#: cp/decl.c:12170
+#, gcc-internal-format
+msgid "template argument required for %<%s %T%>"
+msgstr ""
+
+#: cp/decl.c:12224 cp/name-lookup.c:3202
+#, gcc-internal-format
+msgid "%qD has the same name as the class in which it is declared"
+msgstr ""
+
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
+#, gcc-internal-format
+msgid "reference to %qD is ambiguous"
+msgstr ""
+
+#: cp/decl.c:12375
+#, gcc-internal-format
+msgid "use of enum %q#D without previous declaration"
+msgstr ""
+
+#: cp/decl.c:12400
+#, gcc-internal-format
+msgid "redeclaration of %qT as a non-template"
+msgstr ""
+
+#: cp/decl.c:12401
+#, gcc-internal-format
+msgid "previous declaration %q+D"
+msgstr ""
+
+#: cp/decl.c:12542
+#, gcc-internal-format
+msgid "derived union %qT invalid"
+msgstr ""
+
+#: cp/decl.c:12551
+#, gcc-internal-format
+msgid "Java class %qT cannot have multiple bases"
+msgstr ""
+
+#: cp/decl.c:12562
+#, gcc-internal-format
+msgid "Java class %qT cannot have virtual bases"
+msgstr ""
+
+#: cp/decl.c:12582
+#, gcc-internal-format
+msgid "base type %qT fails to be a struct or class type"
+msgstr ""
+
+#: cp/decl.c:12615
+#, gcc-internal-format
+msgid "recursive type %qT undefined"
+msgstr ""
+
+#: cp/decl.c:12617
+#, gcc-internal-format
+msgid "duplicate base type %qT invalid"
+msgstr ""
+
+#: cp/decl.c:12741
+#, gcc-internal-format
+msgid "scoped/unscoped mismatch in enum %q#T"
+msgstr ""
+
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
+#, gcc-internal-format
+msgid "previous definition here"
+msgstr ""
+
+#: cp/decl.c:12749
+#, gcc-internal-format
+msgid "underlying type mismatch in enum %q#T"
+msgstr ""
+
+#: cp/decl.c:12761
+#, gcc-internal-format
+msgid "different underlying type in enum %q#T"
+msgstr ""
+
+#: cp/decl.c:12828
+#, gcc-internal-format
+msgid "underlying type %<%T%> of %<%T%> must be an integral type"
+msgstr ""
+
+#. DR 377
+#.
+#. IF no integral type can represent all the enumerator values, the
+#. enumeration is ill-formed.
+#: cp/decl.c:12962
+#, gcc-internal-format
+msgid "no integral type can represent all of the enumerator values for %qT"
+msgstr ""
+
+#: cp/decl.c:13124
+#, gcc-internal-format
+msgid "enumerator value for %qD is not an integer constant"
+msgstr ""
+
+#: cp/decl.c:13171
+#, gcc-internal-format
+msgid "incremented enumerator value is too large for %<unsigned long%>"
+msgstr ""
+
+#: cp/decl.c:13183
+#, gcc-internal-format
+msgid "overflow in enumeration values at %qD"
+msgstr ""
+
+#: cp/decl.c:13203
+#, gcc-internal-format
+msgid "enumerator value %E is outside the range of underlying type %<%T%>"
+msgstr ""
+
+#: cp/decl.c:13293
+#, gcc-internal-format
+msgid "return type %q#T is incomplete"
+msgstr ""
+
+#: cp/decl.c:13295
+#, gcc-internal-format
+msgid "return type has Java class type %q#T"
+msgstr ""
+
+#: cp/decl.c:13419 cp/typeck.c:8605
+#, gcc-internal-format
+msgid "%<operator=%> should return a reference to %<*this%>"
+msgstr ""
+
+#: cp/decl.c:13519
+#, gcc-internal-format
+msgid "no previous declaration for %q+D"
+msgstr ""
+
+#: cp/decl.c:13743
+#, gcc-internal-format
+msgid "invalid function declaration"
+msgstr ""
+
+#: cp/decl.c:13825
+#, gcc-internal-format
+msgid "parameter %qD declared void"
+msgstr ""
+
+#: cp/decl.c:14215
+#, gcc-internal-format
+msgid "no return statements in function returning %qT"
+msgstr ""
+
+#: cp/decl.c:14217 cp/typeck.c:8488
+#, gcc-internal-format
+msgid "only plain %<auto%> return type can be deduced to %<void%>"
+msgstr ""
+
+#: cp/decl.c:14315
+#, gcc-internal-format
+msgid "parameter %q+D set but not used"
+msgstr ""
+
+#: cp/decl.c:14411
+#, gcc-internal-format
+msgid "invalid member function declaration"
+msgstr ""
+
+#: cp/decl.c:14425
+#, gcc-internal-format
+msgid "%qD is already defined in class %qT"
+msgstr ""
+
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
+#, gcc-internal-format
+msgid "use of %qD before deduction of %<auto%>"
+msgstr ""
+
+#: cp/decl2.c:344
+#, gcc-internal-format
+msgid "name missing for member function"
+msgstr ""
+
+#: cp/decl2.c:420 cp/decl2.c:434
+#, gcc-internal-format
+msgid "ambiguous conversion for array subscript"
+msgstr ""
+
+#: cp/decl2.c:428
+#, gcc-internal-format
+msgid "invalid types %<%T[%T]%> for array subscript"
+msgstr ""
+
+#: cp/decl2.c:471
+#, gcc-internal-format
+msgid "deleting array %q#E"
+msgstr ""
+
+#: cp/decl2.c:477
+#, gcc-internal-format
+msgid "type %q#T argument given to %<delete%>, expected pointer"
+msgstr ""
+
+#: cp/decl2.c:489
+#, gcc-internal-format
+msgid "cannot delete a function.  Only pointer-to-objects are valid arguments to %<delete%>"
+msgstr ""
+
+#: cp/decl2.c:497
+#, gcc-internal-format
+msgid "deleting %qT is undefined"
+msgstr ""
+
+#: cp/decl2.c:545 cp/pt.c:4843
+#, gcc-internal-format
+msgid "template declaration of %q#D"
+msgstr ""
+
+#: cp/decl2.c:597
+#, gcc-internal-format
+msgid "Java method %qD has non-Java return type %qT"
+msgstr ""
+
+#: cp/decl2.c:614
+#, gcc-internal-format
+msgid "Java method %qD has non-Java parameter type %qT"
+msgstr ""
+
+#: cp/decl2.c:663
+#, gcc-internal-format
+msgid "template parameter lists provided don%'t match the template parameters of %qD"
+msgstr ""
+
+#. [temp.mem]
+#.
+#. A destructor shall not be a member template.
+#: cp/decl2.c:678 cp/pt.c:4813
+#, gcc-internal-format
+msgid "destructor %qD declared as member template"
+msgstr ""
+
+#: cp/decl2.c:749
+#, gcc-internal-format
+msgid "prototype for %q#D does not match any in class %qT"
+msgstr ""
+
+#: cp/decl2.c:835
+#, gcc-internal-format
+msgid "local class %q#T shall not have static data member %q#D"
+msgstr ""
+
+#: cp/decl2.c:843
+#, gcc-internal-format
+msgid "static data member %qD in unnamed class"
+msgstr ""
+
+#: cp/decl2.c:845
+#, gcc-internal-format
+msgid "unnamed class defined here"
+msgstr ""
+
+#: cp/decl2.c:904
+#, gcc-internal-format
+msgid "explicit template argument list not allowed"
+msgstr ""
+
+#: cp/decl2.c:910
+#, gcc-internal-format
+msgid "member %qD conflicts with virtual function table field name"
+msgstr ""
+
+#: cp/decl2.c:952
+#, gcc-internal-format
+msgid "%qD is already defined in %qT"
+msgstr ""
+
+#: cp/decl2.c:979 cp/decl2.c:987
+#, gcc-internal-format
+msgid "invalid initializer for member function %qD"
+msgstr ""
+
+#: cp/decl2.c:994
+#, gcc-internal-format
+msgid "initializer specified for friend function %qD"
+msgstr ""
+
+#: cp/decl2.c:997
+#, gcc-internal-format
+msgid "initializer specified for static member function %qD"
+msgstr ""
+
+#: cp/decl2.c:1041
+#, gcc-internal-format
+msgid "%<asm%> specifiers are not permitted on non-static data members"
+msgstr ""
+
+#: cp/decl2.c:1094
+#, gcc-internal-format
+msgid "bit-field %qD with non-integral type"
+msgstr ""
+
+#: cp/decl2.c:1100
+#, gcc-internal-format
+msgid "cannot declare %qD to be a bit-field type"
+msgstr ""
+
+#: cp/decl2.c:1110
+#, gcc-internal-format
+msgid "cannot declare bit-field %qD with function type"
+msgstr ""
+
+#: cp/decl2.c:1117
+#, gcc-internal-format
+msgid "%qD is already defined in the class %qT"
+msgstr ""
+
+#: cp/decl2.c:1124
+#, gcc-internal-format
+msgid "static member %qD cannot be a bit-field"
+msgstr ""
+
+#: cp/decl2.c:1134
+#, gcc-internal-format
+msgid "width of bit-field %qD has non-integral type %qT"
+msgstr ""
+
+#: cp/decl2.c:1453
+#, gcc-internal-format
+msgid "%q+D static data member inside of declare target directive"
+msgstr ""
+
+#: cp/decl2.c:1522
+#, gcc-internal-format
+msgid "anonymous struct not inside named type"
+msgstr ""
+
+#: cp/decl2.c:1610
+#, gcc-internal-format
+msgid "namespace-scope anonymous aggregates must be static"
+msgstr ""
+
+#: cp/decl2.c:1619
+#, gcc-internal-format
+msgid "anonymous union with no members"
+msgstr ""
+
+#: cp/decl2.c:1652
+#, gcc-internal-format
+msgid "%<operator new%> must return type %qT"
+msgstr ""
+
+#. [basic.stc.dynamic.allocation]
+#.
+#. The first parameter shall not have an associated default
+#. argument.
+#: cp/decl2.c:1663
+#, gcc-internal-format
+msgid "the first parameter of %<operator new%> cannot have a default argument"
+msgstr ""
+
+#: cp/decl2.c:1679
+#, gcc-internal-format
+msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
+msgstr ""
+
+#: cp/decl2.c:1708
+#, gcc-internal-format
+msgid "%<operator delete%> must return type %qT"
+msgstr ""
+
+#: cp/decl2.c:1717
+#, gcc-internal-format
+msgid "%<operator delete%> takes type %qT as first parameter"
+msgstr ""
+
+#: cp/decl2.c:2559
+#, gcc-internal-format
+msgid "%qT has a field %qD whose type uses the anonymous namespace"
+msgstr ""
+
+#: cp/decl2.c:2566
+#, gcc-internal-format
+msgid "%qT declared with greater visibility than the type of its field %qD"
+msgstr ""
+
+#: cp/decl2.c:2579
+#, gcc-internal-format
+msgid "%qT has a base %qT whose type uses the anonymous namespace"
+msgstr ""
+
+#: cp/decl2.c:2585
+#, gcc-internal-format
+msgid "%qT declared with greater visibility than its base %qT"
+msgstr ""
+
+#: cp/decl2.c:4213
+#, gcc-internal-format
+msgid "%q#D, declared using anonymous type, is used but never defined"
+msgstr ""
+
+#. DRs 132, 319 and 389 seem to indicate types with
+#. no linkage can only be used to declare extern "C"
+#. entities.  Since it's not always an error in the
+#. ISO C++ 90 Standard, we only issue a warning.
+#: cp/decl2.c:4222
+#, gcc-internal-format
+msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
+msgstr ""
+
+#: cp/decl2.c:4226
+#, gcc-internal-format
+msgid "anonymous type with no linkage used to declare function %q#D with linkage"
+msgstr ""
+
+#: cp/decl2.c:4230
+#, gcc-internal-format
+msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
+msgstr ""
+
+#: cp/decl2.c:4235
+#, gcc-internal-format
+msgid "%q#D, declared using local type %qT, is used but never defined"
+msgstr ""
+
+#: cp/decl2.c:4238
+#, gcc-internal-format
+msgid "type %qT with no linkage used to declare variable %q#D with linkage"
+msgstr ""
+
+#: cp/decl2.c:4241
+#, gcc-internal-format
+msgid "type %qT with no linkage used to declare function %q#D with linkage"
+msgstr ""
+
+#: cp/decl2.c:4362 cp/decl2.c:4365
+#, gcc-internal-format
+msgid "the program should also define %qD"
+msgstr ""
+
+#: cp/decl2.c:4700
+#, gcc-internal-format
+msgid "inline function %q+D used but never defined"
+msgstr ""
+
+#: cp/decl2.c:4898
+#, gcc-internal-format
+msgid "default argument missing for parameter %P of %q+#D"
+msgstr ""
+
+#. We mark a lambda conversion op as deleted if we can't
+#. generate it properly; see maybe_add_lambda_conv_op.
+#: cp/decl2.c:4962
+#, gcc-internal-format
+msgid "converting lambda which uses %<...%> to function pointer"
+msgstr ""
+
+#: cp/decl2.c:4969
+#, gcc-internal-format
+msgid "use of deleted function %qD"
+msgstr ""
+
+#: cp/error.c:1446
+#, gcc-internal-format
+msgid "with"
+msgstr ""
+
+#: cp/error.c:3538
+#, gcc-internal-format
+msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3543
+#, gcc-internal-format
+msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3548
+#, gcc-internal-format
+msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3553
+#, gcc-internal-format
+msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3558
+#, gcc-internal-format
+msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3562
+#, gcc-internal-format
+msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3566
+#, gcc-internal-format
+msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3571
+#, gcc-internal-format
+msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3576
+#, gcc-internal-format
+msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3581
+#, gcc-internal-format
+msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3586
+#, gcc-internal-format
+msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3591
+#, gcc-internal-format
+msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3596
+#, gcc-internal-format
+msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3601
+#, gcc-internal-format
+msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3606
+#, gcc-internal-format
+msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/error.c:3655
+#, gcc-internal-format
+msgid "incomplete type %qT used in nested name specifier"
+msgstr ""
+
+#: cp/error.c:3659
+#, gcc-internal-format
+msgid "reference to %<%T::%D%> is ambiguous"
+msgstr ""
+
+#: cp/error.c:3664 cp/typeck.c:2321
+#, gcc-internal-format
+msgid "%qD is not a member of %qT"
+msgstr ""
+
+#: cp/error.c:3668
+#, gcc-internal-format
+msgid "%qD is not a member of %qD"
+msgstr ""
+
+#: cp/error.c:3673
+#, gcc-internal-format
+msgid "%<::%D%> has not been declared"
+msgstr ""
+
+#. Can't throw a reference.
+#: cp/except.c:296
+#, gcc-internal-format
+msgid "type %qT is disallowed in Java %<throw%> or %<catch%>"
+msgstr ""
+
+#: cp/except.c:308
+#, gcc-internal-format
+msgid "call to Java %<catch%> or %<throw%> with %<jthrowable%> undefined"
+msgstr ""
+
+#. Thrown object must be a Throwable.
+#: cp/except.c:315
+#, gcc-internal-format
+msgid "type %qT is not derived from %<java::lang::Throwable%>"
+msgstr ""
+
+#: cp/except.c:376
+#, gcc-internal-format
+msgid "mixing C++ and Java catches in a single translation unit"
+msgstr ""
+
+#: cp/except.c:477 java/except.c:592
+#, gcc-internal-format
+msgid "exception handling disabled, use -fexceptions to enable"
+msgstr ""
+
+#: cp/except.c:730
+#, gcc-internal-format
+msgid "throwing NULL, which has integral, not pointer type"
+msgstr ""
+
+#: cp/except.c:754 cp/init.c:2531
+#, gcc-internal-format
+msgid "%qD should never be overloaded"
+msgstr ""
+
+#: cp/except.c:858
+#, gcc-internal-format
+msgid "  in thrown expression"
+msgstr ""
+
+#: cp/except.c:997
+#, gcc-internal-format
+msgid "cannot declare catch parameter to be of rvalue reference type %qT"
+msgstr ""
+
+#: cp/except.c:1004
+#, gcc-internal-format
+msgid "cannot throw expression of type %qT because it involves types of variable size"
+msgstr ""
+
+#: cp/except.c:1007
+#, gcc-internal-format
+msgid "cannot catch type %qT because it involves types of variable size"
+msgstr ""
+
+#: cp/except.c:1093
+#, gcc-internal-format
+msgid "exception of type %qT will be caught"
+msgstr ""
+
+#: cp/except.c:1096
+#, gcc-internal-format
+msgid "   by earlier handler for %qT"
+msgstr ""
+
+#: cp/except.c:1125
+#, gcc-internal-format
+msgid "%<...%> handler must be the last handler for its try block"
+msgstr ""
+
+#: cp/except.c:1205
+#, gcc-internal-format
+msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
+msgstr ""
+
+#: cp/except.c:1207
+#, gcc-internal-format
+msgid "but %q+D does not throw; perhaps it should be declared %<noexcept%>"
+msgstr ""
+
+#: cp/friend.c:161
+#, gcc-internal-format
+msgid "%qD is already a friend of class %qT"
+msgstr ""
+
+#: cp/friend.c:246
+#, gcc-internal-format
+msgid "invalid type %qT declared %<friend%>"
+msgstr ""
+
+#. [temp.friend]
+#. Friend declarations shall not declare partial
+#. specializations.
+#. template <class U> friend class T::X<U>;
+#. [temp.friend]
+#. Friend declarations shall not declare partial
+#. specializations.
+#: cp/friend.c:267 cp/friend.c:297
+#, gcc-internal-format
+msgid "partial specialization %qT declared %<friend%>"
+msgstr ""
+
+#: cp/friend.c:275
+#, gcc-internal-format
+msgid "class %qT is implicitly friends with itself"
+msgstr ""
+
+#: cp/friend.c:333
+#, gcc-internal-format
+msgid "%qT is not a member of %qT"
+msgstr ""
+
+#: cp/friend.c:338
+#, gcc-internal-format
+msgid "%qT is not a member class template of %qT"
+msgstr ""
+
+#: cp/friend.c:340 cp/friend.c:348
+#, gcc-internal-format
+msgid "%q+D declared here"
+msgstr ""
+
+#: cp/friend.c:346
+#, gcc-internal-format
+msgid "%qT is not a nested class of %qT"
+msgstr ""
+
+#. template <class T> friend class T;
+#: cp/friend.c:359
+#, gcc-internal-format
+msgid "template parameter type %qT declared %<friend%>"
+msgstr ""
+
+#. template <class T> friend class A; where A is not a template
+#: cp/friend.c:367
+#, gcc-internal-format
+msgid "%q#T is not a template"
+msgstr ""
+
+#: cp/friend.c:390
+#, gcc-internal-format
+msgid "%qD is already a friend of %qT"
+msgstr ""
+
+#: cp/friend.c:400
+#, gcc-internal-format
+msgid "%qT is already a friend of %qT"
+msgstr ""
+
+#: cp/friend.c:440
+#, gcc-internal-format
+msgid "friend declaration %qD may not have virt-specifiers"
+msgstr ""
+
+#: cp/friend.c:533
+#, gcc-internal-format
+msgid "member %qD declared as friend before type %qT defined"
+msgstr ""
+
+#: cp/friend.c:582
+#, gcc-internal-format
+msgid "friend declaration %qD in local class without prior declaration"
+msgstr ""
+
+#: cp/friend.c:605
+#, gcc-internal-format
+msgid "friend declaration %q#D declares a non-template function"
+msgstr ""
+
+#: cp/friend.c:609
+#, gcc-internal-format
+msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
+msgstr ""
+
+#: cp/init.c:396
+#, gcc-internal-format
+msgid "value-initialization of incomplete type %qT"
+msgstr ""
+
+#: cp/init.c:465
+#, gcc-internal-format
+msgid "cannot value-initialize array of unknown bound %qT"
+msgstr ""
+
+#: cp/init.c:504
+#, gcc-internal-format
+msgid "value-initialization of function type %qT"
+msgstr ""
+
+#: cp/init.c:510
+#, gcc-internal-format
+msgid "value-initialization of reference type %qT"
+msgstr ""
+
+#: cp/init.c:574
+#, gcc-internal-format
+msgid "constructor required before non-static data member for %qD has been parsed"
+msgstr ""
+
+#: cp/init.c:613
+#, gcc-internal-format
+msgid "%qD should be initialized in the member initialization list"
+msgstr ""
+
+#: cp/init.c:631
+#, gcc-internal-format
+msgid "%qD is initialized with itself"
+msgstr ""
+
+#: cp/init.c:729
+#, gcc-internal-format
+msgid "invalid initializer for array member %q#D"
+msgstr ""
+
+#: cp/init.c:743 cp/init.c:767 cp/init.c:2208 cp/method.c:1234
+#, gcc-internal-format
+msgid "uninitialized const member in %q#T"
+msgstr ""
+
+#: cp/init.c:745 cp/init.c:762 cp/init.c:769 cp/init.c:2193 cp/init.c:2221
+#: cp/method.c:1237 cp/method.c:1248
+#, gcc-internal-format
+msgid "%q#D should be initialized"
+msgstr ""
+
+#: cp/init.c:760 cp/init.c:2180 cp/method.c:1245
+#, gcc-internal-format
+msgid "uninitialized reference member in %q#T"
+msgstr ""
+
+#: cp/init.c:926
+#, gcc-internal-format
+msgid "%q+D will be initialized after"
+msgstr ""
+
+#: cp/init.c:929
+#, gcc-internal-format
+msgid "base %qT will be initialized after"
+msgstr ""
+
+#: cp/init.c:932
+#, gcc-internal-format
+msgid "  %q+#D"
+msgstr ""
+
+#: cp/init.c:934
+#, gcc-internal-format
+msgid "  base %qT"
+msgstr ""
+
+#: cp/init.c:936
+#, gcc-internal-format
+msgid "  when initialized here"
+msgstr ""
+
+#: cp/init.c:953
+#, gcc-internal-format
+msgid "multiple initializations given for %qD"
+msgstr ""
+
+#: cp/init.c:957
+#, gcc-internal-format
+msgid "multiple initializations given for base %qT"
+msgstr ""
+
+#: cp/init.c:1043
+#, gcc-internal-format
+msgid "initializations for multiple members of %qT"
+msgstr ""
+
+#: cp/init.c:1122
+#, gcc-internal-format
+msgid "base class %q#T should be explicitly initialized in the copy constructor"
+msgstr ""
+
+#: cp/init.c:1346 cp/init.c:1365
+#, gcc-internal-format
+msgid "class %qT does not have any field named %qD"
+msgstr ""
+
+#: cp/init.c:1352
+#, gcc-internal-format
+msgid "%q#D is a static data member; it can only be initialized at its definition"
+msgstr ""
+
+#: cp/init.c:1359
+#, gcc-internal-format
+msgid "%q#D is not a non-static data member of %qT"
+msgstr ""
+
+#: cp/init.c:1398
+#, gcc-internal-format
+msgid "unnamed initializer for %qT, which has no base classes"
+msgstr ""
+
+#: cp/init.c:1406
+#, gcc-internal-format
+msgid "unnamed initializer for %qT, which uses multiple inheritance"
+msgstr ""
+
+#: cp/init.c:1453
+#, gcc-internal-format
+msgid "%qD is both a direct base and an indirect virtual base"
+msgstr ""
+
+#: cp/init.c:1461
+#, gcc-internal-format
+msgid "type %qT is not a direct or virtual base of %qT"
+msgstr ""
+
+#: cp/init.c:1464
+#, gcc-internal-format
+msgid "type %qT is not a direct base of %qT"
+msgstr ""
+
+#: cp/init.c:1549
+#, gcc-internal-format
+msgid "bad array initializer"
+msgstr ""
+
+#: cp/init.c:1845 cp/semantics.c:3037
+#, gcc-internal-format
+msgid "%qT is not a class type"
+msgstr ""
+
+#: cp/init.c:1901
+#, gcc-internal-format
+msgid "incomplete type %qT does not have member %qD"
+msgstr ""
+
+#: cp/init.c:1915
+#, gcc-internal-format
+msgid "invalid pointer to bit-field %qD"
+msgstr ""
+
+#: cp/init.c:1996
+#, gcc-internal-format
+msgid "invalid use of non-static member function %qD"
+msgstr ""
+
+#: cp/init.c:2003 cp/semantics.c:1741
+#, gcc-internal-format
+msgid "invalid use of non-static data member %qD"
+msgstr ""
+
+#: cp/init.c:2177
+#, gcc-internal-format
+msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
+msgstr ""
+
+#: cp/init.c:2185
+#, gcc-internal-format
+msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
+msgstr ""
+
+#: cp/init.c:2189
+#, gcc-internal-format
+msgid "uninitialized reference member in base %q#T of %q#T"
+msgstr ""
+
+#: cp/init.c:2205
+#, gcc-internal-format
+msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
+msgstr ""
+
+#: cp/init.c:2213
+#, gcc-internal-format
+msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
+msgstr ""
+
+#: cp/init.c:2217
+#, gcc-internal-format
+msgid "uninitialized const member in base %q#T of %q#T"
+msgstr ""
+
+#: cp/init.c:2345
+#, gcc-internal-format
+msgid "integer overflow in array size"
+msgstr ""
+
+#: cp/init.c:2355
+#, gcc-internal-format
+msgid "array size in new-expression must be constant"
+msgstr ""
+
+#: cp/init.c:2369
+#, gcc-internal-format
+msgid "variably modified type not allowed in new-expression"
+msgstr ""
+
+#: cp/init.c:2400
+#, gcc-internal-format
+msgid "invalid type %<void%> for new"
+msgstr ""
+
+#: cp/init.c:2443
+#, gcc-internal-format
+msgid "uninitialized const in %<new%> of %q#T"
+msgstr ""
+
+#: cp/init.c:2512
+#, gcc-internal-format
+msgid "%qT isn%'t a valid Java class type"
+msgstr ""
+
+#: cp/init.c:2525
+#, gcc-internal-format
+msgid "call to Java constructor with %qs undefined"
+msgstr ""
+
+#: cp/init.c:2541
+#, gcc-internal-format
+msgid "Java class %q#T object allocated using placement new"
+msgstr ""
+
+#: cp/init.c:2583
+#, gcc-internal-format
+msgid "no suitable %qD found in class %qT"
+msgstr ""
+
+#: cp/init.c:2590 cp/search.c:1122
+#, gcc-internal-format
+msgid "request for member %qD is ambiguous"
+msgstr ""
+
+#: cp/init.c:2809
+#, gcc-internal-format
+msgid "parenthesized initializer in array new"
+msgstr ""
+
+#: cp/init.c:3047
+#, gcc-internal-format
+msgid "size in array new must have integral type"
+msgstr ""
+
+#: cp/init.c:3061
+#, gcc-internal-format
+msgid "new cannot be applied to a reference type"
+msgstr ""
+
+#: cp/init.c:3070
+#, gcc-internal-format
+msgid "new cannot be applied to a function type"
+msgstr ""
+
+#: cp/init.c:3114
+#, gcc-internal-format
+msgid "call to Java constructor, while %<jclass%> undefined"
+msgstr ""
+
+#: cp/init.c:3132
+#, gcc-internal-format
+msgid "can%'t find %<class$%> in %qT"
+msgstr ""
+
+#: cp/init.c:3192
+#, gcc-internal-format
+msgid "possible problem detected in invocation of delete [] operator:"
+msgstr ""
+
+#: cp/init.c:3196
+#, gcc-internal-format
+msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
+msgstr ""
+
+#: cp/init.c:3682
+#, gcc-internal-format
+msgid "initializer ends prematurely"
+msgstr ""
+
+#: cp/init.c:3768
+#, gcc-internal-format
+msgid "cannot initialize multi-dimensional array with initializer"
+msgstr ""
+
+#: cp/init.c:3975
+#, gcc-internal-format
+msgid "unknown array size in delete"
+msgstr ""
+
+#: cp/init.c:3999
+#, gcc-internal-format
+msgid "possible problem detected in invocation of delete operator:"
+msgstr ""
+
+#: cp/init.c:4004
+#, gcc-internal-format
+msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
+msgstr ""
+
+#: cp/init.c:4019
+#, gcc-internal-format
+msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
+msgstr ""
+
+#: cp/init.c:4024
+#, gcc-internal-format
+msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
+msgstr ""
+
+#: cp/init.c:4321
+#, gcc-internal-format
+msgid "type to vector delete is neither pointer or array type"
+msgstr ""
+
+#: cp/lambda.c:480
+#, gcc-internal-format
+msgid "array of runtime bound cannot be captured by copy, only by reference"
+msgstr ""
+
+#: cp/lambda.c:495
+#, gcc-internal-format
+msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgstr ""
+
+#: cp/lambda.c:499
+#, gcc-internal-format
+msgid "because the array element type %qT has variable size"
+msgstr ""
+
+#: cp/lambda.c:510
+#, gcc-internal-format
+msgid "cannot capture %qE by reference"
+msgstr ""
+
+#: cp/lambda.c:518
+#, gcc-internal-format
+msgid "capture by copy of incomplete type %qT"
+msgstr ""
+
+#: cp/lambda.c:542
+#, gcc-internal-format
+msgid "already captured %qD in lambda expression"
+msgstr ""
+
+#: cp/lambda.c:746
+#, gcc-internal-format
+msgid "%<this%> was not captured for this lambda function"
+msgstr ""
+
+#: cp/lex.c:338
+#, gcc-internal-format, gfc-internal-format
+msgid "junk at end of #pragma %s"
+msgstr ""
+
+#: cp/lex.c:345
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid #pragma %s"
+msgstr ""
+
+#: cp/lex.c:353
+#, gcc-internal-format
+msgid "#pragma vtable no longer supported"
+msgstr ""
+
+#: cp/lex.c:425
+#, gcc-internal-format
+msgid "#pragma implementation for %qs appears after file is included"
+msgstr ""
+
+#: cp/lex.c:449
+#, gcc-internal-format
+msgid "junk at end of #pragma GCC java_exceptions"
+msgstr ""
+
+#: cp/lex.c:464
+#, gcc-internal-format
+msgid "%qD not defined"
+msgstr ""
+
+#: cp/lex.c:470
+#, gcc-internal-format
+msgid "%qD was not declared in this scope"
+msgstr ""
+
+#. In a template, it is invalid to write "f()" or "f(3)" if no
+#. declaration of "f" is available.  Historically, G++ and most
+#. other compilers accepted that usage since they deferred all name
+#. lookup until instantiation time rather than doing unqualified
+#. name lookup at template definition time; explain to the user what
+#. is going wrong.
+#.
+#. Note that we have the exact wording of the following message in
+#. the manual (trouble.texi, node "Name lookup"), so they need to
+#. be kept in synch.
+#: cp/lex.c:510
+#, gcc-internal-format
+msgid "there are no arguments to %qD that depend on a template parameter, so a declaration of %qD must be available"
+msgstr ""
+
+#: cp/lex.c:519
+#, gcc-internal-format
+msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
+msgstr ""
+
+#: cp/mangle.c:2150
+#, gcc-internal-format
+msgid "mangling typeof, use decltype instead"
+msgstr ""
+
+#: cp/mangle.c:2154
+#, gcc-internal-format
+msgid "mangling __underlying_type"
+msgstr ""
+
+#: cp/mangle.c:2379
+#, gcc-internal-format
+msgid "mangling unknown fixed point type"
+msgstr ""
+
+#: cp/mangle.c:2947
+#, gcc-internal-format
+msgid "use of built-in trait %qE in function signature; use library traits instead"
+msgstr ""
+
+#: cp/mangle.c:2952
+#, gcc-internal-format, gfc-internal-format
+msgid "mangling %C"
+msgstr ""
+
+#: cp/mangle.c:3029
+#, gcc-internal-format
+msgid "omitted middle operand to %<?:%> operand cannot be mangled"
+msgstr ""
+
+#: cp/mangle.c:3093
+#, gcc-internal-format
+msgid "string literal in function template signature"
+msgstr ""
+
+#: cp/mangle.c:3557
+#, gcc-internal-format
+msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
+msgstr ""
+
+#: cp/mangle.c:3574
+#, gcc-internal-format
+msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
+msgstr ""
+
+#: cp/mangle.c:3579
+#, gcc-internal-format
+msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
+msgstr ""
+
+#: cp/method.c:713 cp/method.c:1191
+#, gcc-internal-format
+msgid "non-static const member %q#D, can%'t use default assignment operator"
+msgstr ""
+
+#: cp/method.c:719 cp/method.c:1197
+#, gcc-internal-format
+msgid "non-static reference member %q#D, can%'t use default assignment operator"
+msgstr ""
+
+#: cp/method.c:837
+#, gcc-internal-format
+msgid "synthesized method %qD first required here "
+msgstr ""
+
+#: cp/method.c:1143
+#, gcc-internal-format
+msgid "union member %q+D with non-trivial %qD"
+msgstr ""
+
+#: cp/method.c:1152
+#, gcc-internal-format
+msgid "defaulted constructor calls non-constexpr %q+D"
+msgstr ""
+
+#: cp/method.c:1213
+#, gcc-internal-format
+msgid "initializer for %q+#D is invalid"
+msgstr ""
+
+#: cp/method.c:1264
+#, gcc-internal-format
+msgid "defaulted default constructor does not initialize %q+#D"
+msgstr ""
+
+#: cp/method.c:1275
+#, gcc-internal-format
+msgid "copying non-static data member %q#D of rvalue reference type"
+msgstr ""
+
+#. A trivial constructor doesn't have any NSDMI.
+#: cp/method.c:1433
+#, gcc-internal-format
+msgid "defaulted default constructor does not initialize any non-static data member"
+msgstr ""
+
+#: cp/method.c:1510
+#, gcc-internal-format
+msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
+msgstr ""
+
+#: cp/method.c:1616
+#, gcc-internal-format
+msgid "a lambda closure type has a deleted default constructor"
+msgstr ""
+
+#: cp/method.c:1619
+#, gcc-internal-format
+msgid "a lambda closure type has a deleted copy assignment operator"
+msgstr ""
+
+#: cp/method.c:1629
+#, gcc-internal-format
+msgid "%q+#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
+msgstr ""
+
+#: cp/method.c:1648
+#, gcc-internal-format
+msgid "%q+#D is implicitly deleted because the default definition would be ill-formed:"
+msgstr ""
+
+#: cp/method.c:1657
+msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
+msgstr ""
+
+#: cp/method.c:1973
+#, gcc-internal-format
+msgid "defaulted declaration %q+D"
+msgstr ""
+
+#: cp/method.c:1975
+#, gcc-internal-format
+msgid "does not match expected signature %qD"
+msgstr ""
+
+#: cp/method.c:2007
+msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
+msgstr ""
+
+#: cp/method.c:2029
+#, gcc-internal-format
+msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
+msgstr ""
+
+#: cp/method.c:2075
+#, gcc-internal-format
+msgid "a template cannot be defaulted"
+msgstr ""
+
+#: cp/method.c:2103
+#, gcc-internal-format
+msgid "%qD cannot be defaulted"
+msgstr ""
+
+#: cp/method.c:2112
+#, gcc-internal-format
+msgid "defaulted function %q+D with default argument"
+msgstr ""
+
+#: cp/name-lookup.c:599
+#, gcc-internal-format
+msgid "%q#D conflicts with a previous declaration"
+msgstr ""
+
+#: cp/name-lookup.c:601
+#, gcc-internal-format
+msgid "previous declaration %q+#D"
+msgstr ""
+
+#: cp/name-lookup.c:812
+#, gcc-internal-format
+msgid "redeclaration of %<wchar_t%> as %qT"
+msgstr ""
+
+#. A redeclaration of main, but not a duplicate of the
+#. previous one.
+#.
+#. [basic.start.main]
+#.
+#. This function shall not be overloaded.
+#: cp/name-lookup.c:842
+#, gcc-internal-format
+msgid "invalid redeclaration of %q+D"
+msgstr ""
+
+#: cp/name-lookup.c:843
+#, gcc-internal-format
+msgid "as %qD"
+msgstr ""
+
+#: cp/name-lookup.c:884 cp/name-lookup.c:900
+#, gcc-internal-format
+msgid "declaration of %q#D with C language linkage"
+msgstr ""
+
+#: cp/name-lookup.c:887 cp/name-lookup.c:902
+#, gcc-internal-format
+msgid "conflicts with previous declaration %q+#D"
+msgstr ""
+
+#: cp/name-lookup.c:890
+#, gcc-internal-format
+msgid "due to different exception specifications"
+msgstr ""
+
+#: cp/name-lookup.c:1001
+#, gcc-internal-format
+msgid "type mismatch with previous external decl of %q#D"
+msgstr ""
+
+#: cp/name-lookup.c:1003
+#, gcc-internal-format
+msgid "previous external decl of %q+#D"
+msgstr ""
+
+#: cp/name-lookup.c:1092
+#, gcc-internal-format
+msgid "extern declaration of %q#D doesn%'t match"
+msgstr ""
+
+#: cp/name-lookup.c:1093
+#, gcc-internal-format
+msgid "global declaration %q+#D"
+msgstr ""
+
+#: cp/name-lookup.c:1145 cp/name-lookup.c:1215
+#, gcc-internal-format
+msgid "declaration of %q#D shadows a parameter"
+msgstr ""
+
+#: cp/name-lookup.c:1218
+#, gcc-internal-format
+msgid "declaration of %qD shadows a lambda capture"
+msgstr ""
+
+#: cp/name-lookup.c:1222
+#, gcc-internal-format
+msgid "declaration of %qD shadows a previous local"
+msgstr ""
+
+#: cp/name-lookup.c:1265
+#, gcc-internal-format
+msgid "declaration of %qD shadows a member of %qT"
+msgstr ""
+
+#: cp/name-lookup.c:1420
+#, gcc-internal-format
+msgid "name lookup of %qD changed"
+msgstr ""
+
+#: cp/name-lookup.c:1421
+#, gcc-internal-format
+msgid "  matches this %q+D under ISO standard rules"
+msgstr ""
+
+#: cp/name-lookup.c:1423
+#, gcc-internal-format
+msgid "  matches this %q+D under old rules"
+msgstr ""
+
+#: cp/name-lookup.c:1441 cp/name-lookup.c:1449
+#, gcc-internal-format
+msgid "name lookup of %qD changed for ISO %<for%> scoping"
+msgstr ""
+
+#: cp/name-lookup.c:1443
+#, gcc-internal-format
+msgid "  cannot use obsolete binding at %q+D because it has a destructor"
+msgstr ""
+
+#: cp/name-lookup.c:1452
+#, gcc-internal-format
+msgid "  using obsolete binding at %q+D"
+msgstr ""
+
+#: cp/name-lookup.c:1458
+#, gcc-internal-format
+msgid "(if you use %<-fpermissive%> G++ will accept your code)"
+msgstr ""
+
+#: cp/name-lookup.c:1513
+#, gcc-internal-format
+msgid "%s %s(%E) %p %d\n"
+msgstr ""
+
+#: cp/name-lookup.c:1516
+#, gcc-internal-format
+msgid "%s %s %p %d\n"
+msgstr ""
+
+#: cp/name-lookup.c:2388
+#, gcc-internal-format
+msgid "%q#D hides constructor for %q#T"
+msgstr ""
+
+#: cp/name-lookup.c:2426
+#, gcc-internal-format
+msgid "previous non-function declaration %q+#D"
+msgstr ""
+
+#: cp/name-lookup.c:2427
+#, gcc-internal-format
+msgid "conflicts with function declaration %q#D"
+msgstr ""
+
+#: cp/name-lookup.c:2517
+#, gcc-internal-format
+msgid "%qT is not a namespace or unscoped enum"
+msgstr ""
+
+#. 7.3.3/5
+#. A using-declaration shall not name a template-id.
+#: cp/name-lookup.c:2527
+#, gcc-internal-format
+msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
+msgstr ""
+
+#: cp/name-lookup.c:2534
+#, gcc-internal-format
+msgid "namespace %qD not allowed in using-declaration"
+msgstr ""
+
+#. It's a nested name with template parameter dependent scope.
+#. This can only be using-declaration for class member.
+#: cp/name-lookup.c:2542
+#, gcc-internal-format
+msgid "%qT is not a namespace"
+msgstr ""
+
+#. C++11 7.3.3/10.
+#: cp/name-lookup.c:2558 cp/name-lookup.c:2614 cp/name-lookup.c:2684
+#: cp/name-lookup.c:2699
+#, gcc-internal-format
+msgid "%qD is already declared in this scope"
+msgstr ""
+
+#: cp/name-lookup.c:2578
+#, gcc-internal-format
+msgid "%qD not declared"
+msgstr ""
+
+#: cp/name-lookup.c:3351
+#, gcc-internal-format
+msgid "using-declaration for non-member at class scope"
+msgstr ""
+
+#: cp/name-lookup.c:3358
+#, gcc-internal-format
+msgid "%<%T::%D%> names destructor"
+msgstr ""
+
+#: cp/name-lookup.c:3371
+#, gcc-internal-format
+msgid "%<%T::%D%> names constructor in %qT"
+msgstr ""
+
+#: cp/name-lookup.c:3422
+#, gcc-internal-format
+msgid "no members matching %<%T::%D%> in %q#T"
+msgstr ""
+
+#: cp/name-lookup.c:3509
+#, gcc-internal-format
+msgid "declaration of %qD not in a namespace surrounding %qD"
+msgstr ""
+
+#: cp/name-lookup.c:3517
+#, gcc-internal-format
+msgid "explicit qualification in declaration of %qD"
+msgstr ""
+
+#: cp/name-lookup.c:3600
+#, gcc-internal-format
+msgid "%qD should have been declared inside %qD"
+msgstr ""
+
+#: cp/name-lookup.c:3645
+#, gcc-internal-format
+msgid "%qD attribute requires a single NTBS argument"
+msgstr ""
+
+#: cp/name-lookup.c:3652
+#, gcc-internal-format
+msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
+msgstr ""
+
+#: cp/name-lookup.c:3662
+#, gcc-internal-format
+msgid "ignoring %qD attribute on non-inline namespace"
+msgstr ""
+
+#: cp/name-lookup.c:3668
+#, gcc-internal-format
+msgid "ignoring %qD attribute on anonymous namespace"
+msgstr ""
+
+#: cp/name-lookup.c:3687 cp/name-lookup.c:4100
+#, gcc-internal-format
+msgid "%qD attribute directive ignored"
+msgstr ""
+
+#: cp/name-lookup.c:3751
+#, gcc-internal-format
+msgid "namespace alias %qD not allowed here, assuming %qD"
+msgstr ""
+
+#: cp/name-lookup.c:4088
+#, gcc-internal-format
+msgid "strong using only meaningful at namespace scope"
+msgstr ""
+
+#: cp/name-lookup.c:4092
+#, gcc-internal-format
+msgid "current namespace %qD does not enclose strongly used namespace %qD"
+msgstr ""
+
+#: cp/name-lookup.c:4431
+#, gcc-internal-format
+msgid "maximum limit of %d namespaces searched for %qE"
+msgstr ""
+
+#: cp/name-lookup.c:4441
+#, gcc-internal-format
+msgid "suggested alternative:"
+msgid_plural "suggested alternatives:"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: cp/name-lookup.c:4445
+#, gcc-internal-format
+msgid "  %qE"
+msgstr ""
+
+#: cp/name-lookup.c:5712
+#, gcc-internal-format
+msgid "argument dependent lookup finds %q+D"
+msgstr ""
+
+#: cp/name-lookup.c:6246
+#, gcc-internal-format
+msgid "XXX entering pop_everything ()\n"
+msgstr ""
+
+#: cp/name-lookup.c:6255
+#, gcc-internal-format
+msgid "XXX leaving pop_everything ()\n"
+msgstr ""
+
+#: cp/optimize.c:594
+#, gcc-internal-format
+msgid "making multiple clones of %qD"
+msgstr ""
+
+#: cp/parser.c:812
+#, gcc-internal-format
+msgid "identifier %qE is a keyword in C++11"
+msgstr ""
+
+#: cp/parser.c:1313 cp/parser.c:31888
+#, gcc-internal-format
+msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
+msgstr ""
+
+#: cp/parser.c:2605
+#, gcc-internal-format
+msgid "%<#pragma%> is not allowed here"
+msgstr ""
+
+#: cp/parser.c:2636
+#, gcc-internal-format
+msgid "%<%E::%E%> has not been declared"
+msgstr ""
+
+#: cp/parser.c:2639
+#, gcc-internal-format
+msgid "%<::%E%> has not been declared"
+msgstr ""
+
+#: cp/parser.c:2642
+#, gcc-internal-format
+msgid "request for member %qE in non-class type %qT"
+msgstr ""
+
+#: cp/parser.c:2645 cp/parser.c:15943
+#, gcc-internal-format
+msgid "%<%T::%E%> has not been declared"
+msgstr ""
+
+#: cp/parser.c:2648
+#, gcc-internal-format
+msgid "%qE has not been declared"
+msgstr ""
+
+#: cp/parser.c:2655
+#, gcc-internal-format
+msgid "%<%E::%E%> is not a type"
+msgstr "%<%E::%E%> не є типом"
+
+#: cp/parser.c:2659
+#, gcc-internal-format
+msgid "%<%E::%E%> is not a class or namespace"
+msgstr ""
+
+#: cp/parser.c:2664
+#, gcc-internal-format
+msgid "%<%E::%E%> is not a class, namespace, or enumeration"
+msgstr ""
+
+#: cp/parser.c:2677
+#, gcc-internal-format
+msgid "%<::%E%> is not a type"
+msgstr "%<::%E%> не є типом"
+
+#: cp/parser.c:2680
+#, gcc-internal-format
+msgid "%<::%E%> is not a class or namespace"
+msgstr ""
+
+#: cp/parser.c:2684
+#, gcc-internal-format
+msgid "%<::%E%> is not a class, namespace, or enumeration"
+msgstr ""
+
+#: cp/parser.c:2696
+#, gcc-internal-format
+msgid "%qE is not a type"
+msgstr ""
+
+#: cp/parser.c:2699
+#, gcc-internal-format
+msgid "%qE is not a class or namespace"
+msgstr ""
+
+#: cp/parser.c:2703
+#, gcc-internal-format
+msgid "%qE is not a class, namespace, or enumeration"
+msgstr ""
+
+#: cp/parser.c:2766
+#, gcc-internal-format
+msgid "new types may not be defined in a return type"
+msgstr ""
+
+#: cp/parser.c:2768
+#, gcc-internal-format
+msgid "(perhaps a semicolon is missing after the definition of %qT)"
+msgstr ""
+
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
+#, gcc-internal-format
+msgid "%qT is not a template"
+msgstr ""
+
+#: cp/parser.c:2794
+#, gcc-internal-format
+msgid "%qE is not a class template"
+msgstr ""
+
+#: cp/parser.c:2796
+#, gcc-internal-format
+msgid "%qE is not a template"
+msgstr ""
+
+#: cp/parser.c:2799
+#, gcc-internal-format
+msgid "invalid template-id"
+msgstr ""
+
+#: cp/parser.c:2832
+#, gcc-internal-format
+msgid "floating-point literal cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2836 cp/pt.c:14791
+#, gcc-internal-format
+msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2841
+#, gcc-internal-format
+msgid "%<typeid%> operator cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2845
+#, gcc-internal-format
+msgid "non-constant compound literals cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2849
+#, gcc-internal-format
+msgid "a function call cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2853
+#, gcc-internal-format
+msgid "an increment cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2857
+#, gcc-internal-format
+msgid "an decrement cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2861
+#, gcc-internal-format
+msgid "an array reference cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2865
+#, gcc-internal-format
+msgid "the address of a label cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2869
+#, gcc-internal-format
+msgid "calls to overloaded operators cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2873
+#, gcc-internal-format
+msgid "an assignment cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2876
+#, gcc-internal-format
+msgid "a comma operator cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2880
+#, gcc-internal-format
+msgid "a call to a constructor cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2884
+#, gcc-internal-format
+msgid "a transaction expression cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2930
+#, gcc-internal-format
+msgid "%qs cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.c:2962
+#, gcc-internal-format
+msgid "invalid use of template-name %qE without an argument list"
+msgstr ""
+
+#: cp/parser.c:2965
+#, gcc-internal-format
+msgid "invalid use of destructor %qD as a type"
+msgstr ""
+
+#. Something like 'unsigned A a;'
+#: cp/parser.c:2968
+#, gcc-internal-format
+msgid "invalid combination of multiple type-specifiers"
+msgstr ""
+
+#. Issue an error message.
+#: cp/parser.c:2972
+#, gcc-internal-format
+msgid "%qE does not name a type"
+msgstr ""
+
+#: cp/parser.c:2981
+#, gcc-internal-format
+msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/parser.c:2984
+#, gcc-internal-format
+msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/parser.c:2989
+#, gcc-internal-format
+msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/parser.c:3016
+#, gcc-internal-format
+msgid "(perhaps %<typename %T::%E%> was intended)"
+msgstr ""
+
+#: cp/parser.c:3034
+#, gcc-internal-format
+msgid "%qE in namespace %qE does not name a template type"
+msgstr ""
+
+#: cp/parser.c:3038
+#, gcc-internal-format
+msgid "%qE in namespace %qE does not name a type"
+msgstr ""
+
+#. A<T>::A<T>()
+#: cp/parser.c:3045
+#, gcc-internal-format
+msgid "%<%T::%E%> names the constructor, not the type"
+msgstr ""
+
+#: cp/parser.c:3048
+#, gcc-internal-format
+msgid "and %qT has no template constructors"
+msgstr ""
+
+#: cp/parser.c:3053
+#, gcc-internal-format
+msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
+msgstr ""
+
+#: cp/parser.c:3060
+#, gcc-internal-format
+msgid "%qE in %q#T does not name a template type"
+msgstr ""
+
+#: cp/parser.c:3064
+#, gcc-internal-format
+msgid "%qE in %q#T does not name a type"
+msgstr ""
+
+#: cp/parser.c:3638
+#, gcc-internal-format
+msgid "expected string-literal"
+msgstr ""
+
+#: cp/parser.c:3700
+#, gcc-internal-format
+msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
+msgstr ""
+
+#: cp/parser.c:3743
+#, gcc-internal-format
+msgid "a wide string is invalid in this context"
+msgstr ""
+
+#: cp/parser.c:3858
+#, gcc-internal-format
+msgid "unable to find character literal operator %qD with %qT argument"
+msgstr ""
+
+#: cp/parser.c:3959
+#, gcc-internal-format
+msgid "integer literal exceeds range of %qT type"
+msgstr ""
+
+#: cp/parser.c:3966
+#, gcc-internal-format
+msgid "floating literal exceeds range of %qT type"
+msgstr ""
+
+#: cp/parser.c:3970
+#, gcc-internal-format
+msgid "floating literal truncated to zero"
+msgstr ""
+
+#: cp/parser.c:4010
+#, gcc-internal-format
+msgid "unable to find numeric literal operator %qD"
+msgstr ""
+
+#: cp/parser.c:4012
+#, gcc-internal-format
+msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
+msgstr ""
+
+#: cp/parser.c:4064
+#, gcc-internal-format
+msgid "unable to find string literal operator %qD with %qT, %qT arguments"
+msgstr ""
+
+#: cp/parser.c:4124 cp/parser.c:11544
+#, gcc-internal-format
+msgid "expected declaration"
+msgstr ""
+
+#: cp/parser.c:4300
+#, gcc-internal-format
+msgid "fixed-point types not supported in C++"
+msgstr ""
+
+#: cp/parser.c:4380
+#, gcc-internal-format
+msgid "ISO C++ forbids braced-groups within expressions"
+msgstr ""
+
+#: cp/parser.c:4392
+#, gcc-internal-format
+msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
+msgstr ""
+
+#: cp/parser.c:4465 cp/parser.c:4618 cp/parser.c:4771
+#, gcc-internal-format
+msgid "expected primary-expression"
+msgstr ""
+
+#: cp/parser.c:4495
+#, gcc-internal-format
+msgid "%<this%> may not be used in this context"
+msgstr ""
+
+#: cp/parser.c:4613
+#, gcc-internal-format
+msgid "a template declaration cannot appear at block scope"
+msgstr ""
+
+#: cp/parser.c:4747
+#, gcc-internal-format
+msgid "local variable %qD may not appear in this context"
+msgstr ""
+
+#: cp/parser.c:4923
+#, gcc-internal-format
+msgid "expected id-expression"
+msgstr ""
+
+#: cp/parser.c:5055
+#, gcc-internal-format
+msgid "scope %qT before %<~%> is not a class-name"
+msgstr ""
+
+#: cp/parser.c:5084 cp/parser.c:7051
+#, gcc-internal-format
+msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
+msgstr ""
+
+#: cp/parser.c:5188
+#, gcc-internal-format
+msgid "declaration of %<~%T%> as member of %qT"
+msgstr ""
+
+#: cp/parser.c:5203
+#, gcc-internal-format
+msgid "typedef-name %qD used as destructor declarator"
+msgstr ""
+
+#: cp/parser.c:5238
+#, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/parser.c:5249 cp/parser.c:17809
+#, gcc-internal-format
+msgid "expected unqualified-id"
+msgstr ""
+
+#: cp/parser.c:5356
+#, gcc-internal-format
+msgid "found %<:%> in nested-name-specifier, expected %<::%>"
+msgstr ""
+
+#: cp/parser.c:5425
+#, gcc-internal-format
+msgid "decltype evaluates to %qT, which is not a class or enumeration type"
+msgstr ""
+
+#: cp/parser.c:5451
+#, gcc-internal-format
+msgid "function template-id %qD in nested-name-specifier"
+msgstr ""
+
+#: cp/parser.c:5459
+#, gcc-internal-format
+msgid "variable template-id %qD in nested-name-specifier"
+msgstr ""
+
+#: cp/parser.c:5563 cp/typeck.c:2585 cp/typeck.c:2605
+#, gcc-internal-format
+msgid "%qD is not a template"
+msgstr ""
+
+#: cp/parser.c:5641
+#, gcc-internal-format
+msgid "expected nested-name-specifier"
+msgstr ""
+
+#: cp/parser.c:5866 cp/parser.c:7956
+#, gcc-internal-format
+msgid "types may not be defined in casts"
+msgstr ""
+
+#: cp/parser.c:5936
+#, gcc-internal-format
+msgid "types may not be defined in a %<typeid%> expression"
+msgstr ""
+
+#: cp/parser.c:5990
+#, gcc-internal-format
+msgid "%<_Cilk_spawn%> must be followed by an expression"
+msgstr ""
+
+#: cp/parser.c:6128
+#, gcc-internal-format
+msgid "ISO C++ forbids compound-literals"
+msgstr ""
+
+#: cp/parser.c:6186
+#, gcc-internal-format
+msgid "two consecutive %<[%> shall only introduce an attribute"
+msgstr ""
+
+#: cp/parser.c:6582
+#, gcc-internal-format
+msgid "braced list index is not allowed with array notation"
+msgstr ""
+
+#: cp/parser.c:6674
+#, gcc-internal-format
+msgid "%qE does not have class type"
+msgstr ""
+
+#: cp/parser.c:6763 cp/typeck.c:2478
+#, gcc-internal-format
+msgid "invalid use of %qD"
+msgstr ""
+
+#: cp/parser.c:6772
+#, gcc-internal-format
+msgid "%<%D::%D%> is not a class member"
+msgstr ""
+
+#: cp/parser.c:7103
+#, gcc-internal-format
+msgid "non-scalar type"
+msgstr ""
+
+#: cp/parser.c:7202
+#, gcc-internal-format
+msgid "ISO C++ does not allow %<alignof%> with a non-type"
+msgstr ""
+
+#: cp/parser.c:7287
+#, gcc-internal-format
+msgid "types may not be defined in %<noexcept%> expressions"
+msgstr ""
+
+#: cp/parser.c:7522
+#, gcc-internal-format
+msgid "types may not be defined in a new-expression"
+msgstr ""
+
+#: cp/parser.c:7535
+#, gcc-internal-format
+msgid "array bound forbidden after parenthesized type-id"
+msgstr ""
+
+#: cp/parser.c:7537
+#, gcc-internal-format
+msgid "try removing the parentheses around the type-id"
+msgstr ""
+
+#: cp/parser.c:7616
+#, gcc-internal-format
+msgid "types may not be defined in a new-type-id"
+msgstr ""
+
+#: cp/parser.c:7744
+#, gcc-internal-format
+msgid "expression in new-declarator must have integral or enumeration type"
+msgstr ""
+
+#: cp/parser.c:8050
+#, gcc-internal-format
+msgid "use of old-style cast"
+msgstr ""
+
+#: cp/parser.c:8189
+#, gcc-internal-format
+msgid "%<>>%> operator is treated as two right angle brackets in C++11"
+msgstr ""
+
+#: cp/parser.c:8192
+#, gcc-internal-format
+msgid "suggest parentheses around %<>>%> expression"
+msgstr ""
+
+#: cp/parser.c:8369
+#, gcc-internal-format
+msgid "ISO C++ does not allow ?: with omitted middle operand"
+msgstr ""
+
+#: cp/parser.c:9020
+#, gcc-internal-format
+msgid "lambda-expression in unevaluated context"
+msgstr ""
+
+#: cp/parser.c:9029
+#, gcc-internal-format
+msgid "lambda-expression in template-argument"
+msgstr ""
+
+#: cp/parser.c:9180
+#, gcc-internal-format
+msgid "expected end of capture-list"
+msgstr ""
+
+#: cp/parser.c:9194
+#, gcc-internal-format
+msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
+msgstr ""
+
+#: cp/parser.c:9238
+#, gcc-internal-format
+msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
+msgstr ""
+
+#: cp/parser.c:9245
+#, gcc-internal-format
+msgid "empty initializer for lambda init-capture"
+msgstr ""
+
+#: cp/parser.c:9268
+#, gcc-internal-format
+msgid "capture of non-variable %qD "
+msgstr ""
+
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
+#, gcc-internal-format
+msgid "%q+#D declared here"
+msgstr ""
+
+#: cp/parser.c:9276
+#, gcc-internal-format
+msgid "capture of variable %qD with non-automatic storage duration"
+msgstr ""
+
+#: cp/parser.c:9313
+#, gcc-internal-format
+msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
+msgstr ""
+
+#: cp/parser.c:9318
+#, gcc-internal-format
+msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
+msgstr ""
+
+#: cp/parser.c:9364
+#, gcc-internal-format
+msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
+msgstr ""
+
+#: cp/parser.c:9394
+#, gcc-internal-format
+msgid "default argument specified for lambda parameter"
+msgstr ""
+
+#: cp/parser.c:9854
+#, gcc-internal-format
+msgid "attributes at the beginning of statement are ignored"
+msgstr ""
+
+#: cp/parser.c:9882
+#, gcc-internal-format
+msgid "expected labeled-statement"
+msgstr ""
+
+#: cp/parser.c:9920
+#, gcc-internal-format
+msgid "case label %qE not within a switch statement"
+msgstr ""
+
+#: cp/parser.c:10005
+#, gcc-internal-format
+msgid "need %<typename%> before %qE because %qT is a dependent scope"
+msgstr ""
+
+#: cp/parser.c:10014
+#, gcc-internal-format
+msgid "%<%T::%D%> names the constructor, not the type"
+msgstr ""
+
+#: cp/parser.c:10061
+#, gcc-internal-format
+msgid "compound-statement in constexpr function"
+msgstr ""
+
+#: cp/parser.c:10273 cp/parser.c:24926
+#, gcc-internal-format
+msgid "expected selection-statement"
+msgstr ""
+
+#: cp/parser.c:10306
+#, gcc-internal-format
+msgid "types may not be defined in conditions"
+msgstr ""
+
+#: cp/parser.c:10675
+#, gcc-internal-format
+msgid "range-based %<for%> expression of type %qT has incomplete type"
+msgstr ""
+
+#: cp/parser.c:10713
+#, gcc-internal-format
+msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
+msgstr ""
+
+#: cp/parser.c:10719
+#, gcc-internal-format
+msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
+msgstr ""
+
+#: cp/parser.c:10760
+#, gcc-internal-format
+msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
+msgstr ""
+
+#: cp/parser.c:10891 cp/parser.c:24929
+#, gcc-internal-format
+msgid "expected iteration-statement"
+msgstr ""
+
+#: cp/parser.c:10925
+#, gcc-internal-format
+msgid "range-based for loop without a type-specifier only available with -std=c++1z or -std=gnu++1z"
+msgstr ""
+
+#: cp/parser.c:10955
+#, gcc-internal-format
+msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/parser.c:11029
+#, gcc-internal-format
+msgid "break statement used with Cilk Plus for loop"
+msgstr ""
+
+#: cp/parser.c:11086
+#, gcc-internal-format
+msgid "%<goto%> in %<constexpr%> function"
+msgstr "%<goto%> у функції %<constexpr%>"
+
+#. Issue a warning about this use of a GNU extension.
+#: cp/parser.c:11094
+#, gcc-internal-format
+msgid "ISO C++ forbids computed gotos"
+msgstr ""
+
+#: cp/parser.c:11107 cp/parser.c:24932
+#, gcc-internal-format
+msgid "expected jump-statement"
+msgstr ""
+
+#: cp/parser.c:11236 cp/parser.c:20846
+#, gcc-internal-format
+msgid "extra %<;%>"
+msgstr "зайве %<;%>"
+
+#: cp/parser.c:11469
+#, gcc-internal-format
+msgid "%<__label__%> not at the beginning of a block"
+msgstr ""
+
+#: cp/parser.c:11627
+#, gcc-internal-format
+msgid "mixing declarations and function-definitions is forbidden"
+msgstr ""
+
+#: cp/parser.c:11697
+#, gcc-internal-format
+msgid "initializer in range-based %<for%> loop"
+msgstr ""
+
+#: cp/parser.c:11700
+#, gcc-internal-format
+msgid "multiple declarations in range-based %<for%> loop"
+msgstr ""
+
+#: cp/parser.c:11836
+#, gcc-internal-format
+msgid "%<friend%> used outside of class"
+msgstr ""
+
+#. Complain about `auto' as a storage specifier, if
+#. we're complaining about C++0x compatibility.
+#: cp/parser.c:11895
+#, gcc-internal-format
+msgid "%<auto%> changes meaning in C++11; please remove it"
+msgstr ""
+
+#: cp/parser.c:11931
+#, gcc-internal-format
+msgid "decl-specifier invalid in condition"
+msgstr ""
+
+#: cp/parser.c:12023
+#, gcc-internal-format
+msgid "class definition may not be declared a friend"
+msgstr ""
+
+#: cp/parser.c:12091 cp/parser.c:21252
+#, gcc-internal-format
+msgid "templates may not be %<virtual%>"
+msgstr ""
+
+#: cp/parser.c:12131
+#, gcc-internal-format
+msgid "invalid linkage-specification"
+msgstr ""
+
+#: cp/parser.c:12390
+#, gcc-internal-format
+msgid "types may not be defined in %<decltype%> expressions"
+msgstr ""
+
+#: cp/parser.c:12531
+#, gcc-internal-format
+msgid "types may not be defined in a conversion-type-id"
+msgstr ""
+
+#: cp/parser.c:12558
+#, gcc-internal-format
+msgid "invalid use of %<auto%> in conversion operator"
+msgstr ""
+
+#: cp/parser.c:12562
+#, gcc-internal-format
+msgid "use of %<auto%> in member template conversion operator can never be deduced"
+msgstr ""
+
+#: cp/parser.c:12651
+#, gcc-internal-format
+msgid "only constructors take member initializers"
+msgstr ""
+
+#: cp/parser.c:12673
+#, gcc-internal-format
+msgid "cannot expand initializer for member %<%D%>"
+msgstr ""
+
+#: cp/parser.c:12685
+#, gcc-internal-format
+msgid "mem-initializer for %qD follows constructor delegation"
+msgstr ""
+
+#: cp/parser.c:12697
+#, gcc-internal-format
+msgid "constructor delegation follows mem-initializer for %qD"
+msgstr ""
+
+#: cp/parser.c:12749
+#, gcc-internal-format
+msgid "anachronistic old-style base class initializer"
+msgstr ""
+
+#: cp/parser.c:12818
+#, gcc-internal-format
+msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
+msgstr ""
+
+#: cp/parser.c:13167
+#, gcc-internal-format
+msgid "unexpected keyword; remove space between quotes and suffix identifier"
+msgstr ""
+
+#: cp/parser.c:13173
+#, gcc-internal-format
+msgid "expected suffix identifier"
+msgstr ""
+
+#: cp/parser.c:13182
+#, gcc-internal-format
+msgid "expected empty string after %<operator%> keyword"
+msgstr ""
+
+#: cp/parser.c:13188
+#, gcc-internal-format
+msgid "invalid encoding prefix in literal operator"
+msgstr ""
+
+#: cp/parser.c:13211
+#, gcc-internal-format
+msgid "expected operator"
+msgstr ""
+
+#. Warn that we do not support `export'.
+#: cp/parser.c:13248
+#, gcc-internal-format
+msgid "keyword %<export%> not implemented, and will be ignored"
+msgstr ""
+
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
+#, gcc-internal-format
+msgid "template parameter pack %qD cannot have a default argument"
+msgstr ""
+
+#: cp/parser.c:13451 cp/parser.c:19153
+#, gcc-internal-format
+msgid "template parameter pack cannot have a default argument"
+msgstr ""
+
+#: cp/parser.c:13549 cp/parser.c:13658
+#, gcc-internal-format
+msgid "template parameter packs cannot have default arguments"
+msgstr ""
+
+#: cp/parser.c:13742
+#, gcc-internal-format
+msgid "expected template-id"
+msgstr ""
+
+#: cp/parser.c:13790 cp/parser.c:24890
+#, gcc-internal-format
+msgid "expected %<<%>"
+msgstr "мало бути %<<%>"
+
+#: cp/parser.c:13797
+#, gcc-internal-format
+msgid "%<<::%> cannot begin a template-argument list"
+msgstr ""
+
+#: cp/parser.c:13801
+#, gcc-internal-format
+msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
+msgstr ""
+
+#: cp/parser.c:13805
+#, gcc-internal-format
+msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
+msgstr ""
+
+#: cp/parser.c:13891
+#, gcc-internal-format
+msgid "parse error in template argument list"
+msgstr ""
+
+#. The name does not name a template.
+#: cp/parser.c:13960 cp/parser.c:14081 cp/parser.c:14293
+#, gcc-internal-format
+msgid "expected template-name"
+msgstr ""
+
+#. Explain what went wrong.
+#: cp/parser.c:14006
+#, gcc-internal-format
+msgid "non-template %qD used as template"
+msgstr ""
+
+#: cp/parser.c:14008
+#, gcc-internal-format
+msgid "use %<%T::template %D%> to indicate that it is a template"
+msgstr ""
+
+#: cp/parser.c:14148
+#, gcc-internal-format
+msgid "expected parameter pack before %<...%>"
+msgstr ""
+
+#: cp/parser.c:14258 cp/parser.c:14276 cp/parser.c:14425
+#, gcc-internal-format
+msgid "expected template-argument"
+msgstr ""
+
+#: cp/parser.c:14410
+#, gcc-internal-format
+msgid "invalid non-type template argument"
+msgstr ""
+
+#: cp/parser.c:14527
+#, gcc-internal-format
+msgid "explicit instantiation shall not use %<inline%> specifier"
+msgstr ""
+
+#: cp/parser.c:14531
+#, gcc-internal-format
+msgid "explicit instantiation shall not use %<constexpr%> specifier"
+msgstr ""
+
+#: cp/parser.c:14590
+#, gcc-internal-format
+msgid "template specialization with C linkage"
+msgstr ""
+
+#: cp/parser.c:14810
+#, gcc-internal-format
+msgid "expected type specifier"
+msgstr ""
+
+#: cp/parser.c:14969
+#, gcc-internal-format
+msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
+msgstr ""
+
+#: cp/parser.c:14975
+#, gcc-internal-format
+msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
+msgstr ""
+
+#: cp/parser.c:14980
+#, gcc-internal-format
+msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
+msgstr ""
+
+#: cp/parser.c:15124
+#, gcc-internal-format
+msgid "expected template-id for type"
+msgstr ""
+
+#: cp/parser.c:15151
+#, gcc-internal-format
+msgid "expected type-name"
+msgstr ""
+
+#: cp/parser.c:15372
+#, gcc-internal-format
+msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
+msgstr ""
+
+#: cp/parser.c:15581
+#, gcc-internal-format
+msgid "declaration %qD does not declare anything"
+msgstr ""
+
+#: cp/parser.c:15668
+#, gcc-internal-format
+msgid "attributes ignored on uninstantiated type"
+msgstr ""
+
+#: cp/parser.c:15672
+#, gcc-internal-format
+msgid "attributes ignored on template instantiation"
+msgstr ""
+
+#: cp/parser.c:15677
+#, gcc-internal-format
+msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
+msgstr ""
+
+#: cp/parser.c:15811
+#, gcc-internal-format
+msgid "%qD is an enumeration template"
+msgstr ""
+
+#: cp/parser.c:15821
+#, gcc-internal-format
+msgid "%qD is not an enumerator-name"
+msgstr ""
+
+#: cp/parser.c:15833
+#, gcc-internal-format
+msgid "anonymous scoped enum is not allowed"
+msgstr ""
+
+#: cp/parser.c:15888
+#, gcc-internal-format
+msgid "expected %<;%> or %<{%>"
+msgstr "мало бути %<;%> або %<{%>"
+
+#: cp/parser.c:15937
+#, gcc-internal-format
+msgid "cannot add an enumerator list to a template instantiation"
+msgstr ""
+
+#: cp/parser.c:15955 cp/parser.c:20360
+#, gcc-internal-format
+msgid "declaration of %qD in namespace %qD which does not enclose %qD"
+msgstr ""
+
+#: cp/parser.c:15960 cp/parser.c:20365
+#, gcc-internal-format
+msgid "declaration of %qD in %qD which does not enclose %qD"
+msgstr ""
+
+#: cp/parser.c:15985
+#, gcc-internal-format
+msgid "multiple definition of %q#T"
+msgstr ""
+
+#: cp/parser.c:15998
+#, gcc-internal-format
+msgid "ISO C++ forbids empty anonymous enum"
+msgstr ""
+
+#: cp/parser.c:16018
+#, gcc-internal-format
+msgid "opaque-enum-specifier without name"
+msgstr ""
+
+#: cp/parser.c:16021
+#, gcc-internal-format
+msgid "opaque-enum-specifier must use a simple identifier"
+msgstr ""
+
+#: cp/parser.c:16191
+#, gcc-internal-format
+msgid "%qD is not a namespace-name"
+msgstr ""
+
+#: cp/parser.c:16192
+#, gcc-internal-format
+msgid "expected namespace-name"
+msgstr ""
+
+#: cp/parser.c:16318
+#, gcc-internal-format
+msgid "%<namespace%> definition is not allowed here"
+msgstr ""
+
+#: cp/parser.c:16473
+#, gcc-internal-format
+msgid "a template-id may not appear in a using-declaration"
+msgstr ""
+
+#: cp/parser.c:16519
+#, gcc-internal-format
+msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
+msgstr ""
+
+#: cp/parser.c:16584
+#, gcc-internal-format
+msgid "types may not be defined in alias template declarations"
+msgstr ""
+
+#: cp/parser.c:16729
+#, gcc-internal-format
+msgid "%<asm%> in %<constexpr%> function"
+msgstr "%<asm%> у функції %<constexpr%>"
+
+#: cp/parser.c:17067
+#, gcc-internal-format
+msgid "a function-definition is not allowed here"
+msgstr ""
+
+#: cp/parser.c:17078
+#, gcc-internal-format
+msgid "an asm-specification is not allowed on a function-definition"
+msgstr ""
+
+#: cp/parser.c:17082
+#, gcc-internal-format
+msgid "attributes are not allowed on a function-definition"
+msgstr ""
+
+#: cp/parser.c:17133
+#, gcc-internal-format
+msgid "expected constructor, destructor, or type conversion"
+msgstr ""
+
+#. Anything else is an error.
+#: cp/parser.c:17172 cp/parser.c:19333
+#, gcc-internal-format
+msgid "expected initializer"
+msgstr ""
+
+#: cp/parser.c:17252
+#, gcc-internal-format
+msgid "initializer provided for function"
+msgstr ""
+
+#: cp/parser.c:17286
+#, gcc-internal-format
+msgid "attributes after parenthesized initializer ignored"
+msgstr ""
+
+#: cp/parser.c:17291
+#, gcc-internal-format
+msgid "non-function %qD declared as implicit template"
+msgstr ""
+
+#: cp/parser.c:17729
+#, gcc-internal-format
+msgid "array bound is not an integer constant"
+msgstr ""
+
+#: cp/parser.c:17855
+#, gcc-internal-format
+msgid "cannot define member of dependent typedef %qT"
+msgstr ""
+
+#: cp/parser.c:17859
+#, gcc-internal-format
+msgid "%<%T::%E%> is not a type"
+msgstr "%<%T::%E%> не є типом"
+
+#: cp/parser.c:17887
+#, gcc-internal-format
+msgid "invalid use of constructor as a template"
+msgstr ""
+
+#: cp/parser.c:17889
+#, gcc-internal-format
+msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
+msgstr ""
+
+#. We do not attempt to print the declarator
+#. here because we do not have enough
+#. information about its original syntactic
+#. form.
+#: cp/parser.c:17906
+#, gcc-internal-format
+msgid "invalid declarator"
+msgstr ""
+
+#. But declarations with qualified-ids can't appear in a
+#. function.
+#: cp/parser.c:17976
+#, gcc-internal-format
+msgid "qualified-id in declaration"
+msgstr ""
+
+#: cp/parser.c:18001
+#, gcc-internal-format
+msgid "expected declarator"
+msgstr ""
+
+#: cp/parser.c:18104
+#, gcc-internal-format
+msgid "%qD is a namespace"
+msgstr ""
+
+#: cp/parser.c:18106
+#, gcc-internal-format
+msgid "cannot form pointer to member of non-class %q#T"
+msgstr ""
+
+#: cp/parser.c:18127
+#, gcc-internal-format
+msgid "expected ptr-operator"
+msgstr ""
+
+#: cp/parser.c:18186
+#, gcc-internal-format
+msgid "duplicate cv-qualifier"
+msgstr ""
+
+#: cp/parser.c:18240
+#, gcc-internal-format
+msgid "multiple ref-qualifiers"
+msgstr ""
+
+#: cp/parser.c:18298
+#, gcc-internal-format
+msgid "duplicate virt-specifier"
+msgstr ""
+
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
+#, gcc-internal-format
+msgid "invalid use of %<auto%>"
+msgstr ""
+
+#: cp/parser.c:18524
+#, gcc-internal-format
+msgid "types may not be defined in template arguments"
+msgstr ""
+
+#: cp/parser.c:18529
+#, gcc-internal-format
+msgid "invalid use of %<auto%> in template argument"
+msgstr ""
+
+#: cp/parser.c:18616
+#, gcc-internal-format
+msgid "expected type-specifier"
+msgstr ""
+
+#: cp/parser.c:18922
+#, gcc-internal-format
+msgid "expected %<,%> or %<...%>"
+msgstr "мало бути %<,%> або %<...%>"
+
+#: cp/parser.c:18996
+#, gcc-internal-format
+msgid "types may not be defined in parameter types"
+msgstr ""
+
+#: cp/parser.c:19124
+#, gcc-internal-format
+msgid "deprecated use of default argument for parameter of non-function"
+msgstr ""
+
+#: cp/parser.c:19128
+#, gcc-internal-format
+msgid "default arguments are only permitted for function parameters"
+msgstr ""
+
+#: cp/parser.c:19147
+#, gcc-internal-format
+msgid "parameter pack %qD cannot have a default argument"
+msgstr ""
+
+#: cp/parser.c:19155
+#, gcc-internal-format
+msgid "parameter pack cannot have a default argument"
+msgstr ""
+
+#: cp/parser.c:19526
+#, gcc-internal-format
+msgid "ISO C++ does not allow designated initializers"
+msgstr ""
+
+#: cp/parser.c:19540
+#, gcc-internal-format
+msgid "ISO C++ does not allow C99 designated initializers"
+msgstr ""
+
+#: cp/parser.c:19658 cp/parser.c:19783
+#, gcc-internal-format
+msgid "expected class-name"
+msgstr ""
+
+#: cp/parser.c:19965
+#, gcc-internal-format
+msgid "expected %<;%> after class definition"
+msgstr ""
+
+#: cp/parser.c:19967
+#, gcc-internal-format
+msgid "expected %<;%> after struct definition"
+msgstr ""
+
+#: cp/parser.c:19969
+#, gcc-internal-format
+msgid "expected %<;%> after union definition"
+msgstr ""
+
+#: cp/parser.c:20308
+#, gcc-internal-format
+msgid "expected %<{%> or %<:%>"
+msgstr "мало бути %<{%> або %<:%>"
+
+#: cp/parser.c:20319
+#, gcc-internal-format
+msgid "cannot specify %<override%> for a class"
+msgstr ""
+
+#: cp/parser.c:20327
+#, gcc-internal-format
+msgid "global qualification of class name is invalid"
+msgstr ""
+
+#: cp/parser.c:20334
+#, gcc-internal-format
+msgid "qualified name does not name a class"
+msgstr ""
+
+#: cp/parser.c:20346
+#, gcc-internal-format
+msgid "invalid class name in declaration of %qD"
+msgstr ""
+
+#: cp/parser.c:20379
+#, gcc-internal-format
+msgid "extra qualification not allowed"
+msgstr ""
+
+#: cp/parser.c:20391
+#, gcc-internal-format
+msgid "an explicit specialization must be preceded by %<template <>%>"
+msgstr ""
+
+#: cp/parser.c:20421
+#, gcc-internal-format
+msgid "function template %qD redeclared as a class template"
+msgstr ""
+
+#: cp/parser.c:20452
+#, gcc-internal-format
+msgid "could not resolve typename type"
+msgstr "не вдалося визначити тип typename"
+
+#: cp/parser.c:20508
+#, gcc-internal-format
+msgid "previous definition of %q+#T"
+msgstr "попереднє визначення %q+#T"
+
+#: cp/parser.c:20599 cp/parser.c:24935
+#, gcc-internal-format
+msgid "expected class-key"
+msgstr ""
+
+#: cp/parser.c:20623
+#, gcc-internal-format
+msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
+msgstr ""
+
+#: cp/parser.c:20627
+#, gcc-internal-format
+msgid "expected %<class%> or %<typename%>"
+msgstr "мало бути %<class%> або %<typename%>"
+
+#: cp/parser.c:20866
+#, gcc-internal-format
+msgid "in C++03 a class-key must be used when declaring a friend"
+msgstr ""
+
+#: cp/parser.c:20884
+#, gcc-internal-format
+msgid "friend declaration does not name a class or function"
+msgstr ""
+
+#: cp/parser.c:20902
+#, gcc-internal-format
+msgid "a storage class on an anonymous aggregate in class scope is not allowed"
+msgstr ""
+
+#: cp/parser.c:21106
+#, gcc-internal-format
+msgid "pure-specifier on function-definition"
+msgstr ""
+
+#: cp/parser.c:21160
+#, gcc-internal-format
+msgid "stray %<,%> at end of member declaration"
+msgstr ""
+
+#: cp/parser.c:21172
+#, gcc-internal-format
+msgid "expected %<;%> at end of member declaration"
+msgstr ""
+
+#: cp/parser.c:21246
+#, gcc-internal-format
+msgid "invalid pure specifier (only %<= 0%> is allowed)"
+msgstr ""
+
+#: cp/parser.c:21281
+#, gcc-internal-format
+msgid "a brace-enclosed initializer is not allowed here"
+msgstr ""
+
+#: cp/parser.c:21410
+#, gcc-internal-format
+msgid "%<virtual%> specified more than once in base-specified"
+msgstr ""
+
+#: cp/parser.c:21430
+#, gcc-internal-format
+msgid "more than one access specifier in base-specified"
+msgstr ""
+
+#: cp/parser.c:21454
+#, gcc-internal-format
+msgid "keyword %<typename%> not allowed outside of templates"
+msgstr ""
+
+#: cp/parser.c:21457
+#, gcc-internal-format
+msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
+msgstr ""
+
+#: cp/parser.c:21550 cp/parser.c:21632
+#, gcc-internal-format
+msgid "types may not be defined in an exception-specification"
+msgstr ""
+
+#: cp/parser.c:21614
+#, gcc-internal-format
+msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
+msgstr ""
+
+#: cp/parser.c:21704
+#, gcc-internal-format
+msgid "%<try%> in %<constexpr%> function"
+msgstr "%<try%> у функції %<constexpr%>"
+
+#: cp/parser.c:21817
+#, gcc-internal-format
+msgid "types may not be defined in exception-declarations"
+msgstr ""
+
+#: cp/parser.c:22441
+#, gcc-internal-format
+msgid "expected an identifier for the attribute name"
+msgstr ""
+
+#: cp/parser.c:22460
+#, gcc-internal-format
+msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
+msgstr ""
+
+#: cp/parser.c:23141
+#, gcc-internal-format
+msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
+msgstr ""
+
+#: cp/parser.c:23146
+#, gcc-internal-format
+msgid "invalid declaration of %<%T::%E%>"
+msgstr ""
+
+#: cp/parser.c:23150
+#, gcc-internal-format
+msgid "too few template-parameter-lists"
+msgstr ""
+
+#. Otherwise, there are too many template parameter lists.  We have
+#. something like:
+#.
+#. template <class T> template <class U> void S::f();
+#: cp/parser.c:23157
+#, gcc-internal-format
+msgid "too many template-parameter-lists"
+msgstr ""
+
+#: cp/parser.c:23481
+#, gcc-internal-format
+msgid "named return values are no longer supported"
+msgstr ""
+
+#: cp/parser.c:23578
+#, gcc-internal-format
+msgid "invalid declaration of member template in local class"
+msgstr ""
+
+#: cp/parser.c:23587
+#, gcc-internal-format
+msgid "template with C linkage"
+msgstr ""
+
+#: cp/parser.c:23606
+#, gcc-internal-format
+msgid "invalid explicit specialization"
+msgstr ""
+
+#: cp/parser.c:23704
+#, gcc-internal-format
+msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
+msgstr ""
+
+#: cp/parser.c:23709
+#, gcc-internal-format
+msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
+msgstr ""
+
+#: cp/parser.c:23783
+#, gcc-internal-format
+msgid "template declaration of %<typedef%>"
+msgstr ""
+
+#: cp/parser.c:23860
+#, gcc-internal-format
+msgid "explicit template specialization cannot have a storage class"
+msgstr ""
+
+#: cp/parser.c:24105
+#, gcc-internal-format
+msgid "%<>>%> should be %<> >%> within a nested template argument list"
+msgstr ""
+
+#: cp/parser.c:24118
+#, gcc-internal-format
+msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
+msgstr ""
+
+#: cp/parser.c:24415
+#, gcc-internal-format
+msgid "%<sizeof...%> argument must be surrounded by parentheses"
+msgstr ""
+
+#: cp/parser.c:24570
+#, gcc-internal-format
+msgid "invalid use of %qD in linkage specification"
+msgstr ""
+
+#: cp/parser.c:24585
+#, gcc-internal-format
+msgid "%<__thread%> before %qD"
+msgstr ""
+
+#: cp/parser.c:24719
+#, gcc-internal-format
+msgid "ISO C++ 1998 does not support %<long long%>"
+msgstr "У ISO C++ 1998 не передбачено підтримки %<long long%>"
+
+#: cp/parser.c:24727
+#, gcc-internal-format
+msgid "both %<__thread%> and %<thread_local%> specified"
+msgstr "вказано одразу %<__thread%> і %<thread_local%>"
+
+#: cp/parser.c:24729
+#, gcc-internal-format
+msgid "duplicate %qD"
+msgstr "дублювання %qD"
+
+#: cp/parser.c:24751
+#, gcc-internal-format
+msgid "duplicate %qs"
+msgstr "дублювання %qs"
+
+#: cp/parser.c:24793
+#, gcc-internal-format
+msgid "expected %<new%>"
+msgstr "мало бути %<new%>"
+
+#: cp/parser.c:24796
+#, gcc-internal-format
+msgid "expected %<delete%>"
+msgstr "мало бути %<delete%>"
+
+#: cp/parser.c:24799
+#, gcc-internal-format
+msgid "expected %<return%>"
+msgstr "мало бути %<return%>"
+
+#: cp/parser.c:24805
+#, gcc-internal-format
+msgid "expected %<extern%>"
+msgstr "мало бути %<extern%>"
+
+#: cp/parser.c:24808
+#, gcc-internal-format
+msgid "expected %<static_assert%>"
+msgstr "мало бути %<static_assert%>"
+
+#: cp/parser.c:24811
+#, gcc-internal-format
+msgid "expected %<decltype%>"
+msgstr "мало бути %<decltype%>"
+
+#: cp/parser.c:24814
+#, gcc-internal-format
+msgid "expected %<operator%>"
+msgstr "мало бути %<operator%>"
+
+#: cp/parser.c:24817
+#, gcc-internal-format
+msgid "expected %<class%>"
+msgstr "мало бути %<class%>"
+
+#: cp/parser.c:24820
+#, gcc-internal-format
+msgid "expected %<template%>"
+msgstr "мало бути %<template%>"
+
+#: cp/parser.c:24823
+#, gcc-internal-format
+msgid "expected %<namespace%>"
+msgstr "мало бути %<namespace%>"
+
+#: cp/parser.c:24826
+#, gcc-internal-format
+msgid "expected %<using%>"
+msgstr "мало бути %<using%>"
+
+#: cp/parser.c:24829
+#, gcc-internal-format
+msgid "expected %<asm%>"
+msgstr "мало бути %<asm%>"
+
+#: cp/parser.c:24832
+#, gcc-internal-format
+msgid "expected %<try%>"
+msgstr "мало бути %<try%>"
+
+#: cp/parser.c:24835
+#, gcc-internal-format
+msgid "expected %<catch%>"
+msgstr "мало бути %<catch%>"
+
+#: cp/parser.c:24838
+#, gcc-internal-format
+msgid "expected %<throw%>"
+msgstr "мало бути %<throw%>"
+
+#: cp/parser.c:24841
+#, gcc-internal-format
+msgid "expected %<__label__%>"
+msgstr "мало бути %<__label__%>"
+
+#: cp/parser.c:24844
+#, gcc-internal-format
+msgid "expected %<@try%>"
+msgstr "мало бути %<@try%>"
+
+#: cp/parser.c:24847
+#, gcc-internal-format
+msgid "expected %<@synchronized%>"
+msgstr "мало бути %<@synchronized%>"
+
+#: cp/parser.c:24850
+#, gcc-internal-format
+msgid "expected %<@throw%>"
+msgstr "мало бути %<@throw%>"
+
+#: cp/parser.c:24853
+#, gcc-internal-format
+msgid "expected %<__transaction_atomic%>"
+msgstr "мало бути %<__transaction_atomic%>"
+
+#: cp/parser.c:24856
+#, gcc-internal-format
+msgid "expected %<__transaction_relaxed%>"
+msgstr "мало бути %<__transaction_relaxed%>"
+
+#: cp/parser.c:24887
+#, gcc-internal-format
+msgid "expected %<::%>"
+msgstr "мало бути %<::%>"
+
+#: cp/parser.c:24899
+#, gcc-internal-format
+msgid "expected %<...%>"
+msgstr "мало бути %<...%>"
+
+#: cp/parser.c:24902
+#, gcc-internal-format
+msgid "expected %<*%>"
+msgstr "мало бути %<*%>"
+
+#: cp/parser.c:24905
+#, gcc-internal-format
+msgid "expected %<~%>"
+msgstr "мало бути %<~%>"
+
+#: cp/parser.c:24911
+#, gcc-internal-format
+msgid "expected %<:%> or %<::%>"
+msgstr "мало бути %<:%> або %<::%>"
+
+#: cp/parser.c:24939
+#, gcc-internal-format
+msgid "expected %<class%>, %<typename%>, or %<template%>"
+msgstr "мало бути %<class%>, %<typename%> або %<template%>"
+
+#: cp/parser.c:25200
+#, gcc-internal-format
+msgid "%qs tag used in naming %q#T"
+msgstr "теґ %qs використано у назві %q#T"
+
+#: cp/parser.c:25205
+#, gcc-internal-format
+msgid "%q#T was previously declared here"
+msgstr ""
+
+#: cp/parser.c:25224
+#, gcc-internal-format
+msgid "%qD redeclared with different access"
+msgstr ""
+
+#: cp/parser.c:25245
+#, gcc-internal-format
+msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
+msgstr ""
+
+#: cp/parser.c:25477
+#, gcc-internal-format
+msgid "file ends in default argument"
+msgstr ""
+
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
+#, gcc-internal-format
+msgid "misplaced %<@%D%> Objective-C++ construct"
+msgstr ""
+
+#: cp/parser.c:25765
+#, gcc-internal-format
+msgid "objective-c++ message receiver expected"
+msgstr ""
+
+#: cp/parser.c:25835
+#, gcc-internal-format
+msgid "objective-c++ message argument(s) are expected"
+msgstr ""
+
+#: cp/parser.c:25864
+#, gcc-internal-format
+msgid "%<@encode%> must specify a type as an argument"
+msgstr ""
+
+#: cp/parser.c:26240
+#, gcc-internal-format
+msgid "invalid Objective-C++ selector name"
+msgstr ""
+
+#: cp/parser.c:26315 cp/parser.c:26333
+#, gcc-internal-format
+msgid "objective-c++ method declaration is expected"
+msgstr ""
+
+#: cp/parser.c:26327 cp/parser.c:26392
+#, gcc-internal-format
+msgid "method attributes must be specified at the end"
+msgstr ""
+
+#: cp/parser.c:26435
+#, gcc-internal-format
+msgid "stray %qs between Objective-C++ methods"
+msgstr ""
+
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
+#, gcc-internal-format
+msgid "invalid type for instance variable"
+msgstr ""
+
+#: cp/parser.c:26768
+#, gcc-internal-format
+msgid "identifier expected after %<@protocol%>"
+msgstr ""
+
+#: cp/parser.c:26939
+#, gcc-internal-format
+msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
+msgstr ""
+
+#: cp/parser.c:26946
+#, gcc-internal-format
+msgid "prefix attributes are ignored before %<@%D%>"
+msgstr ""
+
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
+#, gcc-internal-format
+msgid "invalid type for property"
+msgstr ""
+
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
+#, gcc-internal-format
+msgid "expected positive integer expression"
+msgstr ""
+
+#: cp/parser.c:28128
+#, gcc-internal-format
+msgid "%<wait%> expression must be integral"
+msgstr ""
+
+#: cp/parser.c:28554
+#, gcc-internal-format
+msgid "invalid reduction-identifier"
+msgstr ""
+
+#: cp/parser.c:30306
+#, gcc-internal-format
+msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
+msgstr ""
+
+#: cp/parser.c:30309
+#, gcc-internal-format
+msgid "parenthesized initialization is not allowed in for-loop"
+msgstr ""
+
+#: cp/parser.c:30378
+#, gcc-internal-format
+msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
+msgstr ""
+
+#: cp/parser.c:30547 cp/pt.c:13811
+#, gcc-internal-format
+msgid "iteration variable %qD should not be reduction"
+msgstr ""
+
+#: cp/parser.c:30617
+#, gcc-internal-format
+msgid "not enough collapsed for loops"
+msgstr ""
+
+#: cp/parser.c:31916
+#, gcc-internal-format
+msgid "vector attribute not immediately followed by a single function declaration or definition"
+msgstr ""
+
+#: cp/parser.c:32143
+#, gcc-internal-format
+msgid "invalid initializer clause"
+msgstr ""
+
+#: cp/parser.c:32171
+#, gcc-internal-format
+msgid "expected id-expression (arguments)"
+msgstr ""
+
+#: cp/parser.c:32183
+#, gcc-internal-format
+msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
+msgstr ""
+
+#: cp/parser.c:32264
+#, gcc-internal-format
+msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
+msgstr ""
+
+#: cp/parser.c:32283
+#, gcc-internal-format
+msgid "types may not be defined in declare reduction type list"
+msgstr ""
+
+#: cp/parser.c:32305 cp/semantics.c:4993
+#, gcc-internal-format
+msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: cp/parser.c:32310 cp/semantics.c:5002
+#, gcc-internal-format
+msgid "function or array type %qT in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
+#, gcc-internal-format
+msgid "reference type %qT in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: cp/parser.c:32316 cp/semantics.c:5014
+#, gcc-internal-format
+msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: cp/parser.c:32703 cp/semantics.c:7070
+#, gcc-internal-format
+msgid "%<__transaction_relaxed%> without transactional memory support enabled"
+msgstr ""
+
+#: cp/parser.c:32705 cp/semantics.c:7072
+#, gcc-internal-format
+msgid "%<__transaction_atomic%> without transactional memory support enabled"
+msgstr ""
+
+#: cp/parser.c:32901
+#, gcc-internal-format
+msgid "junk at end of %<#pragma GCC pch_preprocess%>"
+msgstr ""
+
+#: cp/parser.c:32934
+#, gcc-internal-format
+msgid "invalid grainsize for _Cilk_for"
+msgstr ""
+
+#: cp/parser.c:33120
+#, gcc-internal-format
+msgid "%<#pragma GCC ivdep%> must be inside a function"
+msgstr ""
+
+#: cp/parser.c:33141
+#, gcc-internal-format
+msgid "%<#pragma simd%> must be inside a function"
+msgstr ""
+
+#: cp/parser.c:33151
+#, gcc-internal-format
+msgid "%<#pragma cilk grainsize%> must be inside a function"
+msgstr ""
+
+#: cp/parser.c:33163
+#, gcc-internal-format
+msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
+msgstr ""
+
+#: cp/parser.c:33221
+#, gcc-internal-format
+msgid "inter-module optimizations not implemented for C++"
+msgstr ""
+
+#: cp/parser.c:33331
+#, gcc-internal-format
+msgid "expected variable-name"
+msgstr ""
+
+#: cp/parser.c:33395
+#, gcc-internal-format
+msgid "expected %<,%> or %<)%> after %qE"
+msgstr ""
+
+#: cp/parser.c:33736
+#, gcc-internal-format
+msgid "implicit templates may not be %<virtual%>"
+msgstr ""
+
+#: cp/pt.c:297
+#, gcc-internal-format
+msgid "data member %qD cannot be a member template"
+msgstr ""
+
+#: cp/pt.c:309
+#, gcc-internal-format
+msgid "invalid member template declaration %qD"
+msgstr ""
+
+#: cp/pt.c:690
+#, gcc-internal-format
+msgid "explicit specialization in non-namespace scope %qD"
+msgstr ""
+
+#: cp/pt.c:704
+#, gcc-internal-format
+msgid "enclosing class templates are not explicitly specialized"
+msgstr ""
+
+#: cp/pt.c:790
+#, gcc-internal-format
+msgid "specialization of %qD must appear at namespace scope"
+msgstr ""
+
+#: cp/pt.c:798
+#, gcc-internal-format
+msgid "specialization of %qD in different namespace"
+msgstr ""
+
+#: cp/pt.c:799 cp/pt.c:926
+#, gcc-internal-format
+msgid "  from definition of %q+#D"
+msgstr ""
+
+#: cp/pt.c:816
+#, gcc-internal-format
+msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
+msgstr ""
+
+#: cp/pt.c:839
+#, gcc-internal-format
+msgid "name of class shadows template template parameter %qD"
+msgstr ""
+
+#: cp/pt.c:850
+#, gcc-internal-format
+msgid "specialization of alias template %qD"
+msgstr ""
+
+#: cp/pt.c:853 cp/pt.c:988
+#, gcc-internal-format
+msgid "explicit specialization of non-template %qT"
+msgstr ""
+
+#: cp/pt.c:885
+#, gcc-internal-format
+msgid "specialization of %qT after instantiation"
+msgstr ""
+
+#: cp/pt.c:925
+#, gcc-internal-format
+msgid "specializing %q#T in different namespace"
+msgstr ""
+
+#. But if we've had an implicit instantiation, that's a
+#. problem ([temp.expl.spec]/6).
+#: cp/pt.c:966
+#, gcc-internal-format
+msgid "specialization %qT after instantiation %qT"
+msgstr ""
+
+#: cp/pt.c:984
+#, gcc-internal-format
+msgid "template specialization of %qD not allowed by ISO C++"
+msgstr ""
+
+#: cp/pt.c:1416
+#, gcc-internal-format
+msgid "specialization of %qD after instantiation"
+msgstr ""
+
+#: cp/pt.c:1804
+#, gcc-internal-format
+msgid "candidate is: %#D"
+msgstr ""
+
+#: cp/pt.c:1811 cp/semantics.c:4862
+#, gcc-internal-format
+msgid "%s %#D"
+msgstr "%s %#D"
+
+#: cp/pt.c:1905
+#, gcc-internal-format
+msgid "%qD is not a function template"
+msgstr ""
+
+#: cp/pt.c:1910
+#, gcc-internal-format
+msgid "%qD is not a variable template"
+msgstr ""
+
+#: cp/pt.c:2132
+#, gcc-internal-format
+msgid "template-id %qD for %q+D does not match any template declaration"
+msgstr ""
+
+#: cp/pt.c:2135
+#, gcc-internal-format
+msgid "saw %d %<template<>%>, need %d for specializing a member function template"
+msgstr ""
+
+#: cp/pt.c:2144
+#, gcc-internal-format
+msgid "ambiguous template specialization %qD for %q+D"
+msgstr ""
+
+#: cp/pt.c:2350
+#, gcc-internal-format
+msgid "variable templates only available with -std=c++14 or -std=gnu++14"
+msgstr ""
+
+#: cp/pt.c:2359
+#, gcc-internal-format
+msgid "too many template headers for %D (should be %d)"
+msgstr ""
+
+#: cp/pt.c:2364
+#, gcc-internal-format
+msgid "members of an explicitly specialized class are defined without a template header"
+msgstr ""
+
+#. This case handles bogus declarations like template <>
+#. template <class T> void f<int>();
+#: cp/pt.c:2452 cp/pt.c:2508
+#, gcc-internal-format
+msgid "template-id %qD in declaration of primary template"
+msgstr ""
+
+#: cp/pt.c:2465
+#, gcc-internal-format
+msgid "template parameter list used in explicit instantiation"
+msgstr ""
+
+#: cp/pt.c:2471
+#, gcc-internal-format
+msgid "definition provided for explicit instantiation"
+msgstr ""
+
+#: cp/pt.c:2479
+#, gcc-internal-format
+msgid "too many template parameter lists in declaration of %qD"
+msgstr ""
+
+#: cp/pt.c:2482
+#, gcc-internal-format
+msgid "too few template parameter lists in declaration of %qD"
+msgstr ""
+
+#: cp/pt.c:2484
+#, gcc-internal-format
+msgid "explicit specialization of %qD must be introduced by %<template <>%>"
+msgstr ""
+
+#: cp/pt.c:2518
+#, gcc-internal-format
+msgid "non-type partial specialization %qD is not allowed"
+msgstr ""
+
+#: cp/pt.c:2521
+#, gcc-internal-format
+msgid "non-class, non-variable partial specialization %qD is not allowed"
+msgstr ""
+
+#: cp/pt.c:2554
+#, gcc-internal-format
+msgid "default argument specified in explicit specialization"
+msgstr ""
+
+#: cp/pt.c:2585
+#, gcc-internal-format
+msgid "%qD is not a template function"
+msgstr ""
+
+#: cp/pt.c:2593
+#, gcc-internal-format
+msgid "%qD is not declared in %qD"
+msgstr ""
+
+#. From [temp.expl.spec]:
+#.
+#. If such an explicit specialization for the member
+#. of a class template names an implicitly-declared
+#. special member function (clause _special_), the
+#. program is ill-formed.
+#.
+#. Similar language is found in [temp.explicit].
+#: cp/pt.c:2658
+#, gcc-internal-format
+msgid "specialization of implicitly-declared special member function"
+msgstr ""
+
+#: cp/pt.c:2702
+#, gcc-internal-format
+msgid "no member function %qD declared in %qT"
+msgstr ""
+
+#: cp/pt.c:3382
+#, gcc-internal-format
+msgid "base initializer expansion %<%T%> contains no parameter packs"
+msgstr ""
+
+#: cp/pt.c:3443
+#, gcc-internal-format
+msgid "expansion pattern %<%T%> contains no argument packs"
+msgstr ""
+
+#: cp/pt.c:3445
+#, gcc-internal-format
+msgid "expansion pattern %<%E%> contains no argument packs"
+msgstr ""
+
+#: cp/pt.c:3488
+#, gcc-internal-format
+msgid "parameter packs not expanded with %<...%>:"
+msgstr ""
+
+#: cp/pt.c:3503 cp/pt.c:4214
+#, gcc-internal-format
+msgid "        %qD"
+msgstr ""
+
+#: cp/pt.c:3505
+#, gcc-internal-format
+msgid "        <anonymous>"
+msgstr ""
+
+#: cp/pt.c:3628
+#, gcc-internal-format
+msgid "declaration of %q+#D"
+msgstr ""
+
+#: cp/pt.c:3629
+#, gcc-internal-format
+msgid " shadows template parm %q+#D"
+msgstr ""
+
+#: cp/pt.c:4209
+#, gcc-internal-format
+msgid "template parameters not deducible in partial specialization:"
+msgstr ""
+
+#: cp/pt.c:4228
+#, gcc-internal-format
+msgid "partial specialization %qD does not specialize any template arguments"
+msgstr ""
+
+#: cp/pt.c:4236
+#, gcc-internal-format
+msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
+msgstr ""
+
+#: cp/pt.c:4239
+#, gcc-internal-format
+msgid "primary template here"
+msgstr ""
+
+#: cp/pt.c:4286
+#, gcc-internal-format
+msgid "parameter pack argument %qE must be at the end of the template argument list"
+msgstr ""
+
+#: cp/pt.c:4289
+#, gcc-internal-format
+msgid "parameter pack argument %qT must be at the end of the template argument list"
+msgstr ""
+
+#: cp/pt.c:4310
+#, gcc-internal-format
+msgid "template argument %qE involves template parameter(s)"
+msgstr ""
+
+#: cp/pt.c:4356
+#, gcc-internal-format
+msgid "type %qT of template argument %qE depends on a template parameter"
+msgid_plural "type %qT of template argument %qE depends on template parameters"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: cp/pt.c:4400
+#, gcc-internal-format
+msgid "partial specialization of %qD after instantiation of %qD"
+msgstr ""
+
+#: cp/pt.c:4576
+#, gcc-internal-format
+msgid "no default argument for %qD"
+msgstr ""
+
+#. A primary class template can only have one
+#. parameter pack, at the end of the template
+#. parameter list.
+#: cp/pt.c:4598
+#, gcc-internal-format
+msgid "parameter pack %q+D must be at the end of the template parameter list"
+msgstr ""
+
+#: cp/pt.c:4634
+#, gcc-internal-format
+msgid "default template arguments may not be used in function template friend re-declaration"
+msgstr ""
+
+#: cp/pt.c:4637
+#, gcc-internal-format
+msgid "default template arguments may not be used in function template friend declarations"
+msgstr ""
+
+#: cp/pt.c:4640
+#, gcc-internal-format
+msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
+msgstr ""
+
+#: cp/pt.c:4643
+#, gcc-internal-format
+msgid "default template arguments may not be used in partial specializations"
+msgstr ""
+
+#: cp/pt.c:4646 cp/pt.c:4697
+#, gcc-internal-format
+msgid "default argument for template parameter for class enclosing %qD"
+msgstr ""
+
+#: cp/pt.c:4798
+#, gcc-internal-format
+msgid "template class without a name"
+msgstr ""
+
+#: cp/pt.c:4806
+#, gcc-internal-format
+msgid "member template %qD may not have virt-specifiers"
+msgstr ""
+
+#. [basic.stc.dynamic.allocation]
+#.
+#. An allocation function can be a function
+#. template. ... Template allocation functions shall
+#. have two or more parameters.
+#: cp/pt.c:4828
+#, gcc-internal-format
+msgid "invalid template declaration of %qD"
+msgstr ""
+
+#: cp/pt.c:4956
+#, gcc-internal-format
+msgid "template definition of non-template %q#D"
+msgstr ""
+
+#: cp/pt.c:4999
+#, gcc-internal-format
+msgid "expected %d levels of template parms for %q#D, got %d"
+msgstr ""
+
+#: cp/pt.c:5013
+#, gcc-internal-format
+msgid "got %d template parameters for %q#D"
+msgstr ""
+
+#: cp/pt.c:5016
+#, gcc-internal-format
+msgid "got %d template parameters for %q#T"
+msgstr ""
+
+#: cp/pt.c:5018
+#, gcc-internal-format, gfc-internal-format
+msgid "  but %d required"
+msgstr ""
+
+#: cp/pt.c:5039
+#, gcc-internal-format
+msgid "template arguments to %qD do not match original template %qD"
+msgstr ""
+
+#: cp/pt.c:5043
+#, gcc-internal-format
+msgid "use template<> for an explicit specialization"
+msgstr ""
+
+#: cp/pt.c:5181
+#, gcc-internal-format
+msgid "%qT is not a template type"
+msgstr ""
+
+#: cp/pt.c:5194
+#, gcc-internal-format
+msgid "template specifiers not specified in declaration of %qD"
+msgstr ""
+
+#: cp/pt.c:5205
+#, gcc-internal-format, gfc-internal-format
+msgid "redeclared with %d template parameter"
+msgid_plural "redeclared with %d template parameters"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: cp/pt.c:5209
+#, gcc-internal-format
+msgid "previous declaration %q+D used %d template parameter"
+msgid_plural "previous declaration %q+D used %d template parameters"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: cp/pt.c:5246
+#, gcc-internal-format
+msgid "template parameter %q+#D"
+msgstr ""
+
+#: cp/pt.c:5247
+#, gcc-internal-format
+msgid "redeclared here as %q#D"
+msgstr ""
+
+#. We have in [temp.param]:
+#.
+#. A template-parameter may not be given default arguments
+#. by two different declarations in the same scope.
+#: cp/pt.c:5257
+#, gcc-internal-format
+msgid "redefinition of default argument for %q#D"
+msgstr ""
+
+#: cp/pt.c:5259
+#, gcc-internal-format
+msgid "original definition appeared here"
+msgstr ""
+
+#: cp/pt.c:5492 cp/pt.c:5543
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT"
+msgstr ""
+
+#: cp/pt.c:5495
+#, gcc-internal-format
+msgid "it must be the address of a function with external linkage"
+msgstr ""
+
+#: cp/pt.c:5498
+#, gcc-internal-format
+msgid "it must be the name of a function with external linkage"
+msgstr ""
+
+#: cp/pt.c:5510
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
+msgstr ""
+
+#: cp/pt.c:5514
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
+msgstr ""
+
+#: cp/pt.c:5545
+#, gcc-internal-format
+msgid "it must be a pointer-to-member of the form %<&X::Y%>"
+msgstr ""
+
+#: cp/pt.c:5596
+#, gcc-internal-format
+msgid "  couldn't deduce template parameter %qD"
+msgstr ""
+
+#: cp/pt.c:5611
+#, gcc-internal-format
+msgid "  types %qT and %qT have incompatible cv-qualifiers"
+msgstr ""
+
+#: cp/pt.c:5620
+#, gcc-internal-format
+msgid "  mismatched types %qT and %qT"
+msgstr ""
+
+#: cp/pt.c:5629
+#, gcc-internal-format
+msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
+msgstr ""
+
+#: cp/pt.c:5640
+#, gcc-internal-format
+msgid "  template argument %qE does not match pointer-to-member constant %qE"
+msgstr ""
+
+#: cp/pt.c:5650
+#, gcc-internal-format
+msgid "  %qE is not equivalent to %qE"
+msgstr ""
+
+#: cp/pt.c:5659
+#, gcc-internal-format
+msgid "  inconsistent parameter pack deduction with %qT and %qT"
+msgstr ""
+
+#: cp/pt.c:5671
+#, gcc-internal-format
+msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
+msgstr ""
+
+#: cp/pt.c:5675
+#, gcc-internal-format
+msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
+msgstr ""
+
+#: cp/pt.c:5686
+#, gcc-internal-format
+msgid "  variable-sized array type %qT is not a valid template argument"
+msgstr ""
+
+#: cp/pt.c:5697
+#, gcc-internal-format
+msgid "  member function type %qT is not a valid template argument"
+msgstr ""
+
+#: cp/pt.c:5709
+#, gcc-internal-format, gfc-internal-format
+msgid "  candidate expects at least %d argument, %d provided"
+msgid_plural "  candidate expects at least %d arguments, %d provided"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+
+#: cp/pt.c:5740
+#, gcc-internal-format
+msgid "  cannot convert %qE (type %qT) to type %qT"
+msgstr ""
+
+#: cp/pt.c:5753
+#, gcc-internal-format
+msgid "  %qT is an ambiguous base class of %qT"
+msgstr ""
+
+#: cp/pt.c:5757
+#, gcc-internal-format
+msgid "  %qT is not derived from %qT"
+msgstr ""
+
+#: cp/pt.c:5768
+#, gcc-internal-format
+msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
+msgstr ""
+
+#: cp/pt.c:5778
+#, gcc-internal-format
+msgid "  can't deduce a template for %qT from non-template type %qT"
+msgstr ""
+
+#: cp/pt.c:5788
+#, gcc-internal-format
+msgid "  template argument %qE does not match %qD"
+msgstr ""
+
+#: cp/pt.c:5797
+#, gcc-internal-format
+msgid "  could not resolve address from overloaded function %qE"
+msgstr ""
+
+#: cp/pt.c:5836
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
+msgstr ""
+
+#: cp/pt.c:5990
+#, gcc-internal-format
+msgid "in template argument for type %qT "
+msgstr ""
+
+#: cp/pt.c:6037
+#, gcc-internal-format
+msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
+msgstr ""
+
+#: cp/pt.c:6045
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
+msgstr ""
+
+#: cp/pt.c:6063
+#, gcc-internal-format
+msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
+msgstr ""
+
+#: cp/pt.c:6070
+#, gcc-internal-format
+msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
+msgstr ""
+
+#: cp/pt.c:6078
+#, gcc-internal-format
+msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
+msgstr ""
+
+#: cp/pt.c:6108
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
+msgstr ""
+
+#: cp/pt.c:6116
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
+msgstr ""
+
+#: cp/pt.c:6134
+#, gcc-internal-format
+msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
+msgstr ""
+
+#: cp/pt.c:6144
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
+msgstr ""
+
+#: cp/pt.c:6153
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
+msgstr ""
+
+#: cp/pt.c:6199
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because it is a pointer"
+msgstr ""
+
+#: cp/pt.c:6201
+#, gcc-internal-format
+msgid "try using %qE instead"
+msgstr ""
+
+#: cp/pt.c:6243 cp/pt.c:6274
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
+msgstr ""
+
+#: cp/pt.c:6249
+#, gcc-internal-format
+msgid "standard conversions are not allowed in this context"
+msgstr ""
+
+#: cp/pt.c:6561
+#, gcc-internal-format
+msgid "ignoring attributes on template argument %qT"
+msgstr ""
+
+#: cp/pt.c:6622
+#, gcc-internal-format
+msgid "injected-class-name %qD used as template template argument"
+msgstr ""
+
+#: cp/pt.c:6651
+#, gcc-internal-format
+msgid "invalid use of destructor %qE as a type"
+msgstr ""
+
+#: cp/pt.c:6656
+#, gcc-internal-format
+msgid "to refer to a type member of a template parameter, use %<typename %E%>"
+msgstr ""
+
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
+#, gcc-internal-format
+msgid "type/value mismatch at argument %d in template parameter list for %qD"
+msgstr ""
+
+#: cp/pt.c:6677
+#, gcc-internal-format
+msgid "  expected a constant of type %qT, got %qT"
+msgstr ""
+
+#: cp/pt.c:6682
+#, gcc-internal-format
+msgid "  expected a class template, got %qE"
+msgstr ""
+
+#: cp/pt.c:6685
+#, gcc-internal-format
+msgid "  expected a type, got %qE"
+msgstr ""
+
+#: cp/pt.c:6699
+#, gcc-internal-format
+msgid "  expected a type, got %qT"
+msgstr ""
+
+#: cp/pt.c:6702
+#, gcc-internal-format
+msgid "  expected a class template, got %qT"
+msgstr ""
+
+#: cp/pt.c:6751
+#, gcc-internal-format
+msgid "  expected a template of type %qD, got %qT"
+msgstr ""
+
+#. Not sure if this is reachable, but it doesn't hurt
+#. to be robust.
+#: cp/pt.c:6784
+#, gcc-internal-format
+msgid "type mismatch in nontype parameter pack"
+msgstr ""
+
+#: cp/pt.c:6807
+#, gcc-internal-format
+msgid "could not convert template argument %qE to %qT"
+msgstr ""
+
+#: cp/pt.c:6918 cp/pt.c:7215
+#, gcc-internal-format, gfc-internal-format
+msgid "template argument %d is invalid"
+msgstr ""
+
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong number of template arguments (%d, should be %d)"
+msgstr ""
+
+#: cp/pt.c:7060
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong number of template arguments (%d, should be at least %d)"
+msgstr ""
+
+#: cp/pt.c:7068 cp/pt.c:7243
+#, gcc-internal-format
+msgid "provided for %q+D"
+msgstr ""
+
+#: cp/pt.c:7089
+#, gcc-internal-format
+msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
+msgstr ""
+
+#: cp/pt.c:7181
+#, gcc-internal-format
+msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
+msgstr ""
+
+#: cp/pt.c:7499
+#, gcc-internal-format
+msgid "%q#D is not a function template"
+msgstr ""
+
+#: cp/pt.c:7666
+#, gcc-internal-format
+msgid "non-template type %qT used as a template"
+msgstr ""
+
+#: cp/pt.c:7668
+#, gcc-internal-format
+msgid "for template declaration %q+D"
+msgstr ""
+
+#: cp/pt.c:8557
+#, gcc-internal-format, gfc-internal-format
+msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
+msgstr ""
+
+#: cp/pt.c:10138
+#, gcc-internal-format
+msgid "mismatched argument pack lengths while expanding %<%T%>"
+msgstr ""
+
+#: cp/pt.c:10142
+#, gcc-internal-format
+msgid "mismatched argument pack lengths while expanding %<%E%>"
+msgstr ""
+
+#: cp/pt.c:10635
+#, gcc-internal-format
+msgid "  when instantiating default argument for call to %D"
+msgstr ""
+
+#. It may seem that this case cannot occur, since:
+#.
+#. typedef void f();
+#. void g() { f x; }
+#.
+#. declares a function, not a variable.  However:
+#.
+#. typedef void f();
+#. template <typename T> void g() { T t; }
+#. template void g<f>();
+#.
+#. is an attempt to declare a variable with function
+#. type.
+#: cp/pt.c:11467
+#, gcc-internal-format
+msgid "variable %qD has function type"
+msgstr ""
+
+#: cp/pt.c:11627
+#, gcc-internal-format
+msgid "invalid parameter type %qT"
+msgstr ""
+
+#: cp/pt.c:11629
+#, gcc-internal-format
+msgid "in declaration %q+D"
+msgstr ""
+
+#: cp/pt.c:11740
+#, gcc-internal-format
+msgid "function returning an array"
+msgstr ""
+
+#: cp/pt.c:11742
+#, gcc-internal-format
+msgid "function returning a function"
+msgstr ""
+
+#: cp/pt.c:11782
+#, gcc-internal-format
+msgid "creating pointer to member function of non-class type %qT"
+msgstr ""
+
+#: cp/pt.c:12355
+#, gcc-internal-format
+msgid "forming reference to void"
+msgstr ""
+
+#: cp/pt.c:12357
+#, gcc-internal-format
+msgid "forming pointer to reference type %qT"
+msgstr ""
+
+#: cp/pt.c:12359
+#, gcc-internal-format
+msgid "forming reference to reference type %qT"
+msgstr ""
+
+#: cp/pt.c:12372
+#, gcc-internal-format
+msgid "forming pointer to qualified function type %qT"
+msgstr ""
+
+#: cp/pt.c:12375
+#, gcc-internal-format
+msgid "forming reference to qualified function type %qT"
+msgstr ""
+
+#: cp/pt.c:12423
+#, gcc-internal-format
+msgid "creating pointer to member of non-class type %qT"
+msgstr ""
+
+#: cp/pt.c:12429
+#, gcc-internal-format
+msgid "creating pointer to member reference type %qT"
+msgstr ""
+
+#: cp/pt.c:12435
+#, gcc-internal-format
+msgid "creating pointer to member of type void"
+msgstr ""
+
+#: cp/pt.c:12501
+#, gcc-internal-format
+msgid "creating array of %qT"
+msgstr ""
+
+#: cp/pt.c:12532
+#, gcc-internal-format
+msgid "%qT is not a class, struct, or union type"
+msgstr ""
+
+#: cp/pt.c:12569
+#, gcc-internal-format
+msgid "%qT resolves to %qT, which is not an enumeration type"
+msgstr ""
+
+#: cp/pt.c:12577
+#, gcc-internal-format
+msgid "%qT resolves to %qT, which is is not a class type"
+msgstr ""
+
+#: cp/pt.c:12706
+#, gcc-internal-format
+msgid "use of %qs in template"
+msgstr ""
+
+#: cp/pt.c:12848
+#, gcc-internal-format
+msgid "qualifying type %qT does not match destructor name ~%qT"
+msgstr ""
+
+#: cp/pt.c:12863
+#, gcc-internal-format
+msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
+msgstr ""
+
+#: cp/pt.c:12865
+#, gcc-internal-format
+msgid "say %<typename %E%> if a type is meant"
+msgstr ""
+
+#: cp/pt.c:13069
+#, gcc-internal-format
+msgid "using invalid field %qD"
+msgstr ""
+
+#: cp/pt.c:13510 cp/pt.c:14499
+#, gcc-internal-format
+msgid "invalid use of pack expansion expression"
+msgstr ""
+
+#: cp/pt.c:13514 cp/pt.c:14503
+#, gcc-internal-format
+msgid "use %<...%> to expand argument pack"
+msgstr ""
+
+#: cp/pt.c:15265
+#, gcc-internal-format
+msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
+msgstr ""
+
+#: cp/pt.c:15277
+#, gcc-internal-format
+msgid "declarations in dependent base %qT are not found by unqualified lookup"
+msgstr ""
+
+#: cp/pt.c:15282
+#, gcc-internal-format
+msgid "use %<this->%D%> instead"
+msgstr ""
+
+#: cp/pt.c:15285
+#, gcc-internal-format
+msgid "use %<%T::%D%> instead"
+msgstr ""
+
+#: cp/pt.c:15289
+#, gcc-internal-format
+msgid "%q+D declared here, later in the translation unit"
+msgstr ""
+
+#: cp/pt.c:15560
+#, gcc-internal-format
+msgid "%qT is not a class or namespace"
+msgstr ""
+
+#: cp/pt.c:15563
+#, gcc-internal-format
+msgid "%qD is not a class or namespace"
+msgstr ""
+
+#: cp/pt.c:15917
+#, gcc-internal-format
+msgid "%qT is/uses anonymous type"
+msgstr ""
+
+#: cp/pt.c:15919
+#, gcc-internal-format
+msgid "template argument for %qD uses local type %qT"
+msgstr ""
+
+#: cp/pt.c:15929
+#, gcc-internal-format
+msgid "%qT is a variably modified type"
+msgstr ""
+
+#: cp/pt.c:15944
+#, gcc-internal-format
+msgid "integral expression %qE is not constant"
+msgstr ""
+
+#: cp/pt.c:15962
+#, gcc-internal-format
+msgid "  trying to instantiate %qD"
+msgstr ""
+
+#: cp/pt.c:19573
+#, gcc-internal-format
+msgid "ambiguous template instantiation for %q#T"
+msgstr ""
+
+#: cp/pt.c:19575
+#, gcc-internal-format
+msgid "ambiguous template instantiation for %q#D"
+msgstr ""
+
+#: cp/pt.c:19581
+msgid "%s %#S"
+msgstr "%s %#S"
+
+#: cp/pt.c:19605 cp/pt.c:19692
+#, gcc-internal-format
+msgid "explicit instantiation of non-template %q#D"
+msgstr ""
+
+#: cp/pt.c:19624
+#, gcc-internal-format
+msgid "%qD is not a static data member of a class template"
+msgstr ""
+
+#: cp/pt.c:19630 cp/pt.c:19687
+#, gcc-internal-format
+msgid "no matching template for %qD found"
+msgstr ""
+
+#: cp/pt.c:19635
+#, gcc-internal-format
+msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
+msgstr ""
+
+#: cp/pt.c:19643
+#, gcc-internal-format
+msgid "explicit instantiation of %q#D"
+msgstr ""
+
+#: cp/pt.c:19679
+#, gcc-internal-format
+msgid "duplicate explicit instantiation of %q#D"
+msgstr ""
+
+#: cp/pt.c:19702 cp/pt.c:19799
+#, gcc-internal-format
+msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
+msgstr ""
+
+#: cp/pt.c:19707 cp/pt.c:19816
+#, gcc-internal-format
+msgid "storage class %qD applied to template instantiation"
+msgstr ""
+
+#: cp/pt.c:19775
+#, gcc-internal-format
+msgid "explicit instantiation of non-class template %qD"
+msgstr ""
+
+#: cp/pt.c:19777
+#, gcc-internal-format
+msgid "explicit instantiation of non-template type %qT"
+msgstr ""
+
+#: cp/pt.c:19786
+#, gcc-internal-format
+msgid "explicit instantiation of %q#T before definition of template"
+msgstr ""
+
+#: cp/pt.c:19804
+#, gcc-internal-format
+msgid "ISO C++ forbids the use of %qE on explicit instantiations"
+msgstr ""
+
+#: cp/pt.c:19850
+#, gcc-internal-format
+msgid "duplicate explicit instantiation of %q#T"
+msgstr ""
+
+#. [temp.explicit]
+#.
+#. The definition of a non-exported function template, a
+#. non-exported member function template, or a non-exported
+#. member function or static data member of a class template
+#. shall be present in every translation unit in which it is
+#. explicitly instantiated.
+#: cp/pt.c:20385
+#, gcc-internal-format
+msgid "explicit instantiation of %qD but no definition available"
+msgstr ""
+
+#: cp/pt.c:20611
+#, gcc-internal-format
+msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
+msgstr ""
+
+#: cp/pt.c:20947
+#, gcc-internal-format
+msgid "invalid template non-type parameter"
+msgstr ""
+
+#: cp/pt.c:20949
+#, gcc-internal-format
+msgid "%q#T is not a valid type for a template non-type parameter"
+msgstr ""
+
+#: cp/pt.c:22238
+#, gcc-internal-format
+msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
+msgstr ""
+
+#: cp/pt.c:22289
+#, gcc-internal-format
+msgid "direct-list-initialization of %<auto%> requires exactly one element"
+msgstr ""
+
+#: cp/pt.c:22292
+#, gcc-internal-format
+msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
+msgstr ""
+
+#: cp/pt.c:22309
+#, gcc-internal-format
+msgid "%qT as type rather than plain %<decltype(auto)%>"
+msgstr ""
+
+#: cp/pt.c:22336
+#, gcc-internal-format
+msgid "unable to deduce lambda return type from %qE"
+msgstr ""
+
+#: cp/pt.c:22338
+#, gcc-internal-format
+msgid "unable to deduce %qT from %qE"
+msgstr ""
+
+#: cp/pt.c:22353
+#, gcc-internal-format
+msgid "inconsistent types %qT and %qT deduced for lambda return type"
+msgstr ""
+
+#: cp/pt.c:22357
+#, gcc-internal-format
+msgid "inconsistent deduction for %qT: %qT and then %qT"
+msgstr ""
+
+#: cp/repo.c:128
+#, gcc-internal-format
+msgid "-frepo must be used with -c"
+msgstr ""
+
+#: cp/repo.c:218
+#, gcc-internal-format, gfc-internal-format
+msgid "mysterious repository information in %s"
+msgstr ""
+
+#: cp/repo.c:236
+#, gcc-internal-format
+msgid "can%'t create repository information file %qs"
+msgstr ""
+
+#: cp/rtti.c:300
+#, gcc-internal-format
+msgid "cannot use typeid with -fno-rtti"
+msgstr ""
+
+#: cp/rtti.c:306
+#, gcc-internal-format
+msgid "must #include <typeinfo> before using typeid"
+msgstr ""
+
+#: cp/rtti.c:408
+#, gcc-internal-format
+msgid "cannot create type information for type %qT because it involves types of variable size"
+msgstr ""
+
+#: cp/rtti.c:498
+#, gcc-internal-format
+msgid "typeid of qualified function type %qT"
+msgstr ""
+
+#: cp/rtti.c:678 cp/rtti.c:693
+#, gcc-internal-format
+msgid "dynamic_cast of %q#D to %q#T can never succeed"
+msgstr ""
+
+#: cp/rtti.c:704
+#, gcc-internal-format
+msgid "%<dynamic_cast%> not permitted with -fno-rtti"
+msgstr ""
+
+#: cp/rtti.c:781
+#, gcc-internal-format
+msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
+msgstr ""
+
+#: cp/search.c:269
+#, gcc-internal-format
+msgid "%qT is an ambiguous base of %qT"
+msgstr ""
+
+#: cp/search.c:285
+#, gcc-internal-format
+msgid "%qT is an inaccessible base of %qT"
+msgstr ""
+
+#: cp/search.c:1910
+#, gcc-internal-format
+msgid "invalid covariant return type for %q#D"
+msgstr ""
+
+#: cp/search.c:1912 cp/search.c:1926 cp/search.c:1931 cp/search.c:1955
+#, gcc-internal-format
+msgid "  overriding %q+#D"
+msgstr ""
+
+#: cp/search.c:1925
+#, gcc-internal-format
+msgid "invalid covariant return type for %q+#D"
+msgstr ""
+
+#: cp/search.c:1930
+#, gcc-internal-format
+msgid "conflicting return type specified for %q+#D"
+msgstr ""
+
+#: cp/search.c:1945
+#, gcc-internal-format
+msgid "looser throw specifier for %q+#F"
+msgstr ""
+
+#: cp/search.c:1946
+#, gcc-internal-format
+msgid "  overriding %q+#F"
+msgstr ""
+
+#: cp/search.c:1954
+#, gcc-internal-format
+msgid "conflicting type attributes specified for %q+#D"
+msgstr ""
+
+#: cp/search.c:1964
+#, gcc-internal-format
+msgid "deleted function %q+D"
+msgstr ""
+
+#: cp/search.c:1965
+#, gcc-internal-format
+msgid "overriding non-deleted function %q+D"
+msgstr ""
+
+#: cp/search.c:1970
+#, gcc-internal-format
+msgid "non-deleted function %q+D"
+msgstr ""
+
+#: cp/search.c:1971
+#, gcc-internal-format
+msgid "overriding deleted function %q+D"
+msgstr ""
+
+#: cp/search.c:1977
+#, gcc-internal-format
+msgid "virtual function %q+D"
+msgstr ""
+
+#: cp/search.c:1978
+#, gcc-internal-format
+msgid "overriding final function %q+D"
+msgstr ""
+
+#. A static member function cannot match an inherited
+#. virtual member function.
+#: cp/search.c:2074
+#, gcc-internal-format
+msgid "%q+#D cannot be declared"
+msgstr ""
+
+#: cp/search.c:2075
+#, gcc-internal-format
+msgid "  since %q+#D declared in base class"
+msgstr ""
+
+#: cp/semantics.c:857
+#, gcc-internal-format
+msgid "suggest explicit braces around empty body in %<do%> statement"
+msgstr ""
+
+#: cp/semantics.c:1175
+#, gcc-internal-format
+msgid "switch condition has type bool"
+msgstr ""
+
+#: cp/semantics.c:1523
+#, gcc-internal-format
+msgid "type of asm operand %qE could not be determined"
+msgstr ""
+
+#: cp/semantics.c:1588
+#, gcc-internal-format
+msgid "__label__ declarations are only allowed in function scopes"
+msgstr ""
+
+#: cp/semantics.c:1739
+#, gcc-internal-format
+msgid "invalid use of member %qD in static member function"
+msgstr ""
+
+#: cp/semantics.c:2415
+#, gcc-internal-format
+msgid "arguments to destructor are not allowed"
+msgstr ""
+
+#: cp/semantics.c:2499
+#, gcc-internal-format
+msgid "%<this%> is unavailable for static member functions"
+msgstr ""
+
+#: cp/semantics.c:2501
+#, gcc-internal-format
+msgid "invalid use of %<this%> in non-member function"
+msgstr ""
+
+#: cp/semantics.c:2503
+#, gcc-internal-format
+msgid "invalid use of %<this%> at top level"
+msgstr ""
+
+#: cp/semantics.c:2525
+#, gcc-internal-format
+msgid "invalid qualifying scope in pseudo-destructor name"
+msgstr ""
+
+#: cp/semantics.c:2533 cp/typeck.c:2510
+#, gcc-internal-format
+msgid "qualified type %qT does not match destructor name ~%qT"
+msgstr ""
+
+#: cp/semantics.c:2555
+#, gcc-internal-format
+msgid "%qE is not of type %qT"
+msgstr ""
+
+#: cp/semantics.c:2599
+#, gcc-internal-format
+msgid "compound literal of non-object type %qT"
+msgstr ""
+
+#: cp/semantics.c:2716
+#, gcc-internal-format
+msgid "template type parameters must use the keyword %<class%> or %<typename%>"
+msgstr ""
+
+#: cp/semantics.c:2758
+#, gcc-internal-format
+msgid "invalid use of type %qT as a default value for a template template-parameter"
+msgstr ""
+
+#: cp/semantics.c:2761
+#, gcc-internal-format
+msgid "invalid default argument for a template template parameter"
+msgstr ""
+
+#: cp/semantics.c:2778
+#, gcc-internal-format
+msgid "definition of %q#T inside template parameter list"
+msgstr ""
+
+#: cp/semantics.c:2809
+#, gcc-internal-format
+msgid "invalid definition of qualified type %qT"
+msgstr ""
+
+#: cp/semantics.c:3032
+#, gcc-internal-format
+msgid "invalid base-class specification"
+msgstr ""
+
+#: cp/semantics.c:3178
+#, gcc-internal-format
+msgid "cannot capture member %qD of anonymous union"
+msgstr ""
+
+#: cp/semantics.c:3191 cp/semantics.c:7740
+#, gcc-internal-format
+msgid "%qD is not captured"
+msgstr ""
+
+#: cp/semantics.c:3196
+#, gcc-internal-format
+msgid "the lambda has no capture-default"
+msgstr ""
+
+#: cp/semantics.c:3198
+#, gcc-internal-format
+msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
+msgstr ""
+
+#: cp/semantics.c:3209
+#, gcc-internal-format
+msgid "use of local variable with automatic storage from containing function"
+msgstr ""
+
+#: cp/semantics.c:3210
+#, gcc-internal-format
+msgid "use of parameter from containing function"
+msgstr ""
+
+#: cp/semantics.c:3372
+#, gcc-internal-format
+msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
+msgstr ""
+
+#: cp/semantics.c:3523
+#, gcc-internal-format
+msgid "use of namespace %qD as expression"
+msgstr ""
+
+#: cp/semantics.c:3528
+#, gcc-internal-format
+msgid "use of class template %qT as expression"
+msgstr ""
+
+#. Ambiguous reference to base members.
+#: cp/semantics.c:3534
+#, gcc-internal-format
+msgid "request for member %qD is ambiguous in multiple inheritance lattice"
+msgstr ""
+
+#: cp/semantics.c:3560
+#, gcc-internal-format
+msgid "%qD cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/semantics.c:3689
+#, gcc-internal-format
+msgid "type of %qE is unknown"
+msgstr ""
+
+#: cp/semantics.c:3717
+#, gcc-internal-format
+msgid "%qT is not an enumeration type"
+msgstr ""
+
+#. Parameter packs can only be used in templates
+#: cp/semantics.c:3866
+#, gcc-internal-format
+msgid "Parameter pack __bases only valid in template declaration"
+msgstr ""
+
+#: cp/semantics.c:3895
+#, gcc-internal-format
+msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
+msgstr ""
+
+#: cp/semantics.c:3904
+#, gcc-internal-format
+msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
+msgstr ""
+
+#: cp/semantics.c:3912
+#, gcc-internal-format
+msgid "cannot apply %<offsetof%> to member function %qD"
+msgstr ""
+
+#: cp/semantics.c:3928
+#, gcc-internal-format
+msgid "offsetof within non-standard-layout type %qT is undefined"
+msgstr ""
+
+#: cp/semantics.c:4859
+#, gcc-internal-format
+msgid "user defined reduction lookup is ambiguous"
+msgstr ""
+
+#: cp/semantics.c:5144
+#, gcc-internal-format
+msgid "%qE has invalid type for %<reduction%>"
+msgstr ""
+
+#: cp/semantics.c:5245
+#, gcc-internal-format
+msgid "user defined reduction with constructor initializer for base class %qT"
+msgstr ""
+
+#: cp/semantics.c:5339
+#, gcc-internal-format
+msgid "linear clause applied to non-integral non-pointer variable with %qT type"
+msgstr ""
+
+#: cp/semantics.c:5355
+#, gcc-internal-format
+msgid "linear step expression must be integral"
+msgstr ""
+
+#: cp/semantics.c:5394
+#, gcc-internal-format
+msgid "%qD is not a variable in clause %qs"
+msgstr ""
+
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
+#, gcc-internal-format
+msgid "%qD appears more than once in data clauses"
+msgstr ""
+
+#: cp/semantics.c:5419
+#, gcc-internal-format
+msgid "%qD is not a variable in clause %<firstprivate%>"
+msgstr ""
+
+#: cp/semantics.c:5441
+#, gcc-internal-format
+msgid "%qD is not a variable in clause %<lastprivate%>"
+msgstr ""
+
+#: cp/semantics.c:5483
+#, gcc-internal-format
+msgid "num_threads expression must be integral"
+msgstr ""
+
+#: cp/semantics.c:5506
+#, gcc-internal-format
+msgid "schedule chunk size expression must be integral"
+msgstr ""
+
+#: cp/semantics.c:5538
+#, gcc-internal-format
+msgid "%qs length expression must be integral"
+msgstr ""
+
+#: cp/semantics.c:5551
+#, gcc-internal-format
+msgid "%qs length expression must be positive constant integer expression"
+msgstr ""
+
+#: cp/semantics.c:5568
+#, gcc-internal-format
+msgid "%<num_teams%> expression must be integral"
+msgstr ""
+
+#: cp/semantics.c:5587
+#, gcc-internal-format
+msgid "%<async%> expression must be integral"
+msgstr ""
+
+#: cp/semantics.c:5625
+#, gcc-internal-format
+msgid "%<thread_limit%> expression must be integral"
+msgstr ""
+
+#: cp/semantics.c:5644
+#, gcc-internal-format
+msgid "%<device%> id must be integral"
+msgstr ""
+
+#: cp/semantics.c:5665
+#, gcc-internal-format
+msgid "%<dist_schedule%> chunk size expression must be integral"
+msgstr ""
+
+#: cp/semantics.c:5685
+#, gcc-internal-format
+msgid "%qD is not a variable in %<aligned%> clause"
+msgstr ""
+
+#: cp/semantics.c:5699
+#, gcc-internal-format
+msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
+msgstr ""
+
+#: cp/semantics.c:5705
+#, gcc-internal-format
+msgid "%qD appears more than once in %<aligned%> clauses"
+msgstr ""
+
+#: cp/semantics.c:5718
+#, gcc-internal-format
+msgid "%<aligned%> clause alignment expression must be integral"
+msgstr ""
+
+#: cp/semantics.c:5755
+#, gcc-internal-format
+msgid "%qD is not a variable in %<depend%> clause"
+msgstr ""
+
+#: cp/semantics.c:5996
+#, gcc-internal-format
+msgid "%qE has reference type for %qs"
+msgstr ""
+
+#: cp/semantics.c:6079
+#, gcc-internal-format
+msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
+msgstr ""
+
+#: cp/semantics.c:6093
+#, gcc-internal-format
+msgid "%<threadprivate%> %qE directive not in %qT definition"
+msgstr ""
+
+#: cp/semantics.c:6295
+#, gcc-internal-format
+msgid "difference between %qE and %qD does not have integer type"
+msgstr ""
+
+#: cp/semantics.c:6619
+#, gcc-internal-format
+msgid "%<#pragma omp simd%> used with class iteration variable %qE"
+msgstr ""
+
+#: cp/semantics.c:6894 cp/semantics.c:6904
+#, gcc-internal-format
+msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
+msgstr ""
+
+#. Report the error.
+#: cp/semantics.c:7193
+#, gcc-internal-format, gfc-internal-format
+msgid "static assertion failed: %s"
+msgstr ""
+
+#: cp/semantics.c:7196
+#, gcc-internal-format
+msgid "non-constant condition for static assertion"
+msgstr ""
+
+#: cp/semantics.c:7226
+#, gcc-internal-format
+msgid "argument to decltype must be an expression"
+msgstr ""
+
+#: cp/semantics.c:7254
+#, gcc-internal-format
+msgid "decltype cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/tree.c:1144
+#, gcc-internal-format
+msgid "%qV qualifiers cannot be applied to %qT"
+msgstr ""
+
+#: cp/tree.c:1518
+#, gcc-internal-format
+msgid "lambda-expression in a constant expression"
+msgstr ""
+
+#: cp/tree.c:3375
+#, gcc-internal-format
+msgid "%qE attribute can only be applied to Java class definitions"
+msgstr ""
+
+#: cp/tree.c:3404
+#, gcc-internal-format
+msgid "%qE attribute can only be applied to class definitions"
+msgstr ""
+
+#: cp/tree.c:3410
+#, gcc-internal-format
+msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
+msgstr ""
+
+#: cp/tree.c:3435
+#, gcc-internal-format
+msgid "requested init_priority is not an integer constant"
+msgstr ""
+
+#: cp/tree.c:3456
+#, gcc-internal-format
+msgid "can only use %qE attribute on file-scope definitions of objects of class type"
+msgstr ""
+
+#: cp/tree.c:3464
+#, gcc-internal-format
+msgid "requested init_priority is out of range"
+msgstr ""
+
+#: cp/tree.c:3474
+#, gcc-internal-format
+msgid "requested init_priority is reserved for internal use"
+msgstr ""
+
+#: cp/tree.c:3485
+#, gcc-internal-format
+msgid "%qE attribute is not supported on this platform"
+msgstr ""
+
+#: cp/tree.c:3512
+#, gcc-internal-format
+msgid "redeclaration of %qD adds abi tag %E"
+msgstr ""
+
+#: cp/tree.c:3518
+#, gcc-internal-format
+msgid "previous declaration here"
+msgstr ""
+
+#: cp/tree.c:3532
+#, gcc-internal-format
+msgid "the %qE attribute requires arguments"
+msgstr ""
+
+#: cp/tree.c:3543
+#, gcc-internal-format
+msgid "arguments to the %qE attribute must be narrow string literals"
+msgstr ""
+
+#: cp/tree.c:3556 cp/tree.c:3569
+#, gcc-internal-format
+msgid "arguments to the %qE attribute must contain valid identifiers"
+msgstr ""
+
+#: cp/tree.c:3558
+#, gcc-internal-format
+msgid "%<%c%> is not a valid first character for an identifier"
+msgstr ""
+
+#: cp/tree.c:3571
+#, gcc-internal-format
+msgid "%<%c%> is not a valid character in an identifier"
+msgstr ""
+
+#: cp/tree.c:3595
+#, gcc-internal-format
+msgid "%qE attribute applied to non-class, non-enum type %qT"
+msgstr ""
+
+#: cp/tree.c:3601
+#, gcc-internal-format
+msgid "%qE attribute applied to %qT after its definition"
+msgstr ""
+
+#: cp/tree.c:3607
+#, gcc-internal-format
+msgid "ignoring %qE attribute applied to template instantiation %qT"
+msgstr ""
+
+#: cp/tree.c:3613
+#, gcc-internal-format
+msgid "ignoring %qE attribute applied to template specialization %qT"
+msgstr ""
+
+#: cp/tree.c:3636
+#, gcc-internal-format
+msgid "%qE attribute applied to non-function, non-variable %qD"
+msgstr ""
+
+#: cp/tree.c:3642
+#, gcc-internal-format
+msgid "%qE attribute applied to extern \"C\" declaration %qD"
+msgstr ""
+
+#: cp/tree.c:4342
+#, gcc-internal-format
+msgid "zero as null pointer constant"
+msgstr ""
+
+#: cp/tree.c:4355
+#, gcc-internal-format, gfc-internal-format
+msgid "lang_* check: failed in %s, at %s:%d"
+msgstr ""
+
+#: cp/typeck.c:476
+#, gcc-internal-format
+msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
+msgstr ""
+
+#: cp/typeck.c:482
+#, gcc-internal-format
+msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
+msgstr ""
+
+#: cp/typeck.c:488
+#, gcc-internal-format
+msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
+msgstr ""
+
+#: cp/typeck.c:630
+#, gcc-internal-format
+msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
+msgstr ""
+
+#: cp/typeck.c:635
+#, gcc-internal-format
+msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
+msgstr ""
+
+#: cp/typeck.c:640
+#, gcc-internal-format
+msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
+msgstr ""
+
+#: cp/typeck.c:711
+#, gcc-internal-format
+msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
+msgstr ""
+
+#: cp/typeck.c:716
+#, gcc-internal-format
+msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
+msgstr ""
+
+#: cp/typeck.c:721
+#, gcc-internal-format
+msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
+msgstr ""
+
+#: cp/typeck.c:1428
+#, gcc-internal-format
+msgid "canonical types differ for identical types %T and %T"
+msgstr ""
+
+#: cp/typeck.c:1435
+#, gcc-internal-format
+msgid "same canonical type node for different types %T and %T"
+msgstr ""
+
+#: cp/typeck.c:1565
+#, gcc-internal-format
+msgid "invalid application of %qs to a member function"
+msgstr ""
+
+#: cp/typeck.c:1653
+#, gcc-internal-format
+msgid "invalid application of %<sizeof%> to a bit-field"
+msgstr ""
+
+#: cp/typeck.c:1661
+#, gcc-internal-format
+msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
+msgstr ""
+
+#: cp/typeck.c:1712
+#, gcc-internal-format
+msgid "invalid application of %<__alignof%> to a bit-field"
+msgstr ""
+
+#: cp/typeck.c:1723
+#, gcc-internal-format
+msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
+msgstr ""
+
+#: cp/typeck.c:1831
+#, gcc-internal-format
+msgid "invalid use of non-static member function"
+msgstr ""
+
+#: cp/typeck.c:1990
+#, gcc-internal-format
+msgid "taking address of temporary array"
+msgstr ""
+
+#: cp/typeck.c:2147
+#, gcc-internal-format
+msgid "ISO C++ forbids converting a string constant to %qT"
+msgstr ""
+
+#: cp/typeck.c:2151
+#, gcc-internal-format
+msgid "deprecated conversion from string constant to %qT"
+msgstr ""
+
+#: cp/typeck.c:2285 cp/typeck.c:2678
+#, gcc-internal-format
+msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
+msgstr ""
+
+#: cp/typeck.c:2289 cp/typeck.c:2682
+#, gcc-internal-format
+msgid "request for member %qD in %qE, which is of non-class type %qT"
+msgstr ""
+
+#: cp/typeck.c:2319
+#, gcc-internal-format
+msgid "invalid use of nonstatic data member %qE"
+msgstr ""
+
+#: cp/typeck.c:2375
+#, gcc-internal-format
+msgid "invalid access to non-static data member %qD in virtual base of NULL object"
+msgstr ""
+
+#: cp/typeck.c:2525
+#, gcc-internal-format
+msgid "object type %qT does not match destructor name ~%qT"
+msgstr ""
+
+#: cp/typeck.c:2534
+#, gcc-internal-format
+msgid "the type being destroyed is %qT, but the destructor refers to %qT"
+msgstr ""
+
+#: cp/typeck.c:2722 cp/typeck.c:2734
+#, gcc-internal-format
+msgid "%<%D::%D%> is not a member of %qT"
+msgstr ""
+
+#: cp/typeck.c:2763
+#, gcc-internal-format
+msgid "%qT is not a base of %qT"
+msgstr ""
+
+#: cp/typeck.c:2783
+#, gcc-internal-format
+msgid "%q#T has no member named %qE"
+msgstr ""
+
+#: cp/typeck.c:2801
+#, gcc-internal-format
+msgid "%qD is not a member template function"
+msgstr ""
+
+#: cp/typeck.c:2960
+#, gcc-internal-format
+msgid "%qT is not a pointer-to-object type"
+msgstr ""
+
+#: cp/typeck.c:2991
+#, gcc-internal-format
+msgid "invalid use of array indexing on pointer to member"
+msgstr ""
+
+#: cp/typeck.c:2994
+#, gcc-internal-format
+msgid "invalid use of unary %<*%> on pointer to member"
+msgstr ""
+
+#: cp/typeck.c:2997
+#, gcc-internal-format
+msgid "invalid use of implicit conversion on pointer to member"
+msgstr ""
+
+#: cp/typeck.c:3000
+#, gcc-internal-format
+msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
+msgstr ""
+
+#: cp/typeck.c:3036
+#, gcc-internal-format
+msgid "subscript missing in array reference"
+msgstr ""
+
+#: cp/typeck.c:3052
+#, gcc-internal-format
+msgid "rank of the array%'s index is greater than 1"
+msgstr ""
+
+#: cp/typeck.c:3148
+#, gcc-internal-format
+msgid "subscripting array declared %<register%>"
+msgstr ""
+
+#: cp/typeck.c:3187
+#, gcc-internal-format
+msgid "subscripted value is neither array nor pointer"
+msgstr ""
+
+#: cp/typeck.c:3260
+#, gcc-internal-format
+msgid "object missing in use of %qE"
+msgstr ""
+
+#: cp/typeck.c:3479
+#, gcc-internal-format
+msgid "ISO C++ forbids calling %<::main%> from within program"
+msgstr ""
+
+#: cp/typeck.c:3500
+#, gcc-internal-format
+msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
+msgstr ""
+
+#: cp/typeck.c:3517
+#, gcc-internal-format
+msgid "%qE cannot be used as a function"
+msgstr ""
+
+#: cp/typeck.c:3520
+#, gcc-internal-format
+msgid "%qD cannot be used as a function"
+msgstr ""
+
+#: cp/typeck.c:3523
+#, gcc-internal-format
+msgid "expression cannot be used as a function"
+msgstr ""
+
+#: cp/typeck.c:3572
+#, gcc-internal-format
+msgid "too many arguments to constructor %q#D"
+msgstr ""
+
+#: cp/typeck.c:3573
+#, gcc-internal-format
+msgid "too few arguments to constructor %q#D"
+msgstr ""
+
+#: cp/typeck.c:3578
+#, gcc-internal-format
+msgid "too many arguments to member function %q#D"
+msgstr ""
+
+#: cp/typeck.c:3579
+#, gcc-internal-format
+msgid "too few arguments to member function %q#D"
+msgstr ""
+
+#: cp/typeck.c:3585
+#, gcc-internal-format
+msgid "too many arguments to function %q#D"
+msgstr ""
+
+#: cp/typeck.c:3586
+#, gcc-internal-format
+msgid "too few arguments to function %q#D"
+msgstr ""
+
+#: cp/typeck.c:3596
+#, gcc-internal-format
+msgid "too many arguments to method %q#D"
+msgstr ""
+
+#: cp/typeck.c:3597
+#, gcc-internal-format
+msgid "too few arguments to method %q#D"
+msgstr ""
+
+#: cp/typeck.c:3600
+#, gcc-internal-format
+msgid "too many arguments to function"
+msgstr ""
+
+#: cp/typeck.c:3601
+#, gcc-internal-format
+msgid "too few arguments to function"
+msgstr ""
+
+#: cp/typeck.c:3680
+#, gcc-internal-format
+msgid "parameter %P of %qD has incomplete type %qT"
+msgstr ""
+
+#: cp/typeck.c:3683
+#, gcc-internal-format
+msgid "parameter %P has incomplete type %qT"
+msgstr ""
+
+#: cp/typeck.c:3990 cp/typeck.c:4001
+#, gcc-internal-format
+msgid "assuming cast to type %qT from overloaded function"
+msgstr ""
+
+#: cp/typeck.c:4047
+#, gcc-internal-format
+msgid "NULL used in arithmetic"
+msgstr ""
+
+#: cp/typeck.c:4358
+#, gcc-internal-format
+msgid "left rotate count is negative"
+msgstr ""
+
+#: cp/typeck.c:4359
+#, gcc-internal-format
+msgid "right rotate count is negative"
+msgstr ""
+
+#: cp/typeck.c:4365
+#, gcc-internal-format
+msgid "left rotate count >= width of type"
+msgstr ""
+
+#: cp/typeck.c:4366
+#, gcc-internal-format
+msgid "right rotate count >= width of type"
+msgstr ""
+
+#: cp/typeck.c:4387 cp/typeck.c:4642
+#, gcc-internal-format
+msgid "comparison with string literal results in unspecified behaviour"
+msgstr ""
+
+#: cp/typeck.c:4413 cp/typeck.c:4435
+#, gcc-internal-format
+msgid "the address of %qD will never be NULL"
+msgstr ""
+
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
+#, gcc-internal-format
+msgid "ISO C++ forbids comparison between pointer and integer"
+msgstr ""
+
+#: cp/typeck.c:4657 cp/typeck.c:4669
+#, gcc-internal-format
+msgid "operand types are %qT and %qT"
+msgstr ""
+
+#: cp/typeck.c:4681
+#, gcc-internal-format
+msgid "could not find an integer type of the same size as %qT"
+msgstr ""
+
+#: cp/typeck.c:4745
+#, gcc-internal-format
+msgid "unordered comparison on non-floating point argument"
+msgstr ""
+
+#: cp/typeck.c:4793
+#, gcc-internal-format
+msgid "invalid operands of types %qT and %qT to binary %qO"
+msgstr ""
+
+#: cp/typeck.c:5093
+#, gcc-internal-format
+msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
+msgstr ""
+
+#: cp/typeck.c:5101
+#, gcc-internal-format
+msgid "ISO C++ forbids using pointer to a function in subtraction"
+msgstr ""
+
+#: cp/typeck.c:5109
+#, gcc-internal-format
+msgid "ISO C++ forbids using pointer to a method in subtraction"
+msgstr ""
+
+#: cp/typeck.c:5128
+#, gcc-internal-format
+msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
+msgstr ""
+
+#: cp/typeck.c:5201
+#, gcc-internal-format
+msgid "taking address of constructor %qE"
+msgstr ""
+
+#: cp/typeck.c:5202
+#, gcc-internal-format
+msgid "taking address of destructor %qE"
+msgstr ""
+
+#: cp/typeck.c:5218
+#, gcc-internal-format
+msgid "invalid use of %qE to form a pointer-to-member-function"
+msgstr ""
+
+#: cp/typeck.c:5221
+#, gcc-internal-format
+msgid "  a qualified-id is required"
+msgstr ""
+
+#: cp/typeck.c:5228
+#, gcc-internal-format
+msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
+msgstr ""
+
+#. An expression like &memfn.
+#: cp/typeck.c:5380
+#, gcc-internal-format
+msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
+msgstr ""
+
+#: cp/typeck.c:5385
+#, gcc-internal-format
+msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
+msgstr ""
+
+#. Make this a permerror because we used to accept it.
+#: cp/typeck.c:5422
+#, gcc-internal-format
+msgid "taking address of temporary"
+msgstr ""
+
+#: cp/typeck.c:5424
+#, gcc-internal-format
+msgid "taking address of xvalue (rvalue reference)"
+msgstr ""
+
+#: cp/typeck.c:5441
+#, gcc-internal-format
+msgid "ISO C++ forbids taking address of function %<::main%>"
+msgstr ""
+
+#: cp/typeck.c:5496
+#, gcc-internal-format
+msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
+msgstr ""
+
+#: cp/typeck.c:5524
+#, gcc-internal-format
+msgid "cannot create pointer to reference member %qD"
+msgstr ""
+
+#: cp/typeck.c:5804
+#, gcc-internal-format
+msgid "ISO C++ forbids incrementing an enum"
+msgstr ""
+
+#: cp/typeck.c:5805
+#, gcc-internal-format
+msgid "ISO C++ forbids decrementing an enum"
+msgstr ""
+
+#: cp/typeck.c:5821
+#, gcc-internal-format
+msgid "cannot increment a pointer to incomplete type %qT"
+msgstr ""
+
+#: cp/typeck.c:5822
+#, gcc-internal-format
+msgid "cannot decrement a pointer to incomplete type %qT"
+msgstr ""
+
+#: cp/typeck.c:5833
+#, gcc-internal-format
+msgid "ISO C++ forbids incrementing a pointer of type %qT"
+msgstr ""
+
+#: cp/typeck.c:5834
+#, gcc-internal-format
+msgid "ISO C++ forbids decrementing a pointer of type %qT"
+msgstr ""
+
+#: cp/typeck.c:5869
+#, gcc-internal-format
+msgid "invalid use of Boolean expression as operand to %<operator--%>"
+msgstr ""
+
+#: cp/typeck.c:6031
+#, gcc-internal-format
+msgid "cannot take the address of %<this%>, which is an rvalue expression"
+msgstr ""
+
+#: cp/typeck.c:6053
+#, gcc-internal-format
+msgid "address of explicit register variable %qD requested"
+msgstr ""
+
+#: cp/typeck.c:6058
+#, gcc-internal-format
+msgid "address requested for %qD, which is declared %<register%>"
+msgstr ""
+
+#: cp/typeck.c:6141
+#, gcc-internal-format
+msgid "list-initializer for non-class type must not be parenthesized"
+msgstr ""
+
+#: cp/typeck.c:6153
+#, gcc-internal-format
+msgid "expression list treated as compound expression in initializer"
+msgstr ""
+
+#: cp/typeck.c:6157
+#, gcc-internal-format
+msgid "expression list treated as compound expression in mem-initializer"
+msgstr ""
+
+#: cp/typeck.c:6161
+#, gcc-internal-format
+msgid "expression list treated as compound expression in functional cast"
+msgstr ""
+
+#: cp/typeck.c:6198
+#, gcc-internal-format, gfc-internal-format
+msgid "%s expression list treated as compound expression"
+msgstr ""
+
+#: cp/typeck.c:6288
+#, gcc-internal-format
+msgid "no context to resolve type of %qE"
+msgstr ""
+
+#: cp/typeck.c:6321
+#, gcc-internal-format
+msgid "cast from type %qT to type %qT casts away qualifiers"
+msgstr ""
+
+#: cp/typeck.c:6327
+#, gcc-internal-format
+msgid "static_cast from type %qT to type %qT casts away qualifiers"
+msgstr ""
+
+#: cp/typeck.c:6333
+#, gcc-internal-format
+msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
+msgstr ""
+
+#: cp/typeck.c:6356
+#, gcc-internal-format
+msgid "useless cast to type %qT"
+msgstr ""
+
+#: cp/typeck.c:6723
+#, gcc-internal-format
+msgid "invalid static_cast from type %qT to type %qT"
+msgstr ""
+
+#: cp/typeck.c:6749
+#, gcc-internal-format
+msgid "converting from %qT to %qT"
+msgstr ""
+
+#: cp/typeck.c:6801
+#, gcc-internal-format
+msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgstr ""
+
+#: cp/typeck.c:6871
+#, gcc-internal-format
+msgid "cast from %qT to %qT loses precision"
+msgstr ""
+
+#: cp/typeck.c:6911
+#, gcc-internal-format
+msgid "cast from %qT to %qT increases required alignment of target type"
+msgstr ""
+
+#: cp/typeck.c:6929
+#, gcc-internal-format
+msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
+msgstr ""
+
+#: cp/typeck.c:6943
+#, gcc-internal-format
+msgid "invalid cast from type %qT to type %qT"
+msgstr ""
+
+#: cp/typeck.c:7004
+#, gcc-internal-format
+msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
+msgstr ""
+
+#: cp/typeck.c:7013
+#, gcc-internal-format
+msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
+msgstr ""
+
+#: cp/typeck.c:7053
+#, gcc-internal-format
+msgid "invalid const_cast of an rvalue of type %qT to type %qT"
+msgstr ""
+
+#: cp/typeck.c:7114
+#, gcc-internal-format
+msgid "invalid const_cast from type %qT to type %qT"
+msgstr ""
+
+#: cp/typeck.c:7195 cp/typeck.c:7203
+#, gcc-internal-format
+msgid "ISO C++ forbids casting to an array type %qT"
+msgstr ""
+
+#: cp/typeck.c:7212
+#, gcc-internal-format
+msgid "invalid cast to function type %qT"
+msgstr ""
+
+#: cp/typeck.c:7493
+#, gcc-internal-format
+msgid "  in evaluation of %<%Q(%#T, %#T)%>"
+msgstr ""
+
+#: cp/typeck.c:7554
+#, gcc-internal-format
+msgid "assigning to an array from an initializer list"
+msgstr ""
+
+#: cp/typeck.c:7580
+#, gcc-internal-format
+msgid "incompatible types in assignment of %qT to %qT"
+msgstr ""
+
+#: cp/typeck.c:7594
+#, gcc-internal-format
+msgid "array used as initializer"
+msgstr ""
+
+#: cp/typeck.c:7596
+#, gcc-internal-format
+msgid "invalid array assignment"
+msgstr ""
+
+#: cp/typeck.c:7703
+#, gcc-internal-format
+msgid "   in pointer to member function conversion"
+msgstr ""
+
+#: cp/typeck.c:7717
+#, gcc-internal-format
+msgid "pointer to member conversion via virtual base %qT"
+msgstr ""
+
+#: cp/typeck.c:7764 cp/typeck.c:7783
+#, gcc-internal-format
+msgid "   in pointer to member conversion"
+msgstr ""
+
+#: cp/typeck.c:7865
+#, gcc-internal-format
+msgid "invalid conversion to type %qT from type %qT"
+msgstr ""
+
+#: cp/typeck.c:8147
+#, gcc-internal-format
+msgid "cannot convert %qT to %qT for argument %qP to %qD"
+msgstr ""
+
+#: cp/typeck.c:8153
+#, gcc-internal-format
+msgid "cannot convert %qT to %qT in default argument"
+msgstr ""
+
+#: cp/typeck.c:8157
+#, gcc-internal-format
+msgid "cannot convert %qT to %qT in argument passing"
+msgstr ""
+
+#: cp/typeck.c:8161
+#, gcc-internal-format
+msgid "cannot convert %qT to %qT"
+msgstr ""
+
+#: cp/typeck.c:8165
+#, gcc-internal-format
+msgid "cannot convert %qT to %qT in initialization"
+msgstr ""
+
+#: cp/typeck.c:8169
+#, gcc-internal-format
+msgid "cannot convert %qT to %qT in return"
+msgstr ""
+
+#: cp/typeck.c:8173
+#, gcc-internal-format
+msgid "cannot convert %qT to %qT in assignment"
+msgstr ""
+
+#: cp/typeck.c:8186
+#, gcc-internal-format
+msgid "class type %qT is incomplete"
+msgstr ""
+
+#: cp/typeck.c:8204
+#, gcc-internal-format
+msgid "parameter %qP of %qD might be a candidate for a format attribute"
+msgstr ""
+
+#: cp/typeck.c:8208
+#, gcc-internal-format
+msgid "parameter might be a candidate for a format attribute"
+msgstr ""
+
+#: cp/typeck.c:8213
+#, gcc-internal-format
+msgid "target of conversion might be a candidate for a format attribute"
+msgstr ""
+
+#: cp/typeck.c:8218
+#, gcc-internal-format
+msgid "target of initialization might be a candidate for a format attribute"
+msgstr ""
+
+#: cp/typeck.c:8228
+#, gcc-internal-format
+msgid "left-hand side of assignment might be a candidate for a format attribute"
+msgstr ""
+
+#: cp/typeck.c:8321
+#, gcc-internal-format
+msgid "in passing argument %P of %q+D"
+msgstr ""
+
+#: cp/typeck.c:8380
+#, gcc-internal-format
+msgid "returning reference to temporary"
+msgstr ""
+
+#: cp/typeck.c:8387
+#, gcc-internal-format
+msgid "reference to non-lvalue returned"
+msgstr ""
+
+#: cp/typeck.c:8400
+#, gcc-internal-format
+msgid "reference to local variable %q+D returned"
+msgstr ""
+
+#: cp/typeck.c:8403
+#, gcc-internal-format
+msgid "address of label %q+D returned"
+msgstr ""
+
+#: cp/typeck.c:8406
+#, gcc-internal-format
+msgid "address of local variable %q+D returned"
+msgstr ""
+
+#: cp/typeck.c:8452
+#, gcc-internal-format
+msgid "returning a value from a destructor"
+msgstr ""
+
+#. If a return statement appears in a handler of the
+#. function-try-block of a constructor, the program is ill-formed.
+#: cp/typeck.c:8460
+#, gcc-internal-format
+msgid "cannot return from a handler of a function-try-block of a constructor"
+msgstr ""
+
+#. You can't return a value from a constructor.
+#: cp/typeck.c:8463
+#, gcc-internal-format
+msgid "returning a value from a constructor"
+msgstr ""
+
+#. Give a helpful error message.
+#: cp/typeck.c:8486 cp/typeck.c:8530
+#, gcc-internal-format
+msgid "return-statement with no value, in function returning %qT"
+msgstr ""
+
+#: cp/typeck.c:8494
+#, gcc-internal-format
+msgid "returning initializer list"
+msgstr ""
+
+#: cp/typeck.c:8549
+#, gcc-internal-format
+msgid "return-statement with a value, in function returning 'void'"
+msgstr ""
+
+#: cp/typeck.c:8579
+#, gcc-internal-format
+msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
+msgstr ""
+
+#. Make this a permerror because we used to accept it.
+#: cp/typeck.c:9191
+#, gcc-internal-format
+msgid "using temporary as lvalue"
+msgstr ""
+
+#: cp/typeck.c:9193
+#, gcc-internal-format
+msgid "using xvalue (rvalue reference) as lvalue"
+msgstr ""
+
+#: cp/typeck2.c:62
+#, gcc-internal-format
+msgid "type %qT is not a base type for type %qT"
+msgstr ""
+
+#: cp/typeck2.c:117
+#, gcc-internal-format
+msgid "assignment of constant field %qD"
+msgstr ""
+
+#: cp/typeck2.c:119
+#, gcc-internal-format
+msgid "constant field %qD used as %<asm%> output"
+msgstr ""
+
+#: cp/typeck2.c:121
+#, gcc-internal-format
+msgid "increment of constant field %qD"
+msgstr ""
+
+#: cp/typeck2.c:123
+#, gcc-internal-format
+msgid "decrement of constant field %qD"
+msgstr ""
+
+#: cp/typeck2.c:130
+#, gcc-internal-format
+msgid "assignment of read-only reference %qD"
+msgstr ""
+
+#: cp/typeck2.c:132
+#, gcc-internal-format
+msgid "read-only reference %qD used as %<asm%> output"
+msgstr ""
+
+#: cp/typeck2.c:134
+#, gcc-internal-format
+msgid "increment of read-only reference %qD"
+msgstr ""
+
+#: cp/typeck2.c:136
+#, gcc-internal-format
+msgid "decrement of read-only reference %qD"
+msgstr ""
+
+#: cp/typeck2.c:334
+#, gcc-internal-format
+msgid "cannot declare variable %q+D to be of abstract type %qT"
+msgstr ""
+
+#: cp/typeck2.c:339
+#, gcc-internal-format
+msgid "cannot declare parameter %q+D to be of abstract type %qT"
+msgstr ""
+
+#: cp/typeck2.c:342
+#, gcc-internal-format
+msgid "cannot declare parameter to be of abstract type %qT"
+msgstr ""
+
+#: cp/typeck2.c:346
+#, gcc-internal-format
+msgid "cannot declare field %q+D to be of abstract type %qT"
+msgstr ""
+
+#: cp/typeck2.c:350
+#, gcc-internal-format
+msgid "invalid abstract return type for member function %q+#D"
+msgstr ""
+
+#: cp/typeck2.c:352
+#, gcc-internal-format
+msgid "invalid abstract return type for function %q+#D"
+msgstr ""
+
+#. Here we do not have location information.
+#: cp/typeck2.c:355
+#, gcc-internal-format
+msgid "invalid abstract type %qT for %qE"
+msgstr ""
+
+#: cp/typeck2.c:357
+#, gcc-internal-format
+msgid "invalid abstract type for %q+D"
+msgstr ""
+
+#: cp/typeck2.c:362
+#, gcc-internal-format
+msgid "creating array of %qT, which is an abstract class type"
+msgstr ""
+
+#: cp/typeck2.c:365
+#, gcc-internal-format
+msgid "invalid cast to abstract class type %qT"
+msgstr ""
+
+#: cp/typeck2.c:368
+#, gcc-internal-format
+msgid "invalid new-expression of abstract class type %qT"
+msgstr ""
+
+#: cp/typeck2.c:371
+#, gcc-internal-format
+msgid "invalid abstract return type %qT"
+msgstr ""
+
+#: cp/typeck2.c:374
+#, gcc-internal-format
+msgid "invalid abstract parameter type %qT"
+msgstr ""
+
+#: cp/typeck2.c:377
+#, gcc-internal-format
+msgid "expression of abstract class type %qT cannot be used in throw-expression"
+msgstr ""
+
+#: cp/typeck2.c:381
+#, gcc-internal-format
+msgid "cannot declare catch parameter to be of abstract class type %qT"
+msgstr ""
+
+#: cp/typeck2.c:385
+#, gcc-internal-format
+msgid "cannot allocate an object of abstract type %qT"
+msgstr ""
+
+#: cp/typeck2.c:395
+#, gcc-internal-format
+msgid "  because the following virtual functions are pure within %qT:"
+msgstr ""
+
+#: cp/typeck2.c:401
+#, gcc-internal-format
+msgid "\t%+#D"
+msgstr "\t%+#D"
+
+#: cp/typeck2.c:454
+#, gcc-internal-format
+msgid "definition of %q#T is not complete until the closing brace"
+msgstr ""
+
+#: cp/typeck2.c:457
+#, gcc-internal-format
+msgid "forward declaration of %q#T"
+msgstr ""
+
+#: cp/typeck2.c:459
+#, gcc-internal-format
+msgid "declaration of %q#T"
+msgstr ""
+
+#: cp/typeck2.c:486
+#, gcc-internal-format
+msgid "%q+D has incomplete type"
+msgstr ""
+
+#: cp/typeck2.c:499
+#, gcc-internal-format
+msgid "invalid use of incomplete type %q#T"
+msgstr ""
+
+#: cp/typeck2.c:507
+#, gcc-internal-format
+msgid "invalid use of %qT"
+msgstr ""
+
+#: cp/typeck2.c:529
+#, gcc-internal-format
+msgid "invalid use of member function (did you forget the %<()%> ?)"
+msgstr ""
+
+#: cp/typeck2.c:533
+#, gcc-internal-format
+msgid "invalid use of member (did you forget the %<&%> ?)"
+msgstr ""
+
+#: cp/typeck2.c:544
+#, gcc-internal-format
+msgid "invalid use of template type parameter %qT"
+msgstr ""
+
+#: cp/typeck2.c:549
+#, gcc-internal-format
+msgid "invalid use of template template parameter %qT"
+msgstr ""
+
+#: cp/typeck2.c:555
+#, gcc-internal-format
+msgid "invalid use of dependent type %qT"
+msgstr ""
+
+#: cp/typeck2.c:562
+#, gcc-internal-format
+msgid "invalid use of brace-enclosed initializer list"
+msgstr ""
+
+#: cp/typeck2.c:570
+#, gcc-internal-format
+msgid "address of overloaded function with no contextual type information"
+msgstr ""
+
+#: cp/typeck2.c:574
+#, gcc-internal-format
+msgid "overloaded function with no contextual type information"
+msgstr ""
+
+#: cp/typeck2.c:577
+#, gcc-internal-format
+msgid "insufficient contextual information to determine type"
+msgstr ""
+
+#: cp/typeck2.c:801
+#, gcc-internal-format
+msgid "constructor syntax used, but no constructor declared for type %qT"
+msgstr ""
+
+#: cp/typeck2.c:947
+#, gcc-internal-format
+msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
+msgstr ""
+
+#: cp/typeck2.c:954 cp/typeck2.c:964
+#, gcc-internal-format
+msgid "narrowing conversion of %qE from %qT to %qT inside { }"
+msgstr ""
+
+#: cp/typeck2.c:1033
+#, gcc-internal-format
+msgid "int-array initialized from non-wide string"
+msgstr ""
+
+#: cp/typeck2.c:1039
+#, gcc-internal-format
+msgid "int-array initialized from incompatible wide string"
+msgstr ""
+
+#: cp/typeck2.c:1059
+#, gcc-internal-format
+msgid "initializer-string for array of chars is too long"
+msgstr ""
+
+#: cp/typeck2.c:1120
+#, gcc-internal-format
+msgid "cannot initialize aggregate of type %qT with a compound literal"
+msgstr ""
+
+#: cp/typeck2.c:1138
+#, gcc-internal-format
+msgid "array must be initialized with a brace-enclosed initializer"
+msgstr ""
+
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
+#, gcc-internal-format
+msgid "missing initializer for member %qD"
+msgstr ""
+
+#: cp/typeck2.c:1428
+#, gcc-internal-format
+msgid "member %qD is uninitialized reference"
+msgstr ""
+
+#: cp/typeck2.c:1435
+#, gcc-internal-format
+msgid "member %qD with uninitialized reference fields"
+msgstr ""
+
+#: cp/typeck2.c:1521
+#, gcc-internal-format
+msgid "no field %qD found in union being initialized"
+msgstr ""
+
+#: cp/typeck2.c:1532
+#, gcc-internal-format
+msgid "index value instead of field name in union initializer"
+msgstr ""
+
+#: cp/typeck2.c:1714
+#, gcc-internal-format
+msgid "circular pointer delegation detected"
+msgstr ""
+
+#: cp/typeck2.c:1728
+#, gcc-internal-format
+msgid "base operand of %<->%> has non-pointer type %qT"
+msgstr ""
+
+#: cp/typeck2.c:1754
+#, gcc-internal-format
+msgid "result of %<operator->()%> yields non-pointer result"
+msgstr ""
+
+#: cp/typeck2.c:1756
+#, gcc-internal-format
+msgid "base operand of %<->%> is not a pointer"
+msgstr ""
+
+#: cp/typeck2.c:1783
+#, gcc-internal-format
+msgid "%qE cannot be used as a member pointer, since it is of type %qT"
+msgstr ""
+
+#: cp/typeck2.c:1792
+#, gcc-internal-format
+msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
+msgstr ""
+
+#: cp/typeck2.c:1814
+#, gcc-internal-format
+msgid "pointer to member type %qT incompatible with object type %qT"
+msgstr ""
+
+#: cp/typeck2.c:1873
+#, gcc-internal-format
+msgid "pointer-to-member-function type %qT requires an rvalue"
+msgstr ""
+
+#: cp/typeck2.c:1880
+#, gcc-internal-format
+msgid "pointer-to-member-function type %qT requires an lvalue"
+msgstr ""
+
+#: cp/typeck2.c:1921
+#, gcc-internal-format
+msgid "functional cast to array type %qT"
+msgstr ""
+
+#: cp/typeck2.c:1942
+#, gcc-internal-format
+msgid "invalid value-initialization of reference type"
+msgstr ""
+
+#: cp/typeck2.c:2168
+#, gcc-internal-format
+msgid "call to function %qD which throws incomplete type %q#T"
+msgstr ""
+
+#: cp/typeck2.c:2171
+#, gcc-internal-format
+msgid "call to function which throws incomplete type %q#T"
+msgstr ""
+
+#: cp/vtable-class-hierarchy.c:731
+#, gcc-internal-format
+msgid "unable to open log file %<vtv_class_set_sizes.log%>: %m"
+msgstr ""
+
+#: cp/vtable-class-hierarchy.c:871
+#, gcc-internal-format
+msgid "unable to open log file %<vtv_set_ptr_data.log%>: %m"
+msgstr ""
+
+#: cp/vtable-class-hierarchy.c:1121
+#, gcc-internal-format
+msgid "unable to open log file %<vtv_count_data.log%>: %m"
+msgstr ""
+
+#: fortran/arith.c:45
+#, gcc-internal-format, gfc-internal-format
+msgid "Conversion of an Infinity or Not-a-Number at %L to INTEGER"
+msgstr ""
+
+#: fortran/arith.c:117 fortran/arith.c:1945
+#, gcc-internal-format
+msgid "gfc_arith_error(): Bad error code"
+msgstr ""
+
+#: fortran/arith.c:150
+#, gcc-internal-format
+msgid "Fix min_int calculation"
+msgstr ""
+
+#: fortran/arith.c:530
+#, gcc-internal-format
+msgid "gfc_range_check(): Bad type"
+msgstr ""
+
+#: fortran/arith.c:603
+#, gcc-internal-format
+msgid "gfc_arith_uminus(): Bad basic type"
+msgstr ""
+
+#: fortran/arith.c:637
+#, gcc-internal-format
+msgid "gfc_arith_plus(): Bad basic type"
+msgstr ""
+
+#: fortran/arith.c:671
+#, gcc-internal-format
+msgid "gfc_arith_minus(): Bad basic type"
+msgstr ""
+
+#: fortran/arith.c:706
+#, gcc-internal-format
+msgid "gfc_arith_times(): Bad basic type"
+msgstr ""
+
+#: fortran/arith.c:771
+#, gcc-internal-format
+msgid "gfc_arith_divide(): Bad basic type"
+msgstr ""
+
+#: fortran/arith.c:817
+#, gcc-internal-format
+msgid "arith_power(): Bad base"
+msgstr ""
+
+#: fortran/arith.c:904 fortran/arith.c:929
+#, gcc-internal-format, gfc-internal-format
+msgid "Noninteger exponent in an initialization expression at %L"
+msgstr ""
+
+#: fortran/arith.c:915
+#, gcc-internal-format, gfc-internal-format
+msgid "Raising a negative REAL at %L to a REAL power is prohibited"
+msgstr ""
+
+#: fortran/arith.c:943
+#, gcc-internal-format
+msgid "arith_power(): unknown type"
+msgstr ""
+
+#: fortran/arith.c:1009
+#, gcc-internal-format
+msgid "compare_real(): Bad operator"
+msgstr ""
+
+#: fortran/arith.c:1044
+#, gcc-internal-format
+msgid "gfc_compare_expr(): Bad basic type"
+msgstr ""
+
+#: fortran/arith.c:1555
+#, gcc-internal-format
+msgid "eval_intrinsic(): Bad operator"
+msgstr ""
+
+#: fortran/arith.c:1604
+#, gcc-internal-format
+msgid "eval_type_intrinsic0(): op NULL"
+msgstr ""
+
+#: fortran/arith.c:1913
+#, gcc-internal-format, gfc-internal-format
+msgid "Arithmetic OK converting %s to %s at %L"
+msgstr ""
+
+#: fortran/arith.c:1917
+#, gcc-internal-format
+msgid "Arithmetic overflow converting %s to %s at %L. This check can be disabled with the option %<-fno-range-check%>"
+msgstr ""
+
+#: fortran/arith.c:1922
+#, gcc-internal-format
+msgid "Arithmetic underflow converting %s to %s at %L. This check can be disabled with the option %<-fno-range-check%>"
+msgstr ""
+
+#: fortran/arith.c:1927
+#, gcc-internal-format
+msgid "Arithmetic NaN converting %s to %s at %L. This check can be disabled with the option %<-fno-range-check%>"
+msgstr ""
+
+#: fortran/arith.c:1932
+#, gcc-internal-format, gfc-internal-format
+msgid "Division by zero converting %s to %s at %L"
+msgstr ""
+
+#: fortran/arith.c:1936
+#, gcc-internal-format, gfc-internal-format
+msgid "Array operands are incommensurate converting %s to %s at %L"
+msgstr ""
+
+#: fortran/arith.c:1940
+#, gcc-internal-format, gfc-internal-format
+msgid "Integer outside symmetric range implied by Standard Fortran converting %s to %s at %L"
+msgstr ""
+
+#: fortran/arith.c:2284
+#, gcc-internal-format
+msgid "The Hollerith constant at %L is too long to convert to %qs"
+msgstr ""
+
+#: fortran/array.c:95
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected array subscript at %C"
+msgstr ""
+
+#: fortran/array.c:104
+#, gcc-internal-format
+msgid "Unexpected %<*%> in coarray subscript at %C"
+msgstr ""
+
+#: fortran/array.c:128
+#, gcc-internal-format, gfc-internal-format
+msgid "Strides not allowed in coarray subscript at %C"
+msgstr ""
+
+#: fortran/array.c:136
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected array subscript stride at %C"
+msgstr ""
+
+#: fortran/array.c:193
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid form of array reference at %C"
+msgstr ""
+
+#: fortran/array.c:198 fortran/array.c:271
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference at %C cannot have more than %d dimensions"
+msgstr ""
+
+#: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
+#: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
+#, gcc-internal-format
+msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
+msgstr ""
+
+#: fortran/array.c:219
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected coarray designator at %C"
+msgstr ""
+
+#: fortran/array.c:234
+#, gcc-internal-format, gfc-internal-format
+msgid "Too few codimensions at %C, expected %d not %d"
+msgstr ""
+
+#: fortran/array.c:240
+#, gcc-internal-format, gfc-internal-format
+msgid "Too many codimensions at %C, expected %d not %d"
+msgstr ""
+
+#: fortran/array.c:250 fortran/array.c:258
+#, gcc-internal-format
+msgid "Unexpected %<*%> for codimension %d of %d at %C"
+msgstr ""
+
+#: fortran/array.c:253
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid form of coarray reference at %C"
+msgstr ""
+
+#: fortran/array.c:265
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid codimension %d at %C, only %d codimensions exist"
+msgstr ""
+
+#: fortran/array.c:317
+#, gcc-internal-format
+msgid "Variable %qs at %L in this context must be constant"
+msgstr ""
+
+#: fortran/array.c:320
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression at %L in this context must be constant"
+msgstr ""
+
+#: fortran/array.c:413
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected expression in array specification at %C"
+msgstr ""
+
+#: fortran/array.c:471
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank array at %C"
+msgstr ""
+
+#: fortran/array.c:505
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad array specification for implied-shape array at %C"
+msgstr ""
+
+#: fortran/array.c:521 fortran/array.c:634
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad array specification for an explicitly shaped array at %C"
+msgstr ""
+
+#: fortran/array.c:531 fortran/array.c:644
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad array specification for assumed shape array at %C"
+msgstr ""
+
+#: fortran/array.c:545 fortran/array.c:658
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad specification for deferred shape array at %C"
+msgstr ""
+
+#: fortran/array.c:555 fortran/array.c:662
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad specification for assumed size array at %C"
+msgstr ""
+
+#: fortran/array.c:567 fortran/array.c:674
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected another dimension in array declaration at %C"
+msgstr ""
+
+#: fortran/array.c:573 fortran/array.c:602 fortran/array.c:680
+#, gcc-internal-format, gfc-internal-format
+msgid "Array specification at %C has more than %d dimensions"
+msgstr ""
+
+#: fortran/array.c:579
+#, gcc-internal-format, gfc-internal-format
+msgid "Array specification at %C with more than 7 dimensions"
+msgstr ""
+
+#: fortran/array.c:591
+#, gcc-internal-format, gfc-internal-format
+msgid "Coarray declaration at %C"
+msgstr ""
+
+#: fortran/array.c:688
+#, gcc-internal-format
+msgid "Upper bound of last coarray dimension must be %<*%> at %C"
+msgstr ""
+
+#: fortran/array.c:756
+#, gcc-internal-format
+msgid "The assumed-rank array %qs at %L shall not have a codimension"
+msgstr ""
+
+#: fortran/array.c:840
+#, gcc-internal-format
+msgid "gfc_compare_array_spec(): Array spec clobbered"
+msgstr ""
+
+#: fortran/array.c:916
+#, gcc-internal-format
+msgid "DO-iterator %qs at %L is inside iterator of the same name"
+msgstr ""
+
+#: fortran/array.c:1008 fortran/array.c:1152
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in array constructor at %C"
+msgstr ""
+
+#: fortran/array.c:1061
+#, gcc-internal-format, gfc-internal-format
+msgid "[...] style array constructors at %C"
+msgstr ""
+
+#: fortran/array.c:1083
+#, gcc-internal-format, gfc-internal-format
+msgid "Array constructor including type specification at %C"
+msgstr ""
+
+#: fortran/array.c:1092 fortran/match.c:3407
+#, gcc-internal-format, gfc-internal-format
+msgid "Type-spec at %L cannot contain a deferred type parameter"
+msgstr ""
+
+#: fortran/array.c:1114
+#, gcc-internal-format, gfc-internal-format
+msgid "Empty array constructor at %C is not allowed"
+msgstr ""
+
+#: fortran/array.c:1199
+#, gcc-internal-format, gfc-internal-format
+msgid "Element in %s array constructor at %L is %s"
+msgstr ""
+
+#: fortran/array.c:1530
+#, gcc-internal-format, gfc-internal-format
+msgid "Iterator step at %L cannot be zero"
+msgstr ""
+
+#: fortran/array.c:1667
+#, gcc-internal-format
+msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
+msgstr ""
+
+#: fortran/array.c:1837
+#, gcc-internal-format, gfc-internal-format
+msgid "AC-IMPLIED-DO initial expression references control variable at %L"
+msgstr ""
+
+#: fortran/array.c:1844
+#, gcc-internal-format, gfc-internal-format
+msgid "AC-IMPLIED-DO final expression references control variable at %L"
+msgstr ""
+
+#: fortran/array.c:1851
+#, gcc-internal-format, gfc-internal-format
+msgid "AC-IMPLIED-DO step expression references control variable at %L"
+msgstr ""
+
+#: fortran/array.c:1863
+#, gcc-internal-format, gfc-internal-format
+msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
+msgstr ""
+
+#: fortran/array.c:1946
+#, gcc-internal-format, gfc-internal-format
+msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
+msgstr ""
+
+#: fortran/array.c:2064
+#, gcc-internal-format
+msgid "spec_dimen_size(): Bad dimension"
+msgstr ""
+
+#: fortran/array.c:2122
+#, gcc-internal-format
+msgid "gfc_ref_dimen_size(): Bad dimension"
+msgstr ""
+
+#: fortran/array.c:2250
+#, gcc-internal-format
+msgid "gfc_ref_dimen_size(): Bad dimen_type"
+msgstr ""
+
+#: fortran/array.c:2301
+#, gcc-internal-format
+msgid "gfc_array_dimen_size(): Bad dimension"
+msgstr ""
+
+#: fortran/array.c:2346
+#, gcc-internal-format
+msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
+msgstr ""
+
+#: fortran/array.c:2490
+#, gcc-internal-format
+msgid "gfc_find_array_ref(): No ref found"
+msgstr ""
+
+#. if (c == 0)
+#: fortran/bbt.c:119
+#, gcc-internal-format
+msgid "insert_bbt(): Duplicate key found!"
+msgstr ""
+
+#: fortran/check.c:46
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a scalar"
+msgstr ""
+
+#: fortran/check.c:62
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be %s"
+msgstr ""
+
+#: fortran/check.c:89
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a numeric type"
+msgstr ""
+
+#: fortran/check.c:104
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL"
+msgstr ""
+
+#: fortran/check.c:121
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be REAL or COMPLEX"
+msgstr ""
+
+#: fortran/check.c:138
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
+msgstr ""
+
+#: fortran/check.c:167 fortran/check.c:6252
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a constant"
+msgstr ""
+
+#: fortran/check.c:176
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid kind for %s at %L"
+msgstr ""
+
+#: fortran/check.c:195
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be double precision"
+msgstr ""
+
+#: fortran/check.c:218
+#, gcc-internal-format
+msgid "Expected coarray variable as %qs argument to the %s intrinsic at %L"
+msgstr ""
+
+#: fortran/check.c:235
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a logical array"
+msgstr ""
+
+#: fortran/check.c:261
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be an array"
+msgstr ""
+
+#: fortran/check.c:282
+#, gcc-internal-format
+msgid "%qs at %L must be nonnegative"
+msgstr ""
+
+#: fortran/check.c:313
+#, gcc-internal-format
+msgid "The absolute value of SHIFT at %L must be less than or equal to BIT_SIZE(%qs)"
+msgstr ""
+
+#: fortran/check.c:324
+#, gcc-internal-format
+msgid "%qs at %L must be less than or equal to BIT_SIZE(%qs)"
+msgstr ""
+
+#: fortran/check.c:334
+#, gcc-internal-format
+msgid "%qs at %L must be less than BIT_SIZE(%qs)"
+msgstr ""
+
+#: fortran/check.c:361
+#, gcc-internal-format
+msgid "%qs at %L must be less than or equal to the BIT_SIZE of INTEGER(KIND=%d)"
+msgstr ""
+
+#: fortran/check.c:387
+#, gcc-internal-format
+msgid "%<%s + %s%> at %L must be less than or equal to BIT_SIZE(%qs)"
+msgstr ""
+
+#: fortran/check.c:405
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be the same type and kind as %qs"
+msgstr ""
+
+#: fortran/check.c:422
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of rank %d"
+msgstr ""
+
+#: fortran/check.c:437
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must not be OPTIONAL"
+msgstr ""
+
+#: fortran/check.c:458
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be ALLOCATABLE"
+msgstr ""
+
+#: fortran/check.c:476
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of kind %d"
+msgstr ""
+
+#: fortran/check.c:514
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L cannot be INTENT(IN)"
+msgstr ""
+
+#: fortran/check.c:535
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a variable"
+msgstr ""
+
+#: fortran/check.c:584
+#, gcc-internal-format
+msgid "%<dim%> argument of %qs intrinsic at %L is not a valid codimension index"
+msgstr ""
+
+#: fortran/check.c:634
+#, gcc-internal-format
+msgid "%<dim%> argument of %qs intrinsic at %L is not a valid dimension index"
+msgstr ""
+
+#: fortran/check.c:737
+#, gcc-internal-format, gfc-internal-format
+msgid "Unequal character lengths (%ld/%ld) in %s at %L"
+msgstr ""
+
+#: fortran/check.c:859 fortran/check.c:6196
+#, gcc-internal-format
+msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
+msgstr ""
+
+#: fortran/check.c:868 fortran/check.c:2218 fortran/check.c:2344
+#: fortran/check.c:2418 fortran/check.c:2845
+#, gcc-internal-format, gfc-internal-format
+msgid "Different type kinds at %L"
+msgstr ""
+
+#: fortran/check.c:904
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
+msgstr ""
+
+#: fortran/check.c:913 fortran/check.c:949 fortran/check.c:3363
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
+msgstr ""
+
+#: fortran/check.c:931
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
+msgstr ""
+
+#: fortran/check.c:940
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
+msgstr ""
+
+#: fortran/check.c:965
+#, gcc-internal-format, gfc-internal-format
+msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
+msgstr ""
+
+#: fortran/check.c:976
+#, gcc-internal-format
+msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
+msgstr ""
+
+#: fortran/check.c:1019
+#, gcc-internal-format, gfc-internal-format
+msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
+msgstr ""
+
+#: fortran/check.c:1027
+#, gcc-internal-format, gfc-internal-format
+msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
+msgstr ""
+
+#: fortran/check.c:1034
+#, gcc-internal-format, gfc-internal-format
+msgid "'%s' argument of '%s' intrinsic at %L shall have the same type as '%s' at %L"
+msgstr ""
+
+#: fortran/check.c:1052
+#, gcc-internal-format, gfc-internal-format
+msgid "STAT= argument to %s at %L"
+msgstr ""
+
+#: fortran/check.c:1071 fortran/check.c:1137 fortran/check.c:1181
+#, gcc-internal-format, gfc-internal-format
+msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
+msgstr ""
+
+#: fortran/check.c:1085 fortran/check.c:1164
+#, gcc-internal-format, gfc-internal-format
+msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
+msgstr ""
+
+#: fortran/check.c:1105
+#, gcc-internal-format, gfc-internal-format
+msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
+msgstr ""
+
+#: fortran/check.c:1144 fortran/check.c:1188
+#, gcc-internal-format, gfc-internal-format
+msgid "OLD argument of the %s intrinsic function at %L shall be definable"
+msgstr ""
+
+#: fortran/check.c:1208
+#, gcc-internal-format, gfc-internal-format
+msgid "Negative argument N at %L"
+msgstr ""
+
+#: fortran/check.c:1380 fortran/check.c:1837
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
+msgstr ""
+
+#: fortran/check.c:1389 fortran/check.c:1846
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
+msgstr ""
+
+#: fortran/check.c:1403 fortran/check.c:1409
+#, gcc-internal-format, gfc-internal-format
+msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
+msgstr ""
+
+#: fortran/check.c:1431
+#, gcc-internal-format
+msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
+msgstr ""
+
+#: fortran/check.c:1439
+#, gcc-internal-format, gfc-internal-format
+msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
+msgstr ""
+
+#: fortran/check.c:1462
+#, gcc-internal-format, gfc-internal-format
+msgid "The stat= argument at %L must be a kind=4 integer variable"
+msgstr ""
+
+#: fortran/check.c:1478
+#, gcc-internal-format, gfc-internal-format
+msgid "The errmsg= argument at %L must be a default-kind character variable"
+msgstr ""
+
+#: fortran/check.c:1486
+#, gcc-internal-format
+msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
+msgstr ""
+
+#: fortran/check.c:1501
+#, gcc-internal-format, gfc-internal-format
+msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
+msgstr ""
+
+#: fortran/check.c:1520
+#, gcc-internal-format, gfc-internal-format
+msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
+msgstr ""
+
+#: fortran/check.c:1527
+#, gcc-internal-format, gfc-internal-format
+msgid "Support for the A argument at %L with allocatable components is not yet implemented"
+msgstr ""
+
+#: fortran/check.c:1541
+#, gcc-internal-format, gfc-internal-format
+msgid "OPERATOR argument at %L must be a PURE function"
+msgstr ""
+
+#. None of the intrinsics fulfills the criteria of taking two arguments,
+#. returning the same type and kind as the arguments and being permitted
+#. as actual argument.
+#: fortran/check.c:1551
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
+msgstr ""
+
+#: fortran/check.c:1568
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATOR at %L shall have two arguments"
+msgstr ""
+
+#: fortran/check.c:1578
+#, gcc-internal-format, gfc-internal-format
+msgid "A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
+msgstr ""
+
+#: fortran/check.c:1587
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
+msgstr ""
+
+#: fortran/check.c:1598
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
+msgstr ""
+
+#: fortran/check.c:1606
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
+msgstr ""
+
+#: fortran/check.c:1613
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
+msgstr ""
+
+#: fortran/check.c:1620
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
+msgstr ""
+
+#: fortran/check.c:1628
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
+msgstr ""
+
+#: fortran/check.c:1658
+#, gcc-internal-format, gfc-internal-format
+msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
+msgstr ""
+
+#: fortran/check.c:1665
+#, gcc-internal-format, gfc-internal-format
+msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
+msgstr ""
+
+#: fortran/check.c:1683
+#, gcc-internal-format, gfc-internal-format
+msgid "'%s' argument of '%s' intrinsic at %L shall be of type integer, real or character"
+msgstr ""
+
+#: fortran/check.c:1731 fortran/check.c:2263 fortran/check.c:2366
+#: fortran/check.c:2567 fortran/check.c:2612 fortran/check.c:3893
+#: fortran/check.c:4027 fortran/check.c:4082 fortran/check.c:5124
+#: fortran/check.c:5253
+#, gcc-internal-format
+msgid "%qs intrinsic with KIND argument at %L"
+msgstr ""
+
+#: fortran/check.c:1778 fortran/check.c:2029
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
+msgstr ""
+
+#: fortran/check.c:1793 fortran/check.c:2044 fortran/check.c:2072
+#, gcc-internal-format
+msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
+msgstr ""
+
+#: fortran/check.c:1896 fortran/check.c:2939 fortran/check.c:2947
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
+msgstr ""
+
+#: fortran/check.c:1910
+#, gcc-internal-format
+msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
+msgstr ""
+
+#: fortran/check.c:1930 fortran/check.c:1938
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be default real"
+msgstr ""
+
+#: fortran/check.c:1959
+#, gcc-internal-format, gfc-internal-format
+msgid "'I' at %L and 'J' at %L cannot both be BOZ literal constants"
+msgstr ""
+
+#: fortran/check.c:2090
+#, gcc-internal-format, gfc-internal-format
+msgid "non-default INTEGER kind argument to %s intrinsic at %L"
+msgstr ""
+
+#: fortran/check.c:2150
+#, gcc-internal-format
+msgid "COMPLEX argument %qs of %qs intrinsic at %L"
+msgstr ""
+
+#: fortran/check.c:2314
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of %s at %L must be of length one"
+msgstr ""
+
+#: fortran/check.c:2373
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
+msgstr ""
+
+#: fortran/check.c:2463
+#, gcc-internal-format, gfc-internal-format
+msgid "SIZE at %L must be positive"
+msgstr ""
+
+#: fortran/check.c:2475
+#, gcc-internal-format, gfc-internal-format
+msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
+msgstr ""
+
+#: fortran/check.c:2536
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
+msgstr ""
+
+#: fortran/check.c:2543
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a data entity"
+msgstr ""
+
+#: fortran/check.c:2754
+#, gcc-internal-format
+msgid "Intrinsic %qs at %L must have at least two arguments"
+msgstr ""
+
+#: fortran/check.c:2802
+#, gcc-internal-format
+msgid "Missing %qs argument to the %s intrinsic at %L"
+msgstr ""
+
+#: fortran/check.c:2817
+#, gcc-internal-format
+msgid "Duplicate argument %qs at %L to intrinsic %s"
+msgstr ""
+
+#: fortran/check.c:2822
+#, gcc-internal-format
+msgid "Unknown argument %qs at %L to intrinsic %s"
+msgstr ""
+
+#: fortran/check.c:2851
+#, gcc-internal-format
+msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
+msgstr ""
+
+#: fortran/check.c:2882
+#, gcc-internal-format
+msgid "%qs intrinsic with CHARACTER argument at %L"
+msgstr ""
+
+#: fortran/check.c:2889
+#, gcc-internal-format
+msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
+msgstr ""
+
+#: fortran/check.c:2956
+#, gcc-internal-format
+msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
+msgstr ""
+
+#: fortran/check.c:2970
+#, gcc-internal-format
+msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
+msgstr ""
+
+#: fortran/check.c:2989
+#, gcc-internal-format
+msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
+msgstr ""
+
+#: fortran/check.c:2998
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
+msgstr ""
+
+#: fortran/check.c:3173
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
+msgstr ""
+
+#: fortran/check.c:3233
+#, gcc-internal-format, gfc-internal-format
+msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
+msgstr ""
+
+#: fortran/check.c:3244
+#, gcc-internal-format, gfc-internal-format
+msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
+msgstr ""
+
+#: fortran/check.c:3251
+#, gcc-internal-format, gfc-internal-format
+msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
+msgstr ""
+
+#: fortran/check.c:3262
+#, gcc-internal-format, gfc-internal-format
+msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
+msgstr ""
+
+#: fortran/check.c:3271
+#, gcc-internal-format, gfc-internal-format
+msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
+msgstr ""
+
+#: fortran/check.c:3298
+#, gcc-internal-format
+msgid "Argument %<S%> of NEAREST at %L shall not be zero"
+msgstr ""
+
+#: fortran/check.c:3348
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
+msgstr ""
+
+#: fortran/check.c:3356
+#, gcc-internal-format, gfc-internal-format
+msgid "NULL intrinsic with allocatable MOLD at %L"
+msgstr ""
+
+#: fortran/check.c:3435 fortran/check.c:5200
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
+msgstr ""
+
+#: fortran/check.c:3493
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
+msgstr ""
+
+#: fortran/check.c:3501
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
+msgstr ""
+
+#: fortran/check.c:3520
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
+msgstr ""
+
+#: fortran/check.c:3568
+#, gcc-internal-format, gfc-internal-format
+msgid "The argument of the RANK intrinsic at %L must be a data object"
+msgstr ""
+
+#: fortran/check.c:3672
+#, gcc-internal-format
+msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
+msgstr ""
+
+#: fortran/check.c:3682
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L is empty"
+msgstr ""
+
+#: fortran/check.c:3689
+#, gcc-internal-format
+msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
+msgstr ""
+
+#: fortran/check.c:3706
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
+msgstr ""
+
+#: fortran/check.c:3746
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
+msgstr ""
+
+#: fortran/check.c:3764
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
+msgstr ""
+
+#: fortran/check.c:3773
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %<%d%> duplicated)"
+msgstr ""
+
+#: fortran/check.c:3809
+#, gcc-internal-format, gfc-internal-format
+msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
+msgstr ""
+
+#: fortran/check.c:3826 fortran/check.c:3845
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
+msgstr ""
+
+#: fortran/check.c:3836 fortran/check.c:3855
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
+msgstr ""
+
+#: fortran/check.c:3954
+#, gcc-internal-format
+msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
+msgstr ""
+
+#: fortran/check.c:3985
+#, gcc-internal-format
+msgid "%qs intrinsic with RADIX argument at %L"
+msgstr ""
+
+#: fortran/check.c:4020
+#, gcc-internal-format
+msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
+msgstr ""
+
+#: fortran/check.c:4097 fortran/check.c:6235
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
+msgstr ""
+
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
+msgstr ""
+
+#: fortran/check.c:4121 fortran/check.c:4261
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
+msgstr ""
+
+#: fortran/check.c:4191
+#, gcc-internal-format
+msgid "is_c_interoperable(): gfc_simplify_expr failed"
+msgstr ""
+
+#: fortran/check.c:4240
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
+msgstr ""
+
+#: fortran/check.c:4279
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
+msgstr ""
+
+#: fortran/check.c:4293
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
+msgstr ""
+
+#: fortran/check.c:4317
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
+msgstr ""
+
+#: fortran/check.c:4329
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
+msgstr ""
+
+#: fortran/check.c:4336
+#, gcc-internal-format, gfc-internal-format
+msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
+msgstr ""
+
+#: fortran/check.c:4343
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
+msgstr ""
+
+#: fortran/check.c:4350
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
+msgstr ""
+
+#: fortran/check.c:4356
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
+msgstr ""
+
+#: fortran/check.c:4375
+#, gcc-internal-format, gfc-internal-format
+msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
+msgstr ""
+
+#: fortran/check.c:4385
+#, gcc-internal-format, gfc-internal-format
+msgid "Polymorphic FPTR at %L to C_F_POINTER"
+msgstr ""
+
+#: fortran/check.c:4390
+#, gcc-internal-format, gfc-internal-format
+msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
+msgstr ""
+
+#: fortran/check.c:4406
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
+msgstr ""
+
+#: fortran/check.c:4418
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
+msgstr ""
+
+#: fortran/check.c:4425
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
+msgstr ""
+
+#: fortran/check.c:4431
+#, gcc-internal-format, gfc-internal-format
+msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
+msgstr ""
+
+#: fortran/check.c:4445
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
+msgstr ""
+
+#: fortran/check.c:4460
+#, gcc-internal-format
+msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
+msgstr ""
+
+#: fortran/check.c:4468
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
+msgstr ""
+
+#: fortran/check.c:4474
+#, gcc-internal-format, gfc-internal-format
+msgid "Noninteroperable procedure at %L to C_FUNLOC"
+msgstr ""
+
+#: fortran/check.c:4488
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument X at %L to C_LOC shall not be coindexed"
+msgstr ""
+
+#: fortran/check.c:4494
+#, gcc-internal-format, gfc-internal-format
+msgid "X argument at %L to C_LOC shall not be polymorphic"
+msgstr ""
+
+#: fortran/check.c:4505
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
+msgstr ""
+
+#: fortran/check.c:4513
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
+msgstr ""
+
+#: fortran/check.c:4522
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument at %L to C_LOC shall not be polymorphic"
+msgstr ""
+
+#: fortran/check.c:4529
+#, gcc-internal-format, gfc-internal-format
+msgid "Noninteroperable array at %L as argument to C_LOC: %s"
+msgstr ""
+
+#: fortran/check.c:4540
+#, gcc-internal-format, gfc-internal-format
+msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
+msgstr ""
+
+#: fortran/check.c:4545
+#, gcc-internal-format, gfc-internal-format
+msgid "Array section at %L to C_LOC"
+msgstr ""
+
+#: fortran/check.c:4573
+#, gcc-internal-format, gfc-internal-format
+msgid "non double precision REAL argument to %s intrinsic at %L"
+msgstr ""
+
+#: fortran/check.c:4586
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
+msgstr ""
+
+#: fortran/check.c:4605
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
+msgstr ""
+
+#: fortran/check.c:4868
+#, gcc-internal-format, gfc-internal-format
+msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
+msgstr ""
+
+#: fortran/check.c:4879
+#, gcc-internal-format, gfc-internal-format
+msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
+msgstr ""
+
+#: fortran/check.c:4912
+#, gcc-internal-format, gfc-internal-format
+msgid "DISTANCE= argument to NUM_IMAGES at %L"
+msgstr ""
+
+#: fortran/check.c:4925
+#, gcc-internal-format, gfc-internal-format
+msgid "FAILED= argument to NUM_IMAGES at %L"
+msgstr ""
+
+#: fortran/check.c:4948
+#, gcc-internal-format, gfc-internal-format
+msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
+msgstr ""
+
+#: fortran/check.c:4955
+#, gcc-internal-format, gfc-internal-format
+msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
+msgstr ""
+
+#: fortran/check.c:4966
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected DIM argument with noncoarray argument at %L"
+msgstr ""
+
+#: fortran/check.c:4984
+#, gcc-internal-format, gfc-internal-format
+msgid "DISTANCE= argument to THIS_IMAGE at %L"
+msgstr ""
+
+#: fortran/check.c:5064
+#, gcc-internal-format
+msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
+msgstr ""
+
+#: fortran/check.c:5092
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
+msgstr ""
+
+#: fortran/check.c:5214
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
+msgstr ""
+
+#: fortran/check.c:5227
+#, gcc-internal-format
+msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
+msgstr ""
+
+#: fortran/check.c:5485 fortran/check.c:5517
+#, gcc-internal-format
+msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
+msgstr ""
+
+#: fortran/check.c:5525
+#, gcc-internal-format, gfc-internal-format
+msgid "Too many arguments to %s at %L"
+msgstr ""
+
+#: fortran/check.c:5565
+#, gcc-internal-format, gfc-internal-format
+msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
+msgstr ""
+
+#: fortran/check.c:5584
+#, gcc-internal-format, gfc-internal-format
+msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
+msgstr ""
+
+#: fortran/check.c:5594
+#, gcc-internal-format, gfc-internal-format
+msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
+msgstr ""
+
+#: fortran/check.c:5611
+#, gcc-internal-format, gfc-internal-format
+msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
+msgstr ""
+
+#: fortran/check.c:5828
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
+msgstr ""
+
+#: fortran/check.c:6180 fortran/check.c:6188
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
+msgstr ""
+
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
+#: fortran/class.c:614
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
+msgstr ""
+
+#. Since the extension field is 8 bit wide, we can only have
+#. up to 255 extension levels.
+#: fortran/class.c:725 fortran/decl.c:7810
+#, gcc-internal-format
+msgid "Maximum extension level reached with type %qs at %L"
+msgstr ""
+
+#: fortran/class.c:2761 fortran/class.c:2835
+#, gcc-internal-format
+msgid "%qs of %qs is PRIVATE at %L"
+msgstr ""
+
+#: fortran/cpp.c:465
+#, gcc-internal-format
+msgid "To enable preprocessing, use %<-cpp%>"
+msgstr ""
+
+#: fortran/cpp.c:563 fortran/cpp.c:574 fortran/cpp.c:681
+#, gcc-internal-format
+msgid "opening output file %qs: %s"
+msgstr ""
+
+#: fortran/data.c:65
+#, gcc-internal-format, gfc-internal-format
+msgid "non-constant array in DATA statement %L"
+msgstr ""
+
+#: fortran/data.c:137
+#, gcc-internal-format, gfc-internal-format
+msgid "failure to simplify substring reference in DATA statement at %L"
+msgstr ""
+
+#: fortran/data.c:167
+#, gcc-internal-format, gfc-internal-format
+msgid "Initialization string starting at %L was truncated to fit the variable (%d/%d)"
+msgstr ""
+
+#: fortran/data.c:256
+#, gcc-internal-format, gfc-internal-format
+msgid "'%s' at %L already is initialized at %L"
+msgstr ""
+
+#: fortran/data.c:280
+#, gcc-internal-format, gfc-internal-format
+msgid "Data element below array lower bound at %L"
+msgstr ""
+
+#: fortran/data.c:297 fortran/data.c:386
+#, gcc-internal-format, gfc-internal-format
+msgid "Data element above array upper bound at %L"
+msgstr ""
+
+#: fortran/data.c:327 fortran/data.c:493
+#, gcc-internal-format
+msgid "re-initialization of %qs at %L"
+msgstr ""
+
+#: fortran/data.c:693
+#, gcc-internal-format
+msgid "TODO: Vector sections in data statements"
+msgstr ""
+
+#: fortran/decl.c:287
+#, gcc-internal-format
+msgid "Host associated variable %qs may not be in the DATA statement at %C"
+msgstr ""
+
+#: fortran/decl.c:294
+#, gcc-internal-format
+msgid "initialization of common block variable %qs in DATA statement at %C"
+msgstr ""
+
+#: fortran/decl.c:405
+#, gcc-internal-format
+msgid "Symbol %qs must be a PARAMETER in DATA statement at %C"
+msgstr ""
+
+#: fortran/decl.c:430
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid initializer %s in Data statement at %C"
+msgstr ""
+
+#: fortran/decl.c:532
+#, gcc-internal-format, gfc-internal-format
+msgid "Initialization at %C is not allowed in a PURE procedure"
+msgstr ""
+
+#: fortran/decl.c:592
+#, gcc-internal-format, gfc-internal-format
+msgid "DATA statement at %C is not allowed in a PURE procedure"
+msgstr ""
+
+#: fortran/decl.c:619
+#, gcc-internal-format, gfc-internal-format
+msgid "The assumed-rank array at %C shall not have a codimension"
+msgstr ""
+
+#: fortran/decl.c:687
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad INTENT specification at %C"
+msgstr ""
+
+#: fortran/decl.c:708
+#, gcc-internal-format, gfc-internal-format
+msgid "deferred type parameter at %C"
+msgstr ""
+
+#: fortran/decl.c:745
+#, gcc-internal-format, gfc-internal-format
+msgid "Conflict in attributes of function argument at %C"
+msgstr ""
+
+#: fortran/decl.c:771
+#, gcc-internal-format, gfc-internal-format
+msgid "Old-style character length at %C"
+msgstr ""
+
+#: fortran/decl.c:802
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in character length specification at %C"
+msgstr ""
+
+#: fortran/decl.c:924
+#, gcc-internal-format, gfc-internal-format
+msgid "Procedure '%s' at %C is already defined at %L"
+msgstr ""
+
+#: fortran/decl.c:932
+#, gcc-internal-format, gfc-internal-format
+msgid "Name '%s' at %C is already defined as a generic interface at %L"
+msgstr ""
+
+#: fortran/decl.c:945
+#, gcc-internal-format, gfc-internal-format
+msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
+msgstr ""
+
+#: fortran/decl.c:1016
+#, gcc-internal-format
+msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
+msgstr ""
+
+#: fortran/decl.c:1043
+#, gcc-internal-format
+msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
+msgstr ""
+
+#: fortran/decl.c:1050
+#, gcc-internal-format
+msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
+msgstr ""
+
+#: fortran/decl.c:1057
+#, gcc-internal-format
+msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
+msgstr ""
+
+#: fortran/decl.c:1072
+#, gcc-internal-format
+msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
+msgstr ""
+
+#: fortran/decl.c:1085
+#, gcc-internal-format
+msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
+msgstr ""
+
+#: fortran/decl.c:1093
+#, gcc-internal-format
+msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
+msgstr ""
+
+#: fortran/decl.c:1102
+#, gcc-internal-format
+msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
+msgstr ""
+
+#: fortran/decl.c:1111
+#, gcc-internal-format
+msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
+msgstr ""
+
+#: fortran/decl.c:1118
+#, gcc-internal-format
+msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
+msgstr ""
+
+#: fortran/decl.c:1129
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-shape array '%s' at %L as dummy argument to the BIND(C) procedure '%s' at %L"
+msgstr ""
+
+#: fortran/decl.c:1209
+#, gcc-internal-format
+msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
+msgstr ""
+
+#: fortran/decl.c:1252
+#, gcc-internal-format, gfc-internal-format
+msgid "CHARACTER expression at %L is being truncated (%d/%d)"
+msgstr ""
+
+#: fortran/decl.c:1259
+#, gcc-internal-format, gfc-internal-format
+msgid "The CHARACTER elements of the array constructor at %L must have the same length (%d/%d)"
+msgstr ""
+
+#: fortran/decl.c:1349
+#, gcc-internal-format
+msgid "Initializer not allowed for PARAMETER %qs at %C"
+msgstr ""
+
+#: fortran/decl.c:1359
+#, gcc-internal-format, gfc-internal-format
+msgid "PARAMETER at %L is missing an initializer"
+msgstr ""
+
+#: fortran/decl.c:1369
+#, gcc-internal-format
+msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
+msgstr ""
+
+#: fortran/decl.c:1448
+#, gcc-internal-format, gfc-internal-format
+msgid "Can't initialize implied-shape array at %L with scalar"
+msgstr ""
+
+#: fortran/decl.c:1466
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-constant lower bound in implied-shape declaration at %L"
+msgstr ""
+
+#: fortran/decl.c:1561
+#, gcc-internal-format, gfc-internal-format
+msgid "Component at %C must have the POINTER attribute"
+msgstr ""
+
+#: fortran/decl.c:1569
+#, gcc-internal-format, gfc-internal-format
+msgid "Array component of structure at %C must have explicit or deferred shape"
+msgstr ""
+
+#: fortran/decl.c:1650
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer array component of structure at %C must have a deferred shape"
+msgstr ""
+
+#: fortran/decl.c:1659
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocatable component of structure at %C must have a deferred shape"
+msgstr ""
+
+#: fortran/decl.c:1668
+#, gcc-internal-format, gfc-internal-format
+msgid "Array component of structure at %C must have an explicit shape"
+msgstr ""
+
+#: fortran/decl.c:1722
+#, gcc-internal-format, gfc-internal-format
+msgid "NULL() initialization at %C is ambiguous"
+msgstr ""
+
+#: fortran/decl.c:1739
+#, gcc-internal-format, gfc-internal-format
+msgid "NULL() initialization at %C may not have MOLD"
+msgstr ""
+
+#: fortran/decl.c:1756
+#, gcc-internal-format, gfc-internal-format
+msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
+msgstr ""
+
+#: fortran/decl.c:1777
+#, gcc-internal-format, gfc-internal-format
+msgid "Error in pointer initialization at %C"
+msgstr ""
+
+#: fortran/decl.c:1784
+#, gcc-internal-format, gfc-internal-format
+msgid "non-NULL pointer initialization at %C"
+msgstr ""
+
+#: fortran/decl.c:1807
+#, gcc-internal-format
+msgid "Function name %qs not allowed at %C"
+msgstr ""
+
+#: fortran/decl.c:1874
+#, gcc-internal-format
+msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
+msgstr ""
+
+#: fortran/decl.c:1884
+#, gcc-internal-format, gfc-internal-format
+msgid "Implied-shape array at %L"
+msgstr ""
+
+#: fortran/decl.c:1949 fortran/decl.c:6678
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate array spec for Cray pointee at %C"
+msgstr ""
+
+#: fortran/decl.c:1957
+#, gcc-internal-format
+msgid "Couldn't set pointee array spec."
+msgstr ""
+
+#: fortran/decl.c:2020
+#, gcc-internal-format, gfc-internal-format
+msgid "Old-style initialization at %C"
+msgstr ""
+
+#: fortran/decl.c:2025
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid old style initialization for derived type component at %C"
+msgstr ""
+
+#: fortran/decl.c:2042 fortran/decl.c:5053
+#, gcc-internal-format, gfc-internal-format
+msgid "Initialization at %C isn't for a pointer variable"
+msgstr ""
+
+#: fortran/decl.c:2055
+#, gcc-internal-format
+msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
+msgstr ""
+
+#: fortran/decl.c:2064 fortran/decl.c:7959
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected an initialization expression at %C"
+msgstr ""
+
+#: fortran/decl.c:2071
+#, gcc-internal-format, gfc-internal-format
+msgid "Initialization of variable at %C is not allowed in a PURE procedure"
+msgstr ""
+
+#: fortran/decl.c:2088
+#, gcc-internal-format, gfc-internal-format
+msgid "Initialization of allocatable component at %C is not allowed"
+msgstr ""
+
+#: fortran/decl.c:2142 fortran/decl.c:2178
+#, gcc-internal-format, gfc-internal-format
+msgid "Old-style type declaration %s*%d not supported at %C"
+msgstr ""
+
+#: fortran/decl.c:2184
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonstandard type declaration %s*%d at %C"
+msgstr ""
+
+#: fortran/decl.c:2235 fortran/decl.c:2311
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing right parenthesis at %C"
+msgstr ""
+
+#: fortran/decl.c:2248 fortran/decl.c:2382
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected initialization expression at %C"
+msgstr ""
+
+#: fortran/decl.c:2256 fortran/decl.c:2388
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected scalar initialization expression at %C"
+msgstr ""
+
+#: fortran/decl.c:2287
+#, gcc-internal-format, gfc-internal-format
+msgid "Kind %d not supported for type %s at %C"
+msgstr ""
+
+#: fortran/decl.c:2300
+#, gcc-internal-format, gfc-internal-format
+msgid "C kind type parameter is for type %s but type at %L is %s"
+msgstr ""
+
+#: fortran/decl.c:2309
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing right parenthesis or comma at %C"
+msgstr ""
+
+#: fortran/decl.c:2408
+#, gcc-internal-format, gfc-internal-format
+msgid "Kind %d is not supported for CHARACTER at %C"
+msgstr ""
+
+#: fortran/decl.c:2540
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in CHARACTER declaration at %C"
+msgstr ""
+
+#: fortran/decl.c:2625
+#, gcc-internal-format, gfc-internal-format
+msgid "BYTE type at %C"
+msgstr ""
+
+#: fortran/decl.c:2630
+#, gcc-internal-format, gfc-internal-format
+msgid "BYTE type used at %C is not available on the target machine"
+msgstr ""
+
+#: fortran/decl.c:2652
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed type at %C is not allowed for components"
+msgstr ""
+
+#: fortran/decl.c:2655
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed type at %C"
+msgstr ""
+
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
+#, gcc-internal-format, gfc-internal-format
+msgid "TYPE with intrinsic-type-spec at %C"
+msgstr ""
+
+#: fortran/decl.c:2734
+#, gcc-internal-format, gfc-internal-format
+msgid "DOUBLE COMPLEX at %C"
+msgstr ""
+
+#: fortran/decl.c:2808
+#, gcc-internal-format, gfc-internal-format
+msgid "CLASS statement at %C"
+msgstr ""
+
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
+#, gcc-internal-format
+msgid "Type name %qs at %C is ambiguous"
+msgstr ""
+
+#: fortran/decl.c:2871
+#, gcc-internal-format, gfc-internal-format
+msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
+msgstr ""
+
+#: fortran/decl.c:2984
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate IMPLICIT NONE statement at %C"
+msgstr ""
+
+#: fortran/decl.c:2993
+#, gcc-internal-format, gfc-internal-format
+msgid "IMPORT NONE with spec list at %C"
+msgstr ""
+
+#: fortran/decl.c:3052
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing character range in IMPLICIT at %C"
+msgstr ""
+
+#: fortran/decl.c:3098
+#, gcc-internal-format, gfc-internal-format
+msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
+msgstr ""
+
+#: fortran/decl.c:3151
+#, gcc-internal-format, gfc-internal-format
+msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
+msgstr ""
+
+#: fortran/decl.c:3161
+#, gcc-internal-format, gfc-internal-format
+msgid "Empty IMPLICIT statement at %C"
+msgstr ""
+
+#: fortran/decl.c:3267
+#, gcc-internal-format, gfc-internal-format
+msgid "IMPORT statement at %C only permitted in an INTERFACE body"
+msgstr ""
+
+#: fortran/decl.c:3272
+#, gcc-internal-format, gfc-internal-format
+msgid "IMPORT statement at %C"
+msgstr ""
+
+#: fortran/decl.c:3286
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting list of named entities at %C"
+msgstr ""
+
+#: fortran/decl.c:3315
+#, gcc-internal-format
+msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
+msgstr ""
+
+#: fortran/decl.c:3322
+#, gcc-internal-format
+msgid "%qs is already IMPORTed from host scoping unit at %C"
+msgstr ""
+
+#: fortran/decl.c:3365
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in IMPORT statement at %C"
+msgstr ""
+
+#: fortran/decl.c:3664
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing codimension specification at %C"
+msgstr ""
+
+#: fortran/decl.c:3666
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing dimension specification at %C"
+msgstr ""
+
+#: fortran/decl.c:3749
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate %s attribute at %L"
+msgstr ""
+
+#: fortran/decl.c:3768
+#, gcc-internal-format, gfc-internal-format
+msgid "ALLOCATABLE attribute at %C in a TYPE definition"
+msgstr ""
+
+#: fortran/decl.c:3777
+#, gcc-internal-format, gfc-internal-format
+msgid "Attribute at %L is not allowed in a TYPE definition"
+msgstr ""
+
+#: fortran/decl.c:3795
+#, gcc-internal-format, gfc-internal-format
+msgid "Attribute %s at %L in a TYPE definition"
+msgstr ""
+
+#: fortran/decl.c:3805
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute at %L is not allowed outside of the specification part of a module"
+msgstr ""
+
+#: fortran/decl.c:3819
+#, gcc-internal-format, gfc-internal-format
+msgid "ASYNCHRONOUS attribute at %C"
+msgstr ""
+
+#: fortran/decl.c:3830
+#, gcc-internal-format, gfc-internal-format
+msgid "CONTIGUOUS attribute at %C"
+msgstr ""
+
+#: fortran/decl.c:3875 fortran/decl.c:6974
+#, gcc-internal-format, gfc-internal-format
+msgid "PROTECTED at %C only allowed in specification part of a module"
+msgstr ""
+
+#: fortran/decl.c:3881
+#, gcc-internal-format, gfc-internal-format
+msgid "PROTECTED attribute at %C"
+msgstr ""
+
+#: fortran/decl.c:3910
+#, gcc-internal-format, gfc-internal-format
+msgid "VALUE attribute at %C"
+msgstr ""
+
+#: fortran/decl.c:3917
+#, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE attribute at %C"
+msgstr ""
+
+#: fortran/decl.c:3924
+#, gcc-internal-format
+msgid "match_attr_spec(): Bad attribute"
+msgstr ""
+
+#: fortran/decl.c:3962
+#, gcc-internal-format, gfc-internal-format
+msgid "Multiple identifiers provided with single NAME= specifier at %C"
+msgstr ""
+
+#: fortran/decl.c:4060
+#, gcc-internal-format
+msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
+msgstr ""
+
+#: fortran/decl.c:4082
+#, gcc-internal-format
+msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
+msgstr ""
+
+#: fortran/decl.c:4091
+#, gcc-internal-format
+msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
+msgstr ""
+
+#: fortran/decl.c:4095
+#, gcc-internal-format
+msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
+msgstr ""
+
+#: fortran/decl.c:4107
+#, gcc-internal-format
+msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
+msgstr ""
+
+#: fortran/decl.c:4121
+#, gcc-internal-format
+msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
+msgstr ""
+
+#: fortran/decl.c:4129
+#, gcc-internal-format
+msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
+msgstr ""
+
+#: fortran/decl.c:4141
+#, gcc-internal-format
+msgid "Return type of BIND(C) function %qs at %L cannot be an array"
+msgstr ""
+
+#: fortran/decl.c:4149
+#, gcc-internal-format
+msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
+msgstr ""
+
+#. Use gfc_warning_now because we won't say that the symbol fails
+#. just because of this.
+#: fortran/decl.c:4160
+#, gcc-internal-format
+msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
+msgstr ""
+
+#: fortran/decl.c:4234
+#, gcc-internal-format, gfc-internal-format
+msgid "Need either entity or common block name for attribute specification statement at %C"
+msgstr ""
+
+#: fortran/decl.c:4279
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing entity or common block name for attribute specification statement at %C"
+msgstr ""
+
+#: fortran/decl.c:4286
+#, gcc-internal-format
+msgid "Missing symbol"
+msgstr ""
+
+#: fortran/decl.c:4315
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) statement at %C"
+msgstr ""
+
+#: fortran/decl.c:4393
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
+msgstr ""
+
+#: fortran/decl.c:4425
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in data declaration at %C"
+msgstr ""
+
+#: fortran/decl.c:4498
+#, gcc-internal-format, gfc-internal-format
+msgid "IMPURE procedure at %C"
+msgstr ""
+
+#: fortran/decl.c:4510
+#, gcc-internal-format, gfc-internal-format
+msgid "PURE and IMPURE must not appear both at %C"
+msgstr ""
+
+#: fortran/decl.c:4578 fortran/primary.c:1719
+#, gcc-internal-format, gfc-internal-format
+msgid "Alternate-return argument at %C"
+msgstr ""
+
+#: fortran/decl.c:4624
+#, gcc-internal-format
+msgid "Name %qs at %C is the name of the procedure"
+msgstr ""
+
+#: fortran/decl.c:4636
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk in formal argument list at %C"
+msgstr ""
+
+#: fortran/decl.c:4653
+#, gcc-internal-format
+msgid "Duplicate symbol %qs in formal argument list at %C"
+msgstr ""
+
+#: fortran/decl.c:4703
+#, gcc-internal-format, gfc-internal-format
+msgid "RESULT variable at %C must be different than function name"
+msgstr ""
+
+#: fortran/decl.c:4780
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after function declaration at %C"
+msgstr ""
+
+#: fortran/decl.c:4790 fortran/decl.c:5856
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
+msgstr ""
+
+#: fortran/decl.c:4992
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
+msgstr ""
+
+#: fortran/decl.c:4999
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
+msgstr ""
+
+#: fortran/decl.c:5005
+#, gcc-internal-format, gfc-internal-format
+msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
+msgstr ""
+
+#: fortran/decl.c:5028
+#, gcc-internal-format
+msgid "Procedure %qs at %L already has basic type of %s"
+msgstr ""
+
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in PROCEDURE statement at %C"
+msgstr ""
+
+#: fortran/decl.c:5123 fortran/decl.c:8342
+#, gcc-internal-format
+msgid "Expected %<::%> after binding-attributes at %C"
+msgstr ""
+
+#: fortran/decl.c:5130
+#, gcc-internal-format, gfc-internal-format
+msgid "NOPASS or explicit interface required at %C"
+msgstr ""
+
+#: fortran/decl.c:5134
+#, gcc-internal-format, gfc-internal-format
+msgid "Procedure pointer component at %C"
+msgstr ""
+
+#: fortran/decl.c:5206
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in procedure pointer component at %C"
+msgstr ""
+
+#: fortran/decl.c:5224
+#, gcc-internal-format, gfc-internal-format
+msgid "PROCEDURE at %C must be in a generic interface"
+msgstr ""
+
+#: fortran/decl.c:5233 fortran/decl.c:7471
+#, gcc-internal-format, gfc-internal-format
+msgid "double colon in MODULE PROCEDURE statement at %L"
+msgstr ""
+
+#: fortran/decl.c:5302
+#, gcc-internal-format, gfc-internal-format
+msgid "PROCEDURE statement at %C"
+msgstr ""
+
+#: fortran/decl.c:5369
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected formal argument list in function definition at %C"
+msgstr ""
+
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
+msgstr ""
+
+#: fortran/decl.c:5543
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C"
+msgstr ""
+
+#: fortran/decl.c:5552
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a PROGRAM"
+msgstr ""
+
+#: fortran/decl.c:5555
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a MODULE"
+msgstr ""
+
+#: fortran/decl.c:5558
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
+msgstr ""
+
+#: fortran/decl.c:5562
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within an INTERFACE"
+msgstr ""
+
+#: fortran/decl.c:5566
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
+msgstr ""
+
+#: fortran/decl.c:5570
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
+msgstr ""
+
+#: fortran/decl.c:5575
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a DO block"
+msgstr ""
+
+#: fortran/decl.c:5579
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a SELECT block"
+msgstr ""
+
+#: fortran/decl.c:5583
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a FORALL block"
+msgstr ""
+
+#: fortran/decl.c:5587
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a WHERE block"
+msgstr ""
+
+#: fortran/decl.c:5591
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a contained subprogram"
+msgstr ""
+
+#: fortran/decl.c:5595
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected ENTRY statement at %C"
+msgstr ""
+
+#: fortran/decl.c:5609
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear in a contained procedure"
+msgstr ""
+
+#: fortran/decl.c:5660 fortran/decl.c:5863
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing required parentheses before BIND(C) at %C"
+msgstr ""
+
+#: fortran/decl.c:5920 fortran/decl.c:5927
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid C identifier in NAME= specifier at %C"
+msgstr ""
+
+#: fortran/decl.c:5967
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in NAME= specifier for binding label at %C"
+msgstr ""
+
+#: fortran/decl.c:5983
+#, gcc-internal-format, gfc-internal-format
+msgid "NAME= specifier at %C should be a constant expression"
+msgstr ""
+
+#: fortran/decl.c:5991
+#, gcc-internal-format, gfc-internal-format
+msgid "NAME= specifier at %C should be a scalar of default character kind"
+msgstr ""
+
+#: fortran/decl.c:6010
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing closing paren for binding label at %C"
+msgstr ""
+
+#: fortran/decl.c:6016
+#, gcc-internal-format, gfc-internal-format
+msgid "No binding name is allowed in BIND(C) at %C"
+msgstr ""
+
+#: fortran/decl.c:6022
+#, gcc-internal-format, gfc-internal-format
+msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
+msgstr ""
+
+#: fortran/decl.c:6051
+#, gcc-internal-format, gfc-internal-format
+msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
+msgstr ""
+
+#: fortran/decl.c:6258
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected END statement at %C"
+msgstr ""
+
+#: fortran/decl.c:6267
+#, gcc-internal-format, gfc-internal-format
+msgid "END statement instead of %s statement at %L"
+msgstr ""
+
+#. We would have required END [something].
+#: fortran/decl.c:6275
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement expected at %L"
+msgstr ""
+
+#: fortran/decl.c:6286
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting %s statement at %L"
+msgstr ""
+
+#: fortran/decl.c:6304
+#, gcc-internal-format
+msgid "Expected block name of %qs in %s statement at %L"
+msgstr ""
+
+#: fortran/decl.c:6321
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected terminating name at %C"
+msgstr ""
+
+#: fortran/decl.c:6330 fortran/decl.c:6338
+#, gcc-internal-format
+msgid "Expected label %qs for %s statement at %C"
+msgstr ""
+
+#: fortran/decl.c:6435
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing array specification at %L in DIMENSION statement"
+msgstr ""
+
+#: fortran/decl.c:6443
+#, gcc-internal-format, gfc-internal-format
+msgid "Dimensions specified for %s at %L after its initialisation"
+msgstr ""
+
+#: fortran/decl.c:6451
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing array specification at %L in CODIMENSION statement"
+msgstr ""
+
+#: fortran/decl.c:6460
+#, gcc-internal-format, gfc-internal-format
+msgid "Array specification must be deferred at %L"
+msgstr ""
+
+#: fortran/decl.c:6558
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected character in variable list at %C"
+msgstr ""
+
+#: fortran/decl.c:6595
+#, gcc-internal-format
+msgid "Expected %<(%> at %C"
+msgstr ""
+
+#: fortran/decl.c:6609 fortran/decl.c:6649
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected variable name at %C"
+msgstr ""
+
+#: fortran/decl.c:6625
+#, gcc-internal-format, gfc-internal-format
+msgid "Cray pointer at %C must be an integer"
+msgstr ""
+
+#: fortran/decl.c:6629
+#, gcc-internal-format, gfc-internal-format
+msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
+msgstr ""
+
+#: fortran/decl.c:6635
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected \",\" at %C"
+msgstr ""
+
+#: fortran/decl.c:6674
+#, gcc-internal-format
+msgid "Couldn't set Cray pointee array spec."
+msgstr ""
+
+#: fortran/decl.c:6698
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected \")\" at %C"
+msgstr ""
+
+#: fortran/decl.c:6710
+#, gcc-internal-format
+msgid "Expected %<,%> or end of statement at %C"
+msgstr ""
+
+#: fortran/decl.c:6736
+#, gcc-internal-format, gfc-internal-format
+msgid "INTENT is not allowed inside of BLOCK at %C"
+msgstr ""
+
+#: fortran/decl.c:6768
+#, gcc-internal-format, gfc-internal-format
+msgid "OPTIONAL is not allowed inside of BLOCK at %C"
+msgstr ""
+
+#: fortran/decl.c:6787
+#, gcc-internal-format, gfc-internal-format
+msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
+msgstr ""
+
+#: fortran/decl.c:6826
+#, gcc-internal-format, gfc-internal-format
+msgid "CONTIGUOUS statement at %C"
+msgstr ""
+
+#: fortran/decl.c:6924
+#, gcc-internal-format, gfc-internal-format
+msgid "Access specification of the %s operator at %C has already been specified"
+msgstr ""
+
+#: fortran/decl.c:6941
+#, gcc-internal-format, gfc-internal-format
+msgid "Access specification of the .%s. operator at %C has already been specified"
+msgstr ""
+
+#: fortran/decl.c:6980
+#, gcc-internal-format, gfc-internal-format
+msgid "PROTECTED statement at %C"
+msgstr ""
+
+#: fortran/decl.c:7018
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in PROTECTED statement at %C"
+msgstr ""
+
+#: fortran/decl.c:7042
+#, gcc-internal-format, gfc-internal-format
+msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
+msgstr ""
+
+#: fortran/decl.c:7079
+#, gcc-internal-format, gfc-internal-format
+msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
+msgstr ""
+
+#: fortran/decl.c:7107
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected variable name at %C in PARAMETER statement"
+msgstr ""
+
+#: fortran/decl.c:7114
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected = sign in PARAMETER statement at %C"
+msgstr ""
+
+#: fortran/decl.c:7120
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected expression at %C in PARAMETER statement"
+msgstr ""
+
+#: fortran/decl.c:7140
+#, gcc-internal-format, gfc-internal-format
+msgid "Initializing already initialized variable at %C"
+msgstr ""
+
+#: fortran/decl.c:7175
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected characters in PARAMETER statement at %C"
+msgstr ""
+
+#: fortran/decl.c:7199
+#, gcc-internal-format, gfc-internal-format
+msgid "Blanket SAVE statement at %C follows previous SAVE statement"
+msgstr ""
+
+#: fortran/decl.c:7210
+#, gcc-internal-format, gfc-internal-format
+msgid "SAVE statement at %C follows blanket SAVE statement"
+msgstr ""
+
+#: fortran/decl.c:7256
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in SAVE statement at %C"
+msgstr ""
+
+#: fortran/decl.c:7270
+#, gcc-internal-format, gfc-internal-format
+msgid "VALUE is not allowed inside of BLOCK at %C"
+msgstr ""
+
+#: fortran/decl.c:7274
+#, gcc-internal-format, gfc-internal-format
+msgid "VALUE statement at %C"
+msgstr ""
+
+#: fortran/decl.c:7312
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in VALUE statement at %C"
+msgstr ""
+
+#: fortran/decl.c:7323
+#, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE statement at %C"
+msgstr ""
+
+#: fortran/decl.c:7346
+#, gcc-internal-format
+msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
+msgstr ""
+
+#: fortran/decl.c:7371
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in VOLATILE statement at %C"
+msgstr ""
+
+#: fortran/decl.c:7382
+#, gcc-internal-format, gfc-internal-format
+msgid "ASYNCHRONOUS statement at %C"
+msgstr ""
+
+#: fortran/decl.c:7422
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in ASYNCHRONOUS statement at %C"
+msgstr ""
+
+#: fortran/decl.c:7446
+#, gcc-internal-format, gfc-internal-format
+msgid "MODULE PROCEDURE at %C must be in a generic module interface"
+msgstr ""
+
+#: fortran/decl.c:7504
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
+msgstr ""
+
+#: fortran/decl.c:7553
+#, gcc-internal-format, gfc-internal-format
+msgid "Ambiguous symbol in TYPE definition at %C"
+msgstr ""
+
+#: fortran/decl.c:7562
+#, gcc-internal-format
+msgid "Symbol %qs at %C has not been previously defined"
+msgstr ""
+
+#: fortran/decl.c:7568
+#, gcc-internal-format
+msgid "%qs in EXTENDS expression at %C is not a derived type"
+msgstr ""
+
+#: fortran/decl.c:7575
+#, gcc-internal-format
+msgid "%qs cannot be extended at %C because it is BIND(C)"
+msgstr ""
+
+#: fortran/decl.c:7582
+#, gcc-internal-format
+msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
+msgstr ""
+
+#: fortran/decl.c:7605
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
+msgstr ""
+
+#: fortran/decl.c:7617
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
+msgstr ""
+
+#: fortran/decl.c:7638
+#, gcc-internal-format, gfc-internal-format
+msgid "ABSTRACT type at %C"
+msgstr ""
+
+#: fortran/decl.c:7702
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected :: in TYPE definition at %C"
+msgstr ""
+
+#: fortran/decl.c:7713
+#, gcc-internal-format
+msgid "Type name %qs at %C cannot be the same as an intrinsic type"
+msgstr ""
+
+#: fortran/decl.c:7723
+#, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type of %s"
+msgstr ""
+
+#: fortran/decl.c:7740
+#, gcc-internal-format
+msgid "Derived type definition of %qs at %C has already been defined"
+msgstr ""
+
+#: fortran/decl.c:7845
+#, gcc-internal-format, gfc-internal-format
+msgid "Cray Pointee at %C cannot be assumed shape array"
+msgstr ""
+
+#: fortran/decl.c:7865
+#, gcc-internal-format, gfc-internal-format
+msgid "ENUM and ENUMERATOR at %C"
+msgstr ""
+
+#: fortran/decl.c:7897
+#, gcc-internal-format, gfc-internal-format
+msgid "Enumerator exceeds the C integer type at %C"
+msgstr ""
+
+#: fortran/decl.c:7976
+#, gcc-internal-format, gfc-internal-format
+msgid "ENUMERATOR %L not initialized with integer expression"
+msgstr ""
+
+#: fortran/decl.c:8024
+#, gcc-internal-format, gfc-internal-format
+msgid "ENUM definition statement expected before %C"
+msgstr ""
+
+#: fortran/decl.c:8060
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in ENUMERATOR definition at %C"
+msgstr ""
+
+#: fortran/decl.c:8107 fortran/decl.c:8122
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate access-specifier at %C"
+msgstr ""
+
+#: fortran/decl.c:8142
+#, gcc-internal-format, gfc-internal-format
+msgid "Binding attributes already specify passing, illegal NOPASS at %C"
+msgstr ""
+
+#: fortran/decl.c:8162
+#, gcc-internal-format, gfc-internal-format
+msgid "Binding attributes already specify passing, illegal PASS at %C"
+msgstr ""
+
+#: fortran/decl.c:8189
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate POINTER attribute at %C"
+msgstr ""
+
+#: fortran/decl.c:8207
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate NON_OVERRIDABLE at %C"
+msgstr ""
+
+#: fortran/decl.c:8223
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate DEFERRED at %C"
+msgstr ""
+
+#: fortran/decl.c:8236
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected access-specifier at %C"
+msgstr ""
+
+#: fortran/decl.c:8238
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected binding attribute at %C"
+msgstr ""
+
+#: fortran/decl.c:8246
+#, gcc-internal-format, gfc-internal-format
+msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
+msgstr ""
+
+#: fortran/decl.c:8258
+#, gcc-internal-format, gfc-internal-format
+msgid "POINTER attribute is required for procedure pointer component at %C"
+msgstr ""
+
+#: fortran/decl.c:8300
+#, gcc-internal-format
+msgid "Interface-name expected after %<(%> at %C"
+msgstr ""
+
+#: fortran/decl.c:8306
+#, gcc-internal-format
+msgid "%<)%> expected at %C"
+msgstr ""
+
+#: fortran/decl.c:8326
+#, gcc-internal-format, gfc-internal-format
+msgid "Interface must be specified for DEFERRED binding at %C"
+msgstr ""
+
+#: fortran/decl.c:8331
+#, gcc-internal-format, gfc-internal-format
+msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
+msgstr ""
+
+#: fortran/decl.c:8354
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected binding name at %C"
+msgstr ""
+
+#: fortran/decl.c:8358
+#, gcc-internal-format, gfc-internal-format
+msgid "PROCEDURE list at %C"
+msgstr ""
+
+#: fortran/decl.c:8370
+#, gcc-internal-format
+msgid "%<=> target%> is invalid for DEFERRED binding at %C"
+msgstr ""
+
+#: fortran/decl.c:8376
+#, gcc-internal-format
+msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
+msgstr ""
+
+#: fortran/decl.c:8386
+#, gcc-internal-format
+msgid "Expected binding target after %<=>%> at %C"
+msgstr ""
+
+#: fortran/decl.c:8403
+#, gcc-internal-format
+msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
+msgstr ""
+
+#: fortran/decl.c:8414
+#, gcc-internal-format
+msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
+msgstr ""
+
+#: fortran/decl.c:8463
+#, gcc-internal-format, gfc-internal-format
+msgid "GENERIC at %C must be inside a derived-type CONTAINS"
+msgstr ""
+
+#: fortran/decl.c:8483
+#, gcc-internal-format
+msgid "Expected %<::%> at %C"
+msgstr ""
+
+#: fortran/decl.c:8495
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected generic name or operator descriptor at %C"
+msgstr ""
+
+#: fortran/decl.c:8515
+#, gcc-internal-format, gfc-internal-format
+msgid "Malformed GENERIC statement at %C"
+msgstr ""
+
+#: fortran/decl.c:8526
+#, gcc-internal-format
+msgid "Expected %<=>%> at %C"
+msgstr ""
+
+#: fortran/decl.c:8568
+#, gcc-internal-format
+msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
+msgstr ""
+
+#: fortran/decl.c:8576
+#, gcc-internal-format
+msgid "Binding at %C must have the same access as already defined binding %qs"
+msgstr ""
+
+#: fortran/decl.c:8625
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected specific binding name at %C"
+msgstr ""
+
+#: fortran/decl.c:8635
+#, gcc-internal-format
+msgid "%qs already defined as specific binding for the generic %qs at %C"
+msgstr ""
+
+#: fortran/decl.c:8653
+#, gcc-internal-format, gfc-internal-format
+msgid "Junk after GENERIC binding at %C"
+msgstr ""
+
+#: fortran/decl.c:8688
+#, gcc-internal-format, gfc-internal-format
+msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
+msgstr ""
+
+#: fortran/decl.c:8699
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
+msgstr ""
+
+#: fortran/decl.c:8721
+#, gcc-internal-format, gfc-internal-format
+msgid "Empty FINAL at %C"
+msgstr ""
+
+#: fortran/decl.c:8728
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected module procedure name at %C"
+msgstr ""
+
+#: fortran/decl.c:8738
+#, gcc-internal-format
+msgid "Expected %<,%> at %C"
+msgstr ""
+
+#: fortran/decl.c:8744
+#, gcc-internal-format
+msgid "Unknown procedure name %qs at %C"
+msgstr ""
+
+#: fortran/decl.c:8757
+#, gcc-internal-format
+msgid "%qs at %C is already defined as FINAL procedure!"
+msgstr ""
+
+#: fortran/decl.c:8827
+#, gcc-internal-format, gfc-internal-format
+msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
+msgstr ""
+
+#: fortran/decl.c:8873
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
+msgstr ""
+
+#: fortran/dependency.c:192
+#, gcc-internal-format
+msgid "are_identical_variables: Bad type"
+msgstr ""
+
+#. We are told not to check dependencies.
+#. We do it, however, and issue a warning in case we find one.
+#. If a dependency is found in the case
+#. elemental == ELEM_CHECK_VARIABLE, we will generate
+#. a temporary, so we don't need to bother the user.
+#: fortran/dependency.c:959
+#, gcc-internal-format, gfc-internal-format
+msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
+msgstr ""
+
+#: fortran/dump-parse-tree.c:179
+#, gcc-internal-format
+msgid "show_array_spec(): Unhandled array shape type."
+msgstr ""
+
+#: fortran/dump-parse-tree.c:258
+#, gcc-internal-format
+msgid "show_array_ref(): Unknown array reference"
+msgstr ""
+
+#: fortran/dump-parse-tree.c:290
+#, gcc-internal-format
+msgid "show_ref(): Bad component code"
+msgstr ""
+
+#: fortran/dump-parse-tree.c:554
+#, gcc-internal-format
+msgid "show_expr(): Bad intrinsic in expression!"
+msgstr ""
+
+#: fortran/dump-parse-tree.c:597
+#, gcc-internal-format
+msgid "show_expr(): Don't know how to show expr"
+msgstr ""
+
+#: fortran/dump-parse-tree.c:2479
+#, gcc-internal-format
+msgid "show_code_node(): Bad statement code"
+msgstr ""
+
+#: fortran/error.c:372
+#, gcc-internal-format, gfc-internal-format
+msgid "    Included at %s:%d:"
+msgstr ""
+
+#: fortran/error.c:458
+#, gcc-internal-format
+msgid "<During initialization>\n"
+msgstr "<Під час ініціалізації>\n"
+
+#: fortran/error.c:793
+#, gcc-internal-format, gfc-internal-format
+msgid "Error count reached limit of %d."
+msgstr ""
+
+#: fortran/expr.c:148
+#, gcc-internal-format
+msgid "gfc_get_constant_expr(): locus %<where%> cannot be NULL"
+msgstr ""
+
+#: fortran/expr.c:347
+#, gcc-internal-format
+msgid "gfc_copy_expr(): Bad expr node"
+msgstr ""
+
+#: fortran/expr.c:494
+#, gcc-internal-format
+msgid "free_expr0(): Bad expr type"
+msgstr ""
+
+#: fortran/expr.c:973
+#, gcc-internal-format
+msgid "gfc_is_constant_expr(): Unknown expression type"
+msgstr ""
+
+#: fortran/expr.c:1125
+#, gcc-internal-format
+msgid "simplify_intrinsic_op(): Bad operator"
+msgstr ""
+
+#: fortran/expr.c:1231
+#, gcc-internal-format, gfc-internal-format
+msgid "Index in dimension %d is out of bounds at %L"
+msgstr ""
+
+#: fortran/expr.c:1419 fortran/expr.c:1470
+#, gcc-internal-format, gfc-internal-format
+msgid "index in dimension %d is out of bounds at %L"
+msgstr ""
+
+#: fortran/expr.c:1546
+#, gcc-internal-format, gfc-internal-format
+msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See -fmax-array-constructor option"
+msgstr ""
+
+#: fortran/expr.c:2074
+#, gcc-internal-format, gfc-internal-format
+msgid "elemental function arguments at %C are not compliant"
+msgstr ""
+
+#: fortran/expr.c:2118
+#, gcc-internal-format, gfc-internal-format
+msgid "Numeric or CHARACTER operands are required in expression at %L"
+msgstr ""
+
+#: fortran/expr.c:2143
+#, gcc-internal-format, gfc-internal-format
+msgid "Concatenation operator in expression at %L must have two CHARACTER operands"
+msgstr ""
+
+#: fortran/expr.c:2150
+#, gcc-internal-format, gfc-internal-format
+msgid "Concat operator at %L must concatenate strings of the same kind"
+msgstr ""
+
+#: fortran/expr.c:2160
+#, gcc-internal-format, gfc-internal-format
+msgid ".NOT. operator in expression at %L must have a LOGICAL operand"
+msgstr ""
+
+#: fortran/expr.c:2176
+#, gcc-internal-format, gfc-internal-format
+msgid "LOGICAL operands are required in expression at %L"
+msgstr ""
+
+#: fortran/expr.c:2187
+#, gcc-internal-format, gfc-internal-format
+msgid "Only intrinsic operators can be used in expression at %L"
+msgstr ""
+
+#: fortran/expr.c:2195
+#, gcc-internal-format, gfc-internal-format
+msgid "Numeric operands are required in expression at %L"
+msgstr ""
+
+#: fortran/expr.c:2218
+#, gcc-internal-format
+msgid "Invalid initialization expression for ALLOCATABLE component %qs in structure constructor at %L"
+msgstr ""
+
+#: fortran/expr.c:2329
+#, gcc-internal-format
+msgid "Assumed or deferred character length variable %qs  in constant expression at %L"
+msgstr ""
+
+#: fortran/expr.c:2395
+#, gcc-internal-format
+msgid "transformational intrinsic %qs at %L is not permitted in an initialization expression"
+msgstr ""
+
+#: fortran/expr.c:2426
+#, gcc-internal-format, gfc-internal-format
+msgid "Evaluation of nonstandard initialization expression at %L"
+msgstr ""
+
+#: fortran/expr.c:2495
+#, gcc-internal-format
+msgid "Function %qs in initialization expression at %L must be an intrinsic function"
+msgstr ""
+
+#: fortran/expr.c:2507
+#, gcc-internal-format
+msgid "Intrinsic function %qs at %L is not permitted in an initialization expression"
+msgstr ""
+
+#: fortran/expr.c:2542
+#, gcc-internal-format
+msgid "PARAMETER %qs is used at %L before its definition is complete"
+msgstr ""
+
+#: fortran/expr.c:2562
+#, gcc-internal-format
+msgid "Assumed size array %qs at %L is not permitted in an initialization expression"
+msgstr ""
+
+#: fortran/expr.c:2568
+#, gcc-internal-format
+msgid "Assumed shape array %qs at %L is not permitted in an initialization expression"
+msgstr ""
+
+#: fortran/expr.c:2574
+#, gcc-internal-format
+msgid "Deferred array %qs at %L is not permitted in an initialization expression"
+msgstr ""
+
+#: fortran/expr.c:2580
+#, gcc-internal-format
+msgid "Array %qs at %L is a variable, which does not reduce to a constant expression"
+msgstr ""
+
+#: fortran/expr.c:2590
+#, gcc-internal-format
+msgid "Parameter %qs at %L has not been declared or is a variable, which does not reduce to a constant expression"
+msgstr ""
+
+#: fortran/expr.c:2640
+#, gcc-internal-format
+msgid "check_init_expr(): Unknown expression type"
+msgstr ""
+
+#: fortran/expr.c:2743
+#, gcc-internal-format
+msgid "Specification function %qs at %L cannot be a statement function"
+msgstr ""
+
+#: fortran/expr.c:2750
+#, gcc-internal-format
+msgid "Specification function %qs at %L cannot be an internal function"
+msgstr ""
+
+#: fortran/expr.c:2757
+#, gcc-internal-format
+msgid "Specification function %qs at %L must be PURE"
+msgstr ""
+
+#: fortran/expr.c:2764
+#, gcc-internal-format
+msgid "Specification function %qs at %L cannot be RECURSIVE"
+msgstr ""
+
+#: fortran/expr.c:2898
+#, gcc-internal-format
+msgid "Dummy argument %qs not allowed in expression at %L"
+msgstr ""
+
+#: fortran/expr.c:2905
+#, gcc-internal-format
+msgid "Dummy argument %qs at %L cannot be OPTIONAL"
+msgstr ""
+
+#: fortran/expr.c:2912
+#, gcc-internal-format
+msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
+msgstr ""
+
+#: fortran/expr.c:2943
+#, gcc-internal-format
+msgid "Variable %qs cannot appear in the expression at %L"
+msgstr ""
+
+#: fortran/expr.c:2974
+#, gcc-internal-format
+msgid "check_restricted(): Unknown expression type"
+msgstr ""
+
+#: fortran/expr.c:2994
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression at %L must be of INTEGER type, found %s"
+msgstr ""
+
+#: fortran/expr.c:3006
+#, gcc-internal-format
+msgid "Function %qs at %L must be PURE"
+msgstr ""
+
+#: fortran/expr.c:3015
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression at %L must be scalar"
+msgstr ""
+
+#: fortran/expr.c:3049
+#, gcc-internal-format, gfc-internal-format
+msgid "Incompatible ranks in %s (%d and %d) at %L"
+msgstr ""
+
+#: fortran/expr.c:3063
+#, gcc-internal-format, gfc-internal-format
+msgid "Different shape for %s at %L on dimension %d (%d and %d)"
+msgstr ""
+
+#: fortran/expr.c:3155
+#, gcc-internal-format
+msgid "%qs at %L is not a VALUE"
+msgstr ""
+
+#: fortran/expr.c:3162
+#, gcc-internal-format, gfc-internal-format
+msgid "Incompatible ranks %d and %d in assignment at %L"
+msgstr ""
+
+#: fortran/expr.c:3169
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable type is UNKNOWN in assignment at %L"
+msgstr ""
+
+#: fortran/expr.c:3181
+#, gcc-internal-format, gfc-internal-format
+msgid "NULL appears on right-hand side in assignment at %L"
+msgstr ""
+
+#: fortran/expr.c:3191
+#, gcc-internal-format, gfc-internal-format
+msgid "POINTER-valued function appears on right-hand side of assignment at %L"
+msgstr ""
+
+#: fortran/expr.c:3201
+#, gcc-internal-format
+msgid "BOZ literal at %L used to initialize non-integer variable %qs"
+msgstr ""
+
+#: fortran/expr.c:3206 fortran/resolve.c:9308
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
+msgstr ""
+
+#: fortran/expr.c:3217 fortran/resolve.c:9319
+#, gcc-internal-format
+msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
+msgstr ""
+
+#: fortran/expr.c:3225 fortran/resolve.c:9328
+#, gcc-internal-format
+msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
+msgstr ""
+
+#: fortran/expr.c:3229 fortran/resolve.c:9332
+#, gcc-internal-format
+msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
+msgstr ""
+
+#: fortran/expr.c:3233 fortran/resolve.c:9336
+#, gcc-internal-format
+msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
+msgstr ""
+
+#: fortran/expr.c:3266
+#, gcc-internal-format
+msgid "Change of value in conversion from  %qs to %qs at %L"
+msgstr ""
+
+#: fortran/expr.c:3275
+#, gcc-internal-format
+msgid "Possible change of value in conversion from %qs to %qs at %L"
+msgstr ""
+
+#: fortran/expr.c:3283
+#, gcc-internal-format
+msgid "Conversion from %qs to %qs at %L"
+msgstr ""
+
+#: fortran/expr.c:3304
+#, gcc-internal-format, gfc-internal-format
+msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
+msgstr ""
+
+#: fortran/expr.c:3340
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer assignment target is not a POINTER at %L"
+msgstr ""
+
+#: fortran/expr.c:3348
+#, gcc-internal-format
+msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
+msgstr ""
+
+#: fortran/expr.c:3371
+#, gcc-internal-format
+msgid "Expected bounds specification for %qs at %L"
+msgstr ""
+
+#: fortran/expr.c:3376
+#, gcc-internal-format
+msgid "Bounds specification for %qs in pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.c:3389
+#, gcc-internal-format, gfc-internal-format
+msgid "Lower bound has to be present at %L"
+msgstr ""
+
+#: fortran/expr.c:3395
+#, gcc-internal-format, gfc-internal-format
+msgid "Stride must not be present at %L"
+msgstr ""
+
+#: fortran/expr.c:3407
+#, gcc-internal-format, gfc-internal-format
+msgid "Either all or none of the upper bounds must be specified at %L"
+msgstr ""
+
+#: fortran/expr.c:3433
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer object at %L shall not have a coindex"
+msgstr ""
+
+#: fortran/expr.c:3454
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid procedure pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.c:3478
+#, gcc-internal-format
+msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.c:3487
+#, gcc-internal-format
+msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.c:3497
+#, gcc-internal-format
+msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.c:3503
+#, gcc-internal-format
+msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.c:3510
+#, gcc-internal-format
+msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
+msgstr ""
+
+#: fortran/expr.c:3518
+#, gcc-internal-format
+msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.c:3541
+#, gcc-internal-format, gfc-internal-format
+msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
+msgstr ""
+
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
+#, gcc-internal-format
+msgid "Explicit interface required for %qs at %L: %s"
+msgstr ""
+
+#: fortran/expr.c:3612
+#, gcc-internal-format, gfc-internal-format
+msgid "Interface mismatch in procedure pointer assignment at %L: %s"
+msgstr ""
+
+#: fortran/expr.c:3621
+#, gcc-internal-format
+msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
+msgstr ""
+
+#: fortran/expr.c:3638
+#, gcc-internal-format, gfc-internal-format
+msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
+msgstr ""
+
+#: fortran/expr.c:3644
+#, gcc-internal-format, gfc-internal-format
+msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
+msgstr ""
+
+#: fortran/expr.c:3653
+#, gcc-internal-format, gfc-internal-format
+msgid "Different kind type parameters in pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.c:3660
+#, gcc-internal-format, gfc-internal-format
+msgid "Different ranks in pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.c:3679
+#, gcc-internal-format, gfc-internal-format
+msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
+msgstr ""
+
+#: fortran/expr.c:3692
+#, gcc-internal-format, gfc-internal-format
+msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
+msgstr ""
+
+#: fortran/expr.c:3696
+#, gcc-internal-format, gfc-internal-format
+msgid "Rank remapping target is not rank 1 at %L"
+msgstr ""
+
+#: fortran/expr.c:3720
+#, gcc-internal-format, gfc-internal-format
+msgid "Target expression in pointer assignment at %L must deliver a pointer result"
+msgstr ""
+
+#: fortran/expr.c:3728
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
+msgstr ""
+
+#: fortran/expr.c:3735
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad target in pointer assignment in PURE procedure at %L"
+msgstr ""
+
+#: fortran/expr.c:3744
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer assignment with vector subscript on rhs at %L"
+msgstr ""
+
+#: fortran/expr.c:3752
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer assignment target has PROTECTED attribute at %L"
+msgstr ""
+
+#: fortran/expr.c:3765
+#, gcc-internal-format, gfc-internal-format
+msgid "Data target at %L shall not have a coindex"
+msgstr ""
+
+#: fortran/expr.c:3806
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer at %L in pointer assignment might outlive the pointer target"
+msgstr ""
+
+#: fortran/expr.c:3872
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer initialization target at %L must not be ALLOCATABLE"
+msgstr ""
+
+#: fortran/expr.c:3878
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer initialization target at %L must have the TARGET attribute"
+msgstr ""
+
+#: fortran/expr.c:3893 fortran/resolve.c:1337
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer initialization target at %L must have the SAVE attribute"
+msgstr ""
+
+#: fortran/expr.c:3905
+#, gcc-internal-format, gfc-internal-format
+msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
+msgstr ""
+
+#: fortran/expr.c:4793
+#, gcc-internal-format, gfc-internal-format
+msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.c:4801
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-variable expression in variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.c:4809
+#, gcc-internal-format
+msgid "Named constant %qs in variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.c:4818
+#, gcc-internal-format
+msgid "%qs in variable definition context (%s) at %L is not a variable"
+msgstr ""
+
+#: fortran/expr.c:4829
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-POINTER in pointer association context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.c:4842
+#, gcc-internal-format, gfc-internal-format
+msgid "LOCK_TYPE in variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.c:4871
+#, gcc-internal-format
+msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.c:4879
+#, gcc-internal-format
+msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.c:4892
+#, gcc-internal-format
+msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.c:4900
+#, gcc-internal-format
+msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.c:4912
+#, gcc-internal-format
+msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
+msgstr ""
+
+#: fortran/expr.c:4971
+#, gcc-internal-format
+msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
+msgstr ""
+
+#: fortran/expr.c:4975
+#, gcc-internal-format
+msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
+msgstr ""
+
+#: fortran/expr.c:4986
+#, gcc-internal-format, gfc-internal-format
+msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
+msgstr ""
+
+#: fortran/expr.c:5028
+#, gcc-internal-format, gfc-internal-format
+msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
+msgstr ""
+
+#: fortran/f95-lang.c:269
+#, gcc-internal-format, gfc-internal-format
+msgid "can't open input file: %s"
+msgstr ""
+
+#: fortran/frontend-passes.c:278
+#, gcc-internal-format
+msgid "Illegal id in copy_walk_reduction_arg"
+msgstr ""
+
+#: fortran/frontend-passes.c:658 fortran/trans-array.c:1057
+#: fortran/trans-array.c:5979 fortran/trans-array.c:7267
+#: fortran/trans-intrinsic.c:6225
+#, gcc-internal-format, gfc-internal-format
+msgid "Creating array temporary at %L"
+msgstr ""
+
+#: fortran/frontend-passes.c:681 fortran/frontend-passes.c:684
+#, gcc-internal-format
+msgid "Removing call to function %qs at %L"
+msgstr ""
+
+#: fortran/frontend-passes.c:1656
+#, gcc-internal-format
+msgid "illegal OP in optimize_comparison"
+msgstr ""
+
+#: fortran/frontend-passes.c:1848
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
+msgstr ""
+
+#: fortran/frontend-passes.c:1855
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
+msgstr ""
+
+#: fortran/frontend-passes.c:1920
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
+msgstr ""
+
+#: fortran/frontend-passes.c:1926
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
+msgstr ""
+
+#: fortran/gfortranspec.c:145
+#, gcc-internal-format
+msgid "overflowed output arg list for %qs"
+msgstr ""
+
+#: fortran/gfortranspec.c:300
+#, gcc-internal-format
+msgid "no input files; unwilling to write output files"
+msgstr ""
+
+#: fortran/interface.c:176
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in generic specification at %C"
+msgstr ""
+
+#: fortran/interface.c:203
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error: Trailing garbage in INTERFACE statement at %C"
+msgstr ""
+
+#: fortran/interface.c:222
+#, gcc-internal-format
+msgid "Dummy procedure %qs at %C cannot have a generic interface"
+msgstr ""
+
+#: fortran/interface.c:255
+#, gcc-internal-format, gfc-internal-format
+msgid "ABSTRACT INTERFACE at %C"
+msgstr ""
+
+#: fortran/interface.c:262
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in ABSTRACT INTERFACE statement at %C"
+msgstr ""
+
+#: fortran/interface.c:293
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error: Trailing garbage in END INTERFACE statement at %C"
+msgstr ""
+
+#: fortran/interface.c:306
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected a nameless interface at %C"
+msgstr ""
+
+#: fortran/interface.c:319
+#, gcc-internal-format
+msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
+msgstr ""
+
+#: fortran/interface.c:350
+#, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr ""
+
+#: fortran/interface.c:353
+#, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
+msgstr ""
+
+#: fortran/interface.c:367
+#, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
+msgstr ""
+
+#: fortran/interface.c:378
+#, gcc-internal-format
+msgid "Expecting %<END INTERFACE %s%> at %C"
+msgstr ""
+
+#: fortran/interface.c:651
+#, gcc-internal-format, gfc-internal-format
+msgid "Alternate return cannot appear in operator interface at %L"
+msgstr ""
+
+#: fortran/interface.c:680
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment operator interface at %L must have two arguments"
+msgstr ""
+
+#: fortran/interface.c:683
+#, gcc-internal-format, gfc-internal-format
+msgid "Operator interface at %L has the wrong number of arguments"
+msgstr ""
+
+#: fortran/interface.c:696
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment operator interface at %L must be a SUBROUTINE"
+msgstr ""
+
+#: fortran/interface.c:714
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
+msgstr ""
+
+#: fortran/interface.c:723
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic operator interface at %L must be a FUNCTION"
+msgstr ""
+
+#: fortran/interface.c:734
+#, gcc-internal-format, gfc-internal-format
+msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
+msgstr ""
+
+#: fortran/interface.c:741
+#, gcc-internal-format, gfc-internal-format
+msgid "Second argument of defined assignment at %L must be INTENT(IN)"
+msgstr ""
+
+#: fortran/interface.c:750 fortran/resolve.c:14870
+#, gcc-internal-format, gfc-internal-format
+msgid "First argument of operator interface at %L must be INTENT(IN)"
+msgstr ""
+
+#: fortran/interface.c:757 fortran/resolve.c:14888
+#, gcc-internal-format, gfc-internal-format
+msgid "Second argument of operator interface at %L must be INTENT(IN)"
+msgstr ""
+
+#: fortran/interface.c:862
+#, gcc-internal-format, gfc-internal-format
+msgid "Operator interface at %L conflicts with intrinsic interface"
+msgstr ""
+
+#: fortran/interface.c:1193 fortran/interface.c:1252
+#, gcc-internal-format, gfc-internal-format
+msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
+msgstr ""
+
+#: fortran/interface.c:1365
+#, gcc-internal-format, gfc-internal-format
+msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
+msgstr ""
+
+#: fortran/interface.c:1412
+#, gcc-internal-format, gfc-internal-format
+msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
+msgstr ""
+
+#: fortran/interface.c:1579
+#, gcc-internal-format
+msgid "Procedure %qs in %s at %L has no explicit interface"
+msgstr ""
+
+#: fortran/interface.c:1582
+#, gcc-internal-format
+msgid "Procedure %qs in %s at %L is neither function nor subroutine"
+msgstr ""
+
+#: fortran/interface.c:1594
+#, gcc-internal-format, gfc-internal-format
+msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
+msgstr ""
+
+#: fortran/interface.c:1598
+#, gcc-internal-format, gfc-internal-format
+msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
+msgstr ""
+
+#: fortran/interface.c:1606
+#, gcc-internal-format
+msgid "Internal procedure %qs in %s at %L"
+msgstr ""
+
+#: fortran/interface.c:1663 fortran/interface.c:1667
+#, gcc-internal-format
+msgid "Ambiguous interfaces %qs and %qs in %s at %L"
+msgstr ""
+
+#: fortran/interface.c:1671
+#, gcc-internal-format
+msgid "Although not referenced, %qs has ambiguous interfaces at %L"
+msgstr ""
+
+#: fortran/interface.c:1705
+#, gcc-internal-format
+msgid "%qs at %L is not a module procedure"
+msgstr ""
+
+#: fortran/interface.c:1909
+#, gcc-internal-format
+msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
+msgstr ""
+
+#: fortran/interface.c:1914
+#, gcc-internal-format
+msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
+msgstr ""
+
+#: fortran/interface.c:1919
+#, gcc-internal-format
+msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
+msgstr ""
+
+#: fortran/interface.c:1924
+#, gcc-internal-format
+msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
+msgstr ""
+
+#: fortran/interface.c:1967
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid procedure argument at %L"
+msgstr ""
+
+#: fortran/interface.c:1975 fortran/interface.c:2002
+#, gcc-internal-format
+msgid "Interface mismatch in dummy procedure %qs at %L: %s"
+msgstr ""
+
+#: fortran/interface.c:2013
+#, gcc-internal-format
+msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
+msgstr ""
+
+#: fortran/interface.c:2028
+#, gcc-internal-format
+msgid "Type mismatch in argument %qs at %L; passed %s to %s"
+msgstr ""
+
+#: fortran/interface.c:2037
+#, gcc-internal-format
+msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
+msgstr ""
+
+#: fortran/interface.c:2053
+#, gcc-internal-format
+msgid "Actual argument to %qs at %L must be polymorphic"
+msgstr ""
+
+#: fortran/interface.c:2066
+#, gcc-internal-format
+msgid "Actual argument to %qs at %L must have the same declared type"
+msgstr ""
+
+#: fortran/interface.c:2081
+#, gcc-internal-format
+msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
+msgstr ""
+
+#: fortran/interface.c:2092
+#, gcc-internal-format
+msgid "Actual argument to %qs at %L must be a coarray"
+msgstr ""
+
+#: fortran/interface.c:2111
+#, gcc-internal-format
+msgid "Corank mismatch in argument %qs at %L (%d and %d)"
+msgstr ""
+
+#: fortran/interface.c:2128
+#, gcc-internal-format
+msgid "Actual argument to %qs at %L must be simply contiguous"
+msgstr ""
+
+#: fortran/interface.c:2142
+#, gcc-internal-format
+msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
+msgstr ""
+
+#: fortran/interface.c:2160
+#, gcc-internal-format
+msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
+msgstr ""
+
+#: fortran/interface.c:2173
+#, gcc-internal-format
+msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
+msgstr ""
+
+#: fortran/interface.c:2180
+#, gcc-internal-format
+msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
+msgstr ""
+
+#: fortran/interface.c:2243
+#, gcc-internal-format
+msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.c:2252
+#, gcc-internal-format
+msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.c:2264
+#, gcc-internal-format
+msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.c:2272
+#, gcc-internal-format
+msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.c:2599
+#, gcc-internal-format
+msgid "Keyword argument %qs at %L is not in the procedure"
+msgstr ""
+
+#: fortran/interface.c:2607
+#, gcc-internal-format
+msgid "Keyword argument %qs at %L is already associated with another actual argument"
+msgstr ""
+
+#: fortran/interface.c:2617
+#, gcc-internal-format, gfc-internal-format
+msgid "More actual than formal arguments in procedure call at %L"
+msgstr ""
+
+#: fortran/interface.c:2629 fortran/interface.c:2999
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing alternate return spec in subroutine call at %L"
+msgstr ""
+
+#: fortran/interface.c:2637
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected alternate return spec in subroutine call at %L"
+msgstr ""
+
+#: fortran/interface.c:2664
+#, gcc-internal-format
+msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
+msgstr ""
+
+#: fortran/interface.c:2667
+#, gcc-internal-format
+msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
+msgstr ""
+
+#: fortran/interface.c:2691
+#, gcc-internal-format, gfc-internal-format
+msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
+msgstr ""
+
+#: fortran/interface.c:2713
+#, gcc-internal-format
+msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.c:2721
+#, gcc-internal-format
+msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.c:2735
+#, gcc-internal-format
+msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
+msgstr ""
+
+#: fortran/interface.c:2752
+#, gcc-internal-format
+msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
+msgstr ""
+
+#: fortran/interface.c:2757
+#, gcc-internal-format
+msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
+msgstr ""
+
+#: fortran/interface.c:2776
+#, gcc-internal-format
+msgid "Expected a procedure pointer for argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.c:2792
+#, gcc-internal-format
+msgid "Expected a procedure for argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.c:2806
+#, gcc-internal-format
+msgid "Actual argument for %qs cannot be an assumed-size array at %L"
+msgstr ""
+
+#: fortran/interface.c:2815
+#, gcc-internal-format
+msgid "Actual argument for %qs must be a pointer at %L"
+msgstr ""
+
+#: fortran/interface.c:2825
+#, gcc-internal-format
+msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
+msgstr ""
+
+#: fortran/interface.c:2835
+#, gcc-internal-format
+msgid "Coindexed actual argument at %L to pointer dummy %qs"
+msgstr ""
+
+#: fortran/interface.c:2848
+#, gcc-internal-format
+msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
+msgstr ""
+
+#: fortran/interface.c:2862
+#, gcc-internal-format
+msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
+msgstr ""
+
+#: fortran/interface.c:2876
+#, gcc-internal-format
+msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
+msgstr ""
+
+#: fortran/interface.c:2888
+#, gcc-internal-format
+msgid "Actual CLASS array argument for %qs must be a full array at %L"
+msgstr ""
+
+#: fortran/interface.c:2898
+#, gcc-internal-format
+msgid "Actual argument for %qs must be ALLOCATABLE at %L"
+msgstr ""
+
+#: fortran/interface.c:2927
+#, gcc-internal-format
+msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
+msgstr ""
+
+#: fortran/interface.c:2945
+#, gcc-internal-format
+msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
+msgstr ""
+
+#: fortran/interface.c:2957
+#, gcc-internal-format
+msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
+msgstr ""
+
+#: fortran/interface.c:2976
+#, gcc-internal-format
+msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
+msgstr ""
+
+#: fortran/interface.c:3006
+#, gcc-internal-format
+msgid "Missing actual argument for argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.c:3128
+#, gcc-internal-format
+msgid "compare_actual_expr(): Bad component code"
+msgstr ""
+
+#: fortran/interface.c:3157
+#, gcc-internal-format
+msgid "check_some_aliasing(): List mismatch"
+msgstr ""
+
+#: fortran/interface.c:3183
+#, gcc-internal-format
+msgid "check_some_aliasing(): corrupted data"
+msgstr ""
+
+#: fortran/interface.c:3193
+#, gcc-internal-format
+msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.c:3223
+#, gcc-internal-format
+msgid "check_intents(): List mismatch"
+msgstr ""
+
+#: fortran/interface.c:3243
+#, gcc-internal-format, gfc-internal-format
+msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
+msgstr ""
+
+#: fortran/interface.c:3255
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
+msgstr ""
+
+#: fortran/interface.c:3265
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
+msgstr ""
+
+#: fortran/interface.c:3276
+#, gcc-internal-format
+msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
+msgstr ""
+
+#: fortran/interface.c:3304 fortran/interface.c:3314
+#, gcc-internal-format
+msgid "Procedure %qs called at %L is not explicitly declared"
+msgstr ""
+
+#: fortran/interface.c:3310
+#, gcc-internal-format
+msgid "Procedure %qs called with an implicit interface at %L"
+msgstr ""
+
+#: fortran/interface.c:3324
+#, gcc-internal-format
+msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
+msgstr ""
+
+#: fortran/interface.c:3332
+#, gcc-internal-format
+msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
+msgstr ""
+
+#: fortran/interface.c:3340
+#, gcc-internal-format
+msgid "Allocatable function %qs at %L must have an explicit function interface"
+msgstr ""
+
+#: fortran/interface.c:3350
+#, gcc-internal-format
+msgid "Keyword argument requires explicit interface for procedure %qs at %L"
+msgstr ""
+
+#: fortran/interface.c:3359
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type argument %s at %L requires an explicit interface"
+msgstr ""
+
+#: fortran/interface.c:3372
+#, gcc-internal-format
+msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
+msgstr ""
+
+#: fortran/interface.c:3381
+#, gcc-internal-format, gfc-internal-format
+msgid "MOLD argument to NULL required at %L"
+msgstr ""
+
+#: fortran/interface.c:3389
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank argument requires an explicit interface at %L"
+msgstr ""
+
+#: fortran/interface.c:3427
+#, gcc-internal-format
+msgid "Procedure pointer component %qs called with an implicit interface at %L"
+msgstr ""
+
+#: fortran/interface.c:3438
+#, gcc-internal-format
+msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
+msgstr ""
+
+#: fortran/interface.c:3522
+#, gcc-internal-format, gfc-internal-format
+msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
+msgstr ""
+
+#: fortran/interface.c:3592
+#, gcc-internal-format
+msgid "Unable to find symbol %qs"
+msgstr ""
+
+#: fortran/interface.c:3959
+#, gcc-internal-format
+msgid "Entity %qs at %L is already present in the interface"
+msgstr ""
+
+#: fortran/interface.c:4075
+#, gcc-internal-format
+msgid "gfc_add_interface(): Bad interface type"
+msgstr ""
+
+#: fortran/interface.c:4170
+#, gcc-internal-format
+msgid "Can't overwrite GENERIC %qs at %L"
+msgstr ""
+
+#: fortran/interface.c:4182
+#, gcc-internal-format
+msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
+msgstr ""
+
+#: fortran/interface.c:4190
+#, gcc-internal-format
+msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
+msgstr ""
+
+#: fortran/interface.c:4198
+#, gcc-internal-format
+msgid "%qs at %L overrides a PURE procedure and must also be PURE"
+msgstr ""
+
+#: fortran/interface.c:4207
+#, gcc-internal-format
+msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
+msgstr ""
+
+#: fortran/interface.c:4213
+#, gcc-internal-format
+msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
+msgstr ""
+
+#: fortran/interface.c:4222
+#, gcc-internal-format
+msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
+msgstr ""
+
+#: fortran/interface.c:4233
+#, gcc-internal-format
+msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
+msgstr ""
+
+#: fortran/interface.c:4241
+#, gcc-internal-format
+msgid "Result mismatch for the overriding procedure %qs at %L: %s"
+msgstr ""
+
+#: fortran/interface.c:4252
+#, gcc-internal-format
+msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
+msgstr ""
+
+#: fortran/interface.c:4282
+#, gcc-internal-format
+msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
+msgstr ""
+
+#: fortran/interface.c:4293
+#, gcc-internal-format
+msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
+msgstr ""
+
+#: fortran/interface.c:4302
+#, gcc-internal-format
+msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
+msgstr ""
+
+#: fortran/interface.c:4311
+#, gcc-internal-format
+msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
+msgstr ""
+
+#: fortran/interface.c:4322
+#, gcc-internal-format
+msgid "%qs at %L overrides a binding with PASS and must also be PASS"
+msgstr ""
+
+#: fortran/interface.c:4329
+#, gcc-internal-format
+msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
+msgstr ""
+
+#: fortran/intrinsic.c:196
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable with NO_ARG_CHECK attribute at %L is only permitted as argument to the intrinsic functions C_LOC and PRESENT"
+msgstr ""
+
+#: fortran/intrinsic.c:211
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type argument at %L is not permitted as actual argument to the intrinsic %s"
+msgstr ""
+
+#: fortran/intrinsic.c:218
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type argument at %L is only permitted as first actual argument to the intrinsic %s"
+msgstr ""
+
+#: fortran/intrinsic.c:225
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank argument at %L is only permitted as actual argument to intrinsic inquiry functions"
+msgstr ""
+
+#: fortran/intrinsic.c:232
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank argument at %L is only permitted as first actual argument to the intrinsic inquiry function %s"
+msgstr ""
+
+#: fortran/intrinsic.c:280
+#, gcc-internal-format
+msgid "do_check(): too many args"
+msgstr ""
+
+#: fortran/intrinsic.c:360
+#, gcc-internal-format
+msgid "add_sym(): Bad sizing mode"
+msgstr ""
+
+#: fortran/intrinsic.c:1054
+#, gcc-internal-format
+msgid "The intrinsic %qs at %L is not included in the selected standard but %s and %qs will be treated as if declared EXTERNAL.  Use an appropriate -std=* option or define -fall-intrinsics to allow this intrinsic."
+msgstr ""
+
+#: fortran/intrinsic.c:1089
+#, gcc-internal-format
+msgid "make_generic(): Can't find generic symbol %qs"
+msgstr ""
+
+#: fortran/intrinsic.c:3818
+#, gcc-internal-format
+msgid "Too many arguments in call to %qs at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:3833
+#, gcc-internal-format, gfc-internal-format
+msgid "The argument list functions %%VAL, %%LOC or %%REF are not allowed in this context at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:3836
+#, gcc-internal-format
+msgid "Can't find keyword named %qs in call to %qs at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:3843
+#, gcc-internal-format
+msgid "Argument %qs appears twice in call to %qs at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:3857
+#, gcc-internal-format
+msgid "Missing actual argument %qs in call to %qs at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:3872
+#, gcc-internal-format, gfc-internal-format
+msgid "ALTERNATE RETURN not permitted at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:3929
+#, gcc-internal-format
+msgid "Type of argument %qs in call to %qs at %L should be %s, not %s"
+msgstr ""
+
+#: fortran/intrinsic.c:4035
+#, gcc-internal-format
+msgid "resolve_intrinsic(): Too many args for intrinsic"
+msgstr ""
+
+#: fortran/intrinsic.c:4121
+#, gcc-internal-format
+msgid "do_simplify(): Too many args for intrinsic"
+msgstr ""
+
+#: fortran/intrinsic.c:4160
+#, gcc-internal-format
+msgid "init_arglist(): too many arguments"
+msgstr ""
+
+#: fortran/intrinsic.c:4310
+#, gcc-internal-format
+msgid "Invalid standard code on intrinsic %qs (%d)"
+msgstr ""
+
+#: fortran/intrinsic.c:4319
+#, gcc-internal-format
+msgid "Intrinsic %qs (is %s) is used at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:4390
+#, gcc-internal-format
+msgid "Function %qs as initialization expression at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:4466
+#, gcc-internal-format, gfc-internal-format
+msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:4537
+#, gcc-internal-format
+msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
+msgstr ""
+
+#: fortran/intrinsic.c:4544
+#, gcc-internal-format
+msgid "Subroutine call to intrinsic %qs at %L is not PURE"
+msgstr ""
+
+#: fortran/intrinsic.c:4620
+#, gcc-internal-format, gfc-internal-format
+msgid "Extension: Conversion from %s to %s at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:4654 fortran/intrinsic.c:4670
+#, gcc-internal-format, gfc-internal-format
+msgid "Possible change of value in conversion from %s to %s at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:4659 fortran/intrinsic.c:4679
+#, gcc-internal-format, gfc-internal-format
+msgid "Conversion from %s to %s at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:4732
+#, gcc-internal-format, gfc-internal-format
+msgid "Can't convert %s to %s at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:4737
+#, gcc-internal-format
+msgid "Can't convert %qs to %qs at %L"
+msgstr ""
+
+#: fortran/intrinsic.c:4827
+#, gcc-internal-format
+msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
+msgstr ""
+
+#: fortran/intrinsic.c:4833
+#, gcc-internal-format
+msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
+msgstr ""
+
+#: fortran/io.c:168 fortran/primary.c:868
+#, gcc-internal-format, gfc-internal-format
+msgid "Extension: backslash character at %C"
+msgstr ""
+
+#: fortran/io.c:204 fortran/io.c:207
+#, gcc-internal-format, gfc-internal-format
+msgid "Extension: Tab character in format at %C"
+msgstr ""
+
+#: fortran/io.c:455
+#, gcc-internal-format, gfc-internal-format
+msgid "DP format specifier not allowed at %C"
+msgstr ""
+
+#: fortran/io.c:462
+#, gcc-internal-format, gfc-internal-format
+msgid "DC format specifier not allowed at %C"
+msgstr ""
+
+#: fortran/io.c:651
+#, gcc-internal-format, gfc-internal-format
+msgid "X descriptor requires leading space count at %L"
+msgstr ""
+
+#: fortran/io.c:680
+#, gcc-internal-format, gfc-internal-format
+msgid "$ descriptor at %L"
+msgstr ""
+
+#: fortran/io.c:684
+#, gcc-internal-format, gfc-internal-format
+msgid "$ should be the last specifier in format at %L"
+msgstr ""
+
+#: fortran/io.c:782
+#, gcc-internal-format, gfc-internal-format
+msgid "Extension: Missing positive width after L descriptor at %L"
+msgstr ""
+
+#: fortran/io.c:826
+#, gcc-internal-format
+msgid "%<G0%> in format at %L"
+msgstr ""
+
+#: fortran/io.c:854
+#, gcc-internal-format, gfc-internal-format
+msgid "Positive width required in format specifier %s at %L"
+msgstr ""
+
+#: fortran/io.c:870 fortran/io.c:877
+#, gcc-internal-format, gfc-internal-format
+msgid "Period required in format specifier %s at %L"
+msgstr ""
+
+#: fortran/io.c:949
+#, gcc-internal-format, gfc-internal-format
+msgid "Period required in format specifier at %L"
+msgstr ""
+
+#: fortran/io.c:971
+#, gcc-internal-format, gfc-internal-format
+msgid "The H format specifier at %L is a Fortran 95 deleted feature"
+msgstr ""
+
+#: fortran/io.c:1059 fortran/io.c:1121
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing comma at %L"
+msgstr ""
+
+#: fortran/io.c:1139
+#, gcc-internal-format, gfc-internal-format
+msgid "%s in format string at %L"
+msgstr ""
+
+#: fortran/io.c:1177
+#, gcc-internal-format, gfc-internal-format
+msgid "Extraneous characters in format at %L"
+msgstr ""
+
+#: fortran/io.c:1199
+#, gcc-internal-format, gfc-internal-format
+msgid "Format statement in module main block at %C"
+msgstr ""
+
+#: fortran/io.c:1205
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing format label at %C"
+msgstr ""
+
+#: fortran/io.c:1260 fortran/io.c:1291 fortran/io.c:1357
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid value for %s specification at %C"
+msgstr ""
+
+#: fortran/io.c:1266 fortran/io.c:1297
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate %s specification at %C"
+msgstr ""
+
+#: fortran/io.c:1304
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s cannot be INTENT(IN) at %C"
+msgstr ""
+
+#: fortran/io.c:1312
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s cannot be assigned in PURE procedure at %C"
+msgstr ""
+
+#: fortran/io.c:1363
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate %s label specification at %C"
+msgstr ""
+
+#: fortran/io.c:1383
+#, gcc-internal-format, gfc-internal-format
+msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
+msgstr ""
+
+#: fortran/io.c:1401
+#, gcc-internal-format, gfc-internal-format
+msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
+msgstr ""
+
+#: fortran/io.c:1407
+#, gcc-internal-format, gfc-internal-format
+msgid "ASSIGNED variable in FORMAT tag at %L"
+msgstr ""
+
+#: fortran/io.c:1412
+#, gcc-internal-format
+msgid "Variable %qs at %L has not been assigned a format label"
+msgstr ""
+
+#: fortran/io.c:1419
+#, gcc-internal-format
+msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
+msgstr ""
+
+#: fortran/io.c:1431
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-character in FORMAT tag at %L"
+msgstr ""
+
+#: fortran/io.c:1437
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-character assumed shape array element in FORMAT tag at %L"
+msgstr ""
+
+#: fortran/io.c:1444
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-character assumed size array element in FORMAT tag at %L"
+msgstr ""
+
+#: fortran/io.c:1451
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-character pointer array element in FORMAT tag at %L"
+msgstr ""
+
+#: fortran/io.c:1477
+#, gcc-internal-format, gfc-internal-format
+msgid "%s tag at %L must be of type %s"
+msgstr ""
+
+#: fortran/io.c:1484
+#, gcc-internal-format, gfc-internal-format
+msgid "%s tag at %L must be a character string of default kind"
+msgstr ""
+
+#: fortran/io.c:1491
+#, gcc-internal-format, gfc-internal-format
+msgid "%s tag at %L must be scalar"
+msgstr ""
+
+#: fortran/io.c:1497
+#, gcc-internal-format, gfc-internal-format
+msgid "IOMSG tag at %L"
+msgstr ""
+
+#: fortran/io.c:1505
+#, gcc-internal-format, gfc-internal-format
+msgid "Fortran 95 requires default INTEGER in %s tag at %L"
+msgstr ""
+
+#: fortran/io.c:1514
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-default LOGICAL kind in %s tag at %L"
+msgstr ""
+
+#: fortran/io.c:1521
+#, gcc-internal-format, gfc-internal-format
+msgid "NEWUNIT specifier at %L"
+msgstr ""
+
+#: fortran/io.c:1539
+#, gcc-internal-format, gfc-internal-format
+msgid "CONVERT tag at %L"
+msgstr ""
+
+#: fortran/io.c:1724
+#, gcc-internal-format
+msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
+msgstr ""
+
+#: fortran/io.c:1732 fortran/io.c:1759
+#, gcc-internal-format
+msgid "%s specifier in %s statement at %C has value %qs"
+msgstr ""
+
+#: fortran/io.c:1751
+#, gcc-internal-format
+msgid "Extension: %s specifier in %s statement at %C has value %qs"
+msgstr ""
+
+#: fortran/io.c:1773 fortran/io.c:1781
+#, gcc-internal-format
+msgid "%s specifier in %s statement at %C has invalid value %qs"
+msgstr ""
+
+#: fortran/io.c:1834
+#, gcc-internal-format, gfc-internal-format
+msgid "OPEN statement not allowed in PURE procedure at %C"
+msgstr ""
+
+#: fortran/io.c:1847
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT specifier not allowed with NEWUNIT at %C"
+msgstr ""
+
+#: fortran/io.c:1855
+#, gcc-internal-format, gfc-internal-format
+msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
+msgstr ""
+
+#: fortran/io.c:1862
+#, gcc-internal-format, gfc-internal-format
+msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
+msgstr ""
+
+#: fortran/io.c:1894
+#, gcc-internal-format, gfc-internal-format
+msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.c:1912 fortran/io.c:3350
+#, gcc-internal-format, gfc-internal-format
+msgid "BLANK= at %C not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.c:1930 fortran/io.c:3329
+#, gcc-internal-format, gfc-internal-format
+msgid "DECIMAL= at %C not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.c:1962
+#, gcc-internal-format, gfc-internal-format
+msgid "ENCODING= at %C not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.c:2013 fortran/io.c:3392
+#, gcc-internal-format, gfc-internal-format
+msgid "ROUND= at %C not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.c:2033
+#, gcc-internal-format, gfc-internal-format
+msgid "SIGN= at %C not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.c:2246
+#, gcc-internal-format, gfc-internal-format
+msgid "CLOSE statement not allowed in PURE procedure at %C"
+msgstr ""
+
+#: fortran/io.c:2305
+#, gcc-internal-format, gfc-internal-format
+msgid "CLOSE statement at %L requires a UNIT number"
+msgstr ""
+
+#: fortran/io.c:2313
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT number in CLOSE statement at %L must be non-negative"
+msgstr ""
+
+#: fortran/io.c:2409 fortran/match.c:2634
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement not allowed in PURE procedure at %C"
+msgstr ""
+
+#: fortran/io.c:2443 fortran/io.c:2874
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT number in statement at %L must be non-negative"
+msgstr ""
+
+#: fortran/io.c:2475
+#, gcc-internal-format, gfc-internal-format
+msgid "FLUSH statement at %C"
+msgstr ""
+
+#: fortran/io.c:2530
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate UNIT specification at %C"
+msgstr ""
+
+#: fortran/io.c:2604
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate format specification at %C"
+msgstr ""
+
+#: fortran/io.c:2621
+#, gcc-internal-format
+msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
+msgstr ""
+
+#: fortran/io.c:2657
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate NML specification at %C"
+msgstr ""
+
+#: fortran/io.c:2666
+#, gcc-internal-format
+msgid "Symbol %qs at %C must be a NAMELIST group name"
+msgstr ""
+
+#: fortran/io.c:2731
+#, gcc-internal-format, gfc-internal-format
+msgid "END tag at %C not allowed in output statement"
+msgstr ""
+
+#: fortran/io.c:2808
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT not specified at %L"
+msgstr ""
+
+#: fortran/io.c:2820
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
+msgstr ""
+
+#: fortran/io.c:2842
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid form of WRITE statement at %L, UNIT required"
+msgstr ""
+
+#: fortran/io.c:2853
+#, gcc-internal-format, gfc-internal-format
+msgid "Internal unit with vector subscript at %L"
+msgstr ""
+
+#: fortran/io.c:2867
+#, gcc-internal-format, gfc-internal-format
+msgid "External IO UNIT cannot be an array at %L"
+msgstr ""
+
+#: fortran/io.c:2895
+#, gcc-internal-format
+msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
+msgstr ""
+
+#: fortran/io.c:2905
+#, gcc-internal-format, gfc-internal-format
+msgid "Comma before i/o item list at %L"
+msgstr ""
+
+#: fortran/io.c:2915
+#, gcc-internal-format, gfc-internal-format
+msgid "ERR tag label %d at %L not defined"
+msgstr ""
+
+#: fortran/io.c:2927
+#, gcc-internal-format, gfc-internal-format
+msgid "END tag label %d at %L not defined"
+msgstr ""
+
+#: fortran/io.c:2939
+#, gcc-internal-format, gfc-internal-format
+msgid "EOR tag label %d at %L not defined"
+msgstr ""
+
+#: fortran/io.c:2949
+#, gcc-internal-format, gfc-internal-format
+msgid "FORMAT label %d at %L not defined"
+msgstr ""
+
+#: fortran/io.c:2980
+#, gcc-internal-format
+msgid "io_kind_name(): bad I/O-kind"
+msgstr ""
+
+#: fortran/io.c:3069
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in I/O iterator at %C"
+msgstr ""
+
+#: fortran/io.c:3100
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected variable in READ statement at %C"
+msgstr ""
+
+#: fortran/io.c:3106
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected expression in %s statement at %C"
+msgstr ""
+
+#. A general purpose syntax error.
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in %s statement at %C"
+msgstr ""
+
+#: fortran/io.c:3247
+#, gcc-internal-format, gfc-internal-format
+msgid "Internal file at %L with namelist"
+msgstr ""
+
+#: fortran/io.c:3303
+#, gcc-internal-format, gfc-internal-format
+msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
+msgstr ""
+
+#: fortran/io.c:3371
+#, gcc-internal-format, gfc-internal-format
+msgid "PAD= at %C not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.c:3437
+#, gcc-internal-format, gfc-internal-format
+msgid "DELIM= at %C not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.c:3586
+#, gcc-internal-format, gfc-internal-format
+msgid "PRINT namelist at %C is an extension"
+msgstr ""
+
+#: fortran/io.c:3729
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected comma in I/O list at %C"
+msgstr ""
+
+#: fortran/io.c:3792
+#, gcc-internal-format, gfc-internal-format
+msgid "PRINT statement at %C not allowed within PURE procedure"
+msgstr ""
+
+#: fortran/io.c:3951 fortran/io.c:4011
+#, gcc-internal-format, gfc-internal-format
+msgid "INQUIRE statement not allowed in PURE procedure at %C"
+msgstr ""
+
+#: fortran/io.c:3979
+#, gcc-internal-format, gfc-internal-format
+msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
+msgstr ""
+
+#: fortran/io.c:3989 fortran/trans-io.c:1315
+#, gcc-internal-format, gfc-internal-format
+msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
+msgstr ""
+
+#: fortran/io.c:3996
+#, gcc-internal-format, gfc-internal-format
+msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
+msgstr ""
+
+#: fortran/io.c:4005
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT number in INQUIRE statement at %L can not be -1"
+msgstr ""
+
+#: fortran/io.c:4019
+#, gcc-internal-format, gfc-internal-format
+msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
+msgstr ""
+
+#: fortran/io.c:4193
+#, gcc-internal-format, gfc-internal-format
+msgid "WAIT at %C not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.c:4199
+#, gcc-internal-format, gfc-internal-format
+msgid "WAIT statement not allowed in PURE procedure at %C"
+msgstr ""
+
+#: fortran/match.c:120
+#, gcc-internal-format
+msgid "gfc_op2string(): Bad code"
+msgstr ""
+
+#: fortran/match.c:177
+#, gcc-internal-format
+msgid "Missing %<)%> in statement at or before %L"
+msgstr ""
+
+#: fortran/match.c:182
+#, gcc-internal-format
+msgid "Missing %<(%> in statement at or before %L"
+msgstr ""
+
+#: fortran/match.c:379
+#, gcc-internal-format, gfc-internal-format
+msgid "Integer too large at %C"
+msgstr ""
+
+#: fortran/match.c:472 fortran/parse.c:946
+#, gcc-internal-format, gfc-internal-format
+msgid "Too many digits in statement label at %C"
+msgstr ""
+
+#: fortran/match.c:478
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement label at %C is zero"
+msgstr ""
+
+#: fortran/match.c:511
+#, gcc-internal-format
+msgid "Label name %qs at %C is ambiguous"
+msgstr ""
+
+#: fortran/match.c:517
+#, gcc-internal-format
+msgid "Duplicate construct label %qs at %C"
+msgstr ""
+
+#: fortran/match.c:548
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid character in name at %C"
+msgstr ""
+
+#: fortran/match.c:561
+#, gcc-internal-format, gfc-internal-format
+msgid "Name at %C is too long"
+msgstr ""
+
+#: fortran/match.c:572
+#, gcc-internal-format
+msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
+msgstr ""
+
+#: fortran/match.c:891
+#, gcc-internal-format, gfc-internal-format
+msgid "Loop variable at %C cannot be a coarray"
+msgstr ""
+
+#: fortran/match.c:897
+#, gcc-internal-format, gfc-internal-format
+msgid "Loop variable at %C cannot be a sub-component"
+msgstr ""
+
+#: fortran/match.c:931
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected a step value in iterator at %C"
+msgstr ""
+
+#: fortran/match.c:943
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in iterator at %C"
+msgstr ""
+
+#: fortran/match.c:1111
+#, gcc-internal-format, gfc-internal-format
+msgid "gfc_match(): Bad match code %c"
+msgstr ""
+
+#: fortran/match.c:1184
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid form of PROGRAM statement at %C"
+msgstr ""
+
+#: fortran/match.c:1314 fortran/match.c:1394
+#, gcc-internal-format, gfc-internal-format
+msgid "Arithmetic IF statement at %C"
+msgstr ""
+
+#: fortran/match.c:1369
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in IF-expression at %C"
+msgstr ""
+
+#: fortran/match.c:1380
+#, gcc-internal-format, gfc-internal-format
+msgid "Block label not appropriate for arithmetic IF statement at %C"
+msgstr ""
+
+#: fortran/match.c:1417
+#, gcc-internal-format, gfc-internal-format
+msgid "Block label is not appropriate for IF statement at %C"
+msgstr ""
+
+#: fortran/match.c:1503
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot assign to a named constant at %C"
+msgstr ""
+
+#: fortran/match.c:1513
+#, gcc-internal-format, gfc-internal-format
+msgid "Unclassifiable statement in IF-clause at %C"
+msgstr ""
+
+#: fortran/match.c:1520
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in IF-clause at %C"
+msgstr ""
+
+#: fortran/match.c:1563
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after ELSE statement at %C"
+msgstr ""
+
+#: fortran/match.c:1569 fortran/match.c:1604
+#, gcc-internal-format
+msgid "Label %qs at %C doesn't match IF label %qs"
+msgstr ""
+
+#: fortran/match.c:1598
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after ELSE IF statement at %C"
+msgstr ""
+
+#: fortran/match.c:1662
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement CRITICAL at %C in PURE procedure"
+msgstr ""
+
+#: fortran/match.c:1668
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.c:1675
+#, gcc-internal-format, gfc-internal-format
+msgid "CRITICAL statement at %C"
+msgstr ""
+
+#: fortran/match.c:1687
+#, gcc-internal-format, gfc-internal-format
+msgid "Nested CRITICAL block at %C"
+msgstr ""
+
+#: fortran/match.c:1739
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected association list at %C"
+msgstr ""
+
+#: fortran/match.c:1752
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected association at %C"
+msgstr ""
+
+#: fortran/match.c:1761
+#, gcc-internal-format
+msgid "Duplicate name %qs in association at %C"
+msgstr ""
+
+#: fortran/match.c:1769
+#, gcc-internal-format, gfc-internal-format
+msgid "Association target at %C must not be coindexed"
+msgstr ""
+
+#: fortran/match.c:1787
+#, gcc-internal-format
+msgid "Expected %<)%> or %<,%> at %C"
+msgstr ""
+
+#: fortran/match.c:1805
+#, gcc-internal-format, gfc-internal-format
+msgid "Junk after ASSOCIATE statement at %C"
+msgstr ""
+
+#: fortran/match.c:1874
+#, gcc-internal-format
+msgid "Derived type %qs at %L may not be ABSTRACT"
+msgstr ""
+
+#: fortran/match.c:1937
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid type-spec at %C"
+msgstr ""
+
+#: fortran/match.c:2031
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in FORALL iterator at %C"
+msgstr ""
+
+#: fortran/match.c:2296
+#, gcc-internal-format, gfc-internal-format
+msgid "DO CONCURRENT construct at %C"
+msgstr ""
+
+#: fortran/match.c:2421
+#, gcc-internal-format
+msgid "Name %qs in %s statement at %C is unknown"
+msgstr ""
+
+#: fortran/match.c:2429
+#, gcc-internal-format
+msgid "Name %qs in %s statement at %C is not a construct name"
+msgstr ""
+
+#: fortran/match.c:2441
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C leaves CRITICAL construct"
+msgstr ""
+
+#. F2008, C821 & C845.
+#: fortran/match.c:2449
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C leaves DO CONCURRENT construct"
+msgstr ""
+
+#: fortran/match.c:2461
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C is not within a construct"
+msgstr ""
+
+#: fortran/match.c:2464
+#, gcc-internal-format
+msgid "%s statement at %C is not within construct %qs"
+msgstr ""
+
+#: fortran/match.c:2489
+#, gcc-internal-format
+msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
+msgstr ""
+
+#: fortran/match.c:2494
+#, gcc-internal-format, gfc-internal-format
+msgid "EXIT statement with no do-construct-name at %C"
+msgstr ""
+
+#: fortran/match.c:2500
+#, gcc-internal-format
+msgid "%s statement at %C is not applicable to construct %qs"
+msgstr ""
+
+#: fortran/match.c:2508
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C leaving OpenACC structured block"
+msgstr ""
+
+#: fortran/match.c:2533
+#, gcc-internal-format, gfc-internal-format
+msgid "EXIT statement at %C terminating !$ACC LOOP loop"
+msgstr ""
+
+#: fortran/match.c:2538
+#, gcc-internal-format, gfc-internal-format
+msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
+msgstr ""
+
+#: fortran/match.c:2563
+#, gcc-internal-format, gfc-internal-format
+msgid "EXIT statement at %C terminating !$OMP DO loop"
+msgstr ""
+
+#: fortran/match.c:2568
+#, gcc-internal-format, gfc-internal-format
+msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
+msgstr ""
+
+#: fortran/match.c:2628
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C in PURE procedure"
+msgstr ""
+
+#: fortran/match.c:2644
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement STOP at %C in CRITICAL block"
+msgstr ""
+
+#: fortran/match.c:2649
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement STOP at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.c:2657
+#, gcc-internal-format, gfc-internal-format
+msgid "STOP code at %L must be either INTEGER or CHARACTER type"
+msgstr ""
+
+#: fortran/match.c:2664
+#, gcc-internal-format, gfc-internal-format
+msgid "STOP code at %L must be scalar"
+msgstr ""
+
+#: fortran/match.c:2672
+#, gcc-internal-format, gfc-internal-format
+msgid "STOP code at %L must be default character KIND=%d"
+msgstr ""
+
+#: fortran/match.c:2680
+#, gcc-internal-format, gfc-internal-format
+msgid "STOP code at %L must be default integer KIND=%d"
+msgstr ""
+
+#: fortran/match.c:2726
+#, gcc-internal-format, gfc-internal-format
+msgid "PAUSE statement at %C"
+msgstr ""
+
+#: fortran/match.c:2747
+#, gcc-internal-format, gfc-internal-format
+msgid "ERROR STOP statement at %C"
+msgstr ""
+
+#: fortran/match.c:2772
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement %s at %C in PURE procedure"
+msgstr ""
+
+#: fortran/match.c:2787
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement %s at %C in CRITICAL block"
+msgstr ""
+
+#: fortran/match.c:2794
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement %s at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
+#, gcc-internal-format, gfc-internal-format
+msgid "Redundant STAT tag found at %L "
+msgstr ""
+
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
+#, gcc-internal-format, gfc-internal-format
+msgid "Redundant ERRMSG tag found at %L "
+msgstr ""
+
+#: fortran/match.c:2866
+#, gcc-internal-format, gfc-internal-format
+msgid "Redundant ACQUIRED_LOCK tag found at %L "
+msgstr ""
+
+#: fortran/match.c:2931
+#, gcc-internal-format, gfc-internal-format
+msgid "LOCK statement at %C"
+msgstr ""
+
+#: fortran/match.c:2941
+#, gcc-internal-format, gfc-internal-format
+msgid "UNLOCK statement at %C"
+msgstr ""
+
+#: fortran/match.c:2966
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement SYNC at %C in PURE procedure"
+msgstr ""
+
+#: fortran/match.c:2972
+#, gcc-internal-format, gfc-internal-format
+msgid "SYNC statement at %C"
+msgstr ""
+
+#: fortran/match.c:2984
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement SYNC at %C in CRITICAL block"
+msgstr ""
+
+#: fortran/match.c:2990
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement SYNC at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.c:3170
+#, gcc-internal-format, gfc-internal-format
+msgid "ASSIGN statement at %C"
+msgstr ""
+
+#: fortran/match.c:3214
+#, gcc-internal-format, gfc-internal-format
+msgid "Assigned GOTO statement at %C"
+msgstr ""
+
+#: fortran/match.c:3258 fortran/match.c:3309
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement label list in GOTO at %C cannot be empty"
+msgstr ""
+
+#: fortran/match.c:3319
+#, gcc-internal-format, gfc-internal-format
+msgid "Computed GOTO at %C"
+msgstr ""
+
+#: fortran/match.c:3391
+#, gcc-internal-format, gfc-internal-format
+msgid "Error in type-spec at %L"
+msgstr ""
+
+#: fortran/match.c:3401
+#, gcc-internal-format, gfc-internal-format
+msgid "typespec in ALLOCATE at %L"
+msgstr ""
+
+#: fortran/match.c:3444
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad allocate-object at %C for a PURE procedure"
+msgstr ""
+
+#: fortran/match.c:3468
+#, gcc-internal-format, gfc-internal-format
+msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.c:3473
+#, gcc-internal-format, gfc-internal-format
+msgid "ALLOCATE of coarray at %C in CRITICAL block"
+msgstr ""
+
+#: fortran/match.c:3495
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
+msgstr ""
+
+#: fortran/match.c:3507
+#, gcc-internal-format, gfc-internal-format
+msgid "Type of entity at %L is type incompatible with typespec"
+msgstr ""
+
+#: fortran/match.c:3515
+#, gcc-internal-format, gfc-internal-format
+msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
+msgstr ""
+
+#: fortran/match.c:3529
+#, gcc-internal-format, gfc-internal-format
+msgid "Shape specification for allocatable scalar at %C"
+msgstr ""
+
+#: fortran/match.c:3566
+#, gcc-internal-format, gfc-internal-format
+msgid "ERRMSG tag at %L"
+msgstr ""
+
+#: fortran/match.c:3589
+#, gcc-internal-format, gfc-internal-format
+msgid "SOURCE tag at %L"
+msgstr ""
+
+#: fortran/match.c:3595
+#, gcc-internal-format, gfc-internal-format
+msgid "Redundant SOURCE tag found at %L "
+msgstr ""
+
+#: fortran/match.c:3602
+#, gcc-internal-format, gfc-internal-format
+msgid "SOURCE tag at %L conflicts with the typespec at %L"
+msgstr ""
+
+#: fortran/match.c:3608
+#, gcc-internal-format, gfc-internal-format
+msgid "SOURCE tag at %L with more than a single allocate object"
+msgstr ""
+
+#: fortran/match.c:3626
+#, gcc-internal-format, gfc-internal-format
+msgid "MOLD tag at %L"
+msgstr ""
+
+#: fortran/match.c:3632
+#, gcc-internal-format, gfc-internal-format
+msgid "Redundant MOLD tag found at %L "
+msgstr ""
+
+#: fortran/match.c:3639
+#, gcc-internal-format, gfc-internal-format
+msgid "MOLD tag at %L conflicts with the typespec at %L"
+msgstr ""
+
+#: fortran/match.c:3665
+#, gcc-internal-format, gfc-internal-format
+msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
+msgstr ""
+
+#: fortran/match.c:3673
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
+msgstr ""
+
+#: fortran/match.c:3685
+#, gcc-internal-format, gfc-internal-format
+msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
+msgstr ""
+
+#: fortran/match.c:3747
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer object at %C shall not be coindexed"
+msgstr ""
+
+#: fortran/match.c:3833
+#, gcc-internal-format, gfc-internal-format
+msgid "Illegal allocate-object at %C for a PURE procedure"
+msgstr ""
+
+#: fortran/match.c:3843
+#, gcc-internal-format, gfc-internal-format
+msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.c:3850
+#, gcc-internal-format, gfc-internal-format
+msgid "DEALLOCATE of coarray at %C in CRITICAL block"
+msgstr ""
+
+#: fortran/match.c:3866
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
+msgstr ""
+
+#: fortran/match.c:3903
+#, gcc-internal-format, gfc-internal-format
+msgid "ERRMSG at %L"
+msgstr ""
+
+#: fortran/match.c:3960
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement RETURN at %C in CRITICAL block"
+msgstr ""
+
+#: fortran/match.c:3966
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement RETURN at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.c:3975
+#, gcc-internal-format, gfc-internal-format
+msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
+msgstr ""
+
+#: fortran/match.c:4006
+#, gcc-internal-format, gfc-internal-format
+msgid "RETURN statement in main program at %C"
+msgstr ""
+
+#: fortran/match.c:4034
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected component reference at %C"
+msgstr ""
+
+#: fortran/match.c:4043
+#, gcc-internal-format, gfc-internal-format
+msgid "Junk after CALL at %C"
+msgstr ""
+
+#: fortran/match.c:4054
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected type-bound procedure or procedure pointer component at %C"
+msgstr ""
+
+#: fortran/match.c:4275
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in common block name at %C"
+msgstr ""
+
+#. If we find an error, just print it and continue,
+#. cause it's just semantic, and we can see if there
+#. are more errors.
+#: fortran/match.c:4353
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
+msgstr ""
+
+#: fortran/match.c:4362
+#, gcc-internal-format
+msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
+msgstr ""
+
+#: fortran/match.c:4369
+#, gcc-internal-format
+msgid "Symbol %qs at %C is already in a COMMON block"
+msgstr ""
+
+#: fortran/match.c:4377
+#, gcc-internal-format
+msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
+msgstr ""
+
+#: fortran/match.c:4403
+#, gcc-internal-format
+msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
+msgstr ""
+
+#: fortran/match.c:4413
+#, gcc-internal-format
+msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
+msgstr ""
+
+#: fortran/match.c:4445
+#, gcc-internal-format
+msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
+msgstr ""
+
+#: fortran/match.c:4573
+#, gcc-internal-format
+msgid "Namelist group name %qs at %C already has a basic type of %s"
+msgstr ""
+
+#: fortran/match.c:4581
+#, gcc-internal-format
+msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
+msgstr ""
+
+#: fortran/match.c:4607
+#, gcc-internal-format
+msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
+msgstr ""
+
+#: fortran/match.c:4741
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type component %C is not a permitted EQUIVALENCE member"
+msgstr ""
+
+#: fortran/match.c:4749
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
+msgstr ""
+
+#: fortran/match.c:4777
+#, gcc-internal-format, gfc-internal-format
+msgid "EQUIVALENCE at %C requires two or more objects"
+msgstr ""
+
+#: fortran/match.c:4791
+#, gcc-internal-format, gfc-internal-format
+msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
+msgstr ""
+
+#: fortran/match.c:4804
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting a comma in EQUIVALENCE at %C"
+msgstr ""
+
+#: fortran/match.c:4922
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement function at %L is recursive"
+msgstr ""
+
+#: fortran/match.c:4928
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement function at %C"
+msgstr ""
+
+#: fortran/match.c:5013
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected initialization expression in CASE at %C"
+msgstr ""
+
+#: fortran/match.c:5045
+#, gcc-internal-format
+msgid "Expected block name %qs of SELECT construct at %C"
+msgstr ""
+
+#: fortran/match.c:5325
+#, gcc-internal-format, gfc-internal-format
+msgid "parse error in SELECT TYPE statement at %C"
+msgstr ""
+
+#: fortran/match.c:5349
+#, gcc-internal-format, gfc-internal-format
+msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
+msgstr ""
+
+#: fortran/match.c:5383
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected CASE statement at %C"
+msgstr ""
+
+#: fortran/match.c:5435
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in CASE specification at %C"
+msgstr ""
+
+#: fortran/match.c:5453
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected TYPE IS statement at %C"
+msgstr ""
+
+#: fortran/match.c:5485
+#, gcc-internal-format, gfc-internal-format
+msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
+msgstr ""
+
+#: fortran/match.c:5497
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in TYPE IS specification at %C"
+msgstr ""
+
+#: fortran/match.c:5573
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in CLASS IS specification at %C"
+msgstr ""
+
+#: fortran/match.c:5691
+#, gcc-internal-format, gfc-internal-format
+msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
+msgstr ""
+
+#: fortran/match.c:5729
+#, gcc-internal-format
+msgid "Label %qs at %C doesn't match WHERE label %qs"
+msgstr ""
+
+#: fortran/matchexp.c:72
+#, gcc-internal-format
+msgid "Bad character %<%c%> in OPERATOR name at %C"
+msgstr ""
+
+#: fortran/matchexp.c:80
+#, gcc-internal-format
+msgid "The name %qs cannot be used as a defined operator at %C"
+msgstr ""
+
+#: fortran/matchexp.c:173
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected a right parenthesis in expression at %C"
+msgstr ""
+
+#: fortran/matchexp.c:281
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected exponent in expression at %C"
+msgstr ""
+
+#: fortran/matchexp.c:319 fortran/matchexp.c:324 fortran/matchexp.c:428
+#: fortran/matchexp.c:433
+#, gcc-internal-format, gfc-internal-format
+msgid "Extension: Unary operator following arithmetic operator (use parentheses) at %C"
+msgstr ""
+
+#: fortran/matchexp.c:665
+#, gcc-internal-format
+msgid "match_level_4(): Bad operator"
+msgstr ""
+
+#: fortran/misc.c:105
+#, gcc-internal-format
+msgid "gfc_basic_typename(): Undefined type"
+msgstr ""
+
+#: fortran/misc.c:167
+#, gcc-internal-format
+msgid "gfc_typename(): Undefined type"
+msgstr ""
+
+#: fortran/misc.c:187
+#, gcc-internal-format
+msgid "gfc_code2string(): Bad code"
+msgstr ""
+
+#: fortran/module.c:241
+#, gcc-internal-format
+msgid "free_pi_tree(): Unresolved fixup"
+msgstr ""
+
+#: fortran/module.c:458
+#, gcc-internal-format
+msgid "associate_integer_pointer(): Already associated"
+msgstr ""
+
+#: fortran/module.c:540
+#, gcc-internal-format, gfc-internal-format
+msgid "module nature in USE statement at %C"
+msgstr ""
+
+#: fortran/module.c:552
+#, gcc-internal-format, gfc-internal-format
+msgid "Module nature in USE statement at %C shall be either INTRINSIC or NON_INTRINSIC"
+msgstr ""
+
+#: fortran/module.c:565
+#, gcc-internal-format, gfc-internal-format
+msgid "\"::\" was expected after module nature at %C but was not found"
+msgstr ""
+
+#: fortran/module.c:575
+#, gcc-internal-format, gfc-internal-format
+msgid "\"USE :: module\" at %C"
+msgstr ""
+
+#: fortran/module.c:634
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing generic specification in USE statement at %C"
+msgstr ""
+
+#: fortran/module.c:642
+#, gcc-internal-format, gfc-internal-format
+msgid "Renaming operators in USE statements at %C"
+msgstr ""
+
+#: fortran/module.c:683
+#, gcc-internal-format
+msgid "The name %qs at %C has already been used as an external module name."
+msgstr ""
+
+#: fortran/module.c:1067
+#, gcc-internal-format
+msgid "Reading module %qs at line %d column %d: %s"
+msgstr ""
+
+#: fortran/module.c:1071
+#, gcc-internal-format
+msgid "Writing module %qs at line %d column %d: %s"
+msgstr ""
+
+#: fortran/module.c:1075
+#, gcc-internal-format
+msgid "Module %qs at line %d column %d: %s"
+msgstr ""
+
+#: fortran/module.c:1470
+#, gcc-internal-format
+msgid "require_atom(): bad atom type required"
+msgstr ""
+
+#: fortran/module.c:1519
+#, gcc-internal-format, gfc-internal-format
+msgid "Error writing modules file: %s"
+msgstr ""
+
+#: fortran/module.c:1563
+#, gcc-internal-format
+msgid "write_atom(): Writing negative integer"
+msgstr ""
+
+#: fortran/module.c:1570
+#, gcc-internal-format
+msgid "write_atom(): Trying to write dab atom"
+msgstr ""
+
+#: fortran/module.c:1776
+#, gcc-internal-format
+msgid "unquote_string(): got bad string"
+msgstr ""
+
+#: fortran/module.c:2523
+#, gcc-internal-format
+msgid "mio_array_ref(): Unknown array ref"
+msgstr ""
+
+#: fortran/module.c:3499
+#, gcc-internal-format, gfc-internal-format
+msgid "Namelist %s cannot be renamed by USE association to %s"
+msgstr ""
+
+#: fortran/module.c:4619
+#, gcc-internal-format, gfc-internal-format
+msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
+msgstr ""
+
+#: fortran/module.c:4622
+#, gcc-internal-format, gfc-internal-format
+msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
+msgstr ""
+
+#: fortran/module.c:4810
+#, gcc-internal-format
+msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
+msgstr ""
+
+#: fortran/module.c:5161
+#, gcc-internal-format
+msgid "Symbol %qs referenced at %L not found in module %qs"
+msgstr ""
+
+#: fortran/module.c:5168
+#, gcc-internal-format
+msgid "User operator %qs referenced at %L not found in module %qs"
+msgstr ""
+
+#: fortran/module.c:5173
+#, gcc-internal-format
+msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
+msgstr ""
+
+#: fortran/module.c:5403
+#, gcc-internal-format
+msgid "write_symbol(): bad module symbol %qs"
+msgstr ""
+
+#: fortran/module.c:5736
+#, gcc-internal-format
+msgid "write_symtree(): Symbol not written"
+msgstr ""
+
+#: fortran/module.c:5910
+#, gcc-internal-format
+msgid "Can't open module file %qs for writing at %C: %s"
+msgstr ""
+
+#: fortran/module.c:5930
+#, gcc-internal-format
+msgid "Error writing module file %qs for writing: %s"
+msgstr ""
+
+#: fortran/module.c:5941
+#, gcc-internal-format
+msgid "Can't delete module file %qs: %s"
+msgstr ""
+
+#: fortran/module.c:5944
+#, gcc-internal-format
+msgid "Can't rename module file %qs to %qs: %s"
+msgstr ""
+
+#: fortran/module.c:5950
+#, gcc-internal-format
+msgid "Can't delete temporary module file %qs: %s"
+msgstr ""
+
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
+#, gcc-internal-format
+msgid "Symbol %qs already declared"
+msgstr ""
+
+#: fortran/module.c:6040
+#, gcc-internal-format, gfc-internal-format
+msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
+msgstr ""
+
+#: fortran/module.c:6148 fortran/module.c:6492
+#, gcc-internal-format
+msgid "The symbol %qs, referenced at %L, is not in the selected standard"
+msgstr ""
+
+#: fortran/module.c:6276
+#, gcc-internal-format
+msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
+msgstr ""
+
+#: fortran/module.c:6477
+#, gcc-internal-format
+msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
+msgstr ""
+
+#: fortran/module.c:6499
+#, gcc-internal-format
+msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
+msgstr ""
+
+#: fortran/module.c:6567
+#, gcc-internal-format, gfc-internal-format
+msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
+msgstr ""
+
+#: fortran/module.c:6621
+#, gcc-internal-format
+msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
+msgstr ""
+
+#: fortran/module.c:6647
+#, gcc-internal-format, gfc-internal-format
+msgid "USE statement at %C has no ONLY qualifier"
+msgstr ""
+
+#: fortran/module.c:6665
+#, gcc-internal-format, gfc-internal-format
+msgid "ISO_FORTRAN_ENV intrinsic module at %C"
+msgstr ""
+
+#: fortran/module.c:6677
+#, gcc-internal-format, gfc-internal-format
+msgid "ISO_C_BINDING module at %C"
+msgstr ""
+
+#: fortran/module.c:6690
+#, gcc-internal-format
+msgid "Can't find an intrinsic module named %qs at %C"
+msgstr ""
+
+#: fortran/module.c:6696
+#, gcc-internal-format, gfc-internal-format
+msgid "IEEE_FEATURES module at %C"
+msgstr ""
+
+#: fortran/module.c:6702
+#, gcc-internal-format, gfc-internal-format
+msgid "IEEE_EXCEPTIONS module at %C"
+msgstr ""
+
+#: fortran/module.c:6708
+#, gcc-internal-format, gfc-internal-format
+msgid "IEEE_ARITHMETIC module at %C"
+msgstr ""
+
+#: fortran/module.c:6715
+#, gcc-internal-format
+msgid "Can't open module file %qs for reading at %C: %s"
+msgstr ""
+
+#: fortran/module.c:6723
+#, gcc-internal-format
+msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
+msgstr ""
+
+#: fortran/module.c:6746
+#, gcc-internal-format
+msgid "File %qs opened at %C is not a GNU Fortran module file"
+msgstr ""
+
+#: fortran/module.c:6754
+#, gcc-internal-format
+msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
+msgstr ""
+
+#: fortran/module.c:6768
+#, gcc-internal-format
+msgid "Can't USE the same module we're building!"
+msgstr ""
+
+#: fortran/openmp.c:268 fortran/openmp.c:2099 fortran/openmp.c:2173
+#, gcc-internal-format, gfc-internal-format
+msgid "COMMON block /%s/ not found at %C"
+msgstr ""
+
+#: fortran/openmp.c:306
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in OpenMP variable list at %C"
+msgstr ""
+
+#: fortran/openmp.c:368
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in OpenACC expression list at %C"
+msgstr ""
+
+#: fortran/openmp.c:837
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP DECLARE REDUCTION %s not found at %L"
+msgstr ""
+
+#: fortran/openmp.c:935
+#, gcc-internal-format, gfc-internal-format
+msgid "COLLAPSE clause argument not constant positive integer at %C"
+msgstr ""
+
+#: fortran/openmp.c:1356
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk in !$ACC WAIT at %C"
+msgstr ""
+
+#: fortran/openmp.c:1365
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid argument to $!ACC WAIT at %L"
+msgstr ""
+
+#: fortran/openmp.c:1374
+#, gcc-internal-format, gfc-internal-format
+msgid "WAIT clause at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.c:1402
+#, gcc-internal-format, gfc-internal-format
+msgid "ACC CACHE directive must be inside of loop %C"
+msgstr ""
+
+#: fortran/openmp.c:1428
+#, gcc-internal-format, gfc-internal-format
+msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
+msgstr ""
+
+#: fortran/openmp.c:1452
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
+msgstr ""
+
+#: fortran/openmp.c:1459
+#, gcc-internal-format
+msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %qs"
+msgstr ""
+
+#: fortran/openmp.c:1467
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
+msgstr ""
+
+#: fortran/openmp.c:1475
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after !$ACC ROUTINE at %C"
+msgstr ""
+
+#: fortran/openmp.c:1544
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP CRITICAL statement at %C"
+msgstr ""
+
+#: fortran/openmp.c:1609
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP FLUSH statement at %C"
+msgstr ""
+
+#: fortran/openmp.c:1992 fortran/openmp.c:4823
+#, gcc-internal-format, gfc-internal-format
+msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.c:1996 fortran/openmp.c:4827
+#, gcc-internal-format, gfc-internal-format
+msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.c:2001
+#, gcc-internal-format, gfc-internal-format
+msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.c:2003
+#, gcc-internal-format, gfc-internal-format
+msgid "Previous !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.c:2023
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
+msgstr ""
+
+#: fortran/openmp.c:2052
+#, gcc-internal-format, gfc-internal-format
+msgid "Only the !$OMP DECLARE TARGET form without list is allowed in interface block at %C"
+msgstr ""
+
+#: fortran/openmp.c:2078
+#, gcc-internal-format, gfc-internal-format
+msgid "OMP DECLARE TARGET on a variable at %C is an element of a COMMON block"
+msgstr ""
+
+#: fortran/openmp.c:2117
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
+msgstr ""
+
+#: fortran/openmp.c:2123
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
+msgstr ""
+
+#: fortran/openmp.c:2153
+#, gcc-internal-format, gfc-internal-format
+msgid "Threadprivate variable at %C is an element of a COMMON block"
+msgstr ""
+
+#: fortran/openmp.c:2190
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after OMP THREADPRIVATE at %C"
+msgstr ""
+
+#: fortran/openmp.c:2197
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
+msgstr ""
+
+#: fortran/openmp.c:2278
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after TASKWAIT clause at %C"
+msgstr ""
+
+#: fortran/openmp.c:2292
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after TASKYIELD clause at %C"
+msgstr ""
+
+#: fortran/openmp.c:2417
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
+msgstr ""
+
+#: fortran/openmp.c:2431
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP MASTER statement at %C"
+msgstr ""
+
+#: fortran/openmp.c:2445
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP ORDERED statement at %C"
+msgstr ""
+
+#: fortran/openmp.c:2490
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP ATOMIC statement at %C"
+msgstr ""
+
+#: fortran/openmp.c:2506
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP BARRIER statement at %C"
+msgstr ""
+
+#: fortran/openmp.c:2520
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
+msgstr ""
+
+#: fortran/openmp.c:2570
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
+msgstr ""
+
+#: fortran/openmp.c:2590
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after NOWAIT clause at %C"
+msgstr ""
+
+#: fortran/openmp.c:2630
+#, gcc-internal-format, gfc-internal-format
+msgid "%s clause at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.c:2641
+#, gcc-internal-format, gfc-internal-format
+msgid "INTEGER expression of %s clause at %L must be positive"
+msgstr ""
+
+#: fortran/openmp.c:2652
+#, gcc-internal-format
+msgid "POINTER object %qs of derived type in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2655
+#, gcc-internal-format
+msgid "Cray pointer object of derived type %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2658
+#, gcc-internal-format
+msgid "Cray pointee object of derived type %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2664
+#, gcc-internal-format
+msgid "POINTER object %qs of polymorphic type in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2669
+#, gcc-internal-format
+msgid "Cray pointer object of polymorphic type %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2674
+#, gcc-internal-format
+msgid "Cray pointee object of polymorphic type %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2684 fortran/openmp.c:3212
+#, gcc-internal-format
+msgid "Assumed size array %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2687
+#, gcc-internal-format
+msgid "Assumed rank array %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2691
+#, gcc-internal-format
+msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2699
+#, gcc-internal-format
+msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2704
+#, gcc-internal-format
+msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2716 fortran/openmp.c:3202 fortran/openmp.c:3375
+#, gcc-internal-format
+msgid "POINTER object %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2721 fortran/openmp.c:3378
+#, gcc-internal-format
+msgid "Cray pointer object %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2726 fortran/openmp.c:3381
+#, gcc-internal-format
+msgid "Cray pointee object %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2731 fortran/openmp.c:3370
+#, gcc-internal-format
+msgid "ALLOCATABLE object %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2734
+#, gcc-internal-format
+msgid "VALUE object %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:2777
+#, gcc-internal-format, gfc-internal-format
+msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L "
+msgstr ""
+
+#: fortran/openmp.c:2826
+#, gcc-internal-format, gfc-internal-format
+msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
+msgstr ""
+
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
+#, gcc-internal-format, gfc-internal-format
+msgid "IF clause at %L requires a scalar LOGICAL expression"
+msgstr ""
+
+#: fortran/openmp.c:2893
+#, gcc-internal-format, gfc-internal-format
+msgid "FINAL clause at %L requires a scalar LOGICAL expression"
+msgstr ""
+
+#: fortran/openmp.c:2901
+#, gcc-internal-format, gfc-internal-format
+msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.c:2909
+#, gcc-internal-format, gfc-internal-format
+msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.c:2924
+#, gcc-internal-format
+msgid "Variable %qs is not a dummy argument at %L"
+msgstr ""
+
+#: fortran/openmp.c:2956
+#, gcc-internal-format
+msgid "Object %qs is not a variable at %L"
+msgstr ""
+
+#: fortran/openmp.c:2972 fortran/openmp.c:2983 fortran/openmp.c:2991
+#: fortran/openmp.c:3002 fortran/openmp.c:3014 fortran/openmp.c:4635
+#, gcc-internal-format
+msgid "Symbol %qs present on multiple clauses at %L"
+msgstr ""
+
+#: fortran/openmp.c:3028
+#, gcc-internal-format
+msgid "Symbol %qs present on both FROM and TO clauses at %L"
+msgstr ""
+
+#: fortran/openmp.c:3050
+#, gcc-internal-format
+msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3058
+#, gcc-internal-format
+msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3061
+#, gcc-internal-format
+msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3069
+#, gcc-internal-format
+msgid "THREADPRIVATE object %qs in SHARED clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3072
+#, gcc-internal-format
+msgid "Cray pointee %qs in SHARED clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3075
+#, gcc-internal-format
+msgid "ASSOCIATE name %qs in SHARED clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3090
+#, gcc-internal-format
+msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
+msgstr ""
+
+#: fortran/openmp.c:3102
+#, gcc-internal-format
+msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
+msgstr ""
+
+#: fortran/openmp.c:3121 fortran/openmp.c:3141
+#, gcc-internal-format
+msgid "%qs in %s clause at %L is not a proper array section"
+msgstr ""
+
+#: fortran/openmp.c:3124
+#, gcc-internal-format, gfc-internal-format
+msgid "Coarrays not supported in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3133
+#, gcc-internal-format, gfc-internal-format
+msgid "Stride should not be specified for array section in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3154
+#, gcc-internal-format
+msgid "%qs in DEPEND clause at %L is a zero size array section"
+msgstr ""
+
+#: fortran/openmp.c:3176 fortran/openmp.c:3188
+#, gcc-internal-format
+msgid "THREADPRIVATE object %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3179 fortran/openmp.c:3191
+#, gcc-internal-format
+msgid "Cray pointee %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3194
+#, gcc-internal-format
+msgid "ASSOCIATE name %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3199
+#, gcc-internal-format
+msgid "Procedure pointer %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3205
+#, gcc-internal-format
+msgid "Cray pointer %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3215
+#, gcc-internal-format
+msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
+msgstr ""
+
+#. case OMP_LIST_REDUCTION:
+#: fortran/openmp.c:3225
+#, gcc-internal-format
+msgid "INTENT(IN) POINTER %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.c:3318
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
+msgstr ""
+
+#: fortran/openmp.c:3341
+#, gcc-internal-format
+msgid "LINEAR variable %qs must be INTEGER at %L"
+msgstr ""
+
+#: fortran/openmp.c:3344
+#, gcc-internal-format
+msgid "LINEAR dummy argument %qs must have VALUE attribute at %L"
+msgstr ""
+
+#: fortran/openmp.c:3352
+#, gcc-internal-format
+msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
+msgstr ""
+
+#: fortran/openmp.c:3356
+#, gcc-internal-format
+msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression"
+msgstr ""
+
+#: fortran/openmp.c:3401
+#, gcc-internal-format, gfc-internal-format
+msgid "SAFELEN clause at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.c:3409
+#, gcc-internal-format, gfc-internal-format
+msgid "SIMDLEN clause at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.c:3417
+#, gcc-internal-format, gfc-internal-format
+msgid "NUM_TEAMS clause at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.c:3425
+#, gcc-internal-format, gfc-internal-format
+msgid "DEVICE clause at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.c:3433
+#, gcc-internal-format, gfc-internal-format
+msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.c:3441
+#, gcc-internal-format, gfc-internal-format
+msgid "THREAD_LIMIT clause at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.c:3565
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
+msgstr ""
+
+#: fortran/openmp.c:3590
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
+msgstr ""
+
+#: fortran/openmp.c:3595
+#, gcc-internal-format, gfc-internal-format
+msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
+msgstr ""
+
+#: fortran/openmp.c:3617 fortran/openmp.c:3908
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
+msgstr ""
+
+#: fortran/openmp.c:3632
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
+msgstr ""
+
+#: fortran/openmp.c:3639 fortran/openmp.c:3915
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
+msgstr ""
+
+#: fortran/openmp.c:3655
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
+msgstr ""
+
+#: fortran/openmp.c:3697
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
+msgstr ""
+
+#: fortran/openmp.c:3745
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
+msgstr ""
+
+#: fortran/openmp.c:3759
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
+msgstr ""
+
+#: fortran/openmp.c:3791
+#, gcc-internal-format, gfc-internal-format
+msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
+msgstr ""
+
+#: fortran/openmp.c:3815
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
+msgstr ""
+
+#: fortran/openmp.c:3822
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
+msgstr ""
+
+#: fortran/openmp.c:3839
+#, gcc-internal-format
+msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
+msgstr ""
+
+#: fortran/openmp.c:3846
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
+msgstr ""
+
+#: fortran/openmp.c:3854
+#, gcc-internal-format
+msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
+msgstr ""
+
+#: fortran/openmp.c:3872
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
+msgstr ""
+
+#: fortran/openmp.c:3886
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
+msgstr ""
+
+#: fortran/openmp.c:4163
+#, gcc-internal-format, gfc-internal-format
+msgid "%s cannot be a DO WHILE or DO without loop control at %L"
+msgstr ""
+
+#: fortran/openmp.c:4169
+#, gcc-internal-format, gfc-internal-format
+msgid "%s cannot be a DO CONCURRENT loop at %L"
+msgstr ""
+
+#: fortran/openmp.c:4175
+#, gcc-internal-format, gfc-internal-format
+msgid "%s iteration variable must be of type integer at %L"
+msgstr ""
+
+#: fortran/openmp.c:4179
+#, gcc-internal-format, gfc-internal-format
+msgid "%s iteration variable must not be THREADPRIVATE at %L"
+msgstr ""
+
+#: fortran/openmp.c:4192
+#, gcc-internal-format, gfc-internal-format
+msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
+msgstr ""
+
+#: fortran/openmp.c:4196
+#, gcc-internal-format, gfc-internal-format
+msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
+msgstr ""
+
+#: fortran/openmp.c:4200
+#, gcc-internal-format, gfc-internal-format
+msgid "%s iteration variable present on clause other than LINEAR at %L"
+msgstr ""
+
+#: fortran/openmp.c:4218
+#, gcc-internal-format, gfc-internal-format
+msgid "%s collapsed loops don't form rectangular iteration space at %L"
+msgstr ""
+
+#: fortran/openmp.c:4232
+#, gcc-internal-format, gfc-internal-format
+msgid "collapsed %s loops not perfectly nested at %L"
+msgstr ""
+
+#: fortran/openmp.c:4241 fortran/openmp.c:4249
+#, gcc-internal-format, gfc-internal-format
+msgid "not enough DO loops for collapsed %s at %L"
+msgstr ""
+
+#: fortran/openmp.c:4331 fortran/openmp.c:4344
+#, gcc-internal-format, gfc-internal-format
+msgid "The %s directive cannot be specified within a %s region at %L"
+msgstr ""
+
+#: fortran/openmp.c:4363
+#, gcc-internal-format, gfc-internal-format
+msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
+msgstr ""
+
+#: fortran/openmp.c:4369
+#, gcc-internal-format, gfc-internal-format
+msgid "!$ACC LOOP iteration variable must be of type integer at %L"
+msgstr ""
+
+#: fortran/openmp.c:4385
+#, gcc-internal-format, gfc-internal-format
+msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
+msgstr ""
+
+#: fortran/openmp.c:4399
+#, gcc-internal-format, gfc-internal-format
+msgid "%s !$ACC LOOP loops not perfectly nested at %L"
+msgstr ""
+
+#: fortran/openmp.c:4409 fortran/openmp.c:4418
+#, gcc-internal-format, gfc-internal-format
+msgid "not enough DO loops for %s !$ACC LOOP at %L"
+msgstr ""
+
+#: fortran/openmp.c:4432 fortran/openmp.c:4439
+#, gcc-internal-format, gfc-internal-format
+msgid "!$ACC LOOP %s in PARALLEL region doesn't allow non-static arguments at %L"
+msgstr ""
+
+#: fortran/openmp.c:4461
+#, gcc-internal-format, gfc-internal-format
+msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
+msgstr ""
+
+#: fortran/openmp.c:4465 fortran/openmp.c:4469
+#, gcc-internal-format, gfc-internal-format
+msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
+msgstr ""
+
+#: fortran/openmp.c:4476
+#, gcc-internal-format, gfc-internal-format
+msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
+msgstr ""
+
+#: fortran/openmp.c:4480
+#, gcc-internal-format, gfc-internal-format
+msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
+msgstr ""
+
+#: fortran/openmp.c:4486
+#, gcc-internal-format, gfc-internal-format
+msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
+msgstr ""
+
+#: fortran/openmp.c:4498
+#, gcc-internal-format, gfc-internal-format
+msgid "Clause SEQ conflicts with INDEPENDENT at %L"
+msgstr ""
+
+#: fortran/openmp.c:4500
+#, gcc-internal-format, gfc-internal-format
+msgid "Clause SEQ conflicts with GANG at %L"
+msgstr ""
+
+#: fortran/openmp.c:4502
+#, gcc-internal-format, gfc-internal-format
+msgid "Clause SEQ conflicts with WORKER at %L"
+msgstr ""
+
+#: fortran/openmp.c:4504
+#, gcc-internal-format, gfc-internal-format
+msgid "Clause SEQ conflicts with VECTOR at %L"
+msgstr ""
+
+#: fortran/openmp.c:4506
+#, gcc-internal-format, gfc-internal-format
+msgid "Clause SEQ conflicts with AUTO at %L"
+msgstr ""
+
+#: fortran/openmp.c:4511
+#, gcc-internal-format, gfc-internal-format
+msgid "Clause AUTO conflicts with GANG at %L"
+msgstr ""
+
+#: fortran/openmp.c:4513
+#, gcc-internal-format, gfc-internal-format
+msgid "Clause AUTO conflicts with WORKER at %L"
+msgstr ""
+
+#: fortran/openmp.c:4515
+#, gcc-internal-format, gfc-internal-format
+msgid "Clause AUTO conflicts with VECTOR at %L"
+msgstr ""
+
+#: fortran/openmp.c:4522
+#, gcc-internal-format, gfc-internal-format
+msgid "Clause GANG conflicts with WORKER at %L"
+msgstr ""
+
+#: fortran/openmp.c:4524
+#, gcc-internal-format, gfc-internal-format
+msgid "Clause GANG conflicts with VECTOR at %L"
+msgstr ""
+
+#: fortran/openmp.c:4528
+#, gcc-internal-format, gfc-internal-format
+msgid "Clause WORKER conflicts with VECTOR at %L"
+msgstr ""
+
+#: fortran/openmp.c:4533
+#, gcc-internal-format, gfc-internal-format
+msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
+msgstr ""
+
+#: fortran/openmp.c:4556
+#, gcc-internal-format, gfc-internal-format
+msgid "TILE requires constant expression at %L"
+msgstr ""
+
+#: fortran/openmp.c:4605
+#, gcc-internal-format
+msgid "Sorry, !$ACC cache unimplemented yet"
+msgstr ""
+
+#: fortran/openmp.c:4627
+#, gcc-internal-format
+msgid "PARAMETER object %qs is not allowed at %L"
+msgstr ""
+
+#: fortran/openmp.c:4732
+#, gcc-internal-format, gfc-internal-format
+msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
+msgstr ""
+
+#: fortran/openmp.c:4753
+#, gcc-internal-format
+msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
+msgstr ""
+
+#: fortran/openmp.c:4777
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.c:4785
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.c:4814
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
+msgstr ""
+
+#: fortran/openmp.c:4836
+#, gcc-internal-format, gfc-internal-format
+msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
+msgstr ""
+
+#: fortran/openmp.c:4852
+#, gcc-internal-format, gfc-internal-format
+msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.c:4867
+#, gcc-internal-format, gfc-internal-format
+msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.c:4877
+#, gcc-internal-format, gfc-internal-format
+msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
+msgstr ""
+
+#: fortran/openmp.c:4885
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
+msgstr ""
+
+#: fortran/options.c:217
+#, gcc-internal-format
+msgid "-fexcess-precision=standard for Fortran"
+msgstr ""
+
+#: fortran/options.c:304
+#, gcc-internal-format
+msgid "Reading file %qs as free form"
+msgstr ""
+
+#: fortran/options.c:314
+#, gcc-internal-format
+msgid "%<-fd-lines-as-comments%> has no effect in free form"
+msgstr ""
+
+#: fortran/options.c:317
+#, gcc-internal-format
+msgid "%<-fd-lines-as-code%> has no effect in free form"
+msgstr ""
+
+#: fortran/options.c:348
+#, gcc-internal-format
+msgid "Flag %<-fno-automatic%> overwrites %<-fmax-stack-var-size=%d%>"
+msgstr ""
+
+#: fortran/options.c:351
+#, gcc-internal-format
+msgid "Flag %<-fno-automatic%> overwrites %<-frecursive%>"
+msgstr ""
+
+#: fortran/options.c:353
+#, gcc-internal-format
+msgid "Flag %<-fno-automatic%> overwrites %<-frecursive%> implied by %<-fopenmp%>"
+msgstr ""
+
+#: fortran/options.c:356
+#, gcc-internal-format
+msgid "Flag %<-frecursive%> overwrites %<-fmax-stack-var-size=%d%>"
+msgstr ""
+
+#: fortran/options.c:359
+#, gcc-internal-format
+msgid "Flag %<-fmax-stack-var-size=%d%> overwrites %<-frecursive%> implied by %<-fopenmp%>"
+msgstr ""
+
+#: fortran/options.c:391
+#, gcc-internal-format
+msgid "Fixed line length must be at least seven"
+msgstr ""
+
+#: fortran/options.c:394
+#, gcc-internal-format
+msgid "Free line length must be at least three"
+msgstr ""
+
+#: fortran/options.c:397
+#, gcc-internal-format, gfc-internal-format
+msgid "Maximum subrecord length cannot exceed %d"
+msgstr ""
+
+#: fortran/options.c:416
+#, gcc-internal-format
+msgid "gfortran: Only one %<-J%> option allowed"
+msgstr ""
+
+#: fortran/options.c:488
+#, gcc-internal-format
+msgid "Argument to %<-ffpe-trap%> is not valid: %s"
+msgstr ""
+
+#: fortran/options.c:490
+#, gcc-internal-format
+msgid "Argument to %<-ffpe-summary%> is not valid: %s"
+msgstr ""
+
+#: fortran/options.c:530
+#, gcc-internal-format
+msgid "Argument to %<-fcheck%> is not valid: %s"
+msgstr ""
+
+#: fortran/options.c:579
+#, gcc-internal-format
+msgid "%<-static-libgfortran%> is not supported in this configuration"
+msgstr ""
+
+#: fortran/options.c:602
+#, gcc-internal-format, gfc-internal-format
+msgid "Maximum supported identifier length is %d"
+msgstr ""
+
+#: fortran/options.c:622
+#, gcc-internal-format
+msgid "Unrecognized option to %<-finit-logical%>: %s"
+msgstr ""
+
+#: fortran/options.c:638
+#, gcc-internal-format
+msgid "The value of n in %<-finit-character=n%> must be between 0 and 127"
+msgstr ""
+
+#: fortran/parse.c:556
+#, gcc-internal-format, gfc-internal-format
+msgid "Unclassifiable statement at %C"
+msgstr ""
+
+#: fortran/parse.c:600
+#, gcc-internal-format, gfc-internal-format
+msgid "OpenACC directives at %C may not appear in PURE procedures"
+msgstr ""
+
+#: fortran/parse.c:665
+#, gcc-internal-format, gfc-internal-format
+msgid "Unclassifiable OpenACC directive at %C"
+msgstr ""
+
+#: fortran/parse.c:688
+#, gcc-internal-format, gfc-internal-format
+msgid "OpenMP directives at %C may not appear in PURE or ELEMENTAL procedures"
+msgstr ""
+
+#: fortran/parse.c:863
+#, gcc-internal-format, gfc-internal-format
+msgid "Unclassifiable OpenMP directive at %C"
+msgstr ""
+
+#: fortran/parse.c:890
+#, gcc-internal-format, gfc-internal-format
+msgid "Unclassifiable GCC directive at %C"
+msgstr ""
+
+#: fortran/parse.c:949 fortran/parse.c:1181
+#, gcc-internal-format, gfc-internal-format
+msgid "Zero is not a valid statement label at %C"
+msgstr ""
+
+#: fortran/parse.c:956 fortran/parse.c:1173
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-numeric character in statement label at %C"
+msgstr ""
+
+#: fortran/parse.c:968 fortran/parse.c:1222
+#, gcc-internal-format, gfc-internal-format
+msgid "Semicolon at %C needs to be preceded by statement"
+msgstr ""
+
+#: fortran/parse.c:976 fortran/parse.c:1237
+#, gcc-internal-format, gfc-internal-format
+msgid "Ignoring statement label in empty statement at %L"
+msgstr ""
+
+#: fortran/parse.c:1043 fortran/parse.c:1224
+#, gcc-internal-format, gfc-internal-format
+msgid "Fortran 2008: Semicolon at %C without preceding statement"
+msgstr ""
+
+#: fortran/parse.c:1066 fortran/parse.c:1200
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad continuation line at %C"
+msgstr ""
+
+#: fortran/parse.c:1485
+#, gcc-internal-format, gfc-internal-format
+msgid "FORMAT statement at %L does not have a statement label"
+msgstr ""
+
+#: fortran/parse.c:2147
+#, gcc-internal-format
+msgid "gfc_ascii_statement(): Bad statement code"
+msgstr ""
+
+#: fortran/parse.c:2291
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement at %C"
+msgstr ""
+
+#: fortran/parse.c:2438
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C cannot follow %s statement at %L"
+msgstr ""
+
+#: fortran/parse.c:2455
+#, gcc-internal-format
+msgid "Unexpected end of file in %qs"
+msgstr ""
+
+#: fortran/parse.c:2487
+#, gcc-internal-format
+msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
+msgstr ""
+
+#: fortran/parse.c:2490
+#, gcc-internal-format
+msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
+msgstr ""
+
+#: fortran/parse.c:2510
+#, gcc-internal-format, gfc-internal-format
+msgid "Components in TYPE at %C must precede CONTAINS"
+msgstr ""
+
+#: fortran/parse.c:2514
+#, gcc-internal-format, gfc-internal-format
+msgid "Type-bound procedure at %C"
+msgstr ""
+
+#: fortran/parse.c:2522
+#, gcc-internal-format, gfc-internal-format
+msgid "GENERIC binding at %C"
+msgstr ""
+
+#: fortran/parse.c:2530
+#, gcc-internal-format, gfc-internal-format
+msgid "FINAL procedure declaration at %C"
+msgstr ""
+
+#: fortran/parse.c:2542
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type definition at %C with empty CONTAINS section"
+msgstr ""
+
+#: fortran/parse.c:2552 fortran/parse.c:2655
+#, gcc-internal-format, gfc-internal-format
+msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
+msgstr ""
+
+#: fortran/parse.c:2559
+#, gcc-internal-format, gfc-internal-format
+msgid "PRIVATE statement at %C must precede procedure bindings"
+msgstr ""
+
+#: fortran/parse.c:2566 fortran/parse.c:2668
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate PRIVATE statement at %C"
+msgstr ""
+
+#: fortran/parse.c:2576
+#, gcc-internal-format, gfc-internal-format
+msgid "SEQUENCE statement at %C must precede CONTAINS"
+msgstr ""
+
+#: fortran/parse.c:2580
+#, gcc-internal-format, gfc-internal-format
+msgid "Already inside a CONTAINS block at %C"
+msgstr ""
+
+#: fortran/parse.c:2638
+#, gcc-internal-format, gfc-internal-format
+msgid "FINAL declaration at %C must be inside CONTAINS"
+msgstr ""
+
+#: fortran/parse.c:2646
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type definition at %C without components"
+msgstr ""
+
+#: fortran/parse.c:2662
+#, gcc-internal-format, gfc-internal-format
+msgid "PRIVATE statement at %C must precede structure components"
+msgstr ""
+
+#: fortran/parse.c:2679
+#, gcc-internal-format, gfc-internal-format
+msgid "SEQUENCE statement at %C must precede structure components"
+msgstr ""
+
+#: fortran/parse.c:2685
+#, gcc-internal-format, gfc-internal-format
+msgid "SEQUENCE attribute at %C already specified in TYPE statement"
+msgstr ""
+
+#: fortran/parse.c:2690
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate SEQUENCE statement at %C"
+msgstr ""
+
+#: fortran/parse.c:2700
+#, gcc-internal-format, gfc-internal-format
+msgid "CONTAINS block in derived type definition at %C"
+msgstr ""
+
+#: fortran/parse.c:2788
+#, gcc-internal-format, gfc-internal-format
+msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
+msgstr ""
+
+#: fortran/parse.c:2794
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
+msgstr ""
+
+#: fortran/parse.c:2799
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
+msgstr ""
+
+#: fortran/parse.c:2803
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
+msgstr ""
+
+#: fortran/parse.c:2808
+#, gcc-internal-format, gfc-internal-format
+msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
+msgstr ""
+
+#: fortran/parse.c:2815
+#, gcc-internal-format, gfc-internal-format
+msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
+msgstr ""
+
+#: fortran/parse.c:2867
+#, gcc-internal-format, gfc-internal-format
+msgid "ENUM declaration at %C has no ENUMERATORS"
+msgstr ""
+
+#: fortran/parse.c:2950
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement in INTERFACE block at %C"
+msgstr ""
+
+#: fortran/parse.c:2974
+#, gcc-internal-format
+msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
+msgstr ""
+
+#: fortran/parse.c:3007
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement at %C in INTERFACE body"
+msgstr ""
+
+#: fortran/parse.c:3025
+#, gcc-internal-format
+msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
+msgstr ""
+
+#: fortran/parse.c:3150
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement is not allowed inside of BLOCK at %C"
+msgstr ""
+
+#: fortran/parse.c:3180
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement is not allowed inside of BLOCK DATA at %C"
+msgstr ""
+
+#: fortran/parse.c:3264
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement must appear in a MODULE"
+msgstr ""
+
+#: fortran/parse.c:3272
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C follows another accessibility specification"
+msgstr ""
+
+#: fortran/parse.c:3336
+#, gcc-internal-format
+msgid "Bad kind expression for function %qs at %L"
+msgstr ""
+
+#: fortran/parse.c:3340
+#, gcc-internal-format
+msgid "The type for function %qs at %L is not accessible"
+msgstr ""
+
+#: fortran/parse.c:3398
+#, gcc-internal-format, gfc-internal-format
+msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
+msgstr ""
+
+#: fortran/parse.c:3420
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement in WHERE block at %C"
+msgstr ""
+
+#: fortran/parse.c:3479
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement in FORALL block at %C"
+msgstr ""
+
+#: fortran/parse.c:3530
+#, gcc-internal-format, gfc-internal-format
+msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
+msgstr ""
+
+#: fortran/parse.c:3548
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate ELSE statements at %L and %C"
+msgstr ""
+
+#: fortran/parse.c:3609
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
+msgstr ""
+
+#: fortran/parse.c:3692
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
+msgstr ""
+
+#: fortran/parse.c:3754
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
+msgstr ""
+
+#: fortran/parse.c:3787
+#, gcc-internal-format, gfc-internal-format
+msgid "End of nonblock DO statement at %C is within another block"
+msgstr ""
+
+#: fortran/parse.c:3797
+#, gcc-internal-format, gfc-internal-format
+msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
+msgstr ""
+
+#: fortran/parse.c:3823
+#, gcc-internal-format, gfc-internal-format
+msgid "CRITICAL block inside of OpenACC region at %C"
+msgstr ""
+
+#: fortran/parse.c:3850
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
+msgstr ""
+
+#: fortran/parse.c:3918
+#, gcc-internal-format, gfc-internal-format
+msgid "BLOCK construct at %C"
+msgstr ""
+
+#: fortran/parse.c:3948
+#, gcc-internal-format, gfc-internal-format
+msgid "ASSOCIATE construct at %C"
+msgstr ""
+
+#: fortran/parse.c:4048
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement label in ENDDO at %C doesn't match DO label"
+msgstr ""
+
+#: fortran/parse.c:4064
+#, gcc-internal-format, gfc-internal-format
+msgid "Named block DO at %L requires matching ENDDO name"
+msgstr ""
+
+#: fortran/parse.c:4235
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
+msgstr ""
+
+#: fortran/parse.c:4251 fortran/parse.c:4308
+#, gcc-internal-format, gfc-internal-format
+msgid "OpenACC directive inside of CRITICAL block at %C"
+msgstr ""
+
+#: fortran/parse.c:4284
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting %s at %C"
+msgstr ""
+
+#: fortran/parse.c:4327
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected DO loop at %C"
+msgstr ""
+
+#: fortran/parse.c:4347
+#, gcc-internal-format, gfc-internal-format
+msgid "Redundant !$ACC END LOOP at %C"
+msgstr ""
+
+#: fortran/parse.c:4560
+#, gcc-internal-format, gfc-internal-format
+msgid "Name after !$omp critical and !$omp end critical does not match at %C"
+msgstr ""
+
+#: fortran/parse.c:4617
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C cannot terminate a non-block DO loop"
+msgstr ""
+
+#: fortran/parse.c:4631
+#, gcc-internal-format, gfc-internal-format
+msgid "DATA statement at %C after the first executable statement"
+msgstr ""
+
+#: fortran/parse.c:4858
+#, gcc-internal-format
+msgid "Contained procedure %qs at %C is already ambiguous"
+msgstr ""
+
+#: fortran/parse.c:4914
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement in CONTAINS section at %C"
+msgstr ""
+
+#: fortran/parse.c:4938
+#, gcc-internal-format, gfc-internal-format
+msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
+msgstr ""
+
+#: fortran/parse.c:5015
+#, gcc-internal-format, gfc-internal-format
+msgid "CONTAINS statement at %C is already in a contained program unit"
+msgstr ""
+
+#: fortran/parse.c:5068
+#, gcc-internal-format
+msgid "gfc_global_used(): Bad type"
+msgstr ""
+
+#: fortran/parse.c:5073
+#, gcc-internal-format, gfc-internal-format
+msgid "Global binding name '%s' at %L is already being used as a %s at %L"
+msgstr ""
+
+#: fortran/parse.c:5076
+#, gcc-internal-format, gfc-internal-format
+msgid "Global name '%s' at %L is already being used as a %s at %L"
+msgstr ""
+
+#: fortran/parse.c:5097
+#, gcc-internal-format, gfc-internal-format
+msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
+msgstr ""
+
+#: fortran/parse.c:5123
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement in BLOCK DATA at %C"
+msgstr ""
+
+#: fortran/parse.c:5168
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement in MODULE at %C"
+msgstr ""
+
+#. If we see a duplicate main program, shut down.  If the second
+#. instance is an implied main program, i.e. data decls or executable
+#. statements, we're in for lots of errors.
+#: fortran/parse.c:5546
+#, gcc-internal-format, gfc-internal-format
+msgid "Two main PROGRAMs at %L and %C"
+msgstr ""
+
+#: fortran/primary.c:105
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing kind-parameter at %C"
+msgstr ""
+
+#: fortran/primary.c:138
+#, gcc-internal-format
+msgid "gfc_check_digit(): bad radix"
+msgstr ""
+
+#: fortran/primary.c:232
+#, gcc-internal-format, gfc-internal-format
+msgid "Integer kind %d at %C not available"
+msgstr ""
+
+#: fortran/primary.c:241
+#, gcc-internal-format, gfc-internal-format
+msgid "Integer too big for its kind at %C. This check can be disabled with the option -fno-range-check"
+msgstr ""
+
+#: fortran/primary.c:270
+#, gcc-internal-format, gfc-internal-format
+msgid "Hollerith constant at %C"
+msgstr ""
+
+#: fortran/primary.c:281
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid Hollerith constant: %L must contain at least one character"
+msgstr ""
+
+#: fortran/primary.c:287
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid Hollerith constant: Integer kind at %L should be default"
+msgstr ""
+
+#: fortran/primary.c:307
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid Hollerith constant at %L contains a wide character"
+msgstr ""
+
+#: fortran/primary.c:393
+#, gcc-internal-format, gfc-internal-format
+msgid "Hexadecimal constant at %C uses non-standard syntax"
+msgstr ""
+
+#: fortran/primary.c:402
+#, gcc-internal-format, gfc-internal-format
+msgid "Empty set of digits in BOZ constant at %C"
+msgstr ""
+
+#: fortran/primary.c:408
+#, gcc-internal-format, gfc-internal-format
+msgid "Illegal character in BOZ constant at %C"
+msgstr ""
+
+#: fortran/primary.c:431
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ constant at %C uses non-standard postfix syntax"
+msgstr ""
+
+#: fortran/primary.c:461
+#, gcc-internal-format, gfc-internal-format
+msgid "Integer too big for integer kind %i at %C"
+msgstr ""
+
+#: fortran/primary.c:467
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ used outside a DATA statement at %C"
+msgstr ""
+
+#: fortran/primary.c:557
+#, gcc-internal-format, gfc-internal-format
+msgid "exponent-letter 'q' in real-literal-constant at %C"
+msgstr ""
+
+#: fortran/primary.c:562
+#, gcc-internal-format
+msgid "Extension: exponent-letter %<q%> in real-literal-constant at %C"
+msgstr ""
+
+#: fortran/primary.c:578
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing exponent in real number at %C"
+msgstr ""
+
+#: fortran/primary.c:634
+#, gcc-internal-format
+msgid "Real number at %C has a %<d%> exponent and an explicit kind"
+msgstr ""
+
+#: fortran/primary.c:664
+#, gcc-internal-format
+msgid "Real number at %C has a %<q%> exponent and an explicit kind"
+msgstr ""
+
+#: fortran/primary.c:678
+#, gcc-internal-format
+msgid "Invalid exponent-letter %<q%> in real-literal-constant at %C"
+msgstr ""
+
+#: fortran/primary.c:711
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid real kind %d at %C"
+msgstr ""
+
+#: fortran/primary.c:726
+#, gcc-internal-format, gfc-internal-format
+msgid "Real constant overflows its kind at %C"
+msgstr ""
+
+#: fortran/primary.c:731
+#, gcc-internal-format, gfc-internal-format
+msgid "Real constant underflows its kind at %C"
+msgstr ""
+
+#: fortran/primary.c:736
+#, gcc-internal-format
+msgid "gfc_range_check() returned bad value"
+msgstr ""
+
+#: fortran/primary.c:823
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in SUBSTRING specification at %C"
+msgstr ""
+
+#: fortran/primary.c:1035
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid kind %d for CHARACTER constant at %C"
+msgstr ""
+
+#: fortran/primary.c:1056
+#, gcc-internal-format, gfc-internal-format
+msgid "Unterminated character constant beginning at %C"
+msgstr ""
+
+#: fortran/primary.c:1086
+#, gcc-internal-format
+msgid "Character %qs in string at %C is not representable in character kind %d"
+msgstr ""
+
+#: fortran/primary.c:1099
+#, gcc-internal-format
+msgid "match_string_constant(): Delimiter not found"
+msgstr ""
+
+#: fortran/primary.c:1169
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad kind for logical constant at %C"
+msgstr ""
+
+#: fortran/primary.c:1201
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected PARAMETER symbol in complex constant at %C"
+msgstr ""
+
+#: fortran/primary.c:1207
+#, gcc-internal-format, gfc-internal-format
+msgid "Numeric PARAMETER required in complex constant at %C"
+msgstr ""
+
+#: fortran/primary.c:1213
+#, gcc-internal-format, gfc-internal-format
+msgid "Scalar PARAMETER required in complex constant at %C"
+msgstr ""
+
+#: fortran/primary.c:1217
+#, gcc-internal-format, gfc-internal-format
+msgid "PARAMETER symbol in complex constant at %C"
+msgstr ""
+
+#: fortran/primary.c:1240
+#, gcc-internal-format
+msgid "gfc_match_sym_complex_part(): Bad type"
+msgstr ""
+
+#: fortran/primary.c:1247
+#, gcc-internal-format, gfc-internal-format
+msgid "Error converting PARAMETER constant in complex constant at %C"
+msgstr ""
+
+#: fortran/primary.c:1376
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in COMPLEX constant at %C"
+msgstr ""
+
+#: fortran/primary.c:1583
+#, gcc-internal-format
+msgid "Keyword %qs at %C has already appeared in the current argument list"
+msgstr ""
+
+#: fortran/primary.c:1647
+#, gcc-internal-format, gfc-internal-format
+msgid "argument list function at %C"
+msgstr ""
+
+#: fortran/primary.c:1715
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected alternate return label at %C"
+msgstr ""
+
+#: fortran/primary.c:1737
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing keyword name in actual argument list at %C"
+msgstr ""
+
+#: fortran/primary.c:1783
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in argument list at %C"
+msgstr ""
+
+#: fortran/primary.c:1804
+#, gcc-internal-format
+msgid "extend_ref(): Bad tail"
+msgstr ""
+
+#: fortran/primary.c:1842
+#, gcc-internal-format, gfc-internal-format
+msgid "Array section designator, e.g. '(:)', is required besides the coarray designator '[...]' at %C"
+msgstr ""
+
+#: fortran/primary.c:1850
+#, gcc-internal-format
+msgid "Coarray designator at %C but %qs is not a coarray"
+msgstr ""
+
+#: fortran/primary.c:1920
+#, gcc-internal-format
+msgid "Symbol %qs at %C has no IMPLICIT type"
+msgstr ""
+
+#: fortran/primary.c:1926
+#, gcc-internal-format
+msgid "Unexpected %<%%%> for nonderived-type variable %qs at %C"
+msgstr ""
+
+#: fortran/primary.c:1944
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected structure component name at %C"
+msgstr ""
+
+#: fortran/primary.c:1995
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected argument list at %C"
+msgstr ""
+
+#: fortran/primary.c:2026
+#, gcc-internal-format
+msgid "Procedure pointer component %qs requires an argument list at %C"
+msgstr ""
+
+#: fortran/primary.c:2113
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed procedure-pointer component at %C"
+msgstr ""
+
+#: fortran/primary.c:2148
+#, gcc-internal-format
+msgid "gfc_variable_attr(): Expression isn't a variable"
+msgstr ""
+
+#: fortran/primary.c:2216
+#, gcc-internal-format
+msgid "gfc_variable_attr(): Bad array reference"
+msgstr ""
+
+#: fortran/primary.c:2386
+#, gcc-internal-format, gfc-internal-format
+msgid "Structure constructor with missing optional arguments at %C"
+msgstr ""
+
+#: fortran/primary.c:2395
+#, gcc-internal-format
+msgid "No initializer for allocatable component '%qs' given in the structure constructor at %C"
+msgstr ""
+
+#: fortran/primary.c:2402
+#, gcc-internal-format
+msgid "No initializer for component %qs given in the structure constructor at %C!"
+msgstr ""
+
+#: fortran/primary.c:2450
+#, gcc-internal-format
+msgid "Can't construct ABSTRACT type %qs at %L"
+msgstr ""
+
+#: fortran/primary.c:2470
+#, gcc-internal-format, gfc-internal-format
+msgid "Structure constructor with named arguments at %C"
+msgstr ""
+
+#: fortran/primary.c:2485
+#, gcc-internal-format, gfc-internal-format
+msgid "Component initializer without name after component named %s at %L!"
+msgstr ""
+
+#: fortran/primary.c:2490
+#, gcc-internal-format, gfc-internal-format
+msgid "Too many components in structure constructor at %L!"
+msgstr ""
+
+#: fortran/primary.c:2527
+#, gcc-internal-format
+msgid "Component %qs is initialized twice in the structure constructor at %L!"
+msgstr ""
+
+#: fortran/primary.c:2539
+#, gcc-internal-format
+msgid "Coindexed expression to pointer component %qs in structure constructor at %L!"
+msgstr ""
+
+#: fortran/primary.c:2593
+#, gcc-internal-format
+msgid "component %qs at %L has already been set by a parent derived type constructor"
+msgstr ""
+
+#: fortran/primary.c:2776
+#, gcc-internal-format
+msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
+msgstr ""
+
+#: fortran/primary.c:2899
+#, gcc-internal-format
+msgid "Unexpected use of subroutine name %qs at %C"
+msgstr ""
+
+#: fortran/primary.c:2930
+#, gcc-internal-format
+msgid "Statement function %qs requires argument list at %C"
+msgstr ""
+
+#: fortran/primary.c:2933
+#, gcc-internal-format
+msgid "Function %qs requires an argument list at %C"
+msgstr ""
+
+#: fortran/primary.c:2983
+#, gcc-internal-format
+msgid "Missing argument to %qs at %C"
+msgstr ""
+
+#: fortran/primary.c:3139
+#, gcc-internal-format
+msgid "Missing argument list in function %qs at %C"
+msgstr ""
+
+#: fortran/primary.c:3173
+#, gcc-internal-format, gfc-internal-format
+msgid "Symbol at %C is not appropriate for an expression"
+msgstr ""
+
+#: fortran/primary.c:3272
+#, gcc-internal-format, gfc-internal-format
+msgid "Named constant at %C in an EQUIVALENCE"
+msgstr ""
+
+#: fortran/primary.c:3306
+#, gcc-internal-format
+msgid "%qs at %C is not a variable"
+msgstr ""
+
+#: fortran/resolve.c:125
+#, gcc-internal-format
+msgid "%qs at %L is of the ABSTRACT type %qs"
+msgstr ""
+
+#: fortran/resolve.c:128
+#, gcc-internal-format
+msgid "ABSTRACT type %qs used at %L"
+msgstr ""
+
+#: fortran/resolve.c:145
+#, gcc-internal-format
+msgid "Interface %qs at %L is declared in a later PROCEDURE statement"
+msgstr ""
+
+#: fortran/resolve.c:158
+#, gcc-internal-format
+msgid "Interface %qs at %L may not be generic"
+msgstr ""
+
+#: fortran/resolve.c:165
+#, gcc-internal-format
+msgid "Interface %qs at %L may not be a statement function"
+msgstr ""
+
+#: fortran/resolve.c:174
+#, gcc-internal-format
+msgid "Intrinsic procedure %qs not allowed in PROCEDURE statement at %L"
+msgstr ""
+
+#: fortran/resolve.c:180
+#, gcc-internal-format
+msgid "Interface %qs at %L must be explicit"
+msgstr ""
+
+#: fortran/resolve.c:202
+#, gcc-internal-format
+msgid "PROCEDURE %qs at %L may not be used as its own interface"
+msgstr ""
+
+#: fortran/resolve.c:296
+#, gcc-internal-format
+msgid "Alternate return specifier in elemental subroutine %qs at %L is not allowed"
+msgstr ""
+
+#: fortran/resolve.c:300
+#, gcc-internal-format
+msgid "Alternate return specifier in function %qs at %L is not allowed"
+msgstr ""
+
+#: fortran/resolve.c:311
+#, gcc-internal-format
+msgid "Self-referential argument %qs at %L is not allowed"
+msgstr ""
+
+#: fortran/resolve.c:383
+#, gcc-internal-format
+msgid "Dummy procedure %qs of PURE procedure at %L must also be PURE"
+msgstr ""
+
+#: fortran/resolve.c:393
+#, gcc-internal-format
+msgid "Argument %qs of pure function %qs at %L with VALUE attribute but without INTENT(IN)"
+msgstr ""
+
+#: fortran/resolve.c:398
+#, gcc-internal-format
+msgid "Argument %qs of pure function %qs at %L must be INTENT(IN) or VALUE"
+msgstr ""
+
+#: fortran/resolve.c:406
+#, gcc-internal-format
+msgid "Argument %qs of pure subroutine %qs at %L with VALUE attribute but without INTENT"
+msgstr ""
+
+#: fortran/resolve.c:411
+#, gcc-internal-format
+msgid "Argument %qs of pure subroutine %qs at %L must have its INTENT specified or have the VALUE attribute"
+msgstr ""
+
+#: fortran/resolve.c:421
+#, gcc-internal-format
+msgid "INTENT(OUT) argument '%s' of pure procedure %qs at %L may not be polymorphic"
+msgstr ""
+
+#: fortran/resolve.c:454
+#, gcc-internal-format
+msgid "Coarray dummy argument %qs at %L to elemental procedure"
+msgstr ""
+
+#: fortran/resolve.c:462
+#, gcc-internal-format
+msgid "Argument %qs of elemental procedure at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.c:471
+#, gcc-internal-format
+msgid "Argument %qs of elemental procedure at %L cannot have the ALLOCATABLE attribute"
+msgstr ""
+
+#: fortran/resolve.c:481
+#, gcc-internal-format
+msgid "Argument %qs of elemental procedure at %L cannot have the POINTER attribute"
+msgstr ""
+
+#: fortran/resolve.c:489
+#, gcc-internal-format
+msgid "Dummy procedure %qs not allowed in elemental procedure %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:498
+#, gcc-internal-format
+msgid "Argument %qs of elemental procedure %qs at %L must have its INTENT specified or have the VALUE attribute"
+msgstr ""
+
+#: fortran/resolve.c:511
+#, gcc-internal-format
+msgid "Argument %qs of statement function at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.c:521
+#, gcc-internal-format
+msgid "Character-valued argument %qs of statement function at %L must have constant length"
+msgstr ""
+
+#: fortran/resolve.c:579
+#, gcc-internal-format
+msgid "Contained function %qs at %L has no IMPLICIT type"
+msgstr ""
+
+#: fortran/resolve.c:582
+#, gcc-internal-format
+msgid "Result %qs of contained function %qs at %L has no IMPLICIT type"
+msgstr ""
+
+#: fortran/resolve.c:606
+#, gcc-internal-format
+msgid "Character-valued %s %qs at %L must not be assumed length"
+msgstr ""
+
+#: fortran/resolve.c:780
+#, gcc-internal-format, gfc-internal-format
+msgid "Function %s at %L has entries with mismatched array specifications"
+msgstr ""
+
+#: fortran/resolve.c:797
+#, gcc-internal-format, gfc-internal-format
+msgid "Function %s at %L with entries returning variables of different string lengths"
+msgstr ""
+
+#: fortran/resolve.c:824
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s can't be an array in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.c:828
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s can't be an array in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.c:835
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s can't be a POINTER in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.c:839
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s can't be a POINTER in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.c:877
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s can't be of type %s in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.c:882
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s can't be of type %s in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.c:925
+#, gcc-internal-format
+msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
+msgstr ""
+
+#: fortran/resolve.c:929
+#, gcc-internal-format
+msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
+msgstr ""
+
+#: fortran/resolve.c:936
+#, gcc-internal-format
+msgid "%qs in cannot appear in COMMON at %L [F2008:C5100]"
+msgstr ""
+
+#: fortran/resolve.c:944
+#, gcc-internal-format
+msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
+msgstr ""
+
+#: fortran/resolve.c:948
+#, gcc-internal-format
+msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
+msgstr ""
+
+#: fortran/resolve.c:952
+#, gcc-internal-format
+msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
+msgstr ""
+
+#: fortran/resolve.c:996
+#, gcc-internal-format, gfc-internal-format
+msgid "In Fortran 2003 COMMON '%s' block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
+msgstr ""
+
+#: fortran/resolve.c:1010
+#, gcc-internal-format, gfc-internal-format
+msgid "COMMON block '%s' at %L uses the same global identifier as entity at %L"
+msgstr ""
+
+#: fortran/resolve.c:1018
+#, gcc-internal-format, gfc-internal-format
+msgid "Fortran 2008: COMMON block '%s' with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
+msgstr ""
+
+#: fortran/resolve.c:1040
+#, gcc-internal-format, gfc-internal-format
+msgid "COMMON block at %L with binding label %s uses the same global identifier as entity at %L"
+msgstr ""
+
+#: fortran/resolve.c:1061
+#, gcc-internal-format, gfc-internal-format
+msgid "COMMON block '%s' at %L is used as PARAMETER at %L"
+msgstr ""
+
+#: fortran/resolve.c:1065
+#, gcc-internal-format
+msgid "COMMON block %qs at %L can not have the EXTERNAL attribute"
+msgstr ""
+
+#: fortran/resolve.c:1069
+#, gcc-internal-format
+msgid "COMMON block %qs at %L is also an intrinsic procedure"
+msgstr ""
+
+#: fortran/resolve.c:1073
+#, gcc-internal-format
+msgid "COMMON block %qs at %L that is also a function result"
+msgstr ""
+
+#: fortran/resolve.c:1078
+#, gcc-internal-format
+msgid "COMMON block %qs at %L that is also a global procedure"
+msgstr ""
+
+#: fortran/resolve.c:1164
+#, gcc-internal-format, gfc-internal-format
+msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
+msgstr ""
+
+#: fortran/resolve.c:1185
+#, gcc-internal-format
+msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
+msgstr ""
+
+#: fortran/resolve.c:1270
+#, gcc-internal-format
+msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
+msgstr ""
+
+#: fortran/resolve.c:1304
+#, gcc-internal-format
+msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
+msgstr ""
+
+#: fortran/resolve.c:1320
+#, gcc-internal-format
+msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
+msgstr ""
+
+#: fortran/resolve.c:1331
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer initialization target at %L must not be ALLOCATABLE "
+msgstr ""
+
+#: fortran/resolve.c:1349
+#, gcc-internal-format
+msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
+msgstr ""
+
+#: fortran/resolve.c:1474
+#, gcc-internal-format
+msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:1536
+#, gcc-internal-format
+msgid "%qs at %L is ambiguous"
+msgstr ""
+
+#: fortran/resolve.c:1540
+#, gcc-internal-format
+msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
+msgstr ""
+
+#: fortran/resolve.c:1661
+#, gcc-internal-format
+msgid "Type specified for intrinsic function %qs at %L is ignored"
+msgstr ""
+
+#: fortran/resolve.c:1674
+#, gcc-internal-format
+msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
+msgstr ""
+
+#: fortran/resolve.c:1685
+#, gcc-internal-format
+msgid "%qs declared INTRINSIC at %L does not exist"
+msgstr ""
+
+#: fortran/resolve.c:1698
+#, gcc-internal-format
+msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
+msgstr ""
+
+#: fortran/resolve.c:1734
+#, gcc-internal-format
+msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
+msgstr ""
+
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d referenced at %L is never defined"
+msgstr ""
+
+#: fortran/resolve.c:1816
+#, gcc-internal-format
+msgid "Statement function %qs at %L is not allowed as an actual argument"
+msgstr ""
+
+#: fortran/resolve.c:1824
+#, gcc-internal-format
+msgid "Intrinsic %qs at %L is not allowed as an actual argument"
+msgstr ""
+
+#: fortran/resolve.c:1831
+#, gcc-internal-format
+msgid "Internal procedure %qs is used as actual argument at %L"
+msgstr ""
+
+#: fortran/resolve.c:1839
+#, gcc-internal-format
+msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
+msgstr ""
+
+#: fortran/resolve.c:1866
+#, gcc-internal-format
+msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:1888
+#, gcc-internal-format
+msgid "Symbol %qs at %L is ambiguous"
+msgstr ""
+
+#: fortran/resolve.c:1943
+#, gcc-internal-format, gfc-internal-format
+msgid "By-value argument at %L is not of numeric type"
+msgstr ""
+
+#: fortran/resolve.c:1950
+#, gcc-internal-format, gfc-internal-format
+msgid "By-value argument at %L cannot be an array or an array section"
+msgstr ""
+
+#: fortran/resolve.c:1964
+#, gcc-internal-format, gfc-internal-format
+msgid "By-value argument at %L is not allowed in this context"
+msgstr ""
+
+#: fortran/resolve.c:1976
+#, gcc-internal-format, gfc-internal-format
+msgid "Passing internal procedure at %L by location not allowed"
+msgstr ""
+
+#: fortran/resolve.c:1987
+#, gcc-internal-format
+msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
+msgstr ""
+
+#: fortran/resolve.c:1996
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed actual argument at %L with ultimate pointer component"
+msgstr ""
+
+#: fortran/resolve.c:2127
+#, gcc-internal-format
+msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
+msgstr ""
+
+#: fortran/resolve.c:2164
+#, gcc-internal-format
+msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
+msgstr ""
+
+#: fortran/resolve.c:2436
+#, gcc-internal-format
+msgid "Return type mismatch of function %qs at %L (%s/%s)"
+msgstr ""
+
+#: fortran/resolve.c:2457
+#, gcc-internal-format
+msgid "Interface mismatch in global procedure %qs at %L: %s "
+msgstr ""
+
+#: fortran/resolve.c:2565
+#, gcc-internal-format
+msgid "There is no specific function for the generic %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:2583
+#, gcc-internal-format
+msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
+msgstr ""
+
+#: fortran/resolve.c:2621
+#, gcc-internal-format
+msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
+msgstr ""
+
+#: fortran/resolve.c:2676
+#, gcc-internal-format
+msgid "Unable to resolve the specific function %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
+#, gcc-internal-format
+msgid "Function %qs at %L has no IMPLICIT type"
+msgstr ""
+
+#: fortran/resolve.c:2841
+#, gcc-internal-format
+msgid "Reference to impure function %qs at %L inside a FORALL %s"
+msgstr ""
+
+#: fortran/resolve.c:2848
+#, gcc-internal-format
+msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
+msgstr ""
+
+#: fortran/resolve.c:2855
+#, gcc-internal-format
+msgid "Reference to impure function %qs at %L within a PURE procedure"
+msgstr ""
+
+#: fortran/resolve.c:2918
+#, gcc-internal-format
+msgid "%qs at %L is not a function"
+msgstr ""
+
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
+#, gcc-internal-format
+msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
+msgstr ""
+
+#. Internal procedures are taken care of in resolve_contained_fntype.
+#: fortran/resolve.c:2969
+#, gcc-internal-format
+msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
+msgstr ""
+
+#: fortran/resolve.c:3003
+#, gcc-internal-format
+msgid "resolve_function(): bad function type"
+msgstr ""
+
+#: fortran/resolve.c:3023
+#, gcc-internal-format
+msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
+msgstr ""
+
+#: fortran/resolve.c:3085
+#, gcc-internal-format
+msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
+msgstr ""
+
+#: fortran/resolve.c:3089
+#, gcc-internal-format
+msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
+msgstr ""
+
+#: fortran/resolve.c:3140
+#, gcc-internal-format
+msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
+msgstr ""
+
+#: fortran/resolve.c:3146
+#, gcc-internal-format
+msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
+msgstr ""
+
+#: fortran/resolve.c:3152
+#, gcc-internal-format
+msgid "Subroutine call to %qs at %L is not PURE"
+msgstr ""
+
+#: fortran/resolve.c:3220
+#, gcc-internal-format
+msgid "There is no specific subroutine for the generic %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:3229
+#, gcc-internal-format
+msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
+msgstr ""
+
+#: fortran/resolve.c:3264
+#, gcc-internal-format
+msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
+msgstr ""
+
+#: fortran/resolve.c:3309
+#, gcc-internal-format
+msgid "Unable to resolve the specific subroutine %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:3367
+#, gcc-internal-format, gfc-internal-format
+msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
+msgstr ""
+
+#: fortran/resolve.c:3406
+#, gcc-internal-format
+msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
+msgstr ""
+
+#: fortran/resolve.c:3410
+#, gcc-internal-format
+msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
+msgstr ""
+
+#: fortran/resolve.c:3455
+#, gcc-internal-format
+msgid "resolve_subroutine(): bad function type"
+msgstr ""
+
+#: fortran/resolve.c:3493
+#, gcc-internal-format, gfc-internal-format
+msgid "Shapes for operands at %L and %L are not conformable"
+msgstr ""
+
+#: fortran/resolve.c:3724
+#, gcc-internal-format
+msgid "resolve_operator(): Bad intrinsic"
+msgstr ""
+
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
+#, gcc-internal-format
+msgid "compare_bound_int(): Bad expression"
+msgstr ""
+
+#: fortran/resolve.c:4013
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
+msgstr ""
+
+#: fortran/resolve.c:4018
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
+msgstr ""
+
+#: fortran/resolve.c:4028
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
+msgstr ""
+
+#: fortran/resolve.c:4033
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
+msgstr ""
+
+#: fortran/resolve.c:4053
+#, gcc-internal-format, gfc-internal-format
+msgid "Illegal stride of zero at %L"
+msgstr ""
+
+#: fortran/resolve.c:4070
+#, gcc-internal-format, gfc-internal-format
+msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
+msgstr ""
+
+#: fortran/resolve.c:4078
+#, gcc-internal-format, gfc-internal-format
+msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
+msgstr ""
+
+#: fortran/resolve.c:4094
+#, gcc-internal-format, gfc-internal-format
+msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
+msgstr ""
+
+#: fortran/resolve.c:4103
+#, gcc-internal-format, gfc-internal-format
+msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
+msgstr ""
+
+#: fortran/resolve.c:4119
+#, gcc-internal-format
+msgid "check_dimension(): Bad array reference"
+msgstr ""
+
+#: fortran/resolve.c:4142
+#, gcc-internal-format, gfc-internal-format
+msgid "Rightmost upper bound of assumed size array section not specified at %L"
+msgstr ""
+
+#: fortran/resolve.c:4152
+#, gcc-internal-format, gfc-internal-format
+msgid "Rank mismatch in array reference at %L (%d/%d)"
+msgstr ""
+
+#: fortran/resolve.c:4160
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
+msgstr ""
+
+#: fortran/resolve.c:4176
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindex of codimension %d must be a scalar at %L"
+msgstr ""
+
+#: fortran/resolve.c:4204
+#, gcc-internal-format, gfc-internal-format
+msgid "Array index at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.c:4210
+#, gcc-internal-format, gfc-internal-format
+msgid "Array index at %L must be of INTEGER type, found %s"
+msgstr ""
+
+#: fortran/resolve.c:4216
+#, gcc-internal-format, gfc-internal-format
+msgid "REAL array index at %L"
+msgstr ""
+
+#: fortran/resolve.c:4255
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument dim at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.c:4262
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument dim at %L must be of INTEGER type"
+msgstr ""
+
+#: fortran/resolve.c:4307
+#, gcc-internal-format
+msgid "find_array_spec(): Missing spec"
+msgstr ""
+
+#: fortran/resolve.c:4318
+#, gcc-internal-format
+msgid "find_array_spec(): unused as(1)"
+msgstr ""
+
+#: fortran/resolve.c:4329
+#, gcc-internal-format
+msgid "find_array_spec(): unused as(2)"
+msgstr ""
+
+#: fortran/resolve.c:4372
+#, gcc-internal-format, gfc-internal-format
+msgid "Array index at %L is an array of rank %d"
+msgstr ""
+
+#: fortran/resolve.c:4470
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring start index at %L must be of type INTEGER"
+msgstr ""
+
+#: fortran/resolve.c:4477
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring start index at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.c:4486
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring start index at %L is less than one"
+msgstr ""
+
+#: fortran/resolve.c:4499
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring end index at %L must be of type INTEGER"
+msgstr ""
+
+#: fortran/resolve.c:4506
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring end index at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.c:4516
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring end index at %L exceeds the string length"
+msgstr ""
+
+#: fortran/resolve.c:4526
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring end index at %L is too large"
+msgstr ""
+
+#: fortran/resolve.c:4664
+#, gcc-internal-format
+msgid "resolve_ref(): Bad array reference"
+msgstr ""
+
+#: fortran/resolve.c:4678
+#, gcc-internal-format, gfc-internal-format
+msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
+msgstr ""
+
+#: fortran/resolve.c:4688
+#, gcc-internal-format, gfc-internal-format
+msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
+msgstr ""
+
+#: fortran/resolve.c:4707
+#, gcc-internal-format, gfc-internal-format
+msgid "Two or more part references with nonzero rank must not be specified at %L"
+msgstr ""
+
+#: fortran/resolve.c:4805
+#, gcc-internal-format
+msgid "expression_rank(): Two array specs"
+msgstr ""
+
+#: fortran/resolve.c:4887
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
+msgstr ""
+
+#: fortran/resolve.c:4897
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type variable %s at %L may only be used as actual argument"
+msgstr ""
+
+#. FIXME: It doesn't work reliably as inquiry_argument is not set
+#. for all inquiry functions in resolve_function; the reason is
+#. that the function-name resolution happens too late in that
+#. function.
+#: fortran/resolve.c:4907
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
+msgstr ""
+
+#: fortran/resolve.c:4922
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank variable %s at %L may only be used as actual argument"
+msgstr ""
+
+#. FIXME: It doesn't work reliably as inquiry_argument is not set
+#. for all inquiry functions in resolve_function; the reason is
+#. that the function-name resolution happens too late in that
+#. function.
+#: fortran/resolve.c:4932
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
+msgstr ""
+
+#: fortran/resolve.c:4943
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
+msgstr ""
+
+#: fortran/resolve.c:4952
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type variable %s at %L shall not have a subobject reference"
+msgstr ""
+
+#: fortran/resolve.c:4967
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
+msgstr ""
+
+#: fortran/resolve.c:5057
+#, gcc-internal-format
+msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
+msgstr ""
+
+#: fortran/resolve.c:5062
+#, gcc-internal-format
+msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
+msgstr ""
+
+#: fortran/resolve.c:5132
+#, gcc-internal-format, gfc-internal-format
+msgid "Polymorphic subobject of coindexed object at %L"
+msgstr ""
+
+#: fortran/resolve.c:5145
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
+msgstr ""
+
+#: fortran/resolve.c:5483
+#, gcc-internal-format, gfc-internal-format
+msgid "Passed-object at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.c:5490
+#, gcc-internal-format
+msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
+msgstr ""
+
+#: fortran/resolve.c:5525
+#, gcc-internal-format
+msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
+msgstr ""
+
+#: fortran/resolve.c:5534
+#, gcc-internal-format, gfc-internal-format
+msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
+msgstr ""
+
+#. Nothing matching found!
+#: fortran/resolve.c:5722
+#, gcc-internal-format
+msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:5749
+#, gcc-internal-format
+msgid "%qs at %L should be a SUBROUTINE"
+msgstr ""
+
+#: fortran/resolve.c:5800
+#, gcc-internal-format
+msgid "%qs at %L should be a FUNCTION"
+msgstr ""
+
+#: fortran/resolve.c:6317
+#, gcc-internal-format
+msgid "gfc_resolve_expr(): Bad expression type"
+msgstr ""
+
+#: fortran/resolve.c:6343
+#, gcc-internal-format, gfc-internal-format
+msgid "%s at %L must be a scalar"
+msgstr ""
+
+#: fortran/resolve.c:6353
+#, gcc-internal-format, gfc-internal-format
+msgid "%s at %L must be integer"
+msgstr ""
+
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
+#, gcc-internal-format, gfc-internal-format
+msgid "%s at %L must be INTEGER"
+msgstr ""
+
+#: fortran/resolve.c:6406
+#, gcc-internal-format, gfc-internal-format
+msgid "Step expression in DO loop at %L cannot be zero"
+msgstr ""
+
+#: fortran/resolve.c:6442
+#, gcc-internal-format, gfc-internal-format
+msgid "DO loop at %L will be executed zero times"
+msgstr ""
+
+#: fortran/resolve.c:6503
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL index-name at %L must be a scalar INTEGER"
+msgstr ""
+
+#: fortran/resolve.c:6508
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL start expression at %L must be a scalar INTEGER"
+msgstr ""
+
+#: fortran/resolve.c:6515
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL end expression at %L must be a scalar INTEGER"
+msgstr ""
+
+#: fortran/resolve.c:6523
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL stride expression at %L must be a scalar %s"
+msgstr ""
+
+#: fortran/resolve.c:6528
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL stride expression at %L cannot be zero"
+msgstr ""
+
+#: fortran/resolve.c:6541
+#, gcc-internal-format
+msgid "FORALL index %qs may not appear in triplet specification at %L"
+msgstr ""
+
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
+msgstr ""
+
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed allocatable object at %L"
+msgstr ""
+
+#: fortran/resolve.c:6753
+#, gcc-internal-format, gfc-internal-format
+msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
+msgstr ""
+
+#: fortran/resolve.c:6784
+#, gcc-internal-format, gfc-internal-format
+msgid "Source-expr at %L and allocate-object at %L must have the same shape"
+msgstr ""
+
+#: fortran/resolve.c:6942
+#, gcc-internal-format, gfc-internal-format
+msgid "Type of entity at %L is type incompatible with source-expr at %L"
+msgstr ""
+
+#: fortran/resolve.c:6954
+#, gcc-internal-format, gfc-internal-format
+msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
+msgstr ""
+
+#: fortran/resolve.c:6968
+#, gcc-internal-format, gfc-internal-format
+msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
+msgstr ""
+
+#: fortran/resolve.c:6981
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
+msgstr ""
+
+#: fortran/resolve.c:6994
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
+msgstr ""
+
+#: fortran/resolve.c:7102
+#, gcc-internal-format, gfc-internal-format
+msgid "Array specification required in ALLOCATE statement at %L"
+msgstr ""
+
+#: fortran/resolve.c:7116
+#, gcc-internal-format, gfc-internal-format
+msgid "Coarray specification required in ALLOCATE statement at %L"
+msgstr ""
+
+#: fortran/resolve.c:7143
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad array specification in ALLOCATE statement at %L"
+msgstr ""
+
+#: fortran/resolve.c:7162
+#, gcc-internal-format
+msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
+msgstr ""
+
+#: fortran/resolve.c:7177
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
+msgstr ""
+
+#: fortran/resolve.c:7188
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad coarray specification in ALLOCATE statement at %L"
+msgstr ""
+
+#: fortran/resolve.c:7219
+#, gcc-internal-format, gfc-internal-format
+msgid "Stat-variable at %L must be a scalar INTEGER variable"
+msgstr ""
+
+#: fortran/resolve.c:7242
+#, gcc-internal-format, gfc-internal-format
+msgid "Stat-variable at %L shall not be %sd within the same %s statement"
+msgstr ""
+
+#: fortran/resolve.c:7253
+#, gcc-internal-format, gfc-internal-format
+msgid "ERRMSG at %L is useless without a STAT tag"
+msgstr ""
+
+#: fortran/resolve.c:7264
+#, gcc-internal-format, gfc-internal-format
+msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+msgstr ""
+
+#: fortran/resolve.c:7287
+#, gcc-internal-format, gfc-internal-format
+msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
+msgstr ""
+
+#: fortran/resolve.c:7317
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocate-object at %L also appears at %L"
+msgstr ""
+
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocate-object at %L is subobject of object at %L"
+msgstr ""
+
+#. The cases overlap, or they are the same
+#. element in the list.  Either way, we must
+#. issue an error and get the next case from P.
+#. FIXME: Sort P and Q by line number.
+#: fortran/resolve.c:7533
+#, gcc-internal-format, gfc-internal-format
+msgid "CASE label at %L overlaps with CASE label at %L"
+msgstr ""
+
+#: fortran/resolve.c:7584
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression in CASE statement at %L must be of type %s"
+msgstr ""
+
+#: fortran/resolve.c:7595
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression in CASE statement at %L must be of kind %d"
+msgstr ""
+
+#: fortran/resolve.c:7608
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression in CASE statement at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.c:7654
+#, gcc-internal-format, gfc-internal-format
+msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
+msgstr ""
+
+#: fortran/resolve.c:7673
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of SELECT statement at %L cannot be %s"
+msgstr ""
+
+#: fortran/resolve.c:7683
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of SELECT statement at %L must be a scalar expression"
+msgstr ""
+
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression in CASE statement at %L is not in the range of %s"
+msgstr ""
+
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
+#, gcc-internal-format, gfc-internal-format
+msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
+msgstr ""
+
+#: fortran/resolve.c:7797
+#, gcc-internal-format, gfc-internal-format
+msgid "Logical range in CASE statement at %L is not allowed"
+msgstr ""
+
+#: fortran/resolve.c:7809
+#, gcc-internal-format, gfc-internal-format
+msgid "Constant logical value in CASE statement is repeated at %L"
+msgstr ""
+
+#: fortran/resolve.c:7824
+#, gcc-internal-format, gfc-internal-format
+msgid "Range specification at %L can never be matched"
+msgstr ""
+
+#: fortran/resolve.c:7927
+#, gcc-internal-format, gfc-internal-format
+msgid "Logical SELECT CASE block at %L has more that two cases"
+msgstr ""
+
+#: fortran/resolve.c:7999
+#, gcc-internal-format
+msgid "Associate-name %qs at %L is used as array"
+msgstr ""
+
+#: fortran/resolve.c:8009
+#, gcc-internal-format, gfc-internal-format
+msgid "CLASS selector at %L needs a temporary which is not yet implemented"
+msgstr ""
+
+#: fortran/resolve.c:8063
+#, gcc-internal-format, gfc-internal-format
+msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
+msgstr ""
+
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
+#, gcc-internal-format, gfc-internal-format
+msgid "Selector at %L must not be coindexed"
+msgstr ""
+
+#: fortran/resolve.c:8108
+#, gcc-internal-format
+msgid "Derived type %qs at %L must be extensible"
+msgstr ""
+
+#: fortran/resolve.c:8120
+#, gcc-internal-format
+msgid "Derived type %qs at %L must be an extension of %qs"
+msgstr ""
+
+#: fortran/resolve.c:8123
+#, gcc-internal-format
+msgid "Unexpected intrinsic type %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:8132
+#, gcc-internal-format, gfc-internal-format
+msgid "The type-spec at %L shall specify that each length type parameter is assumed"
+msgstr ""
+
+#: fortran/resolve.c:8324
+#, gcc-internal-format, gfc-internal-format
+msgid "Double CLASS IS block in SELECT TYPE statement at %L"
+msgstr ""
+
+#: fortran/resolve.c:8413
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid context for NULL () intrinsic at %L"
+msgstr ""
+
+#. FIXME: Test for defined input/output.
+#: fortran/resolve.c:8441
+#, gcc-internal-format, gfc-internal-format
+msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
+msgstr ""
+
+#: fortran/resolve.c:8453
+#, gcc-internal-format, gfc-internal-format
+msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
+msgstr ""
+
+#: fortran/resolve.c:8462
+#, gcc-internal-format, gfc-internal-format
+msgid "Data transfer element at %L cannot have procedure pointer components"
+msgstr ""
+
+#: fortran/resolve.c:8469
+#, gcc-internal-format, gfc-internal-format
+msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
+msgstr ""
+
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
+#, gcc-internal-format, gfc-internal-format
+msgid "Data transfer element at %L cannot have PRIVATE components"
+msgstr ""
+
+#: fortran/resolve.c:8500
+#, gcc-internal-format, gfc-internal-format
+msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
+msgstr ""
+
+#: fortran/resolve.c:8555
+#, gcc-internal-format, gfc-internal-format
+msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
+msgstr ""
+
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
+#, gcc-internal-format, gfc-internal-format
+msgid "STAT= argument at %L must be a scalar INTEGER variable"
+msgstr ""
+
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
+#, gcc-internal-format, gfc-internal-format
+msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
+msgstr ""
+
+#: fortran/resolve.c:8586
+#, gcc-internal-format, gfc-internal-format
+msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
+msgstr ""
+
+#: fortran/resolve.c:8650
+#, gcc-internal-format, gfc-internal-format
+msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
+msgstr ""
+
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
+#, gcc-internal-format, gfc-internal-format
+msgid "Imageset argument at %L must between 1 and num_images()"
+msgstr ""
+
+#: fortran/resolve.c:8707
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
+msgstr ""
+
+#: fortran/resolve.c:8717
+#, gcc-internal-format, gfc-internal-format
+msgid "Branch at %L may result in an infinite loop"
+msgstr ""
+
+#. Note: A label at END CRITICAL does not leave the CRITICAL
+#. construct as END CRITICAL is still part of it.
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
+#, gcc-internal-format, gfc-internal-format
+msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
+msgstr ""
+
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
+#, gcc-internal-format, gfc-internal-format
+msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
+msgstr ""
+
+#. The label is not in an enclosing block, so illegal.  This was
+#. allowed in Fortran 66, so we allow it as extension.  No
+#. further checks are necessary in this case.
+#: fortran/resolve.c:8778
+#, gcc-internal-format, gfc-internal-format
+msgid "Label at %L is not in the same block as the GOTO statement at %L"
+msgstr ""
+
+#: fortran/resolve.c:8850
+#, gcc-internal-format, gfc-internal-format
+msgid "WHERE mask at %L has inconsistent shape"
+msgstr ""
+
+#: fortran/resolve.c:8866
+#, gcc-internal-format, gfc-internal-format
+msgid "WHERE assignment target at %L has inconsistent shape"
+msgstr ""
+
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
+msgstr ""
+
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
+#, gcc-internal-format, gfc-internal-format
+msgid "Unsupported statement inside WHERE at %L"
+msgstr ""
+
+#: fortran/resolve.c:8915
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment to a FORALL index variable at %L"
+msgstr ""
+
+#: fortran/resolve.c:8924
+#, gcc-internal-format
+msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
+msgstr ""
+
+#: fortran/resolve.c:9093
+#, gcc-internal-format, gfc-internal-format
+msgid "An outer FORALL construct already has an index with this name %L"
+msgstr ""
+
+#: fortran/resolve.c:9171
+#, gcc-internal-format, gfc-internal-format
+msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
+msgstr ""
+
+#: fortran/resolve.c:9247
+#, gcc-internal-format
+msgid "gfc_resolve_blocks(): Bad block type"
+msgstr ""
+
+#: fortran/resolve.c:9361
+#, gcc-internal-format, gfc-internal-format
+msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
+msgstr ""
+
+#: fortran/resolve.c:9393
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
+msgstr ""
+
+#: fortran/resolve.c:9398
+#, gcc-internal-format, gfc-internal-format
+msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
+msgstr ""
+
+#: fortran/resolve.c:9408
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment to coindexed variable at %L in a PURE procedure"
+msgstr ""
+
+#: fortran/resolve.c:9440
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment to polymorphic coarray at %L is not permitted"
+msgstr ""
+
+#: fortran/resolve.c:9444
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment to an allocatable polymorphic variable at %L"
+msgstr ""
+
+#: fortran/resolve.c:9449
+#, gcc-internal-format
+msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
+msgstr ""
+
+#. See PR 43366.
+#: fortran/resolve.c:9454
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
+msgstr ""
+
+#: fortran/resolve.c:9460
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
+msgstr ""
+
+#: fortran/resolve.c:9471
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
+msgstr ""
+
+#: fortran/resolve.c:9766
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
+msgstr ""
+
+#: fortran/resolve.c:10141
+#, gcc-internal-format, gfc-internal-format
+msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgstr ""
+
+#: fortran/resolve.c:10144
+#, gcc-internal-format
+msgid "Variable %qs has not been assigned a target label at %L"
+msgstr ""
+
+#: fortran/resolve.c:10155
+#, gcc-internal-format, gfc-internal-format
+msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
+msgstr ""
+
+#: fortran/resolve.c:10203
+#, gcc-internal-format, gfc-internal-format
+msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
+msgstr ""
+
+#: fortran/resolve.c:10236
+#, gcc-internal-format, gfc-internal-format
+msgid "Arithmetic IF statement at %L requires a numeric expression"
+msgstr ""
+
+#: fortran/resolve.c:10291
+#, gcc-internal-format
+msgid "gfc_resolve_code(): No expression on DO WHILE"
+msgstr ""
+
+#: fortran/resolve.c:10296
+#, gcc-internal-format, gfc-internal-format
+msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
+msgstr ""
+
+#: fortran/resolve.c:10380
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
+msgstr ""
+
+#: fortran/resolve.c:10449
+#, gcc-internal-format
+msgid "gfc_resolve_code(): Bad statement code"
+msgstr ""
+
+#: fortran/resolve.c:10544
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
+msgstr ""
+
+#. This can only happen if the variable is defined in a module - if it
+#. isn't the same module, reject it.
+#: fortran/resolve.c:10557
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
+msgstr ""
+
+#. Print an error if the procedure is defined multiple times; we have to
+#. exclude references to the same procedure via module association or
+#. multiple checks for the same procedure.
+#: fortran/resolve.c:10574
+#, gcc-internal-format, gfc-internal-format
+msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
+msgstr ""
+
+#: fortran/resolve.c:10645
+#, gcc-internal-format, gfc-internal-format
+msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
+msgstr ""
+
+#: fortran/resolve.c:10658
+#, gcc-internal-format, gfc-internal-format
+msgid "String length at %L is too large"
+msgstr ""
+
+#: fortran/resolve.c:10994
+#, gcc-internal-format
+msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
+msgstr ""
+
+#: fortran/resolve.c:10998
+#, gcc-internal-format
+msgid "Scalar object %qs at %L may not be ALLOCATABLE"
+msgstr ""
+
+#: fortran/resolve.c:11006
+#, gcc-internal-format
+msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
+msgstr ""
+
+#: fortran/resolve.c:11016
+#, gcc-internal-format
+msgid "Array %qs at %L cannot have a deferred shape"
+msgstr ""
+
+#: fortran/resolve.c:11031
+#, gcc-internal-format
+msgid "Type %qs of CLASS variable %qs at %L is not extensible"
+msgstr ""
+
+#: fortran/resolve.c:11043
+#, gcc-internal-format
+msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
+msgstr ""
+
+#: fortran/resolve.c:11074
+#, gcc-internal-format, gfc-internal-format
+msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
+msgstr ""
+
+#: fortran/resolve.c:11096
+#, gcc-internal-format
+msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
+msgstr ""
+
+#. The shape of a main program or module array needs to be
+#. constant.
+#: fortran/resolve.c:11144
+#, gcc-internal-format, gfc-internal-format
+msgid "The module or main program array '%s' at %L must have constant shape"
+msgstr ""
+
+#: fortran/resolve.c:11156
+#, gcc-internal-format
+msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
+msgstr ""
+
+#: fortran/resolve.c:11172
+#, gcc-internal-format, gfc-internal-format
+msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
+msgstr ""
+
+#: fortran/resolve.c:11193
+#, gcc-internal-format, gfc-internal-format
+msgid "'%s' at %L must have constant character length in this context"
+msgstr ""
+
+#: fortran/resolve.c:11200
+#, gcc-internal-format
+msgid "COMMON variable %qs at %L must have constant character length"
+msgstr ""
+
+#: fortran/resolve.c:11247
+#, gcc-internal-format
+msgid "Allocatable %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.c:11250
+#, gcc-internal-format
+msgid "External %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.c:11254
+#, gcc-internal-format
+msgid "Dummy %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.c:11257
+#, gcc-internal-format
+msgid "Intrinsic %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.c:11260
+#, gcc-internal-format
+msgid "Function result %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.c:11263
+#, gcc-internal-format
+msgid "Automatic array %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.c:11306
+#, gcc-internal-format
+msgid "Character-valued statement function %qs at %L must have constant length"
+msgstr ""
+
+#: fortran/resolve.c:11328
+#, gcc-internal-format
+msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
+msgstr ""
+
+#: fortran/resolve.c:11350
+#, gcc-internal-format
+msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
+msgstr ""
+
+#: fortran/resolve.c:11368
+#, gcc-internal-format
+msgid "Function %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.c:11377
+#, gcc-internal-format
+msgid "External object %qs at %L may not have an initializer"
+msgstr ""
+
+#: fortran/resolve.c:11385
+#, gcc-internal-format
+msgid "ELEMENTAL function %qs at %L must have a scalar result"
+msgstr ""
+
+#: fortran/resolve.c:11395
+#, gcc-internal-format
+msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
+msgstr ""
+
+#: fortran/resolve.c:11414
+#, gcc-internal-format
+msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
+msgstr ""
+
+#: fortran/resolve.c:11418
+#, gcc-internal-format
+msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
+msgstr ""
+
+#: fortran/resolve.c:11422
+#, gcc-internal-format
+msgid "CHARACTER(*) function %qs at %L cannot be pure"
+msgstr ""
+
+#: fortran/resolve.c:11426
+#, gcc-internal-format
+msgid "CHARACTER(*) function %qs at %L cannot be recursive"
+msgstr ""
+
+#: fortran/resolve.c:11439
+#, gcc-internal-format
+msgid "CHARACTER(*) function %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:11448
+#, gcc-internal-format
+msgid "Procedure pointer %qs at %L shall not be elemental"
+msgstr ""
+
+#: fortran/resolve.c:11454
+#, gcc-internal-format
+msgid "Dummy procedure %qs at %L shall not be elemental"
+msgstr ""
+
+#: fortran/resolve.c:11510
+#, gcc-internal-format
+msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:11516
+#, gcc-internal-format
+msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:11522
+#, gcc-internal-format
+msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:11530
+#, gcc-internal-format
+msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:11536
+#, gcc-internal-format
+msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
+msgstr ""
+
+#: fortran/resolve.c:11613
+#, gcc-internal-format
+msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
+msgstr ""
+
+#: fortran/resolve.c:11622
+#, gcc-internal-format, gfc-internal-format
+msgid "FINAL procedure at %L must have exactly one argument"
+msgstr ""
+
+#: fortran/resolve.c:11631
+#, gcc-internal-format
+msgid "Argument of FINAL procedure at %L must be of type %qs"
+msgstr ""
+
+#: fortran/resolve.c:11639
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of FINAL procedure at %L must not be a POINTER"
+msgstr ""
+
+#: fortran/resolve.c:11645
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
+msgstr ""
+
+#: fortran/resolve.c:11651
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
+msgstr ""
+
+#: fortran/resolve.c:11659
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
+msgstr ""
+
+#: fortran/resolve.c:11668
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
+msgstr ""
+
+#: fortran/resolve.c:11690
+#, gcc-internal-format
+msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
+msgstr ""
+
+#: fortran/resolve.c:11727
+#, gcc-internal-format
+msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
+msgstr ""
+
+#: fortran/resolve.c:11767
+#, gcc-internal-format
+msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:11803
+#, gcc-internal-format
+msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
+msgstr ""
+
+#: fortran/resolve.c:11862
+#, gcc-internal-format
+msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:11874
+#, gcc-internal-format
+msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
+msgstr ""
+
+#: fortran/resolve.c:11902
+#, gcc-internal-format
+msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
+msgstr ""
+
+#: fortran/resolve.c:11958
+#, gcc-internal-format, gfc-internal-format
+msgid "Type-bound operator at %L can't be NOPASS"
+msgstr ""
+
+#: fortran/resolve.c:12140
+#, gcc-internal-format
+msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
+msgstr ""
+
+#: fortran/resolve.c:12182
+#, gcc-internal-format
+msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
+msgstr ""
+
+#: fortran/resolve.c:12196
+#, gcc-internal-format
+msgid "Procedure %qs with PASS at %L must have at least one argument"
+msgstr ""
+
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
+#, gcc-internal-format
+msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:12218
+#, gcc-internal-format
+msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
+msgstr ""
+
+#: fortran/resolve.c:12227
+#, gcc-internal-format
+msgid "Passed-object dummy argument of %qs at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.c:12233
+#, gcc-internal-format
+msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
+msgstr ""
+
+#: fortran/resolve.c:12239
+#, gcc-internal-format
+msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
+msgstr ""
+
+#: fortran/resolve.c:12268
+#, gcc-internal-format
+msgid "Procedure %qs at %L has the same name as a component of %qs"
+msgstr ""
+
+#: fortran/resolve.c:12277
+#, gcc-internal-format
+msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
+msgstr ""
+
+#: fortran/resolve.c:12369
+#, gcc-internal-format
+msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
+msgstr ""
+
+#: fortran/resolve.c:12467
+#, gcc-internal-format
+msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
+msgstr ""
+
+#: fortran/resolve.c:12480
+#, gcc-internal-format
+msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
+msgstr ""
+
+#: fortran/resolve.c:12500
+#, gcc-internal-format
+msgid "Coarray component %qs at %L must be allocatable with deferred shape"
+msgstr ""
+
+#: fortran/resolve.c:12510
+#, gcc-internal-format
+msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
+msgstr ""
+
+#: fortran/resolve.c:12521
+#, gcc-internal-format
+msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
+msgstr ""
+
+#: fortran/resolve.c:12531
+#, gcc-internal-format
+msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
+msgstr ""
+
+#: fortran/resolve.c:12632
+#, gcc-internal-format
+msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
+msgstr ""
+
+#: fortran/resolve.c:12647
+#, gcc-internal-format
+msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
+msgstr ""
+
+#: fortran/resolve.c:12664
+#, gcc-internal-format
+msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
+msgstr ""
+
+#: fortran/resolve.c:12675
+#, gcc-internal-format
+msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.c:12685
+#, gcc-internal-format
+msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
+msgstr ""
+
+#: fortran/resolve.c:12695
+#, gcc-internal-format
+msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
+msgstr ""
+
+#: fortran/resolve.c:12737
+#, gcc-internal-format
+msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
+msgstr ""
+
+#: fortran/resolve.c:12750
+#, gcc-internal-format
+msgid "Character length of component %qs needs to be a constant specification expression at %L"
+msgstr ""
+
+#: fortran/resolve.c:12761
+#, gcc-internal-format
+msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
+msgstr ""
+
+#: fortran/resolve.c:12792
+#, gcc-internal-format
+msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
+msgstr ""
+
+#: fortran/resolve.c:12800
+#, gcc-internal-format, gfc-internal-format
+msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
+msgstr ""
+
+#: fortran/resolve.c:12809
+#, gcc-internal-format, gfc-internal-format
+msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
+msgstr ""
+
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
+#, gcc-internal-format
+msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
+msgstr ""
+
+#: fortran/resolve.c:12851
+#, gcc-internal-format
+msgid "Component %qs with CLASS at %L must be allocatable or pointer"
+msgstr ""
+
+#: fortran/resolve.c:12919
+#, gcc-internal-format, gfc-internal-format
+msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
+msgstr ""
+
+#: fortran/resolve.c:12975
+#, gcc-internal-format
+msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
+msgstr ""
+
+#: fortran/resolve.c:12981
+#, gcc-internal-format
+msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:12987
+#, gcc-internal-format
+msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:12995
+#, gcc-internal-format
+msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:13005
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/resolve.c:13015
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr ""
+
+#. FIXME: Once UDDTIO is implemented, the following can be
+#. removed.
+#: fortran/resolve.c:13023
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/resolve.c:13040
+#, gcc-internal-format
+msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:13050
+#, gcc-internal-format
+msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:13061
+#, gcc-internal-format
+msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:13088
+#, gcc-internal-format
+msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:13107
+#, gcc-internal-format
+msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
+msgstr ""
+
+#: fortran/resolve.c:13119
+#, gcc-internal-format
+msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
+msgstr ""
+
+#: fortran/resolve.c:13130
+#, gcc-internal-format, gfc-internal-format
+msgid "Incompatible derived type in PARAMETER at %L"
+msgstr ""
+
+#: fortran/resolve.c:13217
+#, gcc-internal-format, gfc-internal-format
+msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
+msgstr ""
+
+#: fortran/resolve.c:13220
+#, gcc-internal-format, gfc-internal-format
+msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
+msgstr ""
+
+#: fortran/resolve.c:13309
+#, gcc-internal-format
+msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
+msgstr ""
+
+#: fortran/resolve.c:13327
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed size array at %L must be a dummy argument"
+msgstr ""
+
+#: fortran/resolve.c:13330
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed shape array at %L must be a dummy argument"
+msgstr ""
+
+#: fortran/resolve.c:13338
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank array at %L must be a dummy argument"
+msgstr ""
+
+#: fortran/resolve.c:13345
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
+msgstr ""
+
+#: fortran/resolve.c:13358
+#, gcc-internal-format, gfc-internal-format
+msgid "Symbol at %L is not a DUMMY variable"
+msgstr ""
+
+#: fortran/resolve.c:13364
+#, gcc-internal-format
+msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
+msgstr ""
+
+#: fortran/resolve.c:13374
+#, gcc-internal-format
+msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
+msgstr ""
+
+#: fortran/resolve.c:13383
+#, gcc-internal-format
+msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
+msgstr ""
+
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
+#, gcc-internal-format
+msgid "The derived type %qs at %L is of type %qs, which has not been defined"
+msgstr ""
+
+#: fortran/resolve.c:13410
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
+msgstr ""
+
+#: fortran/resolve.c:13419
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
+msgstr ""
+
+#: fortran/resolve.c:13428
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
+msgstr ""
+
+#: fortran/resolve.c:13436
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
+msgstr ""
+
+#: fortran/resolve.c:13443
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
+msgstr ""
+
+#: fortran/resolve.c:13463
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
+msgstr ""
+
+#: fortran/resolve.c:13470
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
+msgstr ""
+
+#: fortran/resolve.c:13477
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
+msgstr ""
+
+#: fortran/resolve.c:13484
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
+msgstr ""
+
+#: fortran/resolve.c:13509
+#, gcc-internal-format
+msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
+msgstr ""
+
+#: fortran/resolve.c:13589
+#, gcc-internal-format
+msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
+msgstr ""
+
+#: fortran/resolve.c:13604
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
+msgstr ""
+
+#: fortran/resolve.c:13622
+#, gcc-internal-format
+msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
+msgstr ""
+
+#: fortran/resolve.c:13634
+#, gcc-internal-format
+msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
+msgstr ""
+
+#: fortran/resolve.c:13646
+#, gcc-internal-format
+msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
+msgstr ""
+
+#: fortran/resolve.c:13655
+#, gcc-internal-format
+msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
+msgstr ""
+
+#: fortran/resolve.c:13667
+#, gcc-internal-format
+msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
+msgstr ""
+
+#: fortran/resolve.c:13682
+#, gcc-internal-format
+msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
+msgstr ""
+
+#: fortran/resolve.c:13690
+#, gcc-internal-format
+msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
+msgstr ""
+
+#: fortran/resolve.c:13697
+#, gcc-internal-format
+msgid "Allocatable coarray variable %qs at %L must have deferred shape"
+msgstr ""
+
+#: fortran/resolve.c:13709
+#, gcc-internal-format
+msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
+msgstr ""
+
+#: fortran/resolve.c:13718
+#, gcc-internal-format
+msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
+msgstr ""
+
+#: fortran/resolve.c:13734
+#, gcc-internal-format
+msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
+msgstr ""
+
+#: fortran/resolve.c:13740
+#, gcc-internal-format
+msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
+msgstr ""
+
+#: fortran/resolve.c:13819
+#, gcc-internal-format, gfc-internal-format
+msgid "Threadprivate at %L isn't SAVEd"
+msgstr ""
+
+#: fortran/resolve.c:13830
+#, gcc-internal-format
+msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
+msgstr ""
+
+#: fortran/resolve.c:13917
+#, gcc-internal-format
+msgid "check_data_variable(): Bad expression"
+msgstr ""
+
+#: fortran/resolve.c:13923
+#, gcc-internal-format
+msgid "BLOCK DATA element %qs at %L must be in COMMON"
+msgstr ""
+
+#: fortran/resolve.c:13929
+#, gcc-internal-format
+msgid "DATA array %qs at %L must be specified in a previous declaration"
+msgstr ""
+
+#: fortran/resolve.c:13938
+#, gcc-internal-format
+msgid "DATA element %qs at %L cannot have a coindex"
+msgstr ""
+
+#: fortran/resolve.c:13952
+#, gcc-internal-format
+msgid "DATA element %qs at %L is a pointer and so must be a full array"
+msgstr ""
+
+#: fortran/resolve.c:13998
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonconstant array section at %L in DATA statement"
+msgstr ""
+
+#: fortran/resolve.c:14011
+#, gcc-internal-format, gfc-internal-format
+msgid "DATA statement at %L has more variables than values"
+msgstr ""
+
+#: fortran/resolve.c:14110
+#, gcc-internal-format, gfc-internal-format
+msgid "start of implied-do loop at %L could not be simplified to a constant value"
+msgstr ""
+
+#: fortran/resolve.c:14118
+#, gcc-internal-format, gfc-internal-format
+msgid "end of implied-do loop at %L could not be simplified to a constant value"
+msgstr ""
+
+#: fortran/resolve.c:14126
+#, gcc-internal-format, gfc-internal-format
+msgid "step of implied-do loop at %L could not be simplified to a constant value"
+msgstr ""
+
+#: fortran/resolve.c:14251
+#, gcc-internal-format, gfc-internal-format
+msgid "DATA statement at %L has more values than variables"
+msgstr ""
+
+#: fortran/resolve.c:14416
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d at %L defined but not used"
+msgstr ""
+
+#: fortran/resolve.c:14421
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d at %L defined but cannot be used"
+msgstr ""
+
+#: fortran/resolve.c:14505
+#, gcc-internal-format
+msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
+msgstr ""
+
+#: fortran/resolve.c:14514
+#, gcc-internal-format
+msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
+msgstr ""
+
+#: fortran/resolve.c:14522
+#, gcc-internal-format
+msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
+msgstr ""
+
+#: fortran/resolve.c:14538
+#, gcc-internal-format
+msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
+msgstr ""
+
+#: fortran/resolve.c:14641
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in EQUIVALENCE statement at %L"
+msgstr ""
+
+#: fortran/resolve.c:14656
+#, gcc-internal-format, gfc-internal-format
+msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
+msgstr ""
+
+#: fortran/resolve.c:14668
+#, gcc-internal-format
+msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
+msgstr ""
+
+#: fortran/resolve.c:14677
+#, gcc-internal-format
+msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
+msgstr ""
+
+#: fortran/resolve.c:14750
+#, gcc-internal-format
+msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
+msgstr ""
+
+#: fortran/resolve.c:14761
+#, gcc-internal-format
+msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
+msgstr ""
+
+#: fortran/resolve.c:14772
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring at %L has length zero"
+msgstr ""
+
+#: fortran/resolve.c:14815
+#, gcc-internal-format
+msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
+msgstr ""
+
+#: fortran/resolve.c:14828
+#, gcc-internal-format
+msgid "ENTRY %qs at %L has no IMPLICIT type"
+msgstr ""
+
+#: fortran/resolve.c:14845
+#, gcc-internal-format
+msgid "User operator procedure %qs at %L must be a FUNCTION"
+msgstr ""
+
+#: fortran/resolve.c:14855
+#, gcc-internal-format
+msgid "User operator procedure %qs at %L cannot be assumed character length"
+msgstr ""
+
+#: fortran/resolve.c:14863
+#, gcc-internal-format
+msgid "User operator procedure %qs at %L must have at least one argument"
+msgstr ""
+
+#: fortran/resolve.c:14877
+#, gcc-internal-format, gfc-internal-format
+msgid "First argument of operator interface at %L cannot be optional"
+msgstr ""
+
+#: fortran/resolve.c:14895
+#, gcc-internal-format, gfc-internal-format
+msgid "Second argument of operator interface at %L cannot be optional"
+msgstr ""
+
+#: fortran/resolve.c:14902
+#, gcc-internal-format, gfc-internal-format
+msgid "Operator interface at %L must have, at most, two arguments"
+msgstr ""
+
+#: fortran/resolve.c:14980
+#, gcc-internal-format
+msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
+msgstr ""
+
+#: fortran/scanner.c:330
+#, gcc-internal-format
+msgid "Include directory %qs: %s"
+msgstr ""
+
+#: fortran/scanner.c:334
+#, gcc-internal-format
+msgid "Nonexistent include directory %qs"
+msgstr ""
+
+#: fortran/scanner.c:339
+#, gcc-internal-format
+msgid "%qs is not a directory"
+msgstr ""
+
+#: fortran/scanner.c:742
+#, gcc-internal-format, gfc-internal-format
+msgid "!$ACC at %C starts a commented line as it neither is followed by a space nor is a continuation line"
+msgstr ""
+
+#: fortran/scanner.c:782
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
+msgstr ""
+
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
+#, gcc-internal-format, gfc-internal-format
+msgid "Line truncated at %L"
+msgstr ""
+
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
+#, gcc-internal-format, gfc-internal-format
+msgid "Limit of %d continuations exceeded in statement at %C"
+msgstr ""
+
+#: fortran/scanner.c:1382
+#, gcc-internal-format
+msgid "Missing %<&%> in continued character constant at %C"
+msgstr ""
+
+#: fortran/scanner.c:1634
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonconforming tab character at %C"
+msgstr ""
+
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
+#, gcc-internal-format
+msgid "%<&%> not allowed by itself in line %d"
+msgstr ""
+
+#: fortran/scanner.c:1784
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonconforming tab character in column %d of line %d"
+msgstr ""
+
+#: fortran/scanner.c:2009
+#, gcc-internal-format, gfc-internal-format
+msgid "%s:%d: file %s left but not entered"
+msgstr ""
+
+#: fortran/scanner.c:2043
+#, gcc-internal-format, gfc-internal-format
+msgid "%s:%d: Illegal preprocessor directive"
+msgstr ""
+
+#: fortran/scanner.c:2168
+#, gcc-internal-format
+msgid "Can't open file %qs"
+msgstr ""
+
+#: fortran/simplify.c:89
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of %s overflows its kind at %L"
+msgstr ""
+
+#: fortran/simplify.c:94
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of %s underflows its kind at %L"
+msgstr ""
+
+#: fortran/simplify.c:99
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of %s is NaN at %L"
+msgstr ""
+
+#: fortran/simplify.c:103
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of %s gives range error for its kind at %L"
+msgstr ""
+
+#: fortran/simplify.c:126
+#, gcc-internal-format, gfc-internal-format
+msgid "KIND parameter of %s at %L must be an initialization expression"
+msgstr ""
+
+#: fortran/simplify.c:134
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid KIND parameter of %s at %L"
+msgstr ""
+
+#: fortran/simplify.c:692
+#, gcc-internal-format
+msgid "gfc_simplify_abs(): Bad type"
+msgstr ""
+
+#: fortran/simplify.c:713
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of %s function at %L is negative"
+msgstr ""
+
+#: fortran/simplify.c:720
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of %s function at %L outside of range [0,127]"
+msgstr ""
+
+#: fortran/simplify.c:738
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of %s function at %L is too large for the collating sequence of kind %d"
+msgstr ""
+
+#: fortran/simplify.c:775
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of ACOS at %L must be between -1 and 1"
+msgstr ""
+
+#: fortran/simplify.c:789
+#, gcc-internal-format
+msgid "in gfc_simplify_acos(): Bad type"
+msgstr ""
+
+#: fortran/simplify.c:808
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of ACOSH at %L must not be less than 1"
+msgstr ""
+
+#: fortran/simplify.c:823
+#, gcc-internal-format
+msgid "in gfc_simplify_acosh(): Bad type"
+msgstr ""
+
+#: fortran/simplify.c:1052
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of ASIN at %L must be between -1 and 1"
+msgstr ""
+
+#: fortran/simplify.c:1066
+#, gcc-internal-format
+msgid "in gfc_simplify_asin(): Bad type"
+msgstr ""
+
+#: fortran/simplify.c:1094
+#, gcc-internal-format
+msgid "in gfc_simplify_asinh(): Bad type"
+msgstr ""
+
+#: fortran/simplify.c:1122
+#, gcc-internal-format
+msgid "in gfc_simplify_atan(): Bad type"
+msgstr ""
+
+#: fortran/simplify.c:1143
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of ATANH at %L must be inside the range -1 to 1"
+msgstr ""
+
+#: fortran/simplify.c:1157
+#, gcc-internal-format
+msgid "in gfc_simplify_atanh(): Bad type"
+msgstr ""
+
+#: fortran/simplify.c:1174
+#, gcc-internal-format, gfc-internal-format
+msgid "If first argument of ATAN2 %L is zero, then the second argument must not be zero"
+msgstr ""
+
+#: fortran/simplify.c:1266
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of BESSEL_YN is -INF at %L"
+msgstr ""
+
+#: fortran/simplify.c:1635
+#, gcc-internal-format
+msgid "gfc_simplify_dcmplx(): Bad type (x)"
+msgstr ""
+
+#: fortran/simplify.c:1654
+#, gcc-internal-format
+msgid "gfc_simplify_dcmplx(): Bad type (y)"
+msgstr ""
+
+#: fortran/simplify.c:1731
+#, gcc-internal-format
+msgid "in gfc_simplify_cos(): Bad type"
+msgstr ""
+
+#: fortran/simplify.c:1876
+#, gcc-internal-format
+msgid "gfc_simplify_dim(): Bad type"
+msgstr ""
+
+#: fortran/simplify.c:2184
+#, gcc-internal-format
+msgid "in gfc_simplify_exp(): Bad type"
+msgstr ""
+
+#: fortran/simplify.c:2350
+#, gcc-internal-format
+msgid "gfc_simplify_floor(): Bad kind"
+msgstr ""
+
+#: fortran/simplify.c:2502
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of IACHAR at %L must be of length one"
+msgstr ""
+
+#: fortran/simplify.c:2510
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of IACHAR function at %L outside of range 0..127"
+msgstr ""
+
+#: fortran/simplify.c:2625
+#, gcc-internal-format, gfc-internal-format
+msgid "Sum of second and third arguments of IBITS exceeds bit size at %L"
+msgstr ""
+
+#: fortran/simplify.c:2649
+#, gcc-internal-format
+msgid "IBITS: Bad bit"
+msgstr ""
+
+#: fortran/simplify.c:2700
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of ICHAR at %L must be of length one"
+msgstr ""
+
+#. Left shift, as in SHIFTL.
+#: fortran/simplify.c:3065 fortran/simplify.c:3073
+#, gcc-internal-format, gfc-internal-format
+msgid "Second argument of %s is negative at %L"
+msgstr ""
+
+#: fortran/simplify.c:3085
+#, gcc-internal-format, gfc-internal-format
+msgid "Magnitude of second argument of %s exceeds bit size at %L"
+msgstr ""
+
+#: fortran/simplify.c:3211
+#, gcc-internal-format, gfc-internal-format
+msgid "Magnitude of second argument of ISHFTC exceeds BIT_SIZE of first argument at %L"
+msgstr ""
+
+#: fortran/simplify.c:3514 fortran/simplify.c:3649
+#, gcc-internal-format, gfc-internal-format
+msgid "DIM argument at %L is out of bounds"
+msgstr ""
+
+#: fortran/simplify.c:3828
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of LOG at %L cannot be less than or equal to zero"
+msgstr ""
+
+#: fortran/simplify.c:3841
+#, gcc-internal-format, gfc-internal-format
+msgid "Complex argument of LOG at %L cannot be zero"
+msgstr ""
+
+#: fortran/simplify.c:3852
+#, gcc-internal-format
+msgid "gfc_simplify_log: bad type"
+msgstr ""
+
+#: fortran/simplify.c:3869
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of LOG10 at %L cannot be less than or equal to zero"
+msgstr ""
+
+#: fortran/simplify.c:4172
+#, gcc-internal-format
+msgid "simplify_min_max(): Bad type in arglist"
+msgstr ""
+
+#. Result is processor-dependent.
+#: fortran/simplify.c:4348
+#, gcc-internal-format, gfc-internal-format
+msgid "Second argument MOD at %L is zero"
+msgstr ""
+
+#. Result is processor-dependent.
+#: fortran/simplify.c:4359
+#, gcc-internal-format, gfc-internal-format
+msgid "Second argument of MOD at %L is zero"
+msgstr ""
+
+#: fortran/simplify.c:4370
+#, gcc-internal-format
+msgid "gfc_simplify_mod(): Bad arguments"
+msgstr ""
+
+#. Result is processor-dependent. This processor just opts
+#. to not handle it at all.
+#. Result is processor-dependent.
+#: fortran/simplify.c:4396 fortran/simplify.c:4408
+#, gcc-internal-format, gfc-internal-format
+msgid "Second argument of MODULO at %L is zero"
+msgstr ""
+
+#: fortran/simplify.c:4428
+#, gcc-internal-format
+msgid "gfc_simplify_modulo(): Bad arguments"
+msgstr ""
+
+#: fortran/simplify.c:4488
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of NEAREST is NaN at %L"
+msgstr ""
+
+#: fortran/simplify.c:4964
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
+msgstr ""
+
+#: fortran/simplify.c:5019
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
+msgstr ""
+
+#: fortran/simplify.c:5169
+#, gcc-internal-format, gfc-internal-format
+msgid "Reshaped array too large at %C"
+msgstr ""
+
+#: fortran/simplify.c:5283
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of SCALE overflows its kind at %L"
+msgstr ""
+
+#: fortran/simplify.c:5943
+#, gcc-internal-format
+msgid "Bad type in gfc_simplify_sign"
+msgstr ""
+
+#: fortran/simplify.c:5972
+#, gcc-internal-format
+msgid "in gfc_simplify_sin(): Bad type"
+msgstr ""
+
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
+#, gcc-internal-format
+msgid "Failure getting length of a constant array."
+msgstr ""
+
+#: fortran/simplify.c:6187
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of SQRT at %L has a negative value"
+msgstr ""
+
+#: fortran/simplify.c:6203
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid argument of SQRT at %L"
+msgstr ""
+
+#: fortran/simplify.c:6498
+#, gcc-internal-format, gfc-internal-format
+msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
+msgstr ""
+
+#: fortran/simplify.c:6521
+#, gcc-internal-format, gfc-internal-format
+msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
+msgstr ""
+
+#: fortran/simplify.c:6856
+#, gcc-internal-format
+msgid "gfc_convert_constant(): Unexpected type"
+msgstr ""
+
+#: fortran/simplify.c:6942
+#, gcc-internal-format
+msgid "Character %qs in string at %L cannot be converted into character kind %d"
+msgstr ""
+
+#: fortran/st.c:254
+#, gcc-internal-format
+msgid "gfc_free_statement(): Bad statement"
+msgstr ""
+
+#: fortran/symbol.c:131
+#, gcc-internal-format, gfc-internal-format
+msgid "IMPLICIT NONE (type) statement at %L following an IMPLICIT statement"
+msgstr ""
+
+#: fortran/symbol.c:168
+#, gcc-internal-format
+msgid "Letter %<%c%> already set in IMPLICIT statement at %C"
+msgstr ""
+
+#: fortran/symbol.c:190
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot specify IMPLICIT at %C after IMPLICIT NONE"
+msgstr ""
+
+#: fortran/symbol.c:200
+#, gcc-internal-format, gfc-internal-format
+msgid "Letter %c already has an IMPLICIT type at %C"
+msgstr ""
+
+#: fortran/symbol.c:224
+#, gcc-internal-format
+msgid "Option %<-fallow-leading-underscore%> is for use only by gfortran developers, and should not be used for implicitly typed variables"
+msgstr ""
+
+#: fortran/symbol.c:229
+#, gcc-internal-format
+msgid "gfc_get_default_type(): Bad symbol %qs"
+msgstr ""
+
+#: fortran/symbol.c:248
+#, gcc-internal-format
+msgid "gfc_set_default_type(): symbol already has a type"
+msgstr ""
+
+#: fortran/symbol.c:256
+#, gcc-internal-format
+msgid "Symbol %qs at %L has no IMPLICIT type"
+msgstr ""
+
+#. BIND(C) variables should not be implicitly declared.
+#: fortran/symbol.c:276
+#, gcc-internal-format
+msgid "Implicitly declared BIND(C) variable %qs at %L may not be C interoperable"
+msgstr ""
+
+#. Dummy args to a BIND(C) routine may not be interoperable if
+#. they are implicitly typed.
+#: fortran/symbol.c:292
+#, gcc-internal-format
+msgid "Implicitly declared variable %qs at %L may not be C interoperable but it is a dummy argument to the BIND(C) procedure %qs at %L"
+msgstr ""
+
+#: fortran/symbol.c:333
+#, gcc-internal-format
+msgid "Function result %qs at %L has no IMPLICIT type"
+msgstr ""
+
+#: fortran/symbol.c:424
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
+msgstr ""
+
+#: fortran/symbol.c:448
+#, gcc-internal-format, gfc-internal-format
+msgid "Namelist group name at %L cannot have the SAVE attribute"
+msgstr ""
+
+#: fortran/symbol.c:463
+#, gcc-internal-format, gfc-internal-format
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr ""
+
+#: fortran/symbol.c:489
+#, gcc-internal-format, gfc-internal-format
+msgid "Procedure pointer at %C"
+msgstr ""
+
+#: fortran/symbol.c:658
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute applied to %s %s at %L"
+msgstr ""
+
+#: fortran/symbol.c:665
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) applied to %s %s at %L"
+msgstr ""
+
+#: fortran/symbol.c:777 fortran/symbol.c:1514
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr ""
+
+#: fortran/symbol.c:780
+#, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr ""
+
+#: fortran/symbol.c:788
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute with %s attribute at %L"
+msgstr ""
+
+#: fortran/symbol.c:794
+#, gcc-internal-format
+msgid "%s attribute with %s attribute in %qs at %L"
+msgstr ""
+
+#: fortran/symbol.c:838
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot change attributes of USE-associated symbol at %L"
+msgstr ""
+
+#: fortran/symbol.c:841
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot change attributes of USE-associated symbol %s at %L"
+msgstr ""
+
+#: fortran/symbol.c:857
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate %s attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.c:899
+#, gcc-internal-format, gfc-internal-format
+msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
+msgstr ""
+
+#: fortran/symbol.c:925
+#, gcc-internal-format
+msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
+msgstr ""
+
+#: fortran/symbol.c:951
+#, gcc-internal-format
+msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
+msgstr ""
+
+#: fortran/symbol.c:1081
+#, gcc-internal-format, gfc-internal-format
+msgid "Cray Pointee at %L appears in multiple pointer() statements"
+msgstr ""
+
+#: fortran/symbol.c:1100
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate PROTECTED attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.c:1133
+#, gcc-internal-format, gfc-internal-format
+msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
+msgstr ""
+
+#: fortran/symbol.c:1144
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate SAVE attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.c:1164
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate VALUE attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.c:1183
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate VOLATILE attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.c:1202
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.c:1510
+#, gcc-internal-format
+msgid "%s attribute of %qs conflicts with %s attribute at %L"
+msgstr ""
+
+#: fortran/symbol.c:1544
+#, gcc-internal-format, gfc-internal-format
+msgid "%s procedure at %L is already declared as %s procedure"
+msgstr ""
+
+#: fortran/symbol.c:1579
+#, gcc-internal-format, gfc-internal-format
+msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
+msgstr ""
+
+#: fortran/symbol.c:1603
+#, gcc-internal-format, gfc-internal-format
+msgid "ACCESS specification at %L was already specified"
+msgstr ""
+
+#: fortran/symbol.c:1620
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate BIND attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.c:1627
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) at %L"
+msgstr ""
+
+#: fortran/symbol.c:1643
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate EXTENDS attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.c:1647
+#, gcc-internal-format, gfc-internal-format
+msgid "EXTENDS at %L"
+msgstr ""
+
+#: fortran/symbol.c:1668
+#, gcc-internal-format
+msgid "Symbol %qs at %L already has an explicit interface"
+msgstr ""
+
+#: fortran/symbol.c:1675
+#, gcc-internal-format
+msgid "%qs at %L has attributes specified outside its INTERFACE body"
+msgstr ""
+
+#: fortran/symbol.c:1709
+#, gcc-internal-format, gfc-internal-format
+msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
+msgstr ""
+
+#: fortran/symbol.c:1713
+#, gcc-internal-format
+msgid "Symbol %qs at %L already has basic type of %s"
+msgstr ""
+
+#: fortran/symbol.c:1720
+#, gcc-internal-format
+msgid "Procedure %qs at %L may not have basic type of %s"
+msgstr ""
+
+#: fortran/symbol.c:1732
+#, gcc-internal-format
+msgid "Symbol %qs at %L cannot have a type"
+msgstr ""
+
+#: fortran/symbol.c:1903
+#, gcc-internal-format, gfc-internal-format
+msgid "Component '%s' at %C already declared at %L"
+msgstr ""
+
+#: fortran/symbol.c:1914
+#, gcc-internal-format, gfc-internal-format
+msgid "Component '%s' at %C already in the parent type at %L"
+msgstr ""
+
+#: fortran/symbol.c:1999
+#, gcc-internal-format
+msgid "Symbol %qs at %C is ambiguous"
+msgstr ""
+
+#: fortran/symbol.c:2031
+#, gcc-internal-format
+msgid "Derived type %qs at %C is being used before it is defined"
+msgstr ""
+
+#: fortran/symbol.c:2069
+#, gcc-internal-format
+msgid "Component %qs at %C is a PRIVATE component of %qs"
+msgstr ""
+
+#: fortran/symbol.c:2087
+#, gcc-internal-format
+msgid "%qs at %C is not a member of the %qs structure"
+msgstr ""
+
+#: fortran/symbol.c:2226
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate statement label %d at %L and %L"
+msgstr ""
+
+#: fortran/symbol.c:2237
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d at %C already referenced as branch target"
+msgstr ""
+
+#: fortran/symbol.c:2247
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d at %C already referenced as a format label"
+msgstr ""
+
+#: fortran/symbol.c:2253
+#, gcc-internal-format, gfc-internal-format
+msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
+msgstr ""
+
+#: fortran/symbol.c:2295
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d at %C previously used as a FORMAT label"
+msgstr ""
+
+#: fortran/symbol.c:2304
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d at %C previously used as branch target"
+msgstr ""
+
+#: fortran/symbol.c:2310
+#, gcc-internal-format, gfc-internal-format
+msgid "Shared DO termination label %d at %C"
+msgstr ""
+
+#: fortran/symbol.c:2612
+#, gcc-internal-format
+msgid "new_symbol(): Symbol name too long"
+msgstr ""
+
+#: fortran/symbol.c:2636
+#, gcc-internal-format
+msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
+msgstr ""
+
+#: fortran/symbol.c:2639
+#, gcc-internal-format
+msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
+msgstr ""
+
+#. Symbol is from another namespace.
+#: fortran/symbol.c:2860
+#, gcc-internal-format
+msgid "Symbol %qs at %C has already been host associated"
+msgstr ""
+
+#: fortran/symbol.c:3851
+#, gcc-internal-format
+msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
+msgstr ""
+
+#: fortran/symbol.c:3864
+#, gcc-internal-format
+msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
+msgstr ""
+
+#: fortran/symbol.c:3882
+#, gcc-internal-format
+msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
+msgstr ""
+
+#: fortran/symbol.c:3903
+#, gcc-internal-format, gfc-internal-format
+msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
+msgstr ""
+
+#: fortran/symbol.c:3913
+#, gcc-internal-format, gfc-internal-format
+msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
+msgstr ""
+
+#: fortran/symbol.c:3924
+#, gcc-internal-format, gfc-internal-format
+msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
+msgstr ""
+
+#: fortran/symbol.c:3963
+#, gcc-internal-format
+msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
+msgstr ""
+
+#: fortran/symbol.c:3973
+#, gcc-internal-format
+msgid "Component %qs in derived type %qs at %L may not be C interoperable"
+msgstr ""
+
+#: fortran/symbol.c:3987
+#, gcc-internal-format
+msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
+msgstr ""
+
+#: fortran/symbol.c:3995
+#, gcc-internal-format
+msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
+msgstr ""
+
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
+#, gcc-internal-format
+msgid "Symbol %qs is used before it is typed at %L"
+msgstr ""
+
+#: fortran/target-memory.c:136
+#, gcc-internal-format
+msgid "Invalid expression in gfc_element_size."
+msgstr ""
+
+#: fortran/target-memory.c:356
+#, gcc-internal-format
+msgid "Invalid expression in gfc_target_encode_expr."
+msgstr ""
+
+#: fortran/target-memory.c:620
+#, gcc-internal-format
+msgid "Invalid expression in gfc_target_interpret_expr."
+msgstr ""
+
+#: fortran/target-memory.c:691
+#, gcc-internal-format, gfc-internal-format
+msgid "Overlapping unequal initializers in EQUIVALENCE at %L"
+msgstr ""
+
+#: fortran/target-memory.c:779
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ constant at %L is too large (%ld vs %ld bits)"
+msgstr ""
+
+#. Problems occur when we get something like
+#. integer :: a(lots) = (/(i, i=1, lots)/)
+#: fortran/trans-array.c:5482
+#, gcc-internal-format
+msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
+msgstr ""
+
+#: fortran/trans-array.c:7263
+#, gcc-internal-format
+msgid "Creating array temporary at %L for argument %qs"
+msgstr ""
+
+#: fortran/trans-array.c:9170
+#, gcc-internal-format, gfc-internal-format
+msgid "bad expression type during walk (%d)"
+msgstr ""
+
+#: fortran/trans-common.c:410
+#, gcc-internal-format
+msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
+msgstr ""
+
+#: fortran/trans-common.c:783
+#, gcc-internal-format
+msgid "get_mpz(): Not an integer constant"
+msgstr ""
+
+#: fortran/trans-common.c:811
+#, gcc-internal-format
+msgid "element_number(): Bad dimension type"
+msgstr ""
+
+#: fortran/trans-common.c:873
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad array reference at %L"
+msgstr ""
+
+#: fortran/trans-common.c:881
+#, gcc-internal-format, gfc-internal-format
+msgid "Illegal reference type at %L as EQUIVALENCE object"
+msgstr ""
+
+#: fortran/trans-common.c:921
+#, gcc-internal-format, gfc-internal-format
+msgid "Inconsistent equivalence rules involving '%s' at %L and '%s' at %L"
+msgstr ""
+
+#. Aligning this field would misalign a previous field.
+#: fortran/trans-common.c:1054
+#, gcc-internal-format
+msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
+msgstr ""
+
+#: fortran/trans-common.c:1119
+#, gcc-internal-format
+msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
+msgstr ""
+
+#: fortran/trans-common.c:1134
+#, gcc-internal-format
+msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
+msgstr ""
+
+#: fortran/trans-common.c:1150
+#, gcc-internal-format
+msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use -fno-align-commons"
+msgstr ""
+
+#: fortran/trans-common.c:1156
+#, gcc-internal-format
+msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use -fno-align-commons"
+msgstr ""
+
+#: fortran/trans-common.c:1177
+#, gcc-internal-format, gfc-internal-format
+msgid "COMMON '%s' at %L does not exist"
+msgstr ""
+
+#: fortran/trans-common.c:1186
+#, gcc-internal-format
+msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
+msgstr ""
+
+#: fortran/trans-common.c:1191
+#, gcc-internal-format
+msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
+msgstr ""
+
+#: fortran/trans-const.c:335
+#, gcc-internal-format, gfc-internal-format
+msgid "Assigning value other than 0 or 1 to LOGICAL has undefined result at %L"
+msgstr ""
+
+#: fortran/trans-const.c:372
+#, gcc-internal-format, gfc-internal-format
+msgid "gfc_conv_constant_to_tree(): invalid type: %s"
+msgstr ""
+
+#: fortran/trans-const.c:403
+#, gcc-internal-format, gfc-internal-format
+msgid "non-constant initialization expression at %L"
+msgstr ""
+
+#: fortran/trans-decl.c:1494
+#, gcc-internal-format
+msgid "intrinsic variable which isn't a procedure"
+msgstr ""
+
+#: fortran/trans-decl.c:3869 fortran/trans-decl.c:5880
+#, gcc-internal-format
+msgid "Return value of function %qs at %L not set"
+msgstr ""
+
+#: fortran/trans-decl.c:4262
+#, gcc-internal-format
+msgid "Deferred type parameter not yet supported"
+msgstr ""
+
+#: fortran/trans-decl.c:4489
+#, gcc-internal-format
+msgid "backend decl for module variable %qs already exists"
+msgstr ""
+
+#: fortran/trans-decl.c:4502
+#, gcc-internal-format
+msgid "Unused PRIVATE module variable %qs declared at %L"
+msgstr ""
+
+#: fortran/trans-decl.c:5065
+#, gcc-internal-format
+msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
+msgstr ""
+
+#: fortran/trans-decl.c:5071
+#, gcc-internal-format
+msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
+msgstr ""
+
+#: fortran/trans-decl.c:5081 fortran/trans-decl.c:5202
+#, gcc-internal-format
+msgid "Unused dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/trans-decl.c:5096
+#, gcc-internal-format
+msgid "Unused module variable %qs which has been explicitly imported at %L"
+msgstr ""
+
+#: fortran/trans-decl.c:5105
+#, gcc-internal-format
+msgid "Unused variable %qs declared at %L"
+msgstr ""
+
+#: fortran/trans-decl.c:5154
+#, gcc-internal-format
+msgid "Unused parameter %qs declared at %L"
+msgstr ""
+
+#: fortran/trans-decl.c:5158
+#, gcc-internal-format
+msgid "Unused parameter %qs which has been explicitly imported at %L"
+msgstr ""
+
+#: fortran/trans-decl.c:5174
+#, gcc-internal-format
+msgid "Return value %qs of function %qs declared at %L not set"
+msgstr ""
+
+#: fortran/trans-expr.c:797
+#, gcc-internal-format, gfc-internal-format
+msgid "Can't compute the length of the char array at %L."
+msgstr ""
+
+#: fortran/trans-expr.c:1396
+#, gcc-internal-format, gfc-internal-format
+msgid "Code for reallocating the allocatable array at %L will be added"
+msgstr ""
+
+#: fortran/trans-expr.c:1400
+#, gcc-internal-format, gfc-internal-format
+msgid "Code for reallocating the allocatable variable at %L will be added"
+msgstr ""
+
+#: fortran/trans-expr.c:1708
+#, gcc-internal-format, gfc-internal-format
+msgid "Sorry, coindexed access to a pointer or allocatable component of the coindexed coarray at %L is not yet supported"
+msgstr ""
+
+#: fortran/trans-expr.c:1722
+#, gcc-internal-format, gfc-internal-format
+msgid "Sorry, coindexed coarray at %L with allocatable component is not yet supported"
+msgstr ""
+
+#: fortran/trans-expr.c:1745
+#, gcc-internal-format, gfc-internal-format
+msgid "Sorry, coindexed access at %L to a scalar component with an array partref is not yet supported"
+msgstr ""
+
+#: fortran/trans-expr.c:3109
+#, gcc-internal-format
+msgid "Unknown intrinsic op"
+msgstr ""
+
+#: fortran/trans-expr.c:4397
+#, gcc-internal-format, gfc-internal-format
+msgid "Unknown argument list function at %L"
+msgstr ""
+
+#: fortran/trans-intrinsic.c:869
+#, gcc-internal-format
+msgid "Intrinsic function %qs (%d) not recognized"
+msgstr ""
+
+#: fortran/trans-intrinsic.c:1487 fortran/trans-intrinsic.c:1873
+#: fortran/trans-intrinsic.c:2069
+#, gcc-internal-format
+msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
+msgstr ""
+
+#: fortran/trans-io.c:1861
+#, gcc-internal-format
+msgid "build_dt: format with namelist"
+msgstr ""
+
+#: fortran/trans-io.c:2265
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad IO basetype (%d)"
+msgstr ""
+
+#: fortran/trans-openmp.c:4300
+#, gcc-internal-format
+msgid "gfc_trans_omp_workshare(): Bad statement code"
+msgstr ""
+
+#: fortran/trans-stmt.c:554
+#, gcc-internal-format, gfc-internal-format
+msgid "An alternate return at %L without a * dummy argument"
+msgstr ""
+
+#: fortran/trans-stmt.c:729
+#, gcc-internal-format, gfc-internal-format
+msgid "Sorry, the lock component of derived type at %L is not yet supported"
+msgstr ""
+
+#: fortran/trans-stmt.c:994
+#, gcc-internal-format, gfc-internal-format
+msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
+msgstr ""
+
+#: fortran/trans-stmt.c:2723
+#, gcc-internal-format
+msgid "gfc_trans_select(): Bad type for case expr."
+msgstr ""
+
+#: fortran/trans-types.c:510
+#, gcc-internal-format
+msgid "INTEGER(KIND=8) is not available for %<-fdefault-integer-8%> option"
+msgstr ""
+
+#: fortran/trans-types.c:519
+#, gcc-internal-format
+msgid "INTEGER(KIND=8) is not available for %<-finteger-4-integer-8%> option"
+msgstr ""
+
+#: fortran/trans-types.c:538
+#, gcc-internal-format
+msgid "REAL(KIND=8) is not available for %<-fdefault-real-8%> option"
+msgstr ""
+
+#: fortran/trans-types.c:546
+#, gcc-internal-format
+msgid "REAL(KIND=8) is not available for %<-freal-4-real-8%> option"
+msgstr ""
+
+#: fortran/trans-types.c:554
+#, gcc-internal-format
+msgid "REAL(KIND=10) is not available for %<-freal-4-real-10%> option"
+msgstr ""
+
+#: fortran/trans-types.c:562
+#, gcc-internal-format
+msgid "REAL(KIND=16) is not available for %<-freal-4-real-16%> option"
+msgstr ""
+
+#: fortran/trans-types.c:577
+#, gcc-internal-format
+msgid "Use of %<-fdefault-double-8%> requires %<-fdefault-real-8%>"
+msgstr ""
+
+#: fortran/trans-types.c:587
+#, gcc-internal-format
+msgid "REAL(KIND=4) is not available for %<-freal-8-real-4%> option"
+msgstr ""
+
+#: fortran/trans-types.c:595
+#, gcc-internal-format
+msgid "REAL(KIND=10) is not available for %<-freal-8-real-10%> option"
+msgstr ""
+
+#: fortran/trans-types.c:603
+#, gcc-internal-format
+msgid "REAL(KIND=10) is not available for %<-freal-8-real-16%> option"
+msgstr ""
+
+#: fortran/trans-types.c:743
+#, gcc-internal-format
+msgid "gfc_validate_kind(): Got bad type"
+msgstr ""
+
+#: fortran/trans-types.c:747
+#, gcc-internal-format
+msgid "gfc_validate_kind(): Got bad kind"
+msgstr ""
+
+#: fortran/trans-types.c:1473
+#, gcc-internal-format, gfc-internal-format
+msgid "Array element size too big at %C"
+msgstr ""
+
+#: fortran/trans.c:1934
+#, gcc-internal-format
+msgid "gfc_trans_code(): Bad statement code"
+msgstr ""
+
+#: java/class.c:853
+#, gcc-internal-format
+msgid "bad method signature"
+msgstr ""
+
+#: java/class.c:912
+#, gcc-internal-format
+msgid "misplaced ConstantValue attribute (not in any field)"
+msgstr ""
+
+#: java/class.c:915
+#, gcc-internal-format, gfc-internal-format
+msgid "duplicate ConstantValue attribute for field '%s'"
+msgstr ""
+
+#: java/class.c:926
+#, gcc-internal-format, gfc-internal-format
+msgid "ConstantValue attribute of field '%s' has wrong type"
+msgstr ""
+
+#: java/class.c:1651
+#, gcc-internal-format
+msgid "abstract method in non-abstract class"
+msgstr ""
+
+#: java/class.c:2714
+#, gcc-internal-format
+msgid "non-static method %q+D overrides static method"
+msgstr ""
+
+#: java/decl.c:1225
+#, gcc-internal-format
+msgid "%q+D used prior to declaration"
+msgstr ""
+
+#: java/decl.c:1648
+#, gcc-internal-format
+msgid "In %+D: overlapped variable and exception ranges at %d"
+msgstr ""
+
+#: java/decl.c:1699
+#, gcc-internal-format
+msgid "bad type in parameter debug info"
+msgstr ""
+
+#: java/decl.c:1708
+#, gcc-internal-format
+msgid "bad PC range for debug info for local %q+D"
+msgstr ""
+
+#: java/expr.c:369
+#, gcc-internal-format, gfc-internal-format
+msgid "need to insert runtime check for %s"
+msgstr ""
+
+#: java/expr.c:513 java/expr.c:560
+#, gcc-internal-format, gfc-internal-format
+msgid "assert: %s is assign compatible with %s"
+msgstr ""
+
+#: java/expr.c:671
+#, gcc-internal-format
+msgid "stack underflow - dup* operation"
+msgstr ""
+
+#: java/expr.c:1670
+#, gcc-internal-format
+msgid "reference %qs is ambiguous: appears in interface %qs and interface %qs"
+msgstr ""
+
+#: java/expr.c:1698
+#, gcc-internal-format
+msgid "field %qs not found"
+msgstr ""
+
+#: java/expr.c:2256
+#, gcc-internal-format, gfc-internal-format
+msgid "method '%s' not found in class"
+msgstr ""
+
+#: java/expr.c:2448
+#, gcc-internal-format, gfc-internal-format
+msgid "failed to find class '%s'"
+msgstr ""
+
+#: java/expr.c:2489
+#, gcc-internal-format, gfc-internal-format
+msgid "class '%s' has no method named '%s' matching signature '%s'"
+msgstr ""
+
+#: java/expr.c:2520
+#, gcc-internal-format
+msgid "invokestatic on non static method"
+msgstr ""
+
+#: java/expr.c:2525
+#, gcc-internal-format
+msgid "invokestatic on abstract method"
+msgstr ""
+
+#: java/expr.c:2533
+#, gcc-internal-format
+msgid "invoke[non-static] on static method"
+msgstr ""
+
+#: java/expr.c:2891
+#, gcc-internal-format, gfc-internal-format
+msgid "missing field '%s' in '%s'"
+msgstr ""
+
+#: java/expr.c:2898
+#, gcc-internal-format, gfc-internal-format
+msgid "mismatching signature for field '%s' in '%s'"
+msgstr ""
+
+#: java/expr.c:2927
+#, gcc-internal-format
+msgid "assignment to final field %q+D not in field%'s class"
+msgstr ""
+
+#: java/expr.c:3155
+#, gcc-internal-format
+msgid "invalid PC in line number table"
+msgstr ""
+
+#: java/expr.c:3205
+#, gcc-internal-format, gfc-internal-format
+msgid "unreachable bytecode from %d to before %d"
+msgstr ""
+
+#: java/expr.c:3247
+#, gcc-internal-format, gfc-internal-format
+msgid "unreachable bytecode from %d to the end of the method"
+msgstr ""
+
+#. duplicate code from LOAD macro
+#: java/expr.c:3555
+#, gcc-internal-format
+msgid "unrecognized wide sub-instruction"
+msgstr ""
+
+#: java/jcf-parse.c:525
+#, gcc-internal-format, gfc-internal-format
+msgid "<constant pool index %d not in range>"
+msgstr ""
+
+#: java/jcf-parse.c:535
+#, gcc-internal-format, gfc-internal-format
+msgid "<constant pool index %d unexpected type"
+msgstr ""
+
+#: java/jcf-parse.c:1117
+#, gcc-internal-format
+msgid "bad string constant"
+msgstr "помилкова рядкова стала"
+
+#: java/jcf-parse.c:1135
+#, gcc-internal-format, gfc-internal-format
+msgid "bad value constant type %d, index %d"
+msgstr ""
+
+#: java/jcf-parse.c:1415 java/jcf-parse.c:1421
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot find file for class %s"
+msgstr ""
+
+#: java/jcf-parse.c:1446
+#, gcc-internal-format
+msgid "not a valid Java .class file"
+msgstr ""
+
+#: java/jcf-parse.c:1449
+#, gcc-internal-format
+msgid "error while parsing constant pool"
+msgstr ""
+
+#: java/jcf-parse.c:1465
+#, gcc-internal-format, gfc-internal-format
+msgid "reading class %s for the second time from %s"
+msgstr ""
+
+#: java/jcf-parse.c:1483
+#, gcc-internal-format
+msgid "error while parsing fields"
+msgstr ""
+
+#: java/jcf-parse.c:1486
+#, gcc-internal-format
+msgid "error while parsing methods"
+msgstr ""
+
+#: java/jcf-parse.c:1489
+#, gcc-internal-format
+msgid "error while parsing final attributes"
+msgstr ""
+
+#: java/jcf-parse.c:1528
+#, gcc-internal-format
+msgid "duplicate class will only be compiled once"
+msgstr ""
+
+#: java/jcf-parse.c:1625
+#, gcc-internal-format
+msgid "missing Code attribute"
+msgstr ""
+
+#: java/jcf-parse.c:1873
+#, gcc-internal-format
+msgid "no input file specified"
+msgstr "не вказано файла вхідних даних"
+
+#: java/jcf-parse.c:1909
+#, gcc-internal-format
+msgid "can%'t close input file %s: %m"
+msgstr ""
+
+#: java/jcf-parse.c:1952
+#, gcc-internal-format, gfc-internal-format
+msgid "bad zip/jar file %s"
+msgstr ""
+
+#: java/jcf-parse.c:2155
+#, gcc-internal-format, gfc-internal-format
+msgid "error while reading %s from zip file"
+msgstr ""
+
+#: java/jvspec.c:395
+#, gcc-internal-format
+msgid "can%'t specify %<-D%> without %<--main%>"
+msgstr ""
+
+#: java/jvspec.c:399
+#, gcc-internal-format
+msgid "%qs is not a valid class name"
+msgstr ""
+
+#: java/jvspec.c:405
+#, gcc-internal-format
+msgid "--resource requires -o"
+msgstr ""
+
+#: java/jvspec.c:412
+#, gcc-internal-format
+msgid "already-compiled .class files ignored with -C"
+msgstr ""
+
+#: java/jvspec.c:419
+#, gcc-internal-format
+msgid "cannot specify both -C and -o"
+msgstr ""
+
+#: java/jvspec.c:431
+#, gcc-internal-format
+msgid "cannot create temporary file"
+msgstr "не вдалося створити тимчасовий файл"
+
+#: java/jvspec.c:454
+#, gcc-internal-format
+msgid "using both @FILE with multiple files not implemented"
+msgstr ""
+
+#: java/jvspec.c:539
+#, gcc-internal-format
+msgid "cannot specify %<main%> class when not linking"
+msgstr ""
+
+#: java/lang.c:592
+#, gcc-internal-format
+msgid "-fexcess-precision=standard for Java"
+msgstr ""
+
+#: java/lang.c:603
+#, gcc-internal-format
+msgid "-findirect-dispatch is incompatible with -freduced-reflection"
+msgstr ""
+
+#: java/lang.c:606
+#, gcc-internal-format
+msgid "-fjni is incompatible with -freduced-reflection"
+msgstr ""
+
+#: java/lang.c:617
+#, gcc-internal-format
+msgid "can%'t do dependency tracking with input from stdin"
+msgstr ""
+
+#: java/lang.c:633
+#, gcc-internal-format
+msgid "couldn%'t determine target name for dependency tracking"
+msgstr ""
+
+#: java/mangle_name.c:334 java/mangle_name.c:411
+#, gcc-internal-format
+msgid "internal error - invalid Utf8 name"
+msgstr ""
+
+#: java/typeck.c:437
+#, gcc-internal-format
+msgid "junk at end of signature string"
+msgstr ""
+
+#: java/verify-glue.c:388
+#, gcc-internal-format, gfc-internal-format
+msgid "verification failed: %s"
+msgstr ""
+
+#: java/verify-glue.c:390
+#, gcc-internal-format, gfc-internal-format
+msgid "verification failed at PC=%d: %s"
+msgstr ""
+
+#: java/verify-glue.c:478
+#, gcc-internal-format
+msgid "bad pc in exception_table"
+msgstr ""
+
+#: jit/docs/examples/tut05-bf.c:242
+#, gcc-internal-format
+msgid "too many open parens"
+msgstr ""
+
+#: jit/docs/examples/tut05-bf.c:275
+#, gcc-internal-format
+msgid "mismatching parens"
+msgstr ""
+
+#: jit/docs/examples/tut05-bf.c:310
+#, gcc-internal-format
+msgid "unable to open file"
+msgstr "не вдалося відкрити файл"
+
+#: lto/lto-lang.c:812
+#, gcc-internal-format
+msgid "-fwpa and -fltrans are mutually exclusive"
+msgstr ""
+
+#: lto/lto-object.c:134
+#, gcc-internal-format, gfc-internal-format
+msgid "open %s failed: %s"
+msgstr ""
+
+#: lto/lto-object.c:178 lto/lto-object.c:213 lto/lto-object.c:310
+#: lto/lto-object.c:367 lto/lto-object.c:391
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: %s"
+msgstr "%s: %s"
+
+#: lto/lto-object.c:180
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: %s: %s"
+msgstr ""
+
+#: lto/lto-object.c:222
+#, gcc-internal-format, gfc-internal-format
+msgid "close: %s"
+msgstr ""
+
+#: lto/lto-object.c:278
+#, gcc-internal-format, gfc-internal-format
+msgid "two or more sections for %s"
+msgstr ""
+
+#: lto/lto-symtab.c:196
+#, gcc-internal-format
+msgid "%qD is defined with tls model %s"
+msgstr ""
+
+#: lto/lto-symtab.c:198
+#, gcc-internal-format, gfc-internal-format
+msgid "previously defined here as %s"
+msgstr ""
+
+#: lto/lto-symtab.c:387
+#, gcc-internal-format
+msgid "multiple prevailing defs for %qE"
+msgstr ""
+
+#: lto/lto-symtab.c:405
+#, gcc-internal-format
+msgid "%qD has already been defined"
+msgstr ""
+
+#: lto/lto-symtab.c:407
+#, gcc-internal-format
+msgid "previously defined here"
+msgstr ""
+
+#: lto/lto-symtab.c:489
+#, gcc-internal-format
+msgid "type of %qD does not match original declaration"
+msgstr ""
+
+#: lto/lto-symtab.c:497
+#, gcc-internal-format
+msgid "alignment of %qD is bigger than original declaration"
+msgstr ""
+
+#: lto/lto-symtab.c:503 lto/lto-symtab.c:607
+#, gcc-internal-format
+msgid "previously declared here"
+msgstr ""
+
+#: lto/lto-symtab.c:588
+#, gcc-internal-format
+msgid "variable %qD redeclared as function"
+msgstr ""
+
+#: lto/lto-symtab.c:595
+#, gcc-internal-format
+msgid "function %qD redeclared as variable"
+msgstr ""
+
+#: lto/lto.c:2023
+#, gcc-internal-format
+msgid "bytecode stream: garbage at the end of symbols section"
+msgstr ""
+
+#: lto/lto.c:2050
+#, gcc-internal-format
+msgid "could not parse hex number"
+msgstr ""
+
+#: lto/lto.c:2082
+#, gcc-internal-format, gfc-internal-format
+msgid "unexpected file name %s in linker resolution file. Expected %s"
+msgstr ""
+
+#: lto/lto.c:2091
+#, gcc-internal-format
+msgid "could not parse file offset"
+msgstr ""
+
+#: lto/lto.c:2094
+#, gcc-internal-format
+msgid "unexpected offset"
+msgstr ""
+
+#: lto/lto.c:2116
+#, gcc-internal-format
+msgid "invalid line in the resolution file"
+msgstr ""
+
+#: lto/lto.c:2127
+#, gcc-internal-format
+msgid "invalid resolution in the resolution file"
+msgstr ""
+
+#: lto/lto.c:2133
+#, gcc-internal-format
+msgid "resolution sub id %wx not in object file"
+msgstr ""
+
+#: lto/lto.c:2245
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot read LTO decls from %s"
+msgstr ""
+
+#: lto/lto.c:2351
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot open %s"
+msgstr "Не вдалося відкрити %s"
+
+#: lto/lto.c:2372
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot map %s"
+msgstr ""
+
+#: lto/lto.c:2383
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot read %s"
+msgstr "Не вдалося прочитати %s"
+
+#: lto/lto.c:2497
+#, gcc-internal-format
+msgid "lto_obj_file_open() failed"
+msgstr ""
+
+#: lto/lto.c:2520
+#, gcc-internal-format
+msgid "waitpid failed"
+msgstr "помилка waitpid"
+
+#: lto/lto.c:2523
+#, gcc-internal-format
+msgid "streaming subprocess failed"
+msgstr ""
+
+#: lto/lto.c:2526
+#, gcc-internal-format
+msgid "streaming subprocess was killed by signal"
+msgstr ""
+
+#: lto/lto.c:2602
+#, gcc-internal-format
+msgid "no LTRANS output list filename provided"
+msgstr ""
+
+#: lto/lto.c:2690
+#, gcc-internal-format
+msgid "opening LTRANS output list %s: %m"
+msgstr ""
+
+#: lto/lto.c:2696
+#, gcc-internal-format
+msgid "writing to LTRANS output list %s: %m"
+msgstr ""
+
+#: lto/lto.c:2707
+#, gcc-internal-format
+msgid "closing LTRANS output list %s: %m"
+msgstr ""
+
+#: lto/lto.c:2954
+#, gcc-internal-format
+msgid "could not open symbol resolution file: %m"
+msgstr ""
+
+#: lto/lto.c:3095
+#, gcc-internal-format
+msgid "errors during merging of translation units"
+msgstr ""
+
+#: objc/objc-act.c:452 objc/objc-act.c:6808
+#, gcc-internal-format
+msgid "%<@end%> missing in implementation context"
+msgstr ""
+
+#: objc/objc-act.c:605
+#, gcc-internal-format
+msgid "class attributes are not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.c:620
+#, gcc-internal-format
+msgid "category attributes are not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.c:623
+#, gcc-internal-format
+msgid "category attributes are not available in this version of the compiler, (ignored)"
+msgstr ""
+
+#: objc/objc-act.c:629
+#, gcc-internal-format
+msgid "class extensions are not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.c:643
+#, gcc-internal-format
+msgid "class extension for class %qE declared after its %<@implementation%>"
+msgstr ""
+
+#: objc/objc-act.c:658
+#, gcc-internal-format
+msgid "protocol attributes are not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.c:723
+#, gcc-internal-format
+msgid "%<@end%> must appear in an @implementation context"
+msgstr ""
+
+#: objc/objc-act.c:732
+#, gcc-internal-format
+msgid "%<@package%> is not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.c:734
+#, gcc-internal-format
+msgid "%<@package%> presently has the same effect as %<@public%>"
+msgstr ""
+
+#: objc/objc-act.c:745
+#, gcc-internal-format
+msgid "%<@optional%> is not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.c:747
+#, gcc-internal-format
+msgid "%<@required%> is not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.c:755
+#, gcc-internal-format
+msgid "%<@optional%> is allowed in @protocol context only"
+msgstr ""
+
+#: objc/objc-act.c:757
+#, gcc-internal-format
+msgid "%<@required%> is allowed in @protocol context only"
+msgstr ""
+
+#: objc/objc-act.c:864
+#, gcc-internal-format
+msgid "%<@property%> is not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.c:868
+#, gcc-internal-format
+msgid "%<readonly%> attribute conflicts with %<readwrite%> attribute"
+msgstr ""
+
+#: objc/objc-act.c:885
+#, gcc-internal-format
+msgid "%<readonly%> attribute conflicts with %<setter%> attribute"
+msgstr ""
+
+#: objc/objc-act.c:891
+#, gcc-internal-format
+msgid "%<assign%> attribute conflicts with %<retain%> attribute"
+msgstr ""
+
+#: objc/objc-act.c:896
+#, gcc-internal-format
+msgid "%<assign%> attribute conflicts with %<copy%> attribute"
+msgstr ""
+
+#: objc/objc-act.c:901
+#, gcc-internal-format
+msgid "%<retain%> attribute conflicts with %<copy%> attribute"
+msgstr ""
+
+#: objc/objc-act.c:918
+#, gcc-internal-format
+msgid "property declaration not in @interface or @protocol context"
+msgstr ""
+
+#: objc/objc-act.c:929
+#, gcc-internal-format
+msgid "invalid property declaration"
+msgstr "некоректне оголошення властивості"
+
+#: objc/objc-act.c:937
+#, gcc-internal-format
+msgid "property can not be an array"
+msgstr ""
+
+#. A @property is not an actual variable, but it is a way to
+#. describe a pair of accessor methods, so its type (which is
+#. the type of the return value of the getter and the first
+#. argument of the setter) can't be a bitfield (as return values
+#. and arguments of functions can not be bitfields).  The
+#. underlying instance variable could be a bitfield, but that is
+#. a different matter.
+#: objc/objc-act.c:955
+#, gcc-internal-format
+msgid "property can not be a bit-field"
+msgstr ""
+
+#: objc/objc-act.c:987
+#, gcc-internal-format
+msgid "object property %qD has no %<assign%>, %<retain%> or %<copy%> attribute; assuming %<assign%>"
+msgstr ""
+
+#: objc/objc-act.c:990
+#, gcc-internal-format
+msgid "%<assign%> can be unsafe for Objective-C objects; please state explicitly if you need it"
+msgstr ""
+
+#: objc/objc-act.c:997
+#, gcc-internal-format
+msgid "%<retain%> attribute is only valid for Objective-C objects"
+msgstr ""
+
+#: objc/objc-act.c:1001
+#, gcc-internal-format
+msgid "%<copy%> attribute is only valid for Objective-C objects"
+msgstr ""
+
+#: objc/objc-act.c:1055
+#, gcc-internal-format
+msgid "redeclaration of property %qD"
+msgstr ""
+
+#: objc/objc-act.c:1058 objc/objc-act.c:1123 objc/objc-act.c:1133
+#: objc/objc-act.c:1146 objc/objc-act.c:1157 objc/objc-act.c:1168
+#: objc/objc-act.c:1205 objc/objc-act.c:7581 objc/objc-act.c:7644
+#: objc/objc-act.c:7666 objc/objc-act.c:7679 objc/objc-act.c:7697
+#: objc/objc-act.c:7796
+#, gcc-internal-format
+msgid "originally specified here"
+msgstr ""
+
+#: objc/objc-act.c:1120
+#, gcc-internal-format
+msgid "'nonatomic' attribute of property %qD conflicts with previous declaration"
+msgstr ""
+
+#: objc/objc-act.c:1130
+#, gcc-internal-format
+msgid "'getter' attribute of property %qD conflicts with previous declaration"
+msgstr ""
+
+#: objc/objc-act.c:1143
+#, gcc-internal-format
+msgid "'setter' attribute of property %qD conflicts with previous declaration"
+msgstr ""
+
+#: objc/objc-act.c:1154
+#, gcc-internal-format
+msgid "assign semantics attributes of property %qD conflict with previous declaration"
+msgstr ""
+
+#: objc/objc-act.c:1165
+#, gcc-internal-format
+msgid "'readonly' attribute of property %qD conflicts with previous declaration"
+msgstr ""
+
+#: objc/objc-act.c:1203
+#, gcc-internal-format
+msgid "type of property %qD conflicts with previous declaration"
+msgstr ""
+
+#: objc/objc-act.c:1676
+#, gcc-internal-format
+msgid "the dot syntax is not available in Objective-C 1.0"
+msgstr ""
+
+#. We know that 'class_name' is an Objective-C class name as the
+#. parser won't call this function if it is not.  This is only a
+#. double-check for safety.
+#: objc/objc-act.c:1692
+#, gcc-internal-format
+msgid "could not find class %qE"
+msgstr ""
+
+#. Again, this should never happen, but we do check.
+#: objc/objc-act.c:1700
+#, gcc-internal-format
+msgid "could not find interface for class %qE"
+msgstr ""
+
+#: objc/objc-act.c:1706 objc/objc-act.c:6845 objc/objc-act.c:6976
+#, gcc-internal-format
+msgid "class %qE is deprecated"
+msgstr ""
+
+#: objc/objc-act.c:1735
+#, gcc-internal-format
+msgid "could not find setter/getter for %qE in class %qE"
+msgstr ""
+
+#: objc/objc-act.c:1771
+#, gcc-internal-format
+msgid "readonly property can not be set"
+msgstr ""
+
+#: objc/objc-act.c:2042
+#, gcc-internal-format
+msgid "method declaration not in @interface context"
+msgstr ""
+
+#: objc/objc-act.c:2046
+#, gcc-internal-format
+msgid "method attributes are not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.c:2066
+#, gcc-internal-format
+msgid "method definition not in @implementation context"
+msgstr ""
+
+#: objc/objc-act.c:2081
+#, gcc-internal-format
+msgid "method attributes can not be specified in @implementation context"
+msgstr ""
+
+#: objc/objc-act.c:2310
+#, gcc-internal-format
+msgid "class %qs does not implement the %qE protocol"
+msgstr ""
+
+#: objc/objc-act.c:2313
+#, gcc-internal-format
+msgid "type %qs does not conform to the %qE protocol"
+msgstr ""
+
+#: objc/objc-act.c:2594
+#, gcc-internal-format
+msgid "comparison of distinct Objective-C types lacks a cast"
+msgstr ""
+
+#: objc/objc-act.c:2598
+#, gcc-internal-format
+msgid "initialization from distinct Objective-C type"
+msgstr ""
+
+#: objc/objc-act.c:2602
+#, gcc-internal-format
+msgid "assignment from distinct Objective-C type"
+msgstr ""
+
+#: objc/objc-act.c:2606
+#, gcc-internal-format
+msgid "distinct Objective-C type in return"
+msgstr ""
+
+#: objc/objc-act.c:2610
+#, gcc-internal-format
+msgid "passing argument %d of %qE from distinct Objective-C type"
+msgstr ""
+
+#: objc/objc-act.c:2752
+#, gcc-internal-format
+msgid "statically allocated instance of Objective-C class %qE"
+msgstr ""
+
+#: objc/objc-act.c:2761
+#, gcc-internal-format
+msgid "redeclaration of Objective-C class %qs"
+msgstr ""
+
+#. This case happens when we are given an 'interface' which
+#. is not a valid class name.  For example if a typedef was
+#. used, and 'interface' really is the identifier of the
+#. typedef, but when you resolve it you don't get an
+#. Objective-C class, but something else, such as 'int'.
+#. This is an error; protocols make no sense unless you use
+#. them with Objective-C objects.
+#: objc/objc-act.c:2803
+#, gcc-internal-format
+msgid "only Objective-C object types can be qualified with a protocol"
+msgstr ""
+
+#: objc/objc-act.c:2867
+#, gcc-internal-format
+msgid "protocol %qE has circular dependency"
+msgstr ""
+
+#: objc/objc-act.c:2900 objc/objc-act.c:5709
+#, gcc-internal-format
+msgid "cannot find protocol declaration for %qE"
+msgstr ""
+
+#: objc/objc-act.c:3201 objc/objc-act.c:3856 objc/objc-act.c:6421
+#: objc/objc-act.c:6896 objc/objc-act.c:6969 objc/objc-act.c:7022
+#, gcc-internal-format
+msgid "cannot find interface declaration for %qE"
+msgstr ""
+
+#: objc/objc-act.c:3205
+#, gcc-internal-format
+msgid "interface %qE does not have valid constant string layout"
+msgstr ""
+
+#: objc/objc-act.c:3210
+#, gcc-internal-format
+msgid "cannot find reference tag for class %qE"
+msgstr ""
+
+#: objc/objc-act.c:3355
+#, gcc-internal-format
+msgid "%qE is not an Objective-C class name or alias"
+msgstr ""
+
+#: objc/objc-act.c:3370 objc/objc-act.c:3401 objc/objc-act.c:6802
+#: objc/objc-act.c:8127 objc/objc-act.c:8178
+#, gcc-internal-format
+msgid "Objective-C declarations may only appear in global scope"
+msgstr ""
+
+#: objc/objc-act.c:3375
+#, gcc-internal-format
+msgid "cannot find class %qE"
+msgstr ""
+
+#: objc/objc-act.c:3377
+#, gcc-internal-format
+msgid "class %qE already exists"
+msgstr ""
+
+#: objc/objc-act.c:3419 objc/objc-act.c:6861
+#, gcc-internal-format
+msgid "%qE redeclared as different kind of symbol"
+msgstr ""
+
+#: objc/objc-act.c:3710
+#, gcc-internal-format
+msgid "strong-cast assignment has been intercepted"
+msgstr ""
+
+#: objc/objc-act.c:3752
+#, gcc-internal-format
+msgid "strong-cast may possibly be needed"
+msgstr ""
+
+#: objc/objc-act.c:3762
+#, gcc-internal-format
+msgid "instance variable assignment has been intercepted"
+msgstr ""
+
+#: objc/objc-act.c:3781
+#, gcc-internal-format
+msgid "pointer arithmetic for garbage-collected objects not allowed"
+msgstr ""
+
+#: objc/objc-act.c:3787
+#, gcc-internal-format
+msgid "global/static variable assignment has been intercepted"
+msgstr ""
+
+#: objc/objc-act.c:4006 objc/objc-act.c:4034 objc/objc-act.c:4089
+#, gcc-internal-format
+msgid "duplicate instance variable %q+D"
+msgstr ""
+
+#: objc/objc-act.c:4149
+#, gcc-internal-format
+msgid "%<-fobjc-exceptions%> is required to enable Objective-C exception syntax"
+msgstr ""
+
+#: objc/objc-act.c:4233
+#, gcc-internal-format
+msgid "@catch parameter is not a known Objective-C class type"
+msgstr ""
+
+#: objc/objc-act.c:4239
+#, gcc-internal-format
+msgid "@catch parameter can not be protocol-qualified"
+msgstr ""
+
+#: objc/objc-act.c:4284
+#, gcc-internal-format
+msgid "exception of type %<%T%> will be caught"
+msgstr ""
+
+#: objc/objc-act.c:4286
+#, gcc-internal-format
+msgid "   by earlier handler for %<%T%>"
+msgstr ""
+
+#: objc/objc-act.c:4333
+#, gcc-internal-format
+msgid "%<@try%> without %<@catch%> or %<@finally%>"
+msgstr ""
+
+#: objc/objc-act.c:4361
+#, gcc-internal-format
+msgid "%<@throw%> (rethrow) used outside of a @catch block"
+msgstr ""
+
+#: objc/objc-act.c:4374
+#, gcc-internal-format
+msgid "%<@throw%> argument is not an object"
+msgstr ""
+
+#: objc/objc-act.c:4395
+#, gcc-internal-format
+msgid "%<@synchronized%> argument is not an object"
+msgstr ""
+
+#: objc/objc-act.c:4603
+#, gcc-internal-format
+msgid "%s %qs"
+msgstr ""
+
+#: objc/objc-act.c:4626 objc/objc-act.c:4645
+#, gcc-internal-format
+msgid "inconsistent instance variable specification"
+msgstr ""
+
+#: objc/objc-act.c:4700
+#, gcc-internal-format
+msgid "can not use an object as parameter to a method"
+msgstr ""
+
+#: objc/objc-act.c:4744
+#, gcc-internal-format
+msgid "method argument attributes are not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.c:5118
+#, gcc-internal-format
+msgid "multiple methods named %<%c%E%> found"
+msgstr ""
+
+#: objc/objc-act.c:5121
+#, gcc-internal-format
+msgid "using %<%c%s%>"
+msgstr "використовуємо %<%c%s%>"
+
+#: objc/objc-act.c:5130
+#, gcc-internal-format
+msgid "multiple selectors named %<%c%E%> found"
+msgstr ""
+
+#: objc/objc-act.c:5133
+#, gcc-internal-format
+msgid "found %<%c%s%>"
+msgstr "знайдено %<%c%s%>"
+
+#: objc/objc-act.c:5142
+#, gcc-internal-format
+msgid "also found %<%c%s%>"
+msgstr ""
+
+#. If 'rtype' is NULL_TREE at this point it means that
+#. we have seen no @interface corresponding to that
+#. class name, only a @class declaration (alternatively,
+#. this was a call such as [objc_getClass("SomeClass")
+#. alloc], where we've never seen the @interface of
+#. SomeClass).  So, we have a class name (class_tree)
+#. but no actual details of the class methods.  We won't
+#. be able to check that the class responds to the
+#. method, and we will have to guess the method
+#. prototype.  Emit a warning, then keep going (this
+#. will use any method with a matching name, as if the
+#. receiver was of type 'Class').
+#. We could not find an @interface declaration, and
+#. there are no protocols attached to the receiver,
+#. so we can't complete the check that the receiver
+#. responds to the method, and we can't retrieve the
+#. method prototype.  But, because the receiver has
+#. a well-specified class, the programmer did want
+#. this check to be performed.  Emit a warning, then
+#. keep going as if it was an 'id'.  To remove the
+#. warning, either include an @interface for the
+#. class, or cast the receiver to 'id'.  Note that
+#. rtype is an IDENTIFIER_NODE at this point.
+#: objc/objc-act.c:5428 objc/objc-act.c:5562
+#, gcc-internal-format
+msgid "@interface of class %qE not found"
+msgstr ""
+
+#: objc/objc-act.c:5436
+#, gcc-internal-format
+msgid "no super class declared in @interface for %qE"
+msgstr ""
+
+#: objc/objc-act.c:5487
+#, gcc-internal-format
+msgid "found %<-%E%> instead of %<+%E%> in protocol(s)"
+msgstr ""
+
+#. We have a type, but it's not an Objective-C type (!).
+#: objc/objc-act.c:5599
+#, gcc-internal-format
+msgid "invalid receiver type %qs"
+msgstr ""
+
+#: objc/objc-act.c:5616
+#, gcc-internal-format
+msgid "%<%c%E%> not found in protocol(s)"
+msgstr ""
+
+#: objc/objc-act.c:5630
+#, gcc-internal-format
+msgid "%qE may not respond to %<%c%E%>"
+msgstr ""
+
+#: objc/objc-act.c:5638
+#, gcc-internal-format
+msgid "no %<%c%E%> method found"
+msgstr ""
+
+#: objc/objc-act.c:5645
+#, gcc-internal-format
+msgid "(Messages without a matching method signature"
+msgstr ""
+
+#: objc/objc-act.c:5647
+#, gcc-internal-format
+msgid "will be assumed to return %<id%> and accept"
+msgstr ""
+
+#: objc/objc-act.c:5649
+#, gcc-internal-format
+msgid "%<...%> as arguments.)"
+msgstr ""
+
+#: objc/objc-act.c:5758
+#, gcc-internal-format
+msgid "undeclared selector %qE"
+msgstr ""
+
+#. Historically, a class method that produced objects (factory
+#. method) would assign `self' to the instance that it
+#. allocated.  This would effectively turn the class method into
+#. an instance method.  Following this assignment, the instance
+#. variables could be accessed.  That practice, while safe,
+#. violates the simple rule that a class method should not refer
+#. to an instance variable.  It's better to catch the cases
+#. where this is done unknowingly than to support the above
+#. paradigm.
+#: objc/objc-act.c:5782
+#, gcc-internal-format
+msgid "instance variable %qE accessed in class method"
+msgstr ""
+
+#: objc/objc-act.c:6012 objc/objc-act.c:6032
+#, gcc-internal-format
+msgid "method %<%c%E%> declared %<@optional%> and %<@required%> at the same time"
+msgstr ""
+
+#: objc/objc-act.c:6016
+#, gcc-internal-format
+msgid "previous declaration of %<%c%E%> as %<@required%>"
+msgstr ""
+
+#: objc/objc-act.c:6036
+#, gcc-internal-format
+msgid "previous declaration of %<%c%E%> as %<@optional%>"
+msgstr ""
+
+#: objc/objc-act.c:6096
+#, gcc-internal-format
+msgid "duplicate declaration of method %<%c%E%> with conflicting types"
+msgstr ""
+
+#: objc/objc-act.c:6100
+#, gcc-internal-format
+msgid "previous declaration of %<%c%E%>"
+msgstr ""
+
+#: objc/objc-act.c:6137
+#, gcc-internal-format
+msgid "duplicate interface declaration for category %<%E(%E)%>"
+msgstr ""
+
+#: objc/objc-act.c:6225
+#, gcc-internal-format
+msgid "illegal reference type specified for instance variable %qs"
+msgstr ""
+
+#: objc/objc-act.c:6236
+#, gcc-internal-format
+msgid "instance variable %qs has unknown size"
+msgstr ""
+
+#: objc/objc-act.c:6257
+#, gcc-internal-format
+msgid "instance variable %qs uses flexible array member"
+msgstr ""
+
+#: objc/objc-act.c:6284
+#, gcc-internal-format
+msgid "type %qE has no default constructor to call"
+msgstr ""
+
+#: objc/objc-act.c:6290
+#, gcc-internal-format
+msgid "destructor for %qE shall not be run either"
+msgstr ""
+
+#. Vtable pointers are Real Bad(tm), since Obj-C cannot
+#. initialize them.
+#: objc/objc-act.c:6302
+#, gcc-internal-format
+msgid "type %qE has virtual member functions"
+msgstr ""
+
+#: objc/objc-act.c:6303
+#, gcc-internal-format
+msgid "illegal aggregate type %qE specified for instance variable %qs"
+msgstr ""
+
+#: objc/objc-act.c:6313
+#, gcc-internal-format
+msgid "type %qE has a user-defined constructor"
+msgstr ""
+
+#: objc/objc-act.c:6315
+#, gcc-internal-format
+msgid "type %qE has a user-defined destructor"
+msgstr ""
+
+#: objc/objc-act.c:6319
+#, gcc-internal-format
+msgid "C++ constructors and destructors will not be invoked for Objective-C fields"
+msgstr ""
+
+#: objc/objc-act.c:6450
+#, gcc-internal-format
+msgid "instance variable %qE is declared private"
+msgstr ""
+
+#: objc/objc-act.c:6461
+#, gcc-internal-format
+msgid "instance variable %qE is %s; this will be a hard error in the future"
+msgstr ""
+
+#: objc/objc-act.c:6468
+#, gcc-internal-format
+msgid "instance variable %qE is declared %s"
+msgstr ""
+
+#: objc/objc-act.c:6579 objc/objc-act.c:6694
+#, gcc-internal-format
+msgid "incomplete implementation of class %qE"
+msgstr ""
+
+#: objc/objc-act.c:6583 objc/objc-act.c:6698
+#, gcc-internal-format
+msgid "incomplete implementation of category %qE"
+msgstr ""
+
+#: objc/objc-act.c:6592 objc/objc-act.c:6706
+#, gcc-internal-format
+msgid "method definition for %<%c%E%> not found"
+msgstr ""
+
+#: objc/objc-act.c:6747
+#, gcc-internal-format
+msgid "%s %qE does not fully implement the %qE protocol"
+msgstr ""
+
+#: objc/objc-act.c:6837
+#, gcc-internal-format
+msgid "cannot find interface declaration for %qE, superclass of %qE"
+msgstr ""
+
+#: objc/objc-act.c:6876
+#, gcc-internal-format
+msgid "reimplementation of class %qE"
+msgstr ""
+
+#: objc/objc-act.c:6909
+#, gcc-internal-format
+msgid "conflicting super class name %qE"
+msgstr ""
+
+#: objc/objc-act.c:6912
+#, gcc-internal-format
+msgid "previous declaration of %qE"
+msgstr ""
+
+#: objc/objc-act.c:6914
+#, gcc-internal-format
+msgid "previous declaration"
+msgstr "попереднє оголошення"
+
+#: objc/objc-act.c:6927 objc/objc-act.c:6929
+#, gcc-internal-format
+msgid "duplicate interface declaration for class %qE"
+msgstr ""
+
+#: objc/objc-act.c:7248 objc/objc-act.c:7444
+#, gcc-internal-format
+msgid "can not find instance variable associated with property"
+msgstr ""
+
+#. TODO: This should be caught much earlier than this.
+#: objc/objc-act.c:7410
+#, gcc-internal-format
+msgid "invalid setter, it must have one argument"
+msgstr ""
+
+#: objc/objc-act.c:7574 objc/objc-act.c:7789
+#, gcc-internal-format
+msgid "property %qs already specified in %<@dynamic%>"
+msgstr ""
+
+#: objc/objc-act.c:7577 objc/objc-act.c:7792
+#, gcc-internal-format
+msgid "property %qs already specified in %<@synthesize%>"
+msgstr ""
+
+#: objc/objc-act.c:7591 objc/objc-act.c:7806
+#, gcc-internal-format
+msgid "no declaration of property %qs found in the interface"
+msgstr ""
+
+#: objc/objc-act.c:7618
+#, gcc-internal-format
+msgid "ivar %qs used by %<@synthesize%> declaration must be an existing ivar"
+msgstr ""
+
+#: objc/objc-act.c:7639
+#, gcc-internal-format
+msgid "property %qs is using instance variable %qs of incompatible type"
+msgstr ""
+
+#: objc/objc-act.c:7661
+#, gcc-internal-format
+msgid "'assign' property %qs is using bit-field instance variable %qs"
+msgstr ""
+
+#: objc/objc-act.c:7674
+#, gcc-internal-format
+msgid "'atomic' property %qs is using bit-field instance variable %qs"
+msgstr ""
+
+#: objc/objc-act.c:7692
+#, gcc-internal-format
+msgid "property %qs is using the same instance variable as property %qs"
+msgstr ""
+
+#: objc/objc-act.c:7733
+#, gcc-internal-format
+msgid "%<@synthesize%> is not available in Objective-C 1.0"
+msgstr ""
+
+#. We can get here only in Objective-C; the Objective-C++ parser
+#. detects the problem while parsing, outputs the error
+#. "misplaced '@synthesize' Objective-C++ construct" and skips
+#. the declaration.
+#: objc/objc-act.c:7744
+#, gcc-internal-format
+msgid "%<@synthesize%> not in @implementation context"
+msgstr ""
+
+#: objc/objc-act.c:7750
+#, gcc-internal-format
+msgid "%<@synthesize%> can not be used in categories"
+msgstr ""
+
+#: objc/objc-act.c:7759
+#, gcc-internal-format
+msgid "%<@synthesize%> requires the @interface of the class to be available"
+msgstr ""
+
+#: objc/objc-act.c:7842
+#, gcc-internal-format
+msgid "%<@dynamic%> is not available in Objective-C 1.0"
+msgstr ""
+
+#. We can get here only in Objective-C; the Objective-C++ parser
+#. detects the problem while parsing, outputs the error
+#. "misplaced '@dynamic' Objective-C++ construct" and skips the
+#. declaration.
+#: objc/objc-act.c:7853
+#, gcc-internal-format
+msgid "%<@dynamic%> not in @implementation context"
+msgstr ""
+
+#: objc/objc-act.c:7875
+#, gcc-internal-format
+msgid "%<@dynamic%> requires the @interface of the class to be available"
+msgstr ""
+
+#: objc/objc-act.c:8073
+#, gcc-internal-format
+msgid "definition of protocol %qE not found"
+msgstr ""
+
+#. It would be nice to use warn_deprecated_use() here, but
+#. we are using TREE_CHAIN (which is supposed to be the
+#. TYPE_STUB_DECL for a TYPE) for something different.
+#: objc/objc-act.c:8104
+#, gcc-internal-format
+msgid "protocol %qE is deprecated"
+msgstr ""
+
+#: objc/objc-act.c:8223
+#, gcc-internal-format
+msgid "duplicate declaration for protocol %qE"
+msgstr ""
+
+#: objc/objc-act.c:8734
+#, gcc-internal-format
+msgid "conflicting types for %<%c%s%>"
+msgstr ""
+
+#: objc/objc-act.c:8738
+#, gcc-internal-format
+msgid "previous declaration of %<%c%s%>"
+msgstr ""
+
+#: objc/objc-act.c:8838
+#, gcc-internal-format
+msgid "no super class declared in interface for %qE"
+msgstr ""
+
+#: objc/objc-act.c:8865
+#, gcc-internal-format
+msgid "[super ...] must appear in a method context"
+msgstr ""
+
+#: objc/objc-act.c:8905
+#, gcc-internal-format
+msgid "method possibly missing a [super dealloc] call"
+msgstr ""
+
+#: objc/objc-act.c:9369
+#, gcc-internal-format
+msgid "instance variable %qs is declared private"
+msgstr ""
+
+#: objc/objc-act.c:9422
+#, gcc-internal-format
+msgid "local declaration of %qE hides instance variable"
+msgstr ""
+
+#. This can happen if DECL_ARTIFICIAL (*expr_p), but
+#. should be impossible for real properties, which always
+#. have a getter.
+#: objc/objc-act.c:9468
+#, gcc-internal-format
+msgid "no %qs getter found"
+msgstr ""
+
+#: objc/objc-act.c:9708
+#, gcc-internal-format
+msgid "fast enumeration is not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.c:9718
+#, gcc-internal-format
+msgid "iterating variable in fast enumeration is not an object"
+msgstr ""
+
+#: objc/objc-act.c:9724
+#, gcc-internal-format
+msgid "collection in fast enumeration is not an object"
+msgstr ""
+
+#: objc/objc-encoding.c:142
+#, gcc-internal-format
+msgid "type %qT does not have a known size"
+msgstr ""
+
+#: objc/objc-encoding.c:730
+#, gcc-internal-format
+msgid "unknown type %<%T%> found during Objective-C encoding"
+msgstr ""
+
+#. Do not do any encoding, produce an error and keep going.
+#: objc/objc-encoding.c:813
+#, gcc-internal-format
+msgid "trying to encode non-integer type as a bitfield"
+msgstr ""
+
+#: objc/objc-gnu-runtime-abi-01.c:143
+#, gcc-internal-format
+msgid "%<-fobjc-gc%> is ignored for %<-fgnu-runtime%>"
+msgstr ""
+
+#: objc/objc-gnu-runtime-abi-01.c:151
+#, gcc-internal-format
+msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
+msgstr ""
+
+#: objc/objc-gnu-runtime-abi-01.c:2178 objc/objc-next-runtime-abi-01.c:2828
+#: objc/objc-next-runtime-abi-02.c:3601
+#, gcc-internal-format
+msgid "non-objective-c type '%T' cannot be caught"
+msgstr ""
+
+#: objc/objc-next-runtime-abi-01.c:163
+#, gcc-internal-format
+msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> < 2"
+msgstr ""
+
+#: objc/objc-next-runtime-abi-02.c:256
+#, gcc-internal-format
+msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> >= 2"
+msgstr ""
+
+#: objc/objc-runtime-shared-support.c:437
+#, gcc-internal-format
+msgid "creating selector for nonexistent method %qE"
+msgstr ""
Index: gcc/po/sr.po
===================================================================
--- gcc/po/sr.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/sr.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.2.1\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2007-08-19 12:00+0200\n"
 "Last-Translator: Caslav Ilic <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <gnu@prevod.org>\n"
@@ -213,13 +213,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "лоша употреба реалне константе"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1494,7 +1494,7 @@
 msgid "options enabled: "
 msgstr "укључене опције: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2767,97 +2767,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "неисправан кôд операнда ‘%c;’"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "неисправна %%H вредност"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "неисправна %%J вредност"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "неисправна %%r вредност"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "неисправна %%R вредност"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "неисправна %%N вредност"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "неисправна %%P вредност"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "неисправна %%h вредност"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "неисправна %%L вредност"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "неисправна %%m вредност"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "неисправна %%M вредност"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "неисправна %%U вредност"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "неисправна %%s вредност"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "неисправна %%C вредност"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "неисправна %%E вредност"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "непознато unspec релокације"
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "неисправан %%xn кôд"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid operand address"
@@ -2910,7 +2910,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "неисправан кôд излаза операнада"
@@ -3078,8 +3078,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3301,70 +3301,70 @@
 msgid "bad output_condmove_single operand"
 msgstr "лош операнд output_condmove_single"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "неисправан УНСПЕЦ као операнд"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "неисправан кôд операнда ‘%c;’"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "неисправна ограничења за операнд"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "непознат режим ије"
 
@@ -3407,7 +3407,7 @@
 msgid "invalid %%P operand"
 msgstr "неисправан %%P операнд"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "неисправна %%p вредност"
@@ -3475,7 +3475,7 @@
 msgstr "адреса постувећања није регистар"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "лоша адреса"
 
@@ -3658,105 +3658,105 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "Створи кôд у режиму мале крајности"
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "лоша проба"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "неисправна %%f вредност"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "неисправна %%F вредност"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "неисправна %%G вредност"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "неисправан %%j кôд"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "неисправан %%J кôд"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "неисправна %%k вредност"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "неисправна %%K вредност"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "неисправна %%O вредност"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "неисправна %%q вредност"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "неисправна %%S вредност"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "неисправна %%T вредност"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "неисправна %%u вредност"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "неисправна %%v вредност"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "неисправна %%x вредност"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "неисправна интерпункција %qc у ограничењу"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Не стварај јединствену излазну тачку за сваку функцију"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load offset for fusion"
@@ -3861,60 +3861,60 @@
 msgid "invalid operand to %%S"
 msgstr "неисправан операнд за %%S"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr "направљено и употребљено на различитим архитектурама / АБИјима"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr "направљено и употребљено са различитим АБИјима"
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr "направљено и употребељно са различитом крајношћу"
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "неисправан %%Y операнд"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "неисправан %%A операнд"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "неисправан %%B операнд"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, c-format
 msgid "invalid %%C operand"
 msgstr "неисправан %%C операнд"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, c-format
 msgid "invalid %%D operand"
 msgstr "неисправан %%D операнд"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "неисправан %%f операнд"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "неисправан %%s операнд"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "long long константа није прихватљив непосредни операнд"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "реална константа није прихватљив непосредни операнд"
@@ -4139,7 +4139,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "очекивано је %<;%>"
@@ -4155,15 +4155,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "очекивано је %<(%>"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -4186,8 +4186,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -4195,8 +4195,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -4208,14 +4208,14 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "очекивано је %<{%>"
@@ -4222,8 +4222,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
@@ -4247,7 +4247,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -4267,20 +4267,20 @@
 msgid "expected %<.%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -4287,17 +4287,17 @@
 msgstr "очекивано је %<,%> или %<;%>"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "очекивано је %<=%>"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "очекивано је %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -4309,11 +4309,11 @@
 msgid "(anonymous)"
 msgstr "<анонимно>"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
@@ -4571,11 +4571,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "кандидати су:"
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -4639,50 +4639,50 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "погрешан тип аргумента уз унарно минус"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "погрешан тип аргумента уз унарно плус"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "погрешан тип аргумента уз битски комплемент"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "погрешан тип аргумента за abs"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "погрешан тип аргумента за конјугацију"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "погрешан тип аргумента уз унарно плус"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4782,7 +4782,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "Превелика целобројна вредност у изразу код %C"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 #, fuzzy
 #| msgid "Array assignment"
 msgid "array assignment"
@@ -4807,7 +4807,7 @@
 msgid "Driving:"
 msgstr "Погон:"
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 #, fuzzy
 #| msgid "Actual argument at %L must be definable to match dummy INTENT = OUT/INOUT"
 msgid "actual argument to INTENT = OUT/INOUT"
@@ -4887,13 +4887,13 @@
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4971,7 +4971,7 @@
 msgid "Bad type in constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 msgid "Unexpected end of module"
 msgstr "Неочекиван крај модула"
 
@@ -4999,11 +4999,11 @@
 msgid "implied END DO"
 msgstr "имплицитно END DO"
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr "додела"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 msgid "pointer assignment"
 msgstr "додела показивача"
 
@@ -5021,235 +5021,235 @@
 msgid "internal function"
 msgstr "функција враћа функцију"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 #, fuzzy
 #| msgid "elemental subroutine"
 msgid "elemental procedure"
 msgstr "елементални потпрограм"
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "додела показивача"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-shape argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "parametrized derived type argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 #, fuzzy
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "result with non-constant character length"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, fuzzy, c-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr "Операнд унарног бројевног оператора ‘%s’ код %%L је %s"
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr "Операнди бинарног бројевног оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Операнди оператора надовезивања ниски код %%L су %s/%s"
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr "Операнди логичког оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, fuzzy, c-format
 #| msgid "Operand of .NOT. operator at %%L is %s"
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Операнд оператора .NOT. код %%L је %s"
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Комплексне величине се не могу поредити код %L"
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Логичке код %%L морају бити поређене са %s уместо %s"
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr "Операнди оператора поређења ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, fuzzy, c-format
 #| msgid "unknown operator '%s' in %%:version-compare"
 msgid "Unknown operator '%s' at %%L"
 msgstr "непознате оператор ‘%s’ у %%:version-compare"
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr "Операнд корисничког оператора ‘%s’ код %%L је %s"
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr "Операнди корисничког оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, fuzzy, c-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Изврши праћење променљивих"
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "неисправан израз као операнд"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE "
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALLOCATE "
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5680,16 +5680,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr ""
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr ""
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr ""
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr "не подржава вишебиб"
@@ -5702,6 +5692,12 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "-Xbind-now и -Xbind-lazy нису сагласни"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+#, fuzzy
+#| msgid "profiling not supported with -mg\n"
+msgid "profiling not supported with -mg"
+msgstr "профилисање није подржано уз -mg\n"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "-mhard-float није подржано"
@@ -5710,10 +5706,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "не могу се задати и -msingle-float и -msoft-float"
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr "М210 нема подршку мале крајности"
-
 #: config/cris/cris.h:184
 #, fuzzy
 #| msgid "cannot specify both -C and -o"
@@ -5748,6 +5740,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr ""
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5754,6 +5752,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr "не могу се навести и -m32 и -m64"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr ""
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr "static није подржано на ТПФ-ОСу"
@@ -5768,6 +5770,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian и -mlittle-endian не могу се користити заједно"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr "М210 нема подршку мале крајности"
+
 #: config/avr/specs.h:68
 #, fuzzy
 #| msgid "-mhard-float not supported"
@@ -5799,17 +5805,19 @@
 msgid "no processor type specified for linking"
 msgstr "датотека навода нема навод за повезивање"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr ""
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr ""
 
@@ -5845,12 +5853,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "опција -shared тренутно није подржана за ВАКСов ЕЛФ"
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-#, fuzzy
-#| msgid "profiling not supported with -mg\n"
-msgid "profiling not supported with -mg"
-msgstr "профилисање није подржано уз -mg\n"
-
 #: fortran/lang.opt:146
 #, fuzzy
 #| msgid "Put MODULE files in 'directory'"
@@ -6058,9 +6060,9 @@
 msgstr "Дозволи долар у именима ентитета"
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Does nothing. Preserved for backward compatibility."
@@ -6291,10 +6293,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Не ради ништа. Остављено ради сагласности уназад."
 
@@ -6346,7 +6348,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr "недостаје име датотеке после %qs"
@@ -8423,50 +8425,54 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr "Претпостави да је циљни ЦПУ постављен на малу крајност"
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 #, fuzzy
 #| msgid "Specify the register allocation order"
 msgid "Specify the code model"
 msgstr "Одредите редослед резервисања регистара"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr "Изостави показивач оквира у функцијама-листовима"
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr "Користи могућности и распоређуј кôд за дати ЦПУ"
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 #, fuzzy
 #| msgid "Generate code that conforms to the given ABI"
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr "Створи кôд који поштује дати АБИ"
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -9679,11 +9685,17 @@
 
 #: config/i386/i386.opt:864
 #, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "Подржи уграђене ММИкс и ССЕ функције и стварање кôда"
+
+#: config/i386/i386.opt:868
+#, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use given stack-protector guard"
 msgstr "Користи propolice као метод заштите стека"
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr ""
 
@@ -10075,7 +10087,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -10230,7 +10242,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
@@ -10367,7 +10379,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr "Дозволи распоређивање пролошког редоследа функције"
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr "Не учитавај ПИЦ регистре у пролозима функција"
 
@@ -10718,371 +10730,369 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "Користи медија-инструкције"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr "Не стварај инструкције учитавања/складиштења са ажурирањем"
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr "Стварај инструкције учитавања/складиштења са ажурирањем"
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 #, fuzzy
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "%<__builtin_next_arg%> позвано без аргумената"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr "Распоређуј почетак и крај процедуре"
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr "Враћај све структуре у меморији (подразумевано за Аикс)"
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr "Враћај мале структуре у регистрима (подразумевано за СВР4)"
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr "Поштуј ближе семантику ИБМовог ИксЛЦа"
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 #, fuzzy
 #| msgid "Generate software floating point divide for better throughput"
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr "Стварај софтверско дељење у покретном зарезу ради боље пропусности"
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr "Не стављај константе покретног зареза у ТОЦ"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr "Стављај константе покретног зареза у ТОЦ"
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "Не стављај константе симбола+помака у ТОЦ"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr "Стављај константе симбола+помака у ТОЦ"
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr "Користи само један ТОЦ по процедури"
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr "Стави све у регуларан ТОЦ"
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr "Стварај инструкције VRSAVE при састављању алтивек кода"
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 #, fuzzy
 #| msgid "Deprecated option.  Use -mvrsave/-mno-vrsave instead"
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr "Превазиђена опција; користите -mvrsave и -mno-vrsave"
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 #, fuzzy
 #| msgid "Deprecated option.  Use -mvrsave/-mno-vrsave instead"
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr "Превазиђена опција; користите -mvrsave и -mno-vrsave"
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 msgid "Generate isel instructions"
 msgstr "Стварај инструкције isel"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 #, fuzzy
 #| msgid "Deprecated option.  Use -misel/-mno-isel instead"
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr "Превазиђена опција; користите -misel и -mno-isel"
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 #, fuzzy
 #| msgid "Deprecated option.  Use -misel/-mno-isel instead"
 msgid "Deprecated option.  Use -misel instead"
 msgstr "Превазиђена опција; користите -misel и -mno-isel"
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr "Стварај СПЕ СИМД инструкције на Е500"
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "Стварај инструкције isel"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 #, fuzzy
 #| msgid "Deprecated option.  Use -mspe/-mno-spe instead"
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr "Превазиђена опција; користите -mspe и -mno-spe"
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 #, fuzzy
 #| msgid "Deprecated option.  Use -mspe/-mno-spe instead"
 msgid "Deprecated option.  Use -mspe instead"
 msgstr "Превазиђена опција; користите -mspe и -mno-spe"
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "-mdebug=\tEnable debug output"
 msgstr "Укључи исправљачки излаз"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 #, fuzzy
 #| msgid "Use the Cray Pointer extension"
 msgid "Use the AltiVec ABI extensions"
 msgstr "Користи проширење Крејовог показивача"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 #, fuzzy
 #| msgid "Do not use the bit-field instructions"
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "Не користи инструкције битског нивоа"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 #, fuzzy
 #| msgid "Use the Cray Pointer extension"
 msgid "Use the SPE ABI extensions"
 msgstr "Користи проширење Крејовог показивача"
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 #, fuzzy
 #| msgid "Do not use the bit-field instructions"
 msgid "Do not use the SPE ABI extensions"
 msgstr "Не користи инструкције битског нивоа"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv1 ABI"
 msgstr "Користи ЕАБИ"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv2 ABI"
 msgstr "Користи ЕАБИ"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 #, fuzzy
 #| msgid "Using darwin64 ABI"
 msgid "using darwin64 ABI"
 msgstr "Користим АБИ Дарвина64"
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 #, fuzzy
 #| msgid "Using old darwin ABI"
 msgid "using old darwin ABI"
 msgstr "Користим стари АБИ Дарвина"
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 #, fuzzy
 #| msgid "Using IEEE extended precision long double"
 msgid "using IEEE extended precision long double"
 msgstr "Користим ИЕЕЕ дугачки двоструки проширене тачности"
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 #, fuzzy
 #| msgid "Using IBM extended precision long double"
 msgid "using IBM extended precision long double"
 msgstr "Користим ИБМов дугачки двоструки проширене тачности"
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr "Користи могућности и распоређуј кôд за дати ЦПУ"
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 #, fuzzy
 #| msgid "Schedule code for given CPU"
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "Распореди кôд за дати ЦПУ"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 #, fuzzy
 #| msgid "Select full, part, or no traceback table"
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr "Изаберите пуну или делимичну табелу повратног трага, или без ње"
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr "Избегавај сва ограничења опсега при позивним инструкцијама"
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 #, fuzzy
 #| msgid "Generate SH2e code"
 msgid "Generate Cell microcode"
 msgstr "Створи кôд за СХ2е"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 #, fuzzy
 #| msgid "Warn when all constructors and destructors are private"
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "Упозори када су сви конструктори и деструктори приватни"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr "Упозори на превазиђену употребу алтивек типа ‘vector long ...’"
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 #, fuzzy
 #| msgid "Select GPR floating point method"
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr "Изаберите метод покретног зареза за ГПР"
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 #, fuzzy
 #| msgid "invalid option for -mfloat-gprs: '%s'"
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "неисправна опција за -mfloat-gprs: „%s“"
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 #, fuzzy
 #| msgid "Specify size of long double (64 or 128 bits)"
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr "Наведите величину за ‘long double’ (64 или 128 битова)"
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr "Одредите које зависности између ија се сматрају скупим"
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr "Наведите коју шему пост-распоређивања за уметање НОПа треба применити"
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr "Наведите равнање поља структуре, подразумевано/природно"
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 #, fuzzy
 #| msgid "alias argument not a string"
 msgid "Valid arguments to -malign-:"
 msgstr "аргумент алијаса није ниска"
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr "Наведите приоритет распоређивања за ије ограничене жлебом одашиљања"
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 #, fuzzy
 #| msgid "unordered comparison on non-floating point argument"
 msgid "Single-precision floating point unit"
 msgstr "неуређено поређење са не-реалним аргументом"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 #, fuzzy
 #| msgid "unordered comparison on non-floating point argument"
 msgid "Double-precision floating point unit"
 msgstr "неуређено поређење са не-реалним аргументом"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 #, fuzzy
 #| msgid "decimal floating point not supported for this target"
 msgid "Floating point unit does not support divide & sqrt"
 msgstr "децимални покретни зарез није подржан за овај циљ"
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 #, fuzzy
 #| msgid "Specify an ABI"
 msgid "Specify Xilinx FPU."
 msgstr "Наведите АБИ"
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 #, fuzzy
 #| msgid "Align destination of the string operations"
 msgid "Allow sign extension in fusion operations"
 msgstr "Поравнај одредиште операција над нискама"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
-#, fuzzy
-#| msgid "Use AltiVec instructions"
-msgid "Use ISA 2.07 crypto instructions"
-msgstr "Користи алтивек инструкције"
+#: config/rs6000/rs6000.opt:566
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr ""
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Стварај инструкције вишеструког учитавања/складиштења"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -14315,1742 +14325,1742 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr "Постави основно име датотека за пописе"
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "Поравнај почетке функција"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr "Поравнај етикете које се достижу једино скакањем"
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr "Поравнај све етикете"
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "Поравнај почетке петљи"
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr ""
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr "Овај прекидач је превазиђен; користите -Wextra"
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr "Стварај табеле одмотавања које су тачне на свакој граници инструкција"
 
-#: common.opt:918
+#: common.opt:921
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate auto-inc/dec instructions"
 msgstr "Стварај инструкције isel"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr "Користи профилишуће информације за вероватноће гранања"
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "Стварај кôд за проверу граница пре индексирања низова"
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr "Замени додавање-упоређивање-гранање регистром за гранање-на-збир"
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr "Користи профилишуће информације за вероватноће гранања"
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr "Оптимизуј учитавање циља гранања пре плетења пролога или епилога"
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr "Оптимизуј учитавање циља гранања после плетења пролога или епилога"
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr "Спречи миграцију учитавања циља да користи исте регистре у било којем основном блоку"
 
-#: common.opt:960
+#: common.opt:963
 #, fuzzy
 #| msgid "Mark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr "Означи да се <register> очувава преко функција"
 
-#: common.opt:964
+#: common.opt:967
 #, fuzzy
 #| msgid "Mark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr "Означи да се <register> квари позивима функција"
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr "Сачувавај регистре око позива функција"
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr ""
 
-#: common.opt:979
+#: common.opt:982
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++"
 msgstr "Провери повратни тип за new"
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr "Не стављај неуспостављене глобалне у заједнички одељак"
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr ""
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr ""
 
-#: common.opt:1003
+#: common.opt:1006
 #, fuzzy
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr "Елиминиши глобалне заједничке подизразе после резервисања регистара"
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr ""
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr "Изврши оптимизацију за распростирање копирања преко регистара"
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr "Изврши оптимизацију за укрштање скокова"
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr "При извршавању ЦСЕа прати скокове до њихових циљева"
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr "Изостави корак свођења опсега при комплексним дељењима"
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr ""
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr "Стављај податке у њихов сопствени одељак"
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr ""
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr ""
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr "Одложи за касније подизање аргумената са стека"
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr "Покушај да испуниш жлебове застоја за инструкције гранања"
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr "Обриши бескорисне провере нултог показивача"
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization"
 msgstr "Формирај суперблокове преко умножавања репа"
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1085
+#: common.opt:1088
 #, fuzzy
 #| msgid "How often to emit source location at the beginning of line-wrapped diagnostics"
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr "Колико често емитовати локацију у извору на почетку дијагностике преломљене у више линија"
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr "Допуни одговарајуће дијагностичке поруке опцијом командне линије које их контролишу"
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1145
 #, fuzzy
 #| msgid "Dump various compiler internals to a file"
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr "Попиши разне унутрашње ствари компилатора у датотеку"
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr ""
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr ""
 
-#: common.opt:1157
+#: common.opt:1160
 msgid "Suppress output of addresses in debugging dumps"
 msgstr "Сузбиј испис адреса у исправљачким пописима"
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 #, fuzzy
 #| msgid "Do the full register move optimization pass"
 msgid "Dump optimization passes"
 msgstr "Изврши потпуни пролаз оптимизације померањем регистара"
 
-#: common.opt:1170
+#: common.opt:1173
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr "Сузбиј испис бројева инструкција, бројева линија и адреса у исправљачким пописима"
 
-#: common.opt:1174
+#: common.opt:1177
 #, fuzzy
 #| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr "Сузбиј испис адреса у исправљачким пописима"
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr "Изврши рано уткивање"
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr "Изврши елиминацију дупликата ДВАРФ 2"
 
-#: common.opt:1190
+#: common.opt:1193
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural reduction of aggregates"
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1194
+#: common.opt:1197
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info"
 msgstr "Елиминиши неупотребље типове у исправљачким информацијама"
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr "Елиминиши неупотребље типове у исправљачким информацијама"
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr "Не сузбијај исправљачке податке Ц++ класа."
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "Укључи руковање изузецима"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr "Изврши и неке мање, а скупе оптимизације"
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr ""
 
-#: common.opt:1217
+#: common.opt:1220
 #, fuzzy, c-format
 #| msgid "unknown demangling style '%s'"
 msgid "unknown excess precision style %qs"
 msgstr "непознат стил распетљавања „%s“"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr "Претпостави да се не стварају ни НаНи ни бесконачности"
 
-#: common.opt:1238
+#: common.opt:1241
 #, fuzzy
 #| msgid "Mark <register> as being unavailable to the compiler"
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr "Означи да <register> није доступан компилатору"
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr "Не резервиши једноструке и двоструке у регистрима проширене тачности"
 
-#: common.opt:1250
+#: common.opt:1253
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform a forward propagation pass on RTL"
 msgstr "Изврши распростирање опсега вредности на стаблима"
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, fuzzy, c-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "unknown floating point contraction style %qs"
 msgstr "аргумент који није у покретном зарезу за функцију %qs"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr "Дозволи држање адреса функција у регистрима"
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr "Стави сваку функцију у њен сопствени одељак"
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr "Елиминиши глобалне заједничке подизразе"
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr "Изврши побољшано кретање учитавања током елиминације глобалних заједничких подизраза"
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr "Изврши кретање складиштења током елиминације глобалних заједничких подизраза"
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr "Елиминиши непотребно учитавање после складиштења у глобалном заједничком подизразу"
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr "Елиминиши глобалне заједничке подизразе после резервисања регистара"
 
-#: common.opt:1305
+#: common.opt:1308
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Enable in and out of Graphite representation"
 msgstr "Укључи елиминацију мртвих складиштења"
 
-#: common.opt:1309
+#: common.opt:1312
 #, fuzzy
 #| msgid "Emit call graph information"
 msgid "Enable Graphite Identity transformation"
 msgstr "Емитуј информације за граф позива"
 
-#: common.opt:1313
+#: common.opt:1316
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr ""
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr ""
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr ""
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr ""
 
-#: common.opt:1330
+#: common.opt:1333
 #, fuzzy
 #| msgid "Enable range checking during compilation"
 msgid "Enable Loop Blocking transformation"
 msgstr "Укључи проверу опсега током компилације"
 
-#: common.opt:1334
+#: common.opt:1337
 msgid "Enable Loop Unroll Jam transformation"
 msgstr ""
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr "Укључи погађање вероватноћа гранања"
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr "Обради директиве #ident"
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr "Претвори условне скокове у безгране еквиваленте"
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr "Претвори условне скокове у условно извршавање"
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Stack Reuse Level %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:1394
+#: common.opt:1397
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr "Претвори условне скокове у безгране еквиваленте"
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr ""
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr "Не стварај директиве .size"
 
-#: common.opt:1410
+#: common.opt:1413
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform indirect inlining"
 msgstr "Изврши рано уткивање"
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 #, fuzzy
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "Интегриши једноставне функције у њихове позиваче"
 
-#: common.opt:1424
+#: common.opt:1427
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "Интегриши функције једном позване у њихове позиваче"
 
-#: common.opt:1428
+#: common.opt:1431
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions only required by their single caller"
 msgstr "Интегриши функције једном позване у њихове позиваче"
 
-#: common.opt:1435
+#: common.opt:1438
 #, fuzzy
 #| msgid "Limit the size of inlined functions to <number>"
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr "Ограничи број утканих функција на <number>"
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr "Опреми улаз и излаз функција профилишућим позивима"
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1458
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation"
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1459
+#: common.opt:1462
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1463
+#: common.opt:1466
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1467
+#: common.opt:1470
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural profile propagation"
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr "Изврши међупроцедуралну анализу показује-на"
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr "Откривај чисте и константне функције"
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables"
 msgstr "Одмотај све петље"
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr "Откривај статичке променљиве које су само за читање и не могу се адресирати"
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr ""
 
-#: common.opt:1506
+#: common.opt:1509
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown IRA algorithm %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr ""
 
-#: common.opt:1519
+#: common.opt:1522
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA region %qs"
 msgstr "непознато име регистра: %s"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr "Оптимизуј индукционе променљиве на стаблима"
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "Користи табеле скокова за довољно велике наредбе прекидача"
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr "Стварај кôд за функције чак и ако су потпуно уткане"
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr "Емитуј статичке константне променљиве чак и ако се не користе"
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr "Додај спољашњим симболима водећу подвлаку"
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable link-time optimization."
 msgstr "Укључи оптимизације повезивача"
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr ""
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Report various link-time optimization statistics"
 msgstr "Изврши пролаз оптимизације преименовањем регистара"
 
-#: common.opt:1625
+#: common.opt:1628
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr "Постави errno после уграђених математичких фја"
 
-#: common.opt:1633
+#: common.opt:1636
 #, fuzzy
 #| msgid "Maximum number of errors to report"
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr "Највећи број грешака за пријављивање"
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr "Извештавај о трајном резервисању меморије"
 
-#: common.opt:1641
+#: common.opt:1644
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only"
 msgstr "Извештавај о трајном резервисању меморије"
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr "Покушај да стопиш истоветне константе и константне променљиве"
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr "Покушај да стопиш истоветне константе преко компилационих јединица"
 
-#: common.opt:1656
+#: common.opt:1659
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr "Покушај да стопиш истоветне константе преко компилационих јединица"
 
-#: common.opt:1660
+#: common.opt:1663
 #, fuzzy
 #| msgid "Limit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr "Ограничи дијагностику на <number> знакова по линији.  0 сузбија преламање линија"
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr "Изврши окретно модуло-распоређивање на основу СМСа пре првог распоређивачког пролаза"
 
-#: common.opt:1668
+#: common.opt:1671
 #, fuzzy
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr "Изврши окретно модуло-распоређивање на основу СМСа пре првог распоређивачког пролаза"
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr "Премести инваријантна рачунања изван петљи"
 
-#: common.opt:1676
+#: common.opt:1679
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Use the RTL dead code elimination pass"
 msgstr "Укључи елиминацију мртвих складиштења"
 
-#: common.opt:1680
+#: common.opt:1683
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Use the RTL dead store elimination pass"
 msgstr "Укључи елиминацију мртвих складиштења"
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr "Укључи/искључи традиционално распоређивање у петљама које су већ прошле кроз модуло-распоређивање"
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr "Подржи синхроне непозивне изузетке"
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "недостаје тврдња после %qs"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 #| msgid "unknown tls-model \"%s\""
 msgid "unknown offload ABI %qs"
 msgstr "непознат ТЛС модел „%s“"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr "Када је могуће не стварај оквире стека"
 
-#: common.opt:1713
+#: common.opt:1716
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable all optimization info dumps on stderr"
 msgstr "Укључи оптимизације петљи на нивоу стабла"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr "Оптимизуј сродничке и репно рекурзивне позиве"
 
-#: common.opt:1729
+#: common.opt:1732
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform partial inlining"
 msgstr "Изврши рано уткивање"
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr ""
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr "Пакуј чланове структура заједно без рупа"
 
-#: common.opt:1745
+#: common.opt:1748
 #, fuzzy
 #| msgid "Set initial maximum structure member alignment"
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr "Постави почетно највеће равнање чланова структуре"
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr "Враћај мале скупине у меморији, не у регистрима"
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr "Изврши љушћење петљи"
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr "Укључи машински-зависне окнасте оптимизације"
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr "Укључи окнасти РТЛ пролаз пре sched2"
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr "Стварај положајно-независни кôд ако је могуће (велики режим)"
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr "Стварај положајно-независни кôд за извршне ако је могуће (велики режим)"
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr "Стварај положајно-независни кôд ако је могуће (мали режим)"
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr "Стварај положајно-независни кôд за извршне ако је могуће (мали режим)"
 
-#: common.opt:1781
+#: common.opt:1784
 #, fuzzy
 #| msgid "Specify options to GNAT"
 msgid "Specify a plugin to load"
 msgstr "Наведите опције ГНАТу"
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr ""
 
-#: common.opt:1789
+#: common.opt:1792
 #, fuzzy
 #| msgid "Enables a register move optimization"
 msgid "Run predictive commoning optimization."
 msgstr "Укључи оптимизацију померањем регистара"
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr "Стварај инструкције предохватања, ако су доступне, за низове у петљама"
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr "Укључи основни кôд за профилисање програма"
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr "Убаци кôд за профилисање програма на основу лукова"
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr "Укључи уобичајене опције за стварање профилних информација, ради оптимизација на основу одзива профилисања"
 
-#: common.opt:1818
+#: common.opt:1821
 #, fuzzy
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Укључи уобичајене опције за стварање профилних информација, ради оптимизација на основу одзива профилисања"
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr "Укључи уобичајене опције за оптимизације на основу одзива профилисања"
 
-#: common.opt:1826
+#: common.opt:1829
 #, fuzzy
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Укључи уобичајене опције за оптимизације на основу одзива профилисања"
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr "Умећи кôд за профилисање вредности израза"
 
-#: common.opt:1834
+#: common.opt:1837
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Report on consistency of profile"
 msgstr "неуспех услед унутрашње неусаглашености"
 
-#: common.opt:1838
+#: common.opt:1841
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement"
 msgstr "Прераспореди функције ради побољшања постављења кôда"
 
-#: common.opt:1845
+#: common.opt:1848
 #, fuzzy
 #| msgid "Make compile reproducible using <string>"
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr "Учини компилацију поновљивом користећи <string>"
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr "Враћај мале скупине у регистрима"
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr ""
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr "Изврши пролаз оптимизације преименовањем регистара"
 
-#: common.opt:1880
+#: common.opt:1883
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr "Изврши пролаз оптимизације преименовањем регистара"
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr "Прераспореди основне блокове ради побољшања постављења кôда"
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr "Прераспореди основне блокове и подели на вруће и хладне одељке"
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr "Прераспореди функције ради побољшања постављења кôда"
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr "Додај пролаз елиминације заједничких подизраза после оптимизација петље"
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr "Искључи оптимизације које претпостављају подразумевано понашање ФП заокруживања"
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr "Укључи распоређивање преко основних блокова"
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr "Дозволи спекулативно кретање не-учитавања"
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr "Дозволи спекулативно кретање неких учитавања"
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr "Дозволи спекулативно кретање више учитавања"
 
-#: common.opt:1928
+#: common.opt:1931
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr "Постави ниво опширности распоређивача"
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr "Ако се распоређује после поновљеног учитавања, изврши суперблоковско распоређивање"
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr "Прераспореди инструкције пре резервисања регистара"
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr "Прераспореди инструкције после резервисања регистара"
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr ""
 
-#: common.opt:1955
+#: common.opt:1958
 #, fuzzy
 #| msgid "Use data speculation after reload"
 msgid "Run selective scheduling after reload"
 msgstr "Користи спекулацију података после поновног учитавања"
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr ""
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr "Дозволи прерано распоређивање ија у реду"
 
-#: common.opt:1981
+#: common.opt:1984
 #, fuzzy
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr "Број ија у реду које се могу прерано распоређивати"
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr "Провера растојања зависности у прераном распоређивању ија у реду"
 
-#: common.opt:1993
+#: common.opt:1996
 #, fuzzy
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr "Провера растојања зависности у прераном распоређивању ија у реду"
 
-#: common.opt:1997
+#: common.opt:2000
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the group heuristic in the scheduler"
 msgstr "Постави ниво опширности распоређивача"
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2009
+#: common.opt:2012
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the rank heuristic in the scheduler"
 msgstr "Постави ниво опширности распоређивача"
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr "Приступај подацима у истом одељку из дељених сидришних тачака"
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr "Приказуј бројеве колона у дијагностици, ако су доступни.  Подразумевано укључено."
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr "Искључи оптимизације приметне при ИЕЕЕ издавању НаНа"
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr ""
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr "Претвори константе у покретном зарезу у једноструку прецизност"
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr "Подели времена живота индукционих променљивих када се петље одмотавају"
 
-#: common.opt:2062
+#: common.opt:2065
 #, fuzzy
 #| msgid "Generate APCS conformant stack frames"
 msgid "Generate discontiguous stack frames"
 msgstr "Стварај оквире стека сагласне са АПЦСом"
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr ""
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr ""
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr "Примени ширење променљивих када се петље одмотавају"
 
-#: common.opt:2082
+#: common.opt:2085
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "Уметни кôд за проверу стека у програм"
 
-#: common.opt:2086
+#: common.opt:2089
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "Уметни кôд за проверу стека у програм"
 
-#: common.opt:2093
+#: common.opt:2096
 #, fuzzy
 #| msgid "Trap if the stack goes past <register>"
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr "Хватај ако стек прође поред <register>"
 
-#: common.opt:2097
+#: common.opt:2100
 #, fuzzy
 #| msgid "Trap if the stack goes past symbol <name>"
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr "Хватај ако стек прође поред симбола <name>"
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr "Користи propolice као метод заштите стека"
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr "Користи метод заштите стека за сваку функцију"
 
-#: common.opt:2109
+#: common.opt:2112
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions"
 msgstr "Користи метод заштите стека за сваку функцију"
 
-#: common.opt:2113
+#: common.opt:2116
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr "Користи метод заштите стека за сваку функцију"
 
-#: common.opt:2117
+#: common.opt:2120
 #, fuzzy
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output stack usage information on a per-function basis"
 msgstr "Поново користи r30 од функције до функције"
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr "Претпостави правила строге дволичности"
 
-#: common.opt:2133
+#: common.opt:2136
 msgid "Treat signed overflow as undefined"
 msgstr "Сматрај означено преливање за недефинисано"
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr "Провери синтаксне грешке, па стани"
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr "Створи датотеке потребне за „gcov“"
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr "Изврши оптимизације плетења скокова"
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr "Извести о времену потрошеном у сваком компилаторском пролазу"
 
-#: common.opt:2157
+#: common.opt:2160
 #, fuzzy
 #| msgid "Set the default thread-local storage code generation model"
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr "Подразумевани модел стварања кôда за нитно-локално складиштење"
 
-#: common.opt:2160
+#: common.opt:2163
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown TLS model %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr "Преуреди редослед функција, променљива и асмова највишег нивоа"
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr "Формирај суперблокове преко умножавања репа"
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr "Претпостави да операције у покретном зарезу могу да хватају"
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr "Хватај преливање означених при додавању, одузимању и множењу"
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr "Укључи ССА-ЦЦП оптимизацију над стаблима"
 
-#: common.opt:2199
+#: common.opt:2202
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr "Укључи ССА-ЦЦП оптимизацију над стаблима"
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr "Укључи копирање заглавља петље на стаблима"
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr ""
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr "Смени ССА привремене бољим именима у копијама"
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr "Укључи распростирање копирања на стаблима"
 
-#: common.opt:2231
+#: common.opt:2234
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Transform condition stores into unconditional ones"
 msgstr "Претвори условне скокове у условно извршавање"
 
-#: common.opt:2235
+#: common.opt:2238
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversions of switch initializations."
 msgstr "Претвори условне скокове у условно извршавање"
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr "Укључи ССА оптимизацију елиминације мртвог кôда на стаблима"
 
-#: common.opt:2243
+#: common.opt:2246
 msgid "Enable dominator optimizations"
 msgstr "Укључи доминаторске оптимизације"
 
-#: common.opt:2247
+#: common.opt:2250
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable tail merging on trees"
 msgstr "Укључи копирање заглавља петље на стаблима"
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr "Укључи елиминацију мртвих складиштења"
 
-#: common.opt:2255
+#: common.opt:2258
 #, fuzzy
 #| msgid "Enable copy propagation on trees"
 msgid "Enable forward propagation on trees"
 msgstr "Укључи распростирање копирања на стаблима"
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr "Укључи пуну елиминацију сувишности (ФРЕ) на стаблима"
 
-#: common.opt:2263
+#: common.opt:2266
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable string length optimizations on trees"
 msgstr "Укључи ССА-ЦЦП оптимизацију над стаблима"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop distribution on trees"
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr ""
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr "Укључи кретање инваријанти петље на стаблима"
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr ""
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr "Стварај каноничке индукционе променљиве у петљама"
 
-#: common.opt:2300
+#: common.opt:2303
 msgid "Enable loop optimizations on tree level"
 msgstr "Укључи оптимизације петљи на нивоу стабла"
 
-#: common.opt:2304
+#: common.opt:2307
 #, fuzzy
 #| msgid "Enable automatic template instantiation"
 msgid "Enable automatic parallelization of loops"
 msgstr "Укључи аутоматско извођење шаблона"
 
-#: common.opt:2308
+#: common.opt:2311
 #, fuzzy
 #| msgid "Enable conditional moves"
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Укључи условна померања"
 
-#: common.opt:2312
+#: common.opt:2315
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "Укључи ССА-ПРЕ оптимизацију на стаблима"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 #, fuzzy
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Изврши међупроцедуралну анализу показује-на"
 
-#: common.opt:2324
+#: common.opt:2327
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable reassociation on tree level"
 msgstr "Укључи оптимизације петљи на нивоу стабла"
 
-#: common.opt:2332
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
 msgstr "Укључи ССА потапање кôда на стаблима"
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr ""
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr "Изврши скаларну замену скупина"
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr "Замени привремене изразе у пролазу ССА->нормално"
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr "Изврши поделу опсега уживо током пролаза ССА->нормално"
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr "Изврши распростирање опсега вредности на стаблима"
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr "Компилуј целу компилациону јединицу у једном тренутку"
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr "Одмотај петљу када се зна број итерација"
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr "Одмотај све петље"
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr "Дозволи да оптимизације петље претпоставе да се петље нормално понашају"
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr "Дозволи математичке оптимизације које могу прекршити ИЕЕЕ или ИСО стандарде"
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr "Изврши одусловљавање петљи"
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr "Само створи табеле одмотавања за руковање изузецима"
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr "Изврши праћење променљивих"
 
-#: common.opt:2424
+#: common.opt:2427
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments"
 msgstr "Изврши праћење променљивих"
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr ""
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr ""
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees"
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:2454
+#: common.opt:2457
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:2458
+#: common.opt:2461
 msgid "Specifies the cost model for vectorization"
 msgstr ""
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:2478
+#: common.opt:2481
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Не ради ништа. Остављено ради сагласности уназад."
 
-#: common.opt:2482
+#: common.opt:2485
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Не ради ништа. Остављено ради сагласности уназад."
 
-#: common.opt:2490
+#: common.opt:2493
 #, fuzzy
 #| msgid "Enable copy propagation for stores and loads"
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Укључи распростирање копирања за складиштења и учитавања"
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr "Додај допунске коментаре у испису асемблера"
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr ""
 
-#: common.opt:2507
+#: common.opt:2510
 #, fuzzy, c-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "непрепозната вредност видљивости „%s“"
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(близу успостављања за %qs)"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr "Користи профиле вредности израза у оптимизацијама"
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr "Конструиши мреже и подели неповезане употребе једне променљиве"
 
-#: common.opt:2555
+#: common.opt:2558
 #, fuzzy
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr "Укључи ССА оптимизацију елиминације мртвог кôда на стаблима"
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr "Изврши оптимизације целог програма"
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr "Претпостави да се преливање означене аритметике омотава"
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr "Стави податке успостављене на нулу у одељак bss"
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr "Стварај исправљачке информације у формату КОФФа"
 
-#: common.opt:2579
+#: common.opt:2582
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format"
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:2583
+#: common.opt:2586
 #, fuzzy
 #| msgid "Generate debug information in DWARF v2 format"
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr "Стварај исправљачке информације у формату ДВАРФа 2"
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr "Стварај исправљачке информације у подразумеваном проширеном формату"
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2614
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Don't generate debug information in separate .dwo files"
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:2615
+#: common.opt:2618
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files"
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr "Стварај исправљачке информације у формату СТАБСа"
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr "Стварај исправљачке информације у проширеном формату СТАБСа"
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2638
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation"
 msgstr "Стварај исправљачке информације у формату ВМСа"
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr "Стварај исправљачке информације у формату ВМСа"
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr "Стварај исправљачке информације у формату ИксКОФФа"
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr "Стварај исправљачке информације у проширеном формату ИксКОФФа"
 
-#: common.opt:2665
+#: common.opt:2668
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections"
 msgstr "Стварај инструкције isel"
 
-#: common.opt:2669
+#: common.opt:2672
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:2676
+#: common.opt:2679
 #, fuzzy
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr "-imultilib <дир> Постави <дир> као поддиректоријум укључивања за вишебиба"
 
-#: common.opt:2680
+#: common.opt:2683
 #, fuzzy
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr "-imultilib <дир> Постави <дир> као поддиректоријум укључивања за вишебиба"
 
-#: common.opt:2702
+#: common.opt:2705
 #, fuzzy
 #| msgid "Place output into <file>"
 msgid "-o <file>\tPlace output into <file>"
 msgstr "Стави излаз у <file>"
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr "Укључи профилисање функција"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr "Као -pedantic али их издај као грешке"
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr "Не приказуј компиловане функције или протекло време"
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr "Укључи опширан излаз"
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr "Прикажи верзију компилатора"
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "Сузбиј упозорења"
 
-#: common.opt:2806
+#: common.opt:2809
 #, fuzzy
 #| msgid "Enable ID based shared library"
 msgid "Create a shared library"
 msgstr "Укључи дељене библиотеке на основу ИДа"
 
-#: common.opt:2851
+#: common.opt:2854
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Create a position independent executable"
 msgstr "Стварај положајно-независни кôд за извршне ако је могуће (велики режим)"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "израчуната вредност се не користи"
@@ -16092,301 +16102,301 @@
 msgid "expected integer or boolean type"
 msgstr "очекиван је целобројни израз"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 #, fuzzy
 #| msgid "comparison of promoted ~unsigned with unsigned"
 msgid "invalid comparison of nil with nil"
 msgstr "поређење унапређеног ~неозначеног са неозначеним"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 #, fuzzy
 #| msgid "incompatible types in return"
 msgid "incompatible types in binary expression"
 msgstr "несагласни типови у повратку"
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 #| msgid "division by zero"
 msgid "integer division by zero"
 msgstr "дељење нулом"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 #, fuzzy
 #| msgid "size of array %qs has non-integer type"
 msgid "shift of non-integer operand"
 msgstr "величина низа %qs има нецелобројни тип"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 #, fuzzy
 #| msgid "switch quantity not an integer"
 msgid "shift count not unsigned integer"
 msgstr "величина у прекидачу није целобројна"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 #, fuzzy
 #| msgid "negative insn length"
 msgid "negative shift count"
 msgstr "негативна дужина ије"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 #, fuzzy
 #| msgid "called object %qE is not a function"
 msgid "object is not a method"
 msgstr "позвани објекат %qE није функција"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 #, fuzzy
 #| msgid "argument of type %qT does not match %qT"
 msgid "method type does not match object type"
 msgstr "аргумент типа %qT не поклапа се са %qT"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 #, fuzzy
 #| msgid "invalid argument to builtin function"
 msgid "invalid use of %<...%> with builtin function"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 #, fuzzy
 #| msgid "invalid use of template-name %qE without an argument list"
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "неисправна употреба шаблонског имена %qE без листе аргумената"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 #, fuzzy
 #| msgid "no arguments"
 msgid "not enough arguments"
 msgstr "без аргумената"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 #, fuzzy
 #| msgid "too many arguments for format"
 msgid "too many arguments"
 msgstr "превише аргумената за формат"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 #, fuzzy
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be a map"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 #, fuzzy
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "invalid type for make function"
 msgstr "%qE има неисправан тип за %<reduction%>"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 #, fuzzy
 #| msgid "too many arguments for format"
 msgid "too many arguments to make"
 msgstr "превише аргумената за формат"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 #, fuzzy
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument must be array or slice or channel"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 #, fuzzy
 #| msgid "invalid argument to builtin function"
 msgid "unsupported argument type to builtin function"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 #, fuzzy
 #| msgid "Argument dim at %L must be scalar"
 msgid "argument must be channel"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 #, fuzzy
 #| msgid "Qualifier must be a reference"
 msgid "argument must be a field reference"
 msgstr "Одредба мора бити упућивач"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 #, fuzzy
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "left argument must be a slice"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 #, fuzzy
 #| msgid "first argument of %q+D should be %<int%>"
 msgid "first argument must be []byte"
 msgstr "први аргумент за %q+D треба да је %<int%>"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 #, fuzzy
 #| msgid "tls_model argument not a string"
 msgid "second argument must be slice or string"
 msgstr "аргумент за tls_model није ниска"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 #, fuzzy
 #| msgid "%Jparameter %u has void type"
 msgid "argument 2 has invalid type"
 msgstr "%Jпараметар %u има празан тип"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 #, fuzzy
 #| msgid "%Jparameter %u has incomplete type"
 msgid "argument must have complex type"
 msgstr "%Jпараметар %u има непотпун тип"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 #, fuzzy
 #| msgid "cleanup argument not an identifier"
 msgid "complex arguments must have identical types"
 msgstr "чистачки аргумент није идентификатор"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 #, fuzzy
 #| msgid "Do not use hardware floating point"
 msgid "complex arguments must have floating-point type"
 msgstr "Не користи хардверски покретан зарез"
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 #, fuzzy
 #| msgid "Expected string"
 msgid "expected function"
 msgstr "Очекивана је ниска"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 msgid "multiple-value argument in single-value context"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 #, fuzzy
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<...%> with non-slice"
 msgstr "неисправна употреба %<this%> на највишем нивоу"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 #, fuzzy
 #| msgid "Function return value not set"
 msgid "function result count mismatch"
 msgstr "Повратна вредност функције није постављена"
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 #, fuzzy
 #| msgid "incompatible types in return"
 msgid "incompatible type for receiver"
 msgstr "несагласни типови у повратку"
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 #, fuzzy
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 #, fuzzy
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "number of results does not match number of values"
 msgstr "долазна ивица се не поклапа са бројем ПХИ аргумената"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 #, fuzzy
 #| msgid "Cray pointer at %C must be an integer."
 msgid "index must be integer"
 msgstr "Крејов показивач код %C мора бити целобројни."
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 #, fuzzy
 #| msgid "schedule chunk size expression must be integral"
 msgid "slice end must be integer"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 #| msgid "switch quantity not an integer"
 msgid "slice capacity must be integer"
 msgstr "величина у прекидачу није целобројна"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 #, fuzzy
 #| msgid "incompatible types in assignment"
 msgid "incompatible type for map index"
 msgstr "несагласни типови у додели"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 #, fuzzy
 #| msgid "too many arguments for format"
 msgid "too many expressions for struct"
 msgstr "превише аргумената за формат"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 #, fuzzy
 #| msgid "too few arguments for format"
 msgid "too few expressions for struct"
 msgstr "премало аргумената за формат"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 #, fuzzy
 #| msgid "Invalid interface type"
 msgid "type assertion only valid for interface types"
 msgstr "Неисправан тип сучеља"
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 #, fuzzy
 #| msgid "expected class name"
 msgid "expected channel"
 msgstr "очекивано је име класе"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -16526,83 +16536,83 @@
 msgid "cannot use type %s as type %s"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 #, fuzzy
 #| msgid "invalid receiver type %qs"
 msgid "different receiver types"
 msgstr "неисправан тип примаоца %qs"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "different number of parameters"
 msgstr "поновљена дефиниција параметра %q+D"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 #, fuzzy
 #| msgid "invalid parameter type %qT"
 msgid "different parameter types"
 msgstr "неисправан тип параметра %qT"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "incompatible type for method %s%s%s"
 msgstr "несагласни тип за аргумент %d у %qE"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "несагласни тип за аргумент %d у %qE"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 #, fuzzy
 #| msgid "error while parsing methods"
 msgid "type has no methods"
 msgstr "грешка при рашчлањивању метода"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, fuzzy, c-format
 #| msgid "ambiguous abbreviation %s"
 msgid "ambiguous method %s%s%s"
 msgstr "двосмислена скраћеница %s"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, fuzzy, c-format
 #| msgid "missing argument to \"%s\""
 msgid "missing method %s%s%s"
 msgstr "недостаје аргумент за „%s“"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -16733,7 +16743,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "неисправан трећи аргумент за %<__builtin_prefetch%>; користим нулу"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "премало аргумената за функцију %<va_start%>"
@@ -16930,12 +16940,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "позив функције има скупинску вредност"
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "Pass arguments on the stack"
 msgid "passing too large argument on stack"
@@ -17529,249 +17539,254 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "број об. белешки у ланцу ија (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr "број ивица позивача је негативан"
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge frequency is negative"
 msgstr "број ивица позивача је негативан"
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge frequency is too large"
 msgstr "број ивица позивача је негативан"
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "помоћно поље постављено за ивицу %s->%s"
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, fuzzy, gcc-internal-format
 #| msgid "Execution count is negative"
 msgid "execution count is negative"
 msgstr "Број извршавања је негативан"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Претпостави да симболи могу бити неважећи"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "aux field set for edge %s->%s"
 msgid "aux field set for indirect edge from %s"
 msgstr "помоћно поље постављено за ивицу %s->%s"
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "показивач inlined_to је погрешан"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "вишеструки уткани позивачи"
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "показивач inlined_to постављен за неуткане позиваче"
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "показивач inlined_to постављен али нема претходника"
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "показивач inlined_to упућује на самог себе"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "дељени call_stmt:"
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "ивица показује на погрешну декларацију:"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "недостаје графпоз ивица за call_stmt:"
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "очекивана је наредба"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "ивица %s->%s нема одговарајући call_stmt"
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "edge %s->%s has no corresponding call_stmt"
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "ивица %s->%s нема одговарајући call_stmt"
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node није успело"
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to '-%s' is missing"
 msgid "%s: section %s is missing"
@@ -17919,7 +17934,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
@@ -18174,17 +18189,17 @@
 msgid "          %s"
 msgstr "        %qD"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr ""
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "глобални деструктори нису подржани на овом циљу"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "глобални конструктори нису подржани на овом циљу"
@@ -18231,12 +18246,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -18448,7 +18463,7 @@
 msgid "total size of local objects too large"
 msgstr "%Jукупна величина локалних објеката је превелика"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "немогуће ограничење у %<asm%>"
@@ -18947,9 +18962,9 @@
 msgstr "не могу да запишем ПЦХ датотеку"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
@@ -18966,171 +18981,165 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr "провера стабла: очекивах класу %qs, имам %qs (%s) у %s, код %s:%d"
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "using result of function returning %<void%>"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "немеморијски улаз %d мора остати у меморији"
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "меморијски улаз %d не може се непосредно адресирати"
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, fuzzy, gcc-internal-format
 #| msgid "threadprivate variables not supported in this target"
 msgid "threadprivate variable %qE used in target region"
 msgstr "нитно-локалне променљиве нису подржане за овај циљ"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing target region"
 msgstr "%Hобухватајуће паралелно"
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, fuzzy, gcc-internal-format
 #| msgid "threadprivate variables not supported in this target"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "нитно-локалне променљиве нису подржане за овај циљ"
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing task"
 msgstr "%Hобухватајуће паралелно"
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing parallel"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing parallel"
 msgstr "%Hобухватајуће паралелно"
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing task"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing teams construct"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 #| msgid "%Hiteration variable %qE is unsigned"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%Hнеозначена променљива итерације %qE"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should be private"
 msgstr "требало би да променљива итерације %qs буде приватна"
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be reduction"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should not be private"
 msgstr "требало би да променљива итерације %qs буде приватна"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s променљива %qs је приватна у спољашњем контексту"
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%s variable %qE is private in outer context"
 msgstr "%s променљива %qs је приватна у спољашњем контексту"
 
-#: gimplify.c:7001
-#, fuzzy, gcc-internal-format
-#| msgid "%s variable %qs is private in outer context"
-msgid "lastprivate variable %qE is private in outer context"
-msgstr "%s променљива %qs је приватна у спољашњем контексту"
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, gcc-internal-format
 msgid "directive not yet implemented"
 msgstr ""
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "гимплификација није успела"
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "први аргумент за %<va_arg%> није типа %<va_list%>"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT се унапређује у %qT при прослеђивању кроз %<...%>"
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(стога би требало да проследите %qT уместо %qT за %<va_arg%>)"
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "ако се овај кôд досегне, програм ће се прекинути"
@@ -19572,49 +19581,49 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot find LTO cgraph in %s"
 msgstr "не могу да нађем класу %qs"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find protocol declaration for %qs"
 msgid "cannot find LTO section refs in %s"
 msgstr "не могу да нађем декларацију протокола за %qs"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -19701,51 +19710,51 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "нема улазних датотека"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 #| msgid "%s:error writing output file '%s'\n"
 msgid "writing output file"
 msgstr "%s:грешка при писању у излазну датотеку ‘%s’\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "променљива окружења DJGPP није дефинисана"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "променљива окружења DJGPP није дефинисана"
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen: %s: %m"
@@ -19892,13 +19901,13 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid exit from OpenMP structured block"
 msgid "invalid exit from %s structured block"
 msgstr "неисправан излаз из структуираног блока ОпенМПа"
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid entry to OpenMP structured block"
 msgid "invalid entry to %s structured block"
@@ -19905,19 +19914,19 @@
 msgstr "неисправан улаз у структуирани блок ОпенМПа"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid exit from OpenMP structured block"
 msgid "invalid branch to/from %s structured block"
 msgstr "неисправан излаз из структуираног блока ОпенМПа"
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "ignoring large linear step"
 msgstr "игноришем директоријум дупликат „%s“\n"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -20478,8 +20487,8 @@
 msgstr "„%s“ се не може користити као %s регистар"
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "непознато име регистра: %s"
@@ -20940,7 +20949,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld врати излазни статус %d"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F употребљено али недефинисано"
@@ -22017,42 +22026,42 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr ""
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -22453,53 +22462,53 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript is outside array bounds"
 msgstr "индекс низа није целобројан"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript is above array bounds"
 msgstr "индекс низа није целобројан"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript is below array bounds"
 msgstr "индекс низа није целобројан"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr "претпостављам да се означено преливање не дешава при упрошћавању услова до константе"
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr "претпостављам да се означено преливање не дешава при упрошћавању услова"
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, fuzzy, gcc-internal-format
 #| msgid "comparison is always false due to limited range of data type"
 msgid "comparison always false due to limited range of data type"
 msgstr "поређење је увек нетачно услед ограниченог опсега типа"
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, fuzzy, gcc-internal-format
 #| msgid "comparison is always true due to limited range of data type"
 msgid "comparison always true due to limited range of data type"
 msgstr "поређење је увек тачно услед ограниченог опсега типа"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when simplifying range test"
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr "претпостављам да се означено преливање не дешава при упрошћавању пробе опсега"
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when simplifying range test"
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
@@ -22545,9 +22554,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -22795,7 +22804,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "захтевано равнање за %q+D веће је од имплементираног равнања за %wu"
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "величина складишта за %q+D није позната"
@@ -22956,27 +22965,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "дужина ниске %qd већа је од дужине %qd коју ИСО компилатори Ц%d морају да подрже"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "негативан леви помак"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "негативан десни помак"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "леви помак >= од ширине типа"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "десни помак >= од ширине типа"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "преливање у константном изразу"
@@ -23319,12 +23328,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "предлажем заграде око израза употребљеног као истинитосна вредност"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "неисправна употреба %<restrict%>"
@@ -23817,12 +23826,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "неисправан тип вектора за атрибут %qE"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "величина вектора није целобројни умножак величине компоненте"
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "нулта величина вектора"
@@ -23832,22 +23841,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr "број компоненти вектора није степен двојке"
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "ненулти атрибут без аргумената код непрототипа"
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "ненулти аргумент има неисправан број операнада (аргумент %lu)"
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "ненулти аргумент са бројем операнада ван опсега (аргумент %lu, операнд %lu)"
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "ненулти аргумент упућује на непоказивачки операнд (аргумент %lu, операнд %lu)"
@@ -23887,12 +23896,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "атрибут %qE је примењив само на варијадичке функције"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "захтевани положај није целобројна константа"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "захтевани положај је мањи од нуле"
@@ -23982,7 +23991,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "покушај узимања адресе битског поља %qD у структури"
@@ -24453,7 +24462,7 @@
 msgstr "Индекс у димензији %d је ван граница код %L"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -24922,7 +24931,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for iteration variable %qE"
@@ -24934,25 +24943,25 @@
 msgid "%qE is not initialized"
 msgstr "%H%qE није успостављено"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing controlling predicate"
 msgid "missing controlling predicate"
 msgstr "%Hнедостаје контролишући предикат"
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid controlling predicate"
 msgid "invalid controlling predicate"
 msgstr "%Hнеисправан контролишући предикат"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing increment expression"
 msgid "missing increment expression"
 msgstr "%Hнедостаје израз увећања"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid increment expression"
 msgid "invalid increment expression"
@@ -25524,6 +25533,12 @@
 msgid "too many input files"
 msgstr "превише улазних датотека"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+#| msgid "stack frame too large"
+msgid "-mcpu string too large"
+msgstr "оквир стека превелик"
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -25551,49 +25566,49 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops је застарело, користите -falign-loops"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d није између 0 и %d"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps је застарело, користите -falign-jumps"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-loops=%d није између 0 и %d"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions је застарело, користите -falign-functions"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-loops=%d није између 0 и %d"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d није између 0 и 5"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -26002,64 +26017,64 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr ""
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "лоша вредност %qs за прекидач -mtrap-precision"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "лоша вредност %qs за прекидач -mfp-rounding-mode"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "лоша вредност %qs за прекидач -mfp-trap-mode"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr "лоша вредност %qs за прекидач -mcpu"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for -mtune switch"
 msgstr "лоша вредност (%s) за прекидач -mtune="
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr "ФП софтверско довршавање захтева -mtrap-precision=i"
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "режим заокруживања није подржан за ВАКСове реалне"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "режим клопки није подржан за ВАКСове реалне"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr "128-битни дуги реални није подржан за ВАКСове реалне"
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr "Кашњење L%d оставе непознато за %s"
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr "лоша вредност %qs за -mmemory-latency"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -26553,14 +26568,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
@@ -27257,47 +27272,53 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "не могу да поставим положај у ПЦХ датотеци: %m"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-Werror=%s: No option -%s"
 msgid "wrong arg %s to option %s"
 msgstr "-Werror=%s: нема опције -%s"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "име регистра није наведено за %q+D"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
+#, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386.c:3012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %s specified for option %s"
 msgstr "равнање се не може навести за %q+D"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %s"
 msgstr "нема имена класе наведеног помоћу %qs"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown argument list function at %L"
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "Непозната функције листе аргумената код %L"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mtune=x86-64 is deprecated.  Use -mtune=k8 or -mtune=generic instead as appropriate."
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
@@ -27304,369 +27325,380 @@
 msgstr "-mtune=x86-64 је превазиђено. Користите -mtune=k8 или -mtune=generic уместо тога."
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "модела кôда %qs није подржан у %s-битном режиму"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "модела кôда %qs није подржан у %s-битном режиму"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s није подржано у овој конфигурацији"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-битни режим није укомпилован"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "ЦПУ који сте изабрали не подржава скуп инструкција икс86-64"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s не подржава %s"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "лоша вредност (%s) за прекидач -mtune="
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d није између 0 и %d"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-arrays није подржано за овај циљ"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr "-msseregparm употребљено без укључених ССЕ инструкција"
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "скуп ССЕ инструкција искључен, користим 387 аритметику"
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "скуп 387 инструкција искључен, користим ССЕ аритметику"
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for -mrecip=%s"
 msgstr "непозната опција типа -m%s=: „%s“"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "аргумент алијаса није ниска"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ACCESS specification at %L was already specified"
 msgid "option(\"%s\") was already specified"
 msgstr "Одредница ACCESS код %L је већ наведена "
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибути fastcall и regparm нису сагласни"
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент за атрибут %qs већи од %d"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибути fastcall и cdecl нису сагласни"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Позивање %qD са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Позивање %qT са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.c:5923
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
-#| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr "Позивање %qD са атрибутом sseregparm без укључених ССЕ/ССЕ2"
-
-#: config/i386/i386.c:6210
-#, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "не подржава вишебиб"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "ССЕ векторски аргумент без укључених ССЕ мења АБИ"
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "ССЕ векторско враћање без укључених ССЕ мења АБИ"
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "ССЕ враћање регистра уз искључене ССЕ"
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "ССЕ регистарски аргумент уз искључене ССЕ"
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "враћање из регистра x87 када је x87 искључено"
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, fuzzy, gcc-internal-format
+#| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr "Позивање %qD са атрибутом sseregparm без укључених ССЕ/ССЕ2"
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
+#, fuzzy, gcc-internal-format
+#| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr "Позивање %qD са атрибутом sseregparm без укључених ССЕ/ССЕ2"
+
+#: config/i386/i386.c:11378
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "%s није подржано за угњеждене функције"
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -27674,285 +27706,285 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, fuzzy, gcc-internal-format
 #| msgid "%s functions limited to %d register parameters"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "%s функције ограничене на %d регистарских параметара"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "проширени регистри немају високе половине"
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "неподржана величина операнда за проширени регистар"
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "No dispatcher found for %s"
 msgstr "Није нађена дефиниција етикете за %qs"
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "израз ограничења стека није подржан"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %D"
 msgstr "претходна декларација %q+D"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "Аргумент за -ffpe-trap није исправан: %s"
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "помак мора бити непосредни"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "трећи аргумент за %<__builtin_prefetch%> мора бити константа"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "нетачна ија:"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "нетачно дељење чворова стабла"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "селектор мора бити целобројна константа у опсегу 0..%wi"
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "маска мора бити непосредна"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "нетачна ија:"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs несагласан атрибут игнорисан"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "неподржана комбинација: %s"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -28053,13 +28085,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr "вредност уз -mfixed-range мора бити облика РЕГ1-РЕГ2"
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -28135,7 +28167,7 @@
 msgstr "атрибут %qE није подржан на овој платформи"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%qE attribute argument not an integer constant"
@@ -28204,7 +28236,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "израз ограничења стека није подржан"
@@ -29126,16 +29158,11 @@
 msgid "-g option disabled"
 msgstr "опција -g искључена"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "равнање (%u) за %s премашује највеће равнање за глобалне заједничке податке. Користим %u"
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr "опција -munix=98 потребна за могућности из амандмана 1 Ц-а 89.\n"
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, fuzzy, gcc-internal-format
@@ -29410,334 +29437,339 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "ГЦЦ вектор враћен упућивачем: нестандарно проширење АБИја, без јемства сагласности"
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "вредност се не може вратити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "вредност се не може проследити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "ГЦЦ вектор прослеђен упућивачем: нестандарно проширење АБИја, без јемства сагласности"
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %s already processed"
 msgstr "Сматрај улазну датотеку већ предобрађеном"
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "аргумент 1 за __builtin_altivec_predicate мора бити константа"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "аргумент 1 за __builtin_altivec_predicate ван опсега"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
+#, gcc-internal-format, gfc-internal-format
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "аргумент 1 за __builtin_spe_predicate ван опсега"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "број мора бити 0 или 1"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "број мора бити 0 или 1"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range 0..15"
 msgstr "Аргумент у ATANH код %L мора бити у опсегу -1 до 1"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "неразрешено препуњавање за алтивек уграђено %qF"
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "аргумент за dss мора бити двобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "аргумент 1 за __builtin_spe_predicate мора бити константа"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "аргумент 1 за __builtin_spe_predicate ван опсега"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "аргумент 1 за __builtin_spe_predicate мора бити константа"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "аргумент 1 за __builtin_spe_predicate ван опсега"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "ова уграђена функција доступна је само на фр450"
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mspe option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "Builtin function %s is not supported with the current options"
 msgstr "опција командне линије %qs није подржана овом конфигурацијом"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "internal error: sideeffect-insn affecting main effect"
 msgid "internal error: builtin function %s had no type"
 msgstr "унутрашња грешка: ија за споредни ефекат утиче на главни ефекат"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "оквир стека превелик"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "нема профилисања 64-битног кôда за овај АБИ"
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "употреба %<long double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "употреба логичких типова у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "употреба %<complex%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "употреба децималних реалних типова у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "употреба %<long%> у алтивек типовима није исправна у 64-битном кôду"
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "превазиђена употреба %<long%> у алтивек; користите %<int%>"
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "употреба %<long long%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "употреба %<double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "неисправна употреба %<::%>"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%<#pragma%> није дозвољена овде"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s\"%s\"%s is invalid"
@@ -29996,92 +30028,92 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "укупна величина локалних променљивих премашује ограничење архитектуре"
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "величина оквира за %qs је "
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs користи динамичко резервисање стека"
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "аргумент за „%s“ треба да је ненегативан цео број"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "аргумент за атрибут %qs већи од %d"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "режим з/Архитектуре није подржан на %s"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-битни АБИ није подржан у режиму ЕСЕ/390"
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Ограничи употребу хардверских инструкција покретног зареза на 32-битне операције"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float нису подржани у комбинацији"
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "величина стека мора бити већа од вредности браника стека"
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "величина стека не сме бити већа од 64k"
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard имплицира коришћење -mstack-size"
@@ -30096,35 +30128,35 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "__builtin_saveregs није подржано овим подциљем"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to interrupt functions"
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "атрибут %qs примењив је само на функције прекида"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "%qE attribute is supported only for SH2A"
 msgstr "атрибут %qE није подржан на овој платформи"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr "атрибут interrupt_handler није сагласан са -m5-compact"
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "%qE attribute only applies to SH2A"
 msgstr "атрибут %qs примењује се само на функције"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%qE attribute argument should be between 0 to 255"
@@ -30131,24 +30163,24 @@
 msgstr "аргумент атрибута %qs није целобројна константа"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "%qE attribute argument not a string constant"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr "r0 мора бити доступан као позивом продрман регистар"
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, fuzzy, gcc-internal-format
 #| msgid "Need a second call-clobbered general purpose register"
 msgid "need a second call-clobbered general purpose register"
 msgstr "Потребан је други позивом продрман регистар опште намене"
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, fuzzy, gcc-internal-format
 #| msgid "Need a call-clobbered target register"
 msgid "need a call-clobbered target register"
@@ -30553,49 +30585,49 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid element type for attribute %qs"
 msgstr "неисправан тип вектора за атрибут %qE"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "број компоненти вектора није степен двојке"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "атрибут %qs се игнорише"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "атрибут %qE захтева прототипове са именованим аргументима"
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variadic functions"
 msgid "%qs attribute only applies to variadic functions"
 msgstr "атрибут %qE је примењив само на варијадичке функције"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "%qE attribute has no effect"
 msgstr "атрибут %qE се игнорише"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "attribute %qs applies to array types only"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
@@ -30659,7 +30691,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "празна вредност није игнорисана а требало би"
@@ -30689,65 +30721,65 @@
 msgid "GCC supports only %u nested scopes"
 msgstr "ГЦЦ подржава само %u угњеждених досега"
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "етикета %q+D употребљена али недефинисана"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "угњеждена функција %q+D декларисана али нигде дефинисана"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %q+D declared but never defined"
 msgid "inline function %q+D declared but never defined"
 msgstr "угњеждена функција %q+D декларисана али нигде дефинисана"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "неупотребљена променљива %q+D"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "variable %qD set but not used"
 msgstr "етикета %q+D дефинисана али неупотребљена"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "тип низа %q+D довршен несагласно са имплицитним успостављањем"
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, fuzzy, gcc-internal-format
 #| msgid "original label is here"
 msgid "originally defined here"
 msgstr "првобитна етикета је овде"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr "листа параметара са тротачком не може поклопити декларацију празне листе имена параметара"
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr "тип аргумента који има подразумевано унапређење не може поклопити декларацију празне листе имена параметара"
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "протитип за %q+D декларише више аргумената од претходне старовремске дефиниције"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "протитип за %q+D декларише мање аргумената од претходне старовремске дефиниције"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr "протитип за %q+D декларише %d са несагласним типом"
@@ -30754,42 +30786,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "протитип за %q+D прати непрототипску дефиницију"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "претходна дефиниција %q+D беше овде"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "претходна имплицитна декларација %q+D беше овде"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "претходна декларација %q+D беше овде"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "%q+D поново декларисано као различита врста симбола"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "декларација %q+D заклања уграђену функцију"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "поновљена декларација набрајача %q+D"
@@ -30797,158 +30829,158 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "сукобљени типови за уграђену функцију %q+D"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "сукобљени типови за %q+D"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting return type specified for %q+#D"
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr "сукобљен повратни тип наведен за %q+#D"
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting types for %q+D"
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr "сукобљени типови за %q+D"
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "сукобљене одредбе типа за %q+D"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D"
 msgid "redefinition of typedef %q+D with different type"
 msgstr "поновљена дефиниција типа %q+D"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, fuzzy, gcc-internal-format
 #| msgid "jump into scope of identifier with variably modified type"
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "скок у досег идентификатора са променљиво измењивим типом"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "поновљена дефиниција типа %q+D"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "поновљена дефиниција %q+D"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "статичка декларација %q+D прати нестатичку декларацију"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "нестатичка декларација %q+D прати статичку декларацију"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr ""
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, fuzzy, gcc-internal-format
 #| msgid "  from here"
 msgid "but not here"
 msgstr "  одавде"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "нитно-локална декларација %q+D прати не-нитно-локалну декларацију"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "не-нитно-локална декларација %q+D прати нитно-локалну декларацију"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "декларација спољашњег %q+D прати декларацију без повезивости"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "декларација %q+D без повезивости прати декларацију спољашњег"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "поновљена декларација %q+D без повезивости"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr "поновљена декларација %q+D са различитом видљивошћу (чува се стара видљивост)"
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "уткана декларација %q+D прати декларацију без атрибута noinline"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "декларација %q+D са атрибутом noinline прати уткану декларацију "
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "декларација %q+D са атрибутом noinline прати уткану декларацију "
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "поновљена дефиниција параметра %q+D"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "сувишна поновљена декларација %q+D"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "декларација %q+D заклања претходну не-променљиву"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "декларација %qD заклања глобалну декларацију"
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "декларација %q+D заклања претходну локалну"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
@@ -30955,73 +30987,73 @@
 msgid "shadowed declaration is here"
 msgstr "%Jзаклоњена декларација је овде"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "угњеждена декларација %qD"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "имплицитна декларација функције %qE"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "несагласна имплицитна декларација уграђене функције %qD"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "неисправна поновљена декларација %q+D"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "несагласна имплицитна декларација функције %qD"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function)"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function)"
 msgstr "%H%qE недекларисано (прва употреба у овој функцији)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, fuzzy, gcc-internal-format
 #| msgid "%H(Each undeclared identifier is reported only once"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H(Сваки недекларисани идентификатор пријављен је само једном"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "на етикету %qE упућено ван било које функције"
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "скок у досег идентификатора са променљиво измењивим типом"
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, fuzzy, gcc-internal-format
 #| msgid "Missing variable initializer"
 msgid "jump skips variable initialization"
 msgstr "Недостаје успостављач променљиве"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "label %qD defined here"
 msgstr "етикета %q+D дефинисана али неупотребљена"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
@@ -31028,130 +31060,130 @@
 msgid "%qD declared here"
 msgstr "%q+D декларисано овде"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "скок у наредбени израз"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "Удвостручена декларација етикете %qE"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "удвостручена етикета %qD"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, fuzzy, gcc-internal-format
 #| msgid "%Htraditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "%Hтрадиционалном Ц-у недостаје одвојени именски простор за етикете, те је идентификатор %qE у сукобу"
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in initialization"
 msgid "switch jumps over variable initialization"
 msgstr "несагласни типови у успостављању"
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, fuzzy, gcc-internal-format
 #| msgid "jump into statement expression"
 msgid "switch jumps into statement expression"
 msgstr "скок у наредбени израз"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE defined as wrong kind of tag"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%H%qE дефинисан као погрешна врста ознаке"
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "неименована структура/унија која не дефинише ниједан примерак"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "празна декларација са наводиоцем складишне класе која не редекларише ознаку"
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "празна декларација са одредом типа која не редекларише ознаку"
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration with type qualifier does not redeclare tag"
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "празна декларација са одредом типа која не редекларише ознаку"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "бескорисно име типа у празној декларацији"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> у празној декларацији"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<inline%> у празној декларацији"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> у празној декларацији у досегу датотеке"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> у празној декларацији у досегу датотеке"
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "бескорисан наводилац складишне класе у празној декларацији"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "useless type name in empty declaration"
 msgid "useless %qs in empty declaration"
 msgstr "бескорисно име типа у празној декларацији"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "бескорисна одредба типа у празној декларацији"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 #| msgid "useless %<__thread%> in empty declaration"
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "бескорисно %<__thread%> у празној декларацији"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "празна декларација"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ИСО Ц 90 не подржава %<static%> или одредбе типа у параметарским деклараторима низова"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ИСО Ц 90 не подржава деклараторе низова %<[*]%>"
@@ -31159,38 +31191,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> није дозвољено другде осим у досегу прототипа функције"
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D је обично функција"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "дефиниција типа %qD је успостављена (употребите __typeof__)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "функција %qD је успостављена као променљива"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "параметар %qD је успостављен"
@@ -31199,281 +31231,281 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "објекат променљиве величине не може се успостављати"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "променљива %qD има успостављач али је непотпуног типа"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "утканој функцији %q+D дат је атрибут noinline"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "неуспостављени константни члан %qD"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD should be initialized"
 msgstr "%q+D ће бити успостављено после"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "успостављач не одређује величину за %q+D"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "недостаје величина низа у %q+D"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "нулта или негативна величина низа %q+D"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "величина складишта за %q+D није константна"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "игноришем наводилац asm за нестатичку локалну променљиву %q+D"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "не могу да ставим објекат са непостојаним пољем у регистар"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "неуспостављена константа %qD"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ИСО Ц забрањује унапредне декларације параметара"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "ширина битског поља %qs није целобројна константа"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs width not an integer constant"
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "ширина битског поља %qs није целобројна константа"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "негативна ширина у битском пољу %qs"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "нулта ширина за битско поље %qs"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "битско поље %qs има неисправан тип"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "тип битског поља %qs је проширење ГЦЦа"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "ширина %qs премашује свој тип"
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs је уже од вредности свог типа"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ИСО Ц 90 забрањује низ %qs чија се величина не може израчунати"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ИСО Ц 90 забрањује низ %qs чија се величина не може израчунати"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ИСО Ц 90 забрањује низ променљиве величине %qs"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "ISO C90 forbids variable length array"
 msgstr "ИСО Ц 90 забрањује низ променљиве величине %qs"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified %qs at file scope"
 msgid "variably modified %qE at file scope"
 msgstr "променљиво измењиво %qs у досегу датотеке"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified %qs at file scope"
 msgid "variably modified field at file scope"
 msgstr "променљиво измењиво %qs у досегу датотеке"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "тип спада на %<int%> у декларацији %qs"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in type name"
 msgstr "тип спада на %<int%> у декларацији %qs"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "удвостручено %<const%>"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "удвостручено %<restrict%>"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "удвостручено %<volatile%>"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "удвостручено %<restrict%>"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting super class name %qs"
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "сукобљено име наткласе %qs"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "дефиниција функције декларисана као %<auto%>"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "дефиниција функције декларисана као %<register%>"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "дефиниција функције декларисана као %<typedef%>"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "дефиниција функције декларисана као %<auto%>"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field %qE"
 msgstr "складишна класа наведена за поље структуре %qs"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field"
 msgstr "складишна класа наведена за поље структуре %qs"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for parameter %qE"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for unnamed parameter"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "складишна класа наведена за име типа"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs успостављено и декларисано као %<extern%>"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, fuzzy, gcc-internal-format
 #| msgid "%qs has both %<extern%> and initializer"
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs има и %<extern%> и успостављач"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<auto%>"
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "декларација датотечног досега за %qs наводи %<auto%>"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<register%>"
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "декларација датотечног досега за %qs наводи %<register%>"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested function %qE declared %<extern%>"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -31482,759 +31514,759 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "статичка или одредба типа у непараметарском декларатору низа"
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qE as array of voids"
 msgstr "декларација %qs као низа празних"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of type name as array of voids"
 msgstr "декларација %qs као низа празних"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qE as array of functions"
 msgstr "декларација %qs као низа функција"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of type name as array of functions"
 msgstr "декларација %qs као низа функција"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "неисправна употреба структуре са флексибилним чланским низом"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of array %qE has non-integer type"
 msgstr "величина низа %qs има нецелобројни тип"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of unnamed array has non-integer type"
 msgstr "величина низа %qs има нецелобројни тип"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids zero-size array %qs"
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ИСО Ц забрањује нулту величину низа %qs"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array"
 msgid "ISO C forbids zero-size array"
 msgstr "ИСО Ц++ забрањује низ нулте величине"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE is negative"
 msgstr "величина низа %qs је негативна"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "негативна величина низа"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array %qE is too large"
 msgstr "величина низа %qs је превелика"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of unnamed array is too large"
 msgstr "величина низа %qs је превелика"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ИСО Ц 90 не подржава флексибилне чланске низове"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not allowed in other than a declaration"
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> није дозвољено другде осим у декларацији"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "низовни тип има непотпун тип елемента"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "%qE declared as function returning a function"
 msgstr "%qs декларисано као функција која враћа функцију"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "type name declared as function returning a function"
 msgstr "%qs декларисано као функција која враћа функцију"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "%qE declared as function returning an array"
 msgstr "%qs декларисано као функција која враћа низ"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "type name declared as function returning an array"
 msgstr "%qs декларисано као функција која враћа низ"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "дефиниција функције има одређен празан повратни тип"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ИСО Ц забрањује одређене функцијске типове"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ИСО Ц забрањује одређене функцијске типове"
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting type qualifiers for %q+D"
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "сукобљене одредбе типа за %q+D"
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%qs specified for auto variable %qE"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for parameter %qE"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for unnamed parameter"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field %qE"
 msgstr "складишна класа наведена за поље структуре %qs"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field"
 msgstr "складишна класа наведена за поље структуре %qs"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "битско поље %qs има неисправан тип"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "битско поље %qs има неисправан тип"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for typedef %qE"
 msgstr "равнање се не може навести за %q+D"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for %<register%> object %qE"
 msgstr "равнање се не може навести за %q+D"
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for parameter %qE"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for unnamed parameter"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for bit-field %qE"
 msgstr "равнање се не може навести за %q+D"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 #| msgid "%<__alignof%> applied to a bit-field"
 msgid "alignment specified for unnamed bit-field"
 msgstr "%<__alignof%> примењено на битско поље"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "alignment specified for function %qE"
 msgstr "%qs може бити наведено само за функције"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "дефиниција типа %q+D декларисана као %<inline%>"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "дефиниција типа %q+D декларисана као %<inline%>"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ИСО Ц забрањује константне или непостојане функцијске типове"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "члан структуре или уније не може имати променљиво измењив тип"
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "променљива или поље %qE декларисано празним"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "атрибути у параметарском декларатору низа игнорисани"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "field %qE declared as a function"
 msgstr "поље %qs декларисано као функција"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "field %qE has incomplete type"
 msgstr "поље %qs има непотпун тип"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, fuzzy, gcc-internal-format
 #| msgid "name %qT has incomplete type"
 msgid "unnamed field has incomplete type"
 msgstr "име %qT има непотпун тип"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "invalid storage class for function %qE"
 msgstr "неисправна складишна класа за функцију %qs"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "функција %<main%> се не може уткати"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs успостављено и декларисано као %<extern%>"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "променљива претходно декларисана као %<static%> поново декларисана као %<extern%>"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "променљива %q+D декларисана као %<inline%>"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "променљива %q+D декларисана као %<inline%>"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, fuzzy, gcc-internal-format
 #| msgid "jump into scope of identifier with variably modified type"
 msgid "non-nested function with variably modified type"
 msgstr "скок у досег идентификатора са променљиво измењивим типом"
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "објекат променљиво измењивог типа не може имати повезивост"
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "декларација функције није прототип"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "имена параметара (без типова) у декларацији функције"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "параметар %u (%q+D) има непотпун тип"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "parameter %u has incomplete type"
 msgstr "%Jпараметар %u има непотпун тип"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "параметар %u (%q+D) има празан тип"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has void type"
 msgid "parameter %u has void type"
 msgstr "%Jпараметар %u има празан тип"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> као једини параметар не може бити одређен"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> мора бити једини параметар"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "параметар %q+D има само унапредну декларацију"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "%<%s %E%> декларисано унутар параметарске листе"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "анонимно %s декларисано унутар листе"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "има досег само у овој дефиницији или декларацији, што вероватно није оно што желите"
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "enum type defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "struct defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "union defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "поновна дефиниција %<union %E%>"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "поновна дефиниција %<struct %E%>"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "угњеждена поновна дефиниција %<union %E%>"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "угњеждена поновна дефиниција %<struct %E%>"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларација ништа не декларише"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ИСО Ц не подржава неименоване струкутре/уније"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ИСО Ц не подржава неименоване струкутре/уније"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "удвостручени члан %q+D"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "унија нема именованих чланова"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "унија нема чланова"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "структура нема именованих чланова"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "структура нема чланова"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
 msgstr "%Jфлексибилан члански низ у унији"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member not at end of struct"
 msgstr "%Jфлексибилан члански низ није на крају структуре"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member in otherwise empty struct"
 msgstr "%Jфлексибилан члански низ у иначе празној структури"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "type %qT is too large"
 msgstr "величина низа %qs је превелика"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "унија не може бити учињена провидном"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "угњеждена поновна дефиниција %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "поновљена декларација %<enum %E%>"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "вредности у набрајању премашују опсег највећег целог броја"
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "наведени режим је премали за набројиве вредности"
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "преливање у вредностима набрајача"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute noinline"
 msgstr "утканој функцији %q+D дат је атрибут noinline"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "повратни тип је непотпун тип"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "повратни тип спада на %<int%>"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for %q+D"
 msgid "no previous prototype for %qD"
 msgstr "нема претходног прототипа за %q+D"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D је употребљено без прототипа пре дефиниције"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
 msgstr "нема претходне декларације за %q+D"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD was used with no declaration before its definition"
 msgstr "%q+D је употребљено без декларације пре дефиниције"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %<int%>"
 msgstr "повратни тип за %q+D није %<int%>"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is normally a non-static function"
 msgstr "%q+D је обично нестатичка функција"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style parameter declarations in prototyped function definition"
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%Jстаровремска декларација параметара у дефиницији функције са прототипом"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtraditional C rejects ISO C style function definitions"
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%Jтрадиционални Ц одбија дефиниције функција у стилу ИСО Ц-а"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name omitted"
 msgid "parameter name omitted"
 msgstr "%Jизостављено име параметра"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "old-style function definition"
 msgstr "%Jстаровремска дефиниција функције"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name missing from parameter list"
 msgid "parameter name missing from parameter list"
 msgstr "%Jнедостаје име параметра у листи параметара"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "%qD declared as a non-parameter"
 msgstr "%q+D декларисано као не-параметарско"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, fuzzy, gcc-internal-format
 #| msgid "multiple parameters named %q+D"
 msgid "multiple parameters named %qD"
 msgstr "више параметара по имену %q+D"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "parameter %qD declared with void type"
 msgstr "параметар %q+D декларисан са празним типом"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, fuzzy, gcc-internal-format
 #| msgid "type of %q+D defaults to %<int%>"
 msgid "type of %qD defaults to %<int%>"
 msgstr "тип за %q+D спада на %<int%>"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "параметар %q+D има непотпун тип"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "declaration for parameter %q+D but no such parameter"
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "декларација за параметар %q+D, али нема таквог"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "број аргумената не одговора уграђеном прототипу"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "број аргумената не одговара прототипу"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprototype declaration"
 msgid "prototype declaration"
 msgstr "%Hдекларација прототипа"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "унапређени аргумент %qD не одговара уграђеном прототипу"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "унапређени аргумент %qD не одговара прототипу"
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "аргумент %qD не одговара уграђеном прототипу"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не одговара прототипу"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -32243,214 +32275,214 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declaration used outside C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "Почетна декларација у %<for%> петљи употребљена ван режима Ц-а 99"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "декларација статичке променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> декларисана у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> декларисана у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> декларисан у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "декларација не-променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "удвостручено %qE"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "два или више типова података у наводиоцима декларације"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> је предуго за ГЦЦ"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ИСО Ц не подржава децимални покретни зарез"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "-fdata-sections није подржано за овај циљ"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE није ни по дефиницији типа ни уграђени тип"
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE није на почетку декларације"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> употребљено уз %<auto%>"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> употребљено уз %<register%>"
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> употребљено уз %<typedef%>"
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s не подржава %s"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> пре %<extern%>"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> пре %<static%>"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "вишеструке складишне класе у наводиоцима декларације"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs used with %qE"
 msgstr "%<__thread%> употребљено уз %qE"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, fuzzy, gcc-internal-format
 #| msgid "%<@try%> without %<@catch%> or %<@finally%>"
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<@try%> без %<@catch%> или %<@finally%>"
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ИСО Ц не подржава да обичан %<complex%> значи %<double complex%>"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -32460,7 +32492,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr ""
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -32483,8 +32515,8 @@
 msgid "unknown type name %qE"
 msgstr "непознато име регистра: %s"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "очекивани су наводиоци декларације"
@@ -32501,7 +32533,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "очекиван је идентификатор или %<(%>"
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -32585,7 +32617,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "очекивана је дословна ниска"
@@ -32649,14 +32681,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "очекиван је идентификатор"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "зарез на крају листе набрајања"
@@ -33135,35 +33167,35 @@
 msgid "no type or storage class may be specified here,"
 msgstr "складишна класа наведена за %qs"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "недостаје %<(%> после %<#pragma pack%> — игноришем"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "недостаје %<(%> после %<#pragma pack%> — игноришем"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
@@ -33175,52 +33207,52 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> мора бити прво"
@@ -33236,12 +33268,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -33253,31 +33285,31 @@
 msgid "expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "%qD is not a constant"
 msgstr "аргумент %qd није константа"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD није шаблон"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "поређење означених и неозначених целобројних израза"
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "очекивано је %<none%> или %<shared%>"
@@ -33312,18 +33344,18 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%> или %<||%>"
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "распоред %<runtime%> не узима параметар %<chunk_size%>"
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, fuzzy, gcc-internal-format
 #| msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "распоред %<runtime%> не узима параметар %<chunk_size%>"
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "неисправна врста распореда"
@@ -33346,12 +33378,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "using parameters for %<linear%> step is not supported yet"
@@ -33373,19 +33405,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "неисправна врста распореда"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "неисправна маска"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -33397,61 +33429,61 @@
 msgid "invalid proc_bind kind"
 msgstr "неисправна врста распореда"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs није исправно за %qs"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT није угњеждена класа у %qT"
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr ""
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid pragma"
 msgstr "неисправна #pragma %s"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -33461,18 +33493,18 @@
 msgid "expected %<(%> or end of line"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "_Cilk_for statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "очекивано је успостављање или декларација итерације"
@@ -33482,258 +33514,258 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> мора да се јави пре декларације %D, игноришем"
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%> или %<||%>"
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "очекивано је %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<omp_priv%> or function-name"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected function-name %<(%>"
 msgstr "очекиван је идентификатор или %<(%>"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "очекивано је %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE декларисано као нитно-локално после прве употребе"
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "аутоматска променљива %qE не може бити нитно-локална"
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "нитно-локално %qE има непотпун тип"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "vectorlength must be an integer constant"
 msgstr "селектор мора бити целобројна константа у опсегу 0..%wi"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "величина стека мора бити тачан степен двојке"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "селектор мора бити целобројна константа у опсегу 0..%wi"
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma simd%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma%> није дозвољена овде"
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "base of array section must be pointer or array type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or numeral"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "array notations cannot be used with function type"
 msgstr "new се не може применити на функцијиски тип"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 #| msgid "Expected an initialization expression at %C"
 msgid "expected array notation expression"
@@ -33744,7 +33776,7 @@
 msgid "%qD has an incomplete type"
 msgstr "%qD има непотпун тип"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "неисправна употреба израза празног типа"
@@ -33854,7 +33886,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "индекс низа није целобројан"
@@ -33982,7 +34014,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "прослеђивање аргумента %d за %qE као означеног, због прототипа"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT when passing argument to function"
@@ -34015,7 +34047,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -34104,7 +34136,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "не-л-вредносни низ у условном изразу"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
@@ -34142,7 +34174,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "неслагање типова показивача или целобројних у условном изразу"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr ""
@@ -34230,7 +34262,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "претапање из функцијског позива типа %qT у непоклапајући тип %qT"
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "претапање из целобројног у показивач различите величине"
@@ -34405,7 +34437,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "лева страна успостављања може бити кандидат за форматски атрибут"
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "повратни тип може бити кандидат за форматски атрибут"
@@ -34545,7 +34577,7 @@
 msgid "initialization of a flexible array member"
 msgstr "успостављање флексибилног чланског низа"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-низ успостављен широком ниском"
@@ -34594,7 +34626,7 @@
 msgid "invalid initializer"
 msgstr "неисправан успостављач"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "непрозирни векторски типови не могу бити успостављени"
@@ -34741,7 +34773,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ИСО Ц забрањује %<goto *expr;%>"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функција декларисана са %<noreturn%> има наредбу %<return%>"
@@ -34751,7 +34783,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
@@ -34863,17 +34895,17 @@
 msgid "expression statement has incomplete type"
 msgstr "наредба израза има непотпун тип"
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "поређење реалних помоћу == или != није безбедно"
@@ -34926,12 +34958,12 @@
 msgstr "поређење уређености показивача са целобројном нулом"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "поређење уређености показивача са целобројном нулом"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
@@ -34958,91 +34990,91 @@
 msgid "used vector type where scalar is required"
 msgstr "употребљена вредност структурног типа где се захтева скалар"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Копирај одељке низа у непрекидан блок при улазу у процедуру"
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have pointer or array type"
@@ -35053,18 +35085,18 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE има неисправан тип за %<reduction(%s)%>"
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "user defined reduction not found for %qD"
 msgstr "Није нађена дефиниција етикете за %qs"
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE мора бити нитно-локално за %<copyin%>"
@@ -35074,7 +35106,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE није променљива у одредби %qs"
@@ -35084,17 +35116,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE није променљива у одредби %<firstprivate%>"
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE није променљива у одредби %<lastprivate%>"
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -35112,54 +35144,54 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE је предодређено као %qs за %qs"
@@ -35170,36 +35202,36 @@
 msgstr ""
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "прослеђивање %qT као аргумента %<this%> у %q#D одбацује одредбе"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion from %qT to %qT"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -35208,90 +35240,90 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T, %T) <built-in>"
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr "%s %D(%T, %T, %T) <уграђено>"
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T) <built-in>"
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "%s %D(%T, %T) <уграђено>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T) <built-in>"
 msgid "%s%D(%T) <built-in>"
 msgstr "%s %D(%T) <уграђено>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "%s %T <conversion>"
 msgid "%s%T <conversion>"
 msgstr "%s %T <претварање>"
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D <near match>"
 msgid "%s%#D <near match>"
 msgstr "%s %+#D <приближно поклапање>"
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr ""
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr ""
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument deduction/substitution failed:"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "двосмислено претварање из %qT у %qT"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to non-scalar type %qT requested"
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr "захтевано претварање из %qT у нескаларни тип %qT"
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "нема одговарајуће функције за позив %<%D(%A)%>"
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "двосмислен позив препуњене %<%D(%A)%> "
@@ -35298,499 +35330,499 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr "показивач на чланску функцију %E не може бити позван без објекта; покушајте помоћу .* или ->*"
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "нема поклапања за позив %<(%T) (%A)%>"
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "двосмислен позив %<(%T) (%A)%>"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "двосмислено претварање за индекс низа"
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid " (operand types are %qT and %qT)"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, fuzzy, gcc-internal-format
 #| msgid "User operators:\n"
 msgid "ternary %<operator?:%>"
 msgstr "Кориснички оператори:\n"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, fuzzy, gcc-internal-format
 #| msgid "%s for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%s за тернарно %<operator?:%> у %<%E ? %E : %E%>"
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator%s%>"
 msgstr "Лош оператор"
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s за %<operator%s%> у %<%E%s%>"
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator[]%>"
 msgstr "Лош оператор"
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%s за %<operator[]%> у %<%E[%E]%>"
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "%s за %qs у %<%s %E%>"
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s за %<operator%s%> у %<%E %s %E%>"
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s за %<operator%s%> у %<%s%E%>"
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ИСО Ц++ забрањује изостављање средњег члана израза ?:"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "неслагање набројивих у условном изразу: %qT пр. %qT"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "неслагање набројивих у условном изразу: %qT пр. %qT"
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "набројиви и ненабројиви тип у условном изразу"
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%> није декларисано за постфиксно %qs, покушавам смену префиксним оператором"
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, fuzzy, gcc-internal-format
 #| msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "%<%D(int)%> није декларисано за постфиксно %qs, покушавам смену префиксним оператором"
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "поређење између %q#T и %q#T"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, fuzzy, gcc-internal-format
 #| msgid "no corresponding deallocation function for `%D'"
 msgid "non-placement deallocation function %q+D"
 msgstr "нема одговарајуће функције за ослобађање меморије за ‘%D’"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr ""
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, fuzzy, gcc-internal-format
 #| msgid "no corresponding deallocation function for `%D'"
 msgid "no corresponding deallocation function for %qD"
 msgstr "нема одговарајуће функције за ослобађање меморије за ‘%D’"
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "нема погодног %<operator %s%> за %qT"
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr "%q+#D је приватно"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr "%q+#D је заштићено"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr "%q+#D није приступно"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr "у овом контексту"
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "прослеђивање NULL непоказивачком аргументу %P од %qD"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "претварање у непоказивачки тип %qT из NULL"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "претварање NULL у непоказивачки тип"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "too many braces around initializer for %qT"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "converting to %qT from %qT"
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr "претварање у %qT из %qT"
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "неисправно претварање из %qT у %qT"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  успостављање аргумента %P од %qD"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "неисправно претварање из %qT у %qT"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, fuzzy, gcc-internal-format
 #| msgid "  initializing argument %P of %qD"
 msgid "  initializing argument %P of %q+D"
 msgstr "  успостављање аргумента %P од %qD"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind rvalue %qE to %qT"
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "не може се повезати д-вредност %qE са %qT"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "неисправно успостављање неконстантног упућивача типа %qT привременим типа %qT"
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "прослеђивање %qT као аргумента %<this%> у %q#D одбацује одредбе"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "не може се повезати битско поље %qE са %qT"
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "не може се повезати паковано поље %qE са %qT"
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "не може се повезати д-вредност %qE са %qT"
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "не могу се проследити објекти не-ПОД типа %q#T кроз %<...%>; позив ће искочити при извршавању"
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "не могу се примати објекти не-ПОД типа %q#T кроз %<...%>; позив ће искочити при извршавању"
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, fuzzy, gcc-internal-format
 #| msgid "the default argument for parameter %d of %qD has not yet been parsed"
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "подразумевани аргумент за параметер %d у %qD још увек није рашчлањен"
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "прослеђивање %qT као аргумента %<this%> у %q#D одбацује одредбе"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  у позиву %qD"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT није приступна основа од %qT"
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "deducing %qT as %qT"
 msgstr "декларација %qD као %s"
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, fuzzy, gcc-internal-format
 #| msgid "  in call to %qD"
 msgid "  in call to %q+D"
 msgstr "  у позиву %qD"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr "не могу да нађем поље class$ у јаванском типу сучеља %qT"
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "конструктор не може бити виртуелан"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "позив не-функције %qD"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "нема одговарајуће функције за позив %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr "нема одговарајуће функције за позив %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "нема одговарајуће функције за позив %<%D(%A)%>"
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "двосмислен позив препуњене %<%s(%A)%>"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT нема нестатички члански податак по имену %qD"
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "чланска функција %qD не може се позвати без објекта"
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "прослеђивање %qT бира %qT пре него %qT"
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "бирам %qD пре него %qD"
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  зато што је редослед претварања за аргумент бољи"
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "наведен подразумевани аргумент у експлицитној специјализацији"
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 1: %q+#F"
 msgstr "кандидат је: %+#D"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 2: %q+#F"
 msgstr "кандидат је: %+#D"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ИСО Ц++ каже да је ово двосмислено, чак иако је најгоре претварање првог боље од најгорег претварања другог:"
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %qT to %qT"
 msgstr "не могу да претворим %qE у %qT"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "неисправно успостављање упућивача типа %qT изразом типа %qT"
@@ -35955,7 +35987,7 @@
 msgid "  by %q+D"
 msgstr "  овим %q+D"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D није исправно; анонимна унија може имати само нестатичке чланске податке"
@@ -35966,7 +35998,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D није исправно; анонимна унија може имати само нестатичке чланске податке"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr "приватни члан %q+#D у анонимној унији"
@@ -35977,7 +36009,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "приватни члан %q+#D у анонимној унији"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr "заштићени члан %q+#D у анонимној унији"
@@ -36112,74 +36144,84 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  али не потискује %<operator=(const %T&)%>"
 
-#: cp/class.c:4538
+#: cp/class.c:4300
 #, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, gcc-internal-format
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr ""
+
+#: cp/class.c:4557
+#, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "успостављач наведен за невиртуелни метод %q+D"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q+T is not literal because:"
 msgstr "%q#T није класа"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %q+D"
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "неисправна употреба нестатичког чланског податка %q+D"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %q+D"
 msgid "  non-static data member %q+D has volatile type"
 msgstr "неисправна употреба нестатичког чланског податка %q+D"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr "нестатички упућивач %q+#D у класи без конструктора"
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr "нестатчики константни члан %q+#D у класи без конструктора"
@@ -36186,105 +36228,105 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "непосредна основа %qT није доступна у %qT услед двосмислености"
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "виртуелна основа %qT није доступна у %qT услед двосмислености"
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr "помак за %q+D можда не поштује АБИ и може се изменити у будућим верзијама ГЦЦа"
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "поновна дефиниција %q#T"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T има виртуелне функције, али невиртуелни деструктор"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "класа %qT нема поље по имену %qD"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "тип %qs има виртуелне чланске функције"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "у покушају да довршим структуру, али избачен услед претходних грешака у рашчлањивању"
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "језичка ниска %<\"%E\"%> није препозната"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "не могу да разрешим препуњену функцију %qD на основу претварања у тип %qT"
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "нема поклапања за претварање функције %qD у тип %q#T"
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "двосмислено претварање препуњене функције %qD у тип %q#T"
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "претпостављам показивач на члан %qD"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(показивач на члан може бити формиран само помоћу %<&%E%>)"
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "нема довољно података о типу"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "не може се претворити %qE из типа %qT у тип %qT"
@@ -36294,12 +36336,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "декларација %q#D"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr "мења значење за %qD са %q+#D"
@@ -36343,46 +36385,46 @@
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "%Jосновна класа %q#T треба да се експлицитно успостави у копи-конструктору"
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr "%q+D је обично нестатичка функција"
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function"
 msgstr "позив не-функције %qD"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "expression %qE does not designate a constexpr function"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-constexpr function %qD"
@@ -36389,244 +36431,244 @@
 msgstr "позив не-функције %qD"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD used before its definition"
 msgstr "%q+D је употребљено без прототипа пре дефиниције"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qs has circular dependency"
 msgid "call has circular dependency"
 msgstr "протокол %qs има кружну зависност"
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d (употребите -ftemplate-depth-NN да повећате дубину) извођења %qD"
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%q+E is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "негативан десни помак"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript out of bound"
 msgstr "индекс низа није целобројан"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "negative array subscript"
 msgstr "Очекиван је индекс низа код %C"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qE is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, fuzzy, gcc-internal-format
 #| msgid "array used as initializer"
 msgid "%qD used in its own initializer"
 msgstr "низ употребљен као успостављач"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#D is not const"
 msgstr "%q#T није класа"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D је приватно"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD није декларисано у овом досегу"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "израз у декларатору new мора имати интегрални или набројиви тип"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of %qE is not a constant-expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "набројиви и ненабројиви тип у условном изразу"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant-expression"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "statement is not a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "очекиван је израз"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "pointer comparison expression is not a constant expression"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant-expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -36699,7 +36741,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr ""
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr ""
@@ -36744,7 +36786,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "претапање %qT у %qT не разрешава показивач"
@@ -36754,323 +36796,323 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "претварање из %q#T у %q#T"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T употребљено где је %qT очекивано"
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "не могу да претворим %qE у %qT"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "%q#T употребљено где је очекивана вредност у покретном зарезу"
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "захтевано претварање из %qT у нескаларни тип %qT"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "псеудодеструктор се не позива"
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "претварање у непотпун тип"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to incomplete type %qT "
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "неисправна примена %qs на непотпун тип %qT"
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of type %qT"
 msgstr "претварање у непотпун тип"
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "second operand of conditional expression has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "third operand of conditional expression has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right operand of comma operator has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of comma operator has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, fuzzy, gcc-internal-format
 #| msgid "statement with no effect"
 msgid "statement has no effect"
 msgstr "наредба без ефекта"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "for increment expression has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "претварање NULL у непоказивачки тип"
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "нисам могао да претворим шаблонски аргумент %qE у %qT"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "двосмислено подразумевано претварање типа из %qT"
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  могућа претварања укључују %qD и %qD"
@@ -37524,121 +37566,121 @@
 msgid "template parameters do not match template %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, fuzzy, gcc-internal-format
 #| msgid "%Jan anonymous union cannot have function members"
 msgid "an anonymous struct cannot have function members"
 msgstr "%Jанонимна унија не може имати чланске функције"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "%Jan anonymous union cannot have function members"
 msgid "an anonymous union cannot have function members"
 msgstr "%Jанонимна унија не може имати чланске функције"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "члан %q+#D са конструктором није дозвољен у анонимној скупини"
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "члан %q+#D са деструктором није дозвољен у анонимној скупини"
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "члан %q+#D са оператором копирања-доделе није дозвољен у анонимној скупини"
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "атрибут за %q+#T мора пратити кључну реч %qs"
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "вишеструки типови у једној декларацији"
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "поновљена декларација Ц++ уграђеног типа %qT"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "недостаје име типа у наредби typedef"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ИСО Ц++ забрањује анонимне структуре"
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> може бити наведено само унутар класе"
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> може бити наведено само за конструкторе"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "складишна класа може бити наведена само за објекте и функције"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "декларација typedef није исправна у декларацији параметра"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "%<register%> in file-scope empty declaration"
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<register%> у празној декларацији у досегу датотеке"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
@@ -37645,137 +37687,137 @@
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "дефиниција типа %qD је успостављена (употребите __typeof__)"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "декларација %q#D има %<extern%> и ипак је успостављена"
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "дефиниција %q+D означена као %<dllimport%>"
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "неисправна декларација чланског шаблона %qD"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ИСО Ц++ не дозвољава да %<%T::%D%> буде дефинисано као %<%T::%D%>"
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "удвостручено успостављање %qD"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, fuzzy, gcc-internal-format
 #| msgid "%qE declared %<threadprivate%> after first use"
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr "%qE декларисано као нитно-локално после прве употребе"
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларација %q#D изван класе није дефиниција"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "променљива %q#D има успостављач али је непотпуног типа"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "декларација %q#D има %<extern%> и ипак је успостављена"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "скупина %q#D има непотпун тип и не може се дефинисати"
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD декларисано као упућивач али није успостављено"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "нетривијални утврђени успостављачи нису подржани"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "успостављач не одређује величину %qD"
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "недостаје величина низа у %qD"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "низ %qD нулте величине"
@@ -37783,892 +37825,892 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "величина складишта за %q+D није позната"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "величина складишта за %q+D није константна"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "извините: семантика статичких података уткане функције %q+#D је погрешна (доћи ће до вишеструких копија)"
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  можете ово заобићи уклањањем успостављача"
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "неуспостављена константа %qD"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "регистарска променљива %qD употребљена у угњежденој функцији"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "тип %qs има кориснички дефинисан конструктор"
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "неисправан тип %qT као успостављач за вектор типа %qT"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "успостављач за %qT мора бити у витичастим заградама"
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT нема нестатички члански податак по имену %qD"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "неисправан успостављач"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "превише успостављача за %qT"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "витичасте заграде око скаларног успостављача за тип %qT"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ИСО Ц 90 забрањује сложене дословне ниске"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD има непотпун тип"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "скаларни објекат %qD захтева један елемент у успостављачу"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be initialized by constructor, not by %<{...}%>"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "%qD мора бити успостављен конструктором, не помоћу %<{...}%>"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "низ %qD успостављен заграђеном константном ниском %qE"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "успостављач неисправан за статички члан са конструктором"
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(потребно је успостављање изван класе)"
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "параметар %qD је успостављен"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "заклањање претходне декларације типа за %q#D"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr ""
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "definition of static data member %q+D of dllimport'd class"
 msgid "non-static data member %qD has Java class type"
 msgstr "дефиниција статичког чланског податка %q+D dllimport класе"
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "функција %q#D успостављена као променљива"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "успостављач не одређује величину %qD"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "недостаје величина низа у %qD"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "низ %qD нулте величине"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> variable"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларисано са одредницом изузетака"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "дефиниција %qD није у именском простору који обухвата %qT"
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статичка чланска функција %q#D декларисана са одредбама типа"
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "дефиниција експлицитне специјализације %qD у декларацији пријатеља"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "неисправна употреба ид. шаблона %qD у декларацији примарног шаблона"
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "подразумевани аргументи нису дозвољени у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> није дозвољено у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> није дозвољено у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> се не може декларисати као шаблон"
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> се не може декларисати као уткано"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "%<::main%> се не може декларисати као уткано"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> се не може декларисати као статичко"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "шаблон са Ц повезивошћу"
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "неисправан аргумент опције %qs"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> мора враћати %<int%>"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "дефиниција имплицитно декларисаног %qD"
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "дефиниција имплицитно декларисаног %qD"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q+#D explicitly defaulted here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "чланска функција %q#D није декларисана у класи %qT"
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ИСО Ц++ забрањује успостављање чланске константе %qD неинтегралног типа %qT"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "величина низа %qD има неинтегрални тип %qT"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "величина низа има неинтегрални тип %qT"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "негативна величина низа %qD"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "негативна величина низа"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ИСО Ц++ забрањује низ нулте величине %qD"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ИСО Ц++ забрањује низ нулте величине"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array %qD"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ИСО Ц++ забрањује низ променљиве величине %qD"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ИСО Ц++ забрањује низ променљиве величине"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "преливање у димензији низа"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "декларација %qs као низа празних"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларација %qD као вишедимензионог низа мора имати границе за све димензије осим прве"
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "вишедимензиони низ мора имати границе за све димензије осим прве"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "навод повратног типа за конструктор није исправан"
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "навод повратног типа за деструктор није исправан"
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "наведен повратни тип за %<operator %T%>"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "неименована променљива или поље декларисано празним"
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "променљива или поље декларисано празним"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "неисправна употреба одређеног имена %<::%D%>"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "неисправна употреба одређеног имена %<%T::%D%>"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "неисправна употреба одређеног имена %<%D::%D%>"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or a namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "декларација %qD као не-члана"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "недостаје ид. декларатора; користи се резервисана реч %qD"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "дефиниција функције не декларише параметре"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "декларација %qD као %s"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "ид. шаблона не може да се јави у декларацији употребе"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "два или више типова података у декларацији %qs"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "сукобљени наводиоци у декларацији %qs"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ИСО Ц не подржава да обичан %<complex%> значи %<double complex%>"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ИСО Ц++ забрањује декларацију %qs без типа"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs није подржано овим циљем"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ИСО Ц++ не подржава %<long long%>"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> или %<unsigned%> неисправни за %qs"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> и %<unsigned%> наведени заједно за %qs"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> неисправно за %qs"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> неисправно за %qs"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> неисправно за %qs"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> или %<short%> неисправни за %qs"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> or %<short%> invalid for %qs"
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%> или %<short%> неисправни за %qs"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> или %<short%> наведено уз char за %qs"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> и %<short%> наведени заједно за %qs"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> or %<short%> invalid for %qs"
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<long%> или %<short%> неисправни за %qs"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed или unsigned употребљени неисправно за %qs"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex неисправно за %qs"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr "члан %qD не може бити декларисан и као виртуелни и као статички"
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "декларација typedef није исправна у декларацији параметра"
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "virtual изван декларације класе"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "вишеструке складишне класе у декларацији %qs"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "складишна класа наведена за %qs"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "декларација %qs на највишем нивоу наводи %<auto%>"
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs досега функције имплицитно аутоматска и декларасина као %<__thread%>"
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "наводиоци складишне класе нису исправни у декларацијама пријатељских функција"
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs декларисано као функција која враћа функцију"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs декларисано као функција која враћа низ"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
@@ -38675,276 +38717,276 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "конструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "конструктори не могу бити кн-одређени"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr "конструктор не може бити виртуелан"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "декларација пријатеља није у дефиницији класе"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "не може се дефинисати пријатељска функција %qs у дефиницији локалне класе"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструктори не могу имати параметре"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "не може се декларисати показивач на члан %q#T"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "не може се декларисати битско поље %qD са функцијским типом"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "ид. шаблона %qD употребљен као декларатор"
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "чланске функције су имплицитно пријатељи својих класа"
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "сувишна одредба %<%T::%> на члану %qs"
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "не може се дефинисати чланска функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "не може се декларисати функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "не може се декларисати члан %<%T::%s%> унутар %qT"
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "члански податак %qD не може бити члански шаблон"
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "величина низа %qs је превелика"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "члански податак не може имати променљиво измењив тип %qT"
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметар не може имати променљиво измењив тип %qT"
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual изван декларације класе"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> у празној декларацији"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "само декларације конструктора могу имати %<explicit%>"
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "не-објектни члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "статичко %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "константно %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "дефиниција типа %q+D декларисана као %<inline%>"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jиме за дефиницију типа не може бити угњеждени-именски-наводилац"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ИСО Ц++ забрањује угњеждени тип %qD истог имена као и обухватајућа класа"
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr "одредбе типа наведене уз декларацију пријатељске класе"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> наведено уз декларацију пријатељске класе"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend class %T::%D%>"
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend %#T%>"
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "покушај да се класа %qT учини пријатељем глобалног досега"
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "неисправне одредбе уз тип не-чланске функције"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "апстрактни декларатор %qT употребљен као декларација"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> се не може употребити у овом контексту"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared %<auto%>"
@@ -38951,226 +38993,226 @@
 msgstr "статички члан %qD декларисан као %<register%>"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "неисправна употреба %<::%>"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "декларација Ц функције %q#D коси се са"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "функција %qD декларисана виртуелном унутар уније"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr "%qD не може бити декларисана виртуелном, јер је увек статичка"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларација %qD као члана %qT"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "Конструктор не може бити %s"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "специјализација имплицитно декларисане посебне чланске функције"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "променљива или поље декларисано празним"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "поље %qD има непотпун тип"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "име %qT има непотпун тип"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE није ни функција ни чланска функција; не може се декларисати пријатељем"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "constexpr static data member %qD must have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "складишна класа %<auto%> неисправна за функцију %qs"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "складишна класа %<register%> неисправна за функцију %qs"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "навод asm није дозвољен на дефиницији функције"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr "%<static%> неисправно наведено за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "наводилац %<inline%> није исправан за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуелна не-класна функција %qs"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, fuzzy, gcc-internal-format
 #| msgid "No variable %qs defined in class %qs"
 msgid "%qs defined in a non-class scope"
 msgstr "Променљива %qs није дефинисана у класи %qs"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD није декларисано у овом досегу"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "не може се декларисати статичка повезивост за чланску функцију %qD"
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "не може се декларисати статичка функција унутар друге функције"
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> не може бити употребљено при дефинисању (насупрот декларисања) статичког чланског податка"
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "не може се експлицитно декларисати спољашња повезивост за члан %q#D"
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "декларација %q#D изван класе није дефиниција"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs успостављено и декларисано као %<extern%>"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs има и %<extern%> и успостављач"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has Java class type"
 msgstr "параметар %q+D има непотпун тип"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "параметар %qD неисправно декларише тип метода"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметар %qD укључује %s у низ непознатих граница %qT"
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
@@ -39191,72 +39233,72 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "неисправан конструктор; вероватно сте мислили %<%T (const %T&)%>"
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD не може бити декларисано статичко"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD мора бити или нестатичка чланска функција или не-чланска функција"
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD мора имати аргумент класног или набројивог типа"
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to void will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a base class will never use a type conversion operator"
@@ -39263,109 +39305,109 @@
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ИСО Ц++ забрањује препуњавање оператора ?:"
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не може имати променљив број аргумената"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr "постфиксно %qD мора узимати %<int%> као аргумент"
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr "постфиксно %qD мора узимати %<int%> као други аргумент"
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr "%qD мора узимати ниједан или један аргумент"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr "%qD мора узимати један или два аргумента"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксно %qD треба да враћа %qT"
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксно %qD треба да враћа %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr "%qD мора узимати %<void%>"
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr "%qD мора узимати тачно један аргумент"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "%qD мора узимати тачно два аргумента"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "кориснички дефинисано %qD увек израчунава оба аргумента"
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD треба да враћа по вредност"
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "двосмислена специјализација шаблона %qD за %q+D"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "употреба typedef-имена %qD после %qs"
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D има претходну декларацију овде"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT се помиње као %qs"
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "%q+T има претходну декларацију овде"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT се помиње као набрајање"
@@ -39377,89 +39419,89 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "потребан шаблонски аргумент за %<%s %T%>"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD има исто име као и класа у којој је декларисано"
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "употреба набрајања %q#D без претходне декларације"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "поновљена декларација %qT као не-шаблона"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "претходна декларација %q+D"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "неисправна изведена унија %qT"
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr "јаванска класа %qT не може имати вишеструке основе"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr "јаванска класа %qT не може имати виртуелне основе"
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "тип основе %qT није класа или структура"
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "недефинисан рекурзивни тип %qT"
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "неисправан удвостручен тип основе %qT"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jпретходна дефиниција је овде"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr ""
@@ -39468,94 +39510,94 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ниједан интегрални тип не може представљати све вредности набрајача за %qT"
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "преливање у вредностима набрајача код %qD"
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr ""
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, fuzzy, gcc-internal-format
 #| msgid "return type is an incomplete type"
 msgid "return type has Java class type %q#T"
 msgstr "повратни тип је непотпун тип"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> треба да враћа упућивач на %<*this%>"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "нема претходне декларације за %q+D"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid function declaration"
 msgstr "неисправна декларација чланске функције"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "параметар %qD декларисан празним"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "повратни типови функција нису сагласни услед %<volatile%>"
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "parameter %q+D set but not used"
 msgstr "етикета %q+D дефинисана али неупотребљена"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "неисправна декларација чланске функције"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD је већ дефинисано у класи %qT"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -39596,7 +39638,7 @@
 msgid "deleting %qT is undefined"
 msgstr "брисање %qT није дефинисано"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "декларација шаблона %q#D"
@@ -39620,7 +39662,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "деструктор %qD декларисан као члански шаблон"
@@ -39715,27 +39757,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "битско поље %qD неинтегралног типа"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "анонимна структура није унутар именованог типа"
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "анонимне скупине у досегу именског простора морају бити статичке"
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "анонимна унија без чланова"
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> мора враћати тип %qT"
@@ -39744,48 +39786,48 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, fuzzy, gcc-internal-format
 #| msgid "second parameter of %<va_start%> not last named argument"
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "други параметар за %<va_start%> није последњи именовани аргумент"
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> узима тип %<size_t%> (%qT) као први параметар"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> мора враћати тип %qT"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> узима тип %<size_t%> (%qT) као први параметар"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT декларисано са већом видљивошћу од типа његовог поља %qD"
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT декларисано са већом видљивошћу од своје основе %qT"
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using anonymous type, is used but never defined"
@@ -39795,50 +39837,50 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D не упућује на неодређени тип, тако да се не користи за повезивост"
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "претходна декларација %q+#D са повезивошћу %qL"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "уткана функција %q+D употребљена али недефинисана"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "недостаје подразумевани аргумент за параметар %P од %q+#D"
@@ -39845,12 +39887,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
@@ -40464,43 +40506,43 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни класи посебан оператор delete неће бити позван, чак и ако су декларисани када се класа дефинише."
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "успостављач се прерано окончава"
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr "у успостављачу се не могу успостављати вишедимензиони низови"
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "непозната величина низа за delete"
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "откривен могућ проблем у позиву оператора delete:"
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни класи посебан оператор delete неће бити позван, чак и ако су декларисани када се класа дефинише."
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
@@ -40634,18 +40676,18 @@
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "запетљано име за %qD биће измењено у будућим верзијама ГЦЦа"
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
@@ -41085,7 +41127,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr ""
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -41113,7 +41155,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "захтев за члан %qD у некласном типу %qT"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -41189,7 +41231,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(можда недостаје тачка-зарез после дефиниције %qT)"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT није шаблон"
@@ -41216,7 +41258,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "претапање у тип који није ни интегрални ни набројиви не може се јавити у изразу константе"
@@ -41513,7 +41555,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
@@ -41706,7 +41748,7 @@
 msgid "capture of non-variable %qD "
 msgstr "увећање само-за-читање променљиве %qD"
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q+#D declared here"
@@ -41772,7 +41814,7 @@
 msgid "compound-statement in constexpr function"
 msgstr "Откривај чисте и константне функције"
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
@@ -41805,7 +41847,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
@@ -41838,13 +41880,13 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ИСО Ц++ забрањује рачунско goto"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "сувишно %<;%>"
@@ -41892,7 +41934,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "дефиниција класе не може бити декларисана пријатељем"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "шаблони не могу бити виртуелни"
@@ -41993,13 +42035,13 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "кључна реч %<export%> није имплементирана, игнорише се"
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
@@ -42017,7 +42059,7 @@
 msgid "expected template-id"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -42103,226 +42145,226 @@
 msgid "expected type specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ИСО Ц забрањује унапредне декларације параметара"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "Очекиван је тип израза"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Очекивано је име"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "декларација ништа не декларише"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "атрибут се игнорише за класе без примерака"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "атрибут се игнорише при предоченом-наводиоцу-типа који није унапредна декларација"
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD није шаблон функције"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a namespace-name"
 msgid "%qD is not an enumerator-name"
 msgstr "%qD није име именског простора"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Укључи аутоматско извођење шаблона"
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD in %qD which does not enclose %qD"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "декларација %qD у %qD која не обухвата %qD"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "декларација %qD у %qD која не обухвата %qD"
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "вишеструке дефиниције %q#T"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD није име именског простора"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<#pragma%> није дозвољена овде"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "ид. шаблона не може да се јави у декларацији употребе"
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: дефиниција функције није претворена\n"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "навод asm није дозвољен на дефиницији функције"
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "успостављач дат за функцију"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "функција %q+D поново декларисана као уткана"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "граница низа није целобројна константа"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%D%> није тип"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "неисправна употреба конструктора као шаблона"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "употреба %<%T::%D%> уместо %<%T::%D%> за именовање конструктора у одређеном имену"
@@ -42331,7 +42373,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "invalid declarator"
@@ -42339,325 +42381,325 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Неисправна декларација"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD је именски простор"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "неочекиван операнд"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of %<auto%>"
 msgstr "неисправна употреба %<::%>"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr "превазиђена употреба подразумеваног аргумента као параметра не-функције"
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "подразумевани аргументи су дозвољени само за параметре функција"
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "Неочекивано смеће после декларације функције код %C"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "не могу да нађем датотеку за класу %s"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "неисправно име класе у декларацији %qD"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification ignored"
 msgid "extra qualification not allowed"
 msgstr "сувишне одредбе се игноришу"
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "експлицитној специјализацији мора претходити %<template <>%>"
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "function template %qD redeclared as a class template"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr "претходна дефиниција %q+#T"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, fuzzy, gcc-internal-format
 #| msgid "a class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "при декларацији пријатеља мора бити употребљена кључна реч class"
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<;%> at end of member declaration"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr ""
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "кључна реч %<typename%> није дозвољена у овом контексту (основна класа је имплицитно тип)"
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "очекиван је идентификатор или %<(%>"
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "неисправна поновљена декларација %q+D"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "премало листа параметара шаблона"
@@ -42666,592 +42708,592 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "превише листа шаблонских параметера"
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именоване повратне вредности нису више подржане"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "неисправна декларација чланског шаблона у локалној класи"
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон са Ц повезивошћу"
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "неисправан навод основне класе"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "декларација шаблона %qs"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "експлицитна специјализација у не-именскопросторном досегу %qD"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> треба да је %<> >%> унутар угњеждене листе шаблонских аргумената"
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "сувишно %<>>%>, користите %<>%> за затварање листе шаблонских аргумената"
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "неисправна употреба %qD у одредници повезивости"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> пре %qD"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ИСО Ц++ не подржава %<long long%>"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "и %<short%> и %<char%> у наводиоцима декларације"
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "удвостручено %qE"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "удвостручено %qs"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "ознака %qs употребљена при именовању %q#T"
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D претходно декларисано овде"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD поново декларисано са другачијим приступом"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (као разјашњење двосмислености) дозвољено је само унутар шаблона"
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "датотека се завршава подразумеваним аргументом"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "конструкција %<@%D%> објективног Ц++а на погрешном месту"
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> мора навести тип као аргумент"
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "неисправно име селектора објективног Ц++а"
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Очекивана је декларација класе или сучеља"
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "очекиван је идентификатор после %<@protocol%>"
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "атрибут %qE се игнорише за %qE"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected positive integer expression"
 msgstr "очекиван је целобројни израз"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "неисправан успостављач"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 #| msgid "Initialization at %C is not allowed in a PURE procedure"
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "Успостављање код %C није дозвољено у чистој процедури"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qD should not be reduction"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough collapsed for loops"
 msgstr "нема довољно података о типу"
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "неисправан успостављач"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "очекиван је израз"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%> или %<||%>"
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "смеће на крају %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "неисправна ограничења за операнд"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "Очекивано је име променљиве код %C"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "шаблони не могу бити виртуелни"
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "члански податак %qD не може бити члански шаблон"
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "неисправна декларација чланског шаблона %qD"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "експлицитна специјализација у не-именскопросторном досегу %qD"
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "обухватајући шаблони класа не бивају експлицитно специјализовани"
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "специјализација %qD у различитом именском простору"
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "специјализација %qD у различитом именском простору"
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr "  из дефиниције %q+#D"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "експлицитно извођење %qD у именском простору %qD (који не обухвата простор %qD)"
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "име класе заклања шаблонски шаблонски параметар %qD"
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of alias template %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "специјализација %qT после извођења"
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "специјализација %q#T у различитом именском простору"
@@ -43258,72 +43300,72 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "специјализација %qT после извођења %qT"
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "делимична специјализација шаблона функције %qD није дозвољена"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "специјализација %qD после извођења"
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid "candidate is: %#D"
 msgstr "кандидат је: %+#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
 msgstr "%s %+#D"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD није шаблон функције"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a variable template"
 msgstr "%qD није шаблон"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "ид. шаблона %qD за %q+D не одговара ниједној декларацији шаблона"
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "двосмислена специјализација шаблона %qD за %q+D"
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %D (should be %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -43330,59 +43372,59 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "ид. шаблона %qD у декларацији примарног шаблона"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "листа шаблонских параметара употребљена у експлицитном извођењу"
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "дефиниција дата за експлицитно извођење"
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "превише листа шаблонских параметара у декларацији %qD"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "премало листа шаблонских параметара у декларацији %qD"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "експлицитна специјализација %qD мора бити уведена помоћу %<template <>%>"
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "делимична специјализација шаблона функције %qD није дозвољена"
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "делимична специјализација шаблона функције %qD није дозвољена"
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "наведен подразумевани аргумент у експлицитној специјализацији"
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD није шаблонска функција"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "%qD није декларисано у %qD"
@@ -43395,95 +43437,95 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "специјализација имплицитно декларисане посебне чланске функције"
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "нема чланске функције %qD декларисане у %qT"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, fuzzy, gcc-internal-format
 #| msgid "<anonymous>"
 msgid "        <anonymous>"
 msgstr "<анонимно>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "декларација %q+#D"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr " заклања шаблонски параметар %q+#D"
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT of template argument %qE depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -43493,13 +43535,13 @@
 msgstr[2] "тип %qT шаблонског аргумента %qE зависи од шаблонских параметара"
 msgstr[3] "тип %qT шаблонског аргумента %qE зависи од шаблонских параметара"
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "специјализација %qD после извођења"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нема подразумеваног аргумента за %qD"
@@ -43507,47 +43549,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "подразумевани аргументи нису дозвољени у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr "подразумевани аргументи нису дозвољени у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "подразумевани аргумент за параметар типа %qT има тип %qT"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "шаблонска класа без имена"
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -43558,59 +43600,59 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "неисправна декларација шаблона %qD"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "шаблонска дефиниција нешаблонског %q#D"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "очекивах %d нивоа шаблонских параметара за %q#D, добих %d"
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "добих %d шаблонских параметара за %q#D"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "добих %d шаблонских параметара за %q#T"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  а потребно је %d"
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use template<> for an explicit specialization"
 msgstr "обухватајући шаблони класа не бивају експлицитно специјализовани"
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT није шаблонски тип"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "наводиоци шаблона нису задати у декларацији %qD"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -43620,7 +43662,7 @@
 msgstr[2] "%qD употребљено без параметара шаблона"
 msgstr[3] "%qD употребљено без параметара шаблона"
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %q+D used %d template parameter"
@@ -43630,12 +43672,12 @@
 msgstr[2] "претходном декларацијом %q+#D овде"
 msgstr[3] "претходном декларацијом %q+#D овде"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "шаблонски параметар %q+#D"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "поново декларисано овде као %q#D"
@@ -43644,114 +43686,114 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J  првобитна дефиниција налази се овде"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер објекат %qD нема спољашњу повезивост"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(показивач на члан може бити формиран само помоћу %<&%E%>)"
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "добих %d шаблонских параметара за %q#D"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "  mismatched types %qT and %qT"
 msgstr "поређење између типова %q#T и %q#T"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs није исправно за %qs"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -43760,186 +43802,186 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT је двосмислена основа за %qT"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "тип %qT није изведен из типа %qT"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qD"
 msgstr "аргумент типа %qT не поклапа се са %qT"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "  could not resolve address from overloaded function %qE"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер се константне ниске не могу користити у овом контексту"
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, fuzzy, gcc-internal-format
 #| msgid "template argument for %qD uses local type %qT"
 msgid "in template argument for type %qT "
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD није исправан шаблонски аргумент јер је %qD променљива, а не адреса неке променљиве"
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD није исправан шаблонски аргумент јер је %qD променљива, а не адреса неке променљиве"
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер се коси са кн-одредбом"
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није л-вредност"
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није константан израз"
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер објекат %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер објекат %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "покушајте са %qE уместо тога"
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је типа %qT"
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "стандардна претварања нису дозвољена у овом контексту"
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "примењивање атрибута на шаблонске параметре није имплементирано"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "име класе заклања шаблонски шаблонски параметар %qD"
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "неисправна употреба деструктора %qD као типа"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "да упутите на тип шаблонског параметра, употребите %<typename %E%>"
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "неслагање типа/вредности код аргумента %d у листи шаблонских параметара за %qD"
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  очекивах константу типа %qT, добих %qT"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  очекивах шаблон класе, добих %qE"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  очекивах тип, добих %qE"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr " очекивах тип, добих %qT"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  очекивах шаблон класе, добих %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
@@ -43947,81 +43989,81 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in nontype parameter pack"
 msgstr "неслагање типова у условном изразу"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr "нисам могао да претворим шаблонски аргумент %qE у %qT"
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "дат за %q+D"
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD није шаблон функције"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "нешаблонски тип %qT употребљен као шаблон"
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "за декларацију шаблона %q+D"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d (употребите -ftemplate-depth-NN да повећате дубину) извођења %qD"
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %D"
@@ -44040,283 +44082,283 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "променљива %qD има функцијски тип"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "неисправан тип параметра %qT"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "у декларацији %q+D"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функција враћа низ"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функција враћа функцију"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "стварање показивача на чланску функцију некласног типа %qT"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "обликовање упућивача на празно"
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "стварање показивача на члан празног типа"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "стварање низа типа %qT"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT није тип класе, структуре, нити уније"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT се разрешава до %qT, што није набројиви тип"
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT се разрешава до %qT, што није класни тип"
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависно име %qE рашчлањује се као не-тип, али извођење производи тип"
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "ставите %<typename %E%> ако мислите на тип"
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "употреба неисправног поља %qD"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "неисправна употреба израза празног типа"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> за аргументе.)"
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> није тип"
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D declared here, later in the translation unit"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD није ни класа ни именски простор"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr "%qT јесте/користи анонимни тип"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT је променљиво измењив тип"
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  покушај извођења %qD"
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "експлицитно извођење %q#D"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "удвостручено експлицитно извођење %q#D"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %<extern%> на експлицитним извођењима"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "складишна класа %qD примењена на извођење шаблона"
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "експлицитно извођење %q#T пре дефиниције шаблона"
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %qE на експлицитним извођењима"
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "удвостручено експлицитно извођење %q#T"
@@ -44328,68 +44370,68 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "експлицитно извођење %qD али дефиниција није доступна"
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d извођења %q+D, могуће услед стварања виртуелних табела (употребите -ftemplate-depth-NN да повећате максимум)"
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T није исправан тип за шаблонски константан параметар"
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Неисправна декларација метода, неопходан је повратни тип"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "не могу да емулирам %qs"
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
@@ -44639,71 +44681,71 @@
 msgid "invalid base-class specification"
 msgstr "неисправан навод основне класе"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "заштићени члан %q+#D у анонимној унији"
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
 msgstr "%qD није тип"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "употреба %<auto%> променљиве из обухватајуће функције"
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "употреба параметра из обухватајуће вункције"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "шаблонски параметар %qD типа %qT није дозвољен у интегралном константном изразу јер није интегралног или набројивог типа"
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "употреба именског простора %qD као израза"
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "употреба шаблона класе %qT као израза"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "захтев за члан %qD двосмислен је у вишеструком снопу наслеђивања"
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "тип за %qE није познат"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
@@ -44710,215 +44752,215 @@
 msgstr "%qT није шаблонски тип"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "не може се применити %<offsetof%> на деструктор %<~%T%>"
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "%qE има неисправан тип за %<reduction%>"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %<firstprivate%>"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qE није променљива у одредби %<firstprivate%>"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %<lastprivate%>"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qE није променљива у одредби %<lastprivate%>"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_teams%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "%<device%> id must be integral"
 msgstr "%<continue%> мора бити у оквиру петље"
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr "%qE има упућивачки тип за %qs"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE is not file, namespace or block scope variable"
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qE није датотека, именски простор нити променљива блоковског досега"
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE has incomplete type"
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "нитно-локално %qE има непотпун тип"
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %s"
 msgstr "Тврдња КРИС-порта није прошла: "
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "нестатичка декларација %q+D прати статичку декларацију"
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "argument to decltype must be an expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
@@ -44935,131 +44977,131 @@
 msgid "lambda-expression in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "атрибут %qE може се применити само на јаванске дефиниције класа"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr "%qE је застарело; в-табеле су сада подразумевано сагласне са КОМом"
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "захтевано init_priority није целобројна константа"
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "атрибут %qE може се користити само уз дефиниције објеката класног типа у датотечном досегу"
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "захтевано init_priority је ван опсега"
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "захтевано init_priority резервисано је за унутрашњу употребу"
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "атрибут %qE није подржан на овој платформи"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "декларација %qD као %s"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
 msgstr "претходном декларацијом %q+#D овде"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "атрибут %qs захтева тачно један НТБС аргумент"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> није исправан декларатор"
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> није исправан декларатор"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "граница низа није целобројна константа"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "провера lang_*: крах у %s, код %s:%d"
@@ -45270,613 +45312,608 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr "равнање елемената низа је веће од величине елемента"
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr "ИСО Ц++ забрањује индексирање не-л-вредносног низа"
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "индексирање низа декларисаног као %<register%>"
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "недостаје објекат у употреби %qE"
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ИСО Ц++ забрањује звање %<::main%> унутар програма"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, fuzzy, gcc-internal-format
 #| msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "мора се употребити или %<.*%> или %<->*%> за позив показивача на чланску функцију у %<%E (...)%>"
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "превише аргумената за %s %q+#D"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "премало аргумената за %s %q+#D"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to member function %q#D"
 msgstr "превише аргумената за функцију %qs"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to member function %q#D"
 msgstr "премало аргумената за функцију %qs"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to function %q#D"
 msgstr "превише аргумената за функцију %qs"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to function %q#D"
 msgstr "премало аргумената за функцију %qs"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "превише аргумената за %s %q+#D"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "премало аргумената за %s %q+#D"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "превише аргумената за функцију"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "превише аргумената за функцију"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "параметар %P за %qD непотпуног је типа %qT"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "параметар %P непотпуног је типа %qT"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "претпоставља се претапање у тип %qT из препуњене функције"
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL употребљено аритметички"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "left rotate count is negative"
 msgstr "негативно ротирање %s"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "right rotate count is negative"
 msgstr "негативно ротирање %s"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "left rotate count >= width of type"
 msgstr "ротирање %s >= ширина типа"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "right rotate count >= width of type"
 msgstr "ротирање %s >= ширина типа"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr "поређење са дословном ниском резултује неодређеним понашањем"
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "адреса за %qD никако не може бити NULL"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ИСО Ц++ забрањује поређење показивача и целобројног"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "operand types are %qT and %qT"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "неуређено поређење са не-реалним аргументом"
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "неисправни операнди типова %qT и %qT за бинарно %qO"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача типа %<void *%> у одузимању"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача на функцију у одузимању"
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача на метод у одузимању"
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "неисправна употреба показивача на непотпун тип у аритметици са показивачима"
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qE"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qE"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "неисправна употреба %qE за добијање показивача-на-чланску-функцију"
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  неопходан је одређен ид."
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "заграде око %qE не могу бити коришћене за добијање показивача-на-чланску-функцију"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ИСО Ц++ забрањује узимање адресе неодређене или заграћене нестатичке чланске функције, за добијање показивача на чланску функцију. Употребите %<&%T::%D%>"
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ИСО Ц++ забрањује узимање адресе везане чланске функције за добијање показивача на чланску функцију. Употребите %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ИСО Ц++ забрањује узимање адресе функције %<::main%>"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr "ИСО Ц++ забрањује узимање адресе претапања у не-л-вредносни израз"
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "не може се створити показивач на упућивачки члан %qD"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ИСО Ц++ забрањује %s-вање показивача типа %qT"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ИСО Ц++ забрањује %s-вање показивача типа %qT"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "неисправан израз као операнд"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "не може се узети адреса од %<this%>, јер је д-вредносни израз"
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "затражена је адреса експлицитне регистарске променљиве %qD"
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "затражена је адреса од %qD, а декларисано је као %<register%>"
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "успостављач за %qT мора бити у витичастим заградама"
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "useless cast to type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "претварање из %qT у %qT"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "неисправно претапање д-вредносног израза типа %qT у тип %qT"
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr "претапање из %qT у %qT губи на тачности"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "претапање из %qT у %qT повећава неопходно равнање циљног типа"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ИСО Ц++ забрањује претапање између показивача на функцију и показивача на објекат"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "неисправно претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "неисправна употреба константног претапања са типом %qT, који није показивач, нити показивач на члански податак"
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "неисправна употреба константног претапања са типом %qT, који је показивач или упућивач на функцијски тип"
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "неисправно константно претапање д-вредности типа %qT у тип %qT"
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "неисправно константно претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ИСО Ц++ забрањује претапање у низовни тип %qT"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  у израчунавању %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "несагласни типови у додели %qT у %qT"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "низ употребљен као успостављач"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "неисправна додела низа"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   у претварању показивача на чланску функцију"
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "претварање показивача на члан преко виртуелне основе %qT"
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   у претварању показивача на члан"
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "неисправно претварање у тип %qT из типа %qT"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in return"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "аргумент %d од %qE може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "повратни тип може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "лева страна доделе може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "у прослеђивању аргумента %P за %q+D"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "враћање упућивача на привремени"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "враћање упућивача на не-л-вредност"
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr "враћање упућивача на локалну променљиву %q+D"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %q+D returned"
 msgstr "враћање адресе локалне променљиве %q+D"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr "враћање адресе локалне променљиве %q+D"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "враћање вредности из деструктора"
@@ -45883,46 +45920,46 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "не може се враћати из руковаоца у блоку покушаја у конструктору"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "враћање вредности из конструктора"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "наредба враћања без вредности, у функцији која враћа %qT"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "недостаје успостављач"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "наредба враћања са вредношћу, у функцији која враћа ‘void’"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> не сме вратити NULL, осим ако је декларисан уз %<throw()%> (или је задато -fcheck-new)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -46176,129 +46213,129 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr "двосмислено претварање %qE из %qT у %qT"
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "двосмислено претварање %qE из %qT у %qT"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-низ успостављен из не-широке ниске"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "int-array initialized from non-wide string"
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-низ успостављен из не-широке ниске"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "предугачка ниска успостављача за низ знакова"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "скупина типа %qT не може се успостављати сложеном константном"
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "успостављач низа мора бити нешто у витичастим заградама"
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "поље %qD није нађено у унији која се успоставља"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "индексна вредност уместо имена поља у успостављачу уније"
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "откривено кружно прослеђивање показивача"
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "основни операнд за %<->%> непоказивачког је типа %qT"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> производи непоказивачки резултат"
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "основни операнд за %<->%> није показивач"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE се не може користити као члански показивач, пошто је типа %qT"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "члански показивач %qE не може се применити на %qE, које је некласног типа %qT"
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "тип показивача на члан %qT није сагласан са типом објекта %qT"
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jподразумевано успостављање %q#D, које је упућивачког типа"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "позив функције %qD која баца непотпун тип %q#T"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "позив функције која баца непотпун тип %q#T"
@@ -46483,8 +46520,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -46630,7 +46667,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr "Синтаксна грешка у одредници знаковне дужине код %C"
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Type-spec at %L cannot contain a deferred type parameter"
@@ -46757,7 +46794,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити целобројан или процедура"
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -47429,13 +47466,13 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "Аргумент ‘source’ сопственог ‘shape’ код %L не сме бити низ претпостављене величине"
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити скалар"
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L cannot be INTENT(IN)"
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
@@ -47723,6 +47760,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити целобројан или логички"
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -47730,7 +47772,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -47968,430 +48010,430 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Променљива ‘%s’ код %C са успостављачем већ се појављује у наредби DATA"
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "у успостављачу се не могу успостављати вишедимензиони низови"
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Синтаксна грешка у декларацији података код %C"
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Компонента код %C мора имати атрибут показивача"
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Низовна компонента структуре код %C мора имати експлицитан или одложени облик"
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Показивачка низовна компонента структуре код %C мора имати одложен облик"
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Резервљива компонента структуре код %C мора имати одложен облик"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Низовна компонента структуре код %C мора имати експлицитан облик"
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "Двосмислено успостављање NULL() код %C"
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NULL() initialization at %C is ambiguous"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "Двосмислено успостављање NULL() код %C"
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Успостављање показивача код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Error in pointer initialization at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "non-NULL pointer initialization at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "Function name %qs not allowed at %C"
 msgstr "Име функције ‘%s’ није дозвољено код %C"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate array spec for Cray pointee at %C."
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Удвостручена одредница низа за Крејов показиваног код %C."
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "неисправно успостављање упућивача типа %qT изразом типа %qT"
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Успостављање код %C није за показивачку променљиву"
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Успостављање показивача код %C захтева ‘=>’, не ‘=’"
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Очекиван је успостављачки израз код %C"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Успостављање променљиве код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Успостављање резервљиве компоненте код %C није дозвољено"
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Старовремска декларација типа %s*%d није подржана код %C"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Нестандардна декларација типа %s*%d код %C"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis at %C"
 msgstr "Недостаје лева заграда код %C"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Очекиван је успостављачки израз код %C"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Очекиван је скаларни успостављачки израз код %C"
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Врста %d није подржана за тип %s код %C"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Недостаје лева заграда код %C"
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind %d not supported for type %s at %C"
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Врста %d није подржана за тип %s код %C"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Синтаксна грешка у декларацији CHARACTER код %C"
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Проширење: тип BYTE код %C"
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "Тип BYTE употребљен код %C није доступан на циљној машини"
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument list function at %L is not allowed in this context"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Функција листе аргумената код %L није дозвољена у овом контексту"
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "CLASS statement at %C"
 msgstr "Неочекивана наредба CASE код %C"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Двосмислено име типа ‘%s’ код %C"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Удвостручена наредба IMPLICIT NONE код %C"
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Недостаје знаковни опсег за имплицитно код %C"
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Слова морају бити у алфабетском поретку у наредби IMPLICIT код %C"
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "Наредба SAVE код %C прати покривачку наредбу SAVE"
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "Наредба ENTRY код %C не може бити унутар INTERFACE"
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting list of named entities at %C"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in %s statement at %C"
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Синтаксна грешка у наредби %s код %C"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "Missing codimension specification at %C"
 msgstr "Недостаје одредница димензија код %C"
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Недостаје одредница димензија код %C"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Удвостручени атрибут %s код %L"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute at %L is not allowed outside of a MODULE"
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "Атрибут %s код %L није дозвољен изван модула"
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "PROTECTED attribute at %C"
 msgstr "Удвостручени атрибут %s код %L"
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "VALUE attribute at %C"
 msgstr "Линија одсечена код %C"
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати низовну вредност"
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be a statement function"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -48399,303 +48441,303 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing generic specification in USE statement at %C"
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Недостаје генеричка одредница у наредби USE код %C"
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "Missing name"
 msgid "Missing symbol"
 msgstr "недостаје име"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition."
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Изведени тип код %C није претходно дефинисан и зато се не може појавити у дефиницији изведеног типа."
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Синтаксна грешка у декларацији података код %C"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "IMPURE procedure at %C"
 msgstr "име процедуре = %s"
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Очекивана је етикета алтернативног повратка код %C"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Име ‘%s’ код %C је име процедуре"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Неочекивано смеће у формалној листи аргумената код %C"
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Удвостручени симбол ‘%s’ у формалној листи аргумената код %C"
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "Променљива RESULT код %C мора бити различита од имена функције"
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Неочекивано смеће после декларације функције код %C"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Атрибут SAVE код %L не може бити наведен у чистој процедури"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Лажна процедура ‘%s’ код %C не може имати генеричко сучеље"
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Procedure pointer component at %C"
 msgstr "Очекивано је име компоненте структуре код %C"
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in structure constructor at %C"
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Синтаксна грешка у конструктору структуре код %C"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "MODULE PROCEDURE код %C мора бити у генеричком сучељу модула"
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Очекивана је формална листа аргумената у дефиницији функције код %C"
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "Наредба ENTRY код %C не може бити унутар PROGRAM"
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "Наредба ENTRY код %C не може бити унутар MODULE"
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "Наредба ENTRY код %C не може бити унутар BLOCK DATA"
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "Наредба ENTRY код %C не може бити унутар INTERFACE"
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока DERIVED TYPE"
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока IF-THEN"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока DO"
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока SELECT"
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока FORALL"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока WHERE"
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "Наредба ENTRY код %C не може бити унутар садржаног потпрограма"
 
-#: fortran/decl.c:5597
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
-msgid "gfc_match_entry(): Bad state"
-msgstr "gfc_trans_code(): лош кôд наредбе"
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Unexpected END statement at %C"
+msgid "Unexpected ENTRY statement at %C"
+msgstr "Неочекивана наредба END код %C"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "Наредба ENTRY код %C не може бити у садржаној процедури"
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Period required in format specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Потребна тачка у наводиоцу формата код %C"
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing closing paren for binding label at %C"
 msgstr "Недостаје етикета формата код %C"
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Име функције ‘%s’ није дозвољено код %C"
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot follow %s statement at %L"
 msgid "END statement instead of %s statement at %L"
@@ -48702,568 +48744,574 @@
 msgstr "Наредба %s код %C не може пратити наредбу %s код %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "Очекивана је наредба %s код %L"
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Очекивано је име блока за ‘%s’ у наредби %s код %C"
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Очекивана је етикета ‘%s’ за наредбу %s код %C"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Недостаје одредница низа код %L у наредби DIMENSION"
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr ""
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing array specification at %L in DIMENSION statement"
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Недостаје одредница низа код %L у наредби DIMENSION"
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Одредница низа мора бити одложена код %L"
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Неочекиван знак у листи променљивих код %C"
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Очекивано је име променљиве код %C"
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "Cray pointer at %C must be an integer"
 msgstr "Крејов показивач код %C мора бити целобројни."
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes."
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Крејов показивач код %C има %d бајтова тачности; меморијска адреса захтева %d бајтова."
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Очекивано је ‘,’ код %C"
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Очекивано је ‘)’ код %C"
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Очекивано је ‘,’ или крај наредбе код %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer declaration at %C requires -fcray-pointer flag."
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Декларација Крејовог показивача код %C захтева заставицу -fcray-pointer."
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Одредница приступа оператора %s код %C је већ наведена"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Одредница приступа оператора .%s. код %C је већ наведена"
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Очекивано је име променљиве код %C у наредби PARAMETER"
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Очекиван је знак = у наредби PARAMETER код %C"
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Очекиван је израз код %C у наредби PARAMETER"
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initializer not allowed for COMMON variable '%s' at %C"
 msgid "Initializing already initialized variable at %C"
 msgstr "Успостављач није дозвољен за заједничку променљиву ‘%s’ код %C"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Неочекивани знакови у наредби PARAMETER код %C"
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Покривачка наредба SAVE код %C прати претходну наредбу SAVE"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "Наредба SAVE код %C прати покривачку наредбу SAVE"
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "Удвостручена наредба PRIVATE код %C"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE код %C мора бити у генеричком сучељу модула"
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected :: in TYPE definition at %C"
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Очекивано је :: у дефиницији TYPE код %C"
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Симбол ‘%s’ код %C је већ придружен домаћину"
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qD не може бити нитно-локално зато што је не-ПОД типа %qT"
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PRIVATE within a MODULE"
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Изведени тип код %C може бити само приватан унутар модула"
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PUBLIC within a MODULE"
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Изведени тип код %C може бити само јаван унутар модула"
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Очекивано је :: у дефиницији TYPE код %C"
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Име типа ‘%s’ код %C не може бити исто као сопственог типа"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Дефиниција изведеног типа ‘%s’ код %C је већ учињена"
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Крејов показивани код %C не може бити низ претпостављеног облика"
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "New in Fortran 2003: ENUM and ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Ново у фортрану 2003: ENUM и ENUMERATOR код %C"
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Набрајач премашује Ц-ов целобројни тип код %C"
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "Набрајач %L није успостављен целобројним изразом"
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Очекивана је наредба дефиниције ENUM пре %C"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Синтаксна грешка у дефиницији ENUMERATOR код %C"
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate access-specifier at %C"
 msgstr "Удвостручена одредница %s код %C"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Удвостручени атрибут %s код %L"
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Очекивано је VARIABLE код %C"
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "Duplicate DEFERRED at %C"
 msgstr "Удвостручена наредба SEQUENCE код %C"
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a nameless interface at %C"
 msgid "Expected access-specifier at %C"
 msgstr "Очекивано је безимено сучеље код %C"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding attribute at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, fuzzy, gcc-internal-format
 #| msgid "identifier expected after %<@protocol%>"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "очекиван је идентификатор после %<@protocol%>"
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "%<)%> expected at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding name at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Очекиван је индекс низа код %C"
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Invalid form of PROGRAM statement at %C"
+msgid "Malformed GENERIC statement at %C"
+msgstr "Неисправан облик наредбе PROGRAM код %C"
+
+#: fortran/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected specific binding name at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "Нема одређене функције за генеричко ‘%s’ код %L"
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Empty FINAL at %C"
 msgstr "Очекивано је VARIABLE код %C"
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected module procedure name at %C"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Очекивано је ‘,’ код %C"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 #| msgid "procedure name = %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "име процедуре = %s"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, fuzzy, gcc-internal-format
 #| msgid "%s procedure at %L is already declared as %s procedure"
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "Процедура %s код %L је већ декларисана као процедура %s"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected characters in PARAMETER statement at %C"
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Неочекивани знакови у наредби PARAMETER код %C"
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
@@ -49573,371 +49621,371 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "%s код %L има различит облик за димензију %d (%d/%d)"
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a VALUE"
 msgid "%qs at %L is not a VALUE"
 msgstr "‘%s’ код %L није вредност"
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Несагласни рангови %d и %d у додели код %L"
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "Тип променљиве је UNKNOWN у додели код %L"
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "Појављује се NULL на десној страни у додели код %L"
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "POINTER valued function appears on right-hand side of assignment at %L"
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "Функција са показивачком вредношћу појављује се на десној страни доделе код %L"
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "Претварање из %s у %s код %L"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: Conversion from %s to %s at %L"
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "Проширење: Претварање из %s у %s код %L"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Conversion from %qs to %qs at %L"
 msgstr "Претварање из %s у %s код %L"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible types in assignment at %L, %s to %s"
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Несагласни типови у додели код %L, %s у %s"
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Циљ доделе показивача није показивач код %L"
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "‘%s’ у додели показивача код %L не може бити л-вредност јер је процедура"
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Удвостручена одредница %s код %C"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, fuzzy, gcc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack size must not be greater than 64k"
 msgid "Stride must not be present at %L"
 msgstr "величина стека не сме бити већа од 64k"
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Спољашњи објекат ‘%s’ код %L не може имати успостављач"
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' requires argument list at %C"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Наредбена функција ‘%s’ захтева листу аргумената код %C"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Унутрашња процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not allowed as an actual argument"
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Сопствено ‘%s’ код %L није дозвољено као стварни аргумент"
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "удвостручена декларација сучеља за класу %qs"
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Различите знаковне дужине у додели показивача код %L"
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Различити рангови у додели показивача код %L"
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Циљ доделе показивача није показивач код %L"
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Изборни израз у рачунском GOTO код %L мора бити скаларни целобројан израз"
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Циљ доделе показивача није ни циљ ни показивач код %L"
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Лош циљ у додели показивача у чистој процедури код %L"
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Додела показивача са векторским индексом на десној страни код %L"
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Циљ доделе показивача није показивач код %L"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data target at %L shall not have a coindex"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Успостављање показивача код %C захтева ‘=>’, не ‘=’"
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Компонента код %C мора имати атрибут показивача"
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "не могу да отворим улазну датотеку: %s"
@@ -49961,30 +50009,30 @@
 msgid "Removing call to function %qs at %L"
 msgstr "позив не-функције %qD"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
@@ -50044,640 +50092,646 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr "Очекивано је ‘END INTERFACE ASSIGNMENT (=)’ код %C"
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (%s)' at %C"
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr "Очекивано је ‘END INTERFACE OPERATOR (%s)’ код %C"
+
+#: fortran/interface.c:353
+#, fuzzy, gcc-internal-format
+#| msgid "Expecting 'END INTERFACE OPERATOR (%s)' at %C"
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr "Очекивано је ‘END INTERFACE OPERATOR (%s)’ код %C"
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr "Очекивано је ‘END INTERFACE OPERATOR (.%s.)’ код %C"
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE %s' at %C"
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr "Очекивано је ‘END INTERFACE %s’ код %C"
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr "Алтернативно враћање не може да се јави у сучељу оператора код %L"
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr "Сучеље оператора доделе код %L мора имати два аргумента"
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr "Сучеље оператора код %L има погрешан број аргумената"
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr "Сучеље оператора доделе код %L мора бити потпрограм"
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr "Сучеље оператора доделе код %L не сме редефинисати сопствену типску доделу"
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr "Сучеље сопственог оператора код %L мора бити функција"
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of defined assignment at %L must be INTENT(IN) or INTENT(INOUT)"
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr "Први аргумент дефинисане доделе код %L мора бити намере-у или -у/из"
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Други аргумент дефинисане доделе код %L мора бити намере-у"
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Други аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr "Сучеље оператора код %L коси се са сопственим сучељем"
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr "Симбол ‘%s’ код %L већ има експлицитно сучеље"
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr "Процедура ‘%s’ у %s код %L није ни функција ни потпрограм"
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Internal procedure %qs in %s at %L"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, fuzzy, gcc-internal-format
 #| msgid "Ambiguous interfaces '%s' and '%s' in %s at %L"
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr "Двосмислена сучеља ‘%s’ и ‘%s’ у %s код %L"
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, fuzzy, gcc-internal-format
 #| msgid "Although not referenced, '%s' at %L has ambiguous interfaces"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "Иако се другде не помиње, ‘%s’ код %L има двосмислена сучеља"
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "%qs at %L is not a module procedure"
 msgstr "Име ‘%s’ код %C је име процедуре"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid third argument of IBITS at %L"
 msgid "Invalid procedure argument at %L"
 msgstr "Неисправан трећи аргумент у IBITS код %L"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Аргументи ‘%s’ и ‘%s’ сопственог ‘%s’ код %L морају бити истог типа"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Кључна реч ‘%s’ код %L је већ придружена другом стварном аргументу"
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Више стварних него формалних аргумената у позиву процедуре код %L"
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Недостаје одредница алтернативног враћања у позиву потпрограма код %L"
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr "Неочекивана одредница алтернативног враћања у позиву потпрограма код %L"
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L не може бити низ претпостављене величине"
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити резервљив"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Недостаје стварни аргумент за аргумент ‘%s’ код %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Исти стварни аргумент придружен намере-%s аргументу ‘%s’ и намере-%s аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Аргумент процедуре код %L је локалан у чистој процедури и има атрибут показивача"
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Аргумент процедуре код %L је локалан у чистој процедури и прослеђује се аргументу намере-%s"
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Аргумент процедуре код %L је локалан у чистој процедури и прослеђује се аргументу намере-%s"
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic character length function '%s' at %L must have an explicit interface"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Аутоматска функција знаковне дужине ‘%s’ код %L мора имати експлицитно сучеље"
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Симбол ‘%s’ код %L већ има експлицитно сучеље"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "MOLD argument to NULL required at %L"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qs"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D удволичено са недефинисаним симболом %qs"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Ентитет ‘%s’ код %C је већ присутан у сучељу"
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr "Не могу да претворим %s у %s код %L"
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "Садржана процедура ‘%s’ код %L у чистој процедури мора такође бити чиста"
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "Садржана процедура ‘%s’ код %L у чистој процедури мора такође бити чиста"
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
@@ -51141,13 +51195,13 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "DECIMAL= at %C not allowed in Fortran 95"
@@ -51159,7 +51213,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "ROUND= at %C not allowed in Fortran 95"
@@ -51188,461 +51242,461 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "Наредба %s није дозвољена у чистој процедури код %C"
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: FLUSH statement at %C"
 msgid "FLUSH statement at %C"
 msgstr "Фортран 2003: Наредба FLUSH код %C"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "Удвостручена одредница UNIT код %C"
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Удвостручена одредница формата код %C"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "Симбол ‘%s’ у листи имена ‘%s’ је намере-у код %C"
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Удвостручена одредница NML код %C"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C must be a NAMELIST group name"
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "Симбол ‘%s’ код %C мора бити име групе листе имена"
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-I- specified twice"
 msgid "UNIT not specified at %L"
 msgstr "-I- наведено двапут"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "Одредница UNIT код %L мора бити целобројни израз или знаковна променљива"
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "Неисправан облик наредбе PROGRAM код %C"
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "Унутрашња јединица са векторским индексом код %L"
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "Спољашња У/И јединица не може бити низ код %L"
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Comma before output item list at %C is an extension"
 msgid "Comma before i/o item list at %L"
 msgstr "Проширење: Зарез пре ставке излазне листе код %C је проширење"
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "Етикета %d за ERR код %L није дефинисана"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "Етикета %d за END код %L није дефинисана"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "Етикета %d за EOR код %L није дефинисана"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "Етикета %d за FORMAT код %L није дефинисана"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Синтаксна грешка у У/И итератору код %C"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Очекивана је променљива у наредби READ код %C"
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Очекиван је израз у наредби %s код %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Синтаксна грешка у наредби %s код %C"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic at %L does not exist"
 msgid "Internal file at %L with namelist"
 msgstr "Сопствено код %L не постоји"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "Параметар врсте за %s код %L мора бити инцијализовани израз"
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "Листа имена PRINT код %C је проширење"
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Очекиван је зарез у У/И листи код %C"
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "Наредба PRINT код %C није дозвољена у чистој процедури"
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "Наредба INQUIRE код %C није дозвољена у чистој процедури"
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "Неисправна ознака IOLENGTH у наредби INQUIRE код %C"
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "Наредба INQUIRE код %L не може садржати и наводилац FILE и UNIT"
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "Наредба INQUIRE код %L захтева или наводилац FILE или UNIT"
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L cannot be %s"
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr "Аргумент наредбе SELECT код %L не може бити %s"
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "Наредба INQUIRE код %L захтева или наводилац FILE или UNIT"
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "Наредба %s није дозвољена у чистој процедури код %C"
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_op2string(): Bad code"
 msgstr "gfc_trans_code(): лош кôд наредбе"
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 #| msgid "ENUM definition statement expected before %C"
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "Очекивана је наредба дефиниције ENUM пре %C"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 #| msgid "ENUM definition statement expected before %C"
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "Очекивана је наредба дефиниције ENUM пре %C"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr "Цео број превелик код %C"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "Превише цифара у етикети наредбе код %C"
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr "Етикета наредбе код %C је нула"
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 #| msgid "Label name '%s' at %C is ambiguous"
 msgid "Label name %qs at %C is ambiguous"
 msgstr "Двосмислено име етикете ‘%s’ код %C"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Duplicate construct label %qs at %C"
 msgstr "Удвостручена етикета конструкције ‘%s’ код %C"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad character '%c' in OPERATOR name at %C"
 msgid "Invalid character in name at %C"
 msgstr "Лош знак ‘%c’ у имену оператора код %C"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr "Предугачко име код %C"
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr ""
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a sub-component"
 msgid "Loop variable at %C cannot be a coarray"
 msgstr "Променљива петље код %C не може бити подкомпонента"
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr "Променљива петље код %C не може бити подкомпонента"
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr "Очекивана је вредност корака у итератору код %C"
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr "Синтаксна грешка у итератору код %C"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_match(): Bad match code %c"
 msgstr "gfc_trans_code(): лош кôд наредбе"
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr "Неисправан облик наредбе PROGRAM код %C"
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolescent: arithmetic IF statement at %C"
 msgid "Arithmetic IF statement at %C"
 msgstr "Застарело: аритметичка наредба IF код %C"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr "Синтаксна грешка у IF-изразу код %C"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr "Етикета блока није подесна за аритметичку наредбу IF код %C"
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Block label is not appropriate IF statement at %C"
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr "Етикета блока није подесна за наредбу IF код %C"
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr "Не могу да доделим у именовану константу код %C"
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr "Неразврстљива наредба у одредби IF код %C"
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr "Синтаксна грешка у одредби IF код %C"
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match IF label '%s'"
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "Етикета ‘%s’ код %C не одговара етикети IF ‘%s’"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE IF код %C"
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr "Наредба PRINT код %C није дозвољена у чистој процедури"
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "CRITICAL statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Nested CRITICAL block at %C"
 msgstr "Очекивано је VARIABLE код %C"
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected comma in I/O list at %C"
 msgid "Expected association list at %C"
 msgstr "Очекиван је зарез у У/И листи код %C"
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "Expected association at %C"
 msgstr "Очекиван је индекс низа код %C"
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate name %qs in association at %C"
 msgstr "Удвостручена одредница %s код %C"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr "Удвостручена наредба PRIVATE код %C"
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "Скаларни објекат ‘%s’ код %L не може бити резервљив"
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Invalid type-spec at %C"
 msgstr "неисправан типски аргумент"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "Синтаксна грешка у итератору FORALL код %C"
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "Име ‘%s’ у наредби %s код %C није име петље"
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "Име ‘%s’ у наредби %s код %C није име петље"
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaves CRITICAL construct"
@@ -51649,384 +51703,384 @@
 msgstr "Наредба %s код %C напушта структуирани блок ОпенМПа"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "Наредба %s код %C напушта структуирани блок ОпенМПа"
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "%s statement at %C is not within a construct"
 msgstr "Наредба %s код %C није унутар петље"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "%s statement at %C is not within construct %qs"
 msgstr "Наредба %s код %C није унутар петље ‘%s’"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "Наредба %s код %C није унутар петље ‘%s’"
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "Наредба %s код %C није унутар петље ‘%s’"
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "Наредба %s код %C напушта структуирани блок ОпенМПа"
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "Наредба EXIT код %C окончава петљу !$OMP DO"
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "Наредба EXIT код %C окончава петљу !$OMP DO"
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "Наредба EXIT код %C окончава петљу !$OMP DO"
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "Наредба EXIT код %C окончава петљу !$OMP DO"
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement at %C in PURE procedure"
 msgstr "Наредба %s није дозвољена у чистој процедури код %C"
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "Индекс низа код %L мора бити целобројни"
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be scalar"
 msgid "STOP code at %L must be scalar"
 msgstr "Индекс низа код %L мора бити скалар"
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Крејов показивач код %C мора бити целобројни."
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "PAUSE statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ERROR STOP statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "Наредба PRINT код %C није дозвољена у чистој процедури"
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "LOCK statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "UNLOCK statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "Наредба PRINT код %C није дозвољена у чистој процедури"
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "SYNC statement at %C"
 msgstr "Удвостручена наредба SEQUENCE код %C"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: ASSIGN statement at %C"
 msgid "ASSIGN statement at %C"
 msgstr "Застарело: наредба ASSIGN код %C"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: Assigned GOTO statement at %C"
 msgid "Assigned GOTO statement at %C"
 msgstr "Застарело: Додељена наредба GOTO код %C"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "Листа етикета наредби у GOTO код %C не може бити празна"
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad allocate-object in ALLOCATE statement at %C for a PURE procedure"
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "Лоша објекат у наредби ALLOCATE код %C у чистој процедури"
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "тип показивача на члан %qT није сагласан са типом објекта %qT"
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "Лоша одредница за низ претпостављене величине код %C"
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "Празно BLOCK DATA код %C коси се са претходним BLOCK DATA код %L"
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal deallocate-expression in DEALLOCATE at %C for a PURE procedure"
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "Недозвољени израз у DEALLOCATE код %C за чисту процедуру"
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "Алтернативна наредба RETURN код %C дозвољена је само унутар потпрограма"
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: RETURN statement in main program at %C"
 msgid "RETURN statement in main program at %C"
 msgstr "Проширење: Наредба RETURN у главном програму код %C"
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Expected component reference at %C"
 msgstr "Очекивано је име компоненте структуре код %C"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "Синтаксна грешка у имену заједничког блока код %C"
@@ -52034,162 +52088,162 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr ""
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Симбол ‘%s’ код %C је већ у заједничком блоку"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "Array specification for symbol '%s' in COMMON at %C must be explicit"
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "Одредница низа за симбол ‘%s’ у заједничком код %C мора бити експлицитна"
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in COMMON at %C cannot be a POINTER array"
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "Симбол ‘%s’ у заједничком код %C не може бити низ показивача"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s', in COMMON block '%s' at %C is being indirectly equivalenced to another COMMON block '%s'"
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "Симбол ‘%s’ у заједничком блоку ‘%s’ код %C посредно се еквивалентира са другим заједничким блоком, ‘%s’"
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already has a basic type of %s"
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "Име групе листе имена ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already is USE associated and cannot be respecified."
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "Име групе листе имена ‘%s’ код %C је већ употребно придружено и не може се поново одредити."
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Низ претпостављене величине ‘%s’ у листи имена ‘%s’ код %C није дозвољен."
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "Компонента изведеног типа %C није дозвољен члан у еквиваленцији"
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "Упућивач низа у еквивалецији код %C не може бити одељак низа"
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "Еквиваленција код %C захтева два или више објеката"
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Покушај посредног преклапања заједничких блокова %s и %s помоћу еквиваленције код %C"
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected comma in I/O list at %C"
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Очекиван је зарез у У/И листи код %C"
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "Наредбена функција код %L је рекурзивна"
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement function at %L is recursive"
 msgid "Statement function at %C"
 msgstr "Наредбена функција код %L је рекурзивна"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Очекиван је успостављачки израз у CASE код %C"
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Очекивано је име блока за ‘%s’ у наредби %s код %C"
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Неочекивана наредба CASE код %C"
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CASE specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "Наредба ELSEWHERE код %C није обухваћена блоком WHERE"
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -52346,183 +52400,183 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Листа имена %s не може се преименовати у %s придружењем USE."
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Симбол ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, fuzzy, gcc-internal-format
 #| msgid "User operator '%s' referenced at %L not found in module '%s'"
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Кориснички оператор ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Сопствени оператор ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Не могу да отворим датотеку модула ‘%s’ за писање код %C: %s"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Грешка при отварању датотеке модула ‘%s’ за писање: %s"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file '%s': %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: не могу да обришем датотеку ‘%s’: %s\n"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Не могу да отворим датотеку модула ‘%s’ за писање код %C: %s"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete aux info file '%s': %s\n"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: не могу да обришем помоћну инфотеку ‘%s’: %s\n"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs already declared"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Сопствено ‘%s’ код %L није укључено у изабрани стандард"
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Симбол ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Симбол ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "Наредба %s код %C није унутар петље"
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Не могу да отворим датотеку модула ‘%s’ за читање код %C: %s"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GFORTRAN module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Датотека ‘%s’ отворена код %C није модул Гфортрана"
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr "Не може USE за исти модул који градимо!"
@@ -52858,7 +52912,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба IF код %L захтева скаларни логички израз"
@@ -53626,393 +53680,387 @@
 msgid "Unexpected %s statement at %C"
 msgstr "Неочекивана наредба %s код %C"
 
-#: fortran/parse.c:2428
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected %s statement in MODULE at %C"
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr "Неочекивана наредба %s у модулу код %C"
-
-#: fortran/parse.c:2439
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "Наредба %s код %C не може пратити наредбу %s код %L"
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "Неочекиван крај датотеке у ‘%s’"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement in CONTAINS section at %C"
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "Неочекивана наредба %s у одељку CONTAINS код %C"
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement in CONTAINS section at %C"
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "Неочекивана наредба %s у одељку CONTAINS код %C"
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "FINAL procedure declaration at %C"
 msgstr "претходна декларација %qs"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Дефиниција изведеног типа код %C нема компонената"
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "Наредба PRIVATE у TYPE код %C мора бити унутар модула"
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRIVATE statement at %C must precede structure components"
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "Наредба PRIVATE код %C мора претходити компонентама структуре"
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Удвостручена наредба PRIVATE код %C"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SEQUENCE statement at %C must precede structure components"
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "Наредба SEQUENCE код %C мора претходити компонентама структуре"
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENUM declaration at %C has no ENUMERATORS"
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "Декларација ENUM код %C не садржи набрајаче"
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Derived type definition at %C without components"
 msgstr "Дефиниција изведеног типа код %C нема компонената"
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "Наредба PRIVATE код %C мора претходити компонентама структуре"
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "Наредба SEQUENCE код %C мора претходити компонентама структуре"
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "Атрибут SEQUENCE код %C је већ наведен у наредби TYPE"
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Удвостручена наредба SEQUENCE код %C"
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocatable component of structure at %C must have a deferred shape"
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "Резервљива компонента структуре код %C мора имати одложен облик"
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "Декларација ENUM код %C не садржи набрајаче"
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Неочекивана наредба %s у блоку INTERFACE код %C"
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "Име типа ‘%s’ код %C не може бити исто као сопственог типа"
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Неочекивана наредба %s код %C у телу сучеља"
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "Наредба %s није дозвољена у чистој процедури код %C"
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "Наредба %s није дозвољена у чистој процедури код %C"
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "Наредба %s се мора појавити у модулу"
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "Наредба %s код %C прати другачију одредницу приступа"
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "Bad kind expression for function %qs at %L"
 msgstr "неисправна складишна класа за функцију %qs"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, fuzzy, gcc-internal-format
 #| msgid "Alternate return specifier in function '%s' at %L is not allowed"
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Наводилац алтернативног повратка није дозвољен у функцији ‘%s’ код %L"
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "Наредба ELSEWHERE код %C прати претходно демаскирано ELSEWHERE"
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Неочекивана наредба %s у блоку WHERE код %C"
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Неочекивана наредба %s у блоку FORALL код %C"
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "Наредба ELSE IF код %C не може пратити наредбу ELSE код %L"
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Удвостручене наредбе ELSE код %L и %C"
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "Очекивана је наредба CASE или END SELECT после SELECT CASE код %C"
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "Очекивана је наредба CASE или END SELECT после SELECT CASE код %C"
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "Крај неблоковске наредбе DO код %C је унутар другог блока"
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "Крај неблоковске наредбе DO код %C је уплетена са другом DO петљом"
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "Етикета наредбе у ENDDO код %C не одговара етикети DO"
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "BLOCK construct at %C"
 msgstr "Конструктор не може бити %s"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "Етикета наредбе у ENDDO код %C не одговара етикети DO"
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "named block DO at %L requires matching ENDDO name"
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "именовани блок DO код %L захтева поклапајуће име уз ENDDO"
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s at %C"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "Не слаже се име после !$omp critical и !$omp end critical код %C"
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "Наредба %s код %C не може окончати неблоковску петљу DO"
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORMAT statement at %L does not have a statement label"
 msgid "DATA statement at %C after the first executable statement"
 msgstr "Наредба FORMAT код %L нема етикету наредбе"
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %C is already ambiguous"
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "Садржана процедура ‘%s’ код %C је већ двосмислена"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Неочекивана наредба %s у одељку CONTAINS код %C"
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "Наредба CONTAINS код %C је већ у садржаној програмској јединици"
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr "Глобално име ‘%s’ код %L се већ користи као %s код %L"
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr "Глобално име ‘%s’ код %L се већ користи као %s код %L"
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "Празно BLOCK DATA код %C коси се са претходним BLOCK DATA код %L"
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Неочекивана наредба %s у BLOCK DATA код %C"
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Неочекивана наредба %s у модулу код %C"
@@ -54020,7 +54068,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "Два главна програма, код %L и %C"
@@ -54789,7 +54837,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Етикета %d поменута код %L није дефинисана"
@@ -54850,404 +54898,404 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Није дозвољено прослеђивање унутрашње процедуре по локацији код %L"
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "Елементална несопствена процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optionalargument with the same rank (12.4.1.5)"
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "‘%s’ код %L је низ и опцион; ако недостаје, не може бити стварни аргумент елементалне процедуре, осим ако постоји не-опциони аргумент истог ранга (12.4.1.5)"
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, fuzzy, gcc-internal-format
 #| msgid "coverage mismatch for function %qs while reading counter %qs"
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "неслагање покривача за функцију %qs у току читања бројача %qs"
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Нема одређене функције за генеричко ‘%s’ код %L"
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Генеричка функција ‘%s’ код %L није у складу са одређеним сопственим сучељем"
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Функција ‘%s’ код %L је сопствена али није сагласна са сопственом"
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Не могу да разрешим одређену функцију ‘%s’ код %L"
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, fuzzy, gcc-internal-format
 #| msgid "reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "упућивач на не-чисту функцију ‘%s’ код %L унутар FORALL %s"
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, fuzzy, gcc-internal-format
 #| msgid "reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "упућивач на не-чисту функцију ‘%s’ код %L унутар FORALL %s"
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot write to internal file unit '%s' at %C inside a PURE procedure"
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Не могу да пишем у унутрашњу датотеку ‘%s’ код %C унутар чисте процедуре"
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a function"
 msgid "%qs at %L is not a function"
 msgstr "‘%s’ код %L није функција"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Функција ‘%s’ декларисана је као CHARACTER(*) и не може бити употребљена код %L пошто није лажни аргумент"
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "User defined non-ELEMENTAL function '%s' at %L not allowed in WORKSHARE construct"
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Кориснички дефинисана неелементална функција ‘%s’ код %L није дозвољена у конструкцији WORKSHARE"
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot call itself, as it is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "Потпрограм ‘%s’ код %L не може позивати самог себе, пошто није рекурзиван"
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot call itself, as it is not RECURSIVE"
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Функција ‘%s’ код %L не може позивати саму себе, пошто није рекурзивна"
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Позив потпрограма за ‘%s’ у блоку FORALL код %L није чист"
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Позив потпрограма за ‘%s’ у блоку FORALL код %L није чист"
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Позив потпрограма за ‘%s’ код %L није чист"
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific subroutine for the generic '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Нема одређеног потпрограма за генеричко ‘%s’ код %L"
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Генерички потпрограм ‘%s’ код %L није у складу са сучељем сопственог потпрограма"
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Потпрограм ‘%s’ код %L је сопствени али није сагласан са сопственим"
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Не могу да разрешим одређени потпрограм ‘%s’ код %L"
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr "„%s“ код %L има тип који није у складу са позивом код %L"
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, fuzzy, gcc-internal-format
 #| msgid "Call to ENTRY '%s' at %L is recursive, but subroutine '%s' is not declared as RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "Позив за унос ‘%s’ код %L јесте рекурзиван, али потпрограм ‘%s’ није декларисан као такав"
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot call itself, as it is not RECURSIVE"
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Потпрограм ‘%s’ код %L не може позивати самог себе, пошто није рекурзиван"
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Облици операнада код %L и %L нису усагласиви"
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Недозвољен нулти корак код %L"
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "недостаје индекс у упућивачу низа"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Није наведена десна горња граница низа претпостављене величине код %L"
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Неслагање рангова у упућивачу низа код %L (%d/%d)"
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Неслагање рангова у упућивачу низа код %L (%d/%d)"
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Индекс у димензији %d је ван граница код %L"
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Индекс низа код %L мора бити скалар"
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Индекс низа код %L мора бити целобројни"
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Проширење: реални индекс низа код %L"
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Аргумент димензије код %L мора целобројни"
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Индекс низа код %L је низ ранга %d"
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Индекс почетка подниске код %L мора бити целобројни"
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Индекс почетка подниске код %L мора бити скалар"
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Индекс почетка подниске код %L је мањи од један"
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Индекс краја подниске код %L мора бити целобројни"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Индекс краја подниске код %L мора бити скалар"
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Индекс краја подниске код %L премашује дужину ниске"
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "Индекс краја подниске код %L мора бити скалар"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Лош упућивач низа код %L"
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Компонента десно од делимичног упућивача са ненултим рангом не сме имати атрибут показивача код %L"
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Компонента десно од делимичног упућивача са ненултим рангом не сме имати атрибут резервљивости код %L"
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Два или више делимична упућивача са ненултим рангом не смеју бити наведени код %L"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -55257,12 +55305,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -55272,65 +55320,65 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s',used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Променљива ‘%s’, употребљена у одредничком изразу, користи се код %L пре наредбе ENTRY у којој је параметар"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Променљива ‘%s’ употребљена је код %L пре наредбе ENTRY у којој је параметар"
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "Ознака %s код %L мора бити скалар"
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
@@ -55337,199 +55385,199 @@
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L мора бити скалар"
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Очекиван је тип израза"
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "Израз за почетак у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "Израз за крај у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "Израз за корак у FORALL код %L мора бити скаларни %s"
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "Израз за корак у FORALL код %L не може бити нула"
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Израз у наредби ALLOCATE код %L мора бити резервљив или показивач"
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear an the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’ не може да се јави у одредници низа код %L у истој наредби резервисања где се и само резервише"
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "Одредница UNIT код %L мора бити целобројни израз или знаковна променљива"
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -55538,124 +55586,124 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "Етикета CASE код %L преклапа етикету CASE код %L"
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Израз у наредби CASE код %L мора бити врста %d"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Израз у наредби CASE код %L мора бити скалар"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Изборни израз у рачунском GOTO код %L мора бити скаларни целобројан израз"
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент наредбе SELECT код %L не може бити %s"
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE код %L не може бити праћен другим DEFAULT CASE код %L"
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логички опсег у наредби CASE код %L није дозвољен"
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "константна логичка вредност у наредби CASE поновљена је код %L"
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Одредница опсега код %L не може никако бити поклопљена"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Блок логичког SELECT CASE код %L има више од два случаја"
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Изведени тип ‘%s’ код %C користи се пре него што је дефинисан"
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Неочекивана наредба %s код %C"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
@@ -55662,81 +55710,81 @@
 msgstr "Неисправна врста за %s код %L"
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати резервљиве компоненте"
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Елемент преноса података код %L не може имати приватне компоненте"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Елемент преноса података код %L не може бити пун упућивач на низ претпостављене величине"
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Аргумент у ACOS код %L мора бити између -1 и 1"
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Наредба код %L није исправна наредба циља гранања за наредбу гранања код %L"
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -55744,12 +55792,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -55757,167 +55805,167 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Маска у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "Циљ доделе у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподржана наредба унутар WHERE код %L"
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL са индексом ‘%s’ изазива више од једне доделе овом објекту код %L"
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Спољашња конструкција FORALL већ има индекс са овим именом %L"
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Одредба WHERE/ELSEWHERE код %L захтева логички низ"
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr "Знаковни израз код %L бива подсечен (%d/%d)"
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Десна страна доделе код %L је изведени тип који садржи показивач у чистој процедури"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Десна страна доделе код %L је изведени тип који садржи показивач у чистој процедури"
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr ""
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "Наредба ASSIGNED GOTO код %L захтева целобројну променљиву"
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Променљивој ‘%s’ није додељена циљна етикета код %L"
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Алтернативна наредба повратка код %L захтева скаларни целобројни наводилац повратка"
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr "Аритметичко IF код %L захтева бројевни израз"
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Излазни услов из петље DO WHILE код %L мора бити скаларни логички израз"
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба маске у FORALL код %L захтева логички израз"
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): лош кôд наредбе"
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -55924,7 +55972,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -55932,63 +55980,63 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr ""
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "величина низа %qs је превелика"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Скаларни објекат ‘%s’ код %L не може бити резервљив"
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The type %s cannot be host associated at %L because it is blocked by an incompatible object of the same name at %L"
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Тип %s не може бити придружен домаћину код %L зато што га блокира несагласан објекат истог имена код %L"
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
@@ -55995,116 +56043,116 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr "Низ модула или главног програма ‘%s’ код %L мора имати константан облик"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Ентитет са претпостављеном знаковном дужином код %L мора бити лажни аргумент или параметар"
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Резервљиво ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Спољашње ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Аутоматски низ ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "‘%s’ је приватног типа и не може бити лажни аргумент у ‘%s’, који је јаван код %L"
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Спољашњи објекат ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Елементална функција ‘%s’ код %L мора имати скаларни резултат"
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати низовну вредност"
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
@@ -56111,13 +56159,13 @@
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати показивачку вредност"
 
 # no-c-format
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
@@ -56124,345 +56172,345 @@
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити рекурзивна"
 
 # no-c-format
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Лажна процедура ‘%s’ код %C не може имати генеричко сучеље"
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Атрибут %s коси се са атрибутом %s у ‘%s’ код %L"
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Аргумент у ICHAR код %L мора бити дужине један"
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L не сме бити опциони"
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити скалар"
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Знаковна дужина компоненте ‘%s’ мора бити константан одреднички израз код %L."
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Компонента ‘%s’ је приватни тип и не може бити компонента у ‘%s’, која је јавна код %L"
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонента %s типа SEQUENCE декларисаног код %L нема атрибут SEQUENCE"
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Показивачка компонента ‘%s’ у ‘%s’ код %L припада типу који није декларисан"
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Низ претпостављене величине ‘%s’ у листи имена ‘%s’ код %C није дозвољен."
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -56470,430 +56518,430 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Параметарски низ ‘%s’ код %L не може бити аутоматског или претпостављеног облика"
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Имплицитно типски параметар ‘%s’ код %L не одговара каснијем имплицитном типу"
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несагласан изведени тип у параметру код %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Низ претпостављене величине код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Симбол код %L није лажна променљива"
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Изведени тип ‘%s’ код %L је типа ‘%s’, који није дефинисан."
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Променљива изведеног типа у заједничком код %C нема атрибут SEQUENCE"
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Лажни аргумент намере-из ‘%s’ код %L је претпостављене величине и зато не може имати подразумевани успостављач"
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Лажна процедура код %L није дозвољена у елементалној процедури"
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Нитно-приватно код %L не снима се"
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA елемент ‘%s’ код %L мора бити у заједничком"
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантан одељак низа код %L у наредби DATA"
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "Наредба DATA код %L има више променљивих него вредности"
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "Наредба DATA код %L има више вредности него променљивих"
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Ознака %d код %L дефинисана али неупотребљена"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Ознака %d код %L дефинисана али не може бити употребљена"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L не може имати резервљиве компоненте како би била објекат еквиваленције"
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Променљива изведеног типа ‘%s’ код %L са подразумеваним успостављачем не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L са показивачким компонентама не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Члан заједничког блока ‘%s’ код %L не може бити објекат еквиваленције у чистој процедури ‘%s’"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именована константа ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Низ ‘%s’ код %L са неконстантним границама не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонената структуре ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подниска код %L има нулту дужину"
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "Унос ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора бити функција"
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура корисничког оператора ‘%s’ код %L не може бити претпостављене знаковне дужине"
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Први аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Други аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Сучеље оператора код %L мора имати, највише, два аргумента"
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -56927,51 +56975,51 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr ""
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "Line truncated at %L"
 msgstr "Линија одсечена код %C"
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr "Премашено ограничење од %d настављања у наредби код %C"
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "Missing '&' in continued character constant at %C"
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "Недостаје ‘&’ у настављеној знаковној константи код %C"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr "Табулатор противан стандарду код %C"
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "'&' not allowed by itself in line %d"
 msgid "%<&%> not allowed by itself in line %d"
 msgstr "‘&’ не може бити само у линији %d"
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Nonconforming tab character in column 1 of line %d"
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr "Табулатор противан стандарду у колони 1 линије %d"
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr "%s:%d: датотека %s је напуштена, али у њу није уђено"
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr "%s:%d: Недозвољена предобрађивачка директива"
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open file '%s'"
 msgid "Can't open file %qs"
@@ -57249,55 +57297,55 @@
 msgid "Reshaped array too large at %C"
 msgstr "Цео број превелик код %C"
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "Резултат SCALE прелива своју врсту код %L"
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Лош тип у константном изразу"
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "Аргумент у SQRT код %L има негативну вредност"
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid second argument of IBSET at %L"
 msgid "invalid argument of SQRT at %L"
 msgstr "Неисправан други аргумент у IBSET код %L"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_conv_constant_to_tree(): invalid type: %s"
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): неисправан тип: %s"
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -57381,277 +57429,283 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "Унутрашња процедура ‘%s’ код %L није дозвољена као стварни аргумент"
+
+#: fortran/symbol.c:489
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "Procedure pointer at %C"
 msgstr "име процедуре = %s"
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute applied to %s %s at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr "Атрибут %s коси се са атрибутом %s у ‘%s’ код %L"
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute with %s attribute at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr "Атрибут %s коси се са атрибутом %s у ‘%s’ код %L"
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "Не могу се променити атрибути USE-придруженог симбола код %L"
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "Не могу се променити атрибути USE-придруженог симбола %s код %L"
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute specified at %L"
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Удвостручени атрибут %S наведен код %L"
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray Pointee at %L appears in multiple pointer() statements."
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "Крејов показивани код %L појављује се у више наредби pointer()"
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "Атрибут SAVE код %L не може бити наведен у чистој процедури"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "Процедура %s код %L је већ декларисана као процедура %s"
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "Намера-%s коси се са намером-%s код %L"
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "Одредница ACCESS код %L је већ наведена "
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute specified at %L"
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Удвостручени атрибут %S наведен код %L"
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Симбол ‘%s’ код %L већ има експлицитно сучеље"
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %C already has a type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Функција ‘%s’ код %C већ има тип %s"
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Симбол ‘%s’ код %L не може имати тип"
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Двосмислен симбол ‘%s’ код %C"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Изведени тип ‘%s’ код %C користи се пре него што је дефинисан"
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Компонента ‘%s’ код %C је приватна компонента у ‘%s’"
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "‘%s’ код %C није члан структуре ‘%s’"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Удвостручена етикета наредбе %d код %L и %L"
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Етикета %d код %C је већ поменута као циљ гранања"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Етикета %d код %C је већ поменута код етикета формата"
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Етикета %d код %C је претходно употребљена као етикета формата"
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Етикета %d код %C је претходно употребљена као циљ гранања"
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Име ‘%s’ код %C је двосмислен упућивач на ‘%s’ из модула ‘%s’"
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
@@ -57658,65 +57712,65 @@
 msgstr "Име ‘%s’ код %C је двосмислен упућивач на ‘%s’ из текуће програмске јединице"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Симбол ‘%s’ код %C је већ придружен домаћину"
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -58002,7 +58056,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr "Лош У/И основни тип (%d)"
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_omp_workshare(): Bad statement code"
@@ -62293,6 +62347,9 @@
 #~ msgid "info pointer NULL"
 #~ msgstr "инфопоказивач нулти"
 
+#~ msgid "-munix=98 option required for C89 Amendment 1 features.\n"
+#~ msgstr "опција -munix=98 потребна за могућности из амандмана 1 Ц-а 89.\n"
+
 #~ msgid "unknown -mtraceback arg %qs; expecting %<full%>, %<partial%> or %<none%>"
 #~ msgstr "непознат арг %qs за -mtraceback; очекивах %<full%>, %<partial%> или %<none%>"
 
@@ -62566,6 +62623,9 @@
 #~ msgid "%qD has no member named %qE"
 #~ msgstr "%qD нема члан по имену %qE"
 
+#~ msgid "ISO C++ forbids subscripting non-lvalue array"
+#~ msgstr "ИСО Ц++ забрањује индексирање не-л-вредносног низа"
+
 #~ msgid "at this point in file"
 #~ msgstr "на овом месту у датотеци"
 
Index: gcc/po/da.po
===================================================================
--- gcc/po/da.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/da.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -32,6 +32,7 @@
 # dereference -> følge
 # discard -> fjerne
 # discard -> kassere
+# divide -> division
 # driver -> styringsprogram
 # duplicate -> optræder mere end én gang; mangfoldiggøre
 # edge list -> kantliste
@@ -80,6 +81,7 @@
 # null pointer -> nul[-]henvisning
 # offset -> forskydning
 # opcodes (til ovenstående) -> instruktioner
+# option -> tilvalg
 # out of range -> uden for det gyldige (til tider mulige) interval
 # overflow -> (til tider) løber over
 # overlap -> [interval]sammenfald
@@ -96,6 +98,7 @@
 # scope -> virkningsfelt
 # shadowing -> skygger for
 # shift -> skift
+# slice -> skive (NB UAFKLARET, BEDRE FORSLAG?)
 # specified -> (oftest) angivet
 # specifier -> anvisning, angivelse
 # stab -> stik (?)
@@ -130,10 +133,10 @@
 #
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 5.1.0\n"
+"Project-Id-Version: gcc 5.2.0\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
-"PO-Revision-Date: 2015-04-29 18:00+0200\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
+"PO-Revision-Date: 2015-08-16 18:00+0200\n"
 "Last-Translator: Joe Hansen <joedalton2@yahoo.dk>\n"
 "Language-Team: Danish <dansk@dansk-gruppen.dk>\n"
 "Language: da\n"
@@ -318,13 +321,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "kommatalskonstant misbrugt"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -477,14 +480,12 @@
 msgstr "  -print-multi-os-directory Vis den relative sti for OS-biblioteker\n"
 
 #: gcc.c:3197
-#, fuzzy
-#| msgid "  -dumpmachine             Display the compiler's target processor\n"
 msgid "  -print-sysroot           Display the target libraries directory\n"
-msgstr "  -dumpmachine             Vis oversætterens målprocessor\n"
+msgstr "  -print-sysroot           Vis mappen for målets biblioteker\n"
 
 #: gcc.c:3198
 msgid "  -print-sysroot-headers-suffix Display the sysroot suffix used to find headers\n"
-msgstr ""
+msgstr "  -print-sysroot-headers-suffix Vis sysroot-suffikset brugt til at finde teksthoveder\n"
 
 #: gcc.c:3199
 msgid "  -Wa,<options>            Pass comma-separated <options> on to the assembler\n"
@@ -499,9 +500,8 @@
 msgstr "  -Wl,<tilvalg>            Videregiv komma-adskilte <tilvalg> til sammenkæderen\n"
 
 #: gcc.c:3202
-#, fuzzy
 msgid "  -Xassembler <arg>        Pass <arg> on to the assembler\n"
-msgstr "  -Xlinker <para>          Videregiv <para> til sammenkæderen\n"
+msgstr "  -Xassembler <para>       Videregiv <para> til maskinkodeoversætteren\n"
 
 #: gcc.c:3203
 msgid "  -Xpreprocessor <arg>     Pass <arg> on to the preprocessor\n"
@@ -1533,7 +1533,7 @@
 msgid "options enabled: "
 msgstr "tilvalg slået til: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2912,97 +2912,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "ugyldig operandkode '%c'"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "ugyldig %%H-værdi"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "ugyldig %%J-værdi"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "ugyldig %%r-værdi"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "ugyldig %%R-værdi"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "ugyldig %%N-værdi"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "ugyldig %%P-værdi"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "ugyldig %%h-værdi"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "ugyldig %%L-værdi"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "ugyldig %%m-værdi"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "ugyldig %%M-værdi"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "ugyldig %%U-værdi"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "ugyldig %%s-værdi"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "ugyldig %%C-værdi"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "ugyldig %%E-værdi"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "ukendt relokaliserings-unspec"
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ugyldig %%xn-kode"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid operand address"
@@ -3055,7 +3055,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "ugyldig operand-uddatakode"
@@ -3230,8 +3230,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3490,71 +3490,71 @@
 msgid "bad output_condmove_single operand"
 msgstr "Ugyldig output_condmove_single-operand"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ugyldig UNSPEC som operand"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 #| msgid "invalid operand to %%p code"
 msgid "invalid operand size for operand code 'O'"
 msgstr "ugyldig operand til %%p-koden"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 #| msgid "invalid operand to %%p code"
 msgid "invalid operand size for operand code 'z'"
 msgstr "ugyldig operand til %%p-koden"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, fuzzy, c-format
 #| msgid "invalid operand output code"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ugyldig operand-uddatakode"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 #| msgid "invalid operand to %%p code"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ugyldig operand til %%p-koden"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operand er hverken en konstant eller en betingelseskode, ugyldig operandkode 'c'"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand er hverken en konstant eller en betingelseskode, ugyldig operandkode 'c'"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand er hverken en konstant eller en betingelseskode, ugyldig operandkode 'c'"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand er hverken en konstant eller en betingelseskode, ugyldig operandkode 'c'"
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, fuzzy, c-format
 #| msgid "invalid operand code `%c'"
 msgid "invalid operand code '%c'"
 msgstr "ugyldig operandkode '%c'"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ugyldige begrænsninger for operand"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "ukendt instruktionstilstand"
 
@@ -3601,7 +3601,7 @@
 msgid "invalid %%P operand"
 msgstr "ugyldig %%P-operand"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "ugyldig %%p-værdi"
@@ -3665,7 +3665,7 @@
 msgstr "postfiks forøgelsesadresse er ikke et register"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "ugyldig adresse"
 
@@ -3837,106 +3837,106 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory er ikke tilgængelig i lilleendet tilstand"
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 #, fuzzy
 #| msgid "bad operand"
 msgid "bad move"
 msgstr "ugyldig operand"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "ugyldig %%H-værdi"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "ugyldig %%f-værdi"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "ugyldig %%F-værdi"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "ugyldig %%G-værdi"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "ugyldig %%j-kode"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "ugyldig %%J-kode"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "ugyldig %%k-værdi"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "ugyldig %%K-værdi"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "ugyldig %%O-værdi"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "ugyldig %%q-værdi"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "ugyldig %%S-værdi"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "ugyldig %%T-værdi"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "ugyldig %%u-værdi"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "ugyldig %%v-værdi"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "ugyldig %%x-værdi"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ugyldig %%y-værdi, prøv at brug »Z«-begrænsningen"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "for få parametre til funktionen"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 #| msgid "Do not generate code for a Sun FPA"
 msgid "Could not generate addis value for fusion"
 msgstr "Generér ikke kode til en Sun FPA"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load offset for fusion"
@@ -4043,66 +4043,66 @@
 msgid "invalid operand to %%S"
 msgstr "ugyldig operand til %%R-koden"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 #, fuzzy
 #| msgid "created and used with differing settings of `-m%s'"
 msgid "created and used with different architectures / ABIs"
 msgstr "oprettet og brugt med en anden indstilling af '-m%s'"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 #, fuzzy
 #| msgid "created and used with differing settings of `-m%s'"
 msgid "created and used with different ABIs"
 msgstr "oprettet og brugt med en anden indstilling af '-m%s'"
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 #, fuzzy
 #| msgid "created and used with differing settings of `-m%s'"
 msgid "created and used with different endianness"
 msgstr "oprettet og brugt med en anden indstilling af '-m%s'"
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "ugyldig %%Y-operand"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "ugyldig %%A-operand"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "ugyldig %%B-operand"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, c-format
 msgid "invalid %%C operand"
 msgstr "ugyldig %%C-operand"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, c-format
 msgid "invalid %%D operand"
 msgstr "ugyldig %%D-operand"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "ugyldig %%f-operand"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "ugyldig %%s-operand"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "long long-konstant er ikke en gyldig umiddelbar operand"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "kommatalskonstant er ikke en gyldig umiddelbar operand"
@@ -4330,7 +4330,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<;%>"
@@ -4347,9 +4347,9 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<(%>"
@@ -4356,7 +4356,7 @@
 msgstr "';' forventet"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<,%>"
@@ -4379,8 +4379,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<)%>"
@@ -4388,8 +4388,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<]%>"
@@ -4399,14 +4399,14 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr ""
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<}%>"
 msgstr "';' forventet"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<{%>"
@@ -4414,8 +4414,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<:%>"
@@ -4437,7 +4437,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr ""
@@ -4456,37 +4456,37 @@
 msgid "expected %<.%>"
 msgstr "';' forventet"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<@end%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<>%>"
 msgstr "';' forventet"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<=%>"
 msgstr "';' forventet"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<[%>"
@@ -4498,12 +4498,12 @@
 msgid "(anonymous)"
 msgstr "((anonym))"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 #, fuzzy
 msgid "candidate 1:"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 #, fuzzy
 msgid "candidate 2:"
 msgstr "candidate%s: %+#D"
@@ -4755,12 +4755,12 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 #, fuzzy
 msgid "candidates are:"
 msgstr "candidate%s: %+#D"
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -4823,50 +4823,50 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "forkert parametertype til unært minus"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "forkert parametertype til unært plus"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "forkert parametertype til bitkomplement"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "forkert parametertype til abs"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "forkert parametertype til konjugation"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "forkert parametertype til unært plus"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4970,7 +4970,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "heltalsoverløb i udtryk"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 #, fuzzy
 #| msgid "assignment"
 msgid "array assignment"
@@ -4992,7 +4992,7 @@
 msgid "Driving:"
 msgstr "advarsel: "
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -5073,13 +5073,13 @@
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -5179,7 +5179,7 @@
 msgid "Bad type in constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 #, fuzzy
 #| msgid "unexpected PIC symbol"
 msgid "Unexpected end of module"
@@ -5215,11 +5215,11 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr "tildeling"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 #, fuzzy
 #| msgid "assignment"
 msgid "pointer assignment"
@@ -5239,221 +5239,221 @@
 msgid "internal function"
 msgstr "I funktionen"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 #| msgid "no arguments"
 msgid "pointer argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-shape argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "parametrized derived type argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 #, fuzzy
 #| msgid "Do not allocate BK register"
 msgid "pointer or allocatable result"
 msgstr "Allokér ikke BK-registeret"
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 #, fuzzy
 #| msgid "`%V' qualifiers cannot be applied to `%T'"
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "modifikationerne '%V' kan ikke anvendes på '%T'"
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr ""
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ugyldigt udtryk som operand"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5877,16 +5877,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr ""
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr ""
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr ""
-
 #: config/sol2.h:222 config/sol2.h:227
 #, fuzzy
 msgid "does not support multilib"
@@ -5902,6 +5892,12 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "-membedded-pic og -mabicalls er indbyrdes uforenelige"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+#, fuzzy
+#| msgid "profiling not supported with -mg\n"
+msgid "profiling not supported with -mg"
+msgstr "profilgenerering understøttes ikke med -mg\n"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "-mhard-float understøttes ikke"
@@ -5912,10 +5908,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "-msingle-float og -msoft-float er indbyrdes uforenelige"
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr "m210 har ikke understøttelse for lilleendet"
-
 #: config/cris/cris.h:184
 #, fuzzy
 #| msgid "cannot specify both -C and -o"
@@ -5950,6 +5942,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr ""
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5956,6 +5954,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr "-m32 og -m64 er indbyrdes uforenelige"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr ""
+
 #: config/s390/tpf.h:106
 #, fuzzy
 #| msgid "-traditional is not supported in C++"
@@ -5972,6 +5974,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian og -mlittle-endian kan ikke bruges på samme tid"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr "m210 har ikke understøttelse for lilleendet"
+
 #: config/avr/specs.h:68
 #, fuzzy
 #| msgid "-pipe is not supported"
@@ -6002,17 +6008,19 @@
 msgid "no processor type specified for linking"
 msgstr "specifikationsfil har ingen specifikation til sammenkædning"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr ""
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr ""
 
@@ -6051,12 +6059,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "Tilvalget -shared understøttes i øjeblikket ikke for VAX ELF."
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-#, fuzzy
-#| msgid "profiling not supported with -mg\n"
-msgid "profiling not supported with -mg"
-msgstr "profilgenerering understøttes ikke med -mg\n"
-
 #: fortran/lang.opt:146
 msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgstr ""
@@ -6264,9 +6266,9 @@
 msgstr ""
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -6487,10 +6489,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -6536,7 +6538,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, fuzzy, c-format
 msgid "missing filename after %qs"
 msgstr "et filnavn mangler efter '-%s'"
@@ -8084,10 +8086,8 @@
 msgstr "Udsend kaldegrafinfo"
 
 #: config/mcore/mcore.opt:43
-#, fuzzy
-#| msgid "Do not use the divide instruction"
 msgid "Use the divide instruction"
-msgstr "Benyt ikke divisionsinstruktionen"
+msgstr "Benyt divisionsinstruktionen"
 
 #: config/mcore/mcore.opt:47
 msgid "Inline constants if it can be done in 2 insns or less"
@@ -8602,48 +8602,52 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr "Antag at målprocessoren er konfigureret som lilleendet"
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 #, fuzzy
 #| msgid "Specify the MCU name"
 msgid "Specify the code model"
 msgstr "Angiv MCU-navnet"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr "Antag ikke at ujusterede tilgange håndteres af systemet"
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr "Udelad rammehenvisningen i de yderste funktioner"
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr "Benyt faciliteter fra og planlæg koden til en given processor"
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -9810,7 +9814,7 @@
 
 #: config/i386/i386.opt:844
 msgid "Expand 32bit/64bit integer divide into 8bit unsigned integer divide with run-time check"
-msgstr ""
+msgstr "Udvid 32-bit/64-bit heltalsdivision til 8-bit ej underskrevet heltalsdivision med kørselstidskontrol"
 
 #: config/i386/i386.opt:848
 msgid "Split 32-byte AVX unaligned load"
@@ -9832,10 +9836,16 @@
 msgstr "Ikke-understøttet; påvirker kodegenerering af tabeller"
 
 #: config/i386/i386.opt:864
+#, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "Understøt indbyggede MMX- og SSE-funktioner og kodegenerering"
+
+#: config/i386/i386.opt:868
 msgid "Use given stack-protector guard"
 msgstr ""
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr ""
 
@@ -10240,7 +10250,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -10409,7 +10419,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
@@ -10548,7 +10558,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr "Benyt stubbe til funktionsindledninger"
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr "Indlæs ikke PIC-registeret i funktionsbegyndelser"
 
@@ -10752,10 +10762,8 @@
 msgstr "Benyt faciliteter fra og planlæg koden til en given processor"
 
 #: config/sparc/sparc.opt:199
-#, fuzzy
-#| msgid "Use given SPARC code model"
 msgid "Use given SPARC-V9 code model"
-msgstr "Benyt given SPARC-kodemodel"
+msgstr "Benyt given SPARC-V9-kodemodel"
 
 #: config/sparc/sparc.opt:203
 msgid "Enable debug output"
@@ -10778,18 +10786,16 @@
 msgstr ""
 
 #: config/rs6000/darwin.opt:38 config/rs6000/sysv4.opt:141
-#, fuzzy
 msgid "Generate 64-bit code"
-msgstr "Generér 64 bit x86-64-kode"
+msgstr "Opret 64-bit kode"
 
 #: config/rs6000/darwin.opt:42 config/rs6000/sysv4.opt:145
-#, fuzzy
 msgid "Generate 32-bit code"
-msgstr "Generér 64 bit i386-kode"
+msgstr "Opret 32-bit kode"
 
 #: config/rs6000/rs6000-tables.opt:24
 msgid "Known CPUs (for use with the -mcpu= and -mtune= options):"
-msgstr ""
+msgstr "Kendte cpu'er (for brug med tilvalgene -mcpu= og -mtune=):"
 
 #: config/rs6000/476.opt:24
 msgid "Preserve the PowerPC 476's link stack by matching up a blr with the bcl/bl insns used for GOT accesses"
@@ -10804,10 +10810,8 @@
 msgstr "Oversæt for 32 bit-henvisninger"
 
 #: config/rs6000/aix64.opt:32 config/rs6000/linux64.opt:28
-#, fuzzy
-#| msgid "Use given SPARC code model"
 msgid "Select code model"
-msgstr "Benyt given SPARC-kodemodel"
+msgstr "Vælg kodemodel"
 
 #: config/rs6000/aix64.opt:49
 msgid "Support message passing with the Parallel Environment"
@@ -10831,21 +10835,16 @@
 msgstr "Benyt valgfrie instruktioner fra PowerPC Graphics-gruppen"
 
 #: config/rs6000/rs6000.opt:121
-#, fuzzy
 msgid "Use PowerPC V2.01 single field mfcr instruction"
-msgstr "Generér char-instruktioner"
+msgstr "Benyt PowerPC V2.01-enkeltfelt mfcr-instruktion"
 
 #: config/rs6000/rs6000.opt:125
-#, fuzzy
-#| msgid "Use PowerPC instruction set"
 msgid "Use PowerPC V2.02 popcntb instruction"
-msgstr "Benyt PowerPC-instruktionssættet"
+msgstr "Benyt PowerPC V2.02 popcntb-instruktion"
 
 #: config/rs6000/rs6000.opt:129
-#, fuzzy
-#| msgid "Use hardware floating point instructions"
 msgid "Use PowerPC V2.02 floating point rounding instructions"
-msgstr "Benyt hardware-kommatalsinstruktioner"
+msgstr "Benyt PowerPC V2.02-kommatalsafrundingsinstruktioner"
 
 #: config/rs6000/rs6000.opt:133
 msgid "Use PowerPC V2.05 compare bytes instruction"
@@ -10902,355 +10901,347 @@
 msgstr ""
 
 #: config/rs6000/rs6000.opt:193
-#, fuzzy
-#| msgid "Use AltiVec instructions"
 msgid "Use vector/scalar (VSX) instructions"
-msgstr "Benyt AltiVec-instruktioner"
+msgstr "Benyt vektor/skalar-instruktioner (VSX)"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr "Generér ikke indlæsning/lagring med opdateringsinstruktioner"
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr "Generér indlæsning/lagring med opdateringsinstruktioner"
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 #, fuzzy
 #| msgid "Do not generate load/store multiple instructions"
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr "Generér ikke flere indlæsnings-/lagringsinstruktioner"
 
-#: config/rs6000/rs6000.opt:252
-#, fuzzy
-#| msgid "`__builtin_next_arg' called without an argument"
+#: config/rs6000/rs6000.opt:256
 msgid "Mark __tls_get_addr calls with argument info"
-msgstr "`__builtin_next_arg' kaldt uden en parameter"
+msgstr "Marker __tls_get_addr-kald med parameterinformation"
 
-#: config/rs6000/rs6000.opt:259
-#, fuzzy
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
-msgstr "Planlæg ikke begyndelsen og slutningen af proceduren"
+msgstr "Planlæg begyndelsen og slutningen af proceduren"
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr "Returnér alle strukturer i hukommelse (SVR4-standard)"
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr "Returnér små strukturer i registre (SVR4-standard)"
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
-#, fuzzy
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 msgid "Generate software reciprocal divide and square root for better throughput."
-msgstr "Generér indlejrede heltalsdivisioner, optimér for båndbredde"
+msgstr "Opret programreciprok division og kvadratrod for bedre båndbredde."
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
-#, fuzzy
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr "Anbring ikke kommatalskonstanter i indholdsfortegnelsen"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr "Anbring kommatalskonstanter i indholdsfortegnelsen"
 
-#: config/rs6000/rs6000.opt:295
-#, fuzzy
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "Anbring ikke symbol+afsæt-konstanter i indholdsfortegnelsen"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr "Anbring symbol+afsæt-konstanter i indholdsfortegnelsen"
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr "Anbring alting i den regulære indholdsfortegnelse"
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 #, fuzzy
 #| msgid "Specify yes/no if VRSAVE instructions should be generated for AltiVec"
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr "Angiv yes/no hvis VRSAVE-instruktioner skal genereres til AltiVec"
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 msgid "Deprecated option.  Use -mno-vrsave instead"
-msgstr ""
+msgstr "Forældet tilvalg. Brug -mno-vrsave i stedet"
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 msgid "Deprecated option.  Use -mvrsave instead"
-msgstr ""
+msgstr "Forældet tilvalg. Brug -mvrsave i stedet"
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate isel instructions"
 msgstr "Generér char-instruktioner"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 msgid "Deprecated option.  Use -misel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate SPE SIMD instructions on E500"
 msgstr "Generér char-instruktioner"
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "Generér char-instruktioner"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 msgid "Deprecated option.  Use -mspe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "-mdebug=\tEnable debug output"
 msgstr "Aktivér fejlanalyseringsuddata"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 #, fuzzy
 #| msgid "Use AltiVec instructions"
 msgid "Use the AltiVec ABI extensions"
 msgstr "Benyt AltiVec-instruktioner"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 #, fuzzy
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "Benyt ikke AltiVec-instruktioner"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 msgid "Use the SPE ABI extensions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 #, fuzzy
 #| msgid "Do not use the Xtensa NSA option"
 msgid "Do not use the SPE ABI extensions"
 msgstr "Benyt ikke Xtensa-NSA-indstillingen"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv1 ABI"
 msgstr "Benyt EABI"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv2 ABI"
 msgstr "Benyt EABI"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 msgid "using darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 msgid "using old darwin ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr "Benyt faciliteter fra og planlæg koden til en given processor"
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 #, fuzzy
 #| msgid "Schedule code for given CPU"
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "Planlæg koden til en given processor"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 #, fuzzy
 #| msgid "Select full, part, or no traceback table"
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr "Vælg komplet, partiel eller ingen tilbagesporingstabel"
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr "Undgå alle områdegrænser ved kaldeinstruktioner"
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 #, fuzzy
 #| msgid "Generate CA code"
 msgid "Generate Cell microcode"
 msgstr "Generér CA-kode"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 #, fuzzy
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "Advar ikke når alle konstruktions-/destruktionsfunktioner er private"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 #, fuzzy
 #| msgid "Specify size of long double (64 or 128 bits)"
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr "Angiv størrelsen af long double (64 eller 128 bit)"
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 #, fuzzy
 msgid "Specify alignment of structure fields default/natural"
 msgstr "Angiv den mindste bitjustering af strukturer"
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 msgid "Valid arguments to -malign-:"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 #, fuzzy
 #| msgid "unordered comparison on non-floating point argument"
 msgid "Single-precision floating point unit"
 msgstr "uordnet sammenligning af ikke-kommatalsparameter"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 #, fuzzy
 #| msgid "Do not use the Xtensa floating-point unit"
 msgid "Double-precision floating point unit"
 msgstr "Benyt ikke kommatalsenheden til Xtensa"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 msgid "Floating point unit does not support divide & sqrt"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 #, fuzzy
 #| msgid "Specify an ABI"
 msgid "Specify Xilinx FPU."
 msgstr "Angiv en ABI"
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 #, fuzzy
 #| msgid "Align destination of the string operations"
 msgid "Allow sign extension in fusion operations"
 msgstr "Justér strengoperationernes destination"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
+#: config/rs6000/rs6000.opt:566
 #, fuzzy
 #| msgid "Use AltiVec instructions"
-msgid "Use ISA 2.07 crypto instructions"
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
 msgstr "Benyt AltiVec-instruktioner"
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Generér char-instruktioner"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -11445,21 +11436,16 @@
 msgstr ""
 
 #: config/lm32/lm32.opt:24
-#, fuzzy
 msgid "Enable multiply instructions"
-msgstr "Generér sammensatte gang/addér-instruktioner"
+msgstr "Aktiver multiply-instruktioner"
 
 #: config/lm32/lm32.opt:28
-#, fuzzy
-#| msgid "Enable parallel instructions"
 msgid "Enable divide and modulus instructions"
-msgstr "Aktivér parallelle instruktioner"
+msgstr "Aktiver division- og modulinstruktioner"
 
 #: config/lm32/lm32.opt:32
-#, fuzzy
-#| msgid "Enable parallel instructions"
 msgid "Enable barrel shift instructions"
-msgstr "Aktivér parallelle instruktioner"
+msgstr "Aktiver barrel shift-instruktioner"
 
 #: config/lm32/lm32.opt:36
 #, fuzzy
@@ -11505,7 +11491,7 @@
 
 #: config/nios2/nios2.opt:47
 msgid "Use table based fast divide (default at -O3)"
-msgstr ""
+msgstr "Benyt tabelbaseret hurtig division (standard på -03)"
 
 #: config/nios2/nios2.opt:51
 #, fuzzy
@@ -11820,10 +11806,8 @@
 msgstr ""
 
 #: config/nios2/nios2.opt:322
-#, fuzzy
-#| msgid "Do not use the divide instruction"
 msgid "Do not use the fdivd custom instruction"
-msgstr "Benyt ikke divisionsinstruktionen"
+msgstr "Benyt ikke den fdivd-tilpassede instruktion"
 
 #: config/nios2/nios2.opt:326
 msgid "Integer id (N) of fdivd custom instruction"
@@ -12257,26 +12241,20 @@
 msgstr "Benyt faciliteter fra og planlæg koden til en given processor"
 
 #: config/microblaze/microblaze.opt:56
-#, fuzzy
-#| msgid "Don't optimize block moves"
 msgid "Don't optimize block moves, use memcpy"
-msgstr "Optimér ikke blokflytninger"
+msgstr "Optimer ikke blokflytninger, brug memcpy"
 
 #: config/microblaze/microblaze.opt:68
-#, fuzzy
-#| msgid "Use data cache for volatile mem refs (default)"
 msgid "Use the soft multiply emulation (default)"
-msgstr "Benyt datamellemlager for volatile hukommelsesreferencer (standard)"
+msgstr "Benyt den bløde multiply-emulering (standard)"
 
 #: config/microblaze/microblaze.opt:72
 msgid "Use reorder instructions (swap and byte reversed load/store) (default)"
-msgstr ""
+msgstr "Benyt instruktioner for ny rækkefølge (swap og byte vendt om indlæs/lager) (standard)"
 
 #: config/microblaze/microblaze.opt:76
-#, fuzzy
-#| msgid "Use data cache for volatile mem refs (default)"
 msgid "Use the software emulation for divides (default)"
-msgstr "Benyt datamellemlager for volatile hukommelsesreferencer (standard)"
+msgstr "Benyt programemuleringen for divisioner (standard)"
 
 #: config/microblaze/microblaze.opt:80
 #, fuzzy
@@ -13192,10 +13170,8 @@
 msgstr ""
 
 #: config/mep/mep.opt:78
-#, fuzzy
-#| msgid "Do not use the divide instruction"
 msgid "Enable 32-bit divide instructions"
-msgstr "Benyt ikke divisionsinstruktionen"
+msgstr "Aktiver 32-bit divisionsinstruktioner"
 
 #: config/mep/mep.opt:93
 msgid "__io vars are volatile by default"
@@ -13206,10 +13182,8 @@
 msgstr ""
 
 #: config/mep/mep.opt:101
-#, fuzzy
-#| msgid "Enable parallel instructions"
 msgid "Enable leading zero instructions"
-msgstr "Aktivér parallelle instruktioner"
+msgstr "Aktiver foranstaillede zero-instruktioner"
 
 #: config/mep/mep.opt:108
 #, fuzzy
@@ -13334,10 +13308,8 @@
 msgstr "Forårsag ikke undtagelse ved heltalsdivision med nul"
 
 #: config/mips/mips.opt:112
-#, fuzzy
-#| msgid "Enable use of DB instruction"
 msgid "Allow the use of MDMX instructions"
-msgstr "Aktivér brug af DB-instruktioner"
+msgstr "Tillade brugen af MDMX-instruktioner"
 
 #: config/mips/mips.opt:116
 msgid "Allow hardware floating-point instructions to cover both 32-bit and 64-bit operations"
@@ -13344,22 +13316,16 @@
 msgstr ""
 
 #: config/mips/mips.opt:120
-#, fuzzy
-#| msgid "Don't use MIPS16 instructions"
 msgid "Use MIPS-DSP instructions"
-msgstr "Benyt ikke MIPS16-instruktioner"
+msgstr "Benyt MIPS-DSP-instruktioner"
 
 #: config/mips/mips.opt:124
-#, fuzzy
-#| msgid "Use POWER2 instruction set"
 msgid "Use MIPS-DSP REV 2 instructions"
-msgstr "Benyt POWER2-instruktionssættet"
+msgstr "Benyt MIPS-DSP REV 2-instruktioner"
 
 #: config/mips/mips.opt:146
-#, fuzzy
-#| msgid "Use the bit-field instructions"
 msgid "Use Enhanced Virtual Addressing instructions"
-msgstr "Benyt bitfeltinstruktionerne"
+msgstr "Benyt Enhanced Virtual Addressing-instruktioner"
 
 #: config/mips/mips.opt:150
 msgid "Use NewABI-style %reloc() assembly operators"
@@ -13367,7 +13333,7 @@
 
 #: config/mips/mips.opt:154
 msgid "Use -G for data that is not defined by the current object"
-msgstr ""
+msgstr "Benyt -G for data som ikke er defineret af det nuværende objekt"
 
 #: config/mips/mips.opt:158
 msgid "Work around certain 24K errata"
@@ -13374,16 +13340,12 @@
 msgstr ""
 
 #: config/mips/mips.opt:162
-#, fuzzy
-#| msgid "Work around early 4300 hardware bug"
 msgid "Work around certain R4000 errata"
-msgstr "Arbejd rundt om tidlig 4300-hardwarefejl"
+msgstr "Arbejd rundt om bestemte R4000-fejl"
 
 #: config/mips/mips.opt:166
-#, fuzzy
-#| msgid "Work around early 4300 hardware bug"
 msgid "Work around certain R4400 errata"
-msgstr "Arbejd rundt om tidlig 4300-hardwarefejl"
+msgstr "Arbejd rundt om bestemte R4400-fejl"
 
 #: config/mips/mips.opt:170
 msgid "Work around certain RM7000 errata"
@@ -14471,1761 +14433,1737 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr "  -dumpbase <fil>         Basisnavn til brug for dump fra specifikke faser\n"
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "Justér begyndelsen af funktioner"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr "Justér etiketter som kun nås ved spring"
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr "Justér alle etiketter"
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "Justér begyndelsen af løkker"
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr ""
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 #, fuzzy
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 #, fuzzy
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr "Generér afvindingstabeller eksakt for hver instruktionsgrænse"
 
-#: common.opt:918
+#: common.opt:921
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate auto-inc/dec instructions"
 msgstr "Generér char-instruktioner"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr "Benyt profileringsoplysninger til forgreningssandsynligheder"
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "Generér kode til at kontrollere grænserne før tabeller indekseres"
 
 # RETMIG: rigtig?
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr "Erstat tilføj, sammenlign, forgrening med forgrening på tælleregister"
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr "Benyt profileringsoplysninger til forgreningssandsynligheder"
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr ""
 
-#: common.opt:960
+#: common.opt:963
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr "-fcall-saved-<register>\tMarker <register> som værende bevaret over funktioner"
 
-#: common.opt:964
+#: common.opt:967
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr "-fcall-used-<register>\tMarker <register> som værende benyttet af funktionskald"
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr "Gem registre omkring funktionskald"
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr "Sammenlign resultaterne for flere dataafhængighedsanalyseprogrammer."
 
-#: common.opt:979
+#: common.opt:982
 msgid "Check the return value of new in C++"
 msgstr "Kontroller returværdien for new i C++"
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr "Anbring ikke uklargjorte globale variabler i den fælles sektion"
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr ""
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr ""
 
-#: common.opt:1003
+#: common.opt:1006
 #, fuzzy
 #| msgid "Reschedule instructions after register allocation"
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr "Omplanlæg instruktioner efter registerallokering"
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr ""
 
-#: common.opt:1011
+#: common.opt:1014
 #, fuzzy
 msgid "Perform a register copy-propagation optimization pass"
 msgstr "Foretag registerkopipropageringsoptimering"
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr "Udfør krydsspringsoptimering"
 
 # RETMIG: hvad er CSE?
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr "Ved kørsel af CSE følg spring til deres mål"
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr ""
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr ""
 
-#: common.opt:1035
+#: common.opt:1038
 #, fuzzy
 msgid "Place data items into their own section"
 msgstr "placér dataelementer i deres egen sektion"
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr ""
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr ""
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr "Vent med fjernelse af funktionsparametre fra stakken til senere"
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr "Forsøg at udfylde ventepladser med forgreningsinstruktioner"
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr "Fjern ubrugelige nul-henvisningstjek"
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization"
 msgstr "Udfør superbloksformering vha. haleduplikering"
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1085
+#: common.opt:1088
 #, fuzzy
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr "  -fdiagnostics-show-location=[once | every-line] Indikerer hvor ofte kildeplaceringsoplysninger skal udsendes som præfiks til begyndelsen af meddelelserne ved linjeombrydning\n"
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1145
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr ""
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr ""
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr ""
 
-#: common.opt:1157
+#: common.opt:1160
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps"
 msgstr "Undtryk udskrift af instruktionstal og linjenummernoter i fejlfindingsdump"
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 #, fuzzy
 msgid "Dump optimization passes"
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:1170
+#: common.opt:1173
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr "Undtryk udskrift af instruktionstal og linjenummernoter i fejlfindingsdump"
 
-#: common.opt:1174
+#: common.opt:1177
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr "Undtryk udskrift af instruktionstal og linjenummernoter i fejlfindingsdump"
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1185
 #, fuzzy
 msgid "Perform early inlining"
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr "Udfør DWARF2-eliminering af dubletter"
 
-#: common.opt:1190
+#: common.opt:1193
 msgid "Perform interprocedural reduction of aggregates"
 msgstr ""
 
-#: common.opt:1194
+#: common.opt:1197
 msgid "Perform unused symbol elimination in debug info"
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "Aktivér undtagelseshåndtering"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr "Udfør et antal mindre, dyre optimeringer"
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr ""
 
-#: common.opt:1217
+#: common.opt:1220
 #, fuzzy, c-format
 #| msgid "unknown string token %s\n"
 msgid "unknown excess precision style %qs"
 msgstr "ukendt strengsymbol %s\n"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 #, fuzzy
 msgid "Assume no NaNs or infinities are generated"
 msgstr "Antag at ingen NaN eller +-Inf bliver genereret"
 
-#: common.opt:1238
+#: common.opt:1241
 #, fuzzy
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr "  -ffixed-<register>      Markér <register> som værende utilgængeligt for oversætteren\n"
 
-#: common.opt:1242
+#: common.opt:1245
 #, fuzzy
 #| msgid "Control allocation order of integer registers"
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr "Kontrollér tildelingsordenen for heltalsregistrene"
 
-#: common.opt:1250
+#: common.opt:1253
 #, fuzzy
 msgid "Perform a forward propagation pass on RTL"
 msgstr "Foretag registerkopipropageringsoptimering"
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, fuzzy, c-format
 #| msgid "Use hardware floating point instructions"
 msgid "unknown floating point contraction style %qs"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr "Tillad funktionsadresser at blive opbevaret i registre"
 
-#: common.opt:1278
+#: common.opt:1281
 #, fuzzy
 msgid "Place each function into its own section"
 msgstr "placér hver funktion i dens egen sektion"
 
-#: common.opt:1282
+#: common.opt:1285
 #, fuzzy
 msgid "Perform global common subexpression elimination"
 msgstr "Udfør global eliminering af fælles underudtryk"
 
-#: common.opt:1286
+#: common.opt:1289
 #, fuzzy
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr "Udfør forbedret indlæsningsbevægelse under eliminering af fælles underudtryk"
 
-#: common.opt:1290
+#: common.opt:1293
 #, fuzzy
 msgid "Perform store motion after global common subexpression elimination"
 msgstr "Udfør lagringsbevægelse efter eliminering af fælles underudtryk"
 
-#: common.opt:1294
+#: common.opt:1297
 #, fuzzy
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr "Udfør forbedret indlæsningsbevægelse under eliminering af fælles underudtryk"
 
-#: common.opt:1299
+#: common.opt:1302
 #, fuzzy
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr "Udfør global eliminering af fælles underudtryk"
 
-#: common.opt:1305
+#: common.opt:1308
 #, fuzzy
 #| msgid "Enable automatic template instantiation"
 msgid "Enable in and out of Graphite representation"
 msgstr "Aktivér automatisk skabelonsinstantiering"
 
-#: common.opt:1309
+#: common.opt:1312
 #, fuzzy
 #| msgid "Emit call graph information"
 msgid "Enable Graphite Identity transformation"
 msgstr "Udsend kaldegrafinfo"
 
-#: common.opt:1313
+#: common.opt:1316
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr ""
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr ""
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr ""
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr ""
 
-#: common.opt:1330
+#: common.opt:1333
 #, fuzzy
 #| msgid "Enable linker relaxation"
 msgid "Enable Loop Blocking transformation"
 msgstr "Aktivér tolerant sammenkæder"
 
-#: common.opt:1334
+#: common.opt:1337
 msgid "Enable Loop Unroll Jam transformation"
 msgstr ""
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 #, fuzzy
 msgid "Enable guessing of branch probabilities"
 msgstr "Aktivér gæt af forgreningssandsynligheder"
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr "Behandl #ident-direktiver"
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr "Udfør konvertering af betingede spring til forgreningsløse ækvivalenter"
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr "Udfør konvertering af betingede spring til betinget udførsel"
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1394
+#: common.opt:1397
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr "Udfør konvertering af betingede spring til forgreningsløse ækvivalenter"
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr ""
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr "Generér ikke .size-direktiver"
 
-#: common.opt:1410
+#: common.opt:1413
 msgid "Perform indirect inlining"
 msgstr ""
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 #, fuzzy
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "Integrér simple funktioner i deres kaldere"
 
-#: common.opt:1424
+#: common.opt:1427
 #, fuzzy
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "Integrér simple funktioner i deres kaldere"
 
-#: common.opt:1428
+#: common.opt:1431
 #, fuzzy
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions only required by their single caller"
 msgstr "Integrér simple funktioner i deres kaldere"
 
-#: common.opt:1435
+#: common.opt:1438
 #, fuzzy
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr "  -finline-limit=<str>    Begræns størrelsen af inlie funktion til <str>\n"
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 #, fuzzy
 msgid "Instrument function entry and exit with profiling calls"
 msgstr "Instrumentér funktionsindgange/-afslutninger med profileringskald"
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1458
 #, fuzzy
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Perform interprocedural constant propagation"
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1466
 #, fuzzy
 #| msgid "how much can given compilation unit grow because of the inlining (in percent)"
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr "Hvor meget en oversættelsesenhed kan vokse pga. indlejring (i procent)"
 
-#: common.opt:1467
+#: common.opt:1470
 msgid "Perform interprocedural profile propagation"
 msgstr ""
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1478
 #, fuzzy
 #| msgid "Discard unused virtual functions"
 msgid "Discover pure and const functions"
 msgstr "Kassér ubrugte virtuelle funktioner"
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables"
 msgstr "Udfør løkkeudrulning for alle løkker"
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr ""
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr ""
 
-#: common.opt:1506
+#: common.opt:1509
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA algorithm %qs"
 msgstr "ukendt registernavn: %s"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr ""
 
-#: common.opt:1519
+#: common.opt:1522
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA region %qs"
 msgstr "ukendt registernavn: %s"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1545
 #, fuzzy
 #| msgid "Store locals in argument registers"
 msgid "Share slots for saving different hard registers."
 msgstr "Gem lokale variable i parameterregistre"
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1561
 #, fuzzy
 #| msgid "case label not within a switch statement"
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
 
-#: common.opt:1562
+#: common.opt:1565
 #, fuzzy
 msgid "Generate code for functions even if they are fully inlined"
 msgstr "Generér kode for funktioner selv hvis de indlejres helt"
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr "Konstruér statiske, konstante variabler selv hvis de ikke bruges"
 
-#: common.opt:1570
+#: common.opt:1573
 #, fuzzy
 msgid "Give external symbols a leading underscore"
 msgstr "Eksterne symboler har indledende understreg"
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable link-time optimization."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown LTO partitioning model %qs"
 msgstr "ukendt maskintilstand '%s'"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr ""
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 #, fuzzy
 msgid "Report various link-time optimization statistics"
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:1625
+#: common.opt:1628
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr "Sæt errno efter indbyggede matematikfunktioner"
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1640
 #, fuzzy
 msgid "Report on permanent memory allocation"
 msgstr "Rapportér om permanente hukommelsesallokering ved afslutningen af kørslen"
 
-#: common.opt:1641
+#: common.opt:1644
 #, fuzzy
 msgid "Report on permanent memory allocation in WPA only"
 msgstr "Rapportér om permanente hukommelsesallokering ved afslutningen af kørslen"
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr "Forsøg at forene identiske konstanter og konstante variabler"
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr "Forsøg at forene identiske konstanter over forskellige oversættelsesenheder"
 
-#: common.opt:1656
+#: common.opt:1659
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr "Forsøg at forene identiske konstanter over forskellige oversættelsesenheder"
 
-#: common.opt:1660
+#: common.opt:1663
 #, fuzzy
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr "  -fmessage-length=<antal>  Begræns længden af diagnosticeringmeddelelser til længden <antal> tegn/linje. 0 undertrykker linjeombrydning\n"
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1675
 #, fuzzy
 #| msgid "Force all loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops"
 msgstr "Tving alle løkkeinvariansberegninger ud af løkker"
 
-#: common.opt:1676
+#: common.opt:1679
 #, fuzzy
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Use the RTL dead code elimination pass"
 msgstr "Aktivér aggressiv SSA-eliminering af ubrugt kode"
 
-#: common.opt:1680
+#: common.opt:1683
 #, fuzzy
 msgid "Use the RTL dead store elimination pass"
 msgstr "Foretag en komplet registerflytningsoptimering"
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr "Understøt synkrone ikke-kaldende undtagelser"
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 #| msgid "target missing after %s"
 msgid "options or targets missing after %qs"
 msgstr "et mål mangler efter %s"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 msgid "unknown offload ABI %qs"
 msgstr "'%s': ukendt tls-model-tilvalg"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr "Generér ikke stakrammer når det kan undgås"
 
-#: common.opt:1713
+#: common.opt:1716
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable all optimization info dumps on stderr"
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr "Optimér søskende- og halerekursive kald"
 
-#: common.opt:1729
+#: common.opt:1732
 #, fuzzy
 msgid "Perform partial inlining"
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr ""
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr "Pak strukturmedlemmer sammen uden mellemrum"
 
-#: common.opt:1745
+#: common.opt:1748
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr ""
 
-#: common.opt:1749
+#: common.opt:1752
 #, fuzzy
 msgid "Return small aggregates in memory, not registers"
 msgstr "Returnér små sammensatte værdier i hukommelsen, ikke i registre"
 
-#: common.opt:1753
+#: common.opt:1756
 #, fuzzy
 msgid "Perform loop peeling"
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr "Aktivér maskinspecifikke kighulsoptimeringer"
 
-#: common.opt:1761
+#: common.opt:1764
 #, fuzzy
 msgid "Enable an RTL peephole pass before sched2"
 msgstr "Aktivér en RTL-kikhulsfase før sched2"
 
-#: common.opt:1765
+#: common.opt:1768
 #, fuzzy
 msgid "Generate position-independent code if possible (large mode)"
 msgstr "Generér placeringsuafhængig kode, om muligt"
 
-#: common.opt:1769
+#: common.opt:1772
 #, fuzzy
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr "Generér placeringsuafhængig kode, om muligt"
 
-#: common.opt:1773
+#: common.opt:1776
 #, fuzzy
 msgid "Generate position-independent code if possible (small mode)"
 msgstr "Generér placeringsuafhængig kode, om muligt"
 
-#: common.opt:1777
+#: common.opt:1780
 #, fuzzy
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr "Generér placeringsuafhængig kode, om muligt"
 
-#: common.opt:1781
+#: common.opt:1784
 msgid "Specify a plugin to load"
 msgstr ""
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr ""
 
-#: common.opt:1789
+#: common.opt:1792
 #, fuzzy
 #| msgid "Enables a register move optimization"
 msgid "Run predictive commoning optimization."
 msgstr "Aktivér en registerflytningsoptimering"
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr "Generér præhentningsinstruktioner, hvis tilgængelige, for tabeller i løkker"
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr "Aktivér basal programprofileringskode"
 
-#: common.opt:1801
+#: common.opt:1804
 #, fuzzy
 msgid "Insert arc-based program profiling code"
 msgstr "Indsæt buebaseret programprofileringskode"
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1813
 #, fuzzy
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1821
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1826
+#: common.opt:1829
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1837
 msgid "Report on consistency of profile"
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1841
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement"
 msgstr "Omordn funktioner for at forbedre kodeplacering"
 
-#: common.opt:1845
+#: common.opt:1848
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr ""
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:1859
+#: common.opt:1862
 #, fuzzy
 msgid "Return small aggregates in registers"
 msgstr "Returnér små sammensatte værdier i registre"
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr ""
 
-#: common.opt:1876
+#: common.opt:1879
 #, fuzzy
 msgid "Perform a register renaming optimization pass"
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:1880
+#: common.opt:1883
 #, fuzzy
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr "Omordn basisblokke for at forbedre kodeplacering"
 
-#: common.opt:1888
+#: common.opt:1891
 #, fuzzy
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr "Omordn basisblokke for at forbedre kodeplacering"
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr "Omordn funktioner for at forbedre kodeplacering"
 
-#: common.opt:1896
+#: common.opt:1899
 #, fuzzy
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr "Kør CSE-fase efter løkkeoptimeringer"
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr ""
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr "Aktivér planlægning over basisblokke"
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr "Tillad spekulativ bevægelse af ikke-indlæsninger"
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr "Tillad spekulativ bevægelse af nogle indlæsninger"
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr "Tillad spekulativ bevægelse af flere indlæsninger"
 
-#: common.opt:1928
+#: common.opt:1931
 #, fuzzy
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr "  -fsched-verbose=<tal>    Angiv hvor meget planlæggeren skal fortælle\n"
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr ""
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr "Omplanlæg instruktioner før registerallokering"
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr "Omplanlæg instruktioner efter registerallokering"
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr ""
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr ""
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr ""
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1981
+#: common.opt:1984
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr ""
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1993
+#: common.opt:1996
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1997
+#: common.opt:2000
 msgid "Enable the group heuristic in the scheduler"
-msgstr ""
+msgstr "Aktiver gruppeheuristikken i planlæggeren"
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2009
+#: common.opt:2012
 msgid "Enable the rank heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr ""
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr ""
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr "Deaktivér optimeringer som kan opdages ved IEEE-signalerende NaN'er"
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr ""
 
-#: common.opt:2054
+#: common.opt:2057
 #, fuzzy
 msgid "Convert floating point constants to single precision constants"
 msgstr "Konvertér kommatalskonstanter til enkeltpræcisionskonstanter"
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr ""
 
-#: common.opt:2062
+#: common.opt:2065
 #, fuzzy
 #| msgid "Generate APCS conformant stack frames"
 msgid "Generate discontiguous stack frames"
 msgstr "Generér APCS-overholdende stakrammer"
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr ""
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 #, fuzzy
 #| msgid "Number of registers used to pass integer arguments"
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr "Antallet af registre der skal bruges til at overbringe heltalsparametre"
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr ""
 
-#: common.opt:2082
+#: common.opt:2085
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "Indsæt stakkontrolleringskode i programmet"
 
-#: common.opt:2086
+#: common.opt:2089
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "Indsæt stakkontrolleringskode i programmet"
 
-#: common.opt:2093
+#: common.opt:2096
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr ""
 
-#: common.opt:2097
+#: common.opt:2100
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr ""
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr ""
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr ""
 
-#: common.opt:2109
+#: common.opt:2112
 msgid "Use a smart stack protection method for certain functions"
 msgstr ""
 
-#: common.opt:2113
+#: common.opt:2116
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr ""
 
-#: common.opt:2117
+#: common.opt:2120
 #, fuzzy
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output stack usage information on a per-function basis"
 msgstr "Genbrug r30 på et pr. funktionsgrundlag"
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr "Antag at strenge aliasregler skal anvendes"
 
-#: common.opt:2133
+#: common.opt:2136
 #, fuzzy
 #| msgid "Set Windows defines"
 msgid "Treat signed overflow as undefined"
 msgstr "Angiv Windows-definitioner"
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
-msgstr "Kontrollér syntaks og stop derefter"
+msgstr "Kontroller for syntaksfejl og stop derefter"
 
-#: common.opt:2145
-#, fuzzy
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
-msgstr "Opret datafiler som gcov har brug for"
+msgstr "Opret datafiler som »gcov« har brug for"
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr "Udfør springtrådningsoptimeringer"
 
-#: common.opt:2153
-#, fuzzy
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
-msgstr "Rapportér den tid det tager for hver oversættelsesfase ved afslutningen af kørslen"
+msgstr "Rapporter den tid det tager for hvert kompilergennemløb"
 
-#: common.opt:2157
+#: common.opt:2160
 #, fuzzy
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr "  -ftls-model=[global-dynamic | local-dynamic | initial-exec | local-exec] Indikerer den forvalgte tråd-lokale lagringsmodel for kodegenerering\n"
 
-#: common.opt:2160
-#, fuzzy, c-format
+#: common.opt:2163
+#, c-format
 msgid "unknown TLS model %qs"
-msgstr "'%s': ukendt tls-model-tilvalg"
+msgstr "ukendt tls-model %qs"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr "Udfør superbloksformering vha. haleduplikering"
 
-#: common.opt:2187
+#: common.opt:2190
 #, fuzzy
 msgid "Assume floating-point operations can trap"
 msgstr "Kommatalsoperationer kan fange"
 
-#: common.opt:2191
+#: common.opt:2194
 #, fuzzy
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr "Opsæt fælde for overløb med fortegn i addition/subtraktion/multiplikation"
 
-#: common.opt:2195
+#: common.opt:2198
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-CCP optimization on trees"
 msgstr "Aktivér SSA-optimeringer"
 
-#: common.opt:2199
-#, fuzzy
-#| msgid "Enable SSA optimizations"
+#: common.opt:2202
 msgid "Enable SSA-BIT-CCP optimization on trees"
-msgstr "Aktivér SSA-optimeringer"
+msgstr "Aktiver SSA-BIT-CCP-optimering på træer"
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr ""
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr ""
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr ""
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr ""
 
-#: common.opt:2231
+#: common.opt:2234
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Transform condition stores into unconditional ones"
 msgstr "Udfør konvertering af betingede spring til betinget udførsel"
 
-#: common.opt:2235
+#: common.opt:2238
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversions of switch initializations."
 msgstr "Udfør konvertering af betingede spring til betinget udførsel"
 
-#: common.opt:2239
+#: common.opt:2242
 #, fuzzy
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr "Aktivér aggressiv SSA-eliminering af ubrugt kode"
 
-#: common.opt:2243
+#: common.opt:2246
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable dominator optimizations"
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2247
+#: common.opt:2250
 #, fuzzy
 #| msgid "Enable most warning messages"
 msgid "Enable tail merging on trees"
 msgstr "Aktivér de fleste advarselsbeskeder"
 
-#: common.opt:2251
+#: common.opt:2254
 #, fuzzy
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Enable dead store elimination"
 msgstr "Aktivér aggressiv SSA-eliminering af ubrugt kode"
 
-#: common.opt:2255
+#: common.opt:2258
 msgid "Enable forward propagation on trees"
 msgstr ""
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr ""
 
-#: common.opt:2263
+#: common.opt:2266
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable string length optimizations on trees"
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 #, fuzzy
 #| msgid "Enable parallel instructions"
 msgid "Enable loop distribution on trees"
 msgstr "Aktivér parallelle instruktioner"
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr ""
 
-#: common.opt:2288
+#: common.opt:2291
 #, fuzzy
 #| msgid "Force all loop invariant computations out of loops"
 msgid "Enable loop invariant motion on trees"
 msgstr "Tving alle løkkeinvariansberegninger ud af løkker"
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr ""
 
-#: common.opt:2296
+#: common.opt:2299
 #, fuzzy
 #| msgid "Strength reduce all loop general induction variables"
 msgid "Create canonical induction variables in loops"
 msgstr "Styrkereducér alle generelle løkkeinduktionsvariabler"
 
-#: common.opt:2300
+#: common.opt:2303
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable loop optimizations on tree level"
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2304
+#: common.opt:2307
 #, fuzzy
 #| msgid "Enable automatic template instantiation"
 msgid "Enable automatic parallelization of loops"
 msgstr "Aktivér automatisk skabelonsinstantiering"
 
-#: common.opt:2308
+#: common.opt:2311
 #, fuzzy
 #| msgid "Enable use of conditional move instructions"
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Aktivér brug af betingede flytteinstruktioner"
 
-#: common.opt:2312
+#: common.opt:2315
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "Aktivér SSA-optimeringer"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2324
+#: common.opt:2327
 msgid "Enable reassociation on tree level"
 msgstr ""
 
-#: common.opt:2332
-#, fuzzy
-#| msgid "Enable SSA optimizations"
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
-msgstr "Aktivér SSA-optimeringer"
+msgstr "Aktiver SSA-kodesinking på træer"
 
-#: common.opt:2336
+#: common.opt:2339
 #, fuzzy
 #| msgid "Perform strength reduction optimizations"
 msgid "Perform straight-line strength reduction"
 msgstr "Udfør styrkereduceringsoptimeringer"
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr ""
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2352
+#: common.opt:2355
 #, fuzzy
 msgid "Perform Value Range Propagation on trees"
 msgstr "Foretag registerkopipropageringsoptimering"
 
-#: common.opt:2356
+#: common.opt:2359
 #, fuzzy
 msgid "Compile whole compilation unit at a time"
 msgstr "Anbring hele oversættelsesenheden i en fil"
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr "Udfør løkkeudrulning når iterationsantallet er kendt"
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr "Udfør løkkeudrulning for alle løkker"
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr ""
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2388
+#: common.opt:2391
 #, fuzzy
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr "Tillad matematikoptimeringer der kan overtræde IEEE- eller ANSI-standarderne"
 
-#: common.opt:2392
+#: common.opt:2395
 #, fuzzy
 msgid "Perform loop unswitching"
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr "Generér blot afvindingstabeller for undtagelseshåndtering"
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2416
+#: common.opt:2419
 #, fuzzy
 #| msgid "Perform tail call optimization"
 msgid "Perform variable tracking"
 msgstr "Udfør halekaldsoptimering"
 
-#: common.opt:2424
+#: common.opt:2427
 #, fuzzy
 msgid "Perform variable tracking by annotating assignments"
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr ""
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr ""
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 msgid "Enable vectorization on trees"
 msgstr "Aktivér stakprøvning"
 
-#: common.opt:2450
+#: common.opt:2453
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable loop vectorization on trees"
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2454
+#: common.opt:2457
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr ""
 
-#: common.opt:2458
+#: common.opt:2461
 #, fuzzy
 #| msgid "Specify alternate name for bss section"
 msgid "Specifies the cost model for vectorization"
 msgstr "Angiv alternativt navn til bss-sektionen"
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown vectorizer cost model %qs"
 msgstr "ukendt maskintilstand '%s'"
 
-#: common.opt:2478
+#: common.opt:2481
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2485
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2493
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr "Tilføj ekstra kommentarer til menneskeligt læsbar maskinkodeuddata"
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr ""
 
-#: common.opt:2507
-#, fuzzy, c-format
+#: common.opt:2510
+#, c-format
 msgid "unrecognized visibility value %qs"
-msgstr "ukendt registernavn '%s'"
+msgstr "ikke genkendt synlighedsværdi %qs"
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 #| msgid "(near initialization for `%s')"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(i nærheden af klargøringen af '%s')"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 #, fuzzy
 msgid "Use expression value profiles in optimizations"
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2558
 #, fuzzy
 #| msgid "Enable use of conditional move instructions"
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr "Aktivér brug af betingede flytteinstruktioner"
 
-#: common.opt:2559
+#: common.opt:2562
 #, fuzzy
 msgid "Perform whole program optimizations"
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr "Anbring nul-klargjorte data i bss-sektionen"
 
-#: common.opt:2571
+#: common.opt:2574
 #, fuzzy
 msgid "Generate debug information in default format"
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:2575
+#: common.opt:2578
 #, fuzzy
 msgid "Generate debug information in COFF format"
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:2579
+#: common.opt:2582
 #, fuzzy
 msgid "Generate debug information in default version of DWARF format"
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:2583
+#: common.opt:2586
 #, fuzzy
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:2587
+#: common.opt:2590
 #, fuzzy
 msgid "Generate debug information in default extended format"
 msgstr "Generér fejlfindingsinfo i udvidet standardformat"
 
-#: common.opt:2591
+#: common.opt:2594
 #, fuzzy
 #| msgid "Don't generate fused multiply/add instructions"
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Generér ikke sammensatte gang/addér-instruktioner"
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
-msgstr ""
+msgstr "Opret sektioner for DWARF-pubnavne og pubtyper."
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
-msgstr ""
+msgstr "Opret sektioner for DWARF-pubnavne og pubtyper med GNU-udvidelser."
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2611
-#, fuzzy
+#: common.opt:2614
 msgid "Don't generate debug information in separate .dwo files"
-msgstr "Generér fejlfindingsinfo i standardformat"
+msgstr "Opret ikek fejlsøgningsinformation i separate .dwo-filer"
 
-#: common.opt:2615
-#, fuzzy
+#: common.opt:2618
 msgid "Generate debug information in separate .dwo files"
-msgstr "Generér fejlfindingsinfo i standardformat"
+msgstr "Opret fejlsøgningsinformation i separate .dwo-filer"
 
-#: common.opt:2619
-#, fuzzy
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
-msgstr "Generér fejlfindingsinfo i standardformat"
+msgstr "Opret fejlsøgningsinformation i STABS-format"
 
-#: common.opt:2623
-#, fuzzy
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
-msgstr "Generér fejlfindingsinfo i udvidet standardformat"
+msgstr "Opret fejlsøgningsinformation i udvidet STABS-format"
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2638
 #, fuzzy
 msgid "Toggle debug information generation"
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:2639
-#, fuzzy
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
-msgstr "Generér fejlfindingsinfo i standardformat"
+msgstr "Opret fejlsøgningsinformation i VMS-format"
 
-#: common.opt:2643
-#, fuzzy
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
-msgstr "Generér fejlfindingsinfo i standardformat"
+msgstr "Opret fejlsøgningsinformation i XCOFF-format"
 
-#: common.opt:2647
-#, fuzzy
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
-msgstr "Generér fejlfindingsinfo i udvidet standardformat"
+msgstr "Opret fejlsøgningsinformation i udvidet XCOFF-format"
 
-#: common.opt:2665
-#, fuzzy
-#| msgid "Generate char instructions"
+#: common.opt:2668
 msgid "Generate compressed debug sections"
-msgstr "Generér char-instruktioner"
+msgstr "Opret komprimeret fejlsøgningssektioner"
 
-#: common.opt:2669
+#: common.opt:2672
 #, fuzzy
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:2676
+#: common.opt:2679
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr ""
 
-#: common.opt:2680
+#: common.opt:2683
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr ""
 
-#: common.opt:2702
+#: common.opt:2705
 #, fuzzy
 msgid "-o <file>\tPlace output into <file>"
 msgstr "  -o <fil>                Anbring uddata i <fil>\n"
 
-#: common.opt:2706
+#: common.opt:2709
 #, fuzzy
 msgid "Enable function profiling"
 msgstr "MIPS16-funktionsprofilering"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr ""
 
-#: common.opt:2756
-#, fuzzy
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
-msgstr "  -quiet                  Vis ikke funktioner der oversættes eller forløbet tid\n"
+msgstr "Vis ikke funktioner der oversættes eller forløbet tid"
 
-#: common.opt:2788
-#, fuzzy
+#: common.opt:2791
 msgid "Enable verbose output"
-msgstr "Aktivér fejlanalyseringsuddata"
+msgstr "Aktiver uddybende uddata"
 
-#: common.opt:2792
-#, fuzzy
-#| msgid "  -version                Display the compiler's version\n"
+#: common.opt:2795
 msgid "Display the compiler's version"
-msgstr "  -version                Udskriv oversætterens version\n"
+msgstr "Vis oversætterens version"
 
-#: common.opt:2796
-#, fuzzy
+#: common.opt:2799
 msgid "Suppress warnings"
-msgstr "%s: advarsel: "
+msgstr "Undertryk advarsler"
 
-#: common.opt:2806
+#: common.opt:2809
 msgid "Create a shared library"
-msgstr ""
+msgstr "Opret et delt bibliotek"
 
-#: common.opt:2851
-#, fuzzy
+#: common.opt:2854
 msgid "Create a position independent executable"
-msgstr "Generér placeringsuafhængig kode, om muligt"
+msgstr "Opret en placeringsuafhængig kørbar fil"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
-#, fuzzy, gcc-internal-format
-#| msgid "%Hvalue computed is not used"
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
+#, gcc-internal-format
 msgid "value computed is not used"
-msgstr "%Hberegnet værdi benyttes ikke"
+msgstr "beregnet værdi benyttes ikke"
 
 #: go/gofrontend/expressions.cc:628
-#, fuzzy
-#| msgid "invalid use of `::'"
 msgid "invalid use of type"
-msgstr "ugyldig brug af '::'"
+msgstr "ugyldig brug af type"
 
 #: go/gofrontend/expressions.cc:2725 go/gofrontend/expressions.cc:2791
 #: go/gofrontend/expressions.cc:2807
 msgid "constant refers to itself"
-msgstr ""
+msgstr "konstant har reference til sig selv"
 
 #: go/gofrontend/expressions.cc:3704 go/gofrontend/expressions.cc:4082
 #, fuzzy
@@ -16234,310 +16172,250 @@
 msgstr "uventet operand"
 
 #: go/gofrontend/expressions.cc:4049
-#, fuzzy
 msgid "expected numeric type"
-msgstr "uventet operand"
+msgstr "forventet numerisk type"
 
 #: go/gofrontend/expressions.cc:4054
-#, fuzzy
 msgid "expected boolean type"
-msgstr "uventet operand"
+msgstr "forventet boolesk type"
 
 #: go/gofrontend/expressions.cc:4060
 msgid "expected integer or boolean type"
-msgstr ""
+msgstr "forventet heltal eller boolesk type"
 
-#: go/gofrontend/expressions.cc:5563
-#, fuzzy
-#| msgid "comparison of promoted ~unsigned with unsigned"
+#: go/gofrontend/expressions.cc:5565
 msgid "invalid comparison of nil with nil"
-msgstr "sammenligning af forfremmet ~unsigned med unsigned"
+msgstr "ugyldig sammenligning af nil med nil"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
-#, fuzzy
-#| msgid "incompatible types in %s"
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 msgid "incompatible types in binary expression"
-msgstr "uforenelige typer i %s"
+msgstr "uforenelige typer i binæret udtryk"
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 #| msgid "division by zero"
 msgid "integer division by zero"
 msgstr "division med nul"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 msgid "shift of non-integer operand"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 #, fuzzy
 #| msgid "switch quantity not an integer"
 msgid "shift count not unsigned integer"
 msgstr "switch-størrelsen er ikke et heltal"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 #, fuzzy
 #| msgid "negative insn length"
 msgid "negative shift count"
 msgstr "negativ instruktionslængde"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 #, fuzzy
 #| msgid "called object is not a function"
 msgid "object is not a method"
 msgstr "det kaldte objekt er ikke en funktion"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 #, fuzzy
 #| msgid "cast does not match function type"
 msgid "method type does not match object type"
 msgstr "typeomtvingelse passer ikke til funktionstype"
 
-#: go/gofrontend/expressions.cc:6775
-#, fuzzy
-#| msgid "invalid use of `this' in non-member function"
+#: go/gofrontend/expressions.cc:6777
 msgid "invalid use of %<...%> with builtin function"
-msgstr "ugyldig brug af 'this' i ikke-medlemsfunktion"
+msgstr "ugyldig brug af %<...%> med indbygget funktion"
 
-#: go/gofrontend/expressions.cc:6786
-#, fuzzy
-#| msgid "invalid type argument of `%s'"
+#: go/gofrontend/expressions.cc:6788
 msgid "invalid use of method value as argument of Offsetof"
-msgstr "ugyldig typeparameter '%s'"
+msgstr "ugyldig brug af metodeværdi som argument for Offsetof"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
-#, fuzzy
-#| msgid "no arguments"
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 msgid "not enough arguments"
-msgstr "ingen parametre"
+msgstr "ikke nok parametre"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
-#, fuzzy
-#| msgid "too many arguments for format"
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 msgid "too many arguments"
-msgstr "for mange parametre til formatering"
+msgstr "for mange parametre"
 
-#: go/gofrontend/expressions.cc:6890
-#, fuzzy
-#| msgid "argument 1 must be a 5-bit signed literal"
+#: go/gofrontend/expressions.cc:6892
 msgid "argument 1 must be a map"
-msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
+msgstr "1. parameter skal være en oversættelse"
 
-#: go/gofrontend/expressions.cc:7014
-#, fuzzy
-#| msgid "invalid return type for member function `%#D'"
+#: go/gofrontend/expressions.cc:7016
 msgid "invalid type for make function"
-msgstr "ugyldig returtype for medlemsfunktionen '%#D'"
+msgstr "ugyldig type for make-funktion"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
-msgstr ""
+msgstr "længde krævet når en skive allokeres"
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
-msgstr ""
+msgstr "len større end cap"
 
-#: go/gofrontend/expressions.cc:7077
-#, fuzzy
-#| msgid "too many arguments for format"
+#: go/gofrontend/expressions.cc:7079
 msgid "too many arguments to make"
-msgstr "for mange parametre til formatering"
+msgstr "for mange parametre for make"
 
-#: go/gofrontend/expressions.cc:7851
-#, fuzzy
-#| msgid "argument 1 must be a 5-bit signed literal"
+#: go/gofrontend/expressions.cc:7853
 msgid "argument must be array or slice or channel"
-msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
+msgstr "parameter skal være en array eller skive eller kanal"
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
-msgstr ""
+msgstr "parameter skal være streng eller array eller skive eller oversættelse eller kanal"
 
-# shadowing betyder at en funktion har samme navn og dermed skjuler en anden
-#: go/gofrontend/expressions.cc:7907
-#, fuzzy
-#| msgid "Support 3DNow! built-in functions"
+#: go/gofrontend/expressions.cc:7909
 msgid "unsupported argument type to builtin function"
-msgstr "Understøt indbyggede 3DNow!-funktioner"
+msgstr "ikke understøttet parametertype for indbygget funktion"
 
-#: go/gofrontend/expressions.cc:7918
-#, fuzzy
-#| msgid "argument 2 must be a 5-bit unsigned literal"
+#: go/gofrontend/expressions.cc:7920
 msgid "argument must be channel"
-msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
+msgstr "parameter skal være kanal"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
-msgstr ""
+msgstr "kan ikke lukke modtag-kun kanal"
 
-#: go/gofrontend/expressions.cc:7942
-#, fuzzy
-#| msgid "argument 1 must be a 5-bit signed literal"
+#: go/gofrontend/expressions.cc:7944
 msgid "argument must be a field reference"
-msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
+msgstr "parameter skal være en feltreference"
 
-#: go/gofrontend/expressions.cc:7972
-#, fuzzy
-#| msgid "argument 1 must be a 5-bit signed literal"
+#: go/gofrontend/expressions.cc:7974
 msgid "left argument must be a slice"
-msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
+msgstr "venstre parameter skal være en skive"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
-msgstr ""
+msgstr "elementtyper skal være ens"
 
-#: go/gofrontend/expressions.cc:7985
-#, fuzzy
+#: go/gofrontend/expressions.cc:7987
 msgid "first argument must be []byte"
-msgstr "den første parameter til '%s' skal være 'int'"
+msgstr "første parameter skal være []byte"
 
-#: go/gofrontend/expressions.cc:7988
-#, fuzzy
-#| msgid "second token after #line is not a string"
+#: go/gofrontend/expressions.cc:7990
 msgid "second argument must be slice or string"
-msgstr "det andet symbol efter #line er ikke en streng"
+msgstr "anden parameter skal være skive eller streng"
 
-#: go/gofrontend/expressions.cc:8032
-#, fuzzy
-#| msgid "bit-field `%s' has invalid type"
+#: go/gofrontend/expressions.cc:8034
 msgid "argument 2 has invalid type"
-msgstr "bitfeltet '%s' er af en ufuldstændig type"
+msgstr "parameter 2 har ugyldig type"
 
-#: go/gofrontend/expressions.cc:8048
-#, fuzzy
-#| msgid "parameter `%s' has incomplete type"
+#: go/gofrontend/expressions.cc:8050
 msgid "argument must have complex type"
-msgstr "parameteren '%s' er af en ufuldstændig type"
+msgstr "parameter skal have kompleks type"
 
-#: go/gofrontend/expressions.cc:8066
-#, fuzzy
-#| msgid "macro names must be identifiers"
+#: go/gofrontend/expressions.cc:8068
 msgid "complex arguments must have identical types"
-msgstr "makronavne skal være kaldenavne"
+msgstr "komplekse parametre skal have identiske typer"
 
-#: go/gofrontend/expressions.cc:8068
-#, fuzzy
-#| msgid "Do not use hardware floating point"
+#: go/gofrontend/expressions.cc:8070
 msgid "complex arguments must have floating-point type"
-msgstr "Benyt ikke hardware-kommatal"
+msgstr "komplekse parametre skal have kommatalstype"
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
-#, fuzzy
-#| msgid "In function"
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 msgid "expected function"
-msgstr "I funktionen"
+msgstr "forventet funktion"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 msgid "multiple-value argument in single-value context"
-msgstr ""
+msgstr "multiple-value parameter i enkel-værdi kontekst"
 
-#: go/gofrontend/expressions.cc:8810
-#, fuzzy
-#| msgid "invalid use of non-lvalue array"
+#: go/gofrontend/expressions.cc:8812
 msgid "invalid use of %<...%> with non-slice"
-msgstr "ugyldig brug af en tabel der ikke kan optræde som en venstreværdi"
+msgstr "ugyldig brug af %<...%> med ikke-skive"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 msgid "function result count mismatch"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9180
-#, fuzzy
-#| msgid "incompatible types in %s"
+#: go/gofrontend/expressions.cc:9182
 msgid "incompatible type for receiver"
-msgstr "uforenelige typer i %s"
+msgstr "uforenelige typer for modtager"
 
-#: go/gofrontend/expressions.cc:9198
-#, fuzzy
-#| msgid "invalid use of `this' in non-member function"
+#: go/gofrontend/expressions.cc:9200
 msgid "invalid use of %<...%> calling non-variadic function"
-msgstr "ugyldig brug af 'this' i ikke-medlemsfunktion"
+msgstr "ugyldig brug af %<...%> kaldende ikke-variadic funktion"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
-#, fuzzy
-#| msgid "number of arguments doesn't match prototype"
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 msgid "number of results does not match number of values"
-msgstr "antallet af parametre passer ikke til prototypen"
+msgstr "antallet af resultater matcher ikke antallet af værdier"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
-#, fuzzy
-#| msgid "macro names must be identifiers"
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 msgid "index must be integer"
-msgstr "makronavne skal være kaldenavne"
+msgstr "indeks skal være heltal"
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
-#, fuzzy
-#| msgid "Assume int to be 8 bit integer"
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 msgid "slice end must be integer"
-msgstr "Antag at int er 8 bit-heltal"
+msgstr "skive-slutning skal være heltal"
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 #| msgid "switch quantity not an integer"
 msgid "slice capacity must be integer"
 msgstr "switch-størrelsen er ikke et heltal"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 #, fuzzy
 #| msgid "incompatible types in %s"
 msgid "incompatible type for map index"
 msgstr "uforenelige typer i %s"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11857
-#, fuzzy
-#| msgid "too many arguments for format"
+#: go/gofrontend/expressions.cc:11859
 msgid "too many expressions for struct"
-msgstr "for mange parametre til formatering"
+msgstr "for mange udtryk for struct"
 
-#: go/gofrontend/expressions.cc:11870
-#, fuzzy
-#| msgid "too few arguments for format"
+#: go/gofrontend/expressions.cc:11872
 msgid "too few expressions for struct"
-msgstr "for få parametre til formatering"
+msgstr "for få udtryk for struct"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 #, fuzzy
 #| msgid "Invalid interface type"
 msgid "type assertion only valid for interface types"
 msgstr "Ugyldig grænsefladetype"
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 #, fuzzy
 #| msgid "unexpected operand"
 msgid "expected channel"
 msgstr "uventet operand"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -16667,86 +16545,86 @@
 msgid "cannot use type %s as type %s"
 msgstr "kan ikke konvertere typen '%T' til typen '%T'"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 #, fuzzy
 #| msgid "different type"
 msgid "different receiver types"
 msgstr "anden type"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 #, fuzzy
 #| msgid "destructors take no parameters"
 msgid "different number of parameters"
 msgstr "destruktionsfunktioner kan ikke have parametre"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 #, fuzzy
 #| msgid "different type"
 msgid "different parameter types"
 msgstr "anden type"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 #, fuzzy
 #| msgid "different type"
 msgid "different varargs"
 msgstr "anden type"
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 #, fuzzy
 #| msgid "different type"
 msgid "different result types"
 msgstr "anden type"
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "incompatible type for method %s%s%s"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 #, fuzzy
 #| msgid "error while parsing methods"
 msgid "type has no methods"
 msgstr "fejl ved tolkning af metoder"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, fuzzy, c-format
 #| msgid "ambiguous abbreviation %s"
 msgid "ambiguous method %s%s%s"
 msgstr "tvetydig forkortelse %s"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, fuzzy, c-format
 msgid "missing method %s%s%s"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -16880,7 +16758,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "ugyldig tredje parameter til '__builtin_prefetch'; benytter nul"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `va_start'"
 msgid "too few arguments to function %<va_start%>"
@@ -17081,12 +16959,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "funktionskald har en sammensat værdi"
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "Pass all arguments on stack"
 msgid "passing too large argument on stack"
@@ -17699,251 +17577,256 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "antallet af basisbloknoter i instruktionskæden (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "caller edge count is negative"
 msgstr "venstreskiftsantal er negativ"
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr ""
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr ""
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "execution count is negative"
 msgstr "venstreskiftsantal er negativ"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, fuzzy, gcc-internal-format
 #| msgid "no symbol table found"
 msgid "local symbols must be defined"
 msgstr "ingen symboltabel fundet"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, fuzzy, gcc-internal-format
 #| msgid "section pointer missing"
 msgid "inlined_to pointer is wrong"
 msgstr "sektionshenvisning mangler"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple inline callers"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer to bit-field `%D'"
 msgid "inlined_to pointer refers to itself"
 msgstr "ugyldig henvisning til bitfeltet '%D'"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare references to references"
 msgid "Wrong node is referenced with chkp reference"
 msgstr "kan ikke erklære referencer til referencer"
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' used prior to declaration"
 msgid "edge points to wrong declaration:"
 msgstr "'%s' benyttes før erklæringen"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, fuzzy, gcc-internal-format
 #| msgid "verify_flow_info failed"
 msgid "verify_cgraph_node failed"
 msgstr "verify_flow_info mislykkedes"
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "string section missing"
 msgid "%s: section %s is missing"
@@ -18087,7 +17970,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, gcc-internal-format
 msgid "atexit failed"
@@ -18341,18 +18224,18 @@
 msgid "          %s"
 msgstr "        '%D'"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr ""
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "global destructors not supported on this target"
 msgstr "stakgrænser understøttes ikke på målarkitekturen"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "global constructors not supported on this target"
@@ -18400,12 +18283,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -18614,7 +18497,7 @@
 msgid "total size of local objects too large"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, fuzzy, gcc-internal-format
 #| msgid "impossible constraint in `asm'"
 msgid "impossible constraint in %<asm%>"
@@ -19091,9 +18974,9 @@
 msgstr "kan ikke skrive i uddatafil"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared here"
@@ -19110,166 +18993,161 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr "træ-kontrol: forventede %s, har %s i %s, ved %s:%d"
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "using result of function returning %<void%>"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "invalid lvalue in asm output %d"
 msgstr "ugyldig venstreværdi i asm-sætning"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "output number %d not directly addressable"
 msgid "memory input %d is not directly addressable"
 msgstr "uddata nr. %d kan ikke adresseres direkte"
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr ""
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should be private"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qE should not be reduction"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should not be private"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: gimplify.c:7001
-#, gcc-internal-format
-msgid "lastprivate variable %qE is private in outer context"
-msgstr ""
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not yet implemented"
 msgid "directive not yet implemented"
 msgstr "trampoliner understøttes ikke endnu"
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr ""
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to `va_arg' not of type `va_list'"
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "den første parameter til 'va_arg' er ikke af typen 'va_list'"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is promoted to `%s' when passed through `...'"
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "'%s' forfremmes til '%s' ved overbringelse gennem '...'"
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "(so you should pass `%s' not `%s' to `va_arg')"
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(så du skal overbring '%s' ikke '%s' til 'va_arg')"
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -19706,48 +19584,48 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class `%s'"
 msgid "cannot find LTO cgraph in %s"
 msgstr "kan ikke finde klassen '%s'"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "kan ikke finde kilden %s"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -19835,50 +19713,50 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "ingen inddatafiler"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 msgid "writing output file"
 msgstr "Fejl ved skrivning af uddatafilen %s.\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "miljøvariablen DJGPP er ikke defineret"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "miljøvariablen DJGPP er ikke defineret"
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen: %s: %m"
@@ -20019,12 +19897,12 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr ""
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "invalid entry to %s structured block"
@@ -20031,18 +19909,18 @@
 msgstr "ugyldig parameter til egenskaben '%s'"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring pragma: %s"
 msgid "ignoring large linear step"
 msgstr "ignorerer pragma: %s"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -20571,8 +20449,8 @@
 msgstr "kan ikke bruge %qs som et fast register"
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "ukendt registernavn: %s"
@@ -21012,7 +20890,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld returnerede afslutningskoden %d"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F brugt, men aldrig defineret"
@@ -22063,43 +21941,43 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr "-fdata-sections understøttes ikke på målarkitekturen"
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -22497,52 +22375,52 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript is outside array bounds"
 msgstr "tabelindeks er ikke et heltal"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript is above array bounds"
 msgstr "tabelindeks er ikke et heltal"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript is below array bounds"
 msgstr "tabelindeks er ikke et heltal"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr ""
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr ""
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, fuzzy, gcc-internal-format
 #| msgid "comparison is always false due to limited range of data type"
 msgid "comparison always false due to limited range of data type"
 msgstr "sammenligning er altid falsk på grund af den begrænsede rækkevidde af datatypen"
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, fuzzy, gcc-internal-format
 #| msgid "comparison is always true due to limited range of data type"
 msgid "comparison always true due to limited range of data type"
 msgstr "sammenligning er altid sand på grund af den begrænsede rækkevidde af datatypen"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr ""
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr ""
@@ -22587,9 +22465,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
@@ -22846,7 +22724,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "%Jforespurgt justering for '%D' er større end den implementerede justering på %d"
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't known"
 msgid "storage size of %q+D isn%'t known"
@@ -23010,27 +22888,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "strenglængden '%d' er større end den længde på '%d' som ISO C%d-oversættere er pålagt at understøtte"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "venstreskiftsantal er negativ"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "højreskiftsantal er negativ"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "venstreskiftsantal er større end bredden af typen"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "højreskiftsantal er større end bredden af typen"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overløb i konstant udtryk"
@@ -23378,12 +23256,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "foreslår paranteser omkring tildeling der er benyttet som boolsk værdi"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of %<restrict%>"
@@ -23879,12 +23757,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr ""
@@ -23894,24 +23772,24 @@
 msgid "number of components of the vector not a power of two"
 msgstr ""
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "ikke-nul egenskab uden parametre til en ikke-prototype"
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nonnull argument has invalid operand number (arg %lu)"
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "ikke-nul parameter har ugyldig operandnummer (parameter %lu)"
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nonnull argument with out-of-range operand number (arg %lu, operand %lu)"
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "ikke-nul parameter med operandnummer uden for det gyldig interval (parameter %lu, operand %lu)"
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nonnull argument references non-pointer operand (arg %lu, operand %lu)"
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
@@ -23957,13 +23835,13 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested position is not an integer constant"
 msgstr "den udbedte init_priority er ikke en heltalskonstant"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
@@ -24051,7 +23929,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, fuzzy, gcc-internal-format
 #| msgid "attempt to take address of bit-field structure member `%D'"
 msgid "attempt to take address of bit-field structure member %qD"
@@ -24529,7 +24407,7 @@
 msgstr "akkumulatortal er uden for det gyldig interval"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
@@ -25025,7 +24903,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid type for iteration variable %qE"
@@ -25037,25 +24915,25 @@
 msgid "%qE is not initialized"
 msgstr "manglende startværdi"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, fuzzy, gcc-internal-format
 #| msgid "missing '(' after predicate"
 msgid "missing controlling predicate"
 msgstr "manglende '(' efter udsagn"
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid controlling predicate"
 msgstr "Ugyldigt kontroludtryk"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, fuzzy, gcc-internal-format
 #| msgid "missing ')' in expression"
 msgid "missing increment expression"
 msgstr "manglende ')' i udtryk"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid increment expression"
@@ -25639,6 +25517,12 @@
 msgid "too many input files"
 msgstr "for mange inddatafiler"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+#| msgid "stack frame too big"
+msgid "-mcpu string too large"
+msgstr "stakramme for stor"
+
 #: common/config/alpha/alpha-common.c:76
 #, fuzzy, gcc-internal-format
 #| msgid "bad value `%s' for -mtls-size switch"
@@ -25667,49 +25551,49 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops er forældet, benyt -falign-loops"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d er ikke mellem 0 og %d"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps er forældet, benyt -falign-jumps"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-jumps=%d is not between 1 and %d"
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d er ikke mellem 1 og %d"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions er forældet, benyt -falign-functions"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-functions=%d is not between 1 and %d"
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d er ikke mellem 1 og %d"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d er ikke mellem 0 og 5"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -26119,70 +26003,70 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, fuzzy, gcc-internal-format
 #| msgid "bad value `%s' for -mtrap-precision switch"
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "ugyldig værdi '%s' til tilvalget -mtrap-precision"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, fuzzy, gcc-internal-format
 #| msgid "bad value `%s' for -mfp-rounding-mode switch"
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "ugyldig værdi '%s' til tilvalget -mfp-rounding-mode"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, fuzzy, gcc-internal-format
 #| msgid "bad value `%s' for -mfp-trap-mode switch"
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "ugyldig værdi '%s' til tilvalget -mfp-trap-mode"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, fuzzy, gcc-internal-format
 #| msgid "bad value `%s' for -mcpu switch"
 msgid "bad value %qs for -mcpu switch"
 msgstr "ugyldig værdi '%s' til tilvalget -mcpu"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for -mtune switch"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr "kommatalssoftwarefuldførelse kræver -mtrap-precision=i"
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "afrundingstilstand er ikke understøttet for VAX-kommatal"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "fældetilstand er ikke understøttet for VAX-kommatal"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, fuzzy, gcc-internal-format
 #| msgid "trap mode not supported for VAX floats"
 msgid "128-bit long double not supported for VAX floats"
 msgstr "fældetilstand er ikke understøttet for VAX-kommatal"
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr "L%d-mellemlagersventetid ukendt for %s"
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, fuzzy, gcc-internal-format
 #| msgid "bad value `%s' for -mmemory-latency"
 msgid "bad value %qs for -mmemory-latency"
 msgstr "ugyldig værdi '%s' for -mmemory-latency"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -26673,14 +26557,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
@@ -27373,400 +27257,417 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "kan ikke oprette informationsfilen '%s' til opbevaringssted"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "error in args to spec function `%s'"
 msgid "wrong arg %s to option %s"
 msgstr "fejl i parametre til specifikationsfunktion '%s'"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "return type specified for `operator %T'"
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "returtype angivet for 'operator %T'"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "return type specified for `operator %T'"
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr "returtype angivet for 'operator %T'"
+
+#: config/i386/i386.c:3012
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Tune alignment for the specified chip or CPU version"
 msgid "unknown alignment %s specified for option %s"
 msgstr "Finjustér justering til en given chip- eller processorversion"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too many size ranges specified in option %s"
 msgstr "intet klassenavn angivet med '-%s'"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "code model `%s' not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "kodemodellen %s er ikke understøttet i %s bit-tilstand"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, fuzzy, gcc-internal-format
 #| msgid "code model `%s' not supported in the %s bit mode"
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "kodemodellen %s er ikke understøttet i %s bit-tilstand"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodemodellen %s er ikke understøttet i PIC-tilstand"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
 msgstr "kodemodellen %s er ikke understøttet i PIC-tilstand"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i bit-tilstand er ikke oversat med ind"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "den valgte processor understøtter ikke x86-64-instruktionssættet"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support APCS-32"
 msgid "Intel MPX does not support x32"
 msgstr "målprocessoren understøtter ikke APCS-32"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d er ikke mellem 0 og %d"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-arrays understøttes ikke på målarkitekturen"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-instruktionssæt deaktiveret, bruger 387-beregninger"
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-instruktionssæt deaktiveret, bruger SSE-beregninger"
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown cpu: -mcpu=%s"
 msgid "unknown option for -mrecip=%s"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %<target%> argument not a string"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall og regparm er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "%qE attribute is used for non-class method"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5923
-#, gcc-internal-format
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr ""
-
-#: config/i386/i386.c:6210
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "%s understøtter ikke %s"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, gcc-internal-format
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
 #, gcc-internal-format
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:11378
+#, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -27773,285 +27674,285 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, fuzzy, gcc-internal-format
 #| msgid "-mips%d does not support 64 bit fp registers"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "udvidede registre har ikke høje halvdele"
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ikke-understøttet operandstørrelse for udvidede registre"
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No case for %s"
 msgid "No dispatcher found for %s"
 msgstr "Ingen case for %s"
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%D'"
 msgid "previous declaration of %D"
 msgstr "'%D' er tidligere erklæret"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 #| msgid "argument to dss must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "parameter til dss skal være en 2 bit-konstant uden fortegn"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "skifteværdi skal være en umiddelbar værdi"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect rounding operand"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option %s"
 msgid "%qE needs isa option %s"
 msgstr "ugyldigt tilvalg %s"
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %d"
 msgstr "versionen er ikke understøttet"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -28145,13 +28046,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-egenskaben kræver et strengkonstant som parameter"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr "værdien af -mfixed-range skal være på formen REG1-REG2"
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -28227,7 +28128,7 @@
 msgstr "sektionsegenskaber understøttes ikke på denne målarkitektur"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "%qE attribute argument not an integer constant"
@@ -28289,7 +28190,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread er kun tilgængelig på fido"
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
@@ -29198,16 +29099,11 @@
 msgid "-g option disabled"
 msgstr "tilvalget -g deaktiveret"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr ""
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, fuzzy, gcc-internal-format
@@ -29480,332 +29376,337 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "1. parameter til __builtin_altivec_predicate skal være en konstant"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "1. parameter til __builtin_altivec_predicate er uden for det gyldige interval"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
+#, gcc-internal-format, gfc-internal-format
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "1. parameter til __builtin_spe_predicate er uden for det gyldige interval"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "tal skal enten være 0 eller 1"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "tal skal enten være 0 eller 1"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be in the range 0..15"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' must be a 2-bit unsigned literal"
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "parameter til dss skal være en 2 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "1. parameter til __builtin_spe_predicate er uden for det gyldige interval"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "1. parameter til __builtin_spe_predicate er uden for det gyldige interval"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mspe option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "inline functions not supported for this return value type"
 msgid "Builtin function %s is not supported with the current options"
 msgstr "integrerede funktioner understøttes ikke for denne returværditype"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "internal error - use of undefined type"
 msgid "internal error: builtin function %s had no type"
 msgstr "intern fejl - brug af ikke-defineret type"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, fuzzy, gcc-internal-format
 #| msgid "stack frame too big"
 msgid "stack frame too large"
 msgstr "stakramme for stor"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering af 64 bit-kode for denne ABI"
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%s\"%s\"%s is not allowed"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr ""
@@ -30061,93 +29962,93 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, fuzzy, gcc-internal-format
 #| msgid "Total size of local variables exceeds architecture limit."
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Total størrelse af lokale variable overstiger arkitekturgrænsen."
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsize of '%D' is %d bytes"
 msgid "frame size of %qs is %wd bytes"
 msgstr "%Jstørrelsen af '%D' er %d byte"
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "fældetilstand understøttes ikke på Unicos/Mk"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, fuzzy, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "kodemodellen %s er ikke understøttet i PIC-tilstand"
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, fuzzy, gcc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
@@ -30162,35 +30063,35 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr ""
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "__builtin_saveregs understøttes ikke af denne undermålarkitektur"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to interrupt functions"
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "egenskaben '%s' kan kun anvendes sammen med afbrydelsesfunktioner"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute is not supported on this platform"
 msgid "%qE attribute is supported only for SH2A"
 msgstr "egenskaben '%s' er ikke understøttet på denne platform"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr "egenskaben interrupt_handler er ikke forenelig med -m5-compact"
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qE attribute only applies to SH2A"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "%qE attribute argument should be between 0 to 255"
@@ -30197,24 +30098,24 @@
 msgstr "parameteren til egenskaben '%s' er ikke en heltalskonstant"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "%qE attribute argument not a string constant"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr ""
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, fuzzy, gcc-internal-format
 #| msgid "Use the BK register as a general purpose register"
 msgid "need a second call-clobbered general purpose register"
 msgstr "Benyt BK-registeret som et alment register"
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr ""
@@ -30619,49 +30520,49 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid element type for attribute %qs"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "number of arguments doesn't match prototype"
 msgid "number of components of vector not a power of two"
 msgstr "antallet af parametre passer ikke til prototypen"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qs attribute ignored"
 msgstr "egenskaben '%s' ignoreret"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qs attribute only applies to variadic functions"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "%s har ingen %s"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "attribute %qs applies to array types only"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument `%s'"
@@ -30723,7 +30624,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "tom værdi er ikke ignoreret som den burde være"
@@ -30753,68 +30654,68 @@
 msgid "GCC supports only %u nested scopes"
 msgstr ""
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "label %q+D used but not defined"
 msgstr "etiketten '%D' er benyttet, men ikke defineret"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, fuzzy, gcc-internal-format
 #| msgid "inline function `%D' used but never defined"
 msgid "nested function %q+D declared but never defined"
 msgstr "indbygget funktion '%D' benyttet, men aldrig defineret"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, fuzzy, gcc-internal-format
 #| msgid "inline function `%D' used but never defined"
 msgid "inline function %q+D declared but never defined"
 msgstr "indbygget funktion '%D' benyttet, men aldrig defineret"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, fuzzy, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "ubrugt variabel '%s'"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "variable %qD set but not used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "  oprindelig definition er her"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can't match an empty parameter name list declaration"
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr "en parameterliste med '...' passer ikke til en erklæring med en tom parameterliste"
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, fuzzy, gcc-internal-format
 #| msgid "an argument type that has a default promotion can't match an empty parameter name list declaration"
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr "en parametertype med automatisk forfremmelse passer ikke til en erklæring med en tom parameterliste"
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, fuzzy, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "følger definition uden prototype her"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, fuzzy, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "følger definition uden prototype her"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for `%s' follows and argument %d doesn't match"
 msgid "prototype for %q+D declares argument %d with incompatible type"
@@ -30822,44 +30723,44 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, fuzzy, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "følger definition uden prototype her"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "tidligere definition her"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, fuzzy, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "tidligere underforstået erklæring af '%s'"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "tidligere erklæring af '%#D' her"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' redeclared as different kind of symbol"
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, fuzzy, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "den indbyggede funktion '%s' er erklæret som noget der ikke er en funktion"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "erklæring af '%s' skygger for en global erklæring"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of `enum %s'"
 msgid "redeclaration of enumerator %q+D"
@@ -30868,158 +30769,158 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, fuzzy, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "modstridende typer for den indbyggede funktion '%s'"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, fuzzy, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "modstridende typer for '%#D'"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, fuzzy, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "modstridende typer for '%#D'"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
 msgstr "omdefinering af '%s'"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "omdefinering af '%s'"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "omdefinering af '%s'"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "omdefinering af '%s'"
 
 # anden 'declaration' er underforstået i engelsk original
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, fuzzy, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "static-erklæring af '%s' følger erklæring uden static"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, fuzzy, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "erklæring uden static af '%s' følger static-erklæring"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr ""
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, fuzzy, gcc-internal-format
 #| msgid "  from here"
 msgid "but not here"
 msgstr "  herfra"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "trådlokal erklæring af '%s' følger ikke-trådlokal erklæring"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "ikke-trådlokal erklæring af '%s' følger trådlokal erklæring"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, fuzzy, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "extern-erklæring af '%s' passer ikke med den globale"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "erklæring af '%F' kaster forskellige undtagelser"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr ""
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, fuzzy, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "tidligere erklæring af funktionen '%s' med egenskaben noinline"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "erklæring af '%s' der er en statisk variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "erklæring af '%s' der er en statisk variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, fuzzy, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "omdefinering af '%s'"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "overflødig omerklæring af '%D' i samme virkefelt"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a previous local"
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "erklæring af '%s' skygger for en tidligere lokal variabel"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %q+D shadows a parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "declaration of %qD shadows a global declaration"
 msgstr "erklæring af '%s' skygger for en global erklæring"
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a previous local"
 msgid "declaration of %q+D shadows a previous local"
 msgstr "erklæring af '%s' skygger for en tidligere lokal variabel"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
@@ -31026,43 +30927,43 @@
 msgid "shadowed declaration is here"
 msgstr "%Jskygget erklæring er her"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, fuzzy, gcc-internal-format
 #| msgid "nested extern declaration of `%s'"
 msgid "nested extern declaration of %qD"
 msgstr "indlejret extern-erklæring af '%s'"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%s'"
 msgid "implicit declaration of function %qE"
 msgstr "underforstået erklæring af funktionen '%s'"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "underforstået erklæring af funktionen '%#D'"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "incompatible implicit declaration of function %qD"
 msgstr "underforstået erklæring af funktionen '%#D'"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function)"
 msgstr "'%s' ikke erklæret her (ikke i en funktion)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function)"
@@ -31069,36 +30970,36 @@
 msgstr "'%s' er ikke erklæret (først benyttet i denne funktion)"
 
 # dækkende, og pænere end original i praktisk brug
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, fuzzy, gcc-internal-format
 #| msgid "(Each undeclared identifier is reported only once for each function it appears in.)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(et kaldenavn der ikke er erklæret, rapporteres kun én gang per funktion)"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, fuzzy, gcc-internal-format
 #| msgid "label %s referenced outside of any function"
 msgid "label %qE referenced outside of any function"
 msgstr "der er blevet henvist til etiketten '%s' uden for en funktion"
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, fuzzy, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, fuzzy, gcc-internal-format
 #| msgid "Missing variable initializer"
 msgid "jump skips variable initialization"
 msgstr "Manglende variabelstartværdi"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "label %qD defined here"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
@@ -31105,127 +31006,127 @@
 msgid "%qD declared here"
 msgstr "  '%#D' erklæret her"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "jump into statement expression"
 msgstr "overløb i konstant udtryk"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "duplicate label declaration %qE"
 msgstr "etiketten '%s' er blevet erklæret mere end én gang"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%D'"
 msgid "duplicate label %qD"
 msgstr "etiketten '%D' optræder mere end én gang"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr ""
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, fuzzy, gcc-internal-format
 #| msgid "Missing variable initializer"
 msgid "switch jumps over variable initialization"
 msgstr "Manglende variabelstartværdi"
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "switch jumps into statement expression"
 msgstr "overløb i konstant udtryk"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE defineret som forkert slags mærke"
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "unavngiven struct/union som ikke definerer nogen instanser"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "tom erklæring med lagringsklasseanvisning erklærer ikke mærke igen"
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "tom erklæring med typemodifikation erklærer ikke mærke igen"
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "tom erklæring med %<_Alignas%> erklærer ikke mærke igen"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "ubrugeligt typenavn i tom erklæring"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%>i tom erklæring"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<_Noreturn%> i tom erklæring"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> i file-scope tom erklæring"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> i file-scope tom erklæring"
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "ubrugelig lagringsklasseanvisning i tom erklæring"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "ubrugelig %qs i tom erklæring"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "ubrugelig typemodifikationer i tom erklæring"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "ubrugelig %<_Alignas%> i tom erklæring"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "tom erklæring"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 understøtter ikke %<static%> eller typemodifikationer i parameterarrayerklæringer"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 understøtter ikke %<[*]%> arrayerklæringer"
@@ -31233,39 +31134,39 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D er normalt en funktion"
 
 # init dækker over værditildeling her - samme for de næste mange
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "typedef %qD bliver tildelt en værdi (benyt __typeof__ i stedet)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "funktionen %qD bliver tildelt en startværdi som en variabel"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "parameteren %qD bliver tildelt en startværdi"
@@ -31274,117 +31175,117 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "et objekt af variabel størrelse må ikke tildeles en startværdi"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "variablen %qD bliver tildelt en startværdi, men er af en ufuldstændig type"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "inline funktion %q+D givet egenskaben noinline"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member `%D'"
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "konstant medlem '%D' uden startværdi"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD skal tildeles en startværdi"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of `%D'"
 msgid "initializer fails to determine size of %q+D"
 msgstr "startværdien giver ikke størrelsen af '%D'"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %q+D"
 msgstr "tabelstørrelsen mangler i '%D'"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, fuzzy, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "nul eller negativ størrelse for tabellen '%s'"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't constant"
 msgid "storage size of %q+D isn%'t constant"
 msgstr "lagringsstørrelsen af '%D' er ikke konstant"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, fuzzy, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "ignorerer asm-anvisning til den ikke-statiske, lokale variabel '%s'"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "kan ikke anbringe et objekt med et volatile-felt i et register"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const `%D'"
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "konstant '%D' uden startværdi"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C forbyder forhåndsparametererklæringer"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' width not an integer constant"
 msgid "bit-field %qs width not an integer constant"
 msgstr "bredden af bitfeltet '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' width not an integer constant"
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "bredden af bitfeltet '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, fuzzy, gcc-internal-format
 #| msgid "negative width in bit-field `%s'"
 msgid "negative width in bit-field %qs"
 msgstr "negativ bredde i bitfeltet '%s'"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, fuzzy, gcc-internal-format
 #| msgid "zero width for bit-field `%s'"
 msgid "zero width for bit-field %qs"
 msgstr "en bredde på nul for bitfeltet '%s'"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qs has invalid type"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, fuzzy, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "linjestilsdirektiv er en GCC-udvidelse"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, fuzzy, gcc-internal-format
 #| msgid "width of `%s' exceeds its type"
 msgid "width of %qs exceeds its type"
@@ -31391,175 +31292,175 @@
 msgstr "bredden af '%s' overstiger typen"
 
 # RETMIG: find på et eller andet med præcisionen
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is narrower than values of its type"
 msgid "%qs is narrower than values of its type"
 msgstr "'%s' er smallere end værdier af dens type"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array `%s' whose size can't be evaluated"
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 forbyder tabellen '%s' hvis størrelse ikke kan bestemmes"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array `%s' whose size can't be evaluated"
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 forbyder tabellen '%s' hvis størrelse ikke kan bestemmes"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C++ forbyder tabel med variabel størrelse"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, fuzzy, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "type defaults to %<int%> in type name"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `const'"
 msgid "duplicate %<const%>"
 msgstr "'const' optræder mere end én gang"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<restrict%>"
 msgstr "'restrict' optræder mere end én gang"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate %<volatile%>"
 msgstr "'volatile' optræder mere end én gang"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<_Atomic%>"
 msgstr "'restrict' optræder mere end én gang"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting super class name `%s'"
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "modstridende superklassenavn '%s'"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `auto'"
 msgid "function definition declared %<auto%>"
 msgstr "'auto' er påhæftet funktionsdefinitionen"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `register'"
 msgid "function definition declared %<register%>"
 msgstr "'register' er påhæftet funktionsdefinitionen"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `typedef'"
 msgid "function definition declared %<typedef%>"
 msgstr "'typedef' er påhæftet funktionsdefinitionen"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `auto'"
 msgid "function definition declared %qs"
 msgstr "'auto' er påhæftet funktionsdefinitionen"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "storage class specified for structure field %qE"
 msgstr "lagringsklasse angivet for strukturfelt '%s'"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "storage class specified for structure field"
 msgstr "lagringsklasse angivet for strukturfelt '%s'"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for parameter %qE"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for unnamed parameter"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "lagringsklasse angivet for typenavn"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' initialized and declared `extern'"
 msgid "%qE initialized and declared %<extern%>"
 msgstr "'%s' bliver tildelt en startværdi og er samtidig erklæret 'extern'"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' has both `extern' and initializer"
 msgid "%qE has both %<extern%> and initializer"
 msgstr "'%s' er erklæret 'extern', men bliver tildelt en startværdi"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "nested function `%s' declared `extern'"
 msgid "nested function %qE declared %<extern%>"
 msgstr "indlejret funktion '%s' er erklæret 'extern'"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope `%s' implicitly auto and declared `__thread'"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -31568,313 +31469,313 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static eller typemodifikationer i ikke-parametertabelerklæring"
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of %qE as array of voids"
 msgstr "'%s' erklæret som en tabel af void"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of type name as array of voids"
 msgstr "'%s' erklæret som en tabel af void"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qE as array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of type name as array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ugyldig brug af struktur med fleksibelt tabelmedlem"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' has non-integer type"
 msgid "size of array %qE has non-integer type"
 msgstr "størrelsen af tabellen '%s' er ikke af en heltalstype"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' has non-integer type"
 msgid "size of unnamed array has non-integer type"
 msgstr "størrelsen af tabellen '%s' er ikke af en heltalstype"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids zero-size array `%s'"
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C forbyder tabellen '%s' med størrelsen nul"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array"
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++ forbyder tabel med størrelsen nul"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of array %qE is negative"
 msgstr "størrelsen af tabel er negativ"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "størrelsen af tabel er negativ"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array %qE is too large"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of unnamed array is too large"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%<[*]%> not in a declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "tabeltypen er af en ufuldstændig type"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE er erklæret som en funktion, der returnerer en funktion"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "'typenavn er erklæret som en funktion, der returnerer en funktion"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE er erklæret som en funktion, der returnerer en array"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "typenavn er erklæret som en funktion, der returnerer en array"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "funktiondefinition har kvalificeret void-returtype"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "ignorerer asm-anvisning til den ikke-statiske, lokale variabel '%s'"
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier omitted for parameter `%E'"
 msgid "%qs specified for parameter %qE"
 msgstr "typeangivelse udeladt for parameteren '%E'"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier omitted for parameter"
 msgid "%qs specified for unnamed parameter"
 msgstr "typeangivelsen er ikke angivet for parameteren"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%qs specified for structure field %qE"
 msgstr "lagringsklasse angivet for strukturfelt '%s'"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%qs specified for structure field"
 msgstr "lagringsklasse angivet for strukturfelt '%s'"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field has atomic type"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "justering må ikke angives for '%s'"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "alignment specified for parameter %qE"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "alignment specified for unnamed parameter"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "justering må ikke angives for '%s'"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 #| msgid "`__alignof' applied to a bit-field"
 msgid "alignment specified for unnamed bit-field"
 msgstr "'__alignof' benyttet på et bitfelt"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "alignment specified for function %qE"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "variablen '%s' er erklæret 'inline'"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, fuzzy, gcc-internal-format
 #| msgid "operator `%T' declared to return `%T'"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "operator '%T' erklæret til at returnere '%T'"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C forbyder const eller volatile funktionstyper"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type `%T'"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "datamedlem må ikke have variabelt ændret type '%T'"
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable or field %qE declared void"
 msgstr "variabel eller felt erklæret void"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %q+D declared %<inline%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' declared as a function"
 msgid "field %qE declared as a function"
 msgstr "feltet '%s' er erklæret som en funktion"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' has incomplete type"
 msgid "field %qE has incomplete type"
 msgstr "feltet '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, fuzzy, gcc-internal-format
 #| msgid "name `%T' has incomplete type"
 msgid "unnamed field has incomplete type"
 msgstr "navnet '%T' er af en ufuldstændig type"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function `%s'"
 msgid "invalid storage class for function %qE"
@@ -31881,239 +31782,239 @@
 msgstr "ugyldig lagringsklasse for funktion '%s'"
 
 # at oversætte inline med et udsagnsord her bliver vist for tvetydigt
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, fuzzy, gcc-internal-format
 #| msgid "cannot inline function `main'"
 msgid "cannot inline function %<main%>"
 msgstr "funktionen 'main' kan ikke være inline"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, fuzzy, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "variabel eller felt '%s' erklæret void"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "variablen '%s' er erklæret 'inline'"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "variablen '%s' er erklæret 'inline'"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, fuzzy, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, fuzzy, gcc-internal-format
 #| msgid "function declaration isn't a prototype"
 msgid "function declaration isn%'t a prototype"
 msgstr "funktionserklæringen er ikke en prototype"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "parameternavne (uden typer) i funktionserklæringen"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter has incomplete type"
 msgid "parameter %u has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter `%s' has incomplete type"
 msgid "parameter %u has void type"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, fuzzy, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, fuzzy, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "parameteren '%s' har kun en forhåndserklæring"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, fuzzy, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "'struct %s' erklæret inde i en parameterliste"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "anonym struct erklæret inde i en parameterliste"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "dens virkefelt er kun denne definition eller erklæring hvilket sandsynligvis ikke er hvad du ønsker."
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "enum type defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "struct defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "union defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `union %s'"
 msgid "redefinition of %<union %E%>"
 msgstr "omdefinering af 'union %s'"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `struct %s'"
 msgid "redefinition of %<struct %E%>"
 msgstr "omdefinering af 'struct %s'"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "nested redefinition of %<union %E%>"
 msgstr "indlejret omdefinering af '%s'"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "indlejret omdefinering af '%s'"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "erklæring erklærer ikke noget"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn't support unnamed structs/unions"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C understøtter ikke unavngivne struct/union-konstruktioner"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn't support unnamed structs/unions"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C understøtter ikke unavngivne struct/union-konstruktioner"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate member `%D'"
 msgid "duplicate member %q+D"
 msgstr "medlemmet '%D' optræder mere end én gang"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, fuzzy, gcc-internal-format
 #| msgid "named members"
 msgid "union has no named members"
 msgstr "navngivne medlemmer"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, fuzzy, gcc-internal-format
 msgid "union has no members"
 msgstr "anonym sammensat type uden medlemmer"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, fuzzy, gcc-internal-format
 #| msgid "named members"
 msgid "struct has no named members"
 msgstr "navngivne medlemmer"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, fuzzy, gcc-internal-format
 #| msgid "%s has no member named `%s'"
 msgid "struct has no members"
 msgstr "%s har intet medlem ved navn '%s'"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "fleksibelt tabelmedlem i union"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr "fleksibelt tabelmedlem i ellers tom struktur"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "type %qT is too large"
 msgstr "%s er for stor"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union kan ikke ikke gøres gennemsigtig"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "nested redefinition of %<enum %E%>"
@@ -32120,197 +32021,197 @@
 msgstr "indlejret omdefinering af '%s'"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of `enum %s'"
 msgid "redeclaration of %<enum %E%>"
 msgstr "omerklæring af 'enum %s'"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "enum-værdier overstige rækkevidden af det største heltal"
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "enum-værdier for store"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of `int'"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C begrænser enum-værdier til rækkevidden af 'int'"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "inline funktion '%s' givet egenskaben noinline"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "returtypen er en ufuldstændig type"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, fuzzy, gcc-internal-format
 #| msgid "return type defaults to `int'"
 msgid "return type defaults to %<int%>"
 msgstr "returtypen antages at være 'int'"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "ingen tidligere prototype for '%s'"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "'%s' blev brugt uden en prototype før dens definition"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidligere erklæring af '%s'"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "'%s' blev brugt uden en erklæring før dens definition"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "returtypen til '%s' er ikke 'int'"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "'%s' er normalt en ikke-statisk funktion"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, fuzzy, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "kan ikke bruge '::' i parametererklæring"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "traditionel C tillader ikke ISO C-functionsdefinitioner"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, fuzzy, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "parameternavn udeladt"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, fuzzy, gcc-internal-format
 #| msgid "traditional C rejects ISO C style function definitions"
 msgid "old-style function definition"
 msgstr "traditionel C tillader ikke ISO C-functionsdefinitioner"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "parameternavn mangler fra parameterliste"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "'%D' er erklæret som en ven"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "flere parametre ved navn '%s'"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %qD declared with void type"
 msgstr "parameteren '%D' erklæret void"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "typen til '%s' antages at være 'int'"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, fuzzy, gcc-internal-format
 #| msgid "parameter has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "erklæring af parameteren '%s', men ingen sådan parameter"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, fuzzy, gcc-internal-format
 #| msgid "number of arguments doesn't match prototype"
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "antallet af parametre passer ikke til prototypen"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, fuzzy, gcc-internal-format
 #| msgid "number of arguments doesn't match prototype"
 msgid "number of arguments doesn%'t match prototype"
 msgstr "antallet af parametre passer ikke til prototypen"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "tom erklæring"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "den forfremmede parameter '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "den forfremmede parameter '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "parameteren '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "parameteren '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
@@ -32319,217 +32220,217 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "begyndelseserklæring i 'for'-løkke benyttet uden for C99-tilstand"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der er en statisk variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, fuzzy, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "'struct %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, fuzzy, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "'union %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, fuzzy, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "'enum %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der ikke er en variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qE"
 msgstr "'%s' optræder mere end én gang"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "two or more data types in declaration of `%s'"
 msgid "two or more data types in declaration specifiers"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
 msgstr "'long long long' er for langt for GCC"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%<__int%d%> is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "-fdata-sections understøttes ikke på målarkitekturen"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' fails to be a typedef or built in type"
 msgid "%qE fails to be a typedef or built in type"
 msgstr "'%s' er hverken en typedef eller en indbygget type"
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not at beginning of declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s understøtter ikke %s"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, fuzzy, gcc-internal-format
 #| msgid "`__thread' before `extern'"
 msgid "%<__thread%> before %<extern%>"
 msgstr "'__thread' før 'extern'"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, fuzzy, gcc-internal-format
 #| msgid "`__thread' before `static'"
 msgid "%<__thread%> before %<static%>"
 msgstr "'__thread' før 'static'"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "multiple storage classes in declaration specifiers"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs used with %qE"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C understøtter ikke at blot 'complex' betyder 'double complex'"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -32540,7 +32441,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr "kaldenavnet '%s' er i modstrid med den interne navngivningsstrategi i GNU c++"
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, fuzzy, gcc-internal-format
 #| msgid "garbage at end of #line"
 msgid "expected end of line"
@@ -32564,8 +32465,8 @@
 msgid "unknown type name %qE"
 msgstr "ukendt registernavn: %s"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of unit `%s'"
 msgid "expected declaration specifiers"
@@ -32582,7 +32483,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored for methods"
@@ -32662,7 +32563,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "expected string literal"
@@ -32726,14 +32627,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "uventet operand"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma i slutningen af enum-liste"
@@ -33220,32 +33121,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr "lagringsklasse angivet for typenavn"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "en dataområdeegenskab kan ikke angives for lokale variable"
@@ -33255,47 +33156,47 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
@@ -33310,13 +33211,13 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "expected integer expression before ')'"
@@ -33328,30 +33229,30 @@
 msgid "expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a constant"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qD is not a variable"
 msgstr "'%D' er ikke et navnerum"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a pointer-to-object type"
 msgid "%qD is not a pointer variable"
 msgstr "'%T' er ikke af en henvisning til objekt-type"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
@@ -33384,17 +33285,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr ""
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -33414,12 +33315,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -33439,19 +33340,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "ugyldig %%d-operand"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "ugyldig maske"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -33462,60 +33363,60 @@
 msgid "invalid proc_bind kind"
 msgstr "ugyldig roteringsinstruktion"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s understøtter ikke %s"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr ""
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid pragma"
 msgstr "ugyldig #pragma %s"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ugyldig #pragma %s"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand for 'p' modifier"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ugyldig operand til 'p'-ændring"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -33525,19 +33426,19 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, fuzzy, gcc-internal-format
 #| msgid "')' or term expected"
 msgid "for statement expected"
 msgstr "')' eller term forventet"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 #| msgid "')' or term expected"
 msgid "_Cilk_for statement expected"
 msgstr "')' eller term forventet"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of automaton `%s'"
 msgid "expected iteration declaration or initialization"
@@ -33548,243 +33449,243 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<point%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr ""
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, gcc-internal-format
 msgid "pragma simd must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, fuzzy, gcc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "vectorlength must be an integer constant"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "angivet justering er ikke en potens af 2"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr ""
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr ""
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "base of array section must be pointer or array type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<:%> or numeral"
 msgstr "uventet operand"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "array notations cannot be used with function type"
 msgstr "new kan ikke bruges på en funktionstype"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected array notation expression"
@@ -33796,7 +33697,7 @@
 msgid "%qD has an incomplete type"
 msgstr "'%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ugyldig brug af void-udtryk"
@@ -33910,7 +33811,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "værdien der er påført et indeks, er hverken en tabel eller en henvisningsvariabel"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "tabelindeks er ikke et heltal"
@@ -34051,7 +33952,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "%s som signed på grund af prototypen"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
@@ -34084,7 +33985,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "beregninger udført på en henvisning til en ufuldstændig type"
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -34185,7 +34086,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
@@ -34223,7 +34124,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "henvisnings- og heltalstype i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr ""
@@ -34311,7 +34212,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "typeomtvingelse fra heltal til henvisning af en anden størrelse"
@@ -34488,7 +34389,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "return type might be a candidate for a format attribute"
@@ -34650,7 +34551,7 @@
 msgid "initialization of a flexible array member"
 msgstr "klargøring af fleksibelt tabelmedlem"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-tabel får tildelt startværdi fra en bred streng"
@@ -34700,7 +34601,7 @@
 msgid "invalid initializer"
 msgstr "ugyldig startværdi"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
@@ -34853,7 +34754,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C forbyder 'goto *udtryk;'"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, fuzzy, gcc-internal-format
 #| msgid "function declared `noreturn' has a `return' statement"
 msgid "function declared %<noreturn%> has a %<return%> statement"
@@ -34865,7 +34766,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "kommaudtryk benyttet til at klargøre returværdi"
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -34983,19 +34884,19 @@
 msgid "expression statement has incomplete type"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "comparing vectors with different element types"
 msgstr "operander til ?: har forskellige typer"
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, fuzzy, gcc-internal-format
 #| msgid "operand constraints for `asm' differ in number of alternatives"
 msgid "comparing vectors with different number of elements"
 msgstr "operandbegrænsninger til 'asm' har forskellige antal alternativer"
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "sammenligning af kommatal med == eller != er ikke sikkert"
@@ -35049,12 +34950,12 @@
 msgstr "ordnet sammenligning af henvisning med heltallet nul"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "ordnet sammenligning af henvisning med heltallet nul"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
@@ -35083,89 +34984,89 @@
 msgid "used vector type where scalar is required"
 msgstr "værdi af struct-type angivet hvor skalar er påkrævet"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %qs clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE does not have pointer or array type"
@@ -35177,17 +35078,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -35197,7 +35098,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in clause %qs"
@@ -35208,19 +35109,19 @@
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -35237,49 +35138,49 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' does not declare a template type"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -35290,36 +35191,36 @@
 msgstr ""
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "videregivelse af '%T' som 'this'-parameteren til '%#D' forkaster modifikationer"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  no known conversion from %qT to %qT"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -35326,91 +35227,91 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T, %T) <built-in>"
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr "%s %D(%T, %T, %T) <indbygget>"
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T) <built-in>"
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "%s %D(%T, %T) <indbygget>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T) <built-in>"
 msgid "%s%D(%T) <built-in>"
 msgstr "%s %D(%T) <indbygget>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "%s %T <conversion>"
 msgid "%s%T <conversion>"
 msgstr "%s %T <konvertering>"
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr ""
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr ""
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr ""
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument deduction/substitution failed:"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%T' to `%T' is ambiguous"
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "konvertering fra '%T' til '%T' er tvetydigt"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%T' to non-scalar type `%T' requested"
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr "konvertering fra '%T' til en ikke-skalartype '%T' udbedt"
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%D(%A)'"
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "ingen passende funktion for kald til '%D(%A)'"
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, fuzzy, gcc-internal-format
 #| msgid "call of overloaded `%D(%A)' is ambiguous"
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
@@ -35418,501 +35319,501 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr "henvisning til medlemsfunktionen %E kan ikke kaldes uden et objekt; overvej at benytte .* eller ->*"
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to `(%T) (%A)'"
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "ingen passende fundet for kald til '(%T) (%A)'"
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, fuzzy, gcc-internal-format
 #| msgid "call of `(%T) (%A)' is ambiguous"
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "kald af '(%T) (%A)' er tvetydigt"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "tvetydig konvertering af tabelindeks"
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, fuzzy, gcc-internal-format
 #| msgid "operand is r0"
 msgid " (operand type is %qT)"
 msgstr "operanden er r0"
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: %s"
 msgid "ternary %<operator?:%>"
 msgstr "intern fejl: %s"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ forbyder udeladelse af den mellemste del af et ?:-udtryk"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "henvisningstyperne i betingelsesudtrykket passer ikke sammen"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "operander til ?: har forskellige typer"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: `%T' vs `%T'"
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "enum-typer passer ikke sammen i betinget udtryk: '%T' og '%T'"
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "enum- og ikke enum-type i betinget udtryk"
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, fuzzy, gcc-internal-format
 #| msgid "no `%D(int)' declared for postfix `%s', trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "ingen '%D(int)' erklæret for suffiks '%s', prøver præfiksoperatoren i stedet"
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, fuzzy, gcc-internal-format
 #| msgid "no `%D(int)' declared for postfix `%s', trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "ingen '%D(int)' erklæret for suffiks '%s', prøver præfiksoperatoren i stedet"
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between `%#T' and `%#T'"
 msgid "comparison between %q#T and %q#T"
 msgstr "sammenligning mellem '%#T' og '%#T'"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "non-placement deallocation function %q+D"
 msgstr "underforstået erklæring af funktionen '%#D'"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr ""
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "ingen passende 'operator delete' for '%T'"
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is private"
 msgid "%q+#D is private"
 msgstr "'%+#D' er privat"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is protected"
 msgid "%q+#D is protected"
 msgstr "'%+#D' er beskyttet"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is inaccessible"
 msgid "%q+#D is inaccessible"
 msgstr "'%+#D' er ikke tilgængelig"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr "i denne kontekst"
 
 # %s bliver til returnering eller tildeling eller noget i den retning
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, fuzzy, gcc-internal-format
 #| msgid "passing NULL used for non-pointer %s %P of `%D'"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "overbringelse af NULL benyttet for ikke-henvisnings%s %P af '%D'"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, fuzzy, gcc-internal-format
 #| msgid "%s to non-pointer type `%T' from NULL"
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "%s til ikke-henvisningstypen '%T' fra NULL"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "konverterer NULL til en ikke-henvisningstype"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "too many braces around initializer for %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, gcc-internal-format
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, fuzzy, gcc-internal-format
 #| msgid "  initializing argument %P of `%D'"
 msgid "  initializing argument %P of %qD"
 msgstr "  ved klargøring af parameteren %P til '%D'"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "invalid conversion from %qT to %qT"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, fuzzy, gcc-internal-format
 #| msgid "  initializing argument %P of `%D'"
 msgid "  initializing argument %P of %q+D"
 msgstr "  ved klargøring af parameteren %P til '%D'"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, fuzzy, gcc-internal-format
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "kan ikke klargøre '%T' fra %T'"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, fuzzy, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "videregivelse af '%T' som 'this'-parameteren til '%#D' forkaster modifikationer"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "kan ikke klargøre '%T' fra %T'"
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, fuzzy, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "kan ikke erklære feltet '%D' til at være af typen '%T'"
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "kan ikke klargøre '%T' fra %T'"
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type `%#T' through `...'"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "kan ikke modtage objekter af en ikke-POD type '%#T' gennem '...'"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "omdefinering af standardparameter for '%#D'"
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "videregivelse af '%T' som 'this'-parameteren til '%#D' forkaster modifikationer"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, fuzzy, gcc-internal-format
 #| msgid "  in call to `%D'"
 msgid "  in call to %qD"
 msgstr "  i kald af '%D'"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "'%T' er en utilgængelig stamklasse til '%T'"
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, fuzzy, gcc-internal-format
 #| msgid "  in call to `%D'"
 msgid "  in call to %q+D"
 msgstr "  i kald af '%D'"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, fuzzy, gcc-internal-format
 #| msgid "could not find class$ field in java interface type `%T'"
 msgid "could not find class$ field in java interface type %qT"
 msgstr "kunne ikke finde et class$-felt i Java-grænsefladetypen '%T'"
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to non-function %qD"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call destructor `%T::~%T' without object"
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan ikke kalde destruktionsfunktion '%T::~%T' uden objekt"
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "ingen passende funktion for kald til '%T::%D(%A)%#V'"
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr "ingen passende funktion for kald til '%T::%D(%A)%#V'"
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%D(%A)'"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "ingen passende funktion for kald til '%D(%A)'"
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "kald af flertydig '%D(%A)' er tvetydigt"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call member function `%D' without object"
 msgid "cannot call member function %qD without object"
 msgstr "kan ikke kalde medlemsfunktionen '%D' uden et objekt"
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' chooses `%T' over `%T'"
 msgid "passing %qT chooses %qT over %qT"
 msgstr "videregivelse af '%T' vælger '%T' frem for '%T'"
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, fuzzy, gcc-internal-format
 #| msgid "choosing `%D' over `%D'"
 msgid "choosing %qD over %qD"
 msgstr "vælger '%D' frem for '%D'"
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  for conversion from %qT to %qT"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  fordi konverteringssekvensen for parameteren er bedre"
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "standardparameter angivet i eksplicit specialisering"
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ifølge ISO C++ er '%D' og '%D' tvetydigt selvom den værste konvertering for førstnævnte er bedre end den værste konvertering for den sidstnævnte"
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert `%E' to `%T'"
 msgid "could not convert %qE from %qT to %qT"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, fuzzy, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
@@ -36086,7 +35987,7 @@
 msgid "  by %q+D"
 msgstr "  af '%D'"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' invalid; an anonymous union can only have non-static data members"
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
@@ -36098,7 +35999,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "'%#D' er ugyldig; en anonym union kan kun have ikke-statiske datamedlemmer"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, fuzzy, gcc-internal-format
 #| msgid "private member `%#D' in anonymous union"
 msgid "private member %q+#D in anonymous union"
@@ -36110,7 +36011,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "privat medlem '%#D' i en anonym union"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, fuzzy, gcc-internal-format
 #| msgid "protected member `%#D' in anonymous union"
 msgid "protected member %q+#D in anonymous union"
@@ -36261,74 +36162,85 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  men overskriver ikke 'operator=(const %T&)'"
 
-#: cp/class.c:4538
+#: cp/class.c:4300
+#, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
 #, fuzzy, gcc-internal-format
+#| msgid "assignment (not initialization) in declaration"
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr "tildeling (ikke klargøring) i erklæring"
+
+#: cp/class.c:4557
+#, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-virtual method `%D'"
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "startværdi angivet for ikke-virtuel medlemsfunktion '%D'"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%q+T is not literal because:"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "  non-static data member %q+D has volatile type"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference `%#D' in class without a constructor"
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr "ikke-statisk reference '%#D' i klasse uden en konstruktionsfunktion"
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member `%#D' in class without a constructor"
 msgid "non-static const member %q+#D in class without a constructor"
@@ -36336,114 +36248,114 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, fuzzy, gcc-internal-format
 #| msgid "direct base `%T' inaccessible in `%T' due to ambiguity"
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkte stamklasse '%T' er ikke tilgængelig i '%T' på grund af tvetydighed"
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, fuzzy, gcc-internal-format
 #| msgid "virtual base `%T' inaccessible in `%T' due to ambiguity"
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuel stamklasse '%T' er ikke tilgængelig i '%T' på grund af tvetydighed"
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "offset of `%D' is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr "afsættet for '%D' følger ikke ABI'en og kan ændre sig i en fremtidig version af GCC"
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "redefinition of %q#T"
 msgstr "omdefinering af '%#T'"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "'%#T' har virtuelle funktioner, men ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "type transparent %q#T does not have any fields"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "  eftersom typen '%T' har abstrakte virtuelle funktioner"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "forsøgte at afslutte struct, men blev stoppet af tidligere fortolkningsfejl"
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, fuzzy, gcc-internal-format
 #| msgid "language string `\"%s\"' not recognized"
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "sprogstrengen '\"%s\"' ikke genkendt"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, fuzzy, gcc-internal-format
 #| msgid "cannot resolve overloaded function `%D' based on conversion to type `%T'"
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "kan ikke benytte den flertydiggjorte funktion '%D' baseret på konvertering til typen '%T'"
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, fuzzy, gcc-internal-format
 #| msgid "no matches converting function `%D' to type `%#T'"
 msgid "no matches converting function %qD to type %q#T"
 msgstr "ingen passende ved konvertering af funktionen '%D' til typen '%#T'"
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, fuzzy, gcc-internal-format
 #| msgid "converting overloaded function `%D' to type `%#T' is ambiguous"
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "konvertering af den flertydiggjorte funktion '%D' til typen '%T' er tvetydig"
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, fuzzy, gcc-internal-format
 #| msgid "assuming pointer to member `%D'"
 msgid "assuming pointer to member %qD"
 msgstr "antager henvisning til medlemmet '%D'"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with `&%E')"
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(en henvisning til medlem kan kun dannes med '&%E')"
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "ikke tilstrækkelig information om typen"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%E' from type `%T' to type `%T'"
 msgid "cannot convert %qE from type %qT to type %qT"
@@ -36454,13 +36366,13 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %q#D"
 msgstr "omerklæring af '%#D'"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of `%D' from `%+#D'"
 msgid "changes meaning of %qD from %q+#D"
@@ -36504,43 +36416,43 @@
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr ""
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to internal function"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to non-constexpr function %qD"
@@ -36547,236 +36459,236 @@
 msgstr "kald af ikke-funktion '%D'"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' implicitly declared before its definition"
 msgid "%qD used before its definition"
 msgstr "'%s' er underforstået erklæret efter dens definition"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "protocol `%s' has circular dependency"
 msgid "call has circular dependency"
 msgstr "protokollen '%s' har cirkulær afhængighed"
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%q+E is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "højreskiftsantal er negativ"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript out of bound"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "negative array subscript"
 msgstr "tvetydig konvertering af tabelindeks"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qE is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "accessing uninitialized member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "%qD used in its own initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%q#D is not const"
 msgstr "'%s' er ikke en funktion,"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is private"
 msgid "%q#D is volatile"
 msgstr "'%+#D' er privat"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "modification of %qE is not a constant-expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "enum- og ikke enum-type i betinget udtryk"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "ugyldig reinterpret_cast fra typen '%T' til typen '%T'"
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "uventet adresseudtryk"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, fuzzy, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant-expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unexpected type for `id' (%s)"
 msgid "unexpected AST of kind %s"
@@ -36850,7 +36762,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr ""
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr ""
@@ -36893,7 +36805,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "konvertering fra '%T' til '%T' forkaster modifikationer"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, fuzzy, gcc-internal-format
 #| msgid "casting `%T' to `%T' does not dereference pointer"
 msgid "casting %qT to %qT does not dereference pointer"
@@ -36905,326 +36817,326 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "kan ikke konvertere typen '%T' til typen '%T'"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%#T' to `%#T'"
 msgid "conversion from %q#T to %q#T"
 msgstr "konvertering fra '%#T' til '%#T'"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' used where a `%T' was expected"
 msgid "%q#T used where a %qT was expected"
 msgstr "'%#T' benyttet hvor '%T' var forventet"
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert `%E' to `%T'"
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' used where a floating point value was expected"
 msgid "%q#T used where a floating point value was expected"
 msgstr "'%#T' benyttet hvor der forventedes en kommatalsværdi"
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%T' to non-scalar type `%T' requested"
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "konvertering fra '%T' til en ikke-skalartype '%T' udbedt"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, fuzzy, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "konvertering til en ufuldstændig type"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of type `%T'"
 msgid "conversion to void will not access object of type %qT"
 msgstr "kan ikke allokere et objekt af typen '%T'"
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "second operand of conditional expression has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "third operand of conditional expression has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right operand of comma operator has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of comma operator has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, fuzzy, gcc-internal-format
 #| msgid "%Hstatement with no effect"
 msgid "statement has no effect"
 msgstr "%Hsætning uden nogen virkning"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "for increment expression has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "konverterer NULL til en ikke-henvisningstype"
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument `%E' to `%T'"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "kunne ikke konvertere skabelonsparameteren '%E' til '%T'"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous default type conversion from `%T'"
 msgid "ambiguous default type conversion from %qT"
 msgstr "tvetydig standardtypekonvertering fra '%T'"
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, fuzzy, gcc-internal-format
 #| msgid "  candidate conversions include `%D' and `%D'"
 msgid "  candidate conversions include %qD and %qD"
@@ -37690,126 +37602,126 @@
 msgid "template parameters do not match template %qD"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, fuzzy, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr "en anonym union kan ikke have funktionsmedlemmer"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, fuzzy, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr "en anonym union kan ikke have funktionsmedlemmer"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with constructor not allowed in anonymous aggregate"
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med konstruktionsfunktion er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with destructor not allowed in anonymous aggregate"
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med destruktionsfunktion er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with copy assignment operator not allowed in anonymous aggregate"
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med kopitildelingsoperator er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "forhåndserklæring af '%#T'"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "flere typer i én erklæring"
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type `%T'"
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "omerklæring af indbygget type i C++ '%T'"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "manglende typenavn i typedef-erklæring"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ forbyder anonyme strukturer"
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%qs can only be specified for functions"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified inside a class"
 msgid "%<friend%> can only be specified inside a class"
 msgstr "'%D' kan kun angives inden i en klasse"
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for constructors"
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "'%D' kan kun angives for konstruktionsfunktioner"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "a storage class can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "qualifiers can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "tom erklæring"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter list used in explicit instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "skabelonsparameterliste benyttet i eksplicit instantiering"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
@@ -37816,145 +37728,145 @@
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
 # init dækker over værditildeling her - samme for de næste mange
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, fuzzy, gcc-internal-format
 #| msgid "typedef `%D' is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef '%D' bliver tildelt en værdi (benyt __typeof__ i stedet)"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "erklæringen af '%#D' indeholder 'extern' og variablen bliver tildelt en startværdi"
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "'auto' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "non-member-template declaration of %qD"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "does not match member template declaration here"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not permit `%T::%D' to be defined as `%T::%D'"
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tillader ikke '%T::%D' at blive defineret som '%T::%D'"
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "duplicate initialization of %qD"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr ""
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, fuzzy, gcc-internal-format
 #| msgid "variable `%#D' has initializer but incomplete type"
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variablen '%#D' bliver tildelt en startværdi, men er af en ufuldstændig type"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementer i tabellen '%#D' er af en ufuldstændig type"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "erklæringen af '%#D' indeholder 'extern' og variablen bliver tildelt en startværdi"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, fuzzy, gcc-internal-format
 #| msgid "aggregate `%#D' has incomplete type and cannot be defined"
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "den sammensatte type '%#D' er af en ufuldstændig type og kan ikke defineres"
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as reference but not initialized"
 msgid "%qD declared as reference but not initialized"
 msgstr "'%D' erklæret som en reference, men bliver ikke tildelt en startværdi"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, fuzzy, gcc-internal-format
 #| msgid "non-trivial labeled initializers"
 msgid "non-trivial designated initializers not supported"
 msgstr "ikke-trivielle navngivne startværdier"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of `%D'"
 msgid "initializer fails to determine size of %qD"
 msgstr "startværdien giver ikke størrelsen af '%D'"
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qD"
 msgstr "tabelstørrelsen mangler i '%D'"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qD"
@@ -37963,247 +37875,247 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't known"
 msgid "storage size of %qD isn%'t known"
 msgstr "lagringsstørrelsen af '%D' er ikke kendt"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "lagringsstørrelsen af '%D' er ikke konstant"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data `%#D' are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "semantikken for indlejret funktionsstatisk data '%#D' er forkert (du ender med flere kopier)"
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  du kan arbejde dig rundt om dette ved at fjerne startværdien"
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const `%D'"
 msgid "uninitialized const %qD"
 msgstr "konstant '%D' uden startværdi"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "typen '%T' har ingen destruktionsfunktion"
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for virtual method `%D'"
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for `%T' must be brace-enclosed"
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "startværdi for '%T' skal være indesluttet i krøllede paranteser"
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "%qT has no non-static data member named %qD"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "ugyldig startværdi"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in aggregate initializer"
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "for mange elementer i startværdi til sammensat type"
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, fuzzy, gcc-internal-format
 #| msgid "too many initializers for `%T'"
 msgid "too many initializers for %qT"
 msgstr "for mange startværdier for '%T'"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "braces around scalar initializer for type %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer"
 msgid "missing braces around initializer for %qT"
 msgstr "krøllede paranteser mangler omkring startværdien"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementer i tabellen '%#D' er af en ufuldstændig type"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ISO C89 forbyder sammensatte konstanter"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "'%D' er af en ufuldstændig type"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "scalar object %qD requires one element in initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be initialized by constructor, not by `{...}'"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "'%D' skal klargøres af en konstruktionsfunktion, ikke af '{...}'"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "_Pragma tager en strengkonstant med paranteser omkring"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "tildeling af startværdi er ugyldig for statisk medlem med konstruktionsfunktion"
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(en klargøring uden for klassens erklæring er nødvendig)"
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' with uninitialized const fields"
 msgid "reference %qD is initialized with itself"
 msgstr "medlem '%D' med konstante felter uden startværdi"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing previous type declaration of `%#D'"
 msgid "shadowing previous type declaration of %q#D"
 msgstr "skygger for tidligere typeerklæring af '%#D'"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr ""
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr ""
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, fuzzy, gcc-internal-format
 #| msgid "function `%#D' is initialized like a variable"
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen '%#D' bliver tildelt en startværdi som en variabel"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of `%D'"
 msgid "initializer fails to determine size of %qT"
 msgstr "startværdien giver ikke størrelsen af '%D'"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "tabelstørrelsen mangler i '%D'"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "nulstørrelsestabel '%D'"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, fuzzy, gcc-internal-format
 #| msgid "destructor for alien class `%T' cannot be a member"
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, fuzzy, gcc-internal-format
 #| msgid "constructor for alien class `%T' cannot be a member"
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> variable"
@@ -38210,37 +38122,37 @@
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "'%D' er erklæret som en ven"
 
 # %s bliver omsat til typen
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> type"
@@ -38247,19 +38159,19 @@
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> field"
@@ -38266,37 +38178,37 @@
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%q+D declared as a friend"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared with an exception specification"
 msgid "%q+D declared with an exception specification"
 msgstr "'%D' erklæret med en undtagelsesspecifikation"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' not in a namespace surrounding `%D'"
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "erklæring af '%D' er ikke i et navnerum der omgiver '%D'"
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, fuzzy, gcc-internal-format
 #| msgid "static member function `%#D' declared with type qualifiers"
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion '%#D' erklæret med typemodifikationer"
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "defining explicit specialization %qD in friend declaration"
@@ -38303,614 +38215,614 @@
 msgstr "definering af eksplicit specialisering '%D' i friend-erklæring"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-id `%D' in declaration of primary template"
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ugyldig brug af skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, fuzzy, gcc-internal-format
 #| msgid "`inline' is not allowed in declaration of friend template specialization `%D'"
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "'inline' er ikke tilladt i erklæring venneskabelonsspecialisering '%D'"
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, fuzzy, gcc-internal-format
 #| msgid "`inline' is not allowed in declaration of friend template specialization `%D'"
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr "'inline' er ikke tilladt i erklæring venneskabelonsspecialisering '%D'"
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be a template"
 msgid "cannot declare %<::main%> to be a template"
 msgstr "kan ikke erklære '::main' som en skabelon"
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be inline"
 msgid "cannot declare %<::main%> to be inline"
 msgstr "kan ikke erklære '::main' som indlejret"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be inline"
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "kan ikke erklære '::main' som indlejret"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be static"
 msgid "cannot declare %<::main%> to be static"
 msgstr "kan ikke erklære '::main' som statisk"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "skabelon med C-kædning"
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, fuzzy, gcc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "%qD has invalid argument list"
 msgstr "#%s med ugyldig parameter"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, fuzzy, gcc-internal-format
 #| msgid "`main' must return `int'"
 msgid "%<::main%> must return %<int%>"
 msgstr "'main' skal returnere typen 'int'"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of implicitly-declared %qD"
 msgstr "definition af underforstået-erklæret '%D'"
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definition af underforstået-erklæret '%D'"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' previously defined here"
 msgid "%q+#D explicitly defaulted here"
 msgstr "'%#D' tidligere defineret her"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, fuzzy, gcc-internal-format
 #| msgid "no `%#D' member function declared in class `%T'"
 msgid "no %q#D member function declared in class %qT"
 msgstr "ingen medlemsfunktion '%#D' erklæret i klassen '%T'"
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids initialization of member constant `%D' of non-integral type `%T'"
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ forbyder tildeling af startværdi til medlemskonstant '%D' af en ikke-heltallig type"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "størrelsen af tabellen '%D' er ikke af en heltalstype"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "størrelsen af tabel er ikke af en heltalstype"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is negative"
 msgid "size of array %qD is negative"
 msgstr "størrelsen af tabellen '%D' er negativ"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "størrelsen af tabel er negativ"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array `%D'"
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ forbyder tabellen '%D' med størrelsen nul"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ forbyder tabel med størrelsen nul"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array `%D'"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ forbyder tabellen '%D' med variabel størrelse"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ forbyder tabel med variabel størrelse"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "tabeldimension for stor"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "'%s' erklæret som en tabel af void"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of void"
 msgstr "opretter tabel af '%T'"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of references"
 msgstr "opretter tabel af '%T'"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of function members"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "erklæring af '%D' som flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "angivelse af returneringstypen til konstruktionsfunktion er ugyldigt"
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "angivelse af returneringstypen til destruktionsfunktion er ugyldigt"
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, fuzzy, gcc-internal-format
 #| msgid "return type specified for `operator %T'"
 msgid "return type specified for %<operator %T%>"
 msgstr "returtype angivet for 'operator %T'"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "unavngiven variabel eller felt erklæret void"
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel eller felt erklæret void"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ugyldig brug af medlemmet '%D'"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type `%T'"
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ugyldig definition af modificeret type '%T'"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ugyldig brug af medlemmet '%D'"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%q#T is not a class or a namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qD as non-function"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qD as non-member"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, fuzzy, gcc-internal-format
 #| msgid "declarator-id missing; using reserved word `%D'"
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "erklærer-id mangler; bruger reserveret ord '%D'"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `register'"
 msgid "function definition does not declare parameters"
 msgstr "'register' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "erklæring af '%D' som %s"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, fuzzy, gcc-internal-format
 #| msgid "two or more data types in declaration of `%s'"
 msgid "two or more data types in declaration of %qs"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C understøtter ikke at blot 'complex' betyder 'double complex'"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids declaration of `%s' with no type"
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ forbyder erklæring af '%s' uden en type"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_trap not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_trap understøttes ikke på denne målarkitektur"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ understøtter ikke 'long long'"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for `%s'"
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "short, signed eller unsigned er ugyldig for '%s'"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, fuzzy, gcc-internal-format
 #| msgid "signed and unsigned given together for `%s'"
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "signed og unsigned er begge angivet for '%s'"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long long%> invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long%> invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<short%> invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "long, short, signed og unsigned er ugyldige for '%s'"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, fuzzy, gcc-internal-format
 #| msgid "long or short specified with char for `%s'"
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "long eller short angivet samtidig med char for '%s'"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, fuzzy, gcc-internal-format
 #| msgid "long and short specified together for `%s'"
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "long og short er begge angivet for '%s'"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for `%s'"
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "short, signed eller unsigned er ugyldig for '%s'"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned used invalidly for `%s'"
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed og unsigned er benyttet på ugyldig vis for '%s'"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "complex invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both virtual and static"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-erklæringer er ugyldig i parametererklæringer"
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for template parameter %qs"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "lagringsklasseanvisninger er ugyldige i parametererklæringer"
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "virtual angivet uden for klasseerklæring"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "multiple storage classes in declaration of %qs"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %s `%s'"
 msgid "storage class specified for %qs"
 msgstr "lagringsklasse angivet for %s '%s'"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for parameter %qs"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, fuzzy, gcc-internal-format
 #| msgid "nested function `%s' declared `extern'"
 msgid "nested function %qs declared %<extern%>"
 msgstr "indlejret funktion '%s' er erklæret 'extern'"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, fuzzy, gcc-internal-format
 #| msgid "top-level declaration of `%s' specifies `auto'"
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope `%s' implicitly auto and declared `__thread'"
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "'%s' i funktionsvirkefelt underforstået auto og erklæret '__thread'"
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "lagringsklasseanvisninger er ugyldige i vennefunktionserklæringer"
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "%qs declared as function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning an array"
 msgid "%qs declared as function returning an array"
 msgstr "'%s' er erklæret som en funktion der returnerer en tabel"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
@@ -38917,299 +38829,299 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be cv-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be `%s'"
 msgid "constructors may not be cv-qualified"
 msgstr "konstruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be ref-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function `%s' in a local class definition"
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "kan ikke definere vennefunktion '%s' i en lokal klassedefinition"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktionsfunktioner må ikke have parametre"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T'"
 msgid "cannot declare pointer to %q#T"
 msgstr "kan ikke erklære henvisning til '%#T'"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to `%#T'"
 msgid "cannot declare reference to %q#T"
 msgstr "kan ikke erklære reference til '%#T'"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T' member"
 msgid "cannot declare pointer to %q#T member"
 msgstr "kan ikke erklære henvisning til medlemmet '%#T'"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare references to references"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan ikke erklære referencer til referencer"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' used as a declarator"
 msgid "template-id %qD used as a declarator"
 msgstr "skabelons-id '%D' benyttet som erklærer"
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner er underforstået venner af deres klasse"
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification `%T::' on member `%s' ignored"
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra modifikation '%T::' af medlemmet '%s' ignoreret"
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member `%T::%s' within `%T'"
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlem '%T::%s' inde i '%T'"
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array %qs is too large"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type `%T'"
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type `%T'"
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual angivet uden for klasseerklæring"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "definering af eksplicit specialisering '%D' i friend-erklæring"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be `explicit'"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "kun erklæringer af konstruktionsfunktioner kan være 'explicit'"
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, fuzzy, gcc-internal-format
 #| msgid "non-member `%s' cannot be declared `mutable'"
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er medlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, fuzzy, gcc-internal-format
 #| msgid "non-object member `%s' cannot be declared `mutable'"
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er objektmedlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, fuzzy, gcc-internal-format
 #| msgid "static `%s' cannot be declared `mutable'"
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "static '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, fuzzy, gcc-internal-format
 #| msgid "const `%s' cannot be declared `mutable'"
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, fuzzy, gcc-internal-format
 #| msgid "type is deprecated (declared at %s:%d)"
 msgid "typedef declared %<auto%>"
 msgstr "type er forældet (erklæret ved %s:%d)"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, fuzzy, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids nested type `%D' with same name as enclosing class"
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ forbyder indlejret type '%D' med samme navn som den omgivende klasse"
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr "typemodifikationer angivet for friend class-erklæring"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, fuzzy, gcc-internal-format
 #| msgid "`inline' specified for friend class declaration"
 msgid "%<inline%> specified for friend class declaration"
 msgstr "'inline' angivet for friend class-erklæring"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration requires class-key, i.e. `friend class %T::%D'"
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. 'friend class %T::%D'"
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration requires class-key, i.e. `friend %#T'"
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. 'friend %#T'"
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, fuzzy, gcc-internal-format
 #| msgid "trying to make class `%T' a friend of global scope"
 msgid "trying to make class %qT a friend of global scope"
 msgstr "forsøg på at gøre klassen '%T' til ven af det globale virkningsfelt"
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ugyldige modifikationer for ikke-medlemsfunktionstype"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, fuzzy, gcc-internal-format
 #| msgid "abstract declarator `%T' used as declaration"
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt erklærer '%T' benyttet som erklæring"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use `::' in parameter declaration"
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "kan ikke bruge '::' i parametererklæring"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter declared %<auto%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "non-static data member declared %<auto%>"
@@ -39216,156 +39128,156 @@
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "ugyldig brug af '::'"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function `%#D' conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "erklæring af C-funktionen '%#D' strider mod"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' declared virtual inside a union"
 msgid "function %qD declared virtual inside a union"
 msgstr "funktionen '%D' erklæret virtual inden i en union"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr "'%D' kan ikke erklæres virtual eftersom den altid er statisk"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %qD as member of %qT"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering af underforstået erklæret speciel medlemsfunktion"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel eller felt erklæret void"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "feltet '%D' er af en ufuldstændig type"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, fuzzy, gcc-internal-format
 #| msgid "name `%T' has incomplete type"
 msgid "name %qT has incomplete type"
 msgstr "navnet '%T' er af en ufuldstændig type"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is neither function nor member function; cannot be declared friend"
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "'%s' er hverken en almindelig funktion eller en medlemsfunktion; kan ikke erklæres som friend"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `auto' invalid for function `%s'"
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen 'auto' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `register' invalid for function `%s'"
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen 'register' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier `%s' not allowed after struct or class"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "typeangivelsen '%s' er ikke tilladt efter struct eller class"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, fuzzy, gcc-internal-format
 #| msgid "virtual non-class function `%s'"
 msgid "virtual non-class function %qs"
 msgstr "virtuel funktion '%s' tilhører ikke en klasse"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, fuzzy, gcc-internal-format
 #| msgid "method definition not in class context"
 msgid "%qs defined in a non-class scope"
 msgstr "metodedefinitionen optræder ikke i en klassekontekst"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%D' to have static linkage"
 msgid "cannot declare member function %qD to have static linkage"
@@ -39372,89 +39284,89 @@
 msgstr "kan ikke erklære medlemsfunktion '%D' til at have statisk kædning"
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan ikke erklære en funktion for static inden i en anden funktion"
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, fuzzy, gcc-internal-format
 #| msgid "`static' may not be used when defining (as opposed to declaring) a static data member"
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "'static' må ikke bruges ved definering (i modsætning til erklæring) af et statisk datamedlem"
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, fuzzy, gcc-internal-format
 #| msgid "cannot explicitly declare member `%#D' to have extern linkage"
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "kan ikke eksplicit erklære medlemmet '%#D' til at have extern-kædning"
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' initialized and declared `extern'"
 msgid "%qs initialized and declared %<extern%>"
 msgstr "'%s' bliver tildelt en startværdi og er samtidig erklæret 'extern'"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' has both `extern' and initializer"
 msgid "%qs has both %<extern%> and initializer"
 msgstr "'%s' er erklæret 'extern', men bliver tildelt en startværdi"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `virtual' in template declaration of `%#D'"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ugyldig brug af 'virtual' i skabelonserklæring af '%#D'"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' invalidly declared method type"
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameteren '%D' er på ugyldig vis erklæret som af en medlemsfunktionstype"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameteren '%D' inkluderer %s til tabel med ukendt grænse '%T'"
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
@@ -39475,77 +39387,77 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constructor; you probably meant `%T (const %T&)'"
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ugyldig konstruktionsfunktion; du mente sandsynligvis '%T (const %T&)'"
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD may not be declared within a namespace"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a nonstatic member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be either a non-static member function or a non-member function"
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "'%D' skal enten være en ikke-statisk medlemsfunktion eller ikke en medlemsfunktion"
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must have an argument of class or enumerated type"
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "'%D' skal have en parameter af en klasse- eller enum-type"
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to void will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a base class will never use a type conversion operator"
@@ -39552,123 +39464,123 @@
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ forbyder flertydiggørelse af operatoren ?:"
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must not have variable number of arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its argument"
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr "postfiks '%D' skal tage mod 'int' som parameter"
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its second argument"
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr "postfiks '%D' skal tage mod 'int' som den anden parameter"
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either zero or one argument"
 msgid "%qD must take either zero or one argument"
 msgstr "'%D' skal tage mod nul eller én parameter"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must take either one or two arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, fuzzy, gcc-internal-format
 #| msgid "prefix `%D' should return `%T'"
 msgid "prefix %qD should return %qT"
 msgstr "præfiks '%D' skal returnere '%T'"
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' should return `%T'"
 msgid "postfix %qD should return %qT"
 msgstr "postfiks '%D' skal returnere '%T'"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take `void'"
 msgid "%qD must take %<void%>"
 msgstr "'%D' skal tage mod 'void'"
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "%qD must take exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must take exactly two arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined `%D' always evaluates both arguments"
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should return by value"
 msgid "%qD should return by value"
 msgstr "'%D' skal returnere pr. værdi (ikke reference)"
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "%qD cannot have default arguments"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter `%T' after `%s'"
 msgid "using template type parameter %qT after %qs"
 msgstr "bruger skabelonstypeparameter '%D' efter '%s'"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization `%D' for `%+D'"
 msgid "using alias template specialization %qT after %qs"
 msgstr "tvetydig skabelonsspecialisering '%D' for '%+D'"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, fuzzy, gcc-internal-format
 #| msgid "using typedef-name `%D' after `%s'"
 msgid "using typedef-name %qD after %qs"
 msgstr "bruger typedef-navn '%D' efter '%s'"
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "tidligere erklæring som '%#D'"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "'%#D' omerklæret som %C"
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, fuzzy, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "dette er en tidligere erklæring"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "'%#D' omerklæret som %C"
@@ -39680,29 +39592,29 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, fuzzy, gcc-internal-format
 #| msgid "use of enum `%#D' without previous declaration"
 msgid "use of enum %q#D without previous declaration"
 msgstr "brug af enum '%#D' uden tidligere erklæring"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration `%#D' declares a non-template function"
 msgid "redeclaration of %qT as a non-template"
@@ -39709,67 +39621,67 @@
 msgstr "friend-erklæring '%#D' erklærer en ikke-skabelonsfunktion"
 
 # hænger sammen med næste tekst
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %q+D"
 msgstr "tidligere erklæring '%D'"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, fuzzy, gcc-internal-format
 #| msgid "derived union `%T' invalid"
 msgid "derived union %qT invalid"
 msgstr "nedarvet union '%T' ugyldig"
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, fuzzy, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, fuzzy, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, fuzzy, gcc-internal-format
 #| msgid "base type `%T' fails to be a struct or class type"
 msgid "base type %qT fails to be a struct or class type"
 msgstr "stamklassetype '%T' er hverken en struct- eller class-type"
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, fuzzy, gcc-internal-format
 #| msgid "recursive type `%T' undefined"
 msgid "recursive type %qT undefined"
 msgstr "rekursiv type '%T' ikke defineret"
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate base type `%T' invalid"
 msgid "duplicate base type %qT invalid"
 msgstr "stamklassetype '%T' optræder mere end én gang"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidligere definition her"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr ""
@@ -39778,96 +39690,96 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in enumeration values at `%D'"
 msgid "overflow in enumeration values at %qD"
 msgstr "enum-værdier for store ved '%D'"
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr ""
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "return type %q#T is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, fuzzy, gcc-internal-format
 #| msgid "return type is an incomplete type"
 msgid "return type has Java class type %q#T"
 msgstr "returtypen er en ufuldstændig type"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, fuzzy, gcc-internal-format
 #| msgid "`operator=' should return a reference to `*this'"
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "'operator=' bør returnere en reference til '*this'"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "ingen tidligere erklæring af '%s'"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, fuzzy, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "Ugyldig erklæring"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %qD declared void"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %q+D set but not used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in class `%T'"
 msgid "%qD is already defined in class %qT"
 msgstr "'%D' er allerede defineret i klassen '%T'"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -39912,7 +39824,7 @@
 msgid "deleting %qT is undefined"
 msgstr "benyttelse af delete på '%T' er ikke defineret"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %q#D"
@@ -39939,7 +39851,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
@@ -40045,27 +39957,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "bitfelt '%#D' med en ikke-heltalstype"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonym struct er ikke inden i en navngiven type"
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "anonyme variabler af sammensatte typer i navnerumsvirkefelt skal erklæres static"
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, fuzzy, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonym sammensat type uden medlemmer"
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' must return type `%T'"
 msgid "%<operator new%> must return type %qT"
@@ -40075,50 +39987,50 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' takes type `size_t' (`%T') as first parameter"
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "den første parameter til 'operator new' skal være af typen 'size_t' ('%T')"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, fuzzy, gcc-internal-format
 #| msgid "`operator delete' must return type `%T'"
 msgid "%<operator delete%> must return type %qT"
 msgstr "'operator delete' skal returnere typen '%T'"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, fuzzy, gcc-internal-format
 #| msgid "`operator delete' takes type `%T' as first parameter"
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "den første parameter til 'operator delete' skal være af typen '%T'"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using anonymous type, is used but never defined"
@@ -40128,51 +40040,51 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "'%#D' refererer ikke til den ikkemodificerede type, so den bruges ikke til sammenkædning"
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%J'%F' erklæret 'static', men aldrig defineret"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, fuzzy, gcc-internal-format
 #| msgid "inline function `%D' used but never defined"
 msgid "inline function %q+D used but never defined"
 msgstr "indbygget funktion '%D' benyttet, men aldrig defineret"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, fuzzy, gcc-internal-format
 #| msgid "default argument missing for parameter %P of `%+#D'"
 msgid "default argument missing for parameter %P of %q+#D"
@@ -40180,12 +40092,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "use of deleted function %qD"
@@ -40825,42 +40737,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "startværdien slutter for tidligt"
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr "kan ikke klargøre multidimensional tabel med startværdi"
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "ukendt tabelstørrelse i delete"
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
@@ -40995,17 +40907,17 @@
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, gcc-internal-format
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, gcc-internal-format
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
@@ -41463,7 +41375,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr ""
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -41490,7 +41402,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-klassetype '%T'"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "'%#D' kan ikke erklæres"
@@ -41565,7 +41477,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "semikolon mangler efter erklæring af '%T'"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qT is not a template"
@@ -41593,7 +41505,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -41875,7 +41787,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
@@ -42061,7 +41973,7 @@
 msgid "capture of non-variable %qD "
 msgstr ""
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%q+#D declared here"
@@ -42126,7 +42038,7 @@
 msgid "compound-statement in constexpr function"
 msgstr "I sætningsfunktion"
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
@@ -42158,7 +42070,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "uventet operand"
@@ -42190,12 +42102,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ forbyder beregnede goto'er"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "uventet operand"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
@@ -42244,7 +42156,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
@@ -42343,13 +42255,13 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "det reserverede ord 'export' er ikke implementeret og vil blive ignoreret"
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
@@ -42366,7 +42278,7 @@
 msgid "expected template-id"
 msgstr "uventet operand"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<<%>"
@@ -42447,228 +42359,228 @@
 msgid "expected type specifier"
 msgstr "sigof-typeangivelse"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C forbyder forhåndsparametererklæringer"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type `%D', got `%D'"
 msgid "expected template-id for type"
 msgstr "  forventede en skabelon af typen '%D', modtog '%D'"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "erklæring erklærer ikke noget"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on uninstantiated type"
 msgid "attributes ignored on uninstantiated type"
 msgstr "ugyldig operation på uudskiftet type"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "attributes ignored on template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qD is not an enumerator-name"
 msgstr "'%D' er ikke et navnerum"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aktivér automatisk skabelonsinstantiering"
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, fuzzy, gcc-internal-format
 #| msgid "multiple definition of `%#T'"
 msgid "multiple definition of %q#T"
 msgstr "flere definitioner af '%#T'"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qD is not a namespace-name"
 msgstr "'%D' er ikke et navnerum"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: funktionsdefinitionen er ikke omdannet\n"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, fuzzy, gcc-internal-format
 #| msgid "empty scalar initializer"
 msgid "expected initializer"
 msgstr "tom skalarstartværdi"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-member function `%D'"
 msgid "initializer provided for function"
 msgstr "startværdi angivet for ikke-medlemsfunktion '%D'"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "funktionen '%s' omerklæret som inline"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array bound is not an integer constant"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a template"
 msgid "%<%T::%E%> is not a type"
 msgstr "'%D::%D' er ikke en skabelon"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -42677,7 +42589,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ugyldig erklærer"
@@ -42684,309 +42596,309 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Ugyldig erklæring"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declarator"
 msgstr "tom erklæring"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is a namespace"
 msgid "%qD is a namespace"
 msgstr "'%D' er et navnerum"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "uventet operand"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate case value"
 msgid "duplicate cv-qualifier"
 msgstr "case-værdi optræder mere end én gang"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple ref-qualifiers"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "duplicate virt-specifier"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %<auto%>"
 msgstr "ugyldig brug af '%D"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "uventet operand"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, fuzzy, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ tillader ikke udpegede startværdier"
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tillader ikke udpegede startværdier"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "kan ikke finde filen for klassen %s"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid class name in declaration of %qD"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "ekstra modifikation '%T::' af medlemmet '%D' ignoreret"
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "eksplicit specialisering følger ikke efter 'template <>'"
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "previous definition of %q+#T"
 msgstr "tidligere definition af '%#T'"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "uventet operand"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "uventet operand"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr ""
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
@@ -42995,522 +42907,522 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "for mange skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver understøttes ikke længere"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template `%#D' in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "ugyldig erklæring af medlemsskabelon '%#D' i lokal klasse"
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "skabelon med C-kædning"
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "invalid explicit specialization"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %<typedef%>"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, fuzzy, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> før %qD"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 understøtter ikke %<long long%>"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "duplikere %qD"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "duplikere %qs"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "forventede %<new%>"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "forventede %<delete%>"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "forventede %<return%>"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "forventede %<extern%>"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "forventede %<static_assert%>"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "forventede %<decltype%>"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "forventede %<operator%>"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "forventede %<class%>"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "forventede %<template%>"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "forventede %<namespace%>"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "forventede %<using%>"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "forventede %<asm%>"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "forventede %<try%>"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "forventede %<catch%>"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "forventede %<throw%>"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "forventede %<__label__%>"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "forventede %<@try%>"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "forventede %<@synchronized%>"
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "forventede %<@throw%>"
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "forventede %<__transaction_atomic%>"
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "forventede %<__transaction_relaxed%>"
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "forventede %<::%>"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "forventede %<...%>"
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "forventede %<*%>"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "forventede %<~%>"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "forventede %<:%> or %<::%>"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' tag used in naming `%#T'"
 msgid "%qs tag used in naming %q#T"
 msgstr "'%s'-mærke benyttet i navngivning af '%#T'"
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "'%s' tidligere erklæret her"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "%Hslutningen af filen læst inden i standardparameter"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Klasse- eller grænsefladeerklæring forventet"
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name `%s' for register variable"
 msgid "invalid type for instance variable"
 msgstr "ugyldigt registernavn '%s' for registervariabel"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, fuzzy, gcc-internal-format
 #| msgid "Identifier expected"
 msgid "identifier expected after %<@protocol%>"
 msgstr "Kaldenavn forventet"
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "ugyldig typeparameter"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "expected positive integer expression"
 msgstr "']' forventet, ugyldigt typeudtryk"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid identifier `%s'"
 msgid "invalid reduction-identifier"
 msgstr "ugyldigt kaldenavn '%s'"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr ""
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough collapsed for loops"
 msgstr "ikke tilstrækkelig information om typen"
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, fuzzy, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "ugyldig startværdi"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected side-effects in address"
 msgid "expected id-expression (arguments)"
 msgstr "uventede bivirkninger i adresse"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma GCC java_exceptions"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "ragelse i slutningen af #pragma GCC java_exceptions"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "ugyldige begrænsninger for operand"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "profilering understøttes ikke endnu"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 msgid "expected variable-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "data member %qD cannot be a member template"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid member template declaration %qD"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope `%D'"
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "eksplicit specialisering i virkefeltet '%D' der ikke er et navnerum"
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "omgivende klasseskabeloner er ikke eksplicit specialiserede"
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, fuzzy, gcc-internal-format
 #| msgid "specializing `%#T' in different namespace"
 msgid "specialization of %qD in different namespace"
@@ -43517,42 +43429,42 @@
 msgstr "specialiserer '%#T' i andet navnerum"
 
 # hænger sammen med foregående tekst, derfor ikke 'fra'
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of `%#D'"
 msgid "  from definition of %q+#D"
 msgstr "  i forhold til definition af '%#D'"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of alias template %qD"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit specialization of non-template %qT"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of `%T' after instantiation"
 msgid "specialization of %qT after instantiation"
 msgstr "specialisering af '%T' efter instantiering"
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, fuzzy, gcc-internal-format
 #| msgid "specializing `%#T' in different namespace"
 msgid "specializing %q#T in different namespace"
@@ -43560,76 +43472,76 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, fuzzy, gcc-internal-format
 #| msgid "specialization `%T' after instantiation `%T'"
 msgid "specialization %qT after instantiation %qT"
 msgstr "specialisering af '%T' efter instantiering '%T'"
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, fuzzy, gcc-internal-format
 #| msgid "template specialization with C linkage"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "skabelonsspecialisering med C-kædning"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "specialization of %qD after instantiation"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, fuzzy, gcc-internal-format
 msgid "candidate is: %#D"
 msgstr "candidate%s: %+#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
 msgstr "%s %+#D"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%qD is not a function template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a variable template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization `%D' for `%+D'"
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "tvetydig skabelonsspecialisering '%D' for '%+D'"
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %D (should be %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -43636,62 +43548,62 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' in declaration of primary template"
 msgid "template-id %qD in declaration of primary template"
 msgstr "skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "skabelonsparameterliste benyttet i eksplicit instantiering"
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "definition angivet for eksplicit instantiering"
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of `%D'"
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "for mange skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, fuzzy, gcc-internal-format
 #| msgid "too few template parameter lists in declaration of `%D'"
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "eksplicit specialisering følger ikke efter 'template <>'"
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%D' of function template"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "partiel specialisering '%D' af funktionsskabelon"
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "standardparameter angivet i eksplicit specialisering"
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD is not a template function"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD is not declared in %qD"
@@ -43705,94 +43617,94 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "specialisering af underforstået erklæret speciel medlemsfunktion"
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, fuzzy, gcc-internal-format
 #| msgid "no member function `%D' declared in `%T'"
 msgid "no member function %qD declared in %qT"
 msgstr "ingen medlemsfunktion '%D' erklæret i '%T'"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, fuzzy, gcc-internal-format
 #| msgid "        `%D'"
 msgid "        %qD"
 msgstr "        '%D'"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, fuzzy, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "<anonym %s>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %q+#D"
 msgstr "omerklæring af '%#D'"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, fuzzy, gcc-internal-format
 #| msgid " shadows template parm `%#D'"
 msgid " shadows template parm %q+#D"
 msgstr "  skygger for skabelonsparameter '%#D'"
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "skabelonsparametre der ikke bruges i partiel specialisering:"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
 # flertalsform unødvendig
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "template argument %qE involves template parameter(s)"
@@ -43799,7 +43711,7 @@
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
 # flertalsform unødvendig
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' of template argument `%E' depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -43807,13 +43719,13 @@
 msgstr[0] "typen '%T' af skabelonsparameteren '%E' afhænger af skabelonsparameter"
 msgstr[1] "typen '%T' af skabelonsparameteren '%E' afhænger af skabelonsparameter"
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, fuzzy, gcc-internal-format
 #| msgid "no default argument for `%D'"
 msgid "no default argument for %qD"
@@ -43822,46 +43734,46 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "skabelonsparametre der ikke bruges i partiel specialisering:"
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type `%T' has type `%T'"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "skabelonsklasse uden et navn"
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -43871,66 +43783,66 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid template declaration of %qD"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "template definition of non-template `%#D'"
 msgid "template definition of non-template %q#D"
 msgstr "skabelonsdefinition af ikke-skabelon '%#D'"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, fuzzy, gcc-internal-format
 #| msgid "expected %d levels of template parms for `%#D', got %d"
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "forvented %d niveauer af skabelonsparametre for '%#D', modtog %d"
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "got %d template parameters for %q#D"
 msgstr "modtog %d skabelonsparametre for '%#D'"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#T'"
 msgid "got %d template parameters for %q#T"
 msgstr "modtog %d skabelonsparametre for '%#T'"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  men %d påkrævet"
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use template<> for an explicit specialization"
 msgstr "omgivende klasseskabeloner er ikke eksplicit specialiserede"
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "%qT is not a template type"
 msgstr "'%T' er ikke en skabelonstype"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, fuzzy, gcc-internal-format
 #| msgid "too few template parameter lists in declaration of `%D'"
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -43938,7 +43850,7 @@
 msgstr[0] "'%D' benyttet uden skabelonsparametre"
 msgstr[1] "'%D' benyttet uden skabelonsparametre"
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "previous declaration %q+D used %d template parameter"
@@ -43946,13 +43858,13 @@
 msgstr[0] "tidligere erklæring af '%#D' her"
 msgstr[1] "tidligere erklæring af '%#D' her"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter `%#D'"
 msgid "template parameter %q+#D"
 msgstr "skabelonsparameter '%#D'"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as `%#D'"
 msgid "redeclared here as %q#D"
@@ -43962,114 +43874,114 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "redefinition of default argument for %q#D"
 msgstr "omdefinering af standardparameter for '%#D'"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "  oprindelig definition er her"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "den skal være adressen af en funktion med ekstern kædning"
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "den skal være adressen af en funktion med ekstern kædning"
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, fuzzy, gcc-internal-format
 #| msgid "it must be a pointer-to-member of the form `&X::Y'"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "den skal være en henvisning til medlem på formen '&X::Y'"
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "modtog %d skabelonsparametre for '%#D'"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types `%#T' and `%#T'"
 msgid "  mismatched types %qT and %qT"
 msgstr "sammenligning mellem typerne '%#T' og '%#T'"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
 # flertalsform unødvendig
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -44076,195 +43988,195 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type `%T' to type `%T'"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "kan ikke konvertere typen '%T' til typen '%T'"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is an ambiguous base of `%T'"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "'%T' er en tvetydig stamklasse til '%T'"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' is not derived from type `%T'"
 msgid "  %qT is not derived from %qT"
 msgstr "typen '%T' er ikke nedarvet fra typen '%T'"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument %qE does not match %qD"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "  could not resolve address from overloaded function %qE"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT "
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, fuzzy, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "ugyldig brug af 'restrict'"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, fuzzy, gcc-internal-format
 #| msgid "to refer to a type member of a template parameter, use `typename %E'"
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "benyt 'typename %E' for at referere til et typemedlem af en skabelonsparameter"
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a constant of type `%T', got `%T'"
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  forventede en konstant af typen '%T', modtog '%T'"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected a type, got %qE"
 msgstr "  forventede en type, modtog '%E'"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%T'"
 msgid "  expected a type, got %qT"
 msgstr "  forventede en type, modtog '%T'"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got `%T'"
 msgid "  expected a class template, got %qT"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type `%D', got `%D'"
 msgid "  expected a template of type %qD, got %qT"
@@ -44272,85 +44184,85 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in nontype parameter pack"
 msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument `%E' to `%T'"
 msgid "could not convert template argument %qE to %qT"
 msgstr "kunne ikke konvertere skabelonsparameteren '%E' til '%T'"
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, fuzzy, gcc-internal-format
 #| msgid "provided for `%D'"
 msgid "provided for %q+D"
 msgstr "angivet for '%D'"
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%q#D is not a function template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, fuzzy, gcc-internal-format
 #| msgid "non-template type `%T' used as a template"
 msgid "non-template type %qT used as a template"
 msgstr "ikke-skabelonstype '%T' benyttet som skabelon"
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration `%D'"
 msgid "for template declaration %q+D"
 msgstr "til skabelonserklæring '%D'"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "  when instantiating default argument for call to %D"
@@ -44369,305 +44281,305 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "variable %qD has function type"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "ugyldig parametertype '%T'"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "i erklæringen '%D'"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, fuzzy, gcc-internal-format
 #| msgid "function returns an aggregate"
 msgid "function returning an array"
 msgstr "funktion returnerer en værdi af en sammensat type"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member function of non-class type `%T'"
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "opretter henvisning til medlemsfunktion af typen '%T' der ikke er en klasse"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "danner reference til void"
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming pointer to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming reference to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming pointer to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming reference to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "creating pointer to member of non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member reference type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member of type void"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of %qT"
 msgstr "opretter tabel af '%T'"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class, struct, or union type"
 msgid "%qT is not a class, struct, or union type"
 msgstr "'%T' er ikke en class-, struct- eller union-type"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "unavngiven klargøring af '%T' som ikke har nogen stamklasser"
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%s' in template"
 msgid "use of %qs in template"
 msgstr "brug af '%s' i skabelon"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, fuzzy, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "'%D' benyttes som en type, men er ikke defineret som en type"
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, fuzzy, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "  (benyt 'typename %T::%D' hvis det er hvad du mener)"
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, fuzzy, gcc-internal-format
 #| msgid "missing static field `%s'"
 msgid "using invalid field %qD"
 msgstr "manglende statisk felt '%s'"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%q+D declared here, later in the translation unit"
 msgstr "'%s' ikke erklæret her (ikke i en funktion)"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qT is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qD is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr "skabelonsparameter '%T' benytter anonym type"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "standardparameter for '%#D' har typen '%T'"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, fuzzy, gcc-internal-format
 #| msgid "  trying to instantiate `%D'"
 msgid "  trying to instantiate %qD"
 msgstr "  ved forsøg på at instantiere '%D'"
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-template %q#D"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching template for %qD found"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D'"
 msgid "explicit instantiation of %q#D"
 msgstr "eksplicit instantiering af '%#D'"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#D'"
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "'%#D' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `extern' on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af 'extern' ved eksplicitte instantieringer"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#T' before definition of template"
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplicit instantiering af '%T' før definering af skabelonen"
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `%s' on explicit instantiations"
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af '%s ved eksplicitte instantieringer"
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#T'"
 msgid "duplicate explicit instantiation of %q#T"
@@ -44680,69 +44592,69 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%D' but no definition available"
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplicit instantiering af '%D', men ingen definition tilgængelig"
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'%#T' er ikke en gyldig type for en skabelonsparameterkonstant "
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, fuzzy, gcc-internal-format
 #| msgid "%s as integer rather than floating due to prototype"
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%s som heltal i stedet for kommatal på grund af prototypen"
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Ugyldig metodeerklæring, returtype påkrævet"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
@@ -45010,52 +44922,52 @@
 msgid "invalid base-class specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, fuzzy, gcc-internal-format
 #| msgid "protected member `%#D' in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "beskyttet medlem '%#D' i en anonym union"
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD is not captured"
 msgstr "'%D' ikke erklæret"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of parameter from containing function"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace `%D' as expression"
 msgid "use of namespace %qD as expression"
 msgstr "brug af navnerummet '%D' som udtryk"
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "use of class template %qT as expression"
@@ -45062,24 +44974,24 @@
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' is ambiguous in multiple inheritance lattice"
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "forespørgsel efter medlemmet '%D' er tvetydigt i det multiple nedarvningsnet"
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "type of `%E' is unknown"
 msgid "type of %qE is unknown"
 msgstr "typen af '%E' er ukendt"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "%qT is not an enumeration type"
@@ -45086,202 +44998,202 @@
 msgstr "'%T' er ikke en skabelonstype"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "lagringsklasseanvisninger er ugyldige i parametererklæringer"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, fuzzy, gcc-internal-format
 #| msgid "invalid return type for function `%#D'"
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in clause %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, gcc-internal-format
 msgid "%<num_teams%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid reference type"
 msgid "%qE has reference type for %qs"
 msgstr "Ugyldig referencetype"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "erklæring uden static af '%s' følger static-erklæring"
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "argument to decltype must be an expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
@@ -45299,133 +45211,133 @@
 msgid "lambda-expression in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to Java class definitions"
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "egenskaben '%s' kan kun anvendes med Java-klassedefinitioner"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is obsolete; g++ vtables are now COM-compatible by default"
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr "'%s' er forældet; virtuelle tabeller i g++ er nu COM-kompatible som standard"
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "den udbedte init_priority er ikke en heltalskonstant"
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, fuzzy, gcc-internal-format
 #| msgid "can only use `%s' attribute on file-scope definitions of objects of class type"
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "kan kun bruge egenskaben '%s' på filvirkefeltsdefinitioner af objekter af klassetype"
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "den udbedte init_priority er uden for det gyldige interval"
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "den udbedte init_priority er reserveret til intern brug"
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute is not supported on this platform"
 msgid "%qE attribute is not supported on this platform"
 msgstr "egenskaben '%s' er ikke understøttet på denne platform"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "erklæring af '%D' som %s"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "previous declaration here"
 msgstr "tidligere erklæring af '%#D' her"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "the %qE attribute requires arguments"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "'%T::%D' er ikke en gyldig erklærer"
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a valid expression"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "'%T' er ikke et gyldigt udtryk"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, fuzzy, gcc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "zero as null pointer constant"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_*-kontrol: mislykkedes i %s, ved %s:%d"
@@ -45636,243 +45548,238 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr ""
 
-#: cp/typeck.c:3141
-#, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr "ISO C++ forbyder indeksering af en ikke-venstreværdis tabel"
-
-#: cp/typeck.c:3157
+#: cp/typeck.c:3148
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared `register'"
 msgid "subscripting array declared %<register%>"
 msgstr "indeksering af tabel som er erklæret 'register'"
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "værdien der er påført et indeks, er hverken en tabel eller en henvisningsvariabel"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, fuzzy, gcc-internal-format
 #| msgid "object missing in use of `%E'"
 msgid "object missing in use of %qE"
 msgstr "objekt mangler i brug af '%E'"
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids calling `::main' from within program"
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ forbyder kald af '::main' inde fra programmet"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, fuzzy, gcc-internal-format
 #| msgid "must use .* or ->* to call pointer-to-member function in `%E (...)'"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "brug .* eller ->* i kald af henvisning til medlemsfunktion i '%E (...)'"
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "%qE cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "too many arguments to constructor %q#D"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "too few arguments to constructor %q#D"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to member function %q#D"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to member function %q#D"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %q#D"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %q#D"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "too many arguments to method %q#D"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "too few arguments to method %q#D"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, fuzzy, gcc-internal-format
 #| msgid "assuming cast to type `%T' from overloaded function"
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "antager typeomtvingning til typen '%T' fra flertydig funktion"
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL benyttet i udregning"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "left rotate count is negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "right rotate count is negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "left rotate count >= width of type"
 msgstr "%s-roteringsantal >= bredden af typen"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "right rotate count >= width of type"
 msgstr "%s-roteringsantal >= bredden af typen"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweak declaration of '%D' after first use results in unspecified behavior"
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr "%Jsvag erklæring af '%D' efter første brug resulterer i ikke-defineret opførsel"
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ forbyder sammenligning mellem henvisningsvariabel og heltal"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "uordnet sammenligning af ikke-kommatalsparameter"
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands of types `%T' and `%T' to binary `%O'"
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ugyldige operander af typerne '%T' og '%T' til binær '%O'"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids using pointer of type `void *' in subtraction"
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning af typen 'void *' i fratrækning"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning til funktion i fratrækning"
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning til medlemsfunktion i fratrækning"
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ugyldig brug af en henvisning til en ufuldstændig type i henvisningsberegning"
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of constructor %qE"
 msgstr "tager adressen på en destruktionsfunktion"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of destructor %qE"
 msgstr "tager adressen på en destruktionsfunktion"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' to form a pointer-to-member-function.  Use a qualified-id."
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ugyldig brug af '%E' til at danne en henvisning til medlemsfunktion; benyt et kaldenavn med klassepræfiks"
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesis around '%E' cannot be used to form a pointer-to-member-function"
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
@@ -45879,12 +45786,12 @@
 msgstr "paranteser omkring '%E' kan ikke bruges til at danne en henvisning til medlemsfunktion"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ forbyder at tage adressen på en ikke-modificeret, ikke-statisk medlemsfunktion for at danne en henvisning til medlemsfunktion; brug '&%T::%D'"
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say `&%T::%D'"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
@@ -45891,387 +45798,387 @@
 msgstr "ISO C++ forbyder at tage adressen på en bundet medlemsfunktion for at danne en henvisning til medlemsfunktion; brug '&%T::%D'"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking address of function `::main'"
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ forbyder at tage adressen på funktionen '::main'"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr "ISO C++ forbyder at tage adressen på en typeomtvingning til et udtryk der ikke er en venstreværdi"
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member `%D'"
 msgid "cannot create pointer to reference member %qD"
 msgstr "kan ikke oprette henvisning til reference medlemmet '%D'"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type `%T'"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ forbyder %s af en henvisning af typen '%T'"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type `%T'"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ forbyder %s af en henvisning af typen '%T'"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "ugyldigt udtryk som operand"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of `this', which is an rvalue expression"
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan ikke tage adressen af 'this' som er et højreværdiudtryk"
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable `%s' requested"
 msgid "address of explicit register variable %qD requested"
 msgstr "forespørgsel efter adressen af registervariablen '%s'"
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, fuzzy, gcc-internal-format
 #| msgid "address requested for `%D', which is declared `register'"
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adresse forespurgt for '%D' som er erklæret 'register'"
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast fra typen '%T' til typen '%T' fjerner konstanthed"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, fuzzy, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast fra typen '%T' til typen '%T' fjerner konstanthed"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from `%T' to `%T' casts away const (or volatile)"
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast fra '%T' til '%T' fjerner const (eller volatile)"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %qT"
 msgstr "skabelonsparameter '%T' benytter lokal type '%T'"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type `%T' to type `%T'"
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "ugyldig static_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "converting from %qT to %qT"
 msgstr "konvertering fra '%T' til '%T'"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast of an rvalue expression of type `%T' to type `%T'"
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "ugyldig reinterpret_cast af et højreværdiudtryk fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from `%T' to `%T' loses precision"
 msgid "cast from %qT to %qT loses precision"
 msgstr "reinterpret_cast fra '%T' til '%T' mister præcision"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, fuzzy, gcc-internal-format
 #| msgid "cast from `%T' to `%T' increases required alignment of target type"
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "typeomtvingning fra '%T' til '%T' forøger den påkrævede justering af målets type"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ forbyder sammenligninger mellem henvisning til funktion og henvisning til objekt"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type `%T' to type `%T'"
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ugyldig const_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type `%T', which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ugyldig brug af const_cast med typen '%T' som ikke er en henvisnings-, reference- eller en henvisning til datamedlem-type"
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type `%T', which is a pointer or reference to a function type"
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "ugyldig brug af const_cast med typen '%T' som er en henvisning eller reference til funktion"
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type `%T' to type `%T'"
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type `%T' to type `%T'"
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "ugyldig const_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting to an array type `%T'"
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ forbyder omtvingelse af typen til en tabeltype '%T'"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "invalid cast to function type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, fuzzy, gcc-internal-format
 #| msgid "  in evaluation of `%Q(%#T, %#T)'"
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  i evaluering af '%Q(%#T, %#T)'"
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, fuzzy, gcc-internal-format
 #| msgid "bad array initializer"
 msgid "array used as initializer"
 msgstr "ugyldig tildeling af startværdi til tabel"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "invalid array assignment"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   i henvisning til medlemsfunktion-omdannelse"
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "henvisning til medlem-omdannelse via den virtuelle stamklasse '%T' af '%T'"
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   i henvisning til medlem-omdannelse"
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion to type `%T' from type `%T'"
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' for argument `%P' to `%D'"
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "kan ikke konvertere '%T' til '%T' for parameter '%P' til '%D'"
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' for argument `%P' to `%D'"
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "kan ikke konvertere '%T' til '%T' for parameter '%P' til '%D'"
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT in return"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of `%+D'"
 msgid "in passing argument %P of %q+D"
 msgstr "i overbringelse af parameter %P af '%+D'"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "returnerer reference til midlertidig variabel"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "reference til ikke-venstreværdi returneret"
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable `%D' returned"
 msgid "reference to local variable %q+D returned"
 msgstr "reference til den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of label %q+D returned"
 msgstr "adresse af den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of local variable %q+D returned"
 msgstr "adresse af den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "returnerer en værdi fra en destruktionsfunktion"
@@ -46278,35 +46185,35 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "kan ikke returnere fra en håndtering af en funktions-try-blok i en konstruktionsfunktion"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "returnerer en værdi fra en konstruktionsfunktion"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "manglende startværdi"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "'return' med en værdi i en funktion der returnerer void"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' must not return NULL unless it is declared `throw()' (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
@@ -46313,12 +46220,12 @@
 msgstr "'operator new' må ikke returnere NULL medmindre den er erklæret 'throw()' (eller -fcheck-new er benyttet)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -46579,139 +46486,139 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of `%E' from `%T' to `%T' is ambiguous"
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "konvertering af '%E' fra '%T' til '%T' er tvetydigt"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-tabel får tildelt startværdi fra en ikke-bred streng"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "int-array initialized from non-wide string"
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-tabel får tildelt startværdi fra en ikke-bred streng"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "startværdistrengen til char-tabellen er for lang"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "missing initializer for member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD is uninitialized reference"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, fuzzy, gcc-internal-format
 #| msgid "no field `%D' in union being initialized"
 msgid "no field %qD found in union being initialized"
 msgstr "intet felt '%D' i union der tildeles startværdi"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indeksværdi i stedet for feltnavn i union-startværdi"
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "fundet en henvisningsefterfølgelse der går i ring"
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' has non-pointer type `%T'"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grundoperanden til '->' har en ikke-henvisningstype '%T'"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, fuzzy, gcc-internal-format
 #| msgid "result of `operator->()' yields non-pointer result"
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet af 'operator->()' er ikke en henvisning"
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' is not a pointer"
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grundoperanden til '->' er ikke en henvisning"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a member pointer, since it is of type `%T'"
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "'%E' kan ikke bruges som en medlemshenvisning eftersom udtrykkets type er '%T'"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer `%E' to `%E', which is of non-aggregate type `%T'"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "kan ikke anvende medlemshenvisning '%E' på '%E' som er af den ikke-sammensatte type '%T'"
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, fuzzy, gcc-internal-format
 #| msgid "member type `%T::' incompatible with object type `%T'"
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "medlemstypen '%T::' uforenelige med objekttypen '%T'"
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "functional cast to array type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, fuzzy, gcc-internal-format
 #| msgid "default-initialization of `%#D', which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "standardklargøring af '%#D' som er af en referencetype"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "call to function `%D' which throws incomplete type `%#T'"
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "kald af en funktion '%D' som kaster en ufuldstændig type '%#T'"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, fuzzy, gcc-internal-format
 #| msgid "call to function which throws incomplete type `%#T'"
 msgid "call to function which throws incomplete type %q#T"
@@ -46895,8 +46802,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -47038,7 +46945,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -47157,7 +47064,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -47759,12 +47666,12 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
@@ -48036,6 +47943,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr ""
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -48043,7 +47955,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -48273,420 +48185,420 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "kan ikke klargøre multidimensional tabel med startværdi"
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization designators may not nest"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "klargøringstegn må ikke indlejres"
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Error in pointer initialization at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "non-NULL pointer initialization at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 msgid "Function name %qs not allowed at %C"
 msgstr "sektionsegenskaben er ikke tilladt for '%s'"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Zero-size array at %0"
 msgid "Implied-shape array at %L"
 msgstr "Nulstørrelsestabel ved %0"
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Old-style initialization at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected an initialization expression at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jweak declaration of '%D' not supported"
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "%Jsvag erklæring af '%D' ikke understøttet"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nested extern declaration of `%s'"
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "indlejret extern-erklæring af '%s'"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing formal parameter term"
 msgid "Missing right parenthesis at %C"
 msgstr "Manglende formel parameterterm"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected initialization expression at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected scalar initialization expression at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "rounding mode not supported for VAX floats"
 msgid "Kind %d not supported for type %s at %C"
 msgstr "afrundingstilstand er ikke understøttet for VAX-kommatal"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "rounding mode not supported for VAX floats"
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "afrundingstilstand er ikke understøttet for VAX-kommatal"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing comma in FORMAT statement at %0"
 msgid "IMPORT statement at %C"
 msgstr "Manglende komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflicting I/O control specifications at %0 and %1"
 msgid "Missing codimension specification at %C"
 msgstr "Modstridende I/O-kontrolangivelser ved %0 og %1"
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing dimension specification at %C"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate %s attribute at %L"
 msgstr "mere end én ConstantValue-egenskab for feltet '%s'"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -48693,289 +48605,290 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "Missing term"
 msgid "Missing symbol"
 msgstr "Manglende term"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "Alternate-return argument at %C"
 msgstr "forkert parametertype til %s"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Planlæg ikke begyndelsen og slutningen af proceduren"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicts with function declaration `%#D'"
 msgid "Unexpected junk after function declaration at %C"
 msgstr "strider mod funktionserklæring '%#D'"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "ENTRY statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/decl.c:5597
-#, gcc-internal-format
-msgid "gfc_match_entry(): Bad state"
-msgstr ""
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Unsupported VXT statement at %0"
+msgid "Unexpected ENTRY statement at %C"
+msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing first operand for binary operator at %0"
 msgid "Missing closing paren for binding label at %C"
 msgstr "Manglende første operand for binær operator ved %0"
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected END statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "END statement instead of %s statement at %L"
@@ -48982,538 +48895,544 @@
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expecting %s statement at %L"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%s' in switch statement"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "mere end én '%s'-etiket i switch-sætningen"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr ""
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "Cray pointer at %C must be an integer"
 msgstr "udsagn skal være et kaldenavn"
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Access specifier or PRIVATE statement at %0 invalid for derived-type definition within other than the specification part of a module"
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "Tilgangsangivelse eller PRIVATE-sætning ved %0 er ugyldig for nedarvet typedefinition som ikke er i specifikationsdelen af et modul"
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Access specifier or PRIVATE statement at %0 invalid for derived-type definition within other than the specification part of a module"
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "Tilgangsangivelse eller PRIVATE-sætning ved %0 er ugyldig for nedarvet typedefinition som ikke er i specifikationsdelen af et modul"
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious sign in FORMAT statement at %0"
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Mystisk fortegn i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializing array with parameter list"
 msgid "Initializing already initialized variable at %C"
 msgstr "klargør tabel med en parameterliste"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "VALUE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "VOLATILE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at `%D' because it has a destructor"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "  kan ikke bruge forældet binding til '%D' fordi den har en destruktionsfunktion"
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "Type name at %0 not the same as name at %1"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typenavn ved %0 er ikke det samme som navn ved %1"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type name expected before `*'"
 msgid "ENUM definition statement expected before %C"
 msgstr "der forventedes et typenavn før '*'"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "multiple access specifiers"
 msgid "Duplicate access-specifier at %C"
 msgstr "mere end én tilgangsangivelse"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "multiple access specifiers"
 msgid "Expected access-specifier at %C"
 msgstr "mere end én tilgangsangivelse"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> forventet ved %C"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Unsupported VXT statement at %0"
+msgid "Malformed GENERIC statement at %C"
+msgstr "Ikke-understøttet VXT-sætning ved %0"
+
+#: fortran/decl.c:8526
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "ukendt registernavn: %s"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr ""
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
@@ -49799,350 +49718,350 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr ""
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from NaN to int"
 msgid "Conversion from %qs to %qs at %L"
 msgstr "konvertering fra NaN til int"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, fuzzy, gcc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "can't open output file `%s'"
 msgid "can't open input file: %s"
@@ -50167,27 +50086,27 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Ingen kald i funktionen %s\n"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr ""
@@ -50245,600 +50164,605 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr ""
+
+#: fortran/interface.c:353
+#, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr ""
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr ""
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr ""
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr ""
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr ""
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr ""
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr ""
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr ""
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr ""
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr ""
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
 msgstr ""
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, gcc-internal-format
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr ""
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, fuzzy, gcc-internal-format
 #| msgid "reference `%s' is ambiguous: appears in interface `%s' and interface `%s'"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "reference '%s' er tvetydig: den optræder i grænsefladen '%s' og grænsefladen '%s'"
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr ""
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of `%s'"
 msgid "Invalid procedure argument at %L"
 msgstr "ugyldig typeparameter '%s'"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Missing value at %1 for real-number exponent at %0"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Manglende værdi ved %1 for reel eksponent ved %0"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "Unable to find symbol %qs"
 msgstr "kunne ikke finde klassen '%s'"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - too many interface type"
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "intern fejl - for mange grænsefladetyper"
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, gcc-internal-format
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
@@ -51272,12 +51196,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
@@ -51287,7 +51211,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
@@ -51312,131 +51236,131 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "FLUSH statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr ""
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Duplicate format specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Duplicate NML specification at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported FORMAT specifier at %0"
 msgid "UNIT not specified at %L"
 msgstr "Ikke-understøttet FORMAT-angivelse ved %0"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "ERR tag label %d at %L not defined"
 msgstr "etiketten '%D' er benyttet, men ikke defineret"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "END tag label %d at %L not defined"
 msgstr "etiketten '%D' er benyttet, men ikke defineret"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "EOR tag label %d at %L not defined"
 msgstr "etiketten '%D' er benyttet, men ikke defineret"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "FORMAT label %d at %L not defined"
 msgstr "etiketten '%D' er benyttet, men ikke defineret"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expected variable in READ statement at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid expression statement"
 msgid "Expected expression in %s statement at %C"
@@ -51443,677 +51367,677 @@
 msgstr "Ugyldig udtrykssætning"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error at '%s' token"
 msgid "Syntax error in %s statement at %C"
 msgstr "syntaksfejl ved symbolet '%s'"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expected comma in I/O list at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr ""
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
 msgstr ""
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer at %0 too large"
 msgid "Integer too large at %C"
 msgstr "Heltal ved %0 for stort"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr ""
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 msgid "Label name %qs at %C is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, gcc-internal-format
 msgid "Duplicate construct label %qs at %C"
 msgstr ""
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid character '%c' in #if"
 msgid "Invalid character in name at %C"
 msgstr "ugyldigt tegn '%c' i #if"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr ""
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr ""
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr ""
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr ""
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr ""
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, gcc-internal-format, gfc-internal-format
 msgid "gfc_match(): Bad match code %c"
 msgstr ""
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing comma in FORMAT statement at %0"
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr "Manglende komma i FORMAT-sætning ved %0"
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Arithmetic IF statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "integer overflow in expression"
 msgid "Syntax error in IF-expression at %C"
 msgstr "heltalsoverløb i udtryk"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr ""
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr ""
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
 msgstr ""
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr ""
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr ""
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr ""
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Duplicate name %qs in association at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, gcc-internal-format
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr ""
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr ""
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, gcc-internal-format
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Invalid type-spec at %C"
 msgstr "ugyldig typeparameter"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr ""
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "%s statement at %C is not within a construct"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "%s statement at %C is not within construct %qs"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 follows ELSE block for IF construct at %1"
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "Sætning ved %0 følger ELSE-blok for IF-konstruktion ved %1"
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr ""
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "PAUSE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr ""
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "UNLOCK statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr ""
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In statement function"
 msgid "ASSIGN statement at %C"
 msgstr "I sætningsfunktion"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious sign in FORMAT statement at %0"
 msgid "Assigned GOTO statement at %C"
 msgstr "Mystisk fortegn i FORMAT-sætning ved %0"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "RETURN statement in main program at %C"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "objekt mangler i brug af '%E'"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
@@ -52121,157 +52045,157 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr ""
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attempt to extend COMMON area beyond its starting point via EQUIVALENCE of `%A'"
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Forsøg på at udvide COMMON-område over dets begyndelsespunkt vha. EQUIVALENCE '%A'"
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement function `%A' defined at %0 is not used"
 msgid "Statement function at %L is recursive"
 msgstr "Sætningsfunktion '%A' defineret ved %0, men er ikke brugt"
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In statement function"
 msgid "Statement function at %C"
 msgstr "I sætningsfunktion"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected initialization expression in CASE at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected CASE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in CASE specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -52424,175 +52348,175 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s for writing: %m"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "kan ikke åbne %s til skrivning: %m"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 #| msgid "%s: error writing file `%s': %s\n"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: fejl ved skrivning til filen '%s': %s\n"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file `%s': %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: kan ikke slette filen '%s': %s\n"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "%s: warning: can't rename file `%s' to `%s': %s\n"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: advarsel: kan ikke omdøbe filen '%s' til '%s': %s\n"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete aux info file `%s': %s\n"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: kan ikke slette hjælpeinformationsfilen '%s': %s\n"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 #| msgid "Symbols have a leading underscore"
 msgid "Symbol %qs already declared"
 msgstr "Symboler har en indledende understreg"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: kan ikke åbne filen '%s' til at læse fra: %s\n"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr ""
@@ -52888,7 +52812,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -53590,378 +53514,373 @@
 msgid "Unexpected %s statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/parse.c:2428
-#, gcc-internal-format, gfc-internal-format
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr ""
-
-#: fortran/parse.c:2439
+#: fortran/parse.c:2438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected EOF while reading source file %s.\n"
 msgid "Unexpected end of file in %qs"
 msgstr "Stødt på slutningen af kildefilen %s tidligere end forventet.\n"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of `%D'"
 msgid "FINAL procedure declaration at %C"
 msgstr "'%D' er tidligere erklæret"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr ""
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in BLOCK DATA program unit at %1"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "Sætning ved %0 er ugyldig  i BLOCK DATA-programenhed ved %1"
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid token at %0 in expression or subexpression at %1"
 msgid "Bad kind expression for function %qs at %L"
 msgstr "Ugyldigt symbol ved %0 i udtryk eller underudtryk ved %1"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr ""
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PUBLIC or PRIVATE statement at %1 cannot be specified along with PUBLIC or PRIVATE statement at %0"
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "PUBLIC- eller PRIVATE-sætning ved %1 kan ikke angives sammen med PUBLIC- eller PRIVATE-sætning ved %0"
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In construct"
 msgid "BLOCK construct at %C"
 msgstr "I konstruktionen"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "Expecting %s at %C"
 msgstr "i %s, ved %s:%d"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr ""
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr ""
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected %s statement in MODULE at %C"
@@ -53970,7 +53889,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -54685,7 +54604,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Label %d referenced at %L is never defined"
@@ -54745,372 +54664,372 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr ""
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qs at %L is not a function"
 msgstr "'%s' er ikke en funktion,"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "resolve_function(): bad function type"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, fuzzy, gcc-internal-format
 #| msgid "cast does not match function type"
 msgid "resolve_subroutine(): bad function type"
 msgstr "typeomtvingelse passer ikke til funktionstype"
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "shared and mdll are not compatible"
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "shared og mdll er indbyrdes uforenelige"
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "indeks mangler i tabelopslag"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Argument dim at %L must be scalar"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array `%A' at %0 is too large to handle"
 msgid "Array index at %L is an array of rank %d"
 msgstr "Tabellen '%A' ved %0 er for stor til at håndtere"
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring begin/end point at %0 out of defined range"
 msgid "Substring end index at %L must be scalar"
 msgstr "Understrengs begyndelses-/slutpunkt ved %0 er uden for det definerede interval"
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is too large"
 msgid "Substring end index at %L is too large"
 msgstr "angivet justering er for stor"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -55119,12 +55038,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -55133,253 +55052,253 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "\"%s\" after # is not a positive integer"
 msgid "%s at %L must be integer"
 msgstr "\"%s\" efter # er ikke et positivt heltal"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -55388,190 +55307,190 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -55578,12 +55497,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -55591,160 +55510,160 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr ""
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr ""
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr ""
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -55751,7 +55670,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -55759,58 +55678,58 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr ""
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer at %0 too large"
 msgid "String length at %L is too large"
 msgstr "Heltal ved %0 for stort"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
@@ -55817,425 +55736,425 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "funktion kan ikke indbygges"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object of type `%T' may not be initialized"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -56242,400 +56161,400 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible types in %s"
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "uforenelige typer i %s"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -56667,49 +56586,49 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr ""
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr ""
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr ""
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "Zero-length character constant at %0"
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "Nul-længde tegnkonstant ved %0"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr ""
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
 msgstr ""
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr ""
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr ""
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s in preprocessing directive"
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr "%s i præprocessordirektiv"
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "can't open output file `%s'"
 msgid "Can't open file %qs"
@@ -56979,54 +56898,54 @@
 msgid "Reshaped array too large at %C"
 msgstr ""
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr ""
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "function call has aggregate value"
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "funktionskald har en sammensat værdi"
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "invalid argument of SQRT at %L"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -57105,322 +57024,328 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
+
+#: fortran/symbol.c:489
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr ""
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%s attribute applied to %s %s at %L"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, gcc-internal-format
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "%s attribute with %s attribute at %L"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, gcc-internal-format
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate %s attribute specified at %L"
 msgstr "mere end én ConstantValue-egenskab for feltet '%s'"
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement or attribute at %1 cannot be specified along with SAVE statement or attribute at %0"
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "SAVE-sætning eller -egenskab ved %1 kan ikke angives sammen med SAVE-sætning eller -egenskab ved %0"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "mere end én ConstantValue-egenskab for feltet '%s'"
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "mere end én ConstantValue-egenskab for feltet '%s'"
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr ""
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%D' is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -57692,7 +57617,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -59339,6 +59264,9 @@
 msgid "creating selector for nonexistent method %qE"
 msgstr "opretter vælger for ikke-eksisterende metode '%s'"
 
+#~ msgid "ISO C++ forbids subscripting non-lvalue array"
+#~ msgstr "ISO C++ forbyder indeksering af en ikke-venstreværdis tabel"
+
 #, fuzzy
 #~| msgid "Specify the name of the target architecture"
 #~ msgid "-march=ARCH Select target architecture"
@@ -64189,12 +64117,6 @@
 #~ msgid "fp_offset (%ld) or end_offset (%ld) is less than zero"
 #~ msgstr "fp_offset (%ld) eller end_offset (%ld) er mindre end nul"
 
-#~ msgid "Trap on integer divide overflow"
-#~ msgstr "Forårsag undtagelse ved heltalsdivisionsoverløb"
-
-#~ msgid "Don't trap on integer divide overflow"
-#~ msgstr "Forårsag ikke undtagelse ved heltalsdivisionsoverløb"
-
 #~ msgid "Use mips16 entry/exit psuedo ops"
 #~ msgstr "Benyt MIPS16-indtrædelse-/afslutningspseudooperationer"
 
Index: gcc/po/tr.po
===================================================================
--- gcc/po/tr.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/tr.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.1.1\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2006-11-16 10:10+0200\n"
 "Last-Translator: Nilgün Belma Bugüner <nilgun@buguner.name.tr>\n"
 "Language-Team: Turkish <gnu-tr-u12a@lists.sourceforge.net>\n"
@@ -208,13 +208,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "gerçel sayı sabit yanlış kullanılmış"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1496,7 +1496,7 @@
 msgid "options enabled: "
 msgstr "etkin seçenekler: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2803,97 +2803,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "terim kodu `%c' geçersiz"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "%%H değeri geçersiz"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "%%J değeri geçersiz"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "%%r değeri geçersiz"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "%%R değeri geçersiz"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "%%N değeri geçersiz"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "%%P değeri geçersiz"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "%%h değeri geçersiz"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "%%L değeri geçersiz"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "%%m değeri geçersiz"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "%%M değeri geçersiz"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "%%U değeri geçersiz"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "%%s değeri geçersiz"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "%%C değeri geçersiz"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "%%E değeri geçersiz"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "bilinmeyen yerdeğişim unspec"
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "%%xn kodu geçersiz"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid operand address"
@@ -2946,7 +2946,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "geçersiz terim çıktı kodu"
@@ -3115,8 +3115,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3338,70 +3338,70 @@
 msgid "bad output_condmove_single operand"
 msgstr "output_condmove_single terimi hatalı"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "terim olarak UNSPEC geçersiz"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "terim kodu `%c' geçersiz"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "kısıtlar terim için geçersiz"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "bilinmeyen komut kipi"
 
@@ -3444,7 +3444,7 @@
 msgid "invalid %%P operand"
 msgstr "%%P terimi geçersiz"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "%%p değeri geçersiz"
@@ -3512,7 +3512,7 @@
 msgstr "sonradan arttırımlı adres bir yazmaç değil"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "hatalı adres"
 
@@ -3695,105 +3695,105 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "Kıymetsiz baytın başta olduğu kod üretilir"
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "hatalı test"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "%%f değeri geçersiz"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "%%F değeri geçersiz"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "%%G değeri geçersiz"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "%%j kodu geçersiz"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "%%J kodu geçersiz"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "%%k değeri geçersiz"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "%%K değeri geçersiz"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "%%O değeri geçersiz"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "%%q değeri geçersiz"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "%%S değeri geçersiz"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "%%T değeri geçersiz"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "%%u değeri geçersiz"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "%%v değeri geçersiz"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "%%x değeri geçersiz"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "kısıt içindeki `%qc' işareti geçersiz"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Her işlev için tek çıkış noktası üretilmez"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load offset for fusion"
@@ -3898,60 +3898,60 @@
 msgid "invalid operand to %%S"
 msgstr "%%S için terim geçersiz"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr "farklı ABI/mimarilerle oluşturulup kullanılmış"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr "farklı ABI'lerle oluşturulup kullanılmış"
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr "farklı bayt sıralaması ile oluşturulup kullanılmış"
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "geçersiz %%Y terimi"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "geçersiz %%A terimi"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "geçersiz %%B terimi"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, c-format
 msgid "invalid %%C operand"
 msgstr "geçersiz %%C terimi"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, c-format
 msgid "invalid %%D operand"
 msgstr "geçersiz %%D terimi"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "geçersiz %%f terimi"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "geçersiz %%s terimi"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "long long sabit geçerli bir anlık terim değil"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "gerçel sayı sabit geçerli bir anlık terim değil"
@@ -4176,7 +4176,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> umuluyordu"
@@ -4192,9 +4192,9 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<(%>"
@@ -4201,7 +4201,7 @@
 msgstr "%<{%> umuluyordu"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -4224,8 +4224,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -4233,8 +4233,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -4246,14 +4246,14 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> umuluyordu"
@@ -4260,8 +4260,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
@@ -4284,7 +4284,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -4304,20 +4304,20 @@
 msgid "expected %<.%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -4324,18 +4324,18 @@
 msgstr "%<,%> veya %<;%> umuluyordu"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> umuluyordu"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<}%>"
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -4347,11 +4347,11 @@
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "1. aday:"
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "2. aday:"
 
@@ -4607,11 +4607,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "adaylar:"
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -4673,50 +4673,50 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "tek terimli eksiye yanlış türde argüman"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "tek terimli artıya yanlış türde argüman"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "bit-tümler için yanlış türde argüman"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs'a yanlış türde argüman"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "mantıksal çarpım için yanlış türde argüman"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "tek terimli artıya yanlış türde argüman"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4816,7 +4816,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "%C'deki ifade içindeki tamsayı değer çok büyük"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 #, fuzzy
 #| msgid "Array assignment"
 msgid "array assignment"
@@ -4842,7 +4842,7 @@
 msgid "Driving:"
 msgstr "Sürülüm:"
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 #, fuzzy
 #| msgid "Actual argument at %L must be definable to match dummy INTENT = OUT/INOUT"
 msgid "actual argument to INTENT = OUT/INOUT"
@@ -4922,13 +4922,13 @@
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -5006,7 +5006,7 @@
 msgid "Bad type in constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 msgid "Unexpected end of module"
 msgstr "Beklenmeyen modül sonu"
 
@@ -5034,11 +5034,11 @@
 msgid "implied END DO"
 msgstr "örtük END DO"
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr "atama"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 msgid "pointer assignment"
 msgstr "gösterici ataması"
 
@@ -5056,235 +5056,235 @@
 msgid "internal function"
 msgstr "bir işlev döndüren işlev"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 #, fuzzy
 #| msgid "elemental subroutine"
 msgid "elemental procedure"
 msgstr "öğesel altyordam"
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "gösterici ataması"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-shape argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "parametrized derived type argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 #, fuzzy
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "result with non-constant character length"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, fuzzy, c-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr "%%L'deki tek terimli sayısal '%s' işlecinin terimi %s"
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr "%%L'deki iki terimli sayısal '%s' işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "%%L'deki dizge ekleme işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr "%%L'deki mantıksal '%s' işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, fuzzy, c-format
 #| msgid "Operand of .NOT. operator at %%L is %s"
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "%%L'deki .NOT. işlecinin terimi %s"
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L'de COMPLEX nicelikler karşılaştırılamıyor"
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L'deki mantıksallar %s ile karşılaştırılmalı %s ile değil"
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr "%%L'deki '%s' karşılaştırma işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, fuzzy, c-format
 #| msgid "unknown operator '%s' in %%:version-compare"
 msgid "Unknown operator '%s' at %%L"
 msgstr "%%:version-compare içindeki '%s' işleci bilinmiyor"
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr "%%L'deki '%s' kullanıcı işlecinin terimi %s"
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr "%%L'deki '%s' kullanıcı işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, fuzzy, c-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Değişken izleme uygulanır"
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "terim olarak ifade geçersiz"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "YERAÇ "
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "AYIR "
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5713,16 +5713,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr ""
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr ""
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr ""
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr "multilib desteklenmiyor"
@@ -5735,6 +5725,12 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "-Xbind-now ile -Xbind-lazy uyumsuz"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+#, fuzzy
+#| msgid "profiling not supported with -mg\n"
+msgid "profiling not supported with -mg"
+msgstr "-mg ile ayrımsama desteklenmiyor\n"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "-mhard-float desteklenmiyor"
@@ -5743,10 +5739,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "-msingle-float ve -msoft-float birlikte belirtilemez."
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr "m210 kıymetli baytın sonda olduğu sıralamayı desteklemez"
-
 #: config/cris/cris.h:184
 #, fuzzy
 #| msgid "cannot specify both -C and -o"
@@ -5781,6 +5773,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr ""
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5787,6 +5785,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr "-m32 ve -m64 birlikte kullanılamayabilir"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr ""
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr "static TPF-OS'da desteklenmiyor"
@@ -5801,6 +5803,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian ve -mlittle-endian birlikte kullanılamayabilir"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr "m210 kıymetli baytın sonda olduğu sıralamayı desteklemez"
+
 #: config/avr/specs.h:68
 #, fuzzy
 #| msgid "-mhard-float not supported"
@@ -5832,17 +5838,19 @@
 msgid "no processor type specified for linking"
 msgstr "belirtim dosyası ilintilenecek özellik içermiyor"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr ""
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr ""
 
@@ -5878,12 +5886,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "-shared seçeneği VAX ELF için şu an desteklenmiyor."
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-#, fuzzy
-#| msgid "profiling not supported with -mg\n"
-msgid "profiling not supported with -mg"
-msgstr "-mg ile ayrımsama desteklenmiyor\n"
-
 #: fortran/lang.opt:146
 #, fuzzy
 #| msgid "Put MODULE files in 'directory'"
@@ -6093,9 +6095,9 @@
 msgstr "Öğe isimlerinde dolar simgesine izin verilir"
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -6324,10 +6326,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -6379,7 +6381,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr "%qs den sonra dosyaismi yok"
@@ -8458,50 +8460,54 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr "Hedef işlemci kıymetsiz baytın başta olduğu yapılandırmaya sahip kabul edilir"
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 #, fuzzy
 #| msgid "Specify the register allocation order"
 msgid "Specify the code model"
 msgstr "Yazmaç ayırma sırası belirtilir"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr "Alt düzey işlevlerde çerçeve göstericisi ihmal edilir"
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr "Verilen işlemcinin özellikleri ve zamanlama kodu kullanılır"
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 #, fuzzy
 #| msgid "Generate code that conforms to the given ABI"
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr "Verilen ABI'ye uyumlu kod üretilir"
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -9718,11 +9724,17 @@
 
 #: config/i386/i386.opt:864
 #, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "MMX ve SSE2 yerleşik işlevleri ve kod üretimi desteklenir"
+
+#: config/i386/i386.opt:868
+#, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use given stack-protector guard"
 msgstr "Yığıt koruma yöntemi olarak propolice kullanılır"
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr ""
 
@@ -10114,7 +10126,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -10269,7 +10281,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
@@ -10404,7 +10416,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr "İşlev önbilgisi ardıllığının zamanlanmasına izin verilir"
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr "İşlev önbilgisinde PIC yazmacı yüklenmez"
 
@@ -10759,369 +10771,367 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "Ortam komutları kullanılır"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr "Güncelleme komutlu yükleme/saklama üretilmez"
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr "Güncelleme komutlu yükleme/saklama üretilir"
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 #, fuzzy
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "%<__builtin_next_arg%> argümansız çağrılmış"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr "Yordam başlangıcı ve sonu zamanlanmaz"
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr "Bellekteki tüm veri yapıları döndürülür (AIX öntanımlı)"
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr "Yazmaçlardaki küçük veri yapıları döndürülür (SVR4 öntanımlı)"
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr "IBM XLC anlambilimine uyumluluk arttırılır"
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 #, fuzzy
 #| msgid "Generate software floating point divide for better throughput"
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr "Daha iyi işbitiricilik için yazılımda kayan noktalı bölme üretir"
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr "TOC'daki kayan noktali sabitleri yerleştirmez"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr "TOC'daki kayan noktali sabitleri yerleştirir"
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "TOC'daki simge+konum sabitlerini yerleştirmez"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr "TOC'daki simge+konum sabitlerini yerleştirir"
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr "Yordam başına yalnız bir TOC girdisi kullanılır"
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr "Herşeyi normal TOC'a koyar"
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr "VRSAVE komutları AltiVec kodu üretilirken üretilir"
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 #, fuzzy
 #| msgid "Deprecated option.  Use -mvrsave/-mno-vrsave instead"
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr "Önerilmeyen seçenek. Yerine -mvrsave/-mno-vrsave kullanın"
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 #, fuzzy
 #| msgid "Deprecated option.  Use -mvrsave/-mno-vrsave instead"
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr "Önerilmeyen seçenek. Yerine -mvrsave/-mno-vrsave kullanın"
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 msgid "Generate isel instructions"
 msgstr "isel komutları üretilir"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 #, fuzzy
 #| msgid "Deprecated option.  Use -misel/-mno-isel instead"
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr "Önerilmeyen seçenek. Yerine -misel/-mno-isel kullanın"
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 #, fuzzy
 #| msgid "Deprecated option.  Use -misel/-mno-isel instead"
 msgid "Deprecated option.  Use -misel instead"
 msgstr "Önerilmeyen seçenek. Yerine -misel/-mno-isel kullanın"
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr "E500 üzerinde SPE SIMD komutları üretilir"
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "isel komutları üretilir"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 #, fuzzy
 #| msgid "Deprecated option.  Use -mspe/-mno-spe instead"
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr "Önerilmeyen seçenek. Yerine -mspe/-mno-spe kullanın"
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 #, fuzzy
 #| msgid "Deprecated option.  Use -mspe/-mno-spe instead"
 msgid "Deprecated option.  Use -mspe instead"
 msgstr "Önerilmeyen seçenek. Yerine -mspe/-mno-spe kullanın"
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "-mdebug=\tEnable debug output"
 msgstr "Hata ayıklamalı çıktı etkinleştirilir"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 #, fuzzy
 #| msgid "Use the Cray Pointer extension"
 msgid "Use the AltiVec ABI extensions"
 msgstr "Cray Göstericisi eklentisi kullanılır"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 #, fuzzy
 #| msgid "Do not use the bit-field instructions"
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "Bit alanı komutları kullanılmaz"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 #, fuzzy
 #| msgid "Use the Cray Pointer extension"
 msgid "Use the SPE ABI extensions"
 msgstr "Cray Göstericisi eklentisi kullanılır"
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 #, fuzzy
 #| msgid "Do not use the bit-field instructions"
 msgid "Do not use the SPE ABI extensions"
 msgstr "Bit alanı komutları kullanılmaz"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv1 ABI"
 msgstr "EABI kullanılır"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv2 ABI"
 msgstr "EABI kullanılır"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 #, fuzzy
 #| msgid "Using darwin64 ABI"
 msgid "using darwin64 ABI"
 msgstr "darwin64 ABI kullanılıyor"
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 #, fuzzy
 #| msgid "Using old darwin ABI"
 msgid "using old darwin ABI"
 msgstr "Eski darwin ABI kullanılıyor"
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 #, fuzzy
 #| msgid "Using IEEE extended precision long double"
 msgid "using IEEE extended precision long double"
 msgstr "IEEE ek duyarlıklı long double kullanılıyor"
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 #, fuzzy
 #| msgid "Using IBM extended precision long double"
 msgid "using IBM extended precision long double"
 msgstr "IBM ek duyarlıklı long double kullanılıyor"
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr "Verilen işlemcinin özellikleri ve zamanlama kodu kullanılır"
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 #, fuzzy
 #| msgid "Schedule code for given CPU"
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "Verilen işlemci için kodu zamanlar"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 #, fuzzy
 #| msgid "Select full, part, or no traceback table"
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr "Ya full veya part seçilir ya da hiçbir traceback tablosu seçilmez"
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr "Çağrı komutlarında tüm aralık sınırları engellenir"
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 #, fuzzy
 #| msgid "Generate SH2e code"
 msgid "Generate Cell microcode"
 msgstr "SH2e kodu üretilir"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 #, fuzzy
 #| msgid "Warn when all constructors and destructors are private"
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "Tüm kurucu ve yıkıcılar private olduğunda uyarır"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr "AltiVec tür kullanımında önerilmeyen 'vector long ...' için uyarır"
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 #, fuzzy
 #| msgid "Select GPR floating point method"
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr "GPR kayan nokta yöntemi seçilir"
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 #, fuzzy
 #| msgid "invalid option for -mfloat-gprs: '%s'"
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "-mfloat-gprs için seçenek geçersiz: '%s'"
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 #, fuzzy
 #| msgid "Specify size of long double (64 or 128 bits)"
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr "long double boyutu belirtilir (64 ya da 128 bit)"
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr "Komutlar arasındaki bağımlılıkların hangilerinin maliyetli varsayıldığı saptanır"
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr "Hangi zamanlama sonrası nop yerleştirme şemasının uygulanacağı belirtilir"
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr "Yapı alanlarının hizalaması default/natural olarak belirtilir"
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 #, fuzzy
 #| msgid "alias argument not a string"
 msgid "Valid arguments to -malign-:"
 msgstr "alias argümanı bir dizge değil"
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr "Yuva kısıtlı komutları sevketmek için zamanlama önceliği belirtilir"
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 #, fuzzy
 #| msgid "unordered comparison on non-floating point argument"
 msgid "Single-precision floating point unit"
 msgstr "gerçel sayı olmayan argümanlar arasında düzenlenmemiş karşılaştırma"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 #, fuzzy
 #| msgid "unordered comparison on non-floating point argument"
 msgid "Double-precision floating point unit"
 msgstr "gerçel sayı olmayan argümanlar arasında düzenlenmemiş karşılaştırma"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 msgid "Floating point unit does not support divide & sqrt"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 #, fuzzy
 #| msgid "Specify an ABI"
 msgid "Specify Xilinx FPU."
 msgstr "Bir ABI belirtilir"
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 #, fuzzy
 #| msgid "Align destination of the string operations"
 msgid "Allow sign extension in fusion operations"
 msgstr "Dizge işlemleri hedefi hizalanır"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
-#, fuzzy
-#| msgid "Use AltiVec instructions"
-msgid "Use ISA 2.07 crypto instructions"
-msgstr "AltiVec komutları kullanılır"
+#: config/rs6000/rs6000.opt:566
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr ""
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Yükleme/saklama çoklu komutları üretilir"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -14362,1740 +14372,1740 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr "Dökümleme için kullanılacak dosyanın salt ismi belirtilir"
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "İşlevlerin başlangıcı hizalanır"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr "Sadece atlanarak ulaşılabilen yaftalara hizalanır"
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr "Tum yaftalara hizalanır"
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "Döngü başlangıcına hizalanır"
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr ""
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr "Önerilmiyor; yerine -Wextra kullanın"
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr "Birbirlerini etkilemeyenlerin tablosu her komutun tam sınırında oluşturulur"
 
-#: common.opt:918
+#: common.opt:921
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate auto-inc/dec instructions"
 msgstr "isel komutları üretilir"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr "Dallanma olasılıkları için ayrımlama bilgileri kullanılır"
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "Diziler indislenmeden önce sınırlarını sınayacak kod üretilir"
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr "Ekleme, karşılaştırma, dallanma sayaç yazmacı üzerinden dallanma ile değiştirilir"
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr "Dallanma olasılıkları için ayrımlama bilgileri kullanılır"
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr "Ön ve ard evreleme öncesi dal hedefli yük eniyilemesi uygulanır"
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr "Ön ve ard evreleme sonrası dal hedefli yük eniyilemesi uygulanır"
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr "Hedef yük göçü hiçbir temel bloktaki yazmaçlar yeniden kullanılmayacak şekilde sınırlanır"
 
-#: common.opt:960
+#: common.opt:963
 #, fuzzy
 #| msgid "Mark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr "<yazmaç> işlevlere karşı korunmuş olarak imlenir"
 
-#: common.opt:964
+#: common.opt:967
 #, fuzzy
 #| msgid "Mark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr "<yazmaç> işlev çağrıları tarafından bozulmuş olarak imlenir"
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr "İşlev çağrıları civarındaki yazmaçlar saklanır"
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr ""
 
-#: common.opt:979
+#: common.opt:982
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++"
 msgstr "new için dönüş değeri sınanır"
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr "İlklendirilmemiş global'ler ortak bölüme konmaz"
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr ""
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr ""
 
-#: common.opt:1003
+#: common.opt:1006
 #, fuzzy
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr "Global ortak alt ifade elemesi yazmaç ayırmasından sonra uygulanır"
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr ""
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr "Yazmaç kopyalama girişimi eniyileme geçişi uygulanır"
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr "Çapraz atlama eniyilemesi uygulanır"
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr "Ortak alt ifade elemesi sırasında hedeflerine dallanmalar izlenir"
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr "Karmaşık bölme sırasında aralık arttırma adımı atlanır"
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr ""
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr "Veri öğelerini kendi bölümlerine yerleştirir"
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr ""
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr ""
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr "Yığıttan işlev argümanlarının çekilmesini erteler"
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr "Dallanma komutlarının gecikme yuvalarını doldurmaya çalışır"
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr "Kullanışsız boş gösterici sınamalarını siler"
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization"
 msgstr "Kuyruk tekrarı üzerinden süper blok oluşumu uygulanır"
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1085
+#: common.opt:1088
 #, fuzzy
 #| msgid "How often to emit source location at the beginning of line-wrapped diagnostics"
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr "Satır sarmalamalı teşhislerin başlangıcında kaynak konumunun ne sıklıkta gösterileceği belirtilir. once: bir kere, every-line: her satırda"
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr "İlgili teşhis iletileri onları denetleyen komut satırı seçenekleri ile iyileştirilir"
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1145
 #, fuzzy
 #| msgid "Dump various compiler internals to a file"
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr "Çeşitli derleyici iç oluşumları bir dosyaya dökümlenir"
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr ""
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr ""
 
-#: common.opt:1157
+#: common.opt:1160
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps"
 msgstr "Hata ayıklama dökümlerinde satır numarası ve komut numarası bilgilerinin çıktılanması engellenir"
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 #, fuzzy
 #| msgid "Perform loop optimizations"
 msgid "Dump optimization passes"
 msgstr "Döngü eniyilemeleri uygulanır"
 
-#: common.opt:1170
+#: common.opt:1173
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr "Hata ayıklama dökümlerinde satır numarası ve komut numarası bilgilerinin çıktılanması engellenir"
 
-#: common.opt:1174
+#: common.opt:1177
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr "Hata ayıklama dökümlerinde satır numarası ve komut numarası bilgilerinin çıktılanması engellenir"
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr "Erken satıriçine alma uygulanır"
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr "DWARF2 yinelenmiş elemesi uygulanır"
 
-#: common.opt:1190
+#: common.opt:1193
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural reduction of aggregates"
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1194
+#: common.opt:1197
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info"
 msgstr "Hata ayıklama bilgilerinde kullanılmamış tür elemesi uygulanır"
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr "Hata ayıklama bilgilerinde kullanılmamış tür elemesi uygulanır"
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "Olağan dışılıkların yakalanması etkinleştirilir"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr "Masraflı eniyilemelerden birkaçını uygular"
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr ""
 
-#: common.opt:1217
+#: common.opt:1220
 #, fuzzy, c-format
 #| msgid "unknown demangling style '%s'"
 msgid "unknown excess precision style %qs"
 msgstr "cendereleme tarzı %s bilinmiyor"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr "NaNların ya da sonsuzların üretilmediği varsayılır"
 
-#: common.opt:1238
+#: common.opt:1241
 #, fuzzy
 #| msgid "Mark <register> as being unavailable to the compiler"
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr "<yazmaç> derleyici için elverişsiz olarak imlenir"
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr "Ek duyarlık yazmaçlarında float'lar ve double'lar ayrılmaz"
 
-#: common.opt:1250
+#: common.opt:1253
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform a forward propagation pass on RTL"
 msgstr "Ağaçlarda Değer Aralığı Girişimi uygulanır"
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, fuzzy, c-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "unknown floating point contraction style %qs"
 msgstr "%qs işlevine kayan noktalı olmayan argüman"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr "Yazmaçlarda tutulan işlev adreslerine izin verilir"
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr "Her işlev kendi bölümüne yerleştirilir"
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr "Global ortak alt ifade elemesi uygulanır"
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr "Global ortak alt ifade elemesi sırasında genişletilmiş yük hareketi uygulanır"
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr "Global ortak alt ifade elemesinden sonra saklama hareketi uygulanır"
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr "Genel ortak alt ifade içindeki saklama elemesinden sonra gereğinden fazla yük uygulanır"
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr "Global ortak alt ifade elemesi yazmaç ayırmasından sonra uygulanır"
 
-#: common.opt:1305
+#: common.opt:1308
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Enable in and out of Graphite representation"
 msgstr "Ölü saklama elemesi etkin olur"
 
-#: common.opt:1309
+#: common.opt:1312
 #, fuzzy
 #| msgid "Emit call graph information"
 msgid "Enable Graphite Identity transformation"
 msgstr "Çağrı çizge bilgisi üretir"
 
-#: common.opt:1313
+#: common.opt:1316
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr ""
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr ""
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr ""
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr ""
 
-#: common.opt:1330
+#: common.opt:1333
 #, fuzzy
 #| msgid "Enable linear loop transforms on trees"
 msgid "Enable Loop Blocking transformation"
 msgstr "Ağaçlarda doğrusal döngü dönüşümü etkin olur"
 
-#: common.opt:1334
+#: common.opt:1337
 msgid "Enable Loop Unroll Jam transformation"
 msgstr ""
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr "Dallanma olasılıklarının tahmini etkinleştirilir"
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr "#ident yönergeleri işlenir"
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr "Dallanmasız karşılıklara koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr "Koşullu çalıştırmaya koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Stack Reuse Level %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:1394
+#: common.opt:1397
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr "Dallanmasız karşılıklara koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr ""
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr ".size yönergeleri üretilmez"
 
-#: common.opt:1410
+#: common.opt:1413
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform indirect inlining"
 msgstr "Erken satıriçine alma uygulanır"
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 #, fuzzy
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "Basit işlevler onları çağıranların içine gömülür"
 
-#: common.opt:1424
+#: common.opt:1427
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "İşlevler onları çağıranların içine bir defa gömülür"
 
-#: common.opt:1428
+#: common.opt:1431
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions only required by their single caller"
 msgstr "İşlevler onları çağıranların içine bir defa gömülür"
 
-#: common.opt:1435
+#: common.opt:1438
 #, fuzzy
 #| msgid "Limit the size of inlined functions to <number>"
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr "Satıriçine alınacak işlevlerin uzunluğu <sayı> ile sınırlanır"
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr "İşlevi giriş ve çıkışı ayrımlama çağrılarıyla yapılır"
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1458
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation"
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1459
+#: common.opt:1462
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1463
+#: common.opt:1466
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1467
+#: common.opt:1470
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural profile propagation"
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1471
+#: common.opt:1474
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural points-to analysis"
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr "Saf ve sabit işlevler keşfedilir"
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables"
 msgstr "Tüm döngüler tersine uygulanır"
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr "Salt okunur ve adreslenemeyen durağan değişkenler keşfedilir"
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr ""
 
-#: common.opt:1506
+#: common.opt:1509
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown IRA algorithm %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr ""
 
-#: common.opt:1519
+#: common.opt:1522
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA region %qs"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr "Ağaçlarda tümevarım değişkenleri eniyilenir"
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "Yeterince büyük switch deyimleri için sıçrama tabloları kullanılır"
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr "Tamamen satıriçi olsalar bile işlevler için kod üretilir"
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr "Kullanılmamış bile olsa statik sabit değişkenler içerilir"
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr "Alt çizgi ile başlayan harici simgeler verilir"
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable link-time optimization."
 msgstr "İlintileyici en iyilemesi etkinleştirilir"
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr ""
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Report various link-time optimization statistics"
 msgstr "Yazmaç isimlendirme eniyileme aşaması uygulanır"
 
-#: common.opt:1625
+#: common.opt:1628
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr "Yerleşik matematik işlevlerinden sonra errno kullanılır"
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr "Ayrılan kalıcı bellek miktarı raporlanır"
 
-#: common.opt:1641
+#: common.opt:1644
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only"
 msgstr "Ayrılan kalıcı bellek miktarı raporlanır"
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr "Özdeş sabitler ve sabit değişkenleri katıştırılmaya çalışılır"
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr "Özdeş sabitler derleme birimlerine karşın katıştırılmaya çalışılır"
 
-#: common.opt:1656
+#: common.opt:1659
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr "Özdeş sabitler derleme birimlerine karşın katıştırılmaya çalışılır"
 
-#: common.opt:1660
+#: common.opt:1663
 #, fuzzy
 #| msgid "Limit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr "Teşhis iletilerinin uzunluğu her satırda <sayı> karakterle sınırlanır. 0 satır sarmalamayı engeller"
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr "İlk zamanlama geçişinden önce SMS tabanlı artanlı zamanlama uygular"
 
-#: common.opt:1668
+#: common.opt:1671
 #, fuzzy
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr "İlk zamanlama geçişinden önce SMS tabanlı artanlı zamanlama uygular"
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr "Döngü ile değişmeyen hesaplamalar döngü dışına taşınır"
 
-#: common.opt:1676
+#: common.opt:1679
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Use the RTL dead code elimination pass"
 msgstr "Ölü saklama elemesi etkin olur"
 
-#: common.opt:1680
+#: common.opt:1683
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Use the RTL dead store elimination pass"
 msgstr "Ölü saklama elemesi etkin olur"
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr "Zaten artanlı zamanlamaya tabi tutulmuş döngülerde geleneksel zamanlama etkin olur/iptal edilir"
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr "Eşzamanlı çağrısız olağandışılıklar desteklenir"
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "%qs den sonra olumlama eksik"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 #| msgid "unknown tls-model \"%s\""
 msgid "unknown offload ABI %qs"
 msgstr "\"%s\" tls-modeli bilinmiyor"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr "Mümkün olduğunca yığıt çerçeveleri üretilmez"
 
-#: common.opt:1713
+#: common.opt:1716
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable all optimization info dumps on stderr"
 msgstr "Ağaç seviyesinde döngü eniyilemeleri etkinleştirilir"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr "Kardeş ve kuyruk özyinelemeli çağrıları eniyilenir"
 
-#: common.opt:1729
+#: common.opt:1732
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform partial inlining"
 msgstr "Erken satıriçine alma uygulanır"
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr ""
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr "Yapı üyelerini birlikte deliksiz paketler"
 
-#: common.opt:1745
+#: common.opt:1748
 #, fuzzy
 #| msgid "Set initial maximum structure member alignment"
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr "İlk azami yapı üyesi hizalaması belirtilir"
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr "Yazmaçlardaki değil bellekteki küçük kümeler döndürülür"
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr "Döngü soyması uygulanır"
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr "Makineye özel gözlem deliği eniyilemesi etkinleştirilir"
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr "sched2 öncesi bir rtl gözlem deliği aşaması etkin olur"
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr "Mümkünse, konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr "Mümkünse, konumdan bağımsız kod üretilir (küçük kip)"
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (küçük kip)"
 
-#: common.opt:1781
+#: common.opt:1784
 #, fuzzy
 #| msgid "Specify options to GNAT"
 msgid "Specify a plugin to load"
 msgstr "GNAT'a özgü seçenekler"
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr ""
 
-#: common.opt:1789
+#: common.opt:1792
 #, fuzzy
 #| msgid "Enables a register move optimization"
 msgid "Run predictive commoning optimization."
 msgstr "Yazmaç taşıma eniyilemesi etkinleştirilir"
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr "Mümkünse, döngülerdeki diziler için önalım komutları üretilir"
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr "Temel program profil çıkarma kodu etkinleştirilir"
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr "arc-tabanlı yazılım ayrımlama kodu eklenir"
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr "Ayrımlama geribesleme yönlendirmeli eniyilemelerin ayrımlama bilgileri üretimi için ortak seçenekler etkinleştirilir"
 
-#: common.opt:1818
+#: common.opt:1821
 #, fuzzy
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Ayrımlama geribesleme yönlendirmeli eniyilemelerin ayrımlama bilgileri üretimi için ortak seçenekler etkinleştirilir"
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr "Ayrımlama geribesleme yönlendirmeli eniyilemelerin uygulanması için ortak seçenekler etkinleştirilir"
 
-#: common.opt:1826
+#: common.opt:1829
 #, fuzzy
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Ayrımlama geribesleme yönlendirmeli eniyilemelerin uygulanması için ortak seçenekler etkinleştirilir"
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr "Kod, ifade ayrımlama değerlerine yerleştirilir"
 
-#: common.opt:1834
+#: common.opt:1837
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Report on consistency of profile"
 msgstr "dahili tutarlılık hatası"
 
-#: common.opt:1838
+#: common.opt:1841
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement"
 msgstr "Kod yerleşimini iyileştirecek işlevleri yeniden sıralar"
 
-#: common.opt:1845
+#: common.opt:1848
 #, fuzzy
 #| msgid "Make compile reproducible using <string>"
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr "<dizge> kullanılarak derleme yeniden türetilebilir yapılır"
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr "Yazmaçlardaki küçük kümeler döndürülür"
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr ""
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr "Yazmaç isimlendirme eniyileme aşaması uygulanır"
 
-#: common.opt:1880
+#: common.opt:1883
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr "Yazmaç isimlendirme eniyileme aşaması uygulanır"
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr "Kod yerleşimini iyileştirecek temel blokları yeniden sıralar"
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr "Temel blokları ve parçaları sıcak ve soğuk bölümler halinde yeniden sıralar"
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr "Kod yerleşimini iyileştirecek işlevleri yeniden sıralar"
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr "Döngü eniyilemesinden sonra bir ortak alt ifade elemesi aşaması eklenir"
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr "Kayan nokta yuvarlama davranışını öntanımlı varsayan eniyilemeler yapılmaz"
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr "Temel bloklar arasında zamanlama etkinleştirilir"
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr "Yük oluşturmayanların tahmini hareketine izin verilir"
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr "Bazı yüklerin tahmini hareketine izin verilir"
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr "Fazla yüklerin tahmini hareketine izin verilir"
 
-#: common.opt:1928
+#: common.opt:1931
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr "Sonradan yeniden yükleme zamanlaması varsa süper blok zamanlaması yapılır"
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr "Yazmaç tahsisinden önce komutları yeniden zamanlar"
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr "Yazmaç tahsisinden sonra komutları yeniden zamanlar"
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr ""
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr ""
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr ""
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr "Kuyruklanmış komutların erken zamanlanmasına izin verilir"
 
-#: common.opt:1981
+#: common.opt:1984
 #, fuzzy
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr "Erken zamanlanabilen kuyruklanmış komutların sayısı belirtilir"
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr "Kuyruklanmış komutların erken zamanlanmasında bağımlılık aralığı denetimi yapılır"
 
-#: common.opt:1993
+#: common.opt:1996
 #, fuzzy
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr "Kuyruklanmış komutların erken zamanlanmasında bağımlılık aralığı denetimi yapılır"
 
-#: common.opt:1997
+#: common.opt:2000
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the group heuristic in the scheduler"
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2009
+#: common.opt:2012
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the rank heuristic in the scheduler"
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr ""
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr "Mümkünse, teşhiste sütun numaralarını gösterir. Öntanımlı"
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr "IEEE sinyalleme NaNları tarafından farkedilebilen eniyilemeler iptal edilir"
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr ""
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr "Kayan noktalı sabitler tek duyarlıklı sabitlere dönüştürülür"
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr "Döngüler geri sarılırken tümevarım ömrü bölünür"
 
-#: common.opt:2062
+#: common.opt:2065
 #, fuzzy
 #| msgid "Generate APCS conformant stack frames"
 msgid "Generate discontiguous stack frames"
 msgstr "APCS uyumlu yığıt çerçeveleri üretilir"
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr ""
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr ""
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr "Döngüler geri sarılırken değişken yorumlaması uygulanır"
 
-#: common.opt:2082
+#: common.opt:2085
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "Programa yığıt sınama kodu yerleştirilir"
 
-#: common.opt:2086
+#: common.opt:2089
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "Programa yığıt sınama kodu yerleştirilir"
 
-#: common.opt:2093
+#: common.opt:2096
 #, fuzzy
 #| msgid "Trap if the stack goes past <register>"
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr "Yığıt <yazmaç> geçmişine giderse yakalanır"
 
-#: common.opt:2097
+#: common.opt:2100
 #, fuzzy
 #| msgid "Trap if the stack goes past symbol <name>"
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr "Yığıt <isim> simgesinin geçmişine giderse yakalanır"
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr "Yığıt koruma yöntemi olarak propolice kullanılır"
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: common.opt:2109
+#: common.opt:2112
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions"
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: common.opt:2113
+#: common.opt:2116
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: common.opt:2117
+#: common.opt:2120
 #, fuzzy
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output stack usage information on a per-function basis"
 msgstr "Her işlev için r30 yeniden kullanılır"
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr "Sıkı takma ad kuralları uygulanacağı varsayılır"
 
-#: common.opt:2133
+#: common.opt:2136
 #, fuzzy
 #| msgid "Treat missing header files as generated files"
 msgid "Treat signed overflow as undefined"
 msgstr "Kayıp başlık dosyaları üretilen dosyalar olarak ele alınır"
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr "Sözdizimi denetimi yaptıktan sonra durur"
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr "\"gcov\" için gereken veri dosyaları oluşturulur"
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr "Atlama evreleme eniyilemesi uygulanır"
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr "Her derleme aşaması için harcanan zaman raporlanır"
 
-#: common.opt:2157
+#: common.opt:2160
 #, fuzzy
 #| msgid "Set the default thread-local storage code generation model"
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr "Öntanımlı yerel-evreli saklama kodu üretim modeli belirtilir"
 
-#: common.opt:2160
+#: common.opt:2163
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown TLS model %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr "Kuyruk tekrarı üzerinden süper blok oluşumu uygulanır"
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr "Kayan nokta işlemlerinin yakalanabileceği varsayılır"
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr "Toplama, çıkartma, çarpmada signed taşması için kapan kurulur"
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr "Ağaçlarda SSA-CCP eniyilemesi etkinleştirilir"
 
-#: common.opt:2199
+#: common.opt:2202
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr "Ağaçlarda SSA-CCP eniyilemesi etkinleştirilir"
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr "Ağaçlarda döngü başlığı kopyalaması etkin olur"
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr ""
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr "SSA geçicilerini kopyalarda daha iyi isimlerle değiştirir"
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr "Ağaçlarda kopyalama girişimi etkinleştirilir"
 
-#: common.opt:2231
+#: common.opt:2234
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Transform condition stores into unconditional ones"
 msgstr "Koşullu çalıştırmaya koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:2235
+#: common.opt:2238
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversions of switch initializations."
 msgstr "Koşullu çalıştırmaya koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr "Ağaçlarda SSA ölü kod eleme eniyilemesi etkin olur"
 
-#: common.opt:2243
+#: common.opt:2246
 msgid "Enable dominator optimizations"
 msgstr "Baskınlık eniyilemeleri etkin olur"
 
-#: common.opt:2247
+#: common.opt:2250
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable tail merging on trees"
 msgstr "Ağaçlarda döngü başlığı kopyalaması etkin olur"
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr "Ölü saklama elemesi etkin olur"
 
-#: common.opt:2255
+#: common.opt:2258
 #, fuzzy
 #| msgid "Enable copy propagation on trees"
 msgid "Enable forward propagation on trees"
 msgstr "Ağaçlarda kopyalama girişimi etkinleştirilir"
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr "Ağaçlarda Tam Artıklık Elemesi (TAE) etkin olur"
 
-#: common.opt:2263
+#: common.opt:2266
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable string length optimizations on trees"
 msgstr "Ağaçlarda SSA-CCP eniyilemesi etkinleştirilir"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop distribution on trees"
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr ""
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr "Ağaçlarda döngü içinde değişmez hareket etkin olur"
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr ""
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr "Döngülerde meşru tümevarım değişkenleri oluşturulur"
 
-#: common.opt:2300
+#: common.opt:2303
 msgid "Enable loop optimizations on tree level"
 msgstr "Ağaç seviyesinde döngü eniyilemeleri etkinleştirilir"
 
-#: common.opt:2304
+#: common.opt:2307
 #, fuzzy
 #| msgid "Enable automatic template instantiation"
 msgid "Enable automatic parallelization of loops"
 msgstr "Özdevinimli şablon örneklenimi etkin olur"
 
-#: common.opt:2308
+#: common.opt:2311
 #, fuzzy
 #| msgid "Enable conditional moves"
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Koşullu taşımalar etkin olur"
 
-#: common.opt:2312
+#: common.opt:2315
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "Ağaçlarda SSA-PRE eniyilemesi etkinleştirilir"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2324
+#: common.opt:2327
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable reassociation on tree level"
 msgstr "Ağaç seviyesinde döngü eniyilemeleri etkinleştirilir"
 
-#: common.opt:2332
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
 msgstr "Ağaçlarda SSA kod soğurumu etkinleştirilir"
 
-#: common.opt:2336
+#: common.opt:2339
 #, fuzzy
 #| msgid "Perform strength reduction optimizations"
 msgid "Perform straight-line strength reduction"
 msgstr "Güç azaltma eniyilemesi uygulanır"
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr "Ortak değerlerde sabit yer değiştirmesi yapılır"
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr "Geçici ifadeler SSA->normal geçişine yerleştirilir"
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr "SSA->normal aşamasında canlı aralık ayırması yapılır"
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr "Ağaçlarda Değer Aralığı Girişimi uygulanır"
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr "Derleme biriminin tamamı bir defada derlenir"
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr "Yineleme sayısı bilindiğinde döngü tersine uygulanır"
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr "Tüm döngüler tersine uygulanır"
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr "Döngülerin normal davrandığı kabulüyle döngü eniyilemelerine izin verilir"
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr "IEEE veya ISO standartlarını bozabilen matematiksel eniyilemelere izin verilir"
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr "Döngü anahtarlamaması uygulanır"
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr "Olağandışılıkların yakalanması için birbirlerini etkilemeyenlerin tablosu oluşturulur"
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr "Değişken izleme uygulanır"
 
-#: common.opt:2424
+#: common.opt:2427
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments"
 msgstr "Değişken izleme uygulanır"
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr ""
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr ""
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees"
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2454
+#: common.opt:2457
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2458
+#: common.opt:2461
 msgid "Specifies the cost model for vectorization"
 msgstr ""
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:2478
+#: common.opt:2481
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2485
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2493
 #, fuzzy
 #| msgid "Enable copy propagation for stores and loads"
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Saklama ve yüklemelerde kopyalama girişimi etkinleştirilir"
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr "Çevirici çıktısına fazladan açıklama ekler"
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr ""
 
-#: common.opt:2507
+#: common.opt:2510
 #, fuzzy, c-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "visibility değeri \"%s\" tanınmıyor"
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(%qs için near ilklendirme)"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr "Eniyilemelerde ifade değeri ayrımlaması kullanılır"
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr "Izgara oluşturur ve tek bir değişkenin ilgisiz kullanımlarını ayırır"
 
-#: common.opt:2555
+#: common.opt:2558
 #, fuzzy
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr "Ağaçlarda SSA ölü kod eleme eniyilemesi etkin olur"
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr "Bütün yazılım eniyilemeleri uygulanır"
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr "İşaretli aritmetik taşmaların olurunun bulunduğu varsayılır"
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr "bss bölümüne sıfır ilklendirmeli veri yerleştirilir"
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr "COFF biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2579
+#: common.opt:2582
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format"
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:2583
+#: common.opt:2586
 #, fuzzy
 #| msgid "Generate debug information in DWARF v2 format"
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr "DWARF v2 biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr "Öntanımlı gelişmiş biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2614
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Don't generate debug information in separate .dwo files"
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:2615
+#: common.opt:2618
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files"
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr "STABS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr "Gelişmiş STABS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2638
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation"
 msgstr "VMS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr "VMS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr "XCOFF biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr "Gelişmiş XCOFF biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2665
+#: common.opt:2668
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections"
 msgstr "isel komutları üretilir"
 
-#: common.opt:2669
+#: common.opt:2672
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:2676
+#: common.opt:2679
 #, fuzzy
 #| msgid "Set <dir> to be the system root directory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr "<dizin> sistemin kök dizini olur"
 
-#: common.opt:2680
+#: common.opt:2683
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr ""
 
-#: common.opt:2702
+#: common.opt:2705
 #, fuzzy
 #| msgid "Place output into <file>"
 msgid "-o <file>\tPlace output into <file>"
 msgstr "Çıktı <dosya>ya yazılır"
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr "İşlev ayrımlama etkinleştirilir"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr "-pedantic gibidir ancak uyarılar hata olarak ele alınır"
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr "Derlenen işlevler ve geçen zaman gösterilmez"
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr "Ayrıntılı çıktı verilir"
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr "Derleyici sürümünü gösterir."
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "Uyarılar engellenir"
 
-#: common.opt:2806
+#: common.opt:2809
 #, fuzzy
 #| msgid "Enable ID based shared library"
 msgid "Create a shared library"
 msgstr "ID tabanlı paylaşımlı kütüphane etkin olur"
 
-#: common.opt:2851
+#: common.opt:2854
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Create a position independent executable"
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "hesaplanan değer kullanılmadı"
@@ -16137,299 +16147,299 @@
 msgid "expected integer or boolean type"
 msgstr "Tamsayı dizgesi umuluyordu"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 #, fuzzy
 #| msgid "comparison of promoted ~unsigned with unsigned"
 msgid "invalid comparison of nil with nil"
 msgstr "unsigned ile ~unsigned'a yükseltgenmiş türlerin karşılaştırması"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 #, fuzzy
 #| msgid "incompatible types in return"
 msgid "incompatible types in binary expression"
 msgstr "dönüş değerinde uyumsuz türler"
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 #| msgid "division by zero"
 msgid "integer division by zero"
 msgstr "sıfırla bölme"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 #, fuzzy
 #| msgid "size of array %qs has non-integer type"
 msgid "shift of non-integer operand"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 #, fuzzy
 #| msgid "switch quantity not an integer"
 msgid "shift count not unsigned integer"
 msgstr "switch miktarı bir tamsayı değil"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 #, fuzzy
 #| msgid "negative insn length"
 msgid "negative shift count"
 msgstr "negatif komut uzunluğu"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 #, fuzzy
 #| msgid "called object %qE is not a function"
 msgid "object is not a method"
 msgstr "çağrılan nesne %qE bir işlev değil"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 #, fuzzy
 #| msgid "argument of type %qT does not match %qT"
 msgid "method type does not match object type"
 msgstr "%qT türündeki argüman %qT ile eşleşmiyor"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 #, fuzzy
 #| msgid "invalid argument to builtin function"
 msgid "invalid use of %<...%> with builtin function"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 #, fuzzy
 #| msgid "invalid use of template-name %qE without an argument list"
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "bir argüman listesi olmaksızın %qE şablon isminin kullanımı geçersiz"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 #, fuzzy
 #| msgid "no arguments"
 msgid "not enough arguments"
 msgstr "argüman yok"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 #, fuzzy
 #| msgid "too many arguments for format"
 msgid "too many arguments"
 msgstr "biçim için argüman sayısı çok fazla"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 #, fuzzy
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be a map"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "invalid type for make function"
 msgstr "tür argümanı geçersiz"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 #, fuzzy
 #| msgid "too many arguments for format"
 msgid "too many arguments to make"
 msgstr "biçim için argüman sayısı çok fazla"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 #, fuzzy
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument must be array or slice or channel"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 #, fuzzy
 #| msgid "invalid argument to builtin function"
 msgid "unsupported argument type to builtin function"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 #, fuzzy
 #| msgid "Argument dim at %L must be scalar"
 msgid "argument must be channel"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 #, fuzzy
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument must be a field reference"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 #, fuzzy
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "left argument must be a slice"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 #, fuzzy
 #| msgid "first argument of %q+D should be %<int%>"
 msgid "first argument must be []byte"
 msgstr "%q+D için ilk argüman %<int%> olmalıydı"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 #, fuzzy
 #| msgid "tls_model argument not a string"
 msgid "second argument must be slice or string"
 msgstr "tls_model argümanı bir dizge değil"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 #, fuzzy
 #| msgid "%Jparameter %u has void type"
 msgid "argument 2 has invalid type"
 msgstr "%J%u. parametre void türde"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 #, fuzzy
 #| msgid "%Jparameter %u has incomplete type"
 msgid "argument must have complex type"
 msgstr "%J%u. parametre tamamlanmamış türde"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 #, fuzzy
 #| msgid "cleanup argument not an identifier"
 msgid "complex arguments must have identical types"
 msgstr "cleanup argümanı bir betimleyici değil"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 #, fuzzy
 #| msgid "Do not use hardware floating point"
 msgid "complex arguments must have floating-point type"
 msgstr "Donanım kayan nokta aritmetiği kullanılmaz"
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 #, fuzzy
 #| msgid "unexpected node"
 msgid "expected function"
 msgstr "umulmadık düğüm"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 msgid "multiple-value argument in single-value context"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 #, fuzzy
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<...%> with non-slice"
 msgstr "tepe seviyede %<this%> kullanımı geçersiz"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 #, fuzzy
 #| msgid "Function return value not set"
 msgid "function result count mismatch"
 msgstr "İşlevin dönüş değeri belirtilmemiş"
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 #, fuzzy
 #| msgid "incompatible types in return"
 msgid "incompatible type for receiver"
 msgstr "dönüş değerinde uyumsuz türler"
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 #, fuzzy
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 #, fuzzy
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "number of results does not match number of values"
 msgstr "gelen ayrıt sayısı PHI argüman sayısı ile uyuşmuyor"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 #, fuzzy
 #| msgid "Cray pointer at %C must be an integer."
 msgid "index must be integer"
 msgstr "%C'deki Cray göstericisi bir tamsayı olmalı."
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 #, fuzzy
 #| msgid "Cray pointer at %C must be an integer."
 msgid "slice end must be integer"
 msgstr "%C'deki Cray göstericisi bir tamsayı olmalı."
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 #| msgid "switch quantity not an integer"
 msgid "slice capacity must be integer"
 msgstr "switch miktarı bir tamsayı değil"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 #, fuzzy
 #| msgid "incompatible types in assignment"
 msgid "incompatible type for map index"
 msgstr "atamada uyumsuz türler"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 #, fuzzy
 #| msgid "too many arguments for format"
 msgid "too many expressions for struct"
 msgstr "biçim için argüman sayısı çok fazla"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 #, fuzzy
 #| msgid "too few arguments for format"
 msgid "too few expressions for struct"
 msgstr "biçim için argüman sayısı yetersiz"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 msgid "type assertion only valid for interface types"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 #, fuzzy
 #| msgid "expected class name"
 msgid "expected channel"
 msgstr "sınıf ismi umuluyordu"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -16569,81 +16579,81 @@
 msgid "cannot use type %s as type %s"
 msgstr "%qT türü %qT türüne dönüştürülemiyor"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 #, fuzzy
 #| msgid "invalid receiver type %qs"
 msgid "different receiver types"
 msgstr "alıcı tür %qs geçersiz"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "different number of parameters"
 msgstr "%q+D parametresinin yeniden tanımlanması"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 #, fuzzy
 #| msgid "invalid parameter type %qT"
 msgid "different parameter types"
 msgstr "geçersiz parametre türü %qT"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 #, fuzzy
 #| msgid "error while parsing methods"
 msgid "type has no methods"
 msgstr "yöntemler çözümlenirken hata"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, fuzzy, c-format
 #| msgid "ambiguous abbreviation %s"
 msgid "ambiguous method %s%s%s"
 msgstr "belirsiz kısaltma %s"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, fuzzy, c-format
 #| msgid "missing argument to \"%s\""
 msgid "missing method %s%s%s"
 msgstr "\"%s\" için argüman eksik"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -16774,7 +16784,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "%<__builtin_prefetch%> için 3. argüman geçersiz; sıfır kullanılıyor"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "%<va_start%> işlevine çok az argüman verilmiş"
@@ -16970,12 +16980,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "işlev çağrısı küme değeri içeriyor"
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "Pass arguments on the stack"
 msgid "passing too large argument on stack"
@@ -17569,250 +17579,255 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "komut zinciri (%d) içindeki bb notlarının sayısı != n_basic_blocks (%d)"
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr "çağrıcı ayrıt sayısı negatif"
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge frequency is negative"
 msgstr "çağrıcı ayrıt sayısı negatif"
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge frequency is too large"
 msgstr "çağrıcı ayrıt sayısı negatif"
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "ayrıt %s->%s için yardımcı alan belirtilmiş"
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, fuzzy, gcc-internal-format
 #| msgid "Execution count is negative"
 msgid "execution count is negative"
 msgstr "Çalıştırma sayısı negatif"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Tüm simgelerin geçersiz olabileceği varsayılır"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "aux field set for edge %s->%s"
 msgid "aux field set for indirect edge from %s"
 msgstr "ayrıt %s->%s için yardımcı alan belirtilmiş"
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to göstericisi yanlış"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "çok sayıda satıriçi çağrısı"
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "Inlined_to göstericisi satıriçi olmayan çağrıcılar için belirtilmiş"
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, fuzzy, gcc-internal-format
 #| msgid "inlined_to pointer is set but no predecesors found"
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "inlined_to göstericisi var ama bir öncül yok"
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "Inlined_to göstericisi kendini gösteriyor"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "paylaşımlı call_stmt:"
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "yanlış bildirimin köşeleri:"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "çağrı deyimi için çağrı çizgesi ayrıtı eksik"
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "deyim umuluyordu"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "ayrıt %s->%s için karşılığı olan çağrı deyimi yok"
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "edge %s->%s has no corresponding call_stmt"
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "ayrıt %s->%s için karşılığı olan çağrı deyimi yok"
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node başarısız"
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to '-%s' is missing"
 msgid "%s: section %s is missing"
@@ -17958,7 +17973,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
@@ -18213,17 +18228,17 @@
 msgid "          %s"
 msgstr "        %qD"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr ""
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "bu hedefte global yıkıcılar desteklenmiyor"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "bu hedefte global yapıcılar desteklenmiyor"
@@ -18270,12 +18285,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -18483,7 +18498,7 @@
 msgid "total size of local objects too large"
 msgstr "%Jyerel nesnelerin toplam boyutu çok büyük"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%> içindeki kısıt imnkansız"
@@ -18982,9 +18997,9 @@
 msgstr "PCH dosyasına yazılamıyor"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
@@ -19000,165 +19015,159 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$qs sınıfı umuluyordu, %5$s dosyasının %6$d. satırında %4$s işlevinde %2$qs (%3$s) var"
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "using result of function returning %<void%>"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "asm çıktısı %d içinde geçersiz sol değer"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "bellek girdisi %d doğrudan adreslenebilir değil"
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr ""
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should be private"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "iteration variable %qE should not be reduction"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should not be private"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "yerel değişken %qD bu kapsamda görünemez"
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "%s variable %qE is private in outer context"
 msgstr "yerel değişken %qD bu kapsamda görünemez"
 
-#: gimplify.c:7001
-#, fuzzy, gcc-internal-format
-#| msgid "local variable %qD may not appear in this context"
-msgid "lastprivate variable %qE is private in outer context"
-msgstr "yerel değişken %qD bu kapsamda görünemez"
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, gcc-internal-format
 msgid "directive not yet implemented"
 msgstr ""
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimpleme başarısız"
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "%<va_arg%>'ın ilk argümanının türü %<va_list%> değil"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT %<...%> üzerinden aktarılırken %qT'ye yükseltgenir"
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(bu durumda %<va_arg%>'a %qT değil %qT akarılmalı)"
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "Bu kodun bitiminde uygulama çıkacak"
@@ -19590,49 +19599,49 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot find LTO cgraph in %s"
 msgstr "sınıf %qs bulunamıyor"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find protocol declaration for %qs"
 msgid "cannot find LTO section refs in %s"
 msgstr "%qs için protokol bildirimi bulunamıyor"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -19719,51 +19728,51 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "girdi dosyası yok"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 #| msgid "%s:error writing output file '%s'\n"
 msgid "writing output file"
 msgstr "%s: çıktı dosyası '%s' yazılırken hata.\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "ortam değişkeni DJGPP atanmamış"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "ortam değişkeni DJGPP atanmamış"
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen: %s: %m"
@@ -19902,13 +19911,13 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid exit from %s structured block"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid entry to %s structured block"
@@ -19915,18 +19924,18 @@
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "ignoring large linear step"
 msgstr "tekrar belirtilen \"%s\" dizini yok sayılıyor\n"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -20485,8 +20494,8 @@
 msgstr "'%s' bir %s yazmacı olarak kullanılamıyor"
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "bilinmeyen yazmaç ismi: %s"
@@ -20945,7 +20954,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld çıkış durumu %d ile döndü"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F işlevi tanımlanmadan kullanılmış"
@@ -22024,42 +22033,42 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr ""
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -22459,52 +22468,52 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript is outside array bounds"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript is above array bounds"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript is below array bounds"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr ""
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr ""
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, fuzzy, gcc-internal-format
 #| msgid "comparison is always false due to limited range of data type"
 msgid "comparison always false due to limited range of data type"
 msgstr "veri türünün aralığı sınırlı olduğundan karşılaştırma sonucu daima yanlıştır"
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, fuzzy, gcc-internal-format
 #| msgid "comparison is always true due to limited range of data type"
 msgid "comparison always true due to limited range of data type"
 msgstr "veri türünün aralığı sınırlı olduğundan karşılaştırma sonucu daima doğrudur"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr ""
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr ""
@@ -22549,9 +22558,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -22795,7 +22804,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "%q+D için istenen hizalama gerçeklenmiş hizalama %wu'den daha büyük"
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D nin saklama uzunluğu bilinmiyor"
@@ -22955,27 +22964,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "dizge uzunluğu %1$qd ISO C%3$d derleyicilerin desteklemesi gereken uzunluk %2$qd den büyük"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "sola kaydırma sayısı negatif"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "sağa kaydırma sayısı negatif"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "sola kaydırma sayısı tür genişliğinden büyük ya da eşit"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "sağa kaydırma sayısı tür genişliğinden büyük ya da eşit"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "sabit ifadesinde taşma"
@@ -23319,12 +23328,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "atamayı sarmalayan parantezler muhtemelen doğruluk değeri olarak kullanılmış"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "%<restrict%> kullanımı geçersiz"
@@ -23816,12 +23825,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "vektör boyutu bileşen boyutunun katlarından biri değil"
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "vektör boyutu sıfır"
@@ -23831,22 +23840,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr "vektör elemanlarının sayısı ikinin üstel katlarından biri değil"
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "bir prototip olmayanda argümansız null olmayan öznitelik"
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "null olmayan argüman geçersiz sayıda terim içeriyor (%lu. argüman)"
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "null olmayan argüman aralığın dışında sayıda terim içeriyor (%lu. argüman, %lu terim)"
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "null olmayan argüman gösterici olmayan terime başvuruyor (%lu. argüman, %lu. terim)"
@@ -23886,12 +23895,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "%qE özniteliği sadece değişkin işlevlere uygulanır"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "istenen konum bir tamsayı sabit değil"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "istenen konum sıfırdan küçük"
@@ -23979,7 +23988,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "bit-alanı yapısının %qD üyesinin adresi alınmaya çalışılıyor"
@@ -24450,7 +24459,7 @@
 msgstr "%L'deki altdizge son indisi sınırların dışında"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -24921,7 +24930,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid type for iteration variable %qE"
@@ -24933,24 +24942,24 @@
 msgid "%qE is not initialized"
 msgstr "ilklendirici yok"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid controlling predicate"
 msgstr "koşullu terim geçersiz"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "missing increment expression"
 msgstr "atama engelleme"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, fuzzy, gcc-internal-format
 #| msgid "invalid truth-value expression"
 msgid "invalid increment expression"
@@ -25521,6 +25530,12 @@
 msgid "too many input files"
 msgstr "girdi dosyası sayısı çok fazla"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+#| msgid "stack frame too large"
+msgid "-mcpu string too large"
+msgstr "yığıt çerçevesi çok büyük"
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -25548,49 +25563,49 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops artık kullanılmıyor yerine -falign-loops kullanın"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malıgn-loops=%d, 0 ile %d arasında değil"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malıgn-jumps artık atıl, yerine -falign-jumps kullanın"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malıgn-loops=%d, 0 ile %d arasında değil"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions artık atıl, yerine -falign-functions kullanın"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malıgn-loops=%d, 0 ile %d arasında değil"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d, 0 ile 5 arasında değil"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -26000,64 +26015,64 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr ""
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "-mtrap-precision seçeneği için %qs değeri hatalı"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "-mfp-rounding-mode seçeneği için %qs değeri hatalı"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "-mfp-trap-mode seçeneği için %qs değeri hatalı"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr "-mcpu seçeneği için değer %qs  hatalı"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for -mtune switch"
 msgstr "-mtune= seçeneğinin değeri (%s) hatalı"
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr "fp yazılım tamamlaması -mtrap-precision=i gerektirir"
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "VAX gerçelleri için yuvarlama kipi desteklenmiyor"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "VAX gerçelleri için tuzak kipi desteklenmiyor"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr "VAX gerçek sayılarında 128 bitlik long double desteklenmiyor"
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr "%2$s için L%1$d arabellek gecikmesi bilinmiyor"
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr "-mmemory-latency için değer %qs hatalı"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -26549,14 +26564,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
@@ -27253,411 +27268,428 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "PCH dosyası içinde konum belirlenemiyor: %m"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "error in args to spec function '%s'"
 msgid "wrong arg %s to option %s"
 msgstr "'%s' spec işlevi için argümanlar hatalı"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "%q+D için yazmaç ismi belirtilmemiş"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
+#, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386.c:3012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %s specified for option %s"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %s"
 msgstr "%qs ile belirtilmiş sınıf ismi yok"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr ""
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i bitlik kip bunun içinde derlenmiş değil:"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "Seçtiginiz işlemci  x86-64 komutlarını desteklemiyor."
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s %s desteği vermiyor"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "-march= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "-mtune= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d, 0 ile %d arasında değil"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "bu hedefte -fprefetch-loop-arrays desteklenmiyor"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr "-msseregparm SSE etkin değilken kullanılmış"
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE komut kümesi iptal edildi, 387 aritmetiği kullanılıyor"
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 komut kümesi iptal edildi, SSE aritmetiği kullanılıyor"
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for -mrecip=%s"
 msgstr "bilinmeyen -m%s= seçeneği belirtilmiş: '%s'"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "alias argümanı bir dizge değil"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ACCESS specification at %L was already specified"
 msgid "option(\"%s\") was already specified"
 msgstr "ACCESS belirtimi %L'de zaten belirtilmiş"
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall ve regparm öznitelikleri uyumlu değil"
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qD çağrısı"
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qT çağrısı"
 
-#: config/i386/i386.c:5923
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
-#| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qD çağrısı"
-
-#: config/i386/i386.c:6210
-#, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "multilib desteklenmiyor"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE etkin değilken SSE vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE etkin değilken SSE vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE etkin değilken SSE yazmaç dönüşü"
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE etkin değilken SSE yazmaç argümanı"
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, fuzzy, gcc-internal-format
 #| msgid "SSE register return with SSE disabled"
 msgid "x87 register return with x87 disabled"
 msgstr "SSE etkin değilken SSE yazmaç dönüşü"
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, fuzzy, gcc-internal-format
+#| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qD çağrısı"
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
+#, fuzzy, gcc-internal-format
+#| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qD çağrısı"
+
+#: config/i386/i386.c:11378
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -27664,284 +27696,284 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "ek yazmaçların yüksek yarıları yok"
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ek yazmaç için desteklenmeyen terim boyutu"
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %D"
 msgstr "%q+D bildiriminin önceki bildirimi"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "-ffpe-trap seçeneğinin argümanı geçersiz: %s"
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "shift bir anlık değer olmalı"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%> için 3. argüman bir sabit olmalı"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "yanlış komut:"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "Ağaç düğümlerinin paylaşımı yanlış"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "mask bir anlık değer olmalı"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "yanlış komut:"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs uyumsuz özniteliği yoksayıldı"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -28043,13 +28075,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr "-mfixed-range için değer YAZMAC1-YAZMAC2 şeklinde olmalı"
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -28125,7 +28157,7 @@
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%qE attribute argument not an integer constant"
@@ -28194,7 +28226,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
@@ -29115,16 +29147,11 @@
 msgid "-g option disabled"
 msgstr "-g seçeneği iptal edildi"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "hizalama (%u) %s için genel ortak veri azami hizalamasını aşıyor.  %u kullanılıyor"
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr "-munix=98 seçeneği C89'un 1. Düzeltmesindeki özellikler için gerekli.\n"
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, fuzzy, gcc-internal-format
@@ -29399,335 +29426,340 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektörü başvurusu tarafından döndürüldü: bir uyumluluk garanti etmeksizin standartdışı ABI eklentisi"
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmaçındaki değer döndürülemez, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmacındaki argüman aktarılamaz, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektörü başvurusu tarafından aktarıldı: bir uyumluluk garanti etmeksizin standartdışı ABI eklentisi"
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %s already processed"
 msgstr "Girdi dosyaları evvelce önişlemden geçirilmiş kabul edilir"
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "__builtin_altivec_predicate'in 1. argümanı bir sabit olmalı"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "__builtin_altivec_predicate'in 1. argümanı aralık dışında"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
+#, gcc-internal-format, gfc-internal-format
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate'in 1. argümanı aralık dışında"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range 0..15"
 msgstr "%L'deki ATANH argümanı -1 .. 1 aralığının içinde kalmalı"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "Altivec yerleşiği %qF için çözümlenmemiş aşırı yükleme"
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "dss argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "__builtin_spe_predicate'in 1. argümanı bir sabit olmalı"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "__builtin_spe_predicate'in 1. argümanı aralık dışında"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "__builtin_spe_predicate'in 1. argümanı bir sabit olmalı"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "__builtin_spe_predicate'in 1. argümanı aralık dışında"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "bu yerleşik işlev sadece fr450 üzerinde kullanılabilir"
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mspe option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "Builtin function %s is not supported with the current options"
 msgstr "komut satırı seçeneği %qs bu yapılandırmada desteklenmiyor"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "internal error: sideeffect-insn affecting main effect"
 msgid "internal error: builtin function %s had no type"
 msgstr "iç hata: yan etkili komut main etkisi oluşturuyor"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "yığıt çerçevesi çok büyük"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "bu ABI için 64 bitlik profilleme kodu yok"
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<long double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<complex%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, fuzzy, gcc-internal-format
 #| msgid "use of boolean types in AltiVec types is invalid"
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "AltiVec türlerde %<long%> kullanımı 64 bitlik kod için geçersiz"
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec türlerde %<long%> kullanımı önerilmiyor; %<int%> kullanın"
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "AltiVec türlerde %<long long%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "AltiVec türlerde %<double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s\"%s\"%s is invalid"
@@ -29986,92 +30018,92 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Yerel değişkenlerin toplam boyutu mimarinin izin verdigi sınırı aşıyor"
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "%qs çerçevi boyutu "
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs özdevimli yığıt tahsisi kullanıyor"
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "\"%s\" için argüman sıfır ya da pozitif bir tamsayı olmalı"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/Architecture kipi %s üzerinde desteklenmiyor"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "ESA/390 kipinde 64 bitlik ABI desteklenmiyor."
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Donanım kayan nokta komutlarının kullanımını 32 bitlik işlemlerle sınırlar"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float bir arada desteklenmiyor"
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "yığıt boyutunun yığıt koruma değerinden büyük olması gerekir"
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "yığıt boyutu 64k'dan büyük olmamalıdır"
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard, -mstack-size uyguluyor"
@@ -30086,35 +30118,35 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "__builtin_saveregs bu alt hedef tarafından desteklenmiyor"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to interrupt functions"
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "%qs özniteliği sadece kesme işlevlerine uygulanır"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "%qE attribute is supported only for SH2A"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr "kesme yakalayıcı özniteliği -m5-compact ile uyumlu değil"
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "%qE attribute only applies to SH2A"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%qE attribute argument should be between 0 to 255"
@@ -30121,24 +30153,24 @@
 msgstr "%qs öznitelik argümanı bir tamsayı sabit değil"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "%qE attribute argument not a string constant"
 msgstr "%qs öznitelik argümanı bir dizge sabit değil"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr "r0 bir çağrı taşırmalı yazmaç olarak kullanılabilmeyi gerektirir"
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, fuzzy, gcc-internal-format
 #| msgid "Need a second call-clobbered general purpose register"
 msgid "need a second call-clobbered general purpose register"
 msgstr "İkinci bir çağrı taşırmalı genel amaçlı yazmaç gerekir"
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, fuzzy, gcc-internal-format
 #| msgid "Need a call-clobbered target register"
 msgid "need a call-clobbered target register"
@@ -30543,49 +30575,49 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid element type for attribute %qs"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "vektör elemanlarının sayısı ikinin üstel katlarından biri değil"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "%qs özniteliği yoksayıldı"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "%qE özniteliği isimli argümanları olan prototipler gerektirir"
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variadic functions"
 msgid "%qs attribute only applies to variadic functions"
 msgstr "%qE özniteliği sadece değişkin işlevlere uygulanır"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "%qE attribute has no effect"
 msgstr "%qE özniteliği yoksayıldı"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "attribute %qs applies to array types only"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
@@ -30649,7 +30681,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void değer yoksayılması gerekirken yoksayılmadı"
@@ -30679,65 +30711,65 @@
 msgid "GCC supports only %u nested scopes"
 msgstr "GCC iç içe sadece %u etki alanını destekler"
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "%q+D yaftası tanımlanmadan kullanılmış"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "iç işlev %q+D tanımlanmadan bildirilmiş"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %q+D declared but never defined"
 msgid "inline function %q+D declared but never defined"
 msgstr "iç işlev %q+D tanımlanmadan bildirilmiş"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "%q+D değişkeni kullanılmamış"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "variable %qD set but not used"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "%q+D dizisinin türü örtük ilklendirme ile uyumsuz olarak tamamlanmış"
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "originally defined here"
 msgstr "%J  ozgun tanımı burada görüldü"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr "Üç nokta imli bir parametre listesi bir boş parametre isim listesi bildirimi ile eşleşemez"
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr "Bir öntanımlı yükseltme içeren bir argüman türü, bir boş parametre isim listesi bildirimi ile eşleşemez"
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "%q+D prototipi önceki eski tarz tanımdan daha fazla argüman bildiriyor"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "%q+D prototipi önceki eski tarz tanımdan daha az argüman bildiriyor"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr "%q+D prototipi %d. argümanı uyumsuz türde bildiriyor"
@@ -30744,42 +30776,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "%q+D prototipinden sonraki tanım bir prototip değil"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "%q+D'nin önceki tanımı buradaydı"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "%qD'nin önceki örtük bildirimi buradaydı"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "%qD'nin önceki bildirimi buradaydı"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "%q+D farklı bir simge çeşidi olarak tekrar bildirilmiş"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "%q+D bildirimi bir yerleşik işlevi gölgeliyor"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "enumerator %q+D yeniden bildirilmiş"
@@ -30787,158 +30819,158 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "yerleşik işlev %q+D için tür çelişkisi"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "%q+D için çelişen türler"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting return type specified for %q+#D"
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr "%q+#D için belirtilen dönüş türü çelişiyor"
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting types for %q+D"
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr "%q+D için çelişen türler"
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "%q+D için çelişen tür niteleyiciler"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D"
 msgid "redefinition of typedef %q+D with different type"
 msgstr "typedef %q+D için yeniden tanımlama"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, fuzzy, gcc-internal-format
 #| msgid "jump into scope of identifier with variably modified type"
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "değişkene göre değişen türde betimleyici etki alanına jump"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "typedef %q+D için yeniden tanımlama"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "%q+D için yeniden tanımlama"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "%q+D statik bildirimi statik olmayan bildirimi izliyor"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "%q+D statik olmayan bildirim statik bildirimi izliyor"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr ""
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, fuzzy, gcc-internal-format
 #| msgid "  from here"
 msgid "but not here"
 msgstr "  buradan"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "%q+D'nin yerel-evreli bildirimi yerel-olmayan-evreli bildirimi izliyor"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "%q+D'nin yerel-olmayan-evreli bildirimi yerel-evreli bildirimi izliyor"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "%q+D extern bildirimi ilintisiz bildirimi izliyor"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "ilintisiz %qD bildirimi extern bildirimini izliyor"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "ilintisiz %q+D yeniden bildirimi"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr "%q+D için farklı görünürlükle yeniden bildirim (eski görünürlük saklı)"
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "%qD satıriçi bildirimi satıriçi öznitelikli olmayan bildirimi izliyor"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "%qD satıriçi öznitelikli olmayan bildirimi satıriçi bildirimi izliyor"
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "%qD satıriçi öznitelikli olmayan bildirimi satıriçi bildirimi izliyor"
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "%q+D parametresinin yeniden tanımlanması"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "%q+D'nin gereksiz yeniden bildirimi"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "%qD bildirimi bir önceki değişken olmayan bildirimi gölgeliyor"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "%q+D bildirimi önceki yerel bildirimi gölgeliyor"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
@@ -30945,73 +30977,73 @@
 msgid "shadowed declaration is here"
 msgstr "%Jgölgeli bildirim burada"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "%qD için iç içe 'extern' bildirimi"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "%qE işlevinin örtük bildirimi"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "%qD yerleşik işlevinin uyumsuz örtük bildirimi"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "yeniden %q+D bildirimi geçersiz"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "%qD işlevinin uyumsuz örtük bildirimi"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function)"
 msgstr "%H%qE burada bildirilmemiş (bir işlev içinde değil)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function)"
 msgstr "%H%qE bildirilmemiş (bu işlevde ilk kullanımı)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, fuzzy, gcc-internal-format
 #| msgid "%H(Each undeclared identifier is reported only once"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H(Bildirilmemiş her betimleyici görüldüğü her işlev"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "%qE yaftası işlev dışına başvuruyor"
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "değişkene göre değişen türde betimleyici etki alanına jump"
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "jump skips variable initialization"
 msgstr "  %q+#D ilklendirmesi atlanıyor"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "label %qD defined here"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
@@ -31018,130 +31050,130 @@
 msgid "%qD declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "deyim ifadesine jump"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "%qE yaftası bildirimi yinelenmiş"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "yinelenmiş %qD yaftası"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, fuzzy, gcc-internal-format
 #| msgid "%Htraditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "%Hgeleneksel C yaftalar için ayrı bir isim alanından yoksundur, %qE betimleyici çelişiyor"
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in initialization"
 msgid "switch jumps over variable initialization"
 msgstr "ilklendirmede uyumsuz türler"
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, fuzzy, gcc-internal-format
 #| msgid "jump into statement expression"
 msgid "switch jumps into statement expression"
 msgstr "deyim ifadesine jump"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE defined as wrong kind of tag"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%H%qEyanlış etiket çeşidi olarak tanımlı"
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "ilk tanımı olmayan adsız struct/union"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "saklatım sınıfı belirteçli boş bildirim yeniden etiket bildirmez"
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "tür niteleyicili boş bildirim yeniden etiket bildirmez"
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration with type qualifier does not redeclare tag"
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "tür niteleyicili boş bildirim yeniden etiket bildirmez"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "boş bildirimde kullanışsız tür ismi"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "dosya etki alanı boş bildiriminde %<auto%>"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "dosya etki alanı boş bildiriminde %<register%>"
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "boş bildirimde kullanışsız saklatım sınıfı belirteci"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "useless type name in empty declaration"
 msgid "useless %qs in empty declaration"
 msgstr "boş bildirimde kullanışsız tür ismi"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "boş bildirimde kullanışsız tür niteleyici"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 #| msgid "useless %<__thread%> in empty declaration"
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "boş bildirimde kullanışsız %<__thread%>"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "boş bildirim"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90, parametre dizisi bildirimlerinde `%<static%> veya tür niteleyicileri desteklemez"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 %<[*]%> dizi bildirimlerini desteklemez"
@@ -31149,38 +31181,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D çoğu kez bir işlevdir"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "typedef %qD ilklendirilmiş (yerine  __typeof__  kullanın)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "%qD işlevi bir değişken gibi ilklendirilmiş"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "%qD parametresi ilklendirilmiş"
@@ -31189,281 +31221,281 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "değişken uzunluklu nesne ilklendirilemeyebilir"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "%qD değişkeni ilklendiricili ama içi boş türde"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "satıriçi %q+D işlevine satıriçi olmayan öznitelik verilmiş"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "ilklendirilmemiş sabit üyesi %qD"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD should be initialized"
 msgstr "%q+D sonradan ilklendirilmiş olacak"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "ilklendirici %q+D'nin boyutunu saptayamıyor"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "%q+D de dizi boyutu eksik"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "%q+D dizisi sıfır ya da negatif uzunlukta"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "%q+D nin saklama genişligi sabit değil"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "static olmayan yerel değişken %q+D için asm-belirteci yoksayılıyor"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "oynak alanlı nesne yazmaça konulamaz"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "ilklendirilmemiş sabit %qD"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C ileriye dönük parametre bildirimlerine izin vermez"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "%qs bit alanı genişliği bir tamsayı sabit değil"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs width not an integer constant"
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "%qs bit alanı genişliği bir tamsayı sabit değil"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "%qs bit alanının genişliği negatif"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "bit alanı %qs için sıfır genişlik"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "%qs bit alanı türü bir GCC oluşumudur"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "%qs in genişliği türünü aşıyor"
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs genişliği türününkinden daha dar"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 değerlendirilemeyen boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 değerlendirilemeyen boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 değişken boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 değişken boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is a variably modified type"
 msgid "variably modified %qE at file scope"
 msgstr "%qT değişkene göre değişen türde"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is a variably modified type"
 msgid "variably modified field at file scope"
 msgstr "%qT değişkene göre değişen türde"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "%qs bildiriminde tür öntanımlı olarak %<int%>"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in type name"
 msgstr "%qs bildiriminde tür öntanımlı olarak %<int%>"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "%<const%> yinelenmiş"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "%<restrict%> yinelenmiş"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "%<volatile%> yinelenmiş"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "%<restrict%> yinelenmiş"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting super class name %qs"
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "super sınıf ismi %qs çelişiyor"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "%<auto%> bildirimli işlev tanımı"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "%<register%> bildirimli işlev tanımı"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "%<typedef%> bildirimli işlev tanımı"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "%<auto%> bildirimli işlev tanımı"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field %qE"
 msgstr "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field"
 msgstr "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for parameter %qE"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for unnamed parameter"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "veri türü ismi için saklama sınıfı belirtildi"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs ilklendirilmiş ve %<extern%> bildirilmiş"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, fuzzy, gcc-internal-format
 #| msgid "%qs has both %<extern%> and initializer"
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs hem %<extern%> olarak bildirilmiş hem de ilklendrilmiş"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<auto%>"
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "%qs için dosya etki alanı bildirimi %<auto%> belirtiyor"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<register%>"
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "%qs için dosya etki alanı bildirimi %<register%> belirtiyor"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested function %qE declared %<extern%>"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -31472,760 +31504,760 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "parametresiz dizi bildirimi içinde 'static' veya tür niteleyiciler"
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qE as array of voids"
 msgstr "void dizisi olarak %qs bildirimi"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of type name as array of voids"
 msgstr "void dizisi olarak %qs bildirimi"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qE as array of functions"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of type name as array of functions"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "esnek dizi üyeli yapı kullanımı geçersiz"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of array %qE has non-integer type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of unnamed array has non-integer type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids zero-size array %qs"
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C sıfır boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array"
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++'da sıfır boyutlu dizi yasaktır"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE is negative"
 msgstr "%qs dizisinin boyutu negatif"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "dizi boyutu negatif"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array %qE is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of unnamed array is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<[*]%> not in a declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "dizi türü içi boş öğe türü içeriyor"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "%qE declared as function returning a function"
 msgstr "%qs işlevle dönen işlev olarak bildirilmiş"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "type name declared as function returning a function"
 msgstr "%qs işlevle dönen işlev olarak bildirilmiş"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "%qE declared as function returning an array"
 msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "type name declared as function returning an array"
 msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "işlev tanımı nitelikli void dönüş türü içeriyor"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C nitelikli işlev türlerini yasaklar"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C nitelikli işlev türlerini yasaklar"
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting type qualifiers for %q+D"
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%q+D için çelişen tür niteleyiciler"
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, fuzzy, gcc-internal-format
 #| msgid "illegal aggregate type %qs specified for instance variable %qs"
 msgid "%qs specified for auto variable %qE"
 msgstr "kümeleme türü %qs gerçeklenim değişkeni %qs için kuraldışı"
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for parameter %qE"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field %qE"
 msgstr "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field"
 msgstr "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for typedef %qE"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for %<register%> object %qE"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for parameter %qE"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for unnamed parameter"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for bit-field %qE"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 #| msgid "%<__alignof%> applied to a bit-field"
 msgid "alignment specified for unnamed bit-field"
 msgstr "%<__alignof%> bir bit-alanına uygulanmış"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "alignment specified for function %qE"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "%<inline%> bildirimli typedef %q+D"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "%<inline%> bildirimli typedef %q+D"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C 'const' ya da 'volatile' işlev türlerini yasaklar"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type %qT"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "veri üyesi değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "void bildirimli değişken ya da alan %qE"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "parametre dizisi bildirimindeki öznitelikler yoksayıldı"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "field %qE declared as a function"
 msgstr "%qs alanı bir işlev olarak bildirilmiş"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "field %qE has incomplete type"
 msgstr "%qs alanı tamamlanmamış türde"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, fuzzy, gcc-internal-format
 #| msgid "name %qT has incomplete type"
 msgid "unnamed field has incomplete type"
 msgstr "%qT ismi içi boş türde"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "invalid storage class for function %qE"
 msgstr "%qs işlevi için geçersiz saklama sınıfı"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "%<main%> satıriçi işlev olamaz"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs ilklendirilmiş ve %<extern%> bildirilmiş"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "evvelce %<static%> bildirilmiş değişken %<extern%> olarak yeniden bildirilmiş"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "%<inline%> bildirimli %q+D değişkeni"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "%<inline%> bildirimli %q+D değişkeni"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, fuzzy, gcc-internal-format
 #| msgid "jump into scope of identifier with variably modified type"
 msgid "non-nested function with variably modified type"
 msgstr "değişkene göre değişen türde betimleyici etki alanına jump"
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "işlev bildirimi bir prototip değil"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "işlev bildiriminde (türleri belirtmeksizin) parametre isimleri"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "%u. parametre (%q+D) tamamlanmamış türde"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "parameter %u has incomplete type"
 msgstr "%J%u. parametre tamamlanmamış türde"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "%u. parametre (%q+D) void türde"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has void type"
 msgid "parameter %u has void type"
 msgstr "%J%u. parametre void türde"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "tek parametre olarak %<void%> yeterli olmayabilir"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> tek parametre olmalıdır"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "%q+D parametresi tam bir ilerletme bildirimine sahip"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "%<%s %E%> parametre listesinin içinde bildirilmiş"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "anonim %s parametre listesinin içinde bildirilmiş"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "sadece bu tanım ya da bildirim onun etki alanında, sizin istediğiniz bu olmayabilir"
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "enum type defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "struct defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "union defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%> yeniden tanımlanmış"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%> yeniden tanımlanmış"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "%<union %E%> iç içe yeniden tanımlanmış"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "%<struct %E%> iç içe yeniden tanımlanmış"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C isimsiz struct/union'lara izin vermez"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C isimsiz struct/union'lara izin vermez"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "yinelenmiş üye %q+D"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union hiç isimli üye içermiyor"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union hiç üye içermiyor"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "yapı hiç isimli üye içermiyor"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "yapı hiç üye içermiyor"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
 msgstr "%Junion içinde esnek dizi üye"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member not at end of struct"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member in otherwise empty struct"
 msgstr "%Jbaşka bir boş yapı içinde esnek dizi"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "type %qT is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "%<enum %E%> iç içe yeniden tanımlanmış"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> yeniden bildirilmiş"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "sembolik sabit grubunun değerleri en büyük tamsayı aralığını aşıyor."
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "belirtilen kip sırali sayısal değerler için çok küçük"
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "sembolik sabit listesi değerlerinde taşma"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute noinline"
 msgstr "satıriçi %q+D işlevine satıriçi olmayan öznitelik verilmiş"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "dönüş türü, bir içi boş tür"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "dönen tür %<int%> türüne öntanımlıdir"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for %q+D"
 msgid "no previous prototype for %qD"
 msgstr "%q+D için önceki prototip yok"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D tanımlanmadan önce prototipsiz kullanılmış"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
 msgstr "%q+D için evvelce bildirim yok"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD was used with no declaration before its definition"
 msgstr "%q+D tanımından önce bildirimsiz kullanılmış"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %<int%>"
 msgstr "%q+D için dönüş türü %<int%> değil"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is normally a non-static function"
 msgstr "%q+D normalde bir static olmayan işlevdir"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style parameter declarations in prototyped function definition"
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%Jprototipli işlev tanımında eski tarz parametre bildirimi"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtraditional C rejects ISO C style function definitions"
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%Jgeleneksel C, ISO C tarzı işlev tanımlarına izin vermez"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name omitted"
 msgid "parameter name omitted"
 msgstr "%Jparametre ismi atlandı"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "old-style function definition"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name missing from parameter list"
 msgid "parameter name missing from parameter list"
 msgstr "%Jparametre ismi parametre listesinde yok"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "%qD declared as a non-parameter"
 msgstr "%q+D bir parametre olarak bildirilmemiş"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, fuzzy, gcc-internal-format
 #| msgid "multiple parameters named %q+D"
 msgid "multiple parameters named %qD"
 msgstr "%q+D isimli çok sayıda parametre"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "parameter %qD declared with void type"
 msgstr "%q+D parametresi void olarak bildirilmiş"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, fuzzy, gcc-internal-format
 #| msgid "type of %q+D defaults to %<int%>"
 msgid "type of %qD defaults to %<int%>"
 msgstr "%q+D için tür öntanımlı olarak %<int%>"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "%q+D parametresi tamamlanmamış türde"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "declaration for parameter %q+D but no such parameter"
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "%q+D parametresi için bildirim var ama böyle bir parametre yok"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "argüman sayısı yerleşik prototiple uyumsuz"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "argüman sayısı prototiple uyumsuz"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprototype declaration"
 msgid "prototype declaration"
 msgstr "%Hprototip bildirimi"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "yükseltgenmiş argüman %qD yerleşik prototiple uyumsuz"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "yükseltgenmiş argüman %qD prototiple uyumsuz"
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "%qD argümanı yerleşik prototiple eslesmiyor"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "%qD argümanı prototiple uyumsuz"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -32234,215 +32266,215 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declaration used outside C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> döngüsünün ilk bildirimi C99 kipinin dışında kullanılmış"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde statik değişken %q+D bildirimi"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde %<extern%> değişken %q+D bildirimi"
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde değişken olmayan %q+D bildirimi"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE yinelenmiş"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "bildirim belirteçleri içinde iki veya daha fazla veri türü"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> GCC için çok uzun"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 karmaşık türleri desteklemez"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 karmaşık türleri desteklemez"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "bu hedefte -fdata-sections desteklenmiyor"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE bir typedef veya yerleşik veri türü olarak başarısız"
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE bildirimin başlangıcında değil"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> %<auto%> ile kullanılmış"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> %<register%> ile kullanılmış"
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> %<typedef%> ile kullanılmış"
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s %s desteği vermiyor"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<extern%> öncesinde %<__thread%>"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<static%>  öncesinde %<__thread%>"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "bildirim belirteçlerinde çok sayıda saklama sınıfı"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs used with %qE"
 msgstr "%<__thread%> %qE ile kullanılmış"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, fuzzy, gcc-internal-format
 #| msgid "%<@try%> without %<@catch%> or %<@finally%>"
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<@catch%> veya %<@finally%> olmaksızın %<@try%>"
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C salt %<complex%>i %<double complex%> anlamında desteklemez"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -32452,7 +32484,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr ""
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -32475,8 +32507,8 @@
 msgid "unknown type name %qE"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "bildirim belirteçleri umuluyordu"
@@ -32493,7 +32525,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -32577,7 +32609,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "dizge sabiti umuluyordu"
@@ -32641,14 +32673,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "betimleyici umuluyordu"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "sembolik sabitler listesinin sonunda virgul"
@@ -33126,35 +33158,35 @@
 msgid "no type or storage class may be specified here,"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
@@ -33165,48 +33197,48 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for, while or do statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC pch_preprocess, ignored"
 msgid "%<#pragma GCC pch_preprocess%> must be first"
@@ -33223,13 +33255,13 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected integer expression before ')'"
@@ -33241,31 +33273,31 @@
 msgid "expression must be integral"
 msgstr "%L'deki ifade değişmez olmalı"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "%qD is not a constant"
 msgstr "%qd argümanı bir sabit değil"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<none%> or %<shared%>"
@@ -33299,17 +33331,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr ""
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid schedule kind"
@@ -33330,12 +33362,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "using parameters for %<linear%> step is not supported yet"
@@ -33356,19 +33388,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "geçersiz %%d terimi"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "mask geçersiz"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid dist_schedule kind"
@@ -33380,62 +33412,62 @@
 msgid "invalid proc_bind kind"
 msgstr "geçersiz döngü komutu"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not valid for %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT %qT'nin alt sınıfı değil"
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr ""
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid pragma"
 msgstr "#pragma %s geçersiz"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma align%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma align%> bozuk"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on %<__fpreg%>"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<__fpreg%> üzerinde geçersiz işlem"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -33446,19 +33478,19 @@
 msgid "expected %<(%> or end of line"
 msgstr "Beklenmeyen modül sonu"
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "_Cilk_for statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration declaration or initialization"
@@ -33469,256 +33501,256 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr ""
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected function-name %<(%>"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%J%u. parametre tamamlanmamış türde"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "vectorlength must be an integer constant"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "yığıt boyutu ikinin üstel katlarında olmalı"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr ""
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "base of array section must be pointer or array type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or numeral"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "array notations cannot be used with function type"
 msgstr "new bir işlev türe uygulanamaz"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 #| msgid "Expected an initialization expression at %C"
 msgid "expected array notation expression"
@@ -33729,7 +33761,7 @@
 msgid "%qD has an incomplete type"
 msgstr "%qD bir tamamlanmamış tür içeriyor"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void ifade kullanımı geçersiz"
@@ -33839,7 +33871,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indisli değer ne dizi ne de bir gösterici"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "dizi indisi bir tamsayı değil"
@@ -33967,7 +33999,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "%2$qE işlevinin %1$d. argümanına prototipten dolayı işaretli tamsayı aktarılması"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT when passing argument to function"
@@ -34000,7 +34032,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -34089,7 +34121,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "koşullu ifadede sol değersiz dizi"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
@@ -34127,7 +34159,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "koşullu ifadede gösterici/tamsayı tür uyumsuzluğu"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr ""
@@ -34215,7 +34247,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "%qT türündeki işlev çağrısından eşleşmeyen %qT türüne dönüşüm"
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "farklı boyuttaki tamsayı türden göstericiye dönüşüm"
@@ -34386,7 +34418,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "ilklendirmede sol taraf bir biçim özniteliği adayı olabilir"
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "dönüş türü bir biçim özniteliği adayı olabilir"
@@ -34526,7 +34558,7 @@
 msgid "initialization of a flexible array member"
 msgstr "esnek dizi üyesi ilklendirmesi"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "karakter dizisinin ilklendiricisi olarak geniş dizge kullanılmış"
@@ -34575,7 +34607,7 @@
 msgid "invalid initializer"
 msgstr "geçersiz ilklendirici"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opak vektör türleri ilklendirilemez"
@@ -34723,7 +34755,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C %<goto *expr;%> kullanımına izin vermez"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> olarak bildirilmiş işlev %<return%> deyimi içeriyor"
@@ -34733,7 +34765,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
@@ -34846,18 +34878,18 @@
 msgid "expression statement has incomplete type"
 msgstr "ifade deyimi boş tür içeriyor"
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "comparing vectors with different element types"
 msgstr "?: için terimler farklı türde"
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "== veya != ile karşılaştırma gerçel sayılarda güvenli değil"
@@ -34910,12 +34942,12 @@
 msgstr "tamsayı sıfır ile sıralı gösterici karşılaştırması"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "tamsayı sıfır ile sıralı gösterici karşılaştırması"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
@@ -34942,91 +34974,91 @@
 msgid "used vector type where scalar is required"
 msgstr "doğrudan değer gereken yerde yapı türünde değer kullanılmış"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Dizi bölümlerini yordam girdisinde sürekli bir blokun içine kopyalar"
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have pointer or array type"
@@ -35037,17 +35069,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -35057,7 +35089,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qE is not a variable in clause %qs"
@@ -35068,19 +35100,19 @@
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -35097,50 +35129,50 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bir şablon türü bildirmiyor"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bir işlev şablonu değil"
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -35151,35 +35183,35 @@
 msgstr ""
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, fuzzy, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "%2$q#D işlevinin %<this%> parametresi olarak %1$qT aktarımı niteleyicileri iptal ediyor"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion from %qT to %qT"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -35186,90 +35218,90 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T, %T) <built-in>"
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr "%s %D(%T, %T, %T) <yerleşik>"
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T) <built-in>"
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "%s %D(%T, %T) <yerleşik>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T) <built-in>"
 msgid "%s%D(%T) <built-in>"
 msgstr "%s %D(%T) <yerleşik>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "%s %T <conversion>"
 msgid "%s%T <conversion>"
 msgstr "%s %T <dönüşüm>"
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D <near match>"
 msgid "%s%#D <near match>"
 msgstr "%s %+#D <yakın eşleşme>"
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr ""
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr ""
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument deduction/substitution failed:"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to non-scalar type %qT requested"
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr "%qT türünden skalar olmayan %qT türüne dönüşüm istendi"
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "%<%D(%A)%> çağrısı ile eşleşen bir işlev yok"
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "aşırı yüklü %<%D(%A)%> çağrısı belirsiz"
@@ -35276,485 +35308,485 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr "üye göstericisi işlevi %E nesnesiz çağrılamaz; .* or ->* kullanımı önerilir"
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "%<(%T) (%A)%> çağrısı için eşleşme yok"
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "%<(%T) (%A)%> çağrısı belirsiz"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "dizi indisi için dönüşüm belirsiz"
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands of types %qT and %qT to binary %qO"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "%qT ve %qT türündeki terimler iki terimli `%qO' için geçersiz"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, fuzzy, gcc-internal-format
 #| msgid "User operators:\n"
 msgid "ternary %<operator?:%>"
 msgstr "Kullanıcı işleçleri:\n"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%2$E ? %3$E : %4$E%> içindeki %<?: üç terimlisi%> için %1$s"
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator%s%>"
 msgstr "Hatalı işleç"
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<%3$E%4$s%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator[]%>"
 msgstr "Hatalı işleç"
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%2$E[%3$E]%> içindeki %<[] işleci%> için %1$s"
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%<%3$s %4$E%> içindeki %2$qs için %1$s"
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<%3$E %4$s %5$E%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<%3$s%4$E%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ bir ?: üç terimlisinde ikinci terimin eksikliğine izin vermez"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "koşullu ifade içinde enum uyumsuzluğu: %qT vs %qT"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "?: için terimler farklı türde"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "koşullu ifade içinde enum uyumsuzluğu: %qT vs %qT"
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "koşullu ifade içinde enum ve enum olmayan türler"
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "sonek %2$qs için  %<%1$D(int)%> bildirimi yok, yerine önek işleci deneniyor"
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "sonek %2$qs için  %<%1$D(int)%> bildirimi yok, yerine önek işleci deneniyor"
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T ile %q#T arasında karşılaştırma"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "non-placement deallocation function %q+D"
 msgstr "%qE işlevinin örtük bildirimi"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr ""
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%2$qT için uygun bir %<%1$s işleci%> yok"
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr "%q+#D private'dir"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr "%q+#D protected'dir"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr "%q+#D erişilebilir değil"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr "bu bağlamda"
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "%2$qD işlevinin gösterici olmayan %1$P argümanına NULL aktarılması"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULL'dan gösterici olmayan %qT türüne dönüşüm"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULL'dan gösterici olmayan türe dönüşüm"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "too many braces around initializer for %qT"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "converting to %qT from %qT"
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr "%qT türüne %qT türünden dönüşüm"
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "%qT türünden %qT türüne dönüşüm geçersiz"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  %2$qD işlevinin %1$P argümanının ilklendirilmesi"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "%qT türünden %qT türüne dönüşüm geçersiz"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %q+D"
 msgstr "  %2$qD işlevinin %1$P argümanının ilklendirilmesi"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind rvalue %qE to %qT"
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "sağ taraf değeri %qE, %qT türüne bağlanamaz"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklendirilmesi geçersiz"
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, fuzzy, gcc-internal-format
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "%2$q#D işlevinin %<this%> parametresi olarak %1$qT aktarımı niteleyicileri iptal ediyor"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "%qE bitalanı %qT türüne bağlanamaz"
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "%qE paketli alanı %qT türüne bağlanamaz"
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "sağ taraf değeri %qE, %qT türüne bağlanamaz"
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden aktarılamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "%2$qD işlevinin %1$d. parametresi için öntanımlı argüman henüz çözümlenmedi"
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "%2$q#D işlevinin %<this%> parametresi olarak %1$qT aktarımı niteleyicileri iptal ediyor"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  %qD çağrısında"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, fuzzy, gcc-internal-format
 #| msgid "  in call to %qD"
 msgid "  in call to %q+D"
 msgstr "  %qD çağrısında"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr "java arabiriminde %qT türünde class$ alanı bulunamadı"
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "kurucular virtual olarak bildirilemez"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "%<%T::%s(%A)%#V%> çağrısı ile eşleşen işlev yok"
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr "%<%T::%s(%A)%#V%> çağrısı ile eşleşen işlev yok"
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "%<%D(%A)%> çağrısı ile eşleşen bir işlev yok"
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "aşırı yüklü %<%s(%A)%> çağrısı belirsiz"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "üye işlev %qD nesne olmaksızın çağrılamaz"
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "%qT aktarımı %qT türünü %qT türü üzerinden seçiyor"
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "%qD %qD üzerinden,"
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  çünkü argüman için dönüşüm süreci daha iyi"
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "doğrudan özelleştirmede öntanımlı argüman belirtilmiş"
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 1: %q+#F"
 msgstr "aday: %+#D"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 2: %q+#F"
 msgstr "aday: %+#D"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "İlkinin en kotü dönüşümü ikincisinden daha iyi olsa bile ISO C++ bunlar belirsizdir der:"
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %qT to %qT"
 msgstr "%qE %qT türüne dönüştürülemedi"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "%qT türündeki başvurunun %qT türündeki ifadeden ilklendirilmesi geçersiz"
@@ -35919,7 +35951,7 @@
 msgid "  by %q+D"
 msgstr "  %q+D tarafından gizlendi"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D geçersiz; bir anonim union sadece statik olmayan veri üyeleri içerebilir"
@@ -35930,7 +35962,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D geçersiz; bir anonim union sadece statik olmayan veri üyeleri içerebilir"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr "anonim union içinde private üye %q+#D"
@@ -35941,7 +35973,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "anonim union içinde private üye %q+#D"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr "anonim union içinde protected üye %q+#D"
@@ -36077,74 +36109,84 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  ama %<operator=(const %T&)%>ye değiştirilmiyor"
 
-#: cp/class.c:4538
+#: cp/class.c:4300
 #, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, gcc-internal-format
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr ""
+
+#: cp/class.c:4557
+#, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "sanal olmayan yöntem %q+D için ilklendirici belirtilmiş"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a base of %qT"
 msgid "%q+T is not literal because:"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %q+D"
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "static olmayan veri üyesi %q+D kullanımı geçersiz"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %q+D"
 msgid "  non-static data member %q+D has volatile type"
 msgstr "static olmayan veri üyesi %q+D kullanımı geçersiz"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr "bir kurucu olmaksızın sınıf içinde static olmayan başvuru %q+#D"
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr "bir kurucu olmaksızın sınıf içinde static olmayan sabit üye %q+#D"
@@ -36151,105 +36193,105 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "doğrudan taban %qT belirsizlikten dolayı %qT içinde erişilebilir değil"
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "sanal taban %qT belirsizlikten dolayı %qT içinde erişilebilir değil"
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D alanının göreli konumu ABI-uyumlu değil ve bu GCC'nin gelecek sürümünde değişebilir"
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T sınıfın yeniden tanımı"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T sanal olmayan kuruculu sanal işlevler içeriyor"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "sınıf %qT %qD isminde alan içermiyor"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "%qs türü sanal üye işlevlere sahip"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "yapı tamamlanmaya çalışılırken önceki ayrıştırma hatalarından dolayı kesildi"
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "dil dizgesi %<\"%E\"%> tanınmıyor"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, fuzzy, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "%2$qT türüne dönüşüme dayalı aşırı yüklü %1$qD işlevi çözümlenemiyor"
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "%qD işlevinin %q#T türüne dönüşümü için eşleşme yok"
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "aşırı yüklü %qD işlevinin %q#T türüne dönüşümü belirsiz"
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "%qD üyesine gösterici varsayılıyor"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(bir üye göstericisi sadece %<&%E%> ile şekillendirilebilir)"
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "tür bilgisi yetersiz"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE ifadesi %qT türünden %qT türüne dönüştürülemez"
@@ -36259,12 +36301,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "%q#D yeniden bildirimi"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr "%qD'nin %q+#D üzerindeki anlamını değişiyor"
@@ -36307,46 +36349,46 @@
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "%Jtaban sınıf %q#T kopyalama kurucusunda doğrudan ilklendirilmiş olmalı"
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr "%q+D normalde bir static olmayan işlevdir"
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "expression %qE does not designate a constexpr function"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-constexpr function %qD"
@@ -36353,243 +36395,243 @@
 msgstr "işlev olmayan %qD ye çağrı"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD used before its definition"
 msgstr "%q+D tanımlanmadan önce prototipsiz kullanılmış"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qs has circular dependency"
 msgid "call has circular dependency"
 msgstr "protokol %qs döngüsel bağımlılık içeriyor"
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%q+E is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "sağa kaydırma sayısı negatif"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript out of bound"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "negative array subscript"
 msgstr "%C'de dizi indisi umuluyordu"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qE is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, fuzzy, gcc-internal-format
 #| msgid "no field %qD found in union being initialized"
 msgid "%qD used in its own initializer"
 msgstr "ilklendirilen union içinde %qD diye bir alan yok"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%q#D is not const"
 msgstr "%q+D bir işlev değil,"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D private'dir"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of %qE is not a constant-expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "koşullu ifade içinde enum ve enum olmayan türler"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant-expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "statement is not a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "ifade umuluyordu"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "pointer comparison expression is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant-expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -36662,7 +36704,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr ""
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr ""
@@ -36707,7 +36749,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "%qT türünden %qT türüne dönüşüm niteleyicileri iptal ediyor"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "%qT türünden %qT türüne dönüşüm gösterici başvurusunu kaldırmaz"
@@ -36717,316 +36759,316 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "%qT türü %qT türüne dönüştürülemiyor"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "%q#T türünden %q#T türüne dönüşüm"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, fuzzy, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%2$qT umulan yerde %1$q#T kullanılmış"
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "%qE %qT türüne dönüştürülemedi"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "bir gerçel sayı değer umulan yerde %q#T kullanılmış"
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "%qT türünden skalar olmayan %qT türüne dönüşüm istendi"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "sözde yıkıcılar çağrılmaz"
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "tamamlanmamış türe dönüşüm"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "%2$qT tamamlanmamış türüne %1$qs uygulanması geçersiz"
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of type %qT"
 msgstr "tamamlanmamış türe dönüşüm"
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "second operand of conditional expression has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "third operand of conditional expression has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right operand of comma operator has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of comma operator has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, fuzzy, gcc-internal-format
 #| msgid "statement with no effect"
 msgid "statement has no effect"
 msgstr "deyim etkisiz"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "for increment expression has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "NULL'dan gösterici olmayan türe dönüşüm"
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "şablon argümanı %qE %qT'ye dönüştürülemedi"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "%qT tünüden öntanımlı türe dönüşüm belirsiz"
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  aday dönüşümler %qD ve %qD içeriyor"
@@ -37484,121 +37526,121 @@
 msgid "template parameters do not match template %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, fuzzy, gcc-internal-format
 #| msgid "%Jan anonymous union cannot have function members"
 msgid "an anonymous struct cannot have function members"
 msgstr "%J bir anonim union, işlev üyeler içeremez"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "%Jan anonymous union cannot have function members"
 msgid "an anonymous union cannot have function members"
 msgstr "%J bir anonim union, işlev üyeler içeremez"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde kuruculu üye %q+#D kullanılamaz"
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde yıkıcılı üye %q+#D kullanılamaz"
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde kopya atama isleçli üye %q+#D kullanılamaz"
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T için öznitelik %qs anahtar sözcüğünü izlemeli"
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "bir bildirimde birden fazla tür"
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "C++ yerleşik türü %qT için yeniden bildirim"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef bildiriminde tür ismi eksik"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ anonim yapıları (struct) yasaklar"
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> sadece bir sınıf içinde belirtilebilir"
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> sadece kurucular için belirtilebilir"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "bir saklama sınıfı sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "%<register%> in file-scope empty declaration"
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "dosya etki alanı boş bildiriminde %<register%>"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
@@ -37605,137 +37647,137 @@
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD ilklendirilmiş (yerine  __typeof__  kullanın)"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D hem %<extern%> olarak bildirilmiş hem de ilklendirilmiş"
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D definition is marked dllimport"
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "%q+D işlevinin tanımı dllimport imli"
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "geçersiz üye sablonu bildirimi %qD"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ %<%T::%D%>nin %<%T::%D%> olarak tanımlanmasına izin vermez"
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "%qD ilklendirmesi yinelenmiş"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr ""
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%H%qE burada bildirilmemiş (bir işlev içinde değil)"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "%q#D değişkeni ilklendirilmiş ama içi boş türde"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "%q#D dizisinin elemanları içi boş türde"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D hem %<extern%> olarak bildirilmiş hem de ilklendirilmiş"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "küme %q#D içi boş türde olup tanımlı olamaz"
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD başvuru olarak bildirilmiş ama ilklendirilmemiş"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "alelade olmayan ilklendiriciler desteklenmiyor"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "ilklendirici %qD bildiriminin boyutunu saptayamıyor"
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD bildiriminde dizi boyutu eksik"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "sıfır boyutlu dizi %qD"
@@ -37743,901 +37785,901 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "%q+D nin saklama uzunluğu bilinmiyor"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "%q+D nin saklama genişligi sabit değil"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "özür: satıriçi işlev static verisi %q+#D'nin kodlaması yanlış (sizi çoklu kopyalara sürükleyecek)"
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  ilklendiriciyi kaldırarak bunun olurunu bulabilirsiniz"
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "ilklendirilmemiş sabit %qD"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "%qs türü bir kullanıcı tanımlı yapıcıya sahip"
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "%2$qT türündeki bir vektör için ilklendirici olarak %1$qT türü geçersiz"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT için ilklendirici {} içinde olmalı"
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "geçersiz ilklendirici"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT için ilklendirici sayısı çok fazla"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "%qT için skalar ilklendiriciyi kuşatan parantezler"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "%q#D dizisinin elemanları içi boş türde"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ISO C90 bileşik sabitlere izin vermez"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD içi boş türde"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "scalar object %qD requires one element in initializer"
 msgstr "union ilklendiricide gereğinden fazla öğe"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be initialized by constructor, not by %<{...}%>"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "%qD bir kurucu ile ilklendirilmeli, %<{...}%> ile değil"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "parantezli dizge sabiti %2$qE ile ilklendirilmiş %1$qD dizgesi"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "kuruculu statik üye için ilklendirici geçersiz"
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(bir sınıf dışı ilklendirme gerekli)"
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD parametresi ilklendirilmiş"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "önceki %q#D tür bildirimini gölgeliyor"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr ""
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "definition of static data member %q+D of dllimport'd class"
 msgid "non-static data member %qD has Java class type"
 msgstr "dllimport'lu sınıfın %q+D durağan veri üyesinin tanımı"
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "%q#D işlevi bir değişken gibi ilklendirilmiş"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "ilklendirici %qD bildiriminin boyutunu saptayamıyor"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "%qD bildiriminde dizi boyutu eksik"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "sıfır boyutlu dizi %qD"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için yıkıcı, bir üye olamaz"
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için kurucu, bir üye olamaz"
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> variable"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D bir olağandışılık belirtimi ile bildirilmiş"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD tanımı %qT bağlamını kapsayan isim alanınında değil"
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statik üye işlev %q#D tür niteleyicilerle bildirilmiş"
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "%qD doğrudan özelleştirmesinin kardeş bildirimde tanımı"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "birincil şablon bildiriminde %qD şablon kimliğinin kullanımı geçersiz"
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "kardeş şablon özelleştirmesi %qD bildiriminde %<inline%> kullanılamaz"
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr "kardeş şablon özelleştirmesi %qD bildiriminde %<inline%> kullanılamaz"
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> bir şablon olarak bildirilemez"
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> inline olarak bildirilemez"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "%<::main%> inline olarak bildirilemez"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> static olarak bildirilemez"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "C ilintilemeli şablon"
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "seçenek argümanı %qs geçersiz"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> %<int%> döndürmeli"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "dolaylı bildirimli %qD tanımı"
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "dolaylı bildirimli %qD tanımı"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q+#D explicitly defaulted here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "sınıf %2$qT içinde bildirilmiş %1$q#D diye bir üye işlev yok"
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ tümlemeyen %2$qT türündeki %1$qD üye sabitinin ilklendirilmesine izin vermez"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "%qD dizisinin boyutu tümlemeyen %qT türünde"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "dizi boyutu tümlemeyen %qT türünde"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "%qD dizisinin boyutu negatif"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "dizi boyutu negatif"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ da sıfır boyutlu %qD dizisi yasaktır"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++'da sıfır boyutlu dizi yasaktır"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array %qD"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ değişken boyutlu %qD dizisine izin vermez"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++  değişken boyutlu diziye izin vermez"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "dizi boyutunda taşma"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "void dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi olarak %qD bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "kurucu için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "yıkıcı için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "%<operator %T%> için dönüş türü belirtilmiş"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "void bildirimli adsız değişken ya da alan"
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of undefined type %<%s %E%>"
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "tanımsız tür %<%s %E%> kullanımı geçersiz"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of undefined type %<%s %E%>"
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "tanımsız tür %<%s %E%> kullanımı geçersiz"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or a namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "üye olmayan olarak %qD bildirimi"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "bildirimci kimliği eksik; yedek sözcük %qD kullanılıyor"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<register%>"
 msgid "function definition does not declare parameters"
 msgstr "%<register%> bildirimli işlev tanımı"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs bildiriminde iki veya daha fazla veri türü"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C salt %<complex%>i %<double complex%> anlamında desteklemez"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ türsüz %qs bildirimine izin verilmez"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs bu hedef tarafından desteklenmiyor"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for %qs"
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%qs için short, signed veya unsigned geçersiz"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, fuzzy, gcc-internal-format
 #| msgid "signed and unsigned given together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%qs için signed ve unsigned birlikte verilmiş"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "%<long long%> invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "%<long%> invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "%<short%> invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for %qs"
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%qs için long, short, signed ya da unsigned geçersiz"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for %qs"
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%qs için long, short, signed ya da unsigned geçersiz"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, fuzzy, gcc-internal-format
 #| msgid "long or short specified with char for %qs"
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%qs için char ile long veya short belirtilmiş"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, fuzzy, gcc-internal-format
 #| msgid "long and short specified together for %qs"
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%qs için long ve short birlikte belirtilmiş"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for %qs"
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%qs için short, signed veya unsigned geçersiz"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "%qs için long, short, signed ya da unsigned geçersiz olarak kullanılmış"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr "üye %qD, hem virtual hem de static olarak bildirilemez"
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "saklatım sınıfı belirteçleri parametre bildiriminde geçersiz"
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "sanal dış sınıf bildirimi"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs bildiriminde çok sayıda saklama sınıfı"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "%qs için tepe-seviye bildirim %<auto%> belirtiyor"
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs işlevinin etki alanı dolaylı olarak auto ve %<__thread%> bildirimli"
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "saklatım sınıfı belirteçleri kardeş işlev bildirimlerinde geçersiz"
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs işlevle dönen işlev olarak bildirilmiş"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
@@ -38644,276 +38686,276 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "yıkıcı bir statik üye işlev olamaz"
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "kurucu bir statik üye işlev olamaz"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "kurucular cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr "kurucular virtual olarak bildirilemez"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "kardeş bildirimi sınıf bildiriminde değil"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "yerel sınıf tanımı içinde kardeş işlev %qs tanımlanamaz"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "yıkıcılar parametre almayabilir"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "%q#T üyeye gösterici bildirilemez"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "şablon kimliği %qD bir bildirici olarak kullanılmış"
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "üye işlevler sınıflarının örtük kardeşleridir"
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, fuzzy, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "üye %2$qs üzerinde fazladan niteleme %<%1$T::%>"
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "üye işlev %<%T::%s%> %<%T%> içinde tanımlanamaz"
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "uye işlev %<%T::%s%> %<%T%> içinde bildirilemez"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "üye %<%T::%s%> %qT içinde bildirilemez"
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "veri üyesi değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parametre değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "sanal dış sınıf bildirimi"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "sadece kurucuların bildirimleri %<explicit%> olabilir"
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "nesne olmayan üye %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "static %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "sabit %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "%<inline%> bildirimli typedef %q+D"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jtypedef ismi bir iç içe isimli belirteç olmayabilir"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ kapsayan sınıf ile aynı isimde yuvalanmış %qD türüne izin vermez"
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr "kardeş sınıf bildirimi için tür niteleyiciler belirtilmiş"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "kardeş sınıf bildirimi için %<inline%> belirtilmiş"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend bildirimi sınıf anahtarı gerektirir, %<friend class %T::%D%> gibi"
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend bildirimi %<friend %#T%> gibi bir sınıf anahtarı gerektirir"
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "sınıf %qT genel bağlamın kardeşi yapılmaya çalışılıyor"
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "üye olmayan işlev türünde niteleyiciler geçersiz"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "mutlak bildirimci %qT bildirim olarak kullanılmış"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared %<auto%>"
@@ -38920,225 +38962,225 @@
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "C işlevi %q#D bildirimi"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "işlev %qD bir union içinde virtual olarak bildirilmiş"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr "%qD daima static olduğundan sanal olarak bildirilemez"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%2$qT üyesi olarak %1$qD bildirimi"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "örtük bildirimli özel üye işlev özelleştirmesi"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "%qD alanı içi boş türde"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "%qT ismi içi boş türde"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ne işlev ne de üye işlev; friend olarak bildirilemez"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "constexpr static data member %qD must have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "saklama sınıfı %<auto%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "saklama sınıfı %<register%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "bir işlev tanımında bir asm belirtimine izin verilmez"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<static%> belirteci geçersiz"
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<inline%> belirteci geçersiz"
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "sınıf olmayan sanal işlev %qs"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qs defined in a non-class scope"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "üye işlev %qD static ilintilemeli olarak bildirilemez"
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statik işlev başka bir işlevin içinde bildirilemez"
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "bir statik veri üyesi tanımlarken (bildirime zit olarak) %<static%> kullanılamayabilir"
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "üye %q#D harici ilintilemeli olarak doğrudan bildirilemez"
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs ilklendirilmiş ve %<extern%> bildirilmiş"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hem %<extern%> olarak bildirilmiş hem de ilklendrilmiş"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has Java class type"
 msgstr "%q+D parametresi tamamlanmamış türde"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametre %qD geçersiz olarak yöntem türünde bildirilmiş"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
@@ -39158,72 +39200,72 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "kurucu geçersiz; muhtemelen %<%T (const %T&)%> anlamında kullandınız"
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD bir isim alanı içinde bildirilemeyebilir"
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD static olarak bildirilemeyebilir"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD ya bir statik olmayan üye işlev ya da üye olmayan işlev olmalıdır"
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD ya bir sınıf argümanına sahip olmalı ya da enum türünde olmalı"
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to void will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a base class will never use a type conversion operator"
@@ -39230,108 +39272,108 @@
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ ?: üç terimlisinin aşırı yüklenmesini yasaklar"
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr "sonek %qD argüman olarak %<int%> almalı"
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr "sonek %qD ikinci argümanı olarak %<int%> almalı"
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr "%qD ya hiç argüman almamalı ya da bir argüman almalı"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr "%qD ya bir ya da iki argüman almalı"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "önek %qD %qT döndürmeli"
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "sonek %qD %qT döndürmeli"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr "%qD %<void%> almalı"
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr "%qD sadece ve sadece bir argüman almalı"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "%qD sadece ve sadece iki argüman almalı"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "kullanıcı tanımlı %qD daima her iki argümanıyla birlikte değerlendirilir"
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD değeriyle döndürülmeli"
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "%2$qs sonrası şablon türü %1$qT parametresi kullanımı"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%2$q+D için şablon özelleştirmesi %1$qD belirsiz"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "%2$qs sonrası typedef-ismi %1$qD kullanımı"
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D için burada önceki bir bildirim var"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT türüne %qs olarak başvuruluyor"
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "%q+T için burada önceki bir bildirim var"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT türüne enum olarak başvuruluyor"
@@ -39343,89 +39385,89 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> için şablon argüman gerekli"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD bildirildiği sınıf ile aynı isimde"
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "önceden bildirim olmaksızın enum %q#D kullanımı"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "önceden %q+D bildirimi"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "türetilmiş union %qT geçersiz"
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr "Java sınıfı %qT çok sayıda tabana sahip olamaz"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr "Java sınıfı %qT sanal tabanlara sahip olamaz"
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "taban tür %qT bir yapı veya sınıf türü olarak hatalı"
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "ardışık tür %qT tanımsız"
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "yinelenmiş taban türü %qT geçersiz"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jönceden burada tanımlı"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr ""
@@ -39434,93 +39476,93 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "%qT için simgesel sabit değerlerinin tamamını hiçbir tümleyen tür temsil edemez"
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD'de simgesel sabit değerlerinde taşma"
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr ""
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, fuzzy, gcc-internal-format
 #| msgid "return type is an incomplete type"
 msgid "return type has Java class type %q#T"
 msgstr "dönüş türü, bir içi boş tür"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>, %<*this%> için bir başvuru döndürmeli"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "%q+D için evvelce bildirim yok"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "işlev bildirimi geçersiz"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "işlevin dönüş türü %<volatile%> den dolayı uyumsuz"
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "parameter %q+D set but not used"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "geçersiz üye işlev bildirimi"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD zaten %qT sınıfında tanımlı"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -39561,7 +39603,7 @@
 msgid "deleting %qT is undefined"
 msgstr "%qT silinmesi tanımsız"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D şablon bildirimi"
@@ -39585,7 +39627,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "yıkıcı %qD üye şablon olarak bildirilmiş"
@@ -39681,27 +39723,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "%qD dizisinin boyutu tümlemeyen %qT türünde"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonim yapı isimli türün içinde değil"
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "isim alanı bağlamındaki anonim kümeler static olmalıdır"
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "üyesiz anonim union"
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> %qT türünde dönmeli"
@@ -39710,48 +39752,48 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, fuzzy, gcc-internal-format
 #| msgid "second parameter of %<va_start%> not last named argument"
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "%<va_start%>'in ikinci parametresi isimli son argüman değil"
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> ilk parametreyi %<size_t%> (%qT) türünde alir"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> %qT türünde dönmeli"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> ilk parametreyi %qT türünde alır"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using anonymous type, is used but never defined"
@@ -39761,49 +39803,49 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D niteliksiz türe başvurmuyor, dolasıyla ilintileme için kullanılmaz"
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "satıriçi işlev %q+D tanımlanmadan kullanılmış"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "%2$q+#D'nin %1$P. parametresi için öntanımlı argüman eksik"
@@ -39810,12 +39852,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
@@ -40426,43 +40468,43 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "sınıf tanımlanırken bildirilmiş olsalar bile, ne yıkıcı ne de sınıfa özel silme işleci çağrılır."
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "ilklendirici erken sonlanıyor"
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr "çok boyutlu diziler ilklendiricilerle ilklendirilemez"
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete içindeki dizi boyutu bilinmiyor"
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "silme işlecinin çağrısında bir sorun saptandı:"
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "sınıf tanımlanırken bildirilmiş olsalar bile, ne yıkıcı ne de sınıfa özel silme işleci çağrılır."
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
@@ -40596,18 +40638,18 @@
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
@@ -41043,7 +41085,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr ""
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -41070,7 +41112,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "sınıf olmayan %2$qT türündeki %1$qD üyesi için istek"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -41146,7 +41188,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(belki de %qT bildiriminden sonra bir ; yoktur)"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT bir şablon değil"
@@ -41173,7 +41215,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -41473,7 +41515,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
@@ -41666,7 +41708,7 @@
 msgid "capture of non-variable %qD "
 msgstr "salt-okunur değişken %qD için eksiltme"
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q+#D declared here"
@@ -41731,7 +41773,7 @@
 msgid "compound-statement in constexpr function"
 msgstr "Saf ve sabit işlevler keşfedilir"
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
@@ -41764,7 +41806,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
@@ -41797,13 +41839,13 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ hesaplanmış goto'lara izin vermez"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "fazladan %<;%>"
@@ -41852,7 +41894,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "sınıf tanımı kardeş olarak bildirilemeyebilir"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
@@ -41953,13 +41995,13 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "%<export%> anahtar sözcüğü gerçekleştirilmedi ve yoksayılacak"
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
@@ -41977,7 +42019,7 @@
 msgid "expected template-id"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -42063,228 +42105,228 @@
 msgid "expected type specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C ileriye dönük parametre bildirimlerine izin vermez"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "İfade türü umuluyordu"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Umulmadık isim"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "attributes ignored on uninstantiated type"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "attributes ignored on template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a namespace-name"
 msgid "%qD is not an enumerator-name"
 msgstr "%qD bir isim alanı ismi değil"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Özdevinimli şablon örneklenimi etkin olur"
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%3$qD'yi kapsamayan %2$qD etki alanı içinde %1$qD türünde bildirim"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%3$qD'yi kapsamayan %2$qD etki alanı içinde %1$qD türünde bildirim"
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "çok sayıda %q#T tanımı"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD bir isim alanı ismi değil"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: işlev tanımı dönüştürülmedi\n"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "bir işlev tanımında bir asm belirtimine izin verilmez"
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function %qs"
 msgid "initializer provided for function"
 msgstr "kardeş işlev %qs ilklendirilemiyor"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "işlev %q+D 'inline' olarak yeniden bildirilmiş"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "dizi sınırı bir tamsayı sabit değil"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -42293,7 +42335,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid declarator"
@@ -42301,325 +42343,325 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "qualified-id in declaration"
 msgstr "işlev bildirimi geçersiz"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD bir isim alanıdır"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "beklenmeyen terim"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of %<auto%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr "işlev olmayanın parametresi için öntanımlı argüman kullanımı önerilmiyor"
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "öntanımlı argümanlara sadece işlev parametresi olarak izin verilir"
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "sınıf %s için dosya bulunamıyor"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD bildirimindeki sınıf ismi geçersiz"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification ignored"
 msgid "extra qualification not allowed"
 msgstr "fazladan niteleme yoksayıldı"
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "bir doğrudan özelleştirme %<template <>%> ile öncelenmeli"
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "function template %qD redeclared as a class template"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr "%q+#T türünde önceden tanım"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, fuzzy, gcc-internal-format
 #| msgid "a class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "bir kardeş bildirilirken bir sınıf anahtarı kullanılmalıdır"
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "işlev tanımında pure belirteci"
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "expected %<;%> at end of member declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr ""
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%<typename%> anahtar sözcüğüne bu bağlamda izin verilmez (taban sınıfı örtük olarak bir türdür)"
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "yeniden %q+D bildirimi geçersiz"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "şablon parametresi listesi çok az"
@@ -42628,594 +42670,594 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "şablon parametresi listesi çok fazla"
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "isimli dönüş değerleri artık desteklenmiyor"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template %q#D in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "yerel sınıf içinde %q#D üye şablonu bildirimi geçersiz"
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C ilintilemeli şablon"
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "%qs şablon bildirimi"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "isim alanı olmayan %qD kapsamında doğrudan özelleştirme"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> alt şablon argüman listesinde %<> >%> olmalıydı"
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "sahte  %<>>%>, bir şablon argüman listesini sonlandırmak için %<>%> kullanın"
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> before %<extern%>"
 msgid "%<__thread%> before %qD"
 msgstr "%<extern%> öncesinde %<__thread%>"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "bildirim belirteçlerinde hem %<short%> hem de %<char%>"
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE yinelenmiş"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs yinelenmiş"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs yaftası %q#T isimlemesinde kullanılmış"
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD farklı erişimle tekrar bildirilmiş"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (bir belirsizlik giderici olarak) sadece şablonlarda kullanılabilir"
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "öntanımlı argüman içinde dosya sonu"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "yanlış yere konmuş %<@%D%> Nesnel-C++ oluşumu"
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> bir argüman olarak bir tür belirtmeli"
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Nesnel-C++ seçici ismi geçersiz"
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, fuzzy, gcc-internal-format
 #| msgid "illegal reference type specified for instance variable %qs"
 msgid "invalid type for instance variable"
 msgstr "gerçekleme değişkeni %qs için ilişkilendirme türü kuraldışı"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE özniteliği %qE için yoksayıldı"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected positive integer expression"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<wait%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 #| msgid "Initialization at %C is not allowed in a PURE procedure"
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "%C'de ilklendirmeye bir PURE işlevinde izin verilmez"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough collapsed for loops"
 msgstr "tür bilgisi yetersiz"
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of %<#pragma pack%>"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma pack%> sonunda döküntü"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "kısıtlar terim için geçersiz"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "%C'de değişken ismi umuluyordu"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "geçersiz üye sablonu bildirimi %qD"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "isim alanı olmayan %qD kapsamında doğrudan özelleştirme"
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "sınıf sablonlarının kapsanması doğrudan özelleştirilmez"
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "farklı isim alanında %qD özelleştirmesi"
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "farklı isim alanında %qD özelleştirmesi"
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr "  %q+#D tanımından"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%3$qD isim alanını kapsamayan %2$qD isim alanında doğrudan %1$qD bildirimi"
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, fuzzy, gcc-internal-format
 #| msgid "invalid default argument for a template template parameter"
 msgid "name of class shadows template template parameter %qD"
 msgstr "bir şablonun şablon parametresi için öntanımlı argüman geçersiz"
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of alias template %qD"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "şablon olmayan %qT için doğrudan özelleştirme"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "örneklenim sonrası %qT özelleştirmesi"
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "%q#T farklı isim alanında özelleştiriliyor"
@@ -43222,72 +43264,72 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, fuzzy, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "örneklenim %2$qT sonrası %1$qT özelleştirmesi"
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "işlev şablonu kısmi özelleştirmesi %qD bildiricisine izin verilmez"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "örneklenim sonrası %qD özelleştirmesi"
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid "candidate is: %#D"
 msgstr "aday: %+#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
 msgstr "%s %+#D"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a variable template"
 msgstr "%qD bir şablon değil"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "şablon kimliği %qD %q+D için hiçbir şablon bildirimi ile eşleşmiyor"
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "%2$q+D için şablon özelleştirmesi %1$qD belirsiz"
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %D (should be %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -43294,59 +43336,59 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "birincil şablon bildiriminde şablon kimliği %qD"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "şablon parametre listesi doğrudan örneklenimde kullanılmış"
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "tanım doğrudan örneklenim için sağlanmış"
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD bildiriminde çok fazla şablon parametresi listeleniyor"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD bildiriminde çok az şablon parametresi listeleniyor"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "%qD doğrudan özelleştirmesi %<template <>%> tarafından vurgulanmalı"
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "işlev şablonu kısmi özelleştirmesi %qD bildiricisine izin verilmez"
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "işlev şablonu kısmi özelleştirmesi %qD bildiricisine izin verilmez"
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "doğrudan özelleştirmede öntanımlı argüman belirtilmiş"
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD bir şablon işlevi değildir"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%qD is not declared in %qD"
@@ -43360,95 +43402,95 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "örtük bildirimli özel üye işlev özelleştirmesi"
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "%2$qT türünde bildirimli %1$qD isminde üye işlev yok"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, fuzzy, gcc-internal-format
 #| msgid "<anonymous>"
 msgid "        <anonymous>"
 msgstr "<anonim>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "%q+#D bildirimi"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr " şablon parametresi %q+#D gölgeleniyor"
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "kismi özelleştirmede kullanılmayan şablon parametreleri:"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -43455,13 +43497,13 @@
 msgstr[0] "%2$qE şablon argümanının %1$qT türü şablon parametre(ler)ine bağımlı oluyor"
 msgstr[1] "%2$qE şablon argümanının %1$qT türü şablon parametre(ler)ine bağımlı oluyor"
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "örneklenim sonrası %qD özelleştirmesi"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD için öntanımlı argüman yok"
@@ -43469,47 +43511,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "kismi özelleştirmede kullanılmayan şablon parametreleri:"
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "%qT türündeki parametre için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "bir isim olmaksızın şablon sınıfı"
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -43520,59 +43562,59 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD şablon bildirimi geçersiz"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "şablon olmayan %q#D için şablon tanımı"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d seviye umulurken %q#D için şablon parametresi seviyesi olarak %d seviye alındı"
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "%d şablon parametresi %q#D için alındı"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%d şablon parametresi %q#T için alındı"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  ama %d gerekiyordu"
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use template<> for an explicit specialization"
 msgstr "sınıf sablonlarının kapsanması doğrudan özelleştirilmez"
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT bir şablon türü değil"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD bildiriminde şablon belirteçleri belirtilmemiş"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -43580,7 +43622,7 @@
 msgstr[0] "%qD şablon parametreleri olmaksızın kullanılmış"
 msgstr[1] "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %q+D used %d template parameter"
@@ -43588,12 +43630,12 @@
 msgstr[0] "buradaki önceki %q+#D bildirimi ile çelişiyor"
 msgstr[1] "buradaki önceki %q+#D bildirimi ile çelişiyor"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "şablon parametresi %q+#D"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "burada %q#D olarak yeniden bildirilmiş"
@@ -43602,114 +43644,114 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J  ozgun tanımı burada görüldü"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir göstericidir"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(bir üye göstericisi sadece %<&%E%> ile şekillendirilebilir)"
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "%d şablon parametresi %q#D için alındı"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "  mismatched types %qT and %qT"
 msgstr "%q#T ile %q#T türleri arasında karşılaştırma"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a base of %qT"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -43716,189 +43758,189 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "%qT türü %qT türüne dönüştürülemiyor"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT bir belirsiz %qT tabanıdır"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "%qT türü %qT türünden türetilmemiş"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qD"
 msgstr "%qT türündeki argüman %qT ile eşleşmiyor"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "  could not resolve address from overloaded function %qE"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü bu bağlamda dizge sabitler kullanılamaz"
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "in template argument for type %qT "
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "cv nitelemesinde çeliştiğinden dolayı %qE %qT türü için geçerli bir şablon argümanı değildir"
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a constant pointer"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir sabit göstericisi değildir"
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir göstericidir"
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "yerine %qE kullanmayı deneyin"
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qT türündedir"
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of constructor as a template"
 msgid "invalid use of destructor %qE as a type"
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "bir şablon parametresinin bir tür üyesine basvurmak için %<typename %E%> kullanın"
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "%2$qD için şablon parametre listesindeki %1$d. argümanda tür/değer uyumsuzluğu"
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  %qT türünde bir sabit umulurken %qT alındı"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  bir sınıf sablonu umulurken %qE alındı"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  bir tür umulurken %qE alındı"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  bir tür umulurken %qT alındı"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  bir sınıf sablonu umulurken %qT alındı"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
@@ -43906,81 +43948,81 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in nontype parameter pack"
 msgstr "koşullu ifadede tür uyumsuzluğu"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr "şablon argümanı %qE %qT'ye dönüştürülemedi"
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "%q+D için sağlanmış"
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "şablon olarak şablon olmayan tür %qT kullanılmış"
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "%q+D şablon bildirimi için"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %D"
@@ -43999,283 +44041,283 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD has initializer but incomplete type"
 msgid "variable %qD has function type"
 msgstr "%qD değişkeni ilklendiricili ama içi boş türde"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "geçersiz parametre türü %qT"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "%q+D bildiriminde"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "bir dizi döndüren işlev"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "bir işlev döndüren işlev"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye işlev göstericisi oluşturulması"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "void'e referans oluşturuluyor"
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "void türünde üyeye gösterici oluşturulması"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ne bir class, ne struct, ne de union türünde"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT bir enum türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT bir sınıf türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "şablonda %qs kullanımı"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "%qE bağımlı ismi bir tür olarak çözümlenmedi ama örneklenim onun bir tür olmasını istiyor"
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "eğer bu bir tür anlamındaysa %<typename %E%> deyin"
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "geçersiz alan %qD kullanımı"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "void ifade kullanımı geçersiz"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> kabul edeceği varsayılacak.)"
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D declared here, later in the translation unit"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ne bir sınıf ne de isim alanı"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr "%qT anonim türdür/tür kullanır"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "template argument for %qD uses local type %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT değişkene göre değişen türde"
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  %qD örneklenmeye çalışılıyor"
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "yinelenmiş doğrudan %q#D örneklenimi"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %<extern%> kullanımına izin vermez"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "şablon tanımından önce %q#T'nin doğrudan örneklenimi"
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %qE kullanımına izin vermez"
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "yinelenmiş doğrudan %q#T örneklenimi"
@@ -44287,68 +44329,68 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "bir tanımlama olmadan %qD'nin doğrudan örneklenimi"
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %q+D örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bir şablon sabiti parametresi için geçerli bir tür değildir"
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "%q+#D için ortak değişen dönüş türü geçersiz"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "%qs öykünümü mümkün değil"
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
@@ -44601,71 +44643,71 @@
 msgid "invalid base-class specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anonim union içinde protected üye %q+#D"
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not captured"
 msgstr "%qD bir şablon değil"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "iceren işlevden %<auto%> kullanımı"
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "iceren işlevden parametre kullanımı"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "%qD şablon parametresi %qT türündeyse butunleyen ya da sırali türde olmadığından bir butunleyen sabit ifadesinde kullanılmaz"
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "isim alanı %qD'nin ifade olarak kullanımı"
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "sınıf sablonu %qT'nin ifade olarak kullanımı"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "uye %qD için istek çoklu miras kafesi içinde belirsiz"
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE türü bilinmiyor"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
@@ -44672,207 +44714,207 @@
 msgstr "%qT bir şablon türü değil"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "saklatım sınıfı belirteçleri parametre bildiriminde geçersiz"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "%<restrict%> kullanımı geçersiz"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, gcc-internal-format
 msgid "%<num_teams%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "%qE has reference type for %qs"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %s"
 msgstr "CRIS-port olumlaması başarısız: "
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "%q+D statik olmayan bildirim statik bildirimi izliyor"
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "argument to decltype must be an expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
@@ -44889,130 +44931,130 @@
 msgid "lambda-expression in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "%qE özniteliği sadece Java sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr "%qE artik kullanilmiyor; g++ vtables simdi öntanımlı olarak COM-uyumludur"
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "istenen init_priority bir tamsayı sabit değil"
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "%qE özniteliği sadece sınıf türünde nesnelerin dosya bağlamı tanımlarında kullanılabilir"
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "istenen init_priority aralık dışında"
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "istenen init_priority iç kullanim için ayrilmiştir"
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
 msgstr "buradaki önceki %q+#D bildirimi ile çelişiyor"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "the %qE attribute requires arguments"
 msgstr "%qE özniteliği isimli argümanları olan prototipler gerektirir"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> geçerli bir bildirici değil"
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> geçerli bir bildirici değil"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%J%qE özniteliği sadece işlevlere uygulanır"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%J%qE özniteliği sadece işlevlere uygulanır"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "dizi sınırı bir tamsayı sabit değil"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* denetimi: %2$s dosyasının %3$d. satırındaki %1$s içinde başarısız"
@@ -45225,236 +45267,231 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr "dizi elemanlarının hizalaması eleman boyutundan büyük"
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr "ISO C++ sol yan olmayan dizi indislemesine izin vermez"
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "%<register%> olarak bildirilmiş dizi indislemesi"
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indisli değer ne dizi ne de bir gösterici"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "%qE kullanimında nesne eksik"
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ program içinden %<::main%> çağrısına izin vermez"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, fuzzy, gcc-internal-format
 #| msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "%<%E (...)%> içinde üye gösterici işlevi çağrısı için %<.*%> veya %<->*%> kullanılmalı"
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to member function %q#D"
 msgstr "%qs işlevi için argümanlar çok fazla"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to member function %q#D"
 msgstr "%qs işlevi için argümanlar çok az"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to function %q#D"
 msgstr "%qs işlevi için argümanlar çok fazla"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to function %q#D"
 msgstr "%qs işlevi için argümanlar çok az"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "işlev için çok fazla argüman belirtildi"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "işlev için çok az argüman belirtildi"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%P parametresi %qD içinde tamamlanmamış %qT türünde"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametre %P tamamlanmamış %qT türünde"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "aşırı yüklü işlevden %qT türüne dönüşüm yapildigi varsayılıyor"
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "aritmetik içinde NULL kullanımı"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "left rotate count is negative"
 msgstr "%s döngü sayısı negatif"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "right rotate count is negative"
 msgstr "%s döngü sayısı negatif"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "left rotate count >= width of type"
 msgstr "%s döngü sayısı >= tür genişligi"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "right rotate count >= width of type"
 msgstr "%s döngü sayısı >= tür genişligi"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D after first use results in unspecified behavior"
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr "%q+D zayıf bildirimi ilk kullanımdan sonra belirsiz davranışla sonuçlanıyor"
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "the address of %qD will never be NULL"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ da gösterici ile tamsayı arasında karşılaştırmaya izin verilmez"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "gerçel sayı olmayan argümanlar arasında düzenlenmemiş karşılaştırma"
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "%qT ve %qT türündeki terimler iki terimli `%qO' için geçersiz"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ bir çıkarma içinde %<void *%> türde gösterici kullanımına izin vermez"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ bir çıkartma işlemi içindeki bir işlev göstericisi kullanımına izin vermez"
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ bir çıkartma işlemi içinde bir yöntem göstericisi kullanımına izin vermez"
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "gösterici aritmetiginde tamamlanmamış ture gösterici kullanımı geçersiz"
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qE"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qE"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "%qE kullanımı üye işleve gösterici biçiminde geçersiz"
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  bir nitelemeli kimlik gerekli"
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesis around %qE cannot be used to form a pointer-to-member-function"
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
@@ -45461,379 +45498,379 @@
 msgstr "parantez icene alınmis %qE üye işleve gösterici biçiminde kullanilamaz"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ üye işleve bir gösterici şekillendirecek bir niteliksiz ya da parantezli statik olmayan üye işlevin adresinin alınmasına izin vermez.  %<&%T::%D%> denebilir."
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ üye işleve bir gösterici şekillendirecek bir sınır üye işlevin adresinin alınmasına izin vermez.  %<&%T::%D%> denebilir"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ %<::main%> işlevinin adresinin alınmasına izin vermez"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr "ISO C++ bir sol yan olmayan ifadeye dönüşüm adresi alınmasına izin vermez"
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "referans üye %qD için gösterici oluşturulamaz"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ bir göstericinin %s işlemine %qT türündeyse izin vermez"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ bir göstericinin %s işlemine %qT türündeyse izin vermez"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "terim olarak ifade geçersiz"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "bir sağ taraf ifadesi olan %<this%>'in adresi alınamaz"
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "%qD doğrudan yazmaç değişkeninin adresi istendi"
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr " %qD için adres istegi (%<register%> olarak bildirilmiş olan)"
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "%qT için ilklendirici {} içinde olmalı"
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne dönüşüm niteleyicileri iptal ediyor"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, fuzzy, gcc-internal-format
 #| msgid "%qT uses local type %qT"
 msgid "useless cast to type %qT"
 msgstr "%qT yerel tür %qT kullanıyor"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "%qT'den %qT'ye dönüşüm"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinin %qT türüne dönüşümü geçersiz"
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr "%qT'den %qT'ye tür dönüşümü hassasiyet kaybi oluşturuyor"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "%qT türünden %qT türüne dönüşüm hedef türün hizalama gereksinimini arttiriyor"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ işlev ve nesne göstericileri arasında dönüşüme izin vermez"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ne bir gösterici türü ne de bir veri üyesine gösterici türü olan %qT ile const_cast kullanımı geçersiz"
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "bir gösterici ya da bir işlev türüne referans olan %qT türü ile const_cast kullanımı geçersiz"
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ %qT dizi türüne dönüşüme izin vermez"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  %<%Q(%#T, %#T)%> nin gelisiminde"
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "%qT'nin %qT'ye atanmasında türler uyumsuz"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, fuzzy, gcc-internal-format
 #| msgid "bad array initializer"
 msgid "array used as initializer"
 msgstr "dizi ilklendirici hatalı"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "invalid array assignment"
 msgstr "atamanın sol tarafı geçersiz"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   üye işleve gösterici dönüşümünde"
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "sanal taban %qT üzerinden üye göstericisine dönüşüm"
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   üyeye gösterici dönüşümünde"
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "%qT'ye %qT'den dönüşüm geçersiz"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in return"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "%2$qE işlevinin %1$d. argümanı bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "dönüş türü bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "atamada sol taraf bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "%2$q+D işlevinin %1$P. argümanına aktarımda"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "geçiciye başvuru dönüyor"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "sag yansiz dönüşluye referans"
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr "yerel değişken %q+D'ye referans donduruldu"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %q+D returned"
 msgstr "yerel değişken %q+D adresi donduruldu"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr "yerel değişken %q+D adresi donduruldu"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "bir yıkıcıdan değer donuyor"
@@ -45840,46 +45877,46 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "bir kurucunun bir işlev deneme blokunun bir tutamagından dondurulemez"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "kurucudan bir değer dondurulemez"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "%qT donduren işlevde değer içermeyen return"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "ilklendirici yok"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "'void' dönüşlu işlevde değer içeren `return' deyimi"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%>', %<throw()%> olarak bildirilmedikce (ya da -fcheck-new etkinken) NULL donmemeli"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -46132,130 +46169,130 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr "%qE ifadesinin %qT türünden %qT türüne dönüşümü belirsiz"
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "%qE ifadesinin %qT türünden %qT türüne dönüşümü belirsiz"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "tamsayı dizisinin ilklendiricisi olarak geniş-olmayan dizge kullanılmış"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "int-array initialized from non-wide string"
 msgid "int-array initialized from incompatible wide string"
 msgstr "tamsayı dizisinin ilklendiricisi olarak geniş-olmayan dizge kullanılmış"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "karakter dizisi için dizge ilklendirici çok uzun"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "bir bileşik sabitli %qT türündeki küme ilklendirilemez"
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "ilklendirilen union içinde %qD diye bir alan yok"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "birlesik yapı ilklendiricideki alan isminin yerine index değeri"
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "döngüsel gösterici görevlendirmesi saptandi"
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> için taban terim gösterici olmayan %qT türünde"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr " %<operator->()%> gösterici olmayan sonuc veriyor"
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> için taban terim bir gösterici değil"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE bir üye göstericisi olarak kullanilamaz, cunku %qT türünde"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer %qE to %qE, which is of non-aggregate type %qT"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "uye göstericisi %qE %qE'ye kümeleme türü olmayan %qT türünde uygulanamaz"
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "%qT üye türünde gösterici nesne türü %qT ile uyumsuz"
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jreferans ture sahip %q#D'nin default ilklendirmesi"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "%qD işlevine çağrı (ici boş tür `%q#T' yakalanırken)"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "ici boş tür `%q#T' yakalanırken işleve çağrı"
@@ -46440,8 +46477,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -46588,7 +46625,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr "%C'deki karakter uzunluğu belirtiminde sözdizimi hatası"
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Type-spec at %L cannot contain a deferred type parameter"
@@ -46714,7 +46751,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) INTEGER veya PROCEDURE olmalı"
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -47385,13 +47422,13 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "%L'de 'shape' yerleşiğinin 'source' argümanı tahmini boyutlu bir dizi olmalı"
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir değişmez olmalı"
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L cannot be INTENT(IN)"
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
@@ -47678,6 +47715,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) INTEGER veya LOGICAL olmalı"
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -47685,7 +47727,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -47920,433 +47962,433 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Değişken '%s' %C'de bir ilklendirici ile zaten bir DATA deyiminde görünüyor"
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "çok boyutlu diziler ilklendiricilerle ilklendirilemez"
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "%C'deki bileşen POINTER özniteliğinde olmalı"
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Yapının dizi bileşeni %C'de dolaysız ya da ertelenmiş durumda olmalı"
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Yapının gösterici dizisi bileşeni %C'de ertelenmiş durumda olmalı"
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer array component of structure at %C must have a deferred shape"
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Yapının gösterici dizisi bileşeni %C'de ertelenmiş durumda olmalı"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Yapının dizi bileşeni %C'de dolaysız durumda olmalı"
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL() ilklendirme %C'de belirsiz"
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NULL() initialization at %C is ambiguous"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "NULL() ilklendirme %C'de belirsiz"
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "%C'deki gösterici ilklendirmesi bir PURE yordamında olamaz"
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Error in pointer initialization at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "non-NULL pointer initialization at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "Function name %qs not allowed at %C"
 msgstr "'%s' işlev ismi olarak %C'de kullanılamaz"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate array spec for Cray pointee at %C."
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Cray göstericileri için dizi belirtimi %C'de yinelenmiş"
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "%qT türündeki başvurunun %qT türündeki ifadeden ilklendirilmesi geçersiz"
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%C'deki ilklendirme bir gösterici değişkeni için değil"
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "%C'deki gösterici ilklendirmesi bir '=>' gerektirir, '=' değil"
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "%C'deki değişken ilklendirmesi bir PURE yordamında olamaz"
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "%C'deki değişken ilklendirmesi bir PURE yordamında olamaz"
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Eski tarz tür bildirimi %s*%d %C'de desteklenmiyor"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "%s*%d %C'de standartdısı tür bildirimi"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis at %C"
 msgstr "%C'de sağ parantez eksik"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "%C'de ilklendirme ifadesi umuluyordu"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "%C'deki ilklendirme ifadesinin değişmez olması umuluyordu"
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "%d. çeşit, %s türü için (%C'de) desteklenmiyor"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis or comma at %C"
 msgstr "%C'de sağ parantez eksik"
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind %d not supported for type %s at %C"
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "%d. çeşit, %s türü için (%C'de) desteklenmiyor"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "%C'deki CHARACTER bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Genişletme: %C'de BYTE türü"
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "%C'de hedef makinede desteklenmeyen BYTE türü kullanılmış"
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "%C'deki türetilmiş tür tanımının hiç bileşeni yok"
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "CLASS statement at %C"
 msgstr "%C'de umulmadık CASE deyimi"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Tür ismi '%s' %C'de belirsiz"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "%C'de IMPLICIT NONE deyimi yinelenmiş"
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "%C'deki IMPLICIT içinde karakter aralığı eksik"
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "%C'deki IMPLICIT deyiminde harfler alfabetik sırada olmalı"
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "%C'deki SAVE deyiminden önce bir kapsamlı SAVE deyimi var"
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting list of named entities at %C"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in %s statement at %C"
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "%s deyiminde sözdizimi hatası (%C'de)"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "Missing codimension specification at %C"
 msgstr "%C'de boyut belirtimi eksik"
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "%C'de boyut belirtimi eksik"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "%s özniteliği %L'de yinelenmiş"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute at %L is not allowed outside of a MODULE"
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s özniteliği ('%L'de) bir MODULE dışında kullanılamaz"
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "PROTECTED attribute at %C"
 msgstr "%s özniteliği %L'de yinelenmiş"
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "VALUE attribute at %C"
 msgstr "%C'deki satır kırpıldı"
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de dizi değerli olamaz"
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be a statement function"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -48354,300 +48396,300 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing generic specification in USE statement at %C"
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "%C'deki USE deyiminde soysal belirtim eksik"
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "sayı eksik"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition."
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "%C'deki türetilmiş tür evvelce tanımlanmış olmamalıydı, bu durumda bir türetilmiş tür tanımı içinde görünemez"
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "IMPURE procedure at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "%C'de diğer return yaftası umuluyordu"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "İsim '%s' %C'de işlev ismidir"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Sembol '%s' %C'deki biçimsel argüman listesinde yinelenmiş"
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "%C'deki RESULT değişkeninin ismi işlev isminden farklı olmalı"
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "%L'deki SAVE özniteliği bir PURE yordamında belirtilemez"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Procedure pointer component at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in structure constructor at %C"
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "%C'deki yapı kurucuda söz dizimi hatası"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "%C'deki MODULE PROCEDURE bir soysal modül arayüzü olmalı"
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "%C'deki işlev tanımında biçimsel argüman listesi umuluyordu"
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "%C'deki ENTRY deyimi bir PROGRAM içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "%C'deki ENTRY deyimi bir MODULE içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "%C'deki ENTRY deyimi bir BLOCK DATA içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "%C'deki ENTRY deyimi bir DERIVED TYPE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "%C'deki ENTRY deyimi bir IF-THEN bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "%C'deki ENTRY deyimi bir DO bloku içinde görünemez"
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "%C'deki ENTRY deyimi bir SELECT bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "%C'deki ENTRY deyimi bir FORALL bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "%C'deki ENTRY deyimi bir WHERE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "%C'deki ENTRY deyimi bir içerilmiş altyordamın içinde görünemez"
 
-#: fortran/decl.c:5597
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
-msgid "gfc_match_entry(): Bad state"
-msgstr "gfc_trans_code(): Hatalı deyim kodu"
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Unexpected END statement at %C"
+msgid "Unexpected ENTRY statement at %C"
+msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%C'deki ENTRY deyimi bir içerilmiş işlevde görünemez"
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing closing paren for binding label at %C"
 msgstr "%C'de biçim yaftası eksik"
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "'%s' işlev ismi olarak %C'de kullanılamaz"
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot follow %s statement at %L"
 msgid "END statement instead of %s statement at %L"
@@ -48654,567 +48696,573 @@
 msgstr "%s deyimi (%C'deki), %s deyimini (%L'deki) izlemiyor"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "'%s' için %s deyiminde (%C'de) blok ismi umuluyordu"
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "'%s' etiketi umuluyordu (%s deyiminde, %C'de)"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "DIMENSION deyiminde %L'de dizi belirtimi eksik"
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr ""
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing array specification at %L in DIMENSION statement"
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "DIMENSION deyiminde %L'de dizi belirtimi eksik"
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Dizi belirtimi %L'de ertelenmiş olmalı"
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "%C'deki değişken listesinde umulmadık karakter"
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "%C'de değişken ismi umuluyordu"
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "Cray pointer at %C must be an integer"
 msgstr "%C'deki Cray göstericisi bir tamsayı olmalı."
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes."
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "%C'deki Cray göstericisi %d baytlık hassasiyete sahip ancak bellek adresi %d bayt gerektiriyor"
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "%C'de \",\" umuluyordu"
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "%C'de \")\" umuluyordu"
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%C'de \",\" veya deyim sonu umuluyordu"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer declaration at %C requires -fcray-pointer flag."
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "%C'deki Cray göstericisi bildirimi -fcray-pointer seçeneğini gerektiriyor"
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "%s işlecinin erişim belirtimi %C'de zaten belirtilmişti"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ".%s. işlecinin erişim belirtimi %C'de zaten belirtilmişti"
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "%C'de DATA deyimi için bir PURE işlevinde izin verilmez"
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "%C'de DATA deyimi için bir PURE işlevinde izin verilmez"
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "%C'de PARAMETER deyiminde değişken ismi umuluyordu"
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "%C'deki PARAMETER deyiminde = işareti umuluyordu"
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "%C'deki PARAMETER deyiminde ifade umuluyordu"
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initializer not allowed for COMMON variable '%s' at %C"
 msgid "Initializing already initialized variable at %C"
 msgstr "COMMON değişkeni `%s' için %C'de ilklendirme yapılamaz"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "%C'deki PARAMETER deyiminde umulmayan karakterler"
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "%C'deki kapsamlı SAVE deyiminden önce bir SAVE deyimi var"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "%C'deki SAVE deyiminden önce bir kapsamlı SAVE deyimi var"
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VALUE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "%C'deki MODULE PROCEDURE bir soysal modül arayüzü olmalı"
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected :: in TYPE definition at %C"
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "%C'deki TYPE tanımında :: umuluyordu"
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "'%s' simgesi (%C'deki) zaten konakla ilişkiliymiş"
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qD evreye yerel olamaz çünkü POD olmayan %qT türünde"
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PRIVATE within a MODULE"
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "%C'deki türetilmiş tür sadece bir MODULE içinde PRIVATE olabilir"
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PUBLIC within a MODULE"
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "%C'deki türetilmiş tür sadece bir MODULE içinde PUBLIC olabilir"
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "%C'deki TYPE tanımında :: umuluyordu"
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Tür ismi '%s' (%C'de) bir yerleşik türle aynı olamaz"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Türetilmiş tür ismi '%s' %C'de zaten temel  %s türünde"
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "'%s' için türetilmiş tür tanımı %C'de zaten tanımlı"
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "%C'deki Cray göstericileri tahmini biçimli dizi olamaz"
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "New in Fortran 2003: ENUM AND ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003'te yeni: %C'de ENUM AND ENUMERATOR"
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Sayısal sabitler %C'de C tamsayı türünü aşıyor"
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "bir tamsayı ifadesi ile ilklendirilmemiş ENUMERATOR %L"
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "%C öncesinde ENUM tanım deyimi umuluyordu"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "%C'deki ENUMERATOR tanımında sözdizimi hatası"
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate access-specifier at %C"
 msgstr "%s belirtimi %C'de yinelenmiş"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate POINTER attribute at %C"
 msgstr "%s özniteliği %L'de yinelenmiş"
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "%C'de VARIABLE umuluyordu"
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "Duplicate DEFERRED at %C"
 msgstr "%C'de SEQUENCE deyimi yinelenmiş"
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a nameless interface at %C"
 msgid "Expected access-specifier at %C"
 msgstr "%C'de isimsiz bir arayüz umuluyordu"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding attribute at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, fuzzy, gcc-internal-format
 #| msgid "identifier expected after %<@protocol%>"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "%<)%> expected at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding name at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "%C'de dizi indisi umuluyordu"
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Invalid form of PROGRAM statement at %C"
+msgid "Malformed GENERIC statement at %C"
+msgstr "%C'deki PROGRAM deyiminin biçimi geçersiz"
+
+#: fortran/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected specific binding name at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Empty FINAL at %C"
 msgstr "%C'de VARIABLE umuluyordu"
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Expected module procedure name at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "%C'de \",\" umuluyordu"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 #| msgid "procedure name = %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, fuzzy, gcc-internal-format
 #| msgid "%s procedure at %L is already declared as %s procedure"
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "%s yordamı %L'de zaten %s yordamı olarak bildirilmiş"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RESULT attribute required in ENTRY statement at %C"
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C'deki ENTRY deyimi bir RESULT özniteliği gerektirir"
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
@@ -49528,370 +49576,370 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "%s için %L'de %d. boyutta biçim farklı (%d/%d)"
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a VALUE"
 msgid "%qs at %L is not a VALUE"
 msgstr "'%s' %L'de bir VALUE değil"
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "%d ve %d sıraları uyumsuz (%L'deki atamada)"
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "%L'deki atamada değişken UNKNOWN türünde"
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "NULL %L'deki atamanın sağ tarafında görünüyor"
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "POINTER valued function appears on right-hand side of assignment at %L"
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "POINTER değerli işlev %L'deki atamanın sağ tarafında görünüyor"
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "%s den %s e dönüşüm (%L'de)"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: Conversion from %s to %s at %L"
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "Ek: %s den %s e dönüşüm (%L'de)"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Conversion from %qs to %qs at %L"
 msgstr "%s den %s e dönüşüm (%L'de)"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible types in assignment at %L, %s to %s"
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "%L'deki atamada uyumsuz türler, %s den %s'e"
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "%L'deki gösterici atamasının hedefi bir POINTER değil"
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "'%s' (%L'deki gösterici atamasındaki) bir yordam olduğundan bir sol taraf değeri olamaz"
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "%s belirtimi %C'de yinelenmiş"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, fuzzy, gcc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack size must not be greater than 64k"
 msgid "Stride must not be present at %L"
 msgstr "yığıt boyutu 64k'dan büyük olmamalıdır"
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Harici nesne '%s'  %L'de bir ilklendiriciye sahip olamayabilir"
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' requires argument list at %C"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "'%s' deyim işlevi %C'de argüman listesi gerektiriyor"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "%qs sınıfı için birden fazla arabirim bildirimi"
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "%L'deki gösterici atamasında farklı karakter uzunlukları"
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı sıralamalar"
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "%L'deki gösterici atamasının hedefi bir POINTER değil"
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "%L'deki gösterici atamasının hedefi ne TARGET ne de POINTER"
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "%L'deki PURE yordamdaki gösterici atamasında hedef berbat"
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "%L'de sağ tarafta vektör indisli gösterici ataması"
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "%L'deki gösterici atamasının hedefi bir POINTER değil"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data target at %L shall not have a coindex"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "%C'deki gösterici ilklendirmesi bir '=>' gerektirir, '=' değil"
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "%C'deki bileşen POINTER özniteliğinde olmalı"
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Nesne '%s' (%L'de), %s SAVE özniteliğine sahip olmalı"
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "girdi dosyası açılamıyor: %s"
@@ -49915,30 +49963,30 @@
 msgid "Removing call to function %qs at %L"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
@@ -49998,643 +50046,649 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr "%C'de 'END INTERFACE ASSIGNMENT (=)' umuluyordu"
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (%s)' at %C"
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr "'END INTERFACE OPERATOR (%s)' umuluyordu (%C'de)"
+
+#: fortran/interface.c:353
+#, fuzzy, gcc-internal-format
+#| msgid "Expecting 'END INTERFACE OPERATOR (%s)' at %C"
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr "'END INTERFACE OPERATOR (%s)' umuluyordu (%C'de)"
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr "'END INTERFACE OPERATOR (.%s.)' umuluyordu (%C'de)"
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE %s' at %C"
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr "END INTERFACE %s' umuluyordu (%C'de)"
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr "%L'deki altyordam çağrısında diğer return belirtimi eksik"
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Operator interface at %L must have, at most, two arguments"
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr "%L'deki işleç arayüzünün en fazla iki argümanı olmalı"
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr "%L'deki işleç arayüzü yanlış sayıda argüman içeriyor"
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr "%L'deki atama işleci arayüzü bir SUBROUTINE olmalıdır"
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr "%L'deki atama işleci arayüzü bir SUBROUTINE olmalıdır"
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr "%L'deki yerleşik işleç arayüzü bir FUNCTION olmalıdır"
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of defined assignment at %L must be INTENT(IN) or INTENT(INOUT)"
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr "%L'de tanımlanmış atamanın ilk argümanı INTENT(IN) veya INTENT(INOUT) olmalıdır"
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L'de tanımlanmış atamanın ikinci argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr "%L'deki işleç arayüzü yerleşik arayüz ile çelişiyor"
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr "'%s' simgesi %L'de zaten bir aleni arayüze sahip"
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr "'%s' yordamı (%s içinde, %L'de) be işlev ne de altyordam"
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs in %s at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, fuzzy, gcc-internal-format
 #| msgid "Ambiguous interfaces '%s' and '%s' in %s at %L"
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr "'%s' ve '%s' arayüzleri (%s içinde, %L'de) belirsiz"
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, fuzzy, gcc-internal-format
 #| msgid "reference %qs is ambiguous: appears in interface %qs and interface %qs"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "referans %qs belirsiz: %qs ve %qs arayüzlerinde görünüyor"
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "%qs at %L is not a module procedure"
 msgstr "İsim '%s' %C'de işlev ismidir"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid third argument of IBITS at %L"
 msgid "Invalid procedure argument at %L"
 msgstr "%L'de IBITS'in üçüncü argümanı geçersiz"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "`%s' argümanı (%L'de) tek uzunluk olmalı"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "`%s' ve '%s' argümanları `%s' yerleşiği için  (%L'de) aynı türde olmalı"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "`%s' argümanı (%L'de) tek uzunluk olmalı"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Anahtar sözcük argümanı '%s' (%L'de) başka bir fiili argümanla zaten ilişkili"
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "%L'deki yordam çağrısında biçimselden daha gerçekçi argümanlar"
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "%L'deki altyordam çağrısında diğer return belirtimi eksik"
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr "%L'deki altyordam çağrısında umulmadık diğer return belirtimi"
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "'%s' için fiili argüman (%L'de) bir tahmini boyutlu dizi olamaz"
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Argüman '%s' için fiili argüman eksik (%L'de)"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "INTENT(%s) ile '%s' argümanı ve INTENT(%s) ile '%s' argümanı aynı fiili argüman ile ilişkilendirilmiş"
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "%L'deki yordam argümanı bir PURE yordamına yerel olup POINTER özniteliğine sahiptir"
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "%L'deki yordam argümanı bir PURE yordamına yerel olup bir INTENT(%s) argümanına aktarılmıştır"
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "%L'deki yordam argümanı bir PURE yordamına yerel olup bir INTENT(%s) argümanına aktarılmıştır"
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "'%s' simgesi %L'de zaten bir aleni arayüze sahip"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "MOLD argument to NULL required at %L"
 msgstr "`%s' yerleşiği için (%L'de) argümanlar eksik"
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qs"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D tanımsız %qs simgesine rumuzlu"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "'%s' öğesi (%C'de) zaten arayüzde mevcut"
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr "%s den %s e dönüşüm yapılamaz (%L'de)"
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "Bir PURE yordamında içerilmiş '%s' yordamının kendisi de PURE olmalı"
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "Bir PURE yordamında içerilmiş '%s' yordamının kendisi de PURE olmalı"
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
@@ -51097,13 +51151,13 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "DECIMAL= at %C not allowed in Fortran 95"
@@ -51115,7 +51169,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "ROUND= at %C not allowed in Fortran 95"
@@ -51144,843 +51198,843 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "PURE yordamda %s deyimine izin verilmez (%C'de)"
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: FLUSH statement at %C"
 msgid "FLUSH statement at %C"
 msgstr "Fortran 2003: %C'de FLUSH deyimi"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "%C'de UNIT belirtimi yinelenmiş"
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "%C'de biçim belirtimi yinelenmiş"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "'%s' simgesi '%s' isim alanında INTENT(IN)'dir (%C'de)"
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "%C'de NML belirtimi yinelenmiş"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C must be a NAMELIST group name"
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "'%s' simgesi %C'de bir NAMELIST grup ismi olmalıdır"
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-I- specified twice"
 msgid "UNIT not specified at %L"
 msgstr "-I- iki kere belirtilmiş"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "%L'deki UNIT belirtimi ya bir INTEGER ifadesi ya da bir CHARACTER değişkeni olmalıdır"
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "%C'deki PROGRAM deyiminin biçimi geçersiz"
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "%L'de vektör indisli iç birim"
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "Harici IO UNIT %L'de bir dizi olamaz"
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Comma before output item list at %C is an extension"
 msgid "Comma before i/o item list at %L"
 msgstr "EK: %C'deki çıktı öğe listesinden önceki virgül bir ifadedir"
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR etiketi %d. yaftada (%L'de) tanımsız"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END etiketi %d. yaftada (%L'de) tanımsız"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR etiketi %d. yaftada (%L'de) tanımsız"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT etiketi %d. yaftada (%L'de) tanımsız"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "%C'deki G/C yineleyicide sözdizimi hatası"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "%C'deki READ deyiminde değişken umuluyordu"
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "%s deyiminde ifade umuluyordu (%C'de)"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s deyiminde sözdizimi hatası (%C'de)"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic at %L does not exist"
 msgid "Internal file at %L with namelist"
 msgstr "%L'deki yerleşik mevcut değil"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "%s'in KIND parametresi %L'de bir ilklendirme ifadesi olmalıdır"
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "%C'de PRINT isim listesi bir ifadedir"
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "%C'deki G/C listesinde virgül umuluyordu"
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "%C'deki PRINT deyimi PURE yordamı içinde olamaz"
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "%C'deki INQUIRE deyimi PURE yordamı içinde olamaz"
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "%C'deki IOLENGTH etiketi INQUIRE deyimi içinde geçersiz"
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "%L'deki INQUIRE deyimi hem FILE hem de UNIT belirtecini içeremez"
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "%L'deki INQUIRE deyimi ya FILE ya da UNIT belirteci gerektir"
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L cannot be %s"
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr "%L'deki SELECT deyiminin argümanı %s olamaz"
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "%L'deki INQUIRE deyimi ya FILE ya da UNIT belirteci gerektir"
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "PURE yordamda %s deyimine izin verilmez (%C'de)"
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_op2string(): Bad code"
 msgstr "gfc_trans_code(): Hatalı deyim kodu"
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 #| msgid "ENUM definition statement expected before %C"
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "%C öncesinde ENUM tanım deyimi umuluyordu"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 #| msgid "ENUM definition statement expected before %C"
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "%C öncesinde ENUM tanım deyimi umuluyordu"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr "%C'deki tamsayı çok büyük"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "%C'deki deyim etiketinde çok fazla rakam var"
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr "%C'deki deyim etiketi sıfırdır"
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 #| msgid "Label name '%s' at %C is ambiguous"
 msgid "Label name %qs at %C is ambiguous"
 msgstr "Yafta ismi '%s' (%C'de) belirsiz"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Duplicate construct label %qs at %C"
 msgstr "Oluşum yaftasi '%s' (%C'de) yinelenmiş"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad character '%c' in OPERATOR name at %C"
 msgid "Invalid character in name at %C"
 msgstr "OPERATOR isminde '%c' karakteri geçersiz (%C'de)"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr "%C'de isim çok uzun"
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr ""
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a sub-component"
 msgid "Loop variable at %C cannot be a coarray"
 msgstr "%C'deki döngü değişkeni bir alt bileşen olamaz"
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr "%C'deki döngü değişkeni bir alt bileşen olamaz"
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr "%C'deki yineleyicide bir adım değeri umuluyordu"
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr "%C'deki yineleyicide sözdizimi hatası"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_match(): Bad match code %c"
 msgstr "gfc_trans_code(): Hatalı deyim kodu"
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr "%C'deki PROGRAM deyiminin biçimi geçersiz"
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: arithmetic IF statement at %C"
 msgid "Arithmetic IF statement at %C"
 msgstr "Atıl: %C'deki aritmetik IF deyimi"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr "%C'deki IF ifadesinde sözdizimi hatası"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr "Blok yaftası %C'deki aritmetik IF deyimi için uygun değil"
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Block label is not appropriate IF statement at %C"
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr "Blok yaftası %C'deki IF deyimi için uygun değil"
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cannot assign to a PARAMETER variable at %C"
 msgid "Cannot assign to a named constant at %C"
 msgstr "%C'de bir PARAMETER değişken atanamaz"
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr "%C'deki IF deyiminde tasnif edilemeyen deyim"
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr "%C'deki IF deyiminde sözdizimi hatası"
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match IF label '%s'"
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "Yafta '%s' IF yaftası '%s' ile eşleşmiyor (%C'de)"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr "%C'deki ELSE IF deyiminden sonra umulmadık dotuntu"
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr "%C'deki PRINT deyimi PURE yordamı içinde olamaz"
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "CRITICAL statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Nested CRITICAL block at %C"
 msgstr "%C'de VARIABLE umuluyordu"
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected comma in I/O list at %C"
 msgid "Expected association list at %C"
 msgstr "%C'deki G/C listesinde virgül umuluyordu"
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "Expected association at %C"
 msgstr "%C'de dizi indisi umuluyordu"
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate name %qs in association at %C"
 msgstr "%s belirtimi %C'de yinelenmiş"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "'%s' sabit nesnesi %L'de ALLOCATABLE olmayabilir"
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Invalid type-spec at %C"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "%C'deki FORALL yineleyicisinde sözdizimi hatası"
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "İsim '%s' %s deyimi içindeki bir döngü ismi değil (%C'de)"
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "İsim '%s' %s deyimi içindeki bir döngü ismi değil (%C'de)"
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "%s statement at %C is not within a construct"
 msgstr "%s deyimi bir döngü içinde değil (%C'de)"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "%s statement at %C is not within construct %qs"
 msgstr "%s deyimi '%s' döngüsü içinde değil (%C'de)"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "%s deyimi '%s' döngüsü içinde değil (%C'de)"
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "%s deyimi '%s' döngüsü içinde değil (%C'de)"
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "%s deyimi (%C'deki), bir bloksuz DO döngüsünü sonlandıramaz"
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "%s deyimi bir döngü içinde değil (%C'de)"
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "%s deyimi (%C'deki), bir bloksuz DO döngüsünü sonlandıramaz"
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement at %C in PURE procedure"
 msgstr "PURE yordamda %s deyimine izin verilmez (%C'de)"
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "%L'de dizi indisi INTEGER türünde olmalıdır"
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be scalar"
 msgid "STOP code at %L must be scalar"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "%C'deki Cray göstericisi bir tamsayı olmalı."
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "PAUSE statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ERROR STOP statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "%C'deki PRINT deyimi PURE yordamı içinde olamaz"
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "LOCK statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "UNLOCK statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "%C'deki PRINT deyimi PURE yordamı içinde olamaz"
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "SYNC statement at %C"
 msgstr "%C'de SEQUENCE deyimi yinelenmiş"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: ASSIGN statement at %C"
 msgid "ASSIGN statement at %C"
 msgstr "Atıl: %C'deki ASSIGN deyimi"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: Assigned GOTO statement at %C"
 msgid "Assigned GOTO statement at %C"
 msgstr "Atıl: %C'deki atanmış GOTO deyimi"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "%C'de GOTOdaki deyim yaftası listesi boş olamaz"
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad allocate-object in ALLOCATE statement at %C for a PURE procedure"
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "PURE yordam için ALLOCATE deyiminde hatalı yer ayırma nesnesi (%C'de)"
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "%qT üye türünde gösterici nesne türü %qT ile uyumsuz"
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "%C'deki tahmini boyutlu dizi için belirtim hatalı"
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "%C'deki boş BLOCK DATA %L'deki önceki BLOCK DATA ile çelişiyor"
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal deallocate-expression in DEALLOCATE at %C for a PURE procedure"
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "%C'deki DEALLOCATEde PURE yordamı için kuraldışı yer açma ifadesi"
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "%C'deki diğer RETURN deyimine sadece bir SUBROUTINE içinde izin verilir"
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: RETURN statement in main program at %C"
 msgid "RETURN statement in main program at %C"
 msgstr "Ek: %C'deki main programı içinde RETURN deyimi"
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Expected component reference at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "%C'deki ortak blok isminde sözdizimi hatası"
@@ -51988,162 +52042,162 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr ""
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "'%s' simgesi (%C'deki) zaten bir COMMON blokundadır"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "Array specification for symbol '%s' in COMMON at %C must be explicit"
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "COMMON içindeki '%s' simgesi için dizi belirtimi örtük olmamalıdır (%C'de)"
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in COMMON at %C cannot be a POINTER array"
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "COMMON içindeki '%s' simgesi bir POINTER dizisi olamaz (%C'de)"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s', in COMMON block '%s' at %C is being indirectly equivalenced to another COMMON block '%s'"
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "'%s' simgesi, '%s' COMMON blokunda dolaylı olarak başka bir '%s' COMMON blokuna eşdeğer oluyor (%C'de)"
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already has a basic type of %s"
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "'%s' isim listesi grup ismi (%C'de) zaten bir temel %s türüne sahip"
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already is USE associated and cannot be respecified."
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "'%s' isim listesi grup ismi (%C'de) zaten USE ile ilişkili olup yeniden ilişkilendirilemez"
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'de)."
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "%C'deki türetilmiş tür bileşeni izin verilmiş bir EQUIVALENCE üyesi değildir"
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "EQUIVALENCE içindeki dizi başvurusu bir dizi bölümü olamaz (%C'de)"
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "%C'deki EQUIVALENCE iki veya daha fazla nesne gerektirir"
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "COMMON blokları %s ve %s, EQUIVALENCE tarafından %C'de dolaylı olarak üstüste bindirilmeye çalışılıyor"
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected comma in I/O list at %C"
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "%C'deki G/C listesinde virgül umuluyordu"
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "%L'deki deyim işlevi iç içe"
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement function at %L is recursive"
 msgid "Statement function at %C"
 msgstr "%L'deki deyim işlevi iç içe"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "%C'deki CASE'de ilklendime ifadesi umuluyordu"
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "'%s' için %s deyiminde (%C'de) blok ismi umuluyordu"
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "%C'de umulmadık CASE deyimi"
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CASE specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "%C'deki ELSEWHERE deyimi WHERE bloku içinde değil"
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -52300,182 +52354,182 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "İsim listesinin ismi %s USE ilişkisiyle %s yapılamaz"
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Başvurulan '%s' simgesi (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, fuzzy, gcc-internal-format
 #| msgid "User operator '%s' referenced at %L not found in module '%s'"
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Başvurulan '%s' işleci (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Başvurulan '%s' yerleşik işleci (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Modül dosyası`%s' yazmak için açılamıyor (%C'de): %s"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Modül dosyası `%s' yazmak için açılırken hata: %s"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file '%s': %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: `%s' silinemiyor: %s\n"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Modül dosyası`%s' yazmak için açılamıyor (%C'de): %s"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete aux info file '%s': %s\n"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: yardımcı bilgi dosyası `%s' silinemiyor: %s\n"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs already declared"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Başvurulan '%s' simgesi (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Başvurulan '%s' simgesi (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "%s deyimi bir döngü içinde değil (%C'de)"
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Modül dosyası`%s' okumak için açılamıyor (%C'de): %s"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr "Bizim oluşturduğumuz modülün aynısı (USE olamaz)/kullanılamaz!?"
@@ -52800,7 +52854,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki IF deyimi bir sabit LOGICAL ifadesi gerektirir"
@@ -53543,392 +53597,386 @@
 msgid "Unexpected %s statement at %C"
 msgstr "Umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:2428
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected %s statement in MODULE at %C"
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr "MODULE içinde umulmadık %s deyimi (%C'de)"
-
-#: fortran/parse.c:2439
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "%s deyimi (%C'deki), %s deyimini (%L'deki) izlemiyor"
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "'%s' de umulmadık dosya sonu"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement in CONTAINS section at %C"
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "CONTAINS bölümünde umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement in CONTAINS section at %C"
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "CONTAINS bölümünde umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "FINAL procedure declaration at %C"
 msgstr "%qs'in önceki bildirimi"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "%C'deki türetilmiş tür tanımının hiç bileşeni yok"
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "%C'de TYPEdeki PRIVATE deyimi bir MODULE içinde olmalı"
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRIVATE statement at %C must precede structure components"
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "%C'deki PRIVATE deyimi yapı elemanlarını öncelemelidir"
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SEQUENCE statement at %C must precede structure components"
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "%C'de SEQUENCE deyimi yapı bileşenlerini öncelemelidir"
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENUM declaration at %C has no ENUMERATORS"
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "%C'de ENUM bildirimi hiç ENUMERATORS içermiyor"
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Derived type definition at %C without components"
 msgstr "%C'deki türetilmiş tür tanımının hiç bileşeni yok"
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "%C'deki PRIVATE deyimi yapı elemanlarını öncelemelidir"
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "%C'de SEQUENCE deyimi yapı bileşenlerini öncelemelidir"
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "%C'de SEQUENCE deyimi zaten TYPE deyiminde belirtilmiş"
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "%C'de SEQUENCE deyimi yinelenmiş"
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "%C'de ENUM bildirimi hiç ENUMERATORS içermiyor"
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "INTERFACE blokunda umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "Tür ismi '%s' (%C'de) bir yerleşik türle aynı olamaz"
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "INTERFACE gövdesinde umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "İsim '%s' %C'de işlev ismidir"
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "PURE yordamda %s deyimine izin verilmez (%C'de)"
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "PURE yordamda %s deyimine izin verilmez (%C'de)"
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement must appear in a MODULE"
 msgid "%s statement must appear in a MODULE"
 msgstr "%S deyimi bir MODULE'de görünmemeli"
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "%s deyimi başka erişilebilirlik belirtimini izliyor (%C'de)"
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "Bad kind expression for function %qs at %L"
 msgstr "%qs işlevi için geçersiz saklama sınıfı"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, fuzzy, gcc-internal-format
 #| msgid "Alternate return specifier in function '%s' at %L is not allowed"
 msgid "The type for function %qs at %L is not accessible"
 msgstr "'%s' işlevinde diğer return belirtecine %L'de izin verilmiyor"
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "ELSEWHERE deyimi önceki masksız ELSEWHERE'i izliyor (%C'de)"
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "WHERE blokunda umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "FORALL blokunda umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "%C'deki ELSE IF deyimi %L'deki ELSE deyimini izleyemez"
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "%L ve %C'de yinelenmiş ELSE deyimi"
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "%C'deki SELECT CASE'i umulmadık bir CASE veya END SELECT deyimi izliyor"
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "%C'deki SELECT CASE'i umulmadık bir CASE veya END SELECT deyimi izliyor"
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "%C'de bloksuz DO deyiminin sonu diğer bloğun içindedir"
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "%C'de bloksuz DO deyiminin sonu diğer DO döngüsü ile arabağlantılıdır"
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "%C'de ENDDO'daki deyim yaftası DO yaftası ile uyuşmuyor"
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "BLOCK construct at %C"
 msgstr "Kurucu %s olmayabilir"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "%C'de ENDDO'daki deyim yaftası DO yaftası ile uyuşmuyor"
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s at %C"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "%s deyimi (%C'deki), bir bloksuz DO döngüsünü sonlandıramaz"
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORMAT statement at %L does not have a statement label"
 msgid "DATA statement at %C after the first executable statement"
 msgstr "%L'deki FORMAT deyimi bir deyim yaftası içermiyor"
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %C is already ambiguous"
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "İçerilmiş yordam '%s' zaten belirsiz (%C'de)"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "CONTAINS bölümünde umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "%C'deki CONTAINS bölümü zaken içerilmiş bir program birimidir"
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr "Genel isim '%s' (%L'de), zaten %s (%L'de) olarak kullanılıyor"
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr "Genel isim '%s' (%L'de), zaten %s (%L'de) olarak kullanılıyor"
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "%C'deki boş BLOCK DATA %L'deki önceki BLOCK DATA ile çelişiyor"
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "BLOCK DATA içinde umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "MODULE içinde umulmadık %s deyimi (%C'de)"
@@ -53936,7 +53984,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "%L ve %C'de iki ana PROGRAM"
@@ -54706,7 +54754,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Yafta %d (%L'de başvurulu) hiç tanımlanmamış"
@@ -54768,398 +54816,398 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL INTRINSIC olmayan '%s' yordamına %L'de bir fiili argüman olarak izin verilmez"
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "%2$qs sayacı okunurken %1$qs işlevi için kapsanma çelişkisi"
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "'%s' özel işlevi (%L'de) çözümlenemiyor"
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Soysal işlev '%s' (%L'de) belirli bir yerleşik arayüz ile uyumlu değil"
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "İşlev '%s' (%L'de) bir INTRINSIC ama bir yerleşik ile uyumlu değil"
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "'%s' özel işlevi (%L'de) çözümlenemiyor"
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, fuzzy, gcc-internal-format
 #| msgid "Function reference to '%s' at %L is inside a FORALL block"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "'%s' için işlev başvurusu %L'de bir FORALL blokunun içindedir"
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot write to internal file unit '%s' at %C inside a PURE procedure"
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "PURE yordamının içinde dahili dosya birimi '%s' yazılamıyor (%C'de)"
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qs at %L is not a function"
 msgstr "%q+D bir işlev değil,"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "'%s' işlevi CHARACTER(*) bildirimli olup, bir sözde argüman olmadığından %L'de kullanılamaz"
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "'%s' (%L'de bir FORALL blokunun içindeki) için altyordam başvurusu PURE değil"
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "'%s' (%L'de bir FORALL blokunun içindeki) için altyordam başvurusu PURE değil"
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "'%s' (%L'de) için altyordam başvurusu PURE değil"
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Özel altyordam '%s' %L'de çözümlenemiyor"
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Soysal işlev '%s' (%L'de) bir yerleşik altyordam arayüzü ile uyumlu değil"
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Altyordam '%s' (%L'de) bir INTRINSIC ama bir yerleşik ile uyumlu değil"
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Özel altyordam '%s' %L'de çözümlenemiyor"
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr "'%s' (%L'deki) %L'deki CALL ile uyumlu olmayan bir türe sahip"
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "%L ve %L'de terimlerin biçimleri benzer değil"
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L'de sıfır adım uzunluğu kuraldışı"
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "dizi başvurusunda altindis yok"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Tahmini boyutlu dizi bölümünün en sağ üst sınırı %L'de belirtilmemiş"
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L'de dizi başvurusunda sıra uyumsuz (%d/%d)"
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L'de dizi başvurusunda sıra uyumsuz (%d/%d)"
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%L'de dizi indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Ek: %L'de REAL dizi indisi"
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L'de boyut argümanı INTEGER türünde olmalı"
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L'deki dizi indisi %d. mertebeden bir dizidir"
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L'deki altdizge başlangıç indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L'deki altdizge başlangıç indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L'deki altdizge başlangıç indisi birden küçük olmalıdır"
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L'deki altdizge son indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L'deki altdizge son indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L exceeds the string length"
 msgstr "%L'deki altdizge son indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "%L'deki altdizge son indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L'de hatalı dizi başvurusu"
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Sıfırdan farklı bir mertebeden bir parça başvurusunun sağ bileşeni %L'de POINTER özniteliğinde olmamalıdır"
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Sıfırdan farklı bir mertebeden bir parça başvurusunun sağ bileşeni %L'de POINTER özniteliğinde olmamalıdır"
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "%L'de sıfırdan farklı bir mertebeden iki veya daha fazla parça başvurusu belirtilmemelidir"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -55169,12 +55217,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -55184,63 +55232,63 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "%s' etiketi (%L'de) bir değişmez olmalı"
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
@@ -55247,198 +55295,198 @@
 msgstr "Öğesel yordamın '%s' argümanı değişmez olmalı (%L'de)"
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "İfade türü umuluyordu"
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL başlatma ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL son ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L'deki FORALL adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L'de ALLOCATE deyimindeki ifade ya bir POINTER ya da ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "%L'deki UNIT belirtimi ya bir INTEGER ifadesi ya da bir CHARACTER değişkeni olmalıdır"
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -55447,124 +55495,124 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L'deki CASE etiketi ile %L'deki CASE etiketi birbirinin üzerine taşıyor"
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L'de CASE deyimindeki ifade %d. çeşit olmalı"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L'de CASE deyimindeki ifade bir değişmez olmalı"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L'deki SELECT deyiminin argümanı %s olamaz"
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L'deki DEFAULT CASE deyiminden sonra %L'de ikinci bir DEFAULT CASE olamaz"
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L'deki aralık belirtimi asla eşleşmeyebilir"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L'deki mantıksal SELECT CASE blokunun ikiden fazla case'i var"
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Türetilmiş tür ismi '%s' %C'de zaten temel  %s türünde"
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Umulmadık %s deyimi (%C'de)"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
@@ -55571,81 +55619,81 @@
 msgstr "%s için %L'deki çeşit geçersiz"
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L'deki veri aktarım elemanı tahmini boyutlu bir diziye bir tam başvuru olamaz"
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L'deki ACOS argümanı -1 .. 1 arasında olmalı"
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L'deki deyim %L'deki dallanma deyimi için geçerli bir dallanma hedef deyimi değildir"
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -55653,12 +55701,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -55666,167 +55714,167 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L'deki WHERE maskesi uyumsuz biçimde"
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L'deki WHERE atama hedefi uyumsuz biçimde"
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L'deki WHERE içinde desteklenmeyen deyim"
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "'%s' indisli FORALL %L'de bu nesneye birden fazla atamaya sebep oluyor"
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Bir dış FORALL oluşumu zaten bu isimde bir indise sahip (%L'de)"
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L'deki WHERE/ELSEWHERE deyimi bir değişmez LOGICAL dizisi gerektirir"
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr ""
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "%L'deki atamanın sağ tarafı bir PURE yordamda bir POINTER içeren türetilmiş bir türdür"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "%L'deki atamanın sağ tarafı bir PURE yordamda bir POINTER içeren türetilmiş bir türdür"
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr ""
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "%L'deki ASSIGNED GOTO deyimi bir INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "'%s' değişkenine %L'de bir hedef etiketi atanmış olmamalıydı"
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate RETURN statement at %L requires an INTEGER return specifier"
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Diğer RETURN deyimi %L'de bir INTEGER dönüş belirteci gerektirir"
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr "%L'deki aritmetik IF deyimi bir sayısal ifade gerektirir"
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L'deki DO WHILE döngüsünün çıkış koşulu bir sabit LOGICAL ifadesi olmalıdır"
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki FORALL maske deyimi bir LOGICAL ifadesi gerektirir"
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Hatalı deyim kodu"
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -55833,7 +55881,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -55841,62 +55889,62 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr ""
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "'%s' sabit nesnesi %L'de ALLOCATABLE olmayabilir"
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
@@ -55903,471 +55951,471 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr "Modül veya ana program dizisi '%s' %L'de sabit biçimde olmalı"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, fuzzy, gcc-internal-format
 #| msgid "Possible frontend bug: Deferred array size without pointer or allocatable attribute."
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr "Olası önyüz hatası: gösterici veya tahsis edilebilir öznitelik olmaksızın ertelenmiş dizi boyutu"
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L'deki tahmini karakter uzunluklu öğe ya bir sözde argüman ya da bir PARAMETER olmalı"
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Ayrılabilir '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Harici '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Özdevinimli dizi '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "'%s' bir PRIVATE türündedir ve '%s' (%L'de PUBLIC tanımlı) için bir sözde argüman olamaz"
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Harici nesne '%s'  %L'de bir ilklendiriciye sahip olamayabilir"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de dizi değerli olamaz"
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de gösterici değerli olamaz"
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de iç içe olamaz"
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' of PURE procedure at %L must also be PURE"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "PURE yordamının '%s' sözde yordamı da ayrıca PURE olmalı"
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%s özniteliği ile %s özniteliği '%s' içinde %L'de çelişiyor"
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L'de ICHAR'ın argümanı bir uzunlukta olmalı"
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) OPTIONAL olmamalı"
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir değişmez olmalı"
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Öğesel yordamın '%s' argümanı POINTER özniteliğine sahip olamaz (%L'de)"
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L must have constant array bounds."
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Bileşen karakter uzunluğu '%s'in %L'de bir sabit belirtim ifadesi olması gerekir"
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Bileşen '%s' bir PRIVATE türdür ve '%s' (%L'de PUBLIC tanımlı) bileşeni olamaz"
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component %s of SEQUENCE type declared at %C does not have the SEQUENCE attribute"
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "SEQUENCE türünün %s bileşeni SEQUENCE özniteliğine sahip değil (%C'de)"
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Türetilmiş '%s' türü (%L'de) tanımlanmamış olan '%s' türündedir."
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'de)."
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -56374,433 +56422,433 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametre dizisi '%s' %L'de özdevinimli veya tahmini biçimli olamaz"
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Örtük olarak  PARAMETER türlü '%s' %L'de sonraki bir IMPLICIT türle eşleşmiyor"
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L'de PARAMETER içindeki türetilmiş tür uyumsuz"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L'deki tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L'deki simge bir DUMMY değişken değil"
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Türetilmiş '%s' türü (%L'de) tanımlanmamış olan '%s' türündedir."
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC işlev '%s' %L'de PRIVATE '%s' türünde olamaz"
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) sözde argüman '%s' %L'de ASSUMED SIZE olduğundan bir öntanımlı ilklerdiriciye sahip olamaz"
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L'deki sözde yordama ELEMENTAL yordamında izin verilmez"
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA öğesi '%s' %L'de COMMON içinde olmalıdır"
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "DATA deyiminde %L'de sabit olmayan dizi bölümü"
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L'deki DATA deyiminde değerden çok değişken var"
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L'deki DATA deyiminde değişkenden çok değer var"
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılmamış"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılamıyor"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de öntanımlı ilklendiriciyle bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Ortak blok üyesi '%s' (%L'de), '%s' pure yordamındaki bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "'%s' isimli sabiti %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Sınırları sabit olmayan '%s' dizisi (%L'de) bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Yapı bileşeni '%s' %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L'deki altdizge sıfır uzunlukta"
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC işlev '%s' %L'de PRIVATE '%s' türünde olamaz"
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY '%s' %L'de hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Yerleşik işleç arayüzü '%s' %L'de bir FUNCTION olmalı"
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Kullanıcı işleci yordamı '%s' %L'de tahmini karakter uzunluğunda olamaz"
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ilk argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L'deki işleç arayüzünün en fazla iki argümanı olmalı"
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -56834,50 +56882,50 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr ""
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "Line truncated at %L"
 msgstr "%C'deki satır kırpıldı"
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad continuation line at %C"
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr "%C'deki devam satırı hatalı"
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "Missing '&' in continued character constant at %C"
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "%C'deki devamlı karakter sabitinde '&' eksik"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr ""
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
 msgstr ""
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr ""
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr "%s:%d: %s dosyası solda ama girilmemiş"
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr "%s:%d: önişlemci yönergesi kuraldışı"
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open file '%s'"
 msgid "Can't open file %qs"
@@ -57157,55 +57205,55 @@
 msgid "Reshaped array too large at %C"
 msgstr "%C'deki tamsayı çok büyük"
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "%L'de SCALE sonucu kendi çeşidini üstten taşırıyor"
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "%L'de SQRT'nin argümanı negatif değer içeriyor"
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid second argument of IBSET at %L"
 msgid "invalid argument of SQRT at %L"
 msgstr "%L'de IBSET'in ikinci argümanı geçersiz"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_conv_constant_to_tree(): invalid type: %s"
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): geçersiz tür: %s"
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -57290,277 +57338,283 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
+
+#: fortran/symbol.c:489
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "Procedure pointer at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute applied to %s %s at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr "%s özniteliği ile %s özniteliği '%s' içinde %L'de çelişiyor"
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute with %s attribute at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr "%s özniteliği ile %s özniteliği '%s' içinde %L'de çelişiyor"
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "%L'de USE ile ilişkili simgenin öznitelikleri değiştirilemez"
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "USE ile ilişkili %s simgesinin öznitelikleri %L'de değiştirilemez"
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute specified at %L"
 msgid "Duplicate %s attribute specified at %L"
 msgstr "%L'de yinelenen %s özniteliği belirtilmiş"
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray Pointee at %L appears in multiple pointer() statements."
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "%L'deki Cray Göstericisi çok sayıda pointer() deyiminde görünüyor"
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "%L'deki SAVE özniteliği bir PURE yordamında belirtilemez"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "%s yordamı %L'de zaten %s yordamı olarak bildirilmiş"
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) ile INTENT(%s) %L'de çelişiyor"
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "ACCESS belirtimi %L'de zaten belirtilmiş"
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute specified at %L"
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "%L'de yinelenen %s özniteliği belirtilmiş"
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "'%s' simgesi %L'de zaten bir aleni arayüze sahip"
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "'%s' simgesi (%L'de) bir türe sahip olamaz"
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "'%s' simgesi %C'de belirsiz"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "'%s' bileşeni (%C'deki) '%s'nin bir PRIVATE bileşenidir"
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%s' (%C'deki) '%s' yapısının bir üyesi değil"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr " %d yaftası %L ve %L'de yinelenmiş"
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "%d yaftası (%C'deki) zaten dallanma hedefi olarak başvurulu"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "%d yaftası (%C'deki) zaten bir biçim yaftası olarak başvurulu"
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "%d yaftası (%C'deki) evvelce bir biçim yaftası olarak kullanılmış"
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "%d yaftası (%C'deki) evvelce dallanma hedefi olarak kullanılmış"
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "'%s' ismi (%C'deki) '%s'e '%s' modülünden belirsiz bir başvurudur"
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
@@ -57567,65 +57621,65 @@
 msgstr "'%s' ismi (%C'deki) şu an ki program biriminden '%s'e belirsiz bir başvurudur"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "'%s' simgesi (%C'deki) zaten konakla ilişkiliymiş"
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -57917,7 +57971,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr "Hatalı GÇ tabantürü (%d)"
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_omp_workshare(): Bad statement code"
@@ -61877,6 +61931,9 @@
 #~ msgid "info pointer NULL"
 #~ msgstr "info göstericisi NULL"
 
+#~ msgid "-munix=98 option required for C89 Amendment 1 features.\n"
+#~ msgstr "-munix=98 seçeneği C89'un 1. Düzeltmesindeki özellikler için gerekli.\n"
+
 #~ msgid "unknown -mtraceback arg %qs; expecting %<full%>, %<partial%> or %<none%>"
 #~ msgstr "-mtraceback ile verilen %qs bilinmiyor; %<full%>, %<partial%> veya %<none%> umuluyor"
 
@@ -62179,6 +62236,9 @@
 #~ msgid "%qD has no member named %qE"
 #~ msgstr "%qD %qE isimli üyeye sahip değil"
 
+#~ msgid "ISO C++ forbids subscripting non-lvalue array"
+#~ msgstr "ISO C++ sol yan olmayan dizi indislemesine izin vermez"
+
 #~ msgid "at this point in file"
 #~ msgstr "dosyanın burasında"
 
Index: gcc/po/be.po
===================================================================
--- gcc/po/be.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/be.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: gcc 3.1\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2002-05-17 15:54+0200\n"
 "Last-Translator: Ales Nyakhaychyk <nyakhaychyk@i18n.linux.by>\n"
 "Language-Team: Belarusian <i18n@tut.by>\n"
@@ -192,13 +192,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1373,7 +1373,7 @@
 msgid "options enabled: "
 msgstr "выбары ўключаны:"
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2612,97 +2612,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "нерэчаіснае значэньне %%H"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, fuzzy, c-format
 msgid "invalid %%J value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "нерэчаіснае значэньне %%r"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "нерэчаіснае значэньне %%R"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "нерэчаіснае значэньне %%N"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "нерэчаіснае значэньне %%P"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "нерэчаіснае значэньне %%h"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "нерэчаіснае значэньне %%L"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "нерэчаіснае значэньне %%m"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "нерэчаіснае значэньне %%M"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "нерэчаіснае значэньне %%U"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "нерэчаіснае значэньне %%v"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "нерэчаіснае значэньне %%C"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "нерэчаіснае значэньне %%E"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr ""
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "нерэчаіснае значэньне %%xn"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid operand address"
@@ -2751,7 +2751,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr ""
@@ -2912,8 +2912,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3136,63 +3136,63 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, fuzzy, c-format
 #| msgid "invalid %%c operand"
 msgid "invalid constraints for operand"
 msgstr "нерэчаісны %%c аперанд"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "невядомы рэжым машыны \"%s\""
@@ -3238,7 +3238,7 @@
 msgid "invalid %%P operand"
 msgstr "нерэчаісны %%-код"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -3304,7 +3304,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "дрэнны адрас"
 
@@ -3475,104 +3475,104 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%e value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "нерэчаіснае значэньне %%O"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, fuzzy, c-format
 #| msgid "invalid %%x/X value"
 msgid "invalid %%x value"
 msgstr "нерэчаіснае значэньне %%x/X"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Стварыць код для DLL"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 msgid "Unable to generate load offset for fusion"
 msgstr ""
 
@@ -3666,60 +3666,60 @@
 msgid "invalid operand to %%S"
 msgstr "нерэчаісны %%-код"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr ""
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr ""
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "нерэчаісны %%Y аперанд"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "нерэчаісны %%A аперанд"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "нерэчаісны %%B аперанд"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, c-format
 msgid "invalid %%C operand"
 msgstr "нерэчаісны %%C аперанд"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, c-format
 msgid "invalid %%D operand"
 msgstr "нерэчаісны %%D аперанд"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "нерэчаісны %%f аперанд"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, fuzzy, c-format
 msgid "invalid %%s operand"
 msgstr "нерэчаісны %%-код"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr ""
@@ -3928,7 +3928,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr ""
@@ -3944,15 +3944,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr ""
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr ""
@@ -3974,8 +3974,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr ""
@@ -3982,8 +3982,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr ""
@@ -3992,13 +3992,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr ""
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr ""
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr ""
@@ -4005,8 +4005,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr ""
@@ -4027,7 +4027,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr ""
@@ -4044,34 +4044,34 @@
 msgid "expected %<.%>"
 msgstr ""
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr ""
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr ""
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr ""
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr ""
@@ -4080,11 +4080,11 @@
 msgid "(anonymous)"
 msgstr ""
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr ""
 
@@ -4317,11 +4317,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4372,50 +4372,50 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 #, fuzzy
 #| msgid "too many arguments to function"
 msgid "in argument to unary !"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4513,7 +4513,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr ""
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 msgid "array assignment"
 msgstr ""
 
@@ -4533,7 +4533,7 @@
 msgid "Driving:"
 msgstr "увага:"
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4599,13 +4599,13 @@
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4685,7 +4685,7 @@
 msgid "Bad type in constant expression"
 msgstr ""
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 msgid "Unexpected end of module"
 msgstr ""
 
@@ -4719,11 +4719,11 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 msgid "pointer assignment"
 msgstr ""
 
@@ -4741,209 +4741,209 @@
 msgid "internal function"
 msgstr "У функцыі"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 #| msgid "no arguments"
 msgid "allocatable argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 #| msgid "no arguments"
 msgid "pointer argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 #| msgid "no arguments"
 msgid "value argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 msgid "assumed-shape argument"
 msgstr ""
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 msgid "assumed-type argument"
 msgstr ""
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr ""
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5351,16 +5351,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr ""
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr ""
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr ""
-
 #: config/sol2.h:222 config/sol2.h:227
 #, fuzzy
 #| msgid "%s does not support %s"
@@ -5375,6 +5365,11 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr ""
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+#, fuzzy
+msgid "profiling not supported with -mg"
+msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "-mhard-float не падтрымліваецца"
@@ -5383,10 +5378,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr ""
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr ""
-
 #: config/cris/cris.h:184
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr ""
@@ -5415,6 +5406,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr ""
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5421,6 +5418,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr ""
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr ""
+
 #: config/s390/tpf.h:106
 #, fuzzy
 #| msgid "-pipe is not supported"
@@ -5435,6 +5436,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr ""
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr ""
+
 #: config/avr/specs.h:68
 #, fuzzy
 #| msgid "-pipe is not supported"
@@ -5462,17 +5467,19 @@
 msgid "no processor type specified for linking"
 msgstr ""
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr ""
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr ""
 
@@ -5510,11 +5517,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr ""
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-#, fuzzy
-msgid "profiling not supported with -mg"
-msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
-
 #: fortran/lang.opt:146
 msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgstr ""
@@ -5696,9 +5698,9 @@
 msgstr ""
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -5904,10 +5906,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -5953,7 +5955,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, fuzzy, c-format
 #| msgid "missing white space after number '%.*s'"
 msgid "missing filename after %qs"
@@ -7861,44 +7863,48 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 msgid "Specify the code model"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -9010,10 +9016,14 @@
 msgstr ""
 
 #: config/i386/i386.opt:864
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:868
 msgid "Use given stack-protector guard"
 msgstr ""
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr ""
 
@@ -9404,7 +9414,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -9555,7 +9565,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 msgid "Use LRA instead of reload"
 msgstr ""
@@ -9683,7 +9693,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr ""
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr ""
 
@@ -10018,310 +10028,310 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 #, fuzzy
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "\"__buitin_next_arg\" выклікаецца без аргумента"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 #, fuzzy
 #| msgid "Do not generate char instructions"
 msgid "Generate isel instructions"
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 msgid "Deprecated option.  Use -misel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 msgid "Generate PPC750CL paired-single instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 msgid "Deprecated option.  Use -mspe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 msgid "-mdebug=\tEnable debug output"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 msgid "Use the AltiVec ABI extensions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 #, fuzzy
 #| msgid "Don't use AltiVec instructions"
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "Не выкарыстоўваць інструкцыі AltiVec"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 msgid "Use the SPE ABI extensions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 #, fuzzy
 msgid "Do not use the SPE ABI extensions"
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 msgid "Use the ELFv1 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 msgid "Use the ELFv2 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 msgid "using darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 msgid "using old darwin ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 #, fuzzy
 #| msgid "Generate code for given CPU"
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "Генерыраваць код для дадзенага ЦП"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 msgid "Generate Cell microcode"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 msgid "Valid arguments to -malign-:"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 #, fuzzy
 msgid "Single-precision floating point unit"
 msgstr "Выкарыстоўваць апаратную \"плаваючую кропку\""
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 #, fuzzy
 msgid "Double-precision floating point unit"
 msgstr "Выкарыстоўваць апаратную \"плаваючую кропку\""
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 msgid "Floating point unit does not support divide & sqrt"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 msgid "Specify Xilinx FPU."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 msgid "Allow sign extension in fusion operations"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
-msgid "Use ISA 2.07 crypto instructions"
+#: config/rs6000/rs6000.opt:566
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -13302,1595 +13312,1595 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr ""
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr ""
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr ""
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr ""
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr ""
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr ""
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr ""
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr ""
 
-#: common.opt:918
+#: common.opt:921
 #, fuzzy
 #| msgid "Do not generate char instructions"
 msgid "Generate auto-inc/dec instructions"
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr ""
 
-#: common.opt:936
+#: common.opt:939
 #, fuzzy
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "Генерыраваць код для Intel as"
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr ""
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr ""
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr ""
 
-#: common.opt:960
+#: common.opt:963
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr ""
 
-#: common.opt:964
+#: common.opt:967
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr ""
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr ""
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr ""
 
-#: common.opt:979
+#: common.opt:982
 msgid "Check the return value of new in C++"
 msgstr ""
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr ""
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr ""
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr ""
 
-#: common.opt:1003
+#: common.opt:1006
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr ""
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr ""
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr ""
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr ""
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr ""
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr ""
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr ""
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr ""
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr ""
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr ""
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr ""
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr ""
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 msgid "Perform speculative devirtualization"
 msgstr ""
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1085
+#: common.opt:1088
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr ""
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1145
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr ""
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr ""
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr ""
 
-#: common.opt:1157
+#: common.opt:1160
 msgid "Suppress output of addresses in debugging dumps"
 msgstr ""
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 #, fuzzy
 #| msgid "optimization turned on"
 msgid "Dump optimization passes"
 msgstr "аптымізацыя уключана"
 
-#: common.opt:1170
+#: common.opt:1173
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1177
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr ""
 
-#: common.opt:1190
+#: common.opt:1193
 msgid "Perform interprocedural reduction of aggregates"
 msgstr ""
 
-#: common.opt:1194
+#: common.opt:1197
 msgid "Perform unused symbol elimination in debug info"
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "Уключыць апрацоўку выключэньняў"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr ""
 
-#: common.opt:1217
+#: common.opt:1220
 #, fuzzy, c-format
 msgid "unknown excess precision style %qs"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr ""
 
-#: common.opt:1238
+#: common.opt:1241
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr ""
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr ""
 
-#: common.opt:1250
+#: common.opt:1253
 msgid "Perform a forward propagation pass on RTL"
 msgstr ""
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr ""
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr ""
 
-#: common.opt:1278
+#: common.opt:1281
 #, fuzzy
 #| msgid "for each function it appears in.)"
 msgid "Place each function into its own section"
 msgstr "адзін раз для кожнай функцыі, дзе ён з'яўляецца.)"
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr ""
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr ""
 
-#: common.opt:1305
+#: common.opt:1308
 msgid "Enable in and out of Graphite representation"
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1312
 msgid "Enable Graphite Identity transformation"
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1316
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr ""
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr ""
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr ""
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr ""
 
-#: common.opt:1330
+#: common.opt:1333
 msgid "Enable Loop Blocking transformation"
 msgstr ""
 
-#: common.opt:1334
+#: common.opt:1337
 msgid "Enable Loop Unroll Jam transformation"
 msgstr ""
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr ""
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr ""
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr ""
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr ""
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1394
+#: common.opt:1397
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr ""
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr ""
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr ""
 
-#: common.opt:1410
+#: common.opt:1413
 msgid "Perform indirect inlining"
 msgstr ""
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr ""
 
-#: common.opt:1424
+#: common.opt:1427
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr ""
 
-#: common.opt:1428
+#: common.opt:1431
 msgid "Integrate functions only required by their single caller"
 msgstr ""
 
-#: common.opt:1435
+#: common.opt:1438
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr ""
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1458
 msgid "Perform interprocedural constant propagation"
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1466
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1470
 msgid "Perform interprocedural profile propagation"
 msgstr ""
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr ""
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 msgid "Perform Identical Code Folding for variables"
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr ""
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr ""
 
-#: common.opt:1506
+#: common.opt:1509
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA algorithm %qs"
 msgstr "невядомая назва рэгістра: %s"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr ""
 
-#: common.opt:1519
+#: common.opt:1522
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA region %qs"
 msgstr "невядомая назва рэгістра: %s"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr ""
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr ""
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr ""
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr ""
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable link-time optimization."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown LTO partitioning model %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr ""
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 msgid "Report various link-time optimization statistics"
 msgstr ""
 
-#: common.opt:1625
+#: common.opt:1628
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr ""
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr ""
 
-#: common.opt:1641
+#: common.opt:1644
 msgid "Report on permanent memory allocation in WPA only"
 msgstr ""
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr ""
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1659
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr ""
 
-#: common.opt:1660
+#: common.opt:1663
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr ""
 
-#: common.opt:1676
+#: common.opt:1679
 msgid "Use the RTL dead code elimination pass"
 msgstr ""
 
-#: common.opt:1680
+#: common.opt:1683
 msgid "Use the RTL dead store elimination pass"
 msgstr ""
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 msgid "options or targets missing after %qs"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, c-format
 msgid "unknown offload ABI %qs"
 msgstr ""
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr ""
 
-#: common.opt:1713
+#: common.opt:1716
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable all optimization info dumps on stderr"
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr ""
 
-#: common.opt:1729
+#: common.opt:1732
 msgid "Perform partial inlining"
 msgstr ""
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr ""
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr ""
 
-#: common.opt:1745
+#: common.opt:1748
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr ""
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr ""
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr ""
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr ""
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr ""
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr ""
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr ""
 
-#: common.opt:1781
+#: common.opt:1784
 msgid "Specify a plugin to load"
 msgstr ""
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr ""
 
-#: common.opt:1789
+#: common.opt:1792
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr ""
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr ""
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr ""
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1821
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1826
+#: common.opt:1829
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1837
 msgid "Report on consistency of profile"
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1841
 msgid "Enable function reordering that improves code placement"
 msgstr ""
 
-#: common.opt:1845
+#: common.opt:1848
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr ""
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:1859
+#: common.opt:1862
 #, fuzzy
 msgid "Return small aggregates in registers"
 msgstr "Не выкарыстоўваць рэгістра sb"
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr ""
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr ""
 
-#: common.opt:1880
+#: common.opt:1883
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr ""
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr ""
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr ""
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr ""
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr ""
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr ""
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr ""
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr ""
 
-#: common.opt:1928
+#: common.opt:1931
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr ""
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr ""
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr ""
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr ""
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr ""
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr ""
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr ""
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1981
+#: common.opt:1984
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr ""
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1993
+#: common.opt:1996
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1997
+#: common.opt:2000
 msgid "Enable the group heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2009
+#: common.opt:2012
 msgid "Enable the rank heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr ""
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr ""
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr ""
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr ""
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr ""
 
-#: common.opt:2062
+#: common.opt:2065
 msgid "Generate discontiguous stack frames"
 msgstr ""
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr ""
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr ""
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr ""
 
-#: common.opt:2082
+#: common.opt:2085
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "Уключаць код правэркі стэку ў праграму"
 
-#: common.opt:2086
+#: common.opt:2089
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "Уключаць код правэркі стэку ў праграму"
 
-#: common.opt:2093
+#: common.opt:2096
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr ""
 
-#: common.opt:2097
+#: common.opt:2100
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr ""
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr ""
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr ""
 
-#: common.opt:2109
+#: common.opt:2112
 msgid "Use a smart stack protection method for certain functions"
 msgstr ""
 
-#: common.opt:2113
+#: common.opt:2116
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr ""
 
-#: common.opt:2117
+#: common.opt:2120
 msgid "Output stack usage information on a per-function basis"
 msgstr ""
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr ""
 
-#: common.opt:2133
+#: common.opt:2136
 msgid "Treat signed overflow as undefined"
 msgstr ""
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr ""
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr ""
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr ""
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr ""
 
-#: common.opt:2157
+#: common.opt:2160
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2163
 #, fuzzy, c-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown TLS model %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr ""
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr ""
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr ""
 
-#: common.opt:2195
+#: common.opt:2198
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-CCP optimization on trees"
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2199
+#: common.opt:2202
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr ""
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr ""
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr ""
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr ""
 
-#: common.opt:2231
+#: common.opt:2234
 msgid "Transform condition stores into unconditional ones"
 msgstr ""
 
-#: common.opt:2235
+#: common.opt:2238
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2239
+#: common.opt:2242
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2243
+#: common.opt:2246
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable dominator optimizations"
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2247
+#: common.opt:2250
 msgid "Enable tail merging on trees"
 msgstr ""
 
-#: common.opt:2251
+#: common.opt:2254
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable dead store elimination"
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2255
+#: common.opt:2258
 msgid "Enable forward propagation on trees"
 msgstr ""
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr ""
 
-#: common.opt:2263
+#: common.opt:2266
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable string length optimizations on trees"
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 msgid "Enable loop distribution on trees"
 msgstr ""
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr ""
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr ""
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr ""
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr ""
 
-#: common.opt:2300
+#: common.opt:2303
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable loop optimizations on tree level"
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2304
+#: common.opt:2307
 msgid "Enable automatic parallelization of loops"
 msgstr ""
 
-#: common.opt:2308
+#: common.opt:2311
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2312
+#: common.opt:2315
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2324
+#: common.opt:2327
 msgid "Enable reassociation on tree level"
 msgstr ""
 
-#: common.opt:2332
+#: common.opt:2335
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA code sinking on trees"
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr ""
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr ""
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr ""
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr ""
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr ""
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr ""
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr ""
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr ""
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr ""
 
-#: common.opt:2424
+#: common.opt:2427
 msgid "Perform variable tracking by annotating assignments"
 msgstr ""
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr ""
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr ""
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable vectorization on trees"
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2450
+#: common.opt:2453
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable loop vectorization on trees"
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2454
+#: common.opt:2457
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr ""
 
-#: common.opt:2458
+#: common.opt:2461
 msgid "Specifies the cost model for vectorization"
 msgstr ""
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown vectorizer cost model %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: common.opt:2478
+#: common.opt:2481
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2485
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2493
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr ""
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr ""
 
-#: common.opt:2507
+#: common.opt:2510
 #, fuzzy, c-format
 #| msgid "unrecognized section name \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "нераспазнаная назва сэкцыі \"%s\""
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr ""
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2558
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr ""
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr ""
 
-#: common.opt:2571
+#: common.opt:2574
 #, fuzzy
 #| msgid "Generate code for Intel as"
 msgid "Generate debug information in default format"
 msgstr "Генерыраваць код для Intel as"
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2582
 msgid "Generate debug information in default version of DWARF format"
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2586
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2614
 #, fuzzy
 msgid "Don't generate debug information in separate .dwo files"
 msgstr "Генерыраваць код для Intel as"
 
-#: common.opt:2615
+#: common.opt:2618
 msgid "Generate debug information in separate .dwo files"
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2622
 #, fuzzy
 msgid "Generate debug information in STABS format"
 msgstr "Стварыць код для DLL"
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2638
 msgid "Toggle debug information generation"
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2642
 #, fuzzy
 msgid "Generate debug information in VMS format"
 msgstr "Стварыць код для DLL"
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr ""
 
-#: common.opt:2665
+#: common.opt:2668
 msgid "Generate compressed debug sections"
 msgstr ""
 
-#: common.opt:2669
+#: common.opt:2672
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr ""
 
-#: common.opt:2676
+#: common.opt:2679
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr ""
 
-#: common.opt:2680
+#: common.opt:2683
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr ""
 
-#: common.opt:2702
+#: common.opt:2705
 #, fuzzy
 #| msgid "  -o <file>                Place the output into <file>\n"
 msgid "-o <file>\tPlace output into <file>"
 msgstr "  -o <файл>                Памясціць вывад у <файл>\n"
 
-#: common.opt:2706
+#: common.opt:2709
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Enable function profiling"
 msgstr "Уключыць апрацоўку выключэньняў"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr ""
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr ""
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr ""
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr ""
 
-#: common.opt:2796
+#: common.opt:2799
 #, fuzzy
 #| msgid "%s: warning: "
 msgid "Suppress warnings"
 msgstr "%s: увага: "
 
-#: common.opt:2806
+#: common.opt:2809
 msgid "Create a shared library"
 msgstr ""
 
-#: common.opt:2851
+#: common.opt:2854
 msgid "Create a position independent executable"
 msgstr ""
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr ""
@@ -14922,250 +14932,250 @@
 msgid "expected integer or boolean type"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 msgid "invalid comparison of nil with nil"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 msgid "incompatible types in binary expression"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 msgid "integer division by zero"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 #, fuzzy
 msgid "shift of non-integer operand"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 msgid "shift count not unsigned integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 msgid "negative shift count"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 #, fuzzy
 #| msgid "cannot find method"
 msgid "object is not a method"
 msgstr "немагчыма знайсьці мэтад"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 msgid "method type does not match object type"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 msgid "invalid use of %<...%> with builtin function"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 msgid "invalid use of method value as argument of Offsetof"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 #, fuzzy
 #| msgid "no arguments"
 msgid "not enough arguments"
 msgstr "няма аргументаў"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 #, fuzzy
 #| msgid "too many arguments to function"
 msgid "too many arguments"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 #, fuzzy
 msgid "argument 1 must be a map"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 #, fuzzy
 msgid "invalid type for make function"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 #, fuzzy
 #| msgid "too many arguments to function"
 msgid "too many arguments to make"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 #, fuzzy
 msgid "argument must be array or slice or channel"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "unsupported argument type to builtin function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 #, fuzzy
 msgid "argument must be channel"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 #, fuzzy
 msgid "argument must be a field reference"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 #, fuzzy
 msgid "left argument must be a slice"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 #, fuzzy
 #| msgid "first argument of `%s' should be `int'"
 msgid "first argument must be []byte"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 msgid "second argument must be slice or string"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 #, fuzzy
 #| msgid "bit-field `%s' has invalid type"
 msgid "argument 2 has invalid type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 #, fuzzy
 msgid "argument must have complex type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 msgid "complex arguments must have identical types"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 msgid "complex arguments must have floating-point type"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 #, fuzzy
 #| msgid "In function"
 msgid "expected function"
 msgstr "У функцыі"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 msgid "multiple-value argument in single-value context"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 #, fuzzy
 msgid "invalid use of %<...%> with non-slice"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 msgid "function result count mismatch"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 msgid "incompatible type for receiver"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 msgid "number of results does not match number of values"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 msgid "index must be integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 msgid "slice end must be integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 msgid "slice capacity must be integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 msgid "incompatible type for map index"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 #, fuzzy
 #| msgid "too many arguments to function"
 msgid "too many expressions for struct"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "too few expressions for struct"
 msgstr "не хапае аргументаў у функцыі"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 msgid "type assertion only valid for interface types"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 msgid "expected channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -15278,76 +15288,76 @@
 msgid "cannot use type %s as type %s"
 msgstr ""
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 msgid "different receiver types"
 msgstr ""
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 msgid "different number of parameters"
 msgstr ""
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 #, fuzzy
 #| msgid "invalid parameter type `%T'"
 msgid "different parameter types"
 msgstr "нерэчаісны тып парамэтра `%T'"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, fuzzy, c-format
 #| msgid "no data type for mode `%s'"
 msgid "incompatible type for method %s%s%s"
 msgstr "няма тыпа дадзеных для рэжыма \"%s\""
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, fuzzy, c-format
 #| msgid "no data type for mode `%s'"
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "няма тыпа дадзеных для рэжыма \"%s\""
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 msgid "type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, fuzzy, c-format
 #| msgid "missing field '%s' in '%s'"
 msgid "missing method %s%s%s"
 msgstr "прапушчана поле '%s' у '%s'"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -15472,7 +15482,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "too few arguments to function %<va_start%>"
@@ -15664,12 +15674,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr ""
 
-#: calls.c:3179
+#: calls.c:3195
 #, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr ""
@@ -16250,243 +16260,248 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr ""
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr ""
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr ""
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, gcc-internal-format
 msgid "execution count is negative"
 msgstr ""
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, fuzzy, gcc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "local symbols must be defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr ""
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to `-%s' is missing"
 msgid "%s: section %s is missing"
@@ -16622,7 +16637,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, gcc-internal-format
 msgid "atexit failed"
@@ -16872,17 +16887,17 @@
 msgid "          %s"
 msgstr ""
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr ""
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, fuzzy, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, fuzzy, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
@@ -16929,12 +16944,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -17132,7 +17147,7 @@
 msgid "total size of local objects too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, fuzzy, gcc-internal-format
 #| msgid "impossible operator '%s'"
 msgid "impossible constraint in %<asm%>"
@@ -17599,9 +17614,9 @@
 msgstr "не магу запісаць ў %s"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "declared here"
@@ -17617,152 +17632,147 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr ""
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr ""
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr ""
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:7001
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, gcc-internal-format
-msgid "lastprivate variable %qE is private in outer context"
-msgstr ""
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
-#, gcc-internal-format
 msgid "directive not yet implemented"
 msgstr ""
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr ""
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr ""
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -18181,49 +18191,49 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class `%s'"
 msgid "cannot find LTO cgraph in %s"
 msgstr "немагчыма знайсьці кляс `%s'"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find source %s"
 msgid "cannot find LTO section refs in %s"
 msgstr "не магу знайсці крыніцу %s"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "Нерэчаісны выбар %s"
@@ -18305,47 +18315,47 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 msgid "reading input file"
 msgstr "няма ўваходзячых файлаў"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 msgid "writing output file"
 msgstr "не магу запісаць ў %s"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr ""
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr ""
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr ""
@@ -18484,28 +18494,28 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr ""
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "нявернае выкарыстанне \"restict\""
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, gcc-internal-format
 msgid "ignoring large linear step"
 msgstr ""
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -19037,8 +19047,8 @@
 msgstr "Клас \"%s\" ужо існуе"
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "невядомая назва рэгістра: %s"
@@ -19483,7 +19493,7 @@
 msgid "ld returned %d exit status"
 msgstr ""
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, fuzzy, gcc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "%q+F used but never defined"
@@ -20481,42 +20491,42 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr ""
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -20900,47 +20910,47 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, gcc-internal-format
 msgid "array subscript is outside array bounds"
 msgstr ""
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, gcc-internal-format
 msgid "array subscript is above array bounds"
 msgstr ""
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, gcc-internal-format
 msgid "array subscript is below array bounds"
 msgstr ""
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr ""
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr ""
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr ""
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr ""
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr ""
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr ""
@@ -20984,9 +20994,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
@@ -21219,7 +21229,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
@@ -21367,27 +21377,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr ""
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -21722,12 +21732,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of %<restrict%>"
@@ -22185,12 +22195,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr ""
@@ -22200,22 +22210,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr ""
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr ""
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr ""
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr ""
@@ -22257,12 +22267,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, fuzzy, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
@@ -22348,7 +22358,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "не магу атрымаць адрас бітавага поля \"%s\""
@@ -22773,7 +22783,7 @@
 msgstr ""
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
@@ -23236,7 +23246,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -23247,22 +23257,22 @@
 msgid "%qE is not initialized"
 msgstr "прапушчан ініцыялізатар"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "нерэчаісны ініцыялізатар"
@@ -23809,6 +23819,12 @@
 msgid "too many input files"
 msgstr "вельмі шмат уваходзячых файлаў"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+#| msgid "%s is too large"
+msgid "-mcpu string too large"
+msgstr "%s - вельмі вялікі"
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -23834,47 +23850,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr ""
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr ""
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr ""
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -24261,63 +24277,63 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr ""
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr ""
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr ""
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr ""
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr ""
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, gcc-internal-format
 msgid "bad value %qs for -mtune switch"
 msgstr ""
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr ""
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr ""
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr ""
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr ""
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr ""
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr ""
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -24796,14 +24812,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to functions"
@@ -25453,378 +25469,394 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "немагчыма зачыніць уваходзячы файл %s"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "wrong arg %s to option %s"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr ""
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
 #, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386.c:3012
+#, gcc-internal-format, gfc-internal-format
 msgid "unknown alignment %s specified for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, gcc-internal-format, gfc-internal-format
 msgid "too many size ranges specified in option %s"
 msgstr ""
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr ""
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s does not support %s"
 msgid "code model %s does not support PIC mode"
 msgstr "%s не падтрымлівае %s"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s не падтрымлівае %s"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5923
-#, gcc-internal-format
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr ""
-
-#: config/i386/i386.c:6210
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "X32 does not support ms_abi attribute"
 msgstr "%s не падтрымлівае %s"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, gcc-internal-format
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
 #, gcc-internal-format
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:11378
+#, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -25831,255 +25863,255 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%D'"
 msgid "previous declaration of %D"
 msgstr "папярэдняе абвяшчэньне `%D'"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %d"
 msgstr "непадтрымліваемая версія"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -26173,13 +26205,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr ""
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -26253,7 +26285,7 @@
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument not an integer constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
@@ -26315,7 +26347,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -27172,16 +27204,11 @@
 msgid "-g option disabled"
 msgstr ""
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr ""
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, gcc-internal-format
@@ -27443,308 +27470,313 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
+#, gcc-internal-format, gfc-internal-format
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, fuzzy, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had no type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "stack frame too large"
 msgstr "%s - вельмі вялікі"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr ""
@@ -27997,90 +28029,90 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, fuzzy, gcc-internal-format
 #| msgid "size of `%s' is %d bytes"
 msgid "frame size of %qs is %wd bytes"
 msgstr "памер \"%s\" - %d байт"
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
@@ -28095,53 +28127,53 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr ""
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, fuzzy, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is supported only for SH2A"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr ""
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to SH2A"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, gcc-internal-format
 msgid "%qE attribute argument should be between 0 to 255"
 msgstr ""
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument not a string constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr ""
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, gcc-internal-format
 msgid "need a second call-clobbered general purpose register"
 msgstr ""
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr ""
@@ -28523,45 +28555,45 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, fuzzy, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qs attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE attribute has no effect"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -28619,7 +28651,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -28649,65 +28681,65 @@
 msgid "GCC supports only %u nested scopes"
 msgstr ""
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "label %q+D used but not defined"
 msgstr "адмеціна `%D' выкарыстоўвываецца, але ня вызначана"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, fuzzy, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, fuzzy, gcc-internal-format
 #| msgid "unused variable `%s'"
 msgid "unused variable %q+D"
 msgstr "невыкарыстоўваемая пераменная \"%s\""
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "variable %qD set but not used"
 msgstr "адмеціна `%D' вызначана, але не выкарыстоўваецца"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr ""
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr ""
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr ""
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr ""
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr ""
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr ""
@@ -28714,43 +28746,43 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr ""
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "previous definition of %q+D was here"
 msgstr "папярэдняе вызначэньне"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, fuzzy, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr ""
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, fuzzy, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "redeclaration of enumerator %q+D"
@@ -28759,347 +28791,347 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, fuzzy, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
 msgstr ""
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr ""
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr ""
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr ""
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, fuzzy, gcc-internal-format
 #| msgid "  from here"
 msgid "but not here"
 msgstr " адсюль"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr ""
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr ""
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, fuzzy, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr ""
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr ""
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, fuzzy, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr ""
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, fuzzy, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr ""
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, fuzzy, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, fuzzy, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, fuzzy, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function)"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, fuzzy, gcc-internal-format
 #| msgid "(Each undeclared identifier is reported only once"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Аб кожным неабвешчаным ідэнтыфікатары паведамляецца"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, fuzzy, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "label %qD defined here"
 msgstr "адмеціна `%D' вызначана, але не выкарыстоўваецца"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr ""
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "duplicate label declaration %qE"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "паўтарэнне \"%s\""
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr ""
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr ""
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr ""
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr ""
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, fuzzy, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "%<inline%> in empty declaration"
 msgstr "пустое абвяшчэньне"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "пустое абвяшчэньне"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, fuzzy, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "useless %qs in empty declaration"
 msgstr "пустое абвяшчэньне"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, fuzzy, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "пустое абвяшчэньне"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C89 не падтрымлівае \"long long\""
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C89 не падтрымлівае \"long long\""
@@ -29107,39 +29139,39 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is usually a function"
 msgid "%q+D is usually a function"
 msgstr "`%s' - звычайна функцыя"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr ""
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%s' is initialized"
 msgid "parameter %qD is initialized"
@@ -29149,264 +29181,264 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr ""
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr ""
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %q+D"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero or negative size array %q+D"
 msgstr "нулявы памер масіва `%D'"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, fuzzy, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr ""
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr ""
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qs has invalid type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr ""
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr ""
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr ""
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr ""
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `const'"
 msgid "duplicate %<const%>"
 msgstr "паўтарэнне \"const\""
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<restrict%>"
 msgstr "паўтарэнне \"restrict\""
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate %<volatile%>"
 msgstr "паўтарэнне \"volatile\""
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<_Atomic%>"
 msgstr "паўтарэнне \"restrict\""
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr ""
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr ""
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -29414,81 +29446,81 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr ""
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr ""
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr ""
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, fuzzy, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of array %qE is negative"
 msgstr "адмоўны памер масіва "
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "адмоўны памер масіва "
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array %qE is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of unnamed array is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support flexible array members"
@@ -29495,627 +29527,627 @@
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%<[*]%> not in a declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qE declared as function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function definition has qualified void return type"
 msgstr "функцыя не вяртае тып string"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field has atomic type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr ""
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr ""
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, fuzzy, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, fuzzy, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, fuzzy, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, fuzzy, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, fuzzy, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr ""
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr ""
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr ""
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr ""
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "struct defined here"
 msgstr "папярэдняе вызначэньне"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "union defined here"
 msgstr "папярэдняе вызначэньне"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, fuzzy, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "паўтарэнне \"%s\""
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr ""
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr ""
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr ""
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr ""
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "type %qT is too large"
 msgstr "%s - вельмі вялікі"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "перанакіраванне stdout: %s"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "redeclaration of %<enum %E%>"
 msgstr "абвяшчэньне `%#D'"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, fuzzy, gcc-internal-format
 #| msgid "return type of `%s' is not `int'"
 msgid "return type defaults to %<int%>"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for `%s'"
 msgid "no previous prototype for %qD"
 msgstr "няма папярэдняга прататыпа для \"%s\""
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for `%s'"
 msgid "no previous declaration for %qD"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, fuzzy, gcc-internal-format
 #| msgid "return type of `%s' is not `int'"
 msgid "return type of %qD is not %<int%>"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is usually a function"
 msgid "%qD is normally a non-static function"
 msgstr "`%s' - звычайна функцыя"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr ""
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr ""
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr ""
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "number of arguments doesn%'t match prototype"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "prototype declaration"
 msgstr "пустое абвяшчэньне"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
@@ -30124,210 +30156,210 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qE"
 msgstr "паўтарэньне `%s'"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
 msgstr "`long long long' - вельмі доўга для GCC"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support `long long'"
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C89 не падтрымлівае `long long'"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support `long long'"
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C89 не падтрымлівае `long long'"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not at beginning of declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s не падтрымлівае %s"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C90 does not support %qE"
 msgstr "%s не падтрымлівае %s"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не падтрымлівае просты \"complex\" у значэнні \"double complex\""
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -30337,7 +30369,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr ""
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr ""
@@ -30359,8 +30391,8 @@
 msgid "unknown type name %qE"
 msgstr "невядомая назва рэгістра: %s"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration specifiers"
@@ -30377,7 +30409,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "\"%s\" атрыбут ігнарыруецца"
@@ -30456,7 +30488,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -30515,14 +30547,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -30982,32 +31014,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
@@ -31017,47 +31049,47 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
@@ -31072,13 +31104,13 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr ""
@@ -31088,27 +31120,27 @@
 msgid "expression must be integral"
 msgstr ""
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a constant"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
@@ -31140,17 +31172,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr ""
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%-code"
 msgid "invalid schedule kind"
@@ -31171,12 +31203,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -31196,19 +31228,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "нерэчаісны %%d аперанд"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "нерэчаісная маска"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -31218,59 +31250,59 @@
 msgid "invalid proc_bind kind"
 msgstr "Нерэчаісны выбар %s"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%qs is not valid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr ""
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid pragma"
 msgstr "нерэчаісная маска"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -31280,17 +31312,17 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr ""
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -31300,237 +31332,237 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr ""
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr ""
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr ""
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr ""
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr ""
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, gcc-internal-format
 msgid "pragma simd must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr ""
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr ""
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr ""
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr ""
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, gcc-internal-format
 msgid "base of array section must be pointer or array type"
 msgstr ""
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr ""
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 msgid "array notations cannot be used with function type"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, gcc-internal-format
 msgid "expected array notation expression"
 msgstr ""
@@ -31541,7 +31573,7 @@
 msgid "%qD has an incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -31647,7 +31679,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -31771,7 +31803,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
@@ -31801,7 +31833,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -31888,7 +31920,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
@@ -31923,7 +31955,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr ""
@@ -32006,7 +32038,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -32160,7 +32192,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -32297,7 +32329,7 @@
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr ""
@@ -32343,7 +32375,7 @@
 msgid "invalid initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -32489,7 +32521,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C не падтрымлівае \"goto *expr;\""
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function declared %<noreturn%> has a %<return%> statement"
@@ -32500,7 +32532,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -32605,17 +32637,17 @@
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
@@ -32666,12 +32698,12 @@
 msgstr ""
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
@@ -32696,85 +32728,85 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
@@ -32784,17 +32816,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -32804,7 +32836,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
@@ -32814,17 +32846,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
@@ -32839,47 +32871,47 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -32890,34 +32922,34 @@
 msgstr ""
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "  no known conversion from %qT to %qT"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, gcc-internal-format
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -32924,84 +32956,84 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, gcc-internal-format
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr ""
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, gcc-internal-format
 msgid "%s%D(%T, %T) <built-in>"
 msgstr ""
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, gcc-internal-format
 msgid "%s%D(%T) <built-in>"
 msgstr ""
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, gcc-internal-format
 msgid "%s%T <conversion>"
 msgstr ""
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr ""
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr ""
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr ""
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, gcc-internal-format
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr ""
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
@@ -33008,463 +33040,463 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr ""
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "Унутраная памылка: %s"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 #| msgid "%s\n"
 msgid "%qs"
 msgstr "%s\n"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr ""
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, fuzzy, gcc-internal-format
 msgid "non-placement deallocation function %q+D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr ""
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, fuzzy, gcc-internal-format
 #| msgid "impossible operator '%s'"
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "немагчымы апэратар '%s'"
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr ""
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr ""
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr ""
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr ""
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, gcc-internal-format
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, gcc-internal-format
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "invalid conversion from %qT to %qT"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, gcc-internal-format
 msgid "  initializing argument %P of %q+D"
 msgstr ""
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find source %s"
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "не магу знайсці крыніцу %s"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr ""
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, gcc-internal-format
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr ""
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, gcc-internal-format
 msgid "  in call to %q+D"
 msgstr ""
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr ""
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "  for conversion from %qT to %qT"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr ""
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr ""
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "could not convert %qE from %qT to %qT"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr ""
@@ -33621,7 +33653,7 @@
 msgid "  by %q+D"
 msgstr ""
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
@@ -33631,7 +33663,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr ""
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr ""
@@ -33641,7 +33673,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr ""
@@ -33771,67 +33803,77 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4538
+#: cp/class.c:4300
+#, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, gcc-internal-format
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr ""
+
+#: cp/class.c:4557
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, gcc-internal-format
 msgid "  non-static data member %q+D has non-literal type"
 msgstr ""
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, gcc-internal-format
 msgid "  non-static data member %q+D has volatile type"
 msgstr ""
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr ""
@@ -33838,104 +33880,104 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "redefinition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, fuzzy, gcc-internal-format
 #| msgid "language %s not recognized"
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "мова %s не распазнана"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -33945,13 +33987,13 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %q#D"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr ""
@@ -33991,256 +34033,256 @@
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr ""
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function `%s'"
 msgid "call to internal function"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr ""
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr ""
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "array subscript out of bound"
 msgstr ""
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, gcc-internal-format
 msgid "negative array subscript"
 msgstr ""
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "%qD used in its own initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%q#D is not const"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, gcc-internal-format
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, fuzzy, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
@@ -34311,7 +34353,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr ""
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr ""
@@ -34351,7 +34393,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -34361,293 +34403,293 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "conversion from %q#T to %q#T"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr ""
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr ""
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr ""
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr ""
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr ""
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr ""
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -35070,239 +35112,239 @@
 msgid "template parameters do not match template %qD"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr ""
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr ""
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, fuzzy, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr ""
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qD"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qD"
@@ -35311,850 +35353,850 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr ""
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr ""
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "нулявы памер масіва `%D'"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> variable"
 msgstr ""
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "ініцыялізацыя"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, gcc-internal-format
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr ""
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, fuzzy, gcc-internal-format
 #| msgid "`main' must return `int'"
 msgid "%<::main%> must return %<int%>"
 msgstr "`main' павінна вяртаць `int'"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, fuzzy, gcc-internal-format
 msgid "%q+#D explicitly defaulted here"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "size of array %qD has non-integral type %qT"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is negative"
 msgid "size of array %qD is negative"
 msgstr "памер масіва `%D' - адмоўны"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "адмоўны памер масіва "
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as array of void"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr ""
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as non-member"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as parameter"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "пустое абвяшчэнне"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration `%#D'"
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "канфлікт з папярэднім абвяшчэньнем `%#D'"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не падтрымлівае просты \"complex\" у значэнні \"double complex\""
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ не падтрымлівае \"long long\""
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "long, short, signed ці unsigned нерэчаісны для \"%s\""
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long long%> invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long%> invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<short%> invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "long, short, signed ці unsigned нерэчаісны для \"%s\""
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr ""
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "long, short, signed ці unsigned нерэчаісны для \"%s\""
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed ці unsigned нерэчаісны для \"%s\""
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "complex invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr ""
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "multiple storage classes in declaration of %qs"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qs declared as function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
@@ -36161,474 +36203,474 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr ""
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, fuzzy, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Не магу знайсці файл для класа %s."
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr ""
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr ""
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array %qs is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "%<explicit%> outside class declaration"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, fuzzy, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "Не магу знайсці дэкларацыю пратакола для \"%s\""
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, gcc-internal-format
 msgid "non-static data member declared %<auto%>"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "нерэчаіснае выкарыстаньне `::'"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr ""
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "declaration of %qD as member of %qT"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, gcc-internal-format
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -36648,175 +36690,175 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr ""
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr ""
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%qD has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%q+T has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -36828,90 +36870,90 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "redeclaration of %qT as a non-template"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %q+D"
 msgstr "папярэдняе абвяшчэньне `%D'"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr ""
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr ""
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "паўтарэнне \"restrict\""
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr ""
@@ -36920,90 +36962,90 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr ""
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr ""
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for `%s'"
 msgid "no previous declaration for %q+D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "invalid function declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %q+D set but not used"
 msgstr "адмеціна `%D' вызначана, але не выкарыстоўваецца"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "не знойдзен клас \"%s\""
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -37043,7 +37085,7 @@
 msgid "deleting %qT is undefined"
 msgstr "метка \"%s\" ужываецца, але не вызначана"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "пустое абвяшчэнне"
@@ -37066,7 +37108,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -37156,27 +37198,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -37185,47 +37227,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr ""
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, gcc-internal-format
 msgid "%q#D, declared using anonymous type, is used but never defined"
 msgstr ""
@@ -37234,48 +37276,48 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "inline function %q+D used but never defined"
 msgstr "адмеціна `%D' выкарыстоўвываецца, але ня вызначана"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "аргумент для \"%s\" прапушчан"
@@ -37282,12 +37324,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
@@ -37867,42 +37909,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr ""
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -38032,17 +38074,17 @@
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, gcc-internal-format
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, gcc-internal-format
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
@@ -38460,7 +38502,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr ""
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -38485,7 +38527,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -38550,7 +38592,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "Не магу знайсці дэкларацыю інтэрфейса для \"%s\""
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "\"%s\" мае незавершаны тып"
@@ -38575,7 +38617,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -38846,7 +38888,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
@@ -39022,7 +39064,7 @@
 msgid "capture of non-variable %qD "
 msgstr ""
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, fuzzy, gcc-internal-format
 msgid "%q+#D declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -39084,7 +39126,7 @@
 msgid "compound-statement in constexpr function"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
@@ -39115,7 +39157,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected iteration-statement"
@@ -39147,12 +39189,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
@@ -39200,7 +39242,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
@@ -39292,12 +39334,12 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
@@ -39312,7 +39354,7 @@
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -39389,214 +39431,214 @@
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids label declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr ""
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not an enumerator-name"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "multiple definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids an empty source file"
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a namespace-name"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "expected initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -39605,7 +39647,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "нерэчаісны абвяшчальнік"
@@ -39612,299 +39654,299 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declarator"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate cv-qualifier"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate virt-specifier"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %<auto%>"
 msgstr "нерэчаіснае выкарыстаньне `%D'"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr ""
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr ""
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "немагчыма знайсьці файл для кляса %s"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "previous definition of %q+#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr ""
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "невыкарыстаемы параметр \"%s\""
@@ -39913,542 +39955,542 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe не падтрымліваецца."
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "пустое абвяшчэнне"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ не падтрымлівае \"long long\""
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qD"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qs"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, fuzzy, gcc-internal-format
 #| msgid "unregistered operator %s"
 msgid "expected %<operator%>"
 msgstr "нераспазнаны аператар %s"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid type for instance variable"
 msgstr "нерэчаісны рэжым для gen_tst_reg"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid type for property"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected positive integer expression"
 msgstr ""
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr ""
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, gcc-internal-format
 msgid "not enough collapsed for loops"
 msgstr ""
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr ""
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, gcc-internal-format
 msgid "expected variable-name"
 msgstr ""
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "  from definition of %q+#D"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of alias template %qD"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -40455,67 +40497,67 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, gcc-internal-format
 msgid "candidate is: %#D"
 msgstr ""
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr ""
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, gcc-internal-format
 msgid "too many template headers for %D (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -40522,58 +40564,58 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a template function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, fuzzy, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -40586,93 +40628,93 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "у функцыі \"%s\":"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr ""
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %q+#D"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, fuzzy, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr ""
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -40679,12 +40721,12 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
@@ -40692,42 +40734,42 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr ""
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -40737,58 +40779,58 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "template definition of non-template %q#D"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, fuzzy, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -40795,7 +40837,7 @@
 msgstr[0] "нявернае выкарыстанне \"restict\""
 msgstr[1] "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q+D used %d template parameter"
 msgid_plural "previous declaration %q+D used %d template parameters"
@@ -40802,12 +40844,12 @@
 msgstr[0] "няма папярэдняга аб'яўлення для \"%s\""
 msgstr[1] "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
@@ -40816,103 +40858,103 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "original definition appeared here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -40919,174 +40961,174 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qD"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, gcc-internal-format
 msgid "  could not resolve address from overloaded function %qE"
 msgstr ""
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "in template argument for type %qT "
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr ""
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr ""
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr ""
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
@@ -41093,77 +41135,77 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr ""
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr ""
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, fuzzy, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
@@ -41181,270 +41223,270 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "нерэчаісны тып парамэтра `%T'"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "у абвяшчэньні  `%D'"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function returning an array"
 msgstr "функцыя не вяртае тып string"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, gcc-internal-format
 msgid "%q+D declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr ""
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 msgid "%s %#S"
 msgstr ""
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
@@ -41456,62 +41498,62 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
@@ -41752,260 +41794,260 @@
 msgid "invalid base-class specification"
 msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "\"%s\" мае незавершаны тып"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, gcc-internal-format
 msgid "%<num_teams%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr ""
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
@@ -42020,117 +42062,117 @@
 msgid "lambda-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr ""
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr ""
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "сімвальная канстанта вельмі доўгая"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -42321,572 +42363,567 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr ""
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr ""
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to member function %q#D"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to member function %q#D"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %q#D"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %q#D"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "left rotate count is negative"
 msgstr "адмоўны памер масіва "
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr ""
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr ""
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr ""
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, gcc-internal-format
 msgid "taking address of constructor %qE"
 msgstr ""
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, gcc-internal-format
 msgid "taking address of destructor %qE"
 msgstr ""
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr ""
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr ""
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids an empty source file"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr ""
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, gcc-internal-format
 msgid "useless cast to type %qT"
 msgstr ""
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, fuzzy, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "converting from %qT to %qT"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr ""
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, fuzzy, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Нерэчаісны выбар %s"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr ""
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr ""
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr ""
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "cannot convert %qT to %qT"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr ""
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr ""
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr ""
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr ""
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, gcc-internal-format
 msgid "address of label %q+D returned"
 msgstr ""
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr ""
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -42893,46 +42930,46 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr ""
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -43165,123 +43202,123 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr ""
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr ""
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr ""
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr ""
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
@@ -43458,8 +43495,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -43594,7 +43631,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -43710,7 +43747,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
@@ -44299,12 +44336,12 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
@@ -44574,6 +44611,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr ""
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -44581,7 +44623,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -44804,400 +44846,400 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "ініцыялізацыя"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, gcc-internal-format
 msgid "Function name %qs not allowed at %C"
 msgstr ""
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization"
 msgid "Old-style initialization at %C"
 msgstr "ініцыялізацыя"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -45204,797 +45246,802 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "Missing name"
 msgid "Missing symbol"
 msgstr "Прапушчана назва"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:5597
-#, gcc-internal-format
-msgid "gfc_match_entry(): Bad state"
+#: fortran/decl.c:5595
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr ""
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr ""
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, gcc-internal-format, gfc-internal-format
+msgid "Malformed GENERIC statement at %C"
+msgstr ""
+
+#: fortran/decl.c:8526
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "невядомая назва рэгістра: %s"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr ""
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
@@ -46276,343 +46323,343 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr ""
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, gcc-internal-format
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, gcc-internal-format
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "Conversion from %qs to %qs at %L"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "can't close input file %s"
 msgid "can't open input file: %s"
@@ -46635,27 +46682,27 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr ""
@@ -46710,593 +46757,598 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr ""
+
+#: fortran/interface.c:353
+#, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr ""
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr ""
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr ""
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr ""
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr ""
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr ""
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr ""
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr ""
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr ""
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr ""
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
 msgstr ""
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, gcc-internal-format
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr ""
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, gcc-internal-format
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr ""
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr ""
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr ""
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "Unable to find symbol %qs"
 msgstr "не знойдзен клас \"%s\""
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, gcc-internal-format
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
@@ -47709,12 +47761,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
@@ -47724,7 +47776,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
@@ -47749,780 +47801,780 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr ""
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr ""
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr ""
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "ERR tag label %d at %L not defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "END tag label %d at %L not defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "EOR tag label %d at %L not defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "FORMAT label %d at %L not defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr ""
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr ""
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr ""
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
 msgstr ""
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "прапушчан прабел пасля нумара \"%.*s\""
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "прапушчан прабел пасля нумара \"%.*s\""
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr ""
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr ""
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, gcc-internal-format
 msgid "Label name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, gcc-internal-format
 msgid "Duplicate construct label %qs at %C"
 msgstr ""
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr "сімвальная канстанта вельмі доўгая"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr ""
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr ""
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr ""
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr ""
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr ""
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr ""
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, gcc-internal-format, gfc-internal-format
 msgid "gfc_match(): Bad match code %c"
 msgstr ""
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr ""
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr ""
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr ""
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
 msgstr ""
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr ""
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr ""
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr ""
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, gcc-internal-format
 msgid "Duplicate name %qs in association at %C"
 msgstr ""
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, gcc-internal-format
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr ""
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr ""
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, gcc-internal-format
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr ""
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr ""
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr ""
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr ""
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr ""
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr ""
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr ""
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr ""
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr ""
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr ""
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr ""
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr ""
@@ -48530,147 +48582,147 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr ""
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "метка \"%s\" вызначана, але не выкарыстоўваецца"
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr ""
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr ""
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -48817,174 +48869,174 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "%s: немагчыма адчыніць файл `%s' для чытаньня: %s\n"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: немагчыма адчыніць файл `%s' для чытаньня: %s\n"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file `%s': %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: немагчыма знішчыць файл \"%s\": %s\n"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't change mode of file `%s': %s\n"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: немагчыма зьмяніць рэжым файла `%s': %s\n"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file `%s': %s\n"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: немагчыма знішчыць файл \"%s\": %s\n"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr ""
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: немагчыма адчыніць файл `%s' для чытаньня: %s\n"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr ""
@@ -49279,7 +49331,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -49972,368 +50024,363 @@
 msgid "Unexpected %s statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2428
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr ""
-
-#: fortran/parse.c:2439
-#, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr ""
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr ""
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr ""
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr ""
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In construct"
 msgid "BLOCK construct at %C"
 msgstr "У канструкцыі"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr ""
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr ""
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr ""
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr ""
@@ -50341,7 +50388,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -51037,7 +51084,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -51092,365 +51139,365 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr ""
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qs at %L is not a function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "Substring end index at %L is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -51459,12 +51506,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -51473,248 +51520,248 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -51723,188 +51770,188 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -51911,12 +51958,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -51924,158 +51971,158 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr ""
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr ""
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr ""
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -52082,7 +52129,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -52090,58 +52137,58 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr ""
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "String length at %L is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
@@ -52148,422 +52195,422 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -52570,399 +52617,399 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -52995,48 +53042,48 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr ""
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr ""
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr ""
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "пустая сімвальная канстанта"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr ""
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
 msgstr ""
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr ""
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "%s:%d: file %s left but not entered"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr ""
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s"
 msgid "Can't open file %qs"
@@ -53306,52 +53353,52 @@
 msgid "Reshaped array too large at %C"
 msgstr ""
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr ""
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr ""
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -53429,313 +53476,318 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
 #, gcc-internal-format, gfc-internal-format
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr ""
+
+#: fortran/symbol.c:489
+#, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr ""
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "\"%s\" звычайна функцыя"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, gcc-internal-format
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute with %s attribute at %L"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, gcc-internal-format
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr ""
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr ""
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr ""
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -53997,7 +54049,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
Index: gcc/po/ru.po
===================================================================
--- gcc/po/ru.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/ru.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -11,7 +11,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.8.0\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2013-07-02 16:00+0200\n"
 "Last-Translator: Pavel Maryanov <acid@jack.kiev.ua>\n"
 "Language-Team: Russian <gnu@mx.ru>\n"
@@ -203,13 +203,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "некорректное использование плавающей константы"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1428,7 +1428,7 @@
 msgid "options enabled: "
 msgstr "активные ключи: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2661,97 +2661,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "некорректный код операнда '%c'"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "некорректное %%H значение"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "некорректное %%J значение"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "некорректное значение %%r"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "некорректное значение %%R"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "некорректное значение %%N"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "некорректное значение %%P"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "некорректное значение %%h"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "некорректное значение %%L"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "некорректное значение %%M"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "некорректное значение %%M"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "некорректное значение %%U"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "некорректное значение %%s"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "некорректное значение %%C"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "некорректное значение %%E"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "некорректное unspec-перемещение"
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "некорректный код %%xn"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 msgid "invalid operand address"
 msgstr "некорректный операнд для %%d"
@@ -2803,7 +2803,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "неверный код выходного операнда"
@@ -2963,8 +2963,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3185,62 +3185,62 @@
 msgid "bad output_condmove_single operand"
 msgstr "некорректный операнд для output_condmove_single"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "некорректный операнд UNSPEC"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "недопустимый операнд для кода '%c'"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "недопустимый операнд для кода '%c'"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "недопустимый операнд для кода '%c'"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "недопустимый операнд для кода '%c'"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "операнд не является константой или кодом условия, неверный код операнда 'c'"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "операнд не является константой или кодом условия, неверный код операнда 'c'"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "операнд не является константой или кодом условия, неверный код операнда 'c'"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "операнд не является константой или кодом условия, неверный код операнда 'c'"
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "некорректный код операнда '%c'"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "некорректные ограничения для операнда"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "некорректный режим инструкции"
 
@@ -3281,7 +3281,7 @@
 msgid "invalid %%P operand"
 msgstr "неверный операнд для кода %%P"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "неверное значение для кода %%p"
@@ -3347,7 +3347,7 @@
 msgstr "постинкрементный адрес - не регистр"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "некорректный адрес"
 
@@ -3518,103 +3518,103 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "Генерировать код для обратного (little endian) порядка байт"
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 #, fuzzy
 msgid "bad move"
 msgstr "Некорректная проверка"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "некорректное %%H значение"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "недопустимое значение для кода %%f"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "недопустимое значение для кода %%F"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "недопустимое значение для кода %%G"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "недопустимое значение для кода %%j"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "недопустимое значение для кода %%J"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "недопустимое значение для кода %%k"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "недопустимое значение для кода %%K"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "недопустимое значение для кода %%O"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "недопустимое значение для кода %%q"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "недопустимое значение для кода %%S"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "недопустимое значение для кода %%T"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "недопустимое значение для кода %%u"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "недопустимое значение для кода %%v"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "неверное значение для кода %%x"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "некорректный знак %qc в ограничителе"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Аргумент AltiVec передан в функцию без прототипа"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Не генерировать одну выходную точку для каждой функции"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load offset for fusion"
@@ -3710,60 +3710,60 @@
 msgid "invalid operand to %%S"
 msgstr "некорректный операнд для %%S"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr "создан с одной архитектурой / ABI, а используется с другим"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr "создан с одним ABI, а используется с другим"
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr "создан с одним значением endianness, а используется с другим"
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "некорректный операнд для %%Y"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "некорректный операнд для %%A"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "некорректный операнд для %%B"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, fuzzy, c-format
 msgid "invalid %%C operand"
 msgstr "неверный операнд для кода %%P"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, fuzzy, c-format
 msgid "invalid %%D operand"
 msgstr "неверный операнд для кода %%P"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "некорректный операнд для %%f"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "некорректный операнд для %%s"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "константа long long не является корректным непосредственным операндом"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "плавающая константа не является корректным непосредственным операндом"
@@ -3972,7 +3972,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ожидалось %<;%>"
@@ -3988,15 +3988,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ожидалось %<(%>"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ожидалось %<,%>"
@@ -4018,8 +4018,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ожидалось %<)%>"
@@ -4026,8 +4026,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ожидалось %<]%>"
@@ -4036,13 +4036,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "ожидалось %<;%>, %<,%> или %<)%>"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ожидалось %<}%>"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ожидалось %<{%>"
@@ -4049,8 +4049,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ожидалось %<:%>"
@@ -4073,7 +4073,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ожидалось %<while%>"
@@ -4090,34 +4090,34 @@
 msgid "expected %<.%>"
 msgstr "ожидалось %<.%>"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ожидалось %<@end%>"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ожидалось %<>%>"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ожидалось %<,%> или %<)%>"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ожидалось %<=%>"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "ожидалось %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ожидалось %<{%>"
@@ -4126,11 +4126,11 @@
 msgid "(anonymous)"
 msgstr "(anonymous)"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
@@ -4366,11 +4366,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "    включённом из %qs"
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "претенденты:"
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4425,51 +4425,51 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "неверный тип аргумента для унарного минуса"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "неверный тип аргумента для унарного плюса"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "неверный тип аргумента для побитового дополнения"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "неверный тип аргумента для abs"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "неверный тип аргумента для сопряжения"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "неверный тип аргумента для унарного плюса"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "нельзя %s указатель на неполный тип %qT"
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "нельзя %s указатель на неполный тип %qT"
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4568,7 +4568,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "Переполнение при вычислении выражения в %C"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 #, fuzzy
 msgid "array assignment"
 msgstr "Присваивание массивов"
@@ -4588,7 +4588,7 @@
 msgid "Driving:"
 msgstr "предупреждение:"
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4662,13 +4662,13 @@
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4752,7 +4752,7 @@
 msgid "Bad type in constant expression"
 msgstr "переполнение при вычислении константного выражения"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "некорректный операнд"
@@ -4784,11 +4784,11 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr "присваивание"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 #, fuzzy
 msgid "pointer assignment"
 msgstr "присваивание"
@@ -4807,216 +4807,216 @@
 msgid "internal function"
 msgstr "%qs объявлена как функция, возвращающая функцию"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 #, fuzzy
 msgid "elemental procedure"
 msgstr "В подпрограмме"
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 #| msgid "no arguments"
 msgid "allocatable argument"
 msgstr "отсутствуют аргументы"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "отсутствуют аргументы"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 msgid "optional argument"
 msgstr "некорректный тип аргумента"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 msgid "pointer argument"
 msgstr "присваивание"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 msgid "target argument"
 msgstr "слишком много аргументов для форматирования"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 msgid "value argument"
 msgstr "некорректный тип аргумента"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "отсутствуют аргументы"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-shape argument"
 msgstr "несовпадающие аргументы"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-rank argument"
 msgstr "несовпадающие аргументы"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 msgid "coarray argument"
 msgstr "Присваивание массивов"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "отсутствуют аргументы"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-type argument"
 msgstr "несовпадающие аргументы"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 #, fuzzy
 msgid "result with non-constant character length"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 #, fuzzy
 msgid "bind(c) procedure"
 msgstr "В подпрограмме"
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, fuzzy, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "некорректные ограничители операндов в операторе `asm'"
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 #, fuzzy
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "квалификаторы `%V' не могут быть применены к %qT"
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr "Неизвестный оператор '%s' в %%L"
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, fuzzy, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "некорректные ограничители операндов в операторе `asm'"
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 #, fuzzy
 msgid "iterator variable"
 msgstr "Выполнить отслеживание переменных"
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "в списке операндов задано некорректное выражение"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "некорректное адресное выражение"
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE "
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "ALLOCATE "
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5441,16 +5441,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr ""
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr ""
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr ""
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr "не поддерживает мультибиблиотеку"
@@ -5463,6 +5453,11 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "ключи -Xbind-now и -Xbind-lazy несовместимы"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+#, fuzzy
+msgid "profiling not supported with -mg"
+msgstr "профилирование с -mg не поддерживается\n"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "-mhard-float не поддерживается"
@@ -5471,10 +5466,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "ключи -msingle-float и -msoft-float несовместимы"
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr "для m210 обратный (little endian) порядок байт не поддерживается"
-
 #: config/cris/cris.h:184
 #, fuzzy
 msgid "do not specify both -march=... and -mcpu=..."
@@ -5506,6 +5497,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr ""
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5512,6 +5509,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr "-m32 и -m64 несовместимы"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr ""
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr "в TFP-OS не поддерживается static"
@@ -5525,6 +5526,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "ключи -mbig-endian и -mlittle-endian несовместимы"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr "для m210 обратный (little endian) порядок байт не поддерживается"
+
 #: config/avr/specs.h:68
 #, fuzzy
 msgid "shared is not supported"
@@ -5553,17 +5558,19 @@
 msgid "no processor type specified for linking"
 msgstr "в файле спецификаций отсутствует спецификация для компоновки"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr ""
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr ""
 
@@ -5599,11 +5606,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "Ключ -shared не поддерживается для VAX ELF"
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-#, fuzzy
-msgid "profiling not supported with -mg"
-msgstr "профилирование с -mg не поддерживается\n"
-
 #: fortran/lang.opt:146
 #, fuzzy
 msgid "-J<directory>\tPut MODULE files in 'directory'"
@@ -5802,9 +5804,9 @@
 msgstr ""
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -6019,10 +6021,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -6072,7 +6074,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr "не задано имя файла после %qs"
@@ -8052,48 +8054,52 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr "Считать что процессор имеет обратный порядок байт (little endian)"
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 #, fuzzy
 msgid "Specify the code model"
 msgstr "Имя целевого процессор"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr "Исключать указатель кадра в листовых функциях"
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 #, fuzzy
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr "Использовать свойства указанного процессора и планировать код для него"
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 #, fuzzy
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr "Использовать свойства указанного процессора и планировать код для него"
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 #, fuzzy
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr "Генерировать код в соответствии с заданным ABI"
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 #, fuzzy
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr "некорректный ключ плавающей арифметики: -mfpu=%s"
@@ -9246,11 +9252,17 @@
 
 #: config/i386/i386.opt:864
 #, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "Включить поддержку внутренних функций MMX и SSE при генерации кода"
+
+#: config/i386/i386.opt:868
+#, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use given stack-protector guard"
 msgstr "Использовать propolice как метод защиты стека"
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 #, fuzzy
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr "некорректный ключ плавающей арифметики: -mfpu=%s"
@@ -9625,7 +9637,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -9776,7 +9788,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
@@ -9911,7 +9923,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr "Разрешать планирование пролога функции"
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr "Не загружать PIC-регистр в прологах функций"
 
@@ -10250,336 +10262,335 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "Использовать команды манипулирования медиаданными"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr "Не генерировать команды чтения/записи с изменением адресного регистра"
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr "Генерировать команды чтения/записи с изменением адресного регистра"
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 #, fuzzy
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "вызов %<__builtin_next_arg%> без аргумента"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr "Планировать начало и конец процедуры"
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr "Возвращать все структуры в памяти (умолчание для AIX)"
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr "Возвращать короткие структуры в регистрах (умолчание для SVR4)"
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr "Более подробно следовать семантике IBM XLC"
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 #, fuzzy
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr "Генерировать программное деление плавающих для большей производительности"
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr "Не помещать плавающие константы в TOC"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr "Помещать плавающие константы в TOC"
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "Не помещать константы вида \"символ+смещение\" в TOC"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr "Помещать константы вида \"символ+смещение\" в TOC"
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr "Использовать только одно поле TOC на процедуру"
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr "Помещать все в обычный TOC"
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr "Генерировать инструкции VRSAVE при генерации кода AltiVec"
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 #, fuzzy
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr "Устаревший ключ. Используйте -mvrsave/-mno-vrsave в качестве замены"
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 #, fuzzy
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr "Ключ устарел. используйте -Os в качестве замены"
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 msgid "Generate isel instructions"
 msgstr "Генерировать команды isel"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 #, fuzzy
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr "Устаревший ключ. Используйте -misel/-mno-isel в качестве замены"
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 #, fuzzy
 msgid "Deprecated option.  Use -misel instead"
 msgstr "Ключ устарел. используйте -Os в качестве замены"
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr "Генерировать команды SPE SIMD на E500"
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 #, fuzzy
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "Генерировать команды isel"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 #, fuzzy
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr "Устаревший ключ. Используйте -mspe/-mno-spe в качестве замены"
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 #, fuzzy
 msgid "Deprecated option.  Use -mspe instead"
 msgstr "Ключ устарел. используйте -Os в качестве замены"
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 #, fuzzy
 msgid "-mdebug=\tEnable debug output"
 msgstr "Включить отладочную выдачу"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 #, fuzzy
 msgid "Use the AltiVec ABI extensions"
 msgstr "Использовать расширение указателей Cray"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 #, fuzzy
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "Не использовать команды работы с битовыми полями"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 #, fuzzy
 msgid "Use the SPE ABI extensions"
 msgstr "Использовать расширение указателей Cray"
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 #, fuzzy
 msgid "Do not use the SPE ABI extensions"
 msgstr "Не использовать команды работы с битовыми полями"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv1 ABI"
 msgstr "Использовать EABI"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv2 ABI"
 msgstr "Использовать EABI"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 msgid "using darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 msgid "using old darwin ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 #, fuzzy
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr "Использовать свойства указанного процессора и планировать код для него"
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 #, fuzzy
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "Планировать код для указанного процессора"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 #, fuzzy
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr "Вывод traceback-таблицы: full (полная), part (частичная), no (не выводить таблицу)"
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr "Не устанавливать предельные диапазоны для команд вызова"
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 #, fuzzy
 msgid "Generate Cell microcode"
 msgstr "Генерировать код SH2e"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 #, fuzzy
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "Предупреждать о классах, в которых все конструкторы и деструкторы private"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr "Предупреждать об использовании устаревших типов AltiVec 'vector long ...'"
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 #, fuzzy
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr "Выбрать метод GPR работы с плавающими значениями"
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 #, fuzzy
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "некорректный аргумент атрибута %qs"
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 #, fuzzy
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr "Размер long double (64 или 128 бит)"
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr "Задает стоимость зависимостей между командами"
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr "Задает схему расстановки nop"
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr "Задает выравнивание полей структур default/natural"
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 #, fuzzy
 msgid "Valid arguments to -malign-:"
 msgstr "некорректный аргумент атрибута %qs"
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr "Задать приоритет планирования для команд с ограничениями по dispatch-слотам"
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 #, fuzzy
 msgid "Single-precision floating point unit"
 msgstr "аргумент неупорядоченного сравнения - не плавающее значение"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 #, fuzzy
 msgid "Double-precision floating point unit"
 msgstr "аргумент неупорядоченного сравнения - не плавающее значение"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 #, fuzzy
 msgid "Floating point unit does not support divide & sqrt"
 msgstr "-fdata-sections не поддерживается для этой целевой машины"
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 #, fuzzy
 msgid "Specify Xilinx FPU."
 msgstr "Задать интерфейс (ABI)"
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 #, fuzzy
 #| msgid "Align destination of the string operations"
 msgid "Allow sign extension in fusion operations"
 msgstr "Выравнивать результаты строковых операций"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
-#, fuzzy
-msgid "Use ISA 2.07 crypto instructions"
-msgstr "Использовать команды MIPS-3D"
+#: config/rs6000/rs6000.opt:566
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr ""
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 #, fuzzy
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr "Использовать команды манипулирования медиаданными"
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Генерировать команды множественного чтения/записи"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -13702,1659 +13713,1659 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr "Базовое имя файла для дампов"
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "Выравнивать начало функций"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr "Выравнивать метки, доступные только по командам переходов"
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr "Выравнивать все метки"
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "Выравнивать начало циклов"
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr ""
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr "Этот ключ устарел; используйте -Wextra."
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr "Генерировать unwind-таблицы, корректные на начало каждой команды"
 
-#: common.opt:918
+#: common.opt:921
 #, fuzzy
 msgid "Generate auto-inc/dec instructions"
 msgstr "Генерировать команды isel"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr "Оценивать вероятность переходов на основе данных профилирования"
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "Генерировать код для проверки выхода за границы массивов"
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr "Генерировать для циклов переход по счётчику вместо команд продвижения счётчика, сравнения и перехода"
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr "Оценивать вероятность переходов на основе данных профилирования"
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr "Оптимизировать чтение из памяти в точках, куда передается управление, до генерации прологов и эпилогов"
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr "Оптимизировать чтение из памяти в точках, куда передается управление, после генерации прологов и эпилогов"
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr "Ограничить миграцию регистров, в которые помещаются целевые адреса переходов, чтобы не переиспользовать эти регистры ни в каких блоках"
 
-#: common.opt:960
+#: common.opt:963
 #, fuzzy
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr "Считать, что <регистр> сохраняется при вызовах функций"
 
-#: common.opt:964
+#: common.opt:967
 #, fuzzy
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr "Считать, что <регистр> портится при вызовах функций"
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr "Сохранять/восстанавливать регистры до/после вызовов функций"
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr ""
 
-#: common.opt:979
+#: common.opt:982
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++"
 msgstr "Проверять результат new"
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr "Не размещать неинициализированные глобальные данные в общих блоках"
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr ""
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr ""
 
-#: common.opt:1003
+#: common.opt:1006
 #, fuzzy
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr "Выполнить глобальную экономию общих подвыражений после распределения регистров"
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr ""
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr "Выполнить оптимизацию распространения копий регистров"
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr "Выполнить оптимизацию кода вокруг команд передачи управления"
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr "При экономии общих подвыражений прослеживать код, доступный по переходам"
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr "Отбрасывать шаг редукции отрезка при выполнении комплексного деления"
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr ""
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr "Размещать элементы данных в отдельных секциях"
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr ""
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr ""
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr "Откладывать \"на потом\" выталкивание аргументов из стека после вызовов функций"
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr "Заполнять гнезда задержки команд перехода"
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr "Удалять ненужные сравнения указателей с нулем"
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization"
 msgstr "Формировать суперблоки методом дублирования хвостов"
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1085
+#: common.opt:1088
 #, fuzzy
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr "Выдавать местоположение источника сообщения один раз или для каждой строки (для многострочных сообщений)"
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr "Дополнять диагностические сообщения ключом, который контролирует это сообщение"
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1145
 #, fuzzy
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr "Выдать внутреннюю информацию компилятора в файл"
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr ""
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr ""
 
-#: common.opt:1157
+#: common.opt:1160
 #, fuzzy
 msgid "Suppress output of addresses in debugging dumps"
 msgstr "Подавлять вывод номеров инструкций и номеров строк в отладочных дампах"
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 #, fuzzy
 msgid "Dump optimization passes"
 msgstr "Выполнить полную оптимизацию перемещения регистров"
 
-#: common.opt:1170
+#: common.opt:1173
 #, fuzzy
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr "Подавлять вывод номеров инструкций и номеров строк в отладочных дампах"
 
-#: common.opt:1174
+#: common.opt:1177
 #, fuzzy
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr "Подавлять вывод номеров инструкций и номеров строк в отладочных дампах"
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr "Выполнить inline-подстановки на ранних проходах оптимизации"
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr "Исключить дублирование информации DWARF2"
 
-#: common.opt:1190
+#: common.opt:1193
 #, fuzzy
 msgid "Perform interprocedural reduction of aggregates"
 msgstr "Выполнить межпроцедурное распространение констант"
 
-#: common.opt:1194
+#: common.opt:1197
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info"
 msgstr "Исключить отладочную информацию о неиспользуемых типах"
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr "Исключить отладочную информацию о неиспользуемых типах"
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "Активировать обработку исключительных ситуаций"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr "Выполнить некоторые дополнительные дорогостоящие оптимизации"
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr ""
 
-#: common.opt:1217
+#: common.opt:1220
 #, fuzzy, c-format
 msgid "unknown excess precision style %qs"
 msgstr "неизвестный стиль декодирования имён '%s'"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr "Предполагать что результаты вычислений конечны и не NaN"
 
-#: common.opt:1238
+#: common.opt:1241
 #, fuzzy
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr "Не использовать <регистр> при генерации кода"
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr "Не выделять для значений типа float и double регистры повышенной точности"
 
-#: common.opt:1250
+#: common.opt:1253
 #, fuzzy
 msgid "Perform a forward propagation pass on RTL"
 msgstr "Выполнить оптимизацию распространения диапазонов значений на древовидном представлении"
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, fuzzy, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "не плавающий аргумент в вызове функции %qs"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr "Разрешить хранение адресов функций на регистрах"
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr "Помещать каждую функцию в отдельную секцию"
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr "Выполнить глобальную экономию общих подвыражений"
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr "В рамках глобальной экономии общих подвыражений выполнить расширенный перенос чтений из памяти между блоками"
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr "В рамках глобальной экономии общих подвыражений выполнить перенос записей в память между блоками"
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr "В рамках глобальной экономии общих подвыражений исключать лишние чтения из памяти после записей по тем же адресам"
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr "Выполнить глобальную экономию общих подвыражений после распределения регистров"
 
-#: common.opt:1305
+#: common.opt:1308
 #, fuzzy
 msgid "Enable in and out of Graphite representation"
 msgstr "Выполнить оптимизацию удаления мертвых команд записи в память"
 
-#: common.opt:1309
+#: common.opt:1312
 #, fuzzy
 msgid "Enable Graphite Identity transformation"
 msgstr "Выдавать граф вызовов"
 
-#: common.opt:1313
+#: common.opt:1316
 #, fuzzy
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr "Использовать условные команды move"
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr ""
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr ""
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr ""
 
-#: common.opt:1330
+#: common.opt:1333
 #, fuzzy
 msgid "Enable Loop Blocking transformation"
 msgstr "Включить линейные трансформации циклов на древовидном представлении"
 
-#: common.opt:1334
+#: common.opt:1337
 #, fuzzy
 msgid "Enable Loop Unroll Jam transformation"
 msgstr "Включить автоматическую конкретизацию шаблонов"
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr "Оценивать вероятности переходов"
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr "Обрабатывать директивы #ident"
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr "Преобразовывать условные переходы в эквивалентный код без переходов"
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr "Преобразовывать условные переходы в условно выполняемый код"
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, fuzzy, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "неизвестная машинный режим %qs"
 
-#: common.opt:1394
+#: common.opt:1397
 #, fuzzy
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr "Преобразовывать условные переходы в эквивалентный код без переходов"
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr ""
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr "Не генерировать директивы .size"
 
-#: common.opt:1410
+#: common.opt:1413
 #, fuzzy
 msgid "Perform indirect inlining"
 msgstr "Выполнить inline-подстановки на ранних проходах оптимизации"
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 #, fuzzy
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "Подставлять тела простых функций в места вызовов"
 
-#: common.opt:1424
+#: common.opt:1427
 #, fuzzy
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "Подставлять тела функций, вызываемых один раз, в места вызовов"
 
-#: common.opt:1428
+#: common.opt:1431
 #, fuzzy
 msgid "Integrate functions only required by their single caller"
 msgstr "Подставлять тела функций, вызываемых один раз, в места вызовов"
 
-#: common.opt:1435
+#: common.opt:1438
 #, fuzzy
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr "Максимальный <размер> функций для inline-подстановки"
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr "При входе и выходе из функции генерировать вызовы профилирования"
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1458
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation"
 msgstr "Выполнить межпроцедурное распространение констант"
 
-#: common.opt:1459
+#: common.opt:1462
 #, fuzzy
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr "Выполнить межпроцедурное распространение констант"
 
-#: common.opt:1463
+#: common.opt:1466
 #, fuzzy
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr "Выполнить межпроцедурное распространение констант"
 
-#: common.opt:1467
+#: common.opt:1470
 #, fuzzy
 msgid "Perform interprocedural profile propagation"
 msgstr "Выполнить межпроцедурное распространение констант"
 
-#: common.opt:1471
+#: common.opt:1474
 #, fuzzy
 msgid "Perform interprocedural points-to analysis"
 msgstr "Выполнить межпроцедурное распространение констант"
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr "Выявлять pure и const функции"
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables"
 msgstr "Выполнить развертку всех циклов"
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr "Выявлять неадресуемые статические переменные, доступные только для чтения"
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr ""
 
-#: common.opt:1506
+#: common.opt:1509
 #, fuzzy, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "неизвестная машинный режим %qs"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr ""
 
-#: common.opt:1519
+#: common.opt:1522
 #, fuzzy, c-format
 msgid "unknown IRA region %qs"
 msgstr "неизвестное имя регистра: %s"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr "Оптимизировать индуктивные переменные в древовидном представлении"
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "Использовать таблицы переходов для достаточно больших операторов switch"
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr "Генерировать код для функций даже при 100%% inline-подстановке"
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr "Не удалять даже неиспользуемые статические константные переменные"
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr "Добавлять в начало внешних символов подчеркивание"
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 #, fuzzy
 msgid "Enable link-time optimization."
 msgstr "Включить оптимизации компоновки"
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "неизвестная машинный режим %qs"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr ""
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 #, fuzzy
 msgid "Report various link-time optimization statistics"
 msgstr "Выполнить оптимизацию переименования регистров"
 
-#: common.opt:1625
+#: common.opt:1628
 #, fuzzy
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr "Выполнить оптимизацию переименования регистров"
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr "Устанавливать errno после вызовов встроенных мат. функций"
 
-#: common.opt:1633
+#: common.opt:1636
 #, fuzzy
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr "Максимальный коэффициент развертки цикла"
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr "Вывести информацию о распределении памяти"
 
-#: common.opt:1641
+#: common.opt:1644
 #, fuzzy
 msgid "Report on permanent memory allocation in WPA only"
 msgstr "Вывести информацию о распределении памяти"
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr "Слить идентичные константы и константные переменные"
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr "Слить идентичные константы по всем единицам компиляции"
 
-#: common.opt:1656
+#: common.opt:1659
 #, fuzzy
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr "Слить идентичные константы по всем единицам компиляции"
 
-#: common.opt:1660
+#: common.opt:1663
 #, fuzzy
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr "Установить <длину> строк диагностических сообщений в символах. 0 - подавить разбиение на строки"
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr "Выполнять планирование циклов по модулю методом SMS перед первым проходом планирования команд"
 
-#: common.opt:1668
+#: common.opt:1671
 #, fuzzy
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr "Выполнять планирование циклов по модулю методом SMS перед первым проходом планирования команд"
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr "Выносить инвариантные вычисления за пределы циклов"
 
-#: common.opt:1676
+#: common.opt:1679
 #, fuzzy
 msgid "Use the RTL dead code elimination pass"
 msgstr "Выполнить оптимизацию удаления мертвых команд записи в память"
 
-#: common.opt:1680
+#: common.opt:1683
 #, fuzzy
 msgid "Use the RTL dead store elimination pass"
 msgstr "Выполнить оптимизацию удаления мертвых команд записи в память"
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr "Включить/отменить обычное планирование для конвейеризованных циклов"
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr "Поддерживать синхронные исключения вне вызовов"
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "не задано утверждение после %qs"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 msgid "unknown offload ABI %qs"
 msgstr "неизвестная машинный режим %qs"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr "По возможности не создавать кадры стека"
 
-#: common.opt:1713
+#: common.opt:1716
 #, fuzzy
 msgid "Enable all optimization info dumps on stderr"
 msgstr "Включить оптимизации циклов на древовидном представлении"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr "Оптимизировать парные вызовы и хвостовую рекурсию"
 
-#: common.opt:1729
+#: common.opt:1732
 #, fuzzy
 msgid "Perform partial inlining"
 msgstr "Выполнить inline-подстановки на ранних проходах оптимизации"
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr ""
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr "Паковать поля структур без дыр"
 
-#: common.opt:1745
+#: common.opt:1748
 #, fuzzy
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr "Установить начальное максимальное выравнивание для элементов структур"
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr "Возвращать короткие агрегатные значения в памяти, а не в регистрах"
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr "Выполнить раскатку циклов"
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr "Выполнить машинно-зависимые оптимизации"
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr "Выполнить машинно-зависимые оптимизации перед вторым планированием"
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr "Генерировать позиционно-независимый код, если возможно (режим large)"
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr "Генерировать позиционно-независимый код для выполняемых модулей, если возможно (режим large)"
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr "Генерировать позиционно-независимый код, если возможно (режим small)"
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr "Генерировать позиционно-независимый код для выполняемых модулей, если возможно (режим small)"
 
-#: common.opt:1781
+#: common.opt:1784
 #, fuzzy
 msgid "Specify a plugin to load"
 msgstr "Задать ключи GNAT"
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr ""
 
-#: common.opt:1789
+#: common.opt:1792
 #, fuzzy
 msgid "Run predictive commoning optimization."
 msgstr "Выполнить оптимизацию перемещения регистров"
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr "Генерировать команды предвыборки элементов массивов, если они поддерживаются"
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr "Включить генерацию базового кода для профилирования"
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr "Вставлять код для профилирования по дугам управляющего графа программы"
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr "Активировать ключи генерации данных профилирования для выполнения соответствующих оптимизаций"
 
-#: common.opt:1818
+#: common.opt:1821
 #, fuzzy
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Активировать ключи генерации данных профилирования для выполнения соответствующих оптимизаций"
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr "Активировать ключи оптимизаций, основанных на данных профилирования"
 
-#: common.opt:1826
+#: common.opt:1829
 #, fuzzy
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Активировать ключи оптимизаций, основанных на данных профилирования"
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr "Вставлять код для профилирования значений выражений"
 
-#: common.opt:1834
+#: common.opt:1837
 #, fuzzy
 msgid "Report on consistency of profile"
 msgstr "обнаружена несогласованность внутреннего представления gcc"
 
-#: common.opt:1838
+#: common.opt:1841
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement"
 msgstr "Переупорядочить функции для улучшения размещения кода"
 
-#: common.opt:1845
+#: common.opt:1848
 #, fuzzy
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr "Компилировать воспроизводимым образом, используя <строку> для генерации случайных чисел"
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr "Возвращать короткие агрегатные в регистрах"
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr ""
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr "Выполнить оптимизацию переименования регистров"
 
-#: common.opt:1880
+#: common.opt:1883
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr "Выполнить оптимизацию переименования регистров"
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr "Переупорядочить блоки для улучшения размещения кода"
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr "Переупорядочить блоки и партиции в hot и cold разделы"
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr "Переупорядочить функции для улучшения размещения кода"
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr "Выполнить экономию общих подвыражений еще и после оптимизации циклов"
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr "Отменить оптимизации, предполагающие стандартное округление вещественных значений"
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr "Планировать команды в рамках нескольких блоков"
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr "Разрешить спекулятивный перенос команд, кроме чтения"
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr "Разрешить спекулятивный перенос некоторых команд чтения"
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr "Разрешить более активный спекулятивный перенос команд чтения"
 
-#: common.opt:1928
+#: common.opt:1931
 #, fuzzy
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr "Установить уровень подробности сообщений от планировщика"
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr "При планировании после распределения регистров, использовать метод суперблоков"
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr "Планировать код перед распределением регистров"
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr "Планировать код после распределения регистров"
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr ""
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr ""
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr ""
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr "Разрешить предварительное планирование отложенных команд"
 
-#: common.opt:1981
+#: common.opt:1984
 #, fuzzy
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr "Число отложенных команд, подлежащих предварительному планированию"
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr "Включить проверку дальности зависимостей при предварительном планировании отложенных команд"
 
-#: common.opt:1993
+#: common.opt:1996
 #, fuzzy
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr "Включить проверку дальности зависимостей при предварительном планировании отложенных команд"
 
-#: common.opt:1997
+#: common.opt:2000
 #, fuzzy
 msgid "Enable the group heuristic in the scheduler"
 msgstr "Установить уровень подробности сообщений от планировщика"
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2009
+#: common.opt:2012
 #, fuzzy
 msgid "Enable the rank heuristic in the scheduler"
 msgstr "Установить уровень подробности сообщений от планировщика"
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr ""
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 #, fuzzy
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr "Показывать номера колонок в диагностических сообщений. По умолчанию включено"
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr "Отменить оптимизации, влияющие на поведение сигнализирующих NaN по IEEE"
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr ""
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr "Преобразовывать вещественные константы к значениям одинарной точности"
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr "Разбивать диапазоны жизни индуктивных переменных при развертке циклов"
 
-#: common.opt:2062
+#: common.opt:2065
 #, fuzzy
 msgid "Generate discontiguous stack frames"
 msgstr "Генерировать APCS-совместимые кадры стека"
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr ""
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 #, fuzzy
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr "Число регистров для передачи целочисленных аргументов"
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr "Выполнять расширение переменных при развертке циклов"
 
-#: common.opt:2082
+#: common.opt:2085
 #, fuzzy
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "Генерировать код для проверки стека"
 
-#: common.opt:2086
+#: common.opt:2089
 #, fuzzy
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "Генерировать код для проверки стека"
 
-#: common.opt:2093
+#: common.opt:2096
 #, fuzzy
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr "Прерывание при переполнении стека, <регистр> задает границу стека"
 
-#: common.opt:2097
+#: common.opt:2100
 #, fuzzy
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr "Прерывание при переполнении стека, <символ> задает границу стека"
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr "Использовать propolice как метод защиты стека"
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr "Использовать защиту стека для каждой функции"
 
-#: common.opt:2109
+#: common.opt:2112
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions"
 msgstr "Использовать защиту стека для каждой функции"
 
-#: common.opt:2113
+#: common.opt:2116
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr "Использовать защиту стека для каждой функции"
 
-#: common.opt:2117
+#: common.opt:2120
 #, fuzzy
 msgid "Output stack usage information on a per-function basis"
 msgstr "Включить использование r30"
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr "Предполагать строгое соблюдение правил перекрытия данных в памяти"
 
-#: common.opt:2133
+#: common.opt:2136
 #, fuzzy
 msgid "Treat signed overflow as undefined"
 msgstr "Трактовать отсутствующие заголовки как генерируемые файлы"
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr "Проверить код на наличие синтаксических ошибок и завершить работу"
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr "Создать файлы данных для \"gcov\""
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr "Выполнить протягивание переходов"
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr "Показать время, затраченное на каждый проход оптимизации"
 
-#: common.opt:2157
+#: common.opt:2160
 #, fuzzy
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr "Модель генерации кода для данных, локальных для потов, по умолчанию"
 
-#: common.opt:2160
+#: common.opt:2163
 #, fuzzy, c-format
 msgid "unknown TLS model %qs"
 msgstr "неизвестная машинный режим %qs"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr "Формировать суперблоки методом дублирования хвостов"
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr "Предполагать возможность прерываний при плавающих операциях"
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr "Прерывания при знаковых операциях сложения, вычитания, умножения"
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr "Включить SSA-оптимизацию  распространения констант на древовидном представлении"
 
-#: common.opt:2199
+#: common.opt:2202
 #, fuzzy
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr "Включить SSA-оптимизацию  распространения констант на древовидном представлении"
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr "Включить копирование заголовков циклов в древовидном представлении"
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr ""
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr "Переименовывать временные SSA-переменные при копировании для более близкого соответствия программным переменным"
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr "Выполнять распространение копий в древовидном представлении"
 
-#: common.opt:2231
+#: common.opt:2234
 #, fuzzy
 msgid "Transform condition stores into unconditional ones"
 msgstr "Преобразовывать условные переходы в условно выполняемый код"
 
-#: common.opt:2235
+#: common.opt:2238
 #, fuzzy
 msgid "Perform conversions of switch initializations."
 msgstr "Преобразовывать условные переходы в условно выполняемый код"
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr "Выполнить удаление мертвого SSA-кода на древовидном представлении"
 
-#: common.opt:2243
+#: common.opt:2246
 msgid "Enable dominator optimizations"
 msgstr "Включить оптимизации доминаторов"
 
-#: common.opt:2247
+#: common.opt:2250
 #, fuzzy
 msgid "Enable tail merging on trees"
 msgstr "Включить копирование заголовков циклов в древовидном представлении"
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr "Выполнить оптимизацию удаления мертвых команд записи в память"
 
-#: common.opt:2255
+#: common.opt:2258
 #, fuzzy
 msgid "Enable forward propagation on trees"
 msgstr "Выполнять распространение копий в древовидном представлении"
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr "Выполнить полный набор оптимизаций удаления избыточного кода на древовидном  представлении"
 
-#: common.opt:2263
+#: common.opt:2266
 #, fuzzy
 msgid "Enable string length optimizations on trees"
 msgstr "Включить SSA-оптимизацию  распространения констант на древовидном представлении"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 #, fuzzy
 msgid "Enable loop distribution on trees"
 msgstr "Выполнить векторизацию циклов на древовидном представлении"
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr ""
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr "Выполнить вынесение инвариантных вычислений за пределы циклов на древовидном представлении"
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr ""
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr "Создавать канонические индуктивные переменные в циклах"
 
-#: common.opt:2300
+#: common.opt:2303
 msgid "Enable loop optimizations on tree level"
 msgstr "Включить оптимизации циклов на древовидном представлении"
 
-#: common.opt:2304
+#: common.opt:2307
 #, fuzzy
 msgid "Enable automatic parallelization of loops"
 msgstr "Включить автоматическую конкретизацию шаблонов"
 
-#: common.opt:2308
+#: common.opt:2311
 #, fuzzy
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Использовать условные команды move"
 
-#: common.opt:2312
+#: common.opt:2315
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "Включить оптимизации SSA-PRE на древовидном представлении"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 #, fuzzy
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Выполнить межпроцедурное распространение констант"
 
-#: common.opt:2324
+#: common.opt:2327
 #, fuzzy
 msgid "Enable reassociation on tree level"
 msgstr "Включить оптимизации циклов на древовидном представлении"
 
-#: common.opt:2332
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
 msgstr "Выполнить погружение SSA-кода на древовидном представлении"
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr ""
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr "Выполнить замену скаляров для агрегатных значений"
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr "Выполнить замену временных выражений на проходе SSA->normal"
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr "Выполнить разбиение диапазонов жизни значений на проходе SSA->normal"
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr "Выполнить оптимизацию распространения диапазонов значений на древовидном представлении"
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr "Компилировать весь модуль целиком (а не по функциям)"
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr "Выполнить развертку циклов с известным числом итераций"
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr "Выполнить развертку всех циклов"
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr "При оптимизации циклов предполагать нормальное поведение цикла"
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr "Разрешить оптимизации плавающих вычислений, которые могут противоречить стандартам IEEE или ISO"
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr "Выполнить декомпозицию циклов, содержащих условные ветвления"
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr "Генерировать unwind-таблицы только для обработки исключений"
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr "Выполнить отслеживание переменных"
 
-#: common.opt:2424
+#: common.opt:2427
 #, fuzzy
 msgid "Perform variable tracking by annotating assignments"
 msgstr "Выполнить отслеживание переменных"
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr ""
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr ""
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees"
 msgstr "Выполнить векторизацию циклов на древовидном представлении"
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr "Выполнить векторизацию циклов на древовидном представлении"
 
-#: common.opt:2454
+#: common.opt:2457
 #, fuzzy
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr "Выполнить векторизацию циклов на древовидном представлении"
 
-#: common.opt:2458
+#: common.opt:2461
 #, fuzzy
 msgid "Specifies the cost model for vectorization"
 msgstr "Генерировать код для прямого (big endian) порядка байт"
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "неизвестная машинный режим %qs"
 
-#: common.opt:2478
+#: common.opt:2481
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2485
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2493
 #, fuzzy
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Выполнять распространение копий для записей и загрузок"
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr "Добавить комментарии к ассемблерному коду"
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr ""
 
-#: common.opt:2507
+#: common.opt:2510
 #, fuzzy, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "некорректный тип видимости \"%s\""
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(где-то рядом с инициализацией для %qs)"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr "Использовать данные профилирования значений при оптимизациях"
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr "Снять зависимости между различными использованиями одной и той же переменной"
 
-#: common.opt:2555
+#: common.opt:2558
 #, fuzzy
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr "Выполнить удаление мертвого SSA-кода на древовидном представлении"
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr "Выполнить оптимизации на уровне всей программы"
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr "Предполагать циклический перенос при арифметических переполнениях"
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr "Помещать данные, инициализированные нулями, в секцию bss"
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr "Генерировать отладочную информацию в формате по умолчанию"
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr "Генерировать отладочную информацию в формате COFF"
 
-#: common.opt:2579
+#: common.opt:2582
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format"
 msgstr "Генерировать отладочную информацию в формате по умолчанию"
 
-#: common.opt:2583
+#: common.opt:2586
 #, fuzzy
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr "Генерировать отладочную информацию в формате DWARF версии 2"
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr "Генерировать отладочную информацию в расширенном формате по умолчанию"
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2614
 #, fuzzy
 msgid "Don't generate debug information in separate .dwo files"
 msgstr "Генерировать отладочную информацию в формате по умолчанию"
 
-#: common.opt:2615
+#: common.opt:2618
 #, fuzzy
 msgid "Generate debug information in separate .dwo files"
 msgstr "Генерировать отладочную информацию в формате по умолчанию"
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr "Генерировать отладочную информацию в формате STABS"
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr "Генерировать отладочную информацию в расширенном формате STABS"
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2638
 #, fuzzy
 msgid "Toggle debug information generation"
 msgstr "Генерировать отладочную информацию в формате VMS"
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr "Генерировать отладочную информацию в формате VMS"
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr "Генерировать отладочную информацию в формате XCOFF"
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr "Генерировать отладочную информацию в расширенном формате XCOFF"
 
-#: common.opt:2665
+#: common.opt:2668
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections"
 msgstr "Генерировать команды isel"
 
-#: common.opt:2669
+#: common.opt:2672
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr "Генерировать отладочную информацию в формате по умолчанию"
 
-#: common.opt:2676
+#: common.opt:2679
 #, fuzzy
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr "Считать <каталог> корневым каталогом системы"
 
-#: common.opt:2680
+#: common.opt:2683
 #, fuzzy
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr "Считать <каталог> корневым каталогом системы"
 
-#: common.opt:2702
+#: common.opt:2705
 #, fuzzy
 msgid "-o <file>\tPlace output into <file>"
 msgstr "Записать результат в <файл>"
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr "Включить профилирование функций"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr "Как -pedantic, но выдавать ошибки, а не предупреждения"
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr "Не отображать время компиляции функций"
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr "Включить подробную выдачу"
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr "Показать версию компилятора"
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "Подавить выдачу предупреждений"
 
-#: common.opt:2806
+#: common.opt:2809
 #, fuzzy
 msgid "Create a shared library"
 msgstr "Поддерживать разделяемые библиотеки на основе ID"
 
-#: common.opt:2851
+#: common.opt:2854
 #, fuzzy
 msgid "Create a position independent executable"
 msgstr "Генерировать позиционно-независимый код для выполняемых модулей, если возможно (режим large)"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "вычисленное значение не используется"
@@ -15390,264 +15401,264 @@
 msgid "expected integer or boolean type"
 msgstr "ожидалось выражение"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 #, fuzzy
 msgid "invalid comparison of nil with nil"
 msgstr "некорректный операнд в инструкции"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 #, fuzzy
 msgid "incompatible types in binary expression"
 msgstr "несовместимые типы в операторе возврата"
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 #| msgid "division by zero"
 msgid "integer division by zero"
 msgstr "деление на ноль"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 #, fuzzy
 msgid "shift of non-integer operand"
 msgstr "размер массива %qs имеет не целочисленный тип"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 #, fuzzy
 msgid "shift count not unsigned integer"
 msgstr "в операторе switch задано не целое"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 #, fuzzy
 msgid "negative shift count"
 msgstr "отрицательная длина RTL-инструкции"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 #, fuzzy
 msgid "object is not a method"
 msgstr "вызываемый объект %qE не является функцией"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 #, fuzzy
 msgid "method type does not match object type"
 msgstr "аргумент типа %qT не соответствует типу %qT"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 #, fuzzy
 msgid "invalid use of %<...%> with builtin function"
 msgstr "некорректный аргумент внутренней функции"
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 #, fuzzy
 #| msgid "invalid use of template-name %qE without an argument list"
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "некорректное использование имени шаблона %qE без списка аргументов"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 #, fuzzy
 msgid "not enough arguments"
 msgstr "отсутствуют аргументы"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 #, fuzzy
 msgid "too many arguments"
 msgstr "слишком много аргументов для форматирования"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 #, fuzzy
 msgid "argument 1 must be a map"
 msgstr "аргумент %qD не является константой"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 #, fuzzy
 msgid "invalid type for make function"
 msgstr "неверное употребление спецификатора %<restrict%>"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 #, fuzzy
 msgid "too many arguments to make"
 msgstr "слишком много аргументов для %s `%+#D'"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 #, fuzzy
 msgid "argument must be array or slice or channel"
 msgstr "аргумент %qD не является константой"
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 #, fuzzy
 msgid "unsupported argument type to builtin function"
 msgstr "некорректный аргумент внутренней функции"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 #, fuzzy
 msgid "argument must be channel"
 msgstr "аргумент %qD не является константой"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 #, fuzzy
 msgid "cannot close receive-only channel"
 msgstr "некорректный операнд в инструкции"
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 #, fuzzy
 msgid "argument must be a field reference"
 msgstr "маска должна быть непосредственным значением"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 #, fuzzy
 msgid "left argument must be a slice"
 msgstr "маска должна быть непосредственным значением"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 #, fuzzy
 msgid "first argument must be []byte"
 msgstr "маска должна быть непосредственным значением"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 #, fuzzy
 msgid "second argument must be slice or string"
 msgstr "аргумент %qD не является константой"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 #, fuzzy
 msgid "argument 2 has invalid type"
 msgstr "%Jпараметр %u имеет неполный void"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 #, fuzzy
 msgid "argument must have complex type"
 msgstr "%Jпараметр %u имеет неполный тип"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 #, fuzzy
 msgid "complex arguments must have identical types"
 msgstr "аргумент атрибута cleanup - не идентификатор"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 #, fuzzy
 msgid "complex arguments must have floating-point type"
 msgstr "Не использовать аппаратную плавающую арифметику"
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 #, fuzzy
 msgid "expected function"
 msgstr "Ожидалась строка"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 #, fuzzy
 msgid "multiple-value argument in single-value context"
 msgstr "декларация C-функции `%#D' противоречит"
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 #, fuzzy
 msgid "invalid use of %<...%> with non-slice"
 msgstr "некорректное использование %<this%> на внешнем уровне"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 #, fuzzy
 msgid "function result count mismatch"
 msgstr "функция возвращает агрегатное значение"
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 #, fuzzy
 msgid "incompatible type for receiver"
 msgstr "несовместимые типы в операторе возврата"
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 #, fuzzy
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "некорректное использование %<this%> в функции, не являющейся элементом"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 #, fuzzy
 msgid "number of results does not match number of values"
 msgstr "число входящих дуг не соответствует числу аргументов PHI"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 #, fuzzy
 msgid "index must be integer"
 msgstr "предикат должен быть идентификатором"
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 #, fuzzy
 msgid "slice end must be integer"
 msgstr "предикат должен быть идентификатором"
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 msgid "slice capacity must be integer"
 msgstr "предикат должен быть идентификатором"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 #, fuzzy
 msgid "incompatible type for map index"
 msgstr "несовместимые типы в присваивании"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 #, fuzzy
 msgid "too many expressions for struct"
 msgstr "слишком много аргументов для форматирования"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 #, fuzzy
 msgid "too few expressions for struct"
 msgstr "недостаточно аргументов для указанного формата"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 msgid "type assertion only valid for interface types"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 #, fuzzy
 msgid "expected channel"
 msgstr "ожидалось имя класса"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -15775,75 +15786,75 @@
 msgid "cannot use type %s as type %s"
 msgstr "некорректное преобразование от типа %qT к типу %qT"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 #, fuzzy
 msgid "different receiver types"
 msgstr "некорректный тип приемника %qs"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 #, fuzzy
 msgid "different number of parameters"
 msgstr "повторное определение параметра %q+D"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 #, fuzzy
 msgid "different parameter types"
 msgstr "некорректный тип параметра %qT"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "несовместимый тип аргумента %d функции %qE"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "несовместимый тип аргумента %d функции %qE"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 #, fuzzy
 msgid "type has no methods"
 msgstr "ошибка при грамматическом разборе методов"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, fuzzy, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "неоднозначное сокращение %s"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, fuzzy, c-format
 msgid "missing method %s%s%s"
 msgstr "отсутствует аргумент для \"%s\""
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -15964,7 +15975,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "вместо неверного третьего аргумента `__builtin_prefetch' используется ноль"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "слишком мало аргументов в вызове функции %<va_start%>"
@@ -16146,12 +16157,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "функция возвращает агрегатное значение"
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "при передаче аргумента %P функции `%+D'"
@@ -16712,244 +16723,249 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "число меток блоков в списке RTL-инструкций (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr "отрицательный счётчик дуг, соответствующих вызовам"
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, fuzzy, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr "отрицательный счётчик дуг, соответствующих вызовам"
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, fuzzy, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr "отрицательный счётчик дуг, соответствующих вызовам"
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "для дуги %s->%s установлено вспомогательное поле"
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, fuzzy, gcc-internal-format
 msgid "execution count is negative"
 msgstr "Отрицательный счётчик числа выполнений"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, fuzzy, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "ошибка при возврате ненужной функции"
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Предполагать, что символы могут быть неправильными"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, fuzzy, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "некорректный указатель inlined_to"
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "для дуги %s->%s установлено вспомогательное поле"
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "некорректный указатель inlined_to"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "множественные inline-вызовы"
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "указатель inlined_to установлен для не inline вызова"
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr "отрицательный счётчик дуг, соответствующих вызовам"
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr "отрицательный счётчик дуг, соответствующих вызовам"
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "указатель inlined_to установлен, но не найдено ни одного предшественника"
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "указатель inlined_to ссылается на себя"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, fuzzy, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "присваивание (а не инициализация) в декларации"
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, fuzzy, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr "присваивание (а не инициализация) в декларации"
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, fuzzy, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr "создание %s на ссылочный тип %qT"
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "разделяемый call_stmt:"
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "дуга указывает на неверную декларацию:"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "отсутствует дуга callgraph для инструкции вызова:"
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "ожидался оператор"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "отсутствует call_stmt, соответствующий дуге %s->%s"
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "отсутствует call_stmt, соответствующий дуге %s->%s"
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "процедура verify_cgraph_node выявила ошибки"
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "не задан аргумент ключа '-%s'"
@@ -17079,7 +17095,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "должна быть установлена COLLECT_LTO_WRAPPER"
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, fuzzy, gcc-internal-format
 msgid "atexit failed"
@@ -17320,17 +17336,17 @@
 msgid "          %s"
 msgstr "      "
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr ""
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "глобальные деструкторы не поддерживаются для этой платформы"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "глобальные конструкторы не поддерживаются для этой платформы"
@@ -17375,12 +17391,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -17575,7 +17591,7 @@
 msgid "total size of local objects too large"
 msgstr "%Jобщий размер локальных объектов слишком велик"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "некорректное ограничение в %<asm%>"
@@ -18026,9 +18042,9 @@
 msgstr "ошибка записи PCH файла"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "%q+D объявлено здесь"
@@ -18043,152 +18059,147 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr "дерево: ожидался класс %qs, обнаружен %qs (%s) в %s, на %s:%d"
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, fuzzy, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "неверное lvalue-выражение в выходном операторе %d оператора asm"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "невозможна прямая адресация к входной позиции памяти %d"
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "регистровая переменная %qD использована во вложенной функции"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "регистровая переменная %qD использована во вложенной функции"
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr "отсутствует декларация %qD в %qD"
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "instance-переменная %qs имеет неизвестный размер"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "instance-переменная %qs объявлена как private"
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "instance-переменная %qs объявлена как private"
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "регистровая переменная %qs использована во вложенной функции"
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "instance-переменная %qs объявлена как private"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "instance-переменная %qs объявлена как private"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "локальная переменная %qD недопустима в данном контексте"
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "локальная переменная %qD недопустима в данном контексте"
 
-#: gimplify.c:7001
-#, fuzzy, gcc-internal-format
-msgid "lastprivate variable %qE is private in outer context"
-msgstr "локальная переменная %qD недопустима в данном контексте"
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, gcc-internal-format
 msgid "directive not yet implemented"
 msgstr ""
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, fuzzy, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "ожидалось %<,%> или %<;%>"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "первый аргумент %<va_start%> должен иметь тип %<va_list%>"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT преобразован к %qT при передаче через %<...%>"
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(поэтому %<va_arg%> нужно передать %qT, а не %qT)"
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "при достижении этого кода выполнение программы завершится аварийно"
@@ -18613,47 +18624,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "нет класса %qs"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "нет декларации протокола для %qs"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -18738,48 +18749,48 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "неверно сформирован COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "не заданы входные файлы"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 msgid "writing output file"
 msgstr "%s:ошибка записи в выходной файл '%s'\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "переменная окружения COLLECT_GCC должна быть определена"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "переменная окружения COLLECT_GCC_OPTIONS должна быть определена"
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen %s"
@@ -18915,29 +18926,29 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "  входит в try-блок"
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "  входит в try-блок"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr "  входит в try-блок"
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "ignoring large linear step"
 msgstr "повторное задание каталога \"%s\" проигнорировано\n"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -19454,8 +19465,8 @@
 msgstr "нельзя использовать '%s' как %s регистр"
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "неизвестное имя регистра: %s"
@@ -19896,7 +19907,7 @@
 msgid "ld returned %d exit status"
 msgstr "выполнение ld завершилось с кодом возврата %d"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F используется, но нигде не определена"
@@ -20875,42 +20886,42 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr ""
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -21291,47 +21302,47 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, fuzzy, gcc-internal-format
 msgid "array subscript is outside array bounds"
 msgstr "индекс массива не является целым значением"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, fuzzy, gcc-internal-format
 msgid "array subscript is above array bounds"
 msgstr "индекс массива не является целым значением"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, fuzzy, gcc-internal-format
 msgid "array subscript is below array bounds"
 msgstr "индекс массива не является целым значением"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr ""
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr ""
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, fuzzy, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr "из-за ограниченности диапазона типа данных, результат сравнения всегда ложь"
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, fuzzy, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr "из-за ограниченности диапазона типа данных, результат сравнения всегда истина"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr ""
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr ""
@@ -21375,9 +21386,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21611,7 +21622,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "запрошенное выравнивание для %q+D превышает поддерживаемое выравнивание для %wu"
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "размер %q+D в памяти неизвестен"
@@ -21760,27 +21771,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "строка имеет длину %qd, превышающую максимальную длину %qd, которую должны поддерживать компиляторы по стандарту ISO C%d"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "сдвиг влево на отрицательное число позиций"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "сдвиг вправо на отрицательное число позиций"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "величина сдвига влево больше или равна ширине данного типа"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "величина сдвига вправо больше или равна ширине данного типа"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "переполнение при вычислении константного выражения"
@@ -22111,12 +22122,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "адрес %qD всегда будет %<истина%>"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "присваивание, используемое как логическое выражение, рекомендуется "
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "неверное употребление спецификатора %<restrict%>"
@@ -22568,12 +22579,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "неверно задан векторный тип для атрибута %qE"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "размер вектора не кратен размеру компонент"
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "нулевой размер вектора"
@@ -22583,22 +22594,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr "число компонент вектора не является степенью двойки"
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "непустой атрибут без аргументов допустим только в прототипах"
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "в непустом аргументе задан неверный номер операнда (аргумент %lu)"
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "непустой аргумент содержит номер операнда вне диапазона (аргумент %lu, операнд %lu)"
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "непустой аргумент ссылается на операнд, не являющийся указателем (аргумент %lu, операнд %lu)"
@@ -22638,12 +22649,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "атрибут %qE допустим только для функций с переменным числом аргументом"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "заданная позиция не является целой константой"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "заданная позиция меньше нуля"
@@ -22723,7 +22734,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "некорректное использование нестатической функции-элемента %qD"
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "взятие адреса от битового поля структуры %qD"
@@ -23141,7 +23152,7 @@
 msgstr "индекс размерности %d выходит за границы в %L"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "преобразование из %qT в %qT неоднозначно"
@@ -23597,7 +23608,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "неверно задан векторный тип для атрибута %qE"
@@ -23607,22 +23618,22 @@
 msgid "%qE is not initialized"
 msgstr "параметр %qD инициализирован"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "некорректный операнд условного оператора"
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "некорректный операнд условного оператора"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "подавление присваивания"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "неверное логическое выражение"
@@ -24160,6 +24171,11 @@
 msgid "too many input files"
 msgstr "слишком много входных файлов"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+msgid "-mcpu string too large"
+msgstr "кадр стека слишком велик: %d байт"
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -24186,47 +24202,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, fuzzy, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops - устаревший ключ, используйте -falign-loops"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d вне диапазона 0 - %d"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, fuzzy, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps - устаревший ключ, используйте -falign-jumps"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-loops=%d вне диапазона 0 - %d"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, fuzzy, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions - устаревший ключ, используйте -falign-functions"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-loops=%d вне диапазона 0 - %d"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d вне диапазона 0 - 5"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -24609,63 +24625,63 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr "номер операнда вне диапазона"
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "некорректное значение %qs для ключа -mtrap-precision"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "некорректное значение %qs для ключа -mfp-rounding-mode"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "некорректное значение %qs для ключа -mfp-trap-mode"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr "некорректный аргумент %qs для ключа -mcpu"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mtune switch"
 msgstr "некорректное значение (%s) для ключа -mtune="
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr "-mfp-trap-mode=su требует -mtrap-precision=i"
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "режим округления для поддерживается для плавающих вычислений VAX"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "режим прерываний для поддерживается для плавающих вычислений VAX"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr "128-битные double-значения не поддерживаются для VAX"
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr "L%d латентность кэша для %s неизвестна"
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr "некорректное значение %qs для -mmemory-latency"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -25142,14 +25158,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to functions"
@@ -25793,377 +25809,393 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "ошибка позиционирования в PCH файле: %m"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong arg %s to option %s"
 msgstr "ошибка в аргументах spec-функции '%s'"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "не задано имя регистра для %q+D"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
+#, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386.c:3012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown alignment %s specified for option %s"
 msgstr "вызов не функции %qD"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too many size ranges specified in option %s"
 msgstr "некорректный ключ плавающей арифметики: -mfpu=%s"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "отсутствует аргумент ключа %qs"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "модель кодирования %s не поддерживается в %s-битном режиме"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "модель кодирования %s не поддерживается в %s-битном режиме"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "модель кодирования %s не поддерживается в %s-битном режиме"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "модель кодирования %s не поддерживается в режиме PIC"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s в данной конфигурации не поддерживается"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-битный режим не компилируется в"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "заданный процессор не поддерживает набор команд x86-64"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s не поддерживает %s"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr "некорректное значение (%s) для ключа -mtune="
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr "некорректное значение (%s) для ключа -mtune="
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "некорректное значение (%s) для ключа -march"
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "некорректное значение (%s) для ключа -mtune="
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, fuzzy, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "соглашения о вызовах -mrtd не поддерживаются в 64-битном режиме"
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d вне диапазона 0 - %d"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr "соглашения о вызовах -mrtd не поддерживаются в 64-битном режиме"
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-arrays не поддерживается для этой целевой машины"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d вне диапазона  %d - 12"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d вне диапазона  %d - 12"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "ключ -march=%s несовместим с выбранным ABI"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "межмодульные оптимизации пока не реализованы"
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr "ключ -msseregparm использован без SSE"
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "набор команд SSE отменен, используется арифметика 387"
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "набор команд 387 отменен, используется арифметика SSE"
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr "для корректной поддержки таблиц раскрутки стека требуется либо указатель кадра, либо -maccumulate-outgoing-args"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "некорректный ключ -m%s=: '%s'"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "аргумент атрибута %qs не является строковой константой"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибуты fastcall и regparm несовместимы"
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибуты fastcall и stdcall несовместимы"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "аргументом атрибута %qs должна быть целая константа"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент атрибута %qs больше %d"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибуты fastcall и cdecl несовместимы"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибуты fastcall и stdcall несовместимы"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибуты fastcall и stdcall несовместимы"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибуты stdcall и cdecl несовместимы"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибуты stdcall и fastcall несовместимы"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибуты stdcall и fastcall несовместимы"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибуты stdcall и fastcall несовместимы"
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE для не классовых типов игнорируется"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Вызов %qD с атрибутом sseregparm без задания SSE/SSE2"
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, fuzzy, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Вызов %qT с атрибутом sseregparm без задания SSE/SSE2"
 
-#: config/i386/i386.c:5923
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr "Вызов %qD с атрибутом sseregparm без задания SSE/SSE2"
-
-#: config/i386/i386.c:6210
-#, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "не поддерживает мультибиблиотеку"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "аргумент - вектор MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "аргумент - вектор MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, fuzzy, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "аргумент - вектор MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, fuzzy, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "аргумент - вектор MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "аргумент - вектор SSE без включения SSE изменяет ABI"
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "результат - вектор SSE без включения SSE изменяет ABI"
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "аргумент - вектор MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "возврат вектора MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "возврат результата в SSE регистре без задания SSE"
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "аргумент - SSE регистр без задания SSE"
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "результат - вектор SSE без включения SSE изменяет ABI"
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, fuzzy, gcc-internal-format
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr "Вызов %qD с атрибутом sseregparm без задания SSE/SSE2"
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
+#, fuzzy, gcc-internal-format
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr "Вызов %qD с атрибутом sseregparm без задания SSE/SSE2"
+
+#: config/i386/i386.c:11378
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "индукция не поддерживается"
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "индукция не поддерживается"
@@ -26170,256 +26202,256 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 не поддерживает регулируемые элементы-массивы"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "расширенные регистры не имеют верхних половин"
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "некорректный размер операнда для расширенного регистра"
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "некорректный код операнда '%c'"
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Статическая компоновка не поддерживается.\n"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "предыдущая декларация %q+D"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "-m%s в данной конфигурации не поддерживается"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "аргумент %qs должен быть 2-битным беззнаковым литеральным значением"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "аргумент `asm' - не константная строка"
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "третий аргумент должен быть 4-битным беззнаковым литеральным значением"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "первый аргумент должен быть 5-битным знаковым литеральным значением"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "первый аргумент должен быть 5-битным знаковым литеральным значением"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "третий аргумент должен быть 4-битным беззнаковым литеральным значением"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "третий аргумент должен быть 4-битным беззнаковым литеральным значением"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "третий аргумент должен быть 4-битным беззнаковым литеральным значением"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "третий аргумент должен быть 4-битным беззнаковым литеральным значением"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "третий аргумент должен быть 4-битным беззнаковым литеральным значением"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "первый аргумент должен быть 5-битным знаковым литеральным значением"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "первый аргумент должен быть 5-битным знаковым литеральным значением"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "аргумент %qD не является константой"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "некорректная инструкция:"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "недопустимое разделение узлов дерева"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "третий аргумент должен быть 4-битным беззнаковым литеральным значением"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "третий аргумент должен быть 4-битным беззнаковым литеральным значением"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "первый аргумент должен быть 5-битным знаковым литеральным значением"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "третий аргумент должен быть 4-битным беззнаковым литеральным значением"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "селектор должен быть целой константой в диапазоне 0..%wi"
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "маска должна быть непосредственным значением"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "маска должна быть непосредственным значением"
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "маска должна быть непосредственным значением"
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "некорректная инструкция:"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "первый аргумент должен быть 5-битным знаковым литеральным значением"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qs не является строковой константой"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, fuzzy, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "атрибуты fastcall и stdcall несовместимы"
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs - несовместимый атрибут, игнорируется"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, fuzzy, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr "неизвестная архитектура '%s'"
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "неподдерживаемая комбинация: %s"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "некорректный аргумент внутренней функции"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -26514,13 +26546,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "аргументом атрибута %qs должна быть целая константа"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr "значение ключа -mfixed-range имеет вид РЕГ1-РЕГ2"
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -26592,7 +26624,7 @@
 msgstr "%Jатрибут section для данной платформы не поддерживается"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument not an integer constant"
 msgstr "аргумент атрибута %qs не является целой константой"
@@ -26652,7 +26684,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "выражение для границы стека не поддерживается"
@@ -27509,16 +27541,11 @@
 msgid "-g option disabled"
 msgstr "ключ -g игнорируется"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr ""
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, fuzzy, gcc-internal-format
@@ -27780,312 +27807,317 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, fuzzy, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "Возврат значения в векторном регистре невозможен, поскольку набор команд altivec не задан; используйте -maltivec для его включения"
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, fuzzy, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "Передача аргумента в векторном регистре невозможна, поскольку набор команд altivec не задан; используйте -maltivec для его включения"
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "Считать, что входной файл уже препроцессирован"
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "первый аргумент должен быть 5-битным знаковым литеральным значением"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "первый аргумент должен быть 5-битным знаковым литеральным значением"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "второй аргумент должен быть 5-битным беззнаковым литеральным значением"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "первый аргумент __builtin_altivec_predicate должен быть константой"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "первый аргумент __builtin_altivec_predicate вне диапазона"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr "соглашения о вызовах -mrtd не поддерживаются в 64-битном режиме"
+
+#: config/rs6000/rs6000.c:12763
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "второй аргумент должен быть 5-битным беззнаковым литеральным значением"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "первый аргумент __builtin_spe_predicate вне диапазона"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "третий аргумент должен быть 4-битным беззнаковым литеральным значением"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "третий аргумент должен быть 4-битным беззнаковым литеральным значением"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "третий аргумент должен быть 4-битным беззнаковым литеральным значением"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "аргумент %qD не является константой"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "третий аргумент должен быть 4-битным беззнаковым литеральным значением"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "второй аргумент должен быть 5-битным беззнаковым литеральным значением"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "число должно быть 0 или 1"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "аргумент %qs должен быть 2-битным беззнаковым литеральным значением"
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "аргумент dss должен быть 2-битным беззнаковым литеральным значением"
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "первый аргумент __builtin_spe_predicate должен быть константой"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "первый аргумент __builtin_spe_predicate вне диапазона"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "первый аргумент __builtin_spe_predicate должен быть константой"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "первый аргумент __builtin_spe_predicate вне диапазона"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "эта media-функция имеется только в fr400"
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "внутренняя функция %q+D декларирована как не функция"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "внутренняя функция %q+D декларирована как не функция"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "внутренняя функция %q+D декларирована как не функция"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "внутренняя функция %q+D декларирована как не функция"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "внутренняя функция %q+D декларирована как не функция"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "внутренняя функция %q+D декларирована как не функция"
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "внутренняя функция %q+D декларирована как не функция"
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "внутренняя функция %q+D декларирована как не функция"
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "внутренняя функция %q+D декларирована как не функция"
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "внутренняя функция %q+D декларирована как не функция"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "-m%s в данной конфигурации не поддерживается"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had no type"
 msgstr "внутренняя ошибка: инструкция с побочным эффектом, влияющим на основной эффект"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "кадр стека слишком велик: %d байт"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "отсутствует профилирование 64-битного кода для этого ABI"
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, fuzzy, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "использование 'long' в типах AltiVec-данных будет отменено; используйте 'int'"
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, fuzzy, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "использование 'long' в типах AltiVec-данных будет отменено; используйте 'int'"
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, fuzzy, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "использование 'long' в типах AltiVec-данных будет отменено; используйте 'int'"
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, fuzzy, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "использование 'long' в типах AltiVec-данных будет отменено; используйте 'int'"
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "использование 'long' в типах AltiVec-данных будет отменено; используйте 'int'"
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "использование 'long' в типах AltiVec-данных будет отменено; используйте 'int'"
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "использование 'long' в типах AltiVec-данных будет отменено; используйте 'int'"
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "использование 'long' в типах AltiVec-данных будет отменено; используйте 'int'"
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "недопустимое использование '%%%c'"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "некорректно употреблять %<#pragma%>"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "недопустимый параметр '%s'"
@@ -28336,88 +28368,88 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, fuzzy, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Суммарный размер локальных переменных превышает предел для данной архитектуры"
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "размер %qD в памяти неизвестен"
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "аргумент \"%s\" должен быть неотрицательным целым числом"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "аргумент атрибута %qs больше %d"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "режим z/Architecture на %s не поддерживается."
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, fuzzy, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-битный ABI в режиме ESA/390 не поддерживается."
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Ограничить использование плавающей арифметики операциями над 32-битными значениями"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Ограничить использование плавающей арифметики операциями над 32-битными значениями"
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
@@ -28432,53 +28464,53 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr "для корректной поддержки таблиц раскрутки стека требуется либо указатель кадра, либо -maccumulate-outgoing-args"
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "__builtin_saveregs для этой платформы не поддерживается"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "атрибут %qs применим только к функциям обработки прерываний"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is supported only for SH2A"
 msgstr "атрибут %qs не поддерживается на данной платформе"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr "атрибут interrupt_handler несовместим с -m5-compact"
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to SH2A"
 msgstr "атрибут %qs допустим только для функций"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument should be between 0 to 255"
 msgstr "аргумент атрибута %qs не является целой константой"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument not a string constant"
 msgstr "аргумент атрибута %qs не является строковой константой"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr ""
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, fuzzy, gcc-internal-format
 msgid "need a second call-clobbered general purpose register"
 msgstr "Использовать регистр BK как регистр общего назначения"
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, fuzzy, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr "Использовать регистр BK как регистр общего назначения"
@@ -28857,44 +28889,44 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, fuzzy, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "неверно задан векторный тип для атрибута %qE"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "число компонент вектора не является степенью двойки"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "атрибут %qs проигнорирован"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "в атрибуте %qE требуется прототип с именованными аргументами"
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "атрибут %qE допустим только для функций с переменным числом аргументом"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "атрибут %qE проигнорирован"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -28956,7 +28988,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "использование пустого (void) значения"
@@ -28986,62 +29018,62 @@
 msgid "GCC supports only %u nested scopes"
 msgstr "GCC поддерживает только %u вложенных областей видимости"
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "метка %q+D используется, но не определяется"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "вложенная функция %q+D объявлена, но нигде не определена"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr "вложенная функция %q+D объявлена, но нигде не определена"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "неиспользуемая переменная %q+D"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, fuzzy, gcc-internal-format
 msgid "variable %qD set but not used"
 msgstr "метка %q+D определена, но не используется"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "тип массива %q+D завершен несовместимым с неявной инициализацией образом"
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "%J  исходное определение находится здесь"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr "список параметров с многоточием несовместим с пустым списком параметров"
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr "тип аргумента с преобразованием по умолчанию несовместим с пустым списком параметров"
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "в прототипе для %q+D декларировано больше аргументов, чем в предшествующем определении в устаревшем стиле"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "в прототипе для %q+D декларировано меньше аргументов, чем в предшествующем определении в старом стиле"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr "в прототипе %q+D объявлен аргумент %d несовместимого типа"
@@ -29048,42 +29080,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "прототип %q+D задан после непрототипного определения"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "здесь было предыдущее определение %q+D"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "здесь была предыдущая неявная декларация %q+D"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "здесь была предыдущая декларация %q+D"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "%q+D повторно декларирован как символ другого вида"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "внутренняя функция %q+D декларирована как не функция"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "декларация %q+D перекрывает внутреннюю функцию"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "повторная декларация перечислимого типа %q+D"
@@ -29091,341 +29123,341 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "несовместимые типы для внутренней функции %q+D"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "несовместимые типы для %q+D"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr "несовместимое именование адресных пространств (generic и %s) для %q+D"
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr "несовместимое именование адресных пространств (%s и generic) для %q+D"
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr "несовместимое именование адресных пространств (%s и %s) для %q+D"
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "несовместимые квалификаторы типа для %q+D"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
 msgstr "переопределение typedef %q+D"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "переход в область идентификатора с переменно модифицируемым типом"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "переопределение typedef %q+D"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "переопределение %q+D"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "static-декларация %q+D после неstatic-декларации"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "неstatic-декларация %q+D после static-декларации"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr ""
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, fuzzy, gcc-internal-format
 msgid "but not here"
 msgstr "%J  здесь задан один тип,"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "локальная для потока декларация %q+D следует после не локальной для потока декларации"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "не локальная для потока декларация %q+D следует после локальной для потока декларации"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "extern декларация %q+D следует за декларацией без привязки"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "декларация %q+D без привязки следует за extern-декларацией"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "повторная декларация %q+D без привязки"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr "повторная декларация %q+D с другой областью видимости (сохранена прежняя область видимости)"
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "inline-декларация %qD после декларации с атрибутом noinline"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "декларация %q+D с атрибутом noinline после inline-декларации"
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "декларация %q+D с атрибутом noinline после inline-декларации"
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "повторное определение параметра %q+D"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "избыточная повторная декларация %q+D"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "декларация %q+D перекрывает предшествующую декларацию не переменной"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr "декларация %q+D перекрывает параметр"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "декларация %qD перекрывает глобальную декларирацию"
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "декларация %q+D перекрывает декларированную ранее локальную переменную"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "%Jперекрытая декларация находится здесь"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "вложенная extern-декларация %qD"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "неявная декларация функции %qE"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "несовместимая неявная декларация внутренней функции %qD"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "некорректная декларация %q+D"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "несовместимая неявная декларация функции %qD"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%H%qE не описан в этой области (не в функции)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%H%qE не описан (первое использование в этой функции)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, fuzzy, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H(Сообщение о неописанном идентификаторе выдается один раз"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "ссылка на метку %qE вне функции"
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "переход в область идентификатора с переменно модифицируемым типом"
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, fuzzy, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "  пропускает инициализацию `%#D'"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, fuzzy, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "метка %q+D определена, но не используется"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%q+D объявлено здесь"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "переход в выражение-оператор"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "повторная декларация метки %qE"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "дублирование метки %qD"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, fuzzy, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "%Hв традиционном C нет отдельного пространства имён для меток, конфликт по идентификатору %qE "
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, fuzzy, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "несовместимые типы при инициализации"
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, fuzzy, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "переход в выражение-оператор"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, fuzzy, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%H%qE: определение с некорректным видом тега"
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "struct/union без имени и без описания переменных этого типа"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "пустая декларация со спецификатором класса памяти не переопределяет тег"
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "пустая декларация с квалификатором типа не переопределяет тег"
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, fuzzy, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "пустая декларация с квалификатором типа не переопределяет тег"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "бесполезное имя типа в пустой декларации"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> в пустой декларации"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, fuzzy, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<inline%> в пустой декларации"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> в пустой декларации на уровне файла"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> в пустой декларации на уровне файла"
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "бесполезный спецификатор класса хранения в пустой декларации"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "бесполезное %<__thread%> в пустой декларации"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "бесполезный квалификатор типа в пустой декларации"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "бесполезное %<__thread%> в пустой декларации"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "пустая декларация"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 не поддерживает квалификаторы типов и спецификатор %<static%> в деклараторах параметров-массивов"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 не поддерживает конструкцию [*] в декларациях массивов"
@@ -29433,38 +29465,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D обычно является функцией"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "typedef-декларация %qD с инициализацией (используйте конструкцию __typeof__)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "функция %qD инициализирована как переменная"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "параметр %qD инициализирован"
@@ -29473,259 +29505,259 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "объект переменного размера нельзя инициализировать"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "переменная %qD инициализирована, хотя имеет неполный тип"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "inline функция %q+D с атрибутом noinline"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "не инициализирован константный элемент %qD"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%q+D будет инициализирован после"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "при инициализации не удалось определить размер %q+D"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "не задан размер массива для %q+D"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "размер массива %q+D нулевой или отрицательный"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "размер %q+D в памяти не является константой"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "asm-спецификация в описании локальной нестатической переменной %q+D игнорируется"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "некорректная попытка разместить в регистре объект с volatile-полем"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "неинициализированная константа %qD"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "в ISO C упреждающие декларации параметров запрещены"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "размер битового поля %qs не является целочисленной константой"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "размер битового поля %qs не является целочисленной константой"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "битовое поле %qs имеет отрицательный размер"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "битовое поле %qs имеет нулевой размер"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "неверный тип битового поля %qs"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "тип для битового поля %qs является расширением GCC"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "размер поля %qs превышает размер указанного типа"
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "ширина поля %qs не достаточна для значений указанного типа"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 не поддерживает массив %qs, размер которого нельзя определить"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 не поддерживает массив %qs, размер которого нельзя определить"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 не поддерживает массив %qs переменного размера"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 не поддерживает массив %qs переменного размера"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "имя переменной или поля %qs объявлено void"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, fuzzy, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "имя переменной или поля %qs объявлено void"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "в декларации %qs по умолчанию установлен тип %<int%>"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "в декларации %qs по умолчанию установлен тип %<int%>"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "повторное употребление %<const%>"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "повторное употребление %<restrict%>"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "повторное употребление %<volatile%>"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "повторное употребление %<restrict%>"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "конфликтующее имя суперкласса %qs"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "определение функции с классом хранения %<auto%>"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "определение функции с классом хранения %<register%>"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "определение функции с классом хранения %<typedef%>"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "определение функции с классом хранения %<auto%>"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "класс хранения в декларации поля структуры %qs"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "класс хранения в декларации поля структуры %qs"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "класс хранения задан для имени типа"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, fuzzy, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%<extern%> декларация %qs с инициализацией"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, fuzzy, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "для %qs задан спецификатор %<extern%> и инициализатор"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "в декларации %qs на уровне файла задан класс хранения %<auto%>"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "в декларации %qs на уровне файла задан класс хранения %<register%>"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, fuzzy, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "вложенная функция %qs объявлена %<extern%>"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "имя %qs на уровне функции неявно имеет класс auto и объявлено %<__thread%>"
@@ -29733,687 +29765,687 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static или квалификаторы типа в деклараторе массива, не являющегося "
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "имя %qs описано как массив элементов типа void"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "имя %qs описано как массив элементов типа void"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "имя %qs описано как массив функций"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "имя %qs описано как массив функций"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "неверное употребление структуры с регулируемым элементом-массивом"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "размер массива %qs имеет не целочисленный тип"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "размер массива %qs имеет не целочисленный тип"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "в ISO C массив %qs нулевой длины недопустим"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++ запрещает массивы нулевого размера"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "размер массива %qs отрицательный"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "размер массива отрицательный"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "размер массива %qs слишком велик"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "размер массива %qs слишком велик"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 не поддерживает регулируемые элементы-массивы"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "пространство имён %qD не допускается в using-декларации"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "тип элементов массива неполный"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qs объявлена как функция, возвращающая функцию"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "%qs объявлена как функция, возвращающая функцию"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qs объявлена как функция, возвращающая массив"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "%qs объявлена как функция, возвращающая массив"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "в определении функции задан квалифицированный void-тип возвращаемого значения"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "квалификаторы в описании типа возвращаемого значения функции "
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "в ISO C употребление квалификаторов в описании типа функции запрещено"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "в ISO C употребление квалификаторов в описании типа функции запрещено"
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "несовместимые квалификаторы типа для %q+D"
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "неверно задан векторный тип для атрибута %qE"
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "класс хранения в декларации поля структуры %qs"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "класс хранения в декларации поля структуры %qs"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "неверный тип битового поля %qs"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "неверный тип битового поля %qs"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "нельзя задавать выравнивание для %q+D"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "нельзя задавать выравнивание для %q+D"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "вызов не функции %qD"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D декларирован %<inline%>"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D декларирован %<inline%>"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "в ISO C функции с квалификаторами const и volatile запрещены"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, fuzzy, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "элемент данных не может иметь тип %qT модифицируемого размера"
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "переменная или поле %qE объявлено void"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "атрибуты в деклараторе массива-параметра проигнорированы"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "параметр %q+D объявлен %<inline%>"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "параметр %q+D объявлен %<inline%>"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, fuzzy, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "поле %qs описано как функция"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "поле %qs имеет неполный тип"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, fuzzy, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "имя %qT имеет неполный тип"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, fuzzy, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "для функции %qs задан неверный класс хранения"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "inline-подстановка функции %<main%> невозможна"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<extern%> декларация %qs с инициализацией"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 не поддерживает тип %<long long%>"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 не поддерживает тип %<long long%>"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "переменная декларирована сначала как %<static%>, а затем как %<extern%>"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "переменная %q+D декларирована со спецификатором %<inline%>"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "переменная %q+D декларирована со спецификатором %<inline%>"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, fuzzy, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "переход в область идентификатора с переменно модифицируемым типом"
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "декларация функции не является прототипом"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "в декларации функции указаны имена параметров без типов"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "параметр %u (%q+D) имеет неполный тип"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "%Jпараметр %u имеет неполный тип"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "параметр %u (%q+D) имеет тип void"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "%Jпараметр %u имеет неполный void"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%>, как единственный параметры не может содержать квалификаторы"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> должен быть единственным параметром"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "для параметра %q+D есть только упреждающая декларация"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "декларация %<%s %E%> внутри списка параметров"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "декларация %s без имени внутри списка параметров"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "область действия типа - только данная декларация или определение, что может не соответствовать вашим намерениям"
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, fuzzy, gcc-internal-format
 msgid "enum type defined here"
 msgstr "это предыдущее определение `%#D'"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, fuzzy, gcc-internal-format
 msgid "struct defined here"
 msgstr "это предыдущее определение `%#D'"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, fuzzy, gcc-internal-format
 msgid "union defined here"
 msgstr "это предыдущее определение `%#D'"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "повторное определение %<union %E%>"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "повторное определение %<struct %E%>"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "вложенное переопределение %<union %E%>"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "вложенное переопределение %<struct %E%>"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларация ничего не описывает"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C не поддерживает безымянные структуры и объединения"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C не поддерживает безымянные структуры и объединения"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "повторное описание члена %q+D"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "объединение не содержит именованных элементов"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "объединение без элементов"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "структура не содержит именованных элементов"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "структура не содержит элементов"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "%Jрегулируемый элемент-массив в объединении"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "%Jрегулируемый элемент-массив - не последний элемент структуры"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr "%Jрегулируемый массив - единственный именованный элемент структуры"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "выравнивание слишком велико"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "трактовка данного объединения как прозрачного невозможна"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "вложенное переопределение %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "повторная декларация %<enum %E%>"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "перечислимый тип превышает диапазон максимального целочисленного типа"
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "заданный режим слишком мал для значений перечислимого типа"
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "значение перечислимого типа для %qE не является константой целого типа"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "значение перечислимого типа для %qE не является константой целого типа"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "переполнение значений перечислимого типа"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "в ISO C значения перечислимого типа ограничены диапазоном типа %<int%>"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "inline функция %q+D с атрибутом noinline"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "тип возвращаемого значения не полный"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "по умолчанию возвращаемый тип функции - %<int%>"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "прототип для %q+D не был предварительно определен"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D использована без предварительного определения"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "отсутствует предварительная декларация %q+D"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "функция %q+D использована до определения без предварительной декларации"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "возвращаемое значение функции %q+D - не %<int%>"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "обычно %q+D является нестатической функцией"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, fuzzy, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%Jстарый стиль деклараций параметров в определении функции с прототипом"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, fuzzy, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%Jв традиционном С не поддерживаются определения функций в стиле ISO C"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, fuzzy, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "%Jопущено имя параметра"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, fuzzy, gcc-internal-format
 msgid "old-style function definition"
 msgstr "%Jопределение функции в старом стиле"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "%Jв списке параметров пропущено имя параметра"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%q+D декларирован как не параметр"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "более одного параметра с именем %q+D"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "параметр %q+D объявлен void"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "по умолчанию для %q+D принят тип %<int%>"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "параметр %q+D имеет неполный тип"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "декларация параметра %q+D, не заданного в списке параметров"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "число аргументов не соответствует встроенному прототипу"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "число аргументов не соответствует прототипу"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "%Hдекларация прототипа"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "аргумент %qD после приведения типа не соответствует встроенному прототипу"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD после приведения типа не соответствует прототипу"
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "аргумент %qD не соответствует встроенному прототипу"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не соответствует прототипу"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "параметр %qD инициализирован"
@@ -30421,201 +30453,201 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "декларация в заголовке %<for%>-цикла поддерживается только в стандарте C99"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "декларация статической переменной %q+D в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "декларация %<extern%> переменной %q+D в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<struct %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<union %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<enum %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "декларация %q+D, не являющегося переменной, в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "дублирование %qE"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "два или более типа в декларации"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "GCC не поддерживает тип %<long long long%>"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 не поддерживает тип %<long long%>"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 не поддерживает комплексные типы"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C не поддерживает целочисленные комплексные типы"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C не поддерживает целочисленные комплексные типы"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "-fdata-sections не поддерживается для этой целевой машины"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 не поддерживает комплексные типы"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C90 не поддерживает тип %<long long%>"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "-fdata-sections не поддерживается для этой целевой машины"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C не поддерживает целочисленные комплексные типы"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE не является встроенным типом или typedef-типом"
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE - не в начале декларации"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "спецификатор %<__thread%> использован с %<auto%>"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "спецификатор %<__thread%> использован с %<register%>"
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "спецификатор %<__thread%> использован с %<typedef%>"
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "%s не поддерживает %s"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 не поддерживает тип %<long long%>"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> перед %<extern%>"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> перед %<static%>"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "в декларации задано более одного класса хранения"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "-frepo следует использовать вместе с -c"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<@try%> без %<@catch%> или %<@finally%>"
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не поддерживает %<complex%> как эквивалент %<double complex%>"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не поддерживает целочисленные комплексные типы"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -30625,7 +30657,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr ""
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "ожидался конец строки"
@@ -30645,8 +30677,8 @@
 msgid "unknown type name %qE"
 msgstr "неизвестное имя регистра: %s"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "ожидались спецификаторы декларации"
@@ -30661,7 +30693,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ожидался идентификатор или %<(%>"
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "атрибут %qE для %qE проигнорирован"
@@ -30739,7 +30771,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 не поддерживает тип %<long long%>"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "ожидался строковый литерал"
@@ -30796,14 +30828,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "ожидался идентификатор"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "запятая в конце списка значений перечислимого типа"
@@ -31257,32 +31289,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr "для %qs задан класс хранения"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "отсутствует %<(%> после %<#pragma pack%> - директива проигнорирована"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "отсутствует %<(%> после %<#pragma pack%> - директива проигнорирована"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jатрибут section недопустим для локальных переменных"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%Jатрибут адресного пространства для функций недопустим"
@@ -31292,47 +31324,47 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "перед `*' должно быть имя типа"
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "некорректный формат #pragma GCC pch_preprocess, директива проигнорирована"
@@ -31347,12 +31379,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "фигурные скобки внутри выражений допускаются только в теле функции"
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "слишком много входных файлов"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "ожидалось выражение"
@@ -31362,27 +31394,27 @@
 msgid "expression must be integral"
 msgstr "предикат должен быть идентификатором"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a constant"
 msgstr "%q#T не является классом"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "аргумент `asm' - не константная строка"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "аргумент `asm' - не константная строка"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "сравнение знакового и беззнакового целых выражений"
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "ожидалось %<,%> или %<;%>"
@@ -31414,17 +31446,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr "ожидалось %<:%>, %<,%>, %<;%>, %<}%> или %<__attribute__%>"
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "некорректный операнд const_double"
@@ -31444,12 +31476,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr "%qD не является элементом типа %qT"
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "сравнение знакового и беззнакового целых выражений"
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, fuzzy, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr "модель кодирования %s не поддерживается в режиме PIC"
@@ -31469,18 +31501,18 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "сравнение знакового и беззнакового целых выражений"
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "некорректный операнд const_double"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "некорректная маска"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "некорректный операнд const_double"
@@ -31490,58 +31522,58 @@
 msgid "invalid proc_bind kind"
 msgstr "некорректный операнд const_double"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "ожидалось %<{%>"
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs не является корректным выходным файлом"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "-frepo следует использовать вместе с -c"
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr "ожидался строковый литерал"
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid pragma"
 msgstr "некорректная директива #pragma %s"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "некорректный операнд для %<__fpreg%>"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "некорректный операнд для %<__fpreg%>"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -31551,17 +31583,17 @@
 msgid "expected %<(%> or end of line"
 msgstr "некорректный операнд"
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "перед `*' должно быть имя типа"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "перед `*' должно быть имя типа"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "ожидалась декларация или оператор"
@@ -31571,244 +31603,244 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "instance-переменная %qs объявлена как private"
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "ожидалось %<{%>"
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "ожидалось %<{%>"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "ожидалось %<{%>"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "ожидалось %<{%>"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "декларации Objective-C могут находиться только в глобальной области"
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr "ожидалось %<:%>, %<,%>, %<;%>, %<}%> или %<__attribute__%>"
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, fuzzy, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "предыдущая декларация %q+D"
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, fuzzy, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "некорректный операнд"
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "Ожидалась строка"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "ожидалось %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%q+F объявлена %<static%>, но нигде не определена"
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "instance-переменная %qs объявлена как private"
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%Jпараметр %u имеет неполный тип"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, fuzzy, gcc-internal-format
 msgid "pragma simd must be inside a function"
 msgstr "фигурные скобки внутри выражений допускаются только в теле функции"
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "vectorlength must be an integer constant"
 msgstr "селектор должен быть целой константой в диапазоне 0..%wi"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "выравнивание не является степенью числа 2"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "селектор должен быть целой константой в диапазоне 0..%wi"
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "ожидалось %<{%>"
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "некорректно употреблять %<#pragma%>"
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "base of array section must be pointer or array type"
 msgstr "размер в new для массива должен иметь целочисленный тип"
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "ожидалось %<:%> или %<...%>"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "array notations cannot be used with function type"
 msgstr "new нельзя применять к типу функции"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 msgid "expected array notation expression"
 msgstr "ожидалось выражение"
@@ -31818,7 +31850,7 @@
 msgid "%qD has an incomplete type"
 msgstr "%qD имеет неполный тип"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "неправильное использование void-выражения"
@@ -31926,7 +31958,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "индексируемый объект не является ни массивом, ни указателем"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "индекс массива не является целым значением"
@@ -32049,7 +32081,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "аргумент %d %qE согласно прототипу будет передан как signed"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "неявная конверсия из %qT в %qT, запрещенная в C++"
@@ -32079,7 +32111,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "арифметическая операция над указателем на неполный тип"
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -32165,7 +32197,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "не lvalue-массив в условном выражении"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "неявная конверсия из %qT в %qT, запрещенная в C++"
@@ -32201,7 +32233,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "несоответствие типов указатель/целое в условном выражении"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, fuzzy, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr "%s не может присутствовать в константном выражении"
@@ -32287,7 +32319,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "приведение вызова функции типа %qT к несоответствующему типу %qT"
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "приведение к типу указателя от целого другого размера"
@@ -32449,7 +32481,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "левой части инициализации, вероятно, можно задать атрибут format"
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "тип результата, вероятно, может быть задан с атрибутом format"
@@ -32586,7 +32618,7 @@
 msgid "initialization of a flexible array member"
 msgstr "инициализация регулируемого элемента-массива"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "инициализация символьного массива строкой широких символов"
@@ -32632,7 +32664,7 @@
 msgid "invalid initializer"
 msgstr "неверный инициализатор"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "вектор скрытого типа не может быть инициализирован"
@@ -32777,7 +32809,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "в ISO C операторы вида %<goto *expr;%> запрещены"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функция декларированная с атрибутом %<noreturn%> содержит оператор %<return%>"
@@ -32787,7 +32819,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "%qE нельзя использовать как функцию"
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -32895,17 +32927,17 @@
 msgid "expression statement has incomplete type"
 msgstr "оператор-выражение имеет неполный тип"
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "Предупреждать о отступлениях от стиля Effective C++"
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "сравнение плавающих значений при помощи == или != не надежно"
@@ -32956,12 +32988,12 @@
 msgstr "упорядоченное сравнение указателя с целочисленным нулем"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "упорядоченное сравнение указателя с целочисленным нулем"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "неявная конверсия из %qT в %qT, запрещенная в C++"
@@ -32986,87 +33018,87 @@
 msgid "used vector type where scalar is required"
 msgstr "структурное значение употреблено в контексте, где допустимо только скалярное значение"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qT не является базовым для %qT"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qT не является базовым для %qT"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qT не является базовым для %qT"
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "размер в new для массива должен иметь целочисленный тип"
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "размер в new для массива должен иметь целочисленный тип"
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "используется массив переменного размера %qD"
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "левый операнд операции `запятая' не имеет побочных эффектов"
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "передано %qT для %s %P в %qD"
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "выражение в деклараторе new должно иметь целый или перечислимый тип"
@@ -33076,17 +33108,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -33096,7 +33128,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qT не является базовым для %qT"
@@ -33106,17 +33138,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "instance-переменная %qs объявлена как private"
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "instance-переменная %qs объявлена как private"
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qT не является базовым для %qT"
@@ -33132,47 +33164,47 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qT не является базовым для %qT"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "передано %qT для %s %P в %qD"
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qT не является базовым для %qT"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qT не является базовым для %qT"
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qT не является базовым для %qT"
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -33183,34 +33215,34 @@
 msgstr ""
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, fuzzy, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "передача %qT как `this'-аргумента `%#D' отменяет квалификаторы"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "  при преобразовании из %qT в %qT,"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion from %qT to %qT"
 msgstr "  при преобразовании из %qT в %qT,"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, fuzzy, gcc-internal-format
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "  при преобразовании из %qT в %qT,"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -33218,83 +33250,83 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, fuzzy, gcc-internal-format
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr "%s %D(%T, %T, %T) <built-in>"
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, fuzzy, gcc-internal-format
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "%s %D(%T, %T) <built-in>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, fuzzy, gcc-internal-format
 msgid "%s%D(%T) <built-in>"
 msgstr "%s %D(%T) <built-in>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, fuzzy, gcc-internal-format
 msgid "%s%T <conversion>"
 msgstr "%s %T <conversion>"
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, fuzzy, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr "%J%s %+#D <near match>"
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr ""
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr ""
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "некорректный аргумент шаблона %d"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "преобразование из %qT в %qT неоднозначно"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr "запрошено преобразование от %qT к нескалярному типу %qT"
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "нет соответствующей функции для вызова %<%D(%A)%>"
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "вызов перегруженной функции %<%D(%A)%> неоднозначен"
@@ -33301,458 +33333,458 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr "указатель на элемент-функцию %E нельзя вызвать без задания объекта; рекомендуется использовать конструкцию .* или ->*"
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "не найден метод для преобразования в %<(%T) (%A)%>"
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "вызов %<(%T) (%A)%> неоднозначен"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "%s для %qs в '%s %E'"
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, fuzzy, gcc-internal-format
 msgid "no match for "
 msgstr "%s для %qs в '%s %E'"
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "неверные операнды бинарной операции %s"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "неверные операнды бинарной операции %s"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%s для трехиестного 'operator?:' в '%E ? %E : %E'"
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s для 'operator%s' в '%E%s'"
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%s для 'operator[]' в '%E[%E]'"
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%s для %qs в '%s %E'"
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s для 'operator%s' в '%E %s %E'"
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s для 'operator%s' в '%s%E'"
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ запрещает опускать средний операнд выражения ?:"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "несоответствие перечислимых типов в условном выражении: %qT vs %qT"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, fuzzy, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "операнды выражения ?: имеют различные типы"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "несоответствие перечислимых типов в условном выражении: %qT vs %qT"
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "перечислимый и неперечислимый тип в условном выражении"
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "нет декларации `%D(int)' для постфиксного %qs, попробуем применить соответствующую префиксную операцию"
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "нет декларации `%D(int)' для постфиксного %qs, попробуем применить соответствующую префиксную операцию"
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "сравнение между %q#T и %q#T"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, fuzzy, gcc-internal-format
 msgid "non-placement deallocation function %q+D"
 msgstr "неявная декларация функции %qE"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr ""
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "нет подходящего `operator %s' для %qT"
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is private"
 msgstr "`%+#D' - частный (private) элемент"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr "`%+#D' - защищенный (protected) элемент"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr "`%+#D' недоступен"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr "в данном контексте"
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "переданное значение NULL используется для %s %P в %qD"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, fuzzy, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "%s неуказательному типу %qT значения NULL"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "ошибка преобразования %qT в %qT для аргумента `%P' функции %qD"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "ошибка преобразования %qT в %qT для аргумента `%P' функции %qD"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "отсутствуют фигурные скобки вокруг инициализатора %qT"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, fuzzy, gcc-internal-format
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr "ошибка преобразования %qT в %qT в %s"
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, fuzzy, gcc-internal-format
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "некорректное преобразование из %qT в %qT"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  при инициализации %P -го аргумента %qD"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "некорректное преобразование из %qT в %qT"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %q+D"
 msgstr "  при инициализации %P -го аргумента %qD"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, fuzzy, gcc-internal-format
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "недопустимое связывание rvalue %qE с %qT"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, fuzzy, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "некорректная инициализация неконстантной ссылки типа %qT из временного выражения типа %qT"
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, fuzzy, gcc-internal-format
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "передача %qT как `this'-аргумента `%#D' отменяет квалификаторы"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "недопустимое связывание битового поля %qE с %qT"
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "недопустимое связывание упакованного  поля %qE с %qT"
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "недопустимое связывание rvalue %qE с %qT"
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, fuzzy, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "некорректная передача объекта не POD-типа %q#T через %<...%>; вызов завершится аварийно во время выполнения"
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "некорректное получение объекта не POD-типа %q#T через %<...%>; вызов завершится аварийно во время выполнения"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, fuzzy, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "некорректное получение объекта не POD-типа %q#T через %<...%>; вызов завершится аварийно во время выполнения"
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "повторное определение аргумента по умолчанию для `%#D'"
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "аргумент по умолчанию для параметра %d %qD еще не был проанализирован"
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, fuzzy, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "Предупреждать о функциях, которым можно назначить атрибут format"
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "конец файла в аргументе по умолчанию"
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "передача %qT как `this'-аргумента `%#D' отменяет квалификаторы"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  в вызове %qD"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT не является базовым для %qT"
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "декларация %qD как %s"
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, fuzzy, gcc-internal-format
 msgid "  in call to %q+D"
 msgstr "  в вызове %qD"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr "не найдено поле класса в интерфейсном типе java %qT"
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "указатель inlined_to ссылается на себя"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "вызов не функции %qD"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "нет подходящей функции для вызова %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr "нет подходящей функции для вызова %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "нет соответствующей функции для вызова %<%D(%A)%>"
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "вызов перегруженной %<%s(%A)%> имеет неоднозначную трактовку"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT не имеет нестатического элемента данных с именем %qD"
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "некорректный вызов элемента-функции %qD без объекта"
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "при передаче %qT предпочтение отдается %qT, а не %qT"
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "предпочтение отдается %qD (а не %qD)"
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  при преобразовании из %qT в %qT,"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  поскольку это дает лучшую последовательность преобразований аргумента"
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "отсутствует аргумент по умолчанию для параметра %P функции %q+#D"
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr "претендент: %+#D"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr "претендент: %+#D"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "ошибка преобразования %qE в %qT"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "некорректная инициализация ссылки типа %qT из выражения типа %qT"
@@ -33912,7 +33944,7 @@
 msgid "  by %q+D"
 msgstr "  методом %q+D"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, fuzzy, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr "`%#D' некорректно; в анонимном объединении допустимы только нестатические элементы"
@@ -33922,7 +33954,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "`%#D' некорректно; в анонимном объединении допустимы только нестатические элементы"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, fuzzy, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr "private-элемент `%#D' в анонимном объединении"
@@ -33932,7 +33964,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "private-элемент `%#D' в анонимном объединении"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, fuzzy, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr "protected-элемент `%#D' в анонимном объединении"
@@ -34066,68 +34098,78 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  но не переопределяет %<operator=(const %T&)%>"
 
-#: cp/class.c:4538
+#: cp/class.c:4300
 #, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, fuzzy, gcc-internal-format
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr "присваивание (а не инициализация) в декларации"
+
+#: cp/class.c:4557
+#, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "инициализатор задан для невиртуального метода %q+D"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "%qs не является именем типа"
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q#T не является классом"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "базовый класс %q#T имеет невиртуальный деструктор"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "%qs не является именем типа"
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "`%#D' не является нестатическим элементом %qT"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has volatile type"
 msgstr "`%#D' не является нестатическим элементом %qT"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "базовый класс %q#T имеет невиртуальный деструктор"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr "нестатическая ссылка %q+#D в классе без конструктора"
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr "нестатический константный элемент %q+#D в классе без конструктора"
@@ -34134,102 +34176,102 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "непосредственная база %qT недоступна в %qT из-за неоднозначности"
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "виртуальная база %qT недоступна в %qT из-за неоднозначности"
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr "смещение %q+D несовместимо с ABI и может измениться в будущих версиях GCC"
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T содержит виртуальные функции, но невиртуальный деструктор"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "в типе прозрачного класса %qT нет никаких полей"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "в типе прозрачного класса %qT есть виртуальные функции"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "не удалось завершить структуру из-за предыдущих грамматических ошибок"
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "некорректная строка %<\"%E\"%>, задающая язык"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "ошибка при выборе перегруженной функции %qD при преобразовании к типу %qT"
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "нет способа для преобразования функции %qD к типу %q#T"
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "преобразование перегруженной функции %qD к типу %q#T неоднозначно"
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "предполагается указатель на элемент %qD"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(указатель на элемент можно получить только при помощи %<&%E%>)"
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "недостаточная информация о типе"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "ошибка преобразования %qE из типа %qT в тип %qT"
@@ -34239,12 +34281,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "декларация %q#D"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr "делает трактовку %qD отличной от %q+#D"
@@ -34284,258 +34326,258 @@
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "некорректная инициализация внутри класса статического элемента данных нецелочисленного типа %qT"
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, fuzzy, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "неинициализированный элемент %qD константного типа %qT"
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, fuzzy, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr "%qD не является функцией шаблоном"
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 msgid "call to internal function"
 msgstr "%qs объявлена как функция, возвращающая функцию"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "в декларации friend нет имени класса или функции"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, fuzzy, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "вызов не функции %qD"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%q+D использована без предварительного определения"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, fuzzy, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "циклическая зависимость в протоколе %qs"
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (задайте -ftemplate-depth-NN, чтобы увеличить максимум) при конкретизации %qD"
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "сдвиг вправо на отрицательное число позиций"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "левый операнд операции `запятая' не имеет побочных эффектов"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 msgid "array subscript out of bound"
 msgstr "индекс массива не является целым значением"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "negative array subscript"
 msgstr "неоднозначное преобразование индекса массива"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "отсутствует инициализатор для элемента %qD"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "некорректный инициализатор массива"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#T не является классом"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "`%+#D' - частный (private) элемент"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "нет декларации %qD в этой области видимости"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "выражение в деклараторе new должно иметь целый или перечислимый тип"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant-expression"
 msgstr "размер массива не является целочисленным константным выражением"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "перечислимый и неперечислимый тип в условном выражении"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "некорректное применение static_cast от типа %qT к типу %qT"
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant-expression"
 msgstr "элемент инициализатора не является константой"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "ожидалось выражение"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr "выражение %qE, имеющее тип абстрактного класса %qT, нельзя использовать в throw-выражении"
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, fuzzy, gcc-internal-format
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "размер массива не является целочисленным константным выражением"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, fuzzy, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "перечислимый и неперечислимый тип в условном выражении"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant-expression"
 msgstr "размер массива не является целочисленным константным выражением"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "неконстантный индекс массива в инициализаторе"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Неожиданное окончание строки формата"
@@ -34607,7 +34649,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr "Оператор в %0 некорректен в программной единице BLOCK DATA в %1"
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr ""
@@ -34647,7 +34689,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "преобразование из %qT в %qT отменяет квалификаторы"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "преобразование %qT в %qT не снимает указатель"
@@ -34657,292 +34699,292 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "некорректное преобразование от типа %qT к типу %qT"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "преобразование из %q#T в %q#T"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T использовано там, где ожидалось %qT"
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "ошибка преобразования %qE в %qT"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "%q#T использовано там, где ожидалось плавающее значение"
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "запрошено преобразование от %qT к нескалярному типу %qT"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "псевдо-деструктор не вызывается"
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "преобразование к неполному типу"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "некорректное применение %qs к неполному типу %qT "
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "преобразование к неполному типу"
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "доступ к объекту %qE неполного типа %qT не будет осуществлён в %s"
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "доступ к объекту %qE неполного типа %qT не будет осуществлён в %s"
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "доступ к объекту %qE неполного типа %qT не будет осуществлён в %s"
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "доступ к объекту %qE неполного типа %qT не будет осуществлён в %s"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "доступ к объекту %qE неполного типа %qT не будет осуществлён в %s"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "доступ к объекту %qE неполного типа %qT не будет осуществлён в %s"
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, fuzzy, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s: ошибка при определении адреса перегруженной функции"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s: ошибка при определении адреса перегруженной функции"
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s: ошибка при определении адреса перегруженной функции"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s: ошибка при определении адреса перегруженной функции"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s: ошибка при определении адреса перегруженной функции"
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, fuzzy, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s: ошибка при определении адреса перегруженной функции"
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, fuzzy, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s: ошибка при определении адреса перегруженной функции"
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "левый операнд операции `запятая' не имеет побочных эффектов"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "левый операнд операции `запятая' не имеет побочных эффектов"
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "левый операнд операции `запятая' не имеет побочных эффектов"
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "левый операнд операции `запятая' не имеет побочных эффектов"
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, fuzzy, gcc-internal-format
 msgid "statement has no effect"
 msgstr "оператор без побочного эффекта"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, fuzzy, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "левый операнд операции `запятая' не имеет побочных эффектов"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "преобразование NULL к неуказательному типу"
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "обнаружено %d параметров шаблона для `%#D'"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "неоднозначное преобразование из типа %qT по умолчанию"
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  возможные преобразования - %qD и %qD"
@@ -35360,242 +35402,242 @@
 msgid "template parameters do not match template %qD"
 msgstr "параметры не подходят шаблону"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, fuzzy, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr "%Jанонимная структура не может иметь элементов-функций"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, fuzzy, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr "%Jанонимное объединение не может иметь элементов-функций"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с конструктором недопустим в анонимном агрегатном типе"
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с деструктором недопустим в анонимном агрегатном типе"
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с операцией присваивания-копирования недопустим в анонимном агрегатном типе"
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "атрибуты декларации %q+#T отброшены"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "атрибут для %q+#T должен следовать за ключевым словом %qs"
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "несколько типов в одной декларации"
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "повторная декларация внутреннего типа C++ %qT"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs допустим только для функций"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "отсутствует имя типа в typedef-декларации"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "в ISO C++ анонимные структуры запрещены"
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr "%qs допустим только для функций"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> может быть задан только внутри класса"
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> может быть задан только для конструкторов"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "класс хранения может быть задан только для объектов и функций"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr "квалификаторы могут быть заданы только для объектов и функций"
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> в этой декларации отброшен"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<register%> в пустой декларации на уровне файла"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "класс хранения %qD в конкретизации шаблона"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "атрибут %qs допустим только для определений классов"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "отброшены атрибуты класса, заданные вне его объявления"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "отброшены атрибуты класса, заданные вне его объявления"
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef-декларация %qD с инициализацией (используйте конструкцию __typeof__)"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "декларация %q#D содержит %<extern%> и инициализацию"
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "определение функции %q#D помечено %<dllimport%>"
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "`%#D' не является нестатическим элементом %qT"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "шаблонная декларация %q#D"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "некорректная декларация элемента-шаблона %qD"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ не разрешает определять %<%T::%D%> как %<%T::%D%>"
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "повторная инициализация %qD"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr "%q+F объявлена %<static%>, но нигде не определена"
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларация %q#D вне класса не является определением"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "некорректный класс хранения %<__thread%> для функции %qs"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F объявлена %<static%>, но нигде не определена"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "переменная %q#D инициализирована, хотя имеет неполный тип"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "элементы массива %q#D имеют неполный тип"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "декларация %q#D содержит %<extern%> и инициализацию"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "агрегатный тип %q#D неполон и не может быть определён"
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "переменная %qD декларирована как ссылка, но не инициализирована"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, fuzzy, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "имя %qD использовано в назначенном инициализаторе массива, являющемся GNU-расширением языка"
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "имя %qD использовано в назначенном инициализаторе массива, являющемся GNU-расширением языка"
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "нетривиальные инициализаторы с метками"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "при инициализации не удалось определить размер %qD"
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "не задан размер массива для %qD"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "массив %qD имеет нулевой размер"
@@ -35603,829 +35645,829 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "размер %q+D в памяти неизвестен"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "размер %q+D в памяти не является константой"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "некорректная семантика статических данных %q+#D inline-функции (придётся заводить несколько копий)"
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "%J  проблему можно обойти, исключив инициализацию"
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "неинициализированная константа %qD"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "неинициализированный элемент %qD константного типа %qT"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "тип %qs имеет конструктор, определённый пользователем"
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "некорректный тип %qT является инициализатором для вектора типа %qT"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "инициализатор для %qT должен быт заключен в фигурные скобки"
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "имя %qD использовано в назначенном инициализаторе массива, являющемся GNU-расширением языка"
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT не имеет нестатического элемента данных с именем %qD"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "некорректное начальное значение для элемента %qs"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "избыточные элементы в инициализаторе для %qT"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "фигурные скобки вокруг скалярного инициализатора для типа %qT"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "отсутствуют фигурные скобки вокруг инициализатора %qT"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "элементы массива %q#D имеют неполный тип"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ISO C90 не поддерживает составные литеральные выражения"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%qD имеет неполный тип"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "в инициализаторе скалярного объекта %qD должен быть только один элемент"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "%qD следует инициализировать при помощи конструктора, а не %<{...}%>"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "массив %qD инициализируется строковой константой %qE, заключённой в скобки"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "инициализатор недопустим для статического элемента с конструктором"
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ запрещает инициализацию внутри класса неконстантного статического элемента %qD"
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(запрошена инициализация вне класса)"
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%H%qD используется без инициализации в данной функции"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "присваивание (а не инициализация) в декларации"
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "перекрытие предыдущей декларации %q#D"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr ""
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr "`%#D' не является нестатическим элементом %qT"
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "функция %q#D инициализирована как переменная"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "базовый класс %q#T имеет невиртуальный деструктор"
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "при инициализации не удалось определить размер %qD"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "не задан размер массива для %qD"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "массив %qD имеет нулевой размер"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларирован как %<virtual%> %s"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> variable"
 msgstr "%qD декларирован как %<inline%> %s"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации %s"
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларирован как %<virtual%> %s"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларирован как %<inline%> %s"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации %s"
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларирован как %<virtual%> %s"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларирован как %<inline%> %s"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации %s"
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларирован как %<virtual%> %s"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларирован как %<inline%> %s"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации %s"
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларировано как friend"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларировано со спецификацией исключительной ситуации"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "определение %qD вне пространства имён, объемлющего %qT"
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статическая функция-член %q#D объявлена с квалификаторами типа"
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "определение явной специализации %qD в friend-декларации"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "некорректное использование идентификатора шаблона %qD в декларации первичного шаблона"
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "аргументы по умолчанию не допускаются в декларации специализации friend-шаблона %qD"
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "не допускается использовать %<inline%> в декларации специализации friend-шаблона %qD"
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr "не допускается использовать %<inline%> в декларации специализации friend-шаблона %qD"
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "недопустимая декларация %<::main%> как шаблона"
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "недопустимая декларация %<::main%> как inline-функции"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "недопустимая декларация %<::main%> как inline-функции"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "недопустимая декларация %<::main%> как статической функции"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%sэлемент, функция %qD, не может иметь квалификатор метода - %qT"
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%sэлемент, функция %qD, не может иметь квалификатор метода - %qT"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%sэлемент, функция %qD, не может иметь квалификатор метода - %qT"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "шаблон с привязкой C"
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "некорректный аргумент внутренней функции"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD должен быть нестатической элементом-функцией"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> должна возвращать %<int%>"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "определение неявно декларированного %qD"
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "определение неявно декларированного %qD"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, fuzzy, gcc-internal-format
 msgid "%q+#D explicitly defaulted here"
 msgstr "это предыдущее определение `%#D'"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "нет элемента-функции %q#D в классе %qT"
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "некорректная инициализация внутри класса статического элемента данных нецелочисленного типа %qT"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "некорректная инициализация внутри класса статического элемента данных нецелочисленного типа %qT"
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "некорректная инициализация внутри класса статического элемента данных нецелочисленного типа %qT"
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "некорректная инициализация внутри класса статического элемента данных нецелочисленного типа %qT"
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ запрещает инициализацию внутри класса неконстантного статического элемента %qD"
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ запрещает инициализацию элемента-константы %qD нецелочисленного типа %qT"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "размер массива %qD имеет нецелочисленный тип %qT"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "размер массива имеет нецелочисленный тип %qT"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "размер массива %qD отрицательный"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "размер массива отрицательный"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ запрещает массив нулевого размера %qD"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ запрещает массивы нулевого размера"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "размер массива не является целочисленным константным выражением"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ запрещает массив переменного размера %qD"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ запрещает массивы переменного размера"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "используется массив переменного размера %qD"
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "переполнение в размерности массива"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D декларировано как friend"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "имя %qs описано как массив элементов типа void"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "создание массива элементов типа %qT"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "имя %qs описано как массив функций"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "создание массива элементов типа %qT"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "имя %qs описано как массив функций"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "создание массива элементов типа %qT"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "имя %qs описано как массив функций"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "имя %qs описано как массив функций"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларация многомерного массива %qD должна определять границы для всех размерностей, кроме первой"
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "в многомерном массиве должны быть определены границы для всех размерностей, кроме первой"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "некорректная спецификация возвращаемого типа в конструкторе"
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "некорректная спецификация возвращаемого типа в деструкторе"
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "тип результата задан для %<operator %T%>"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "декларация безымянной переменной или поля с типом void"
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "декларация переменной или поля с типом void"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<::%D%>"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<%T::%D%>"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<%D::%D%>"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%qT не является классом или пространством имён"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларация %qD как не-функции"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "декларация %qD как не-элемента"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "декларатор отсутствует; используется зарезервированное слово %qD"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "определение функции не объявляет параметры"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "шаблонная декларация `%#D'"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "декларация %q+D перекрывает параметр"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "идентификатор шаблона недопустим в using-декларации"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "два или более типа в декларации имени %qs"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "конфликтующие спецификаторы в декларации %qs"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не поддерживает %<complex%> как эквивалент %<double complex%>"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ запрещает декларации %qs без типа"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs не поддерживается для этой целевой платформы"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ не поддерживает %<long long%>"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> или %<unsigned%> некорректны для %qs"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> и %<unsigned%> одновременно заданы для %qs"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "недопустимо использовать %<long long%> для %qs"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "недопустимо использовать %<long%> для %qs"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "недопустимо использовать %<short%> для %qs"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> или %<short%> некорректны для %qs"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, fuzzy, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%> или %<short%> некорректны для %qs"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> или %<short%> заданы в описании %qs с типом char"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> и %<short%> одновременно заданы для %qs"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, fuzzy, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<long%> или %<short%> некорректны для %qs"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "неверное употребление long, short, signed или unsigned в описании %s"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "спецификатор complex для %qs недопустим"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "квалификаторы не допускаются в декларации %<operator %T%>"
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr "элемент %qD не может быть декларирован как virtual и static"
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-декларация не допускается в декларации параметров"
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "спецификаторы класса хранения не допускаются в декларациях параметров"
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "недопустимая декларация не-элемента %qs как %<mutable%>"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "virtual вне декларации класса"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "в декларации %qs задано более одного класса хранения"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "для %qs задан класс хранения"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "вложенная функция %qs объявлена %<extern%>"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "имя %qs описано на верхнем уровне с классом хранения %<auto%>"
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "имя %qs на уровне функции неявно имеет класс auto и объявлено %<__thread%>"
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "класс хранения не допускается в декларации friend-функции"
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs объявлена как функция, возвращающая функцию"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs объявлена как функция, возвращающая массив"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
@@ -36432,475 +36474,475 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не может быть статической элементом-функцией"
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "деструктор не может быть статической элементом-функцией"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr "конструкторы нельзя декларировать как virtual"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-декларация вне определения класса"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, fuzzy, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "недопустимое определение friend-функции %qs в определении локального класса"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструкторы не могут иметь параметров"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "недопустимая декларация указателя на %q#T"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "недопустимая декларация ссылки на %q#T"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "недопустимая декларация указателя на элемент %q#T"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "недопустимая декларация ссылки на %q#T"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "нельзя %s указатель на неполный тип %qT"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Недопустимо определять ссылку на %q#T, которая не будет определением типа или аргументом шаблона"
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "идентификатор шаблона %qD использован как декларатор"
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "элементы-функции неявно считаются friend-функциями своего класса"
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "избыточная квалификация %<%T::%> элемента %qs"
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "недопустимая декларация элемента-функции %<%T::%s%> внутри %<%T%>"
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "недопустимая декларация элемента-функции %<%T::%s%> внутри %<%T%>"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "недопустимая декларация элемента %<%T::%s%> внутри %qT"
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "не параметрический %qs не может содержать параметры"
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "размер массива %qs слишком велик"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "элемент данных не может иметь тип %qT модифицируемого размера"
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметр не может иметь модифицированный тип `%T"
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual вне декларации класса"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> в пустой декларации"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "только декларации конструкторов могут быть %<explicit%>"
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не-элемента %qs как %<mutable%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не объектного элемента %qs как %<mutable%>"
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация функции %qs как %<mutable%>"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация статического %qs как %<mutable%>"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация константного %qs как %<mutable%>"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация функции %qs как %<mutable%>"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "параметр %q+D объявлен %<inline%>"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, fuzzy, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jдля typedef-имени недопустимы квалификаторы классов"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ запрещает определять вложенный тип %qD с тем же именем, что и объемлющий класс"
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr "в декларации friend-класса использованы квалификаторы типа"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "в декларации friend-класса использован квалификатор %<inline%>"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "параметры шаблона не могут быть friend"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "в friend-декларации требуется указание класса: %<friend class %T::%D%>"
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "в friend-декларации требуется указание класса: %<friend %#T%>"
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "попытка сделать класс %qT \"другом\" глобальной области видимости"
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "некорректные квалификаторы для типа функции, не являющейся элементом"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "абстрактный декларатор %qT использован в качестве декларатора"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "недопустимое использование %<::%> в декларации параметра"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> недопустим в данном контексте"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "параметр %q+D объявлен %<inline%>"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared %<auto%>"
 msgstr "статический элемент %qD объявлен как %<register%>"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "недопустимое использование %<::%>"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "декларация C-функции `%#D' противоречит"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "функция %qD объявлена виртуальной внутри объединения"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr "%qD не может быть объявлена виртуальной, поскольку она всегда статическая"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "квалификаторы не допускаются в декларации `operator %T'"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларация %qD перекрывает элемент класса, на который указывает 'this'"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "конструкторы нельзя декларировать как virtual"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "квалификаторы не допускаются в декларации `operator %T'"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "явная специализация не-шаблона %qT"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%J  исходное определение находится здесь"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "поле %qD имеет неполный тип"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "имя %qT имеет неполный тип"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qs не является ни функцией, ни элементом-функцией; friend-декларация не допускается"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr "`%#D' не является нестатическим элементом %qT"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "статический элемент %qD объявлен как %<register%>"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "некорректный класс хранения %<auto%> для функции %qs"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "некорректный класс хранения %<register%> для функции %qs"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "некорректный класс хранения %<__thread%> для функции %qs"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "некорректный класс хранения %<__thread%> для функции %qs"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "спецификация asm не допускается при определении функции"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr "некорректно указано %<static%> для функции %qs, объявленной вне глобальной области видимости"
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "некорректно указано %<inline%> для функции %qs, объявленной вне глобальной области видимости"
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуальная функция %qs не является элементом класса"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "атрибут %qE для не классовых типов игнорируется"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "атрибут %qE для не классовых типов игнорируется"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "недопустимая декларация статического элемента-функции %qD"
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "недопустимая декларация статической функции внутри другой функции"
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "слово %<static%> недопустимо при определении (в отличие от объявления) статического элемента данных в классе"
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статический элемент %qD объявлен как %<register%>"
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "недопустимая явная extern-декларация элемента %q#D"
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, fuzzy, gcc-internal-format
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "декларация %q#D вне класса не является определением"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%<extern%> декларация %qs с инициализацией"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "для %qs задан спецификатор %<extern%> и инициализатор"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "аргумент по умолчанию %qE использует локальную переменную %qD"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "аргумент по умолчанию %qE использует локальную переменную %qD"
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "некорректная template-декларация %qD"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "некорректная template-декларация %qD"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "параметр %q+D имеет неполный тип"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "некорректная декларация параметра %qD с типом метода"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметр %qD включает %s на массив с неизвестной границей %qT"
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "параметр %qD включает %s на массив с неизвестной границей %qT"
@@ -36920,173 +36962,173 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "некорректный конструктор; возможно, вы имели в виду %<%T (const %T&)%>"
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "декларация %qD может не действовать в пространстве имён"
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD можно не определять статической"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD должен быть нестатической элементом-функцией"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD должен быть либо нестатическим элементом-функцией или функцией-не-элементом"
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD должен иметь аргумент типа класс или перечислимого типа"
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "преобразование к %s%s никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "преобразование к %s%s никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "преобразование к %s%s никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, fuzzy, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "преобразование к %s%s никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "преобразование к %s%s никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, fuzzy, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "преобразование к %s%s никогда не будет использовать операцию преобразования типа"
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ не поддерживает перегрузку операции ?:"
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не может иметь переменное число аргументов"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr "постфиксный %qD должен иметь аргумент типа %<int%>"
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr "постфиксный %qD должен иметь второй аргумент типа %<int%>"
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr "%qD должен иметь не более одного аргумента"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr "%qD должен иметь один или два аргумента"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксный %qD должен возвращать %qT"
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксный %qD должен возвращать %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr "%qD должен иметь список параметров %<void%>"
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr "%qD должен иметь ровно один аргумент"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "%qD должен иметь ровно два аргумента"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "пользовательский оператор %qD всегда вычисляет оба аргумента"
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD должен возвращать результат по значению"
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не может иметь аргументов по умолчанию"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "использование параметра шаблона %qT после %qs"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "неоднозначная конкретизация шаблона %qD для %q+D"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "использование typedef-имени %qD после %qs"
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+D ранее декларирован здесь"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "ссылка на %qT как на %qs"
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "%q+T ранее декларирован здесь"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "ссылка на %qT как на enum"
@@ -37098,88 +37140,88 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "для %<%s %T%> нужен аргумент-шаблон"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD имеет то же имя, что и класс, в котором он(а) декларируется"
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "ссылка на %qD противоречива"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "использование перечисления %q#D без предыдущей декларации"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "повторная декларация %qT как не-шаблона"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "предыдущая декларация %q+D"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "некорректный производный тип union %qT"
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr "Java-класс %qT не может иметь несколько базовых классов"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr "Java-класс %qT не может иметь виртуальных базовых классов"
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "базовый тип %qT не является ни структурой, ни классом"
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "рекурсивный тип %qT не определён"
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "некорректное дублирование базового типа %qT"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "%Jэто предыдущее определение"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr ""
@@ -37188,87 +37230,87 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ни один целочисленный тип не годится для представления всех значений перечислимого типа %qT"
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "значение перечислимого типа для %qD не является константой целого типа"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "целая константа слишком велика для типа %qs"
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "переполнение в перечисляемых значениях для %qD"
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr "значение перечислимого типа для %qE не является константой целого типа"
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "тип результата %q#T неполный"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, fuzzy, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr "тип возвращаемого значения не полный"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> должен возвращать ссылку на %<*this%>"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "отсутствует предварительная декларация %q+D"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, fuzzy, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "некорректная декларация элемента-функции"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "параметр %qD объявлен void"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "типы возвращаемых значений функции несовместимы из-за %<volatile%>"
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D set but not used"
 msgstr "метка %q+D определена, но не используется"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "некорректная декларация элемента-функции"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD уже определена в классе %qT"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "по умолчанию для %q+D принят тип %<int%>"
@@ -37308,7 +37350,7 @@
 msgid "deleting %qT is undefined"
 msgstr "удаление %qT не определено"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "шаблонная декларация %q#D"
@@ -37331,7 +37373,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "деструктор %qD объявлен как шаблон элемента"
@@ -37422,27 +37464,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "битовое поле %qD не целочисленного типа"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, fuzzy, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "`%#D' не является нестатическим элементом %qT"
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "анонимная структура не внутри именованного типа"
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "анонимные агрегатные данные в области видимости пространства имён должны быть статическими"
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "безымянное объединение без элементов"
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> должен возвращать тип %qT"
@@ -37451,47 +37493,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "первый аргумент %<operator new%> не может иметь значение по умолчанию"
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> имеет %<size_t%> (%qT) в качестве первого параметра"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> должен иметь результат типа %qT"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> имеет первый параметр типа %qT"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT имеет поле %qD, использующее анонимное пространоство имён"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT объявлен с большей областью видимости, чем тип его поля %qD"
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT наследован от %qT, использующего анонимное пространоство имён"
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT объявлен с большей областью видимости, чем родитель %qT"
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using anonymous type, is used but never defined"
 msgstr "%q+F объявлена %<static%>, но нигде не определена"
@@ -37500,48 +37542,48 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D не ссылается на неквалифицированный тип, поэтому не используется для связывания"
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+F объявлена %<static%>, но нигде не определена"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "предыдущая декларация `%#D' с привязкой %L"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "inline функция %q+D использована, но нигде не определена"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "отсутствует аргумент по умолчанию для параметра %P функции %q+#D"
@@ -37548,12 +37590,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "вызов не функции %qD"
@@ -38132,42 +38174,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни специфический для класса оператор delete не будут вызваны, даже если они декларированы в определении класса."
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "преждевременное завершение инициализатора"
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr "недопустимая инициализация многомерного массива при помощи инициализатора"
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "неизвестный размер массива в операторе delete"
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "в вызове оператора delete обнаружена возможная проблема:"
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни специфический для класса оператор delete не будут вызваны, даже если они декларированы в определении класса."
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
@@ -38297,18 +38339,18 @@
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "кодированное имя %qD изменится в будущих версиях GCC"
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
@@ -38724,7 +38766,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr ""
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -38749,7 +38791,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "запрос элемента %qD в %qE, имеющего не классовый тип %qT"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> не был декларирован"
@@ -38814,7 +38856,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(возможно, пропущена точка с запятой после определения %qT)"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT не является шаблоном"
@@ -38839,7 +38881,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -39107,7 +39149,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ожидался список спецификаторов и квалификаторов"
@@ -39284,7 +39326,7 @@
 msgid "capture of non-variable %qD "
 msgstr "инкрементация переменной %qD, доступной только на чтение"
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, fuzzy, gcc-internal-format
 msgid "%q+#D declared here"
 msgstr "%q+D объявлено здесь"
@@ -39344,7 +39386,7 @@
 msgid "compound-statement in constexpr function"
 msgstr "%qD не является функцией шаблоном"
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "ожидалась декларация или оператор"
@@ -39374,7 +39416,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "ожидалась декларация или оператор"
@@ -39405,12 +39447,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ не поддерживает вычисляемые goto"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ожидался оператор"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "избыточная %<;%>"
@@ -39457,7 +39499,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "определение класса не должно содержать friend"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
@@ -39548,12 +39590,12 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "ключевое слово %<export%> не реализовано; игнорируется"
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qD не может иметь аргументов по умолчанию"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "%qD не может иметь аргументов по умолчанию"
@@ -39568,7 +39610,7 @@
 msgid "expected template-id"
 msgstr "ожидался оператор"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ожидалось %<{%>"
@@ -39645,210 +39687,210 @@
 msgid "expected type specifier"
 msgstr "ожидались спецификаторы декларации"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "в ISO C упреждающие декларации параметров запрещены"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "некорректное адресное выражение"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "Ожидалось имя"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "декларация ничего не описывает"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "атрибут %qE для не классовых типов игнорируется"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "класс хранения %qD в конкретизации шаблона"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD не является шаблоном функции"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an enumerator-name"
 msgstr "%qT не является пространством имён"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "ожидалось %<,%> или %<;%>"
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Включить автоматическую конкретизацию шаблонов"
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "декларация %qD в %qD, который не объемлет %qD"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "декларация %qD в %qD, который не объемлет %qD"
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C++ не поддерживает %sацию по отношению к перечислимому типу"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qT не является пространством имён"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "ожидалось имя класса"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "#pragma %s уже зарегистрирована"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "идентификатор шаблона недопустим в using-декларации"
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "в описании возвращаемого типа нельзя определять новые типы"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%qD не является функцией шаблоном"
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "#pragma %s уже зарегистрирована"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "спецификация asm не допускается при определении функции"
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "атрибуты не допускаются при определении функции"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "ожидался идентификатор"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "недопустимая инициализация friend-функции %qs"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "атрибуты после инициализатора в скобках проигнорированы"
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "функция %q+D повторно декларирована как inline"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "индекс массива не является целым значением"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "создание указателя на элемент ссылочного типа %qT"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%D%> не является типом"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "некорректное использование нестатического элемента данных '%E'"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "используйте %<%T::%D%> вместо %<%T::%D%> для именования конструктора в имени с квалификатором"
@@ -39857,7 +39899,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "некорректная декларация %q+D"
@@ -39864,292 +39906,292 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "%J%qD использовано до декларации"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "ожидались спецификаторы декларации"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, fuzzy, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qT не является пространством имён"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "создание указателя на элемент не классового типа %qT"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "некорректный операнд"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, fuzzy, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "повтор case-значения,"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "повтор case-значения,"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "повтор case-значения,"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%>"
 msgstr "недопустимое использование %<::%>"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "в описании возвращаемого типа нельзя определять новые типы"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "некорректный тип аргумента"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "ожидался идентификатор"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "ожидалось %<:%> или %<...%>"
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "в описании возвращаемого типа нельзя определять новые типы"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr "устаревшее использование аргумента по умолчанию в качестве параметра не-функции"
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "аргументы по умолчанию разрешены только для параметров функций"
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qD не может иметь аргументов по умолчанию"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "%qD не может иметь аргументов по умолчанию"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ не поддерживает назначенные инициализаторы"
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ не поддерживает назначенные инициализаторы"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "ожидалось имя класса"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%q+D: inline-декларация после определения"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D: inline-декларация после определения"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "Некорректный мусор после определения в %C"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "ожидалось %<,%> или %<;%>"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "нет файла для класса %s"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "в декларации friend нет имени класса или функции"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "некорректная template-декларация %qD"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "избыточные квалификаторы проигнориованы"
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "перед явной специализацией должно быть 'template <>'"
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "не шаблон %qD использован как шаблон"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr "предыдущее определение %q+#T"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "ожидалось имя класса"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "ожидалось %<,%>, %<;%> или %<}%>"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, fuzzy, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "в декларации friend должно быть использовано ключевое слово класса"
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "в декларации friend нет имени класса или функции"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "спецификатор pure в определении функции"
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "некорректный операнд"
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "некорректный операнд"
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "#pragma %s уже зарегистрирована"
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr ""
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "использование `typename' вне шаблона"
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "ключевое слово `typename' запрещено в этом контексте (инициализатор квалифицированного элемента неявно является типом)"
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "в описании возвращаемого типа нельзя определять новые типы"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%qD не является типом"
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "в описании возвращаемого типа нельзя определять новые типы"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "ожидался идентификатор или %<(%>"
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "некорректная декларация %q+D"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "недостаточно списков параметров шаблонов"
@@ -40158,538 +40200,538 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "слишком много списков параметров шаблонов"
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именованные возвращаемые значения больше не поддерживаются"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "некорректная декларация шаблона-элемента `%#D' в локальном классе"
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон с привязкой C"
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "некорректная спецификация базового класса"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "шаблонная декларация `%#D'"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "явная специализация в не-namespace области %qD"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> должно быть %<> >%> внутри списка аргументов вложенного шаблона"
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "ошибочное использование %<>>%>, используйте %<>%> для завершения списка аргументов шаблона"
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "некорректная спецификация базового класса"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> перед %<extern%>"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ не поддерживает %<long long%>"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "в декларации использованы спецификаторы %<short%> и %<char%>"
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "дублирование %qE"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "дублирование %s"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ожидался оператор"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "ожидался оператор"
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "ожидался оператор"
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ожидалось %<{%>"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ожидалось %<:%> или %<...%>"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ожидалось %<,%>, %<;%> или %<}%>"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "определение %qD уже есть в %qT"
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "это предыдущее определение `%#D'"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%J%qD повторно декларирован как символ другого вида"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "слово %<template%> (для снятия неоднозначности) допускается только внутри шаблонов"
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "конец файла в аргументе по умолчанию"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "неверное положение %<@%D%> конструкции Objective-C++"
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "ожидались спецификаторы декларации"
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "в конструкции %<@encode%> в качестве аргумента должен быть задан тип"
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "ожидались спецификаторы декларации"
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "%Jатрибут section недопустим для локальных переменных"
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "неверно задан векторный тип для атрибута %qE"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Ожидался идентификатор"
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "атрибут %qE для %qE проигнорирован"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "некорректный тип аргумента"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 msgid "expected positive integer expression"
 msgstr "ожидалось выражение"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%qD не является элементом типа %qT"
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "неверный инициализатор"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "#pragma %s уже зарегистрирована"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "регистровая переменная %qs использована во вложенной функции"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, fuzzy, gcc-internal-format
 msgid "not enough collapsed for loops"
 msgstr "недостаточная информация о типе"
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "атрибуты не допускаются при определении функции"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "неверный инициализатор"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "ожидалось выражение"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "ожидалось %<:%>, %<,%>, %<;%>, %<}%> или %<__attribute__%>"
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "в описании возвращаемого типа нельзя определять новые типы"
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "мусор в конце директивы %<#pragma pack%>"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "некорректные ограничения для операнда"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "фигурные скобки внутри выражений допускаются только в теле функции"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "фигурные скобки внутри выражений допускаются только в теле функции"
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "фигурные скобки внутри выражений допускаются только в теле функции"
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "межмодульные оптимизации пока не реализованы"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 msgid "expected variable-name"
 msgstr "ожидалось имя класса"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "ожидалось %<,%> или %<)%>"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "элемент данных %qD не должен быть членом шаблона"
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "некорректная декларация элемента-шаблона %qD"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "явная специализация в не-namespace области %qD"
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "объемлющие шаблоны классов не были явно специализированы"
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "специализация %qD в другой namespace-области"
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "специализация %qD в другой namespace-области"
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, fuzzy, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr "%Jпереопрелеление %qD"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "декларация %qD в %qD, который не объемлет %qD"
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "параметр шаблона `%#D'"
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "явная специализация не-шаблона %qT"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "явная специализация не-шаблона %qT"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "специализация %qT после конкретизации"
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "специализация %q#T в другой namespace-области"
@@ -40696,67 +40738,67 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "специализация %qT после конкретизации %qT"
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "специализация шаблона с привязкой C"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "явная специализация %D после первого использования"
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, fuzzy, gcc-internal-format
 msgid "candidate is: %#D"
 msgstr "претендент: %+#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, fuzzy, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %+#T"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD не является шаблоном функции"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "аргумент `asm' - не константная строка"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "идентификатор шаблона %qD использован как декларатор"
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "неоднозначная конкретизация шаблона %qD для %q+D"
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %D (should be %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -40763,57 +40805,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "перед явной специализацией должно быть 'template <>'"
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "специализация шаблона с привязкой C"
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD не является функцией шаблоном"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "отсутствует декларация %qD в %qD"
@@ -40826,93 +40868,93 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr ""
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, fuzzy, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "<anonymous>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "декларация `%#D'"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, fuzzy, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr "параметр шаблона `%#D'"
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "аргументы по умолчанию не допускаются в декларации специализации friend-шаблона %qD"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT declared %<friend%>"
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr "частичная специализация %qT объявлена %<friend%>"
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "это предыдущее определение `%#D'"
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -40920,12 +40962,12 @@
 msgstr[1] "несоответствия типа/значения в аргументе %d в списке параметров шаблона для %qD"
 msgstr[2] ""
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "специализация %qT после конкретизации %qT"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -40933,42 +40975,42 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%Jв списке параметров пропущено имя параметра"
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "аргументы по умолчанию не допускаются в декларации специализации friend-шаблона %qD"
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr "аргументы по умолчанию не допускаются в декларации специализации friend-шаблона %qD"
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "аргументы по умолчанию не допускаются в декларации специализации friend-шаблона %qD"
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "аргументы по умолчанию не допускаются в декларации специализации friend-шаблона %qD"
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "аргумент по умолчанию для параметра типа %qT имеет тип %qT"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "%sэлемент, функция %qD, не может иметь квалификатор метода - %qT"
@@ -40978,57 +41020,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "некорректная template-декларация %qD"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "определение шаблона для не-шаблона `%#D'"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, fuzzy, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "ожидалось %d уровней параметров шаблона для `%#D', обнаружено %d"
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "обнаружено %d параметров шаблона для `%#D'"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "обнаружено %d параметров шаблона для %q#T"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  вместо требуемых %d"
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "параметры шаблона не могут быть friend"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, fuzzy, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr "объемлющие шаблоны классов не были явно специализированы"
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT не является шаблонным типом"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "в декларации %qs по умолчанию установлен тип `int'"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -41036,7 +41078,7 @@
 msgstr[1] "использование %qD без параметров шаблона"
 msgstr[2] ""
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q+D used %d template parameter"
 msgid_plural "previous declaration %q+D used %d template parameters"
@@ -41044,12 +41086,12 @@
 msgstr[1] "предыдущей декларации `%#D', которая находится здесь"
 msgstr[2] ""
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "параметр шаблона `%#D'"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, fuzzy, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "повторно объявлен здесь как `%#D'"
@@ -41058,102 +41100,102 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "повторное определение аргумента по умолчанию для `%#D'"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "%J  исходное определение находится здесь"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE не является корректным аргументом шаблона"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "строковый литерал %E  не является корректным аргументом шаблона, потому что это адрес статического объекта"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "строковый литерал %E  не является корректным аргументом шаблона, потому что это адрес статического объекта"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, fuzzy, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(указатель на элемент можно получить только при помощи %<&%E%>)"
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "обнаружено %d параметров шаблона для `%#D'"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "сравнение между типами `%#T' и `%#T'"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "%qD не может иметь аргументов по умолчанию"
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "параметры шаблона не могут быть friend"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs не является корректным выходным файлом"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "%qE не является корректным аргументом шаблона"
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "%qE не является корректным аргументом шаблона"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -41161,172 +41203,172 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "некорректное преобразование от типа %qT к типу %qT"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT является неоднозначной базой %qT"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "тип %qT не является производным от %qT"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "нельзя %s указатель на неполный тип %qT"
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qD"
 msgstr "параметры шаблона не могут быть friend"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, fuzzy, gcc-internal-format
 msgid "  could not resolve address from overloaded function %qE"
 msgstr "%s: ошибка при определении адреса перегруженной функции"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "строковый литерал %E  не является корректным аргументом шаблона, потому что это адрес статического объекта"
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT "
 msgstr "аргумент по умолчанию для `%#D' имеет тип %qT"
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qE не является корректным аргументом шаблона"
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE не является корректным аргументом шаблона"
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE не является корректным аргументом шаблона"
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "строковый литерал %E  не является корректным аргументом шаблона, потому что это адрес статического объекта"
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE не является корректным аргументом шаблона"
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE не является корректным аргументом шаблона"
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE не является корректным аргументом шаблона"
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "строковый литерал %E  не является корректным аргументом шаблона, потому что это адрес статического объекта"
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr "строковый литерал %E  не является корректным аргументом шаблона, потому что это адрес статического объекта"
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE не является корректным аргументом шаблона"
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "попробуйте задать %qE"
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE не является корректным аргументом шаблона"
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "стандартные преобразования в данном контексте недопустимы"
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "некорректный тип аргумента"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "параметр шаблона `%#D'"
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "некорректное использование деструктора %qD в качестве типа"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "для того чтобы сослаться на тип параметра шаблона, используйте конструкцию %<typename %E%>"
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "несоответствия типа/значения в аргументе %d в списке параметров шаблона для %qD"
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  ожидалась константа типа %qT, а обнаружено %qT"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  ожидался шаблон класса, а обнаружено %qE"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  ожидался тип, обнаружено %qE"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  ожидался тип, обнаружено %qT"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  ожидался шаблон класса, обнаружено %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ожидался шаблон типа %qD, обнаружено %qD"
@@ -41333,78 +41375,78 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "несоответствие типов в условном выражении"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr "ошибка при преобразовании аргумента шаблона %qE в %qT"
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "некорректный аргумент шаблона %d"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "задано для %q+D"
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "аргумент по умолчанию для параметра типа %qT имеет тип %qT"
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%qD не является шаблоном функции"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "не-шаблонный тип %qT использован как шаблон"
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "для декларации шаблона %q+D"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (задайте -ftemplate-depth-NN, чтобы увеличить максимум) при конкретизации %qD"
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "повторное определение аргумента по умолчанию для `%#D'"
@@ -41422,267 +41464,267 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "переменная %qs инициализирована, хотя имеет неполный тип"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "некорректный тип параметра %qT"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "в декларации %q+D"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "функция возвращает агрегатное значение"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "%qs объявлена как функция, возвращающая функцию"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "создание указателя на элемент-функцию не классового типа %qT"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "создание ссылки на void"
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "создание %s на ссылочный тип %qT"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "создание %s на ссылочный тип %qT"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "нельзя %s указатель на неполный тип %qT"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "недопустимая декларация ссылки на %q#T"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "создание указателя на элемент не классового типа %qT"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "создание указателя на элемент ссылочного типа %qT"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "создание указателя на элемент ссылочного типа %qT"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "создание массива элементов типа %qT"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT не является типом class, struct или union"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "создание массива элементов типа %qT, являющегося абстрактным классом"
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "использование %qs в шаблоне"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора `~%T'"
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "задайте %<typename %E%>, если подразумевается тип"
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "отсутствует статическое поле %qs"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "неправильное использование void-выражения"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "аргументы %<...%>.)"
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> не является типом"
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared here, later in the translation unit"
 msgstr "%H%qE не описан в этой области (не в функции)"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT не является классом или пространством имён"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD не является классом или пространством имён"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr "в %qT используется анонимный тип"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "аргумент по умолчанию для `%#D' имеет тип %qT"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  при конкретизации %qD"
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "неоднозначная конкретизация шаблона класса для %q#T"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "неоднозначная конкретизация шаблона класса для %q#T"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 msgid "%s %#S"
 msgstr "%s %+#T"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "явная конкретизация `%#D', не являющегося шаблоном"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "`%#D' не является нестатическим элементом %qT"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "нет подходящего шаблона для %qD"
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "явная конкретизация типа %qT, не являющегося шаблоном"
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "явная конкретизация `%#D'"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "повторная явная конкретизация `%#D'"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ запрещает использование %<extern%> в явной конкретизации"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "класс хранения %qD в конкретизации шаблона"
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "явная конкретизация `%#D', не являющегося шаблоном"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "явная конкретизация типа %qT, не являющегося шаблоном"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "явная конкретизация %q#T до определения шаблона"
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ запрещает использование %qE в явных конкретизациях"
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "повторная явная конкретизация %q#T"
@@ -41694,62 +41736,62 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "явная конкретизация %qD без определения"
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (задайте -ftemplate-depth-NN, чтобы увеличить максимум) при конкретизации %qD"
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "неправильное использование недоопределенного typedef %qD"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "`%#T' не является корректным типом для константного параметра шаблона"
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "эмуляция %qs невозможна"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "эмуляция %qs невозможна"
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "в описании возвращаемого типа нельзя определять новые типы"
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
@@ -41988,261 +42030,261 @@
 msgid "invalid base-class specification"
 msgstr "некорректная спецификация базового класса"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "protected-элемент `%#D' в анонимном объединении"
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD не является типом"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, fuzzy, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "использование %s в объемлющей функции"
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, fuzzy, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "использование %s в объемлющей функции"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "использование пространства имён %qD в качестве выражения"
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "использование шаблона класса %qT в качестве выражения"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "запрос элемента %qD неоднозначен в сетке множественного наследования"
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "тип %qE неизвестен"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT не является пространством имён"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "спецификаторы класса хранения не допускаются в декларациях параметров"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "некорректное использование нестатической функции-элемента %qD"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "ссылка на %qD противоречива"
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, fuzzy, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "неверное употребление спецификатора %<restrict%>"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "предикат должен быть идентификатором"
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qT не является базовым для %qT"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "instance-переменная %qs объявлена как private"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "instance-переменная %qs объявлена как private"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "предикат должен быть идентификатором"
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "сравнение знакового и беззнакового целых выражений"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, gcc-internal-format
 msgid "%<num_teams%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "предикат должен быть идентификатором"
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "предикат должен быть идентификатором"
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qT не является базовым для %qT"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qT не является базовым для %qT"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, fuzzy, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr "создание %s на ссылочный тип %qT"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jпараметр %u имеет неполный тип"
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "Не выполнено необходимое условие в коде CRIS: "
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "неstatic-декларация %q+D после static-декларации"
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, fuzzy, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "использование шаблона класса %qT в качестве выражения"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s: ошибка при определении адреса перегруженной функции"
@@ -42257,119 +42299,119 @@
 msgid "lambda-expression in a constant expression"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "атрибут %qs допустим только для определений Java-классов"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "атрибут %qs допустим только для определений классов"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, fuzzy, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr "%qs устарел; таблицы виртуальных функций g++ теперь COM-совместимы по умолчанию"
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "заданный init_priority не является целой константой"
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, fuzzy, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "атрибут %qs может использоваться только для определений объектов типа class на уровне файла"
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "заданный init_priority вне диапазона"
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "заданный init_priority зарезервировано для внутреннего использования"
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "атрибут %qs не поддерживается на данной платформе"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "декларация %qD перекрывает элемент класса, на который указывает 'this'"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "предыдущей декларации `%#D', которая находится здесь"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "аргументом атрибута %qs должна быть целая константа"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргумент атрибута %qs не является строковой константой"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргумент атрибута %qs не является строковой константой"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> не является корректным декларатором"
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> не является корректным декларатором"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "атрибут %qE для не классовых типов игнорируется"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "отброшены атрибуты класса, заданные вне его объявления"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "отброшены атрибуты класса, заданные вне его объявления"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "отброшены атрибуты класса, заданные вне его объявления"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%J%qE: атрибут допустим только для функций"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%J%qE: атрибут допустим только для функций"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "индекс массива не является целым значением"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check: ошибка в %s, в %s:%d"
@@ -42561,567 +42603,562 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr "выравнивание элементов массива превышает их размер"
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr "ISO C++ не поддерживает индексирование массива, не являющегося левой частью присваивания"
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "индексируемый массив объявлен как %<register%>"
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "индексируемый объект не является ни массивом, ни указателем"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "не задан объект при использовании %qE"
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ запрещает использование %<::main%> из программы"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, fuzzy, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "необходимо использовать .* или ->* для вызова по указателю на элемент-функцию в `%E (...)'"
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE нельзя использовать как функцию"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qE нельзя использовать как функцию"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "%qE нельзя использовать как функцию"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "слишком много аргументов для %s `%+#D'"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "слишком мало аргументов для %s `%+#D'"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "слишком много аргументов в вызове функции %qE"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "слишком мало аргументов в вызове функции %qE"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "слишком много аргументов в вызове функции %qE"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "слишком мало аргументов в вызове функции %qE"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "слишком много аргументов для %s `%+#D'"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "слишком мало аргументов для %s `%+#D'"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "для функции задано слишком много аргументов"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "слишком мало аргументов функции"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "параметр %P %qD имеет неполный тип %qT"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "параметр %P имеет неполный тип %qT"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "предполагается приведение к типу %qT из перегруженной функции"
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL в арифметическом выражении"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, fuzzy, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "%s величина сдвига для rotate отрицательная"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, fuzzy, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "%s величина сдвига для rotate отрицательная"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, fuzzy, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "%s величина сдвига для rotate >= ширина типа"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, fuzzy, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "%s величина сдвига для rotate >= ширина типа"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, fuzzy, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr "для weak декларации %q+D после первого использования поведение системы не специфицировано"
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "адрес %qD всегда будет %<истина%>"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ не поддерживает сравнение между указателем и целым"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "шаблон класса с именем %q#T' отсутствует в %q#T"
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "нет файла для класса %s"
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "аргумент неупорядоченного сравнения - не плавающее значение"
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "некорректные операнды типов %qT и %qT для бинарной операции `%O'"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя %<void *%> в вычитании"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя на функцию в вычитании"
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя на метод в вычитании"
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "некорректное использование указателя на неполный тип в вычислениях с указателями"
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qE"
 msgstr "адрес от временной переменной"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qE"
 msgstr "адрес от временной переменной"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "некорректное использование '%E' для образования указателя на элемент-функцию. Используйте квалифицированный идентификатор."
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "нельзя использовать скобки вокруг '%E' для образования указателя на элемент-функцию."
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ не поддерживает взятие адреса от неквалифицированного элемента-функцииили элемента в скобках для формирования указателя на элемент-функцию.Используйте синтаксис %<&%T::%D%>"
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++  не поддерживает взятие адреса от bound-элемента-функции для формирования указателя на элемент-функцию. Используйте синтаксис %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "адрес от временной переменной"
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, fuzzy, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "адрес от временной переменной"
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ не поддерживает взятие адреса от функции %<::main%>"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr "ISO C++  не поддерживает взятие адреса от приведения к не-lvalue-выражению"
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "нельзя создать указатель на элемент-ссылку %qD"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ не поддерживает %sацию по отношению к перечислимому типу"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ не поддерживает %sацию по отношению к перечислимому типу"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "нельзя %s указатель на неполный тип %qT"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "нельзя %s указатель на неполный тип %qT"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ не поддерживает %sацию по отношению к указателю на тип %qT"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ не поддерживает %sацию по отношению к указателю на тип %qT"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "в списке операндов задано некорректное выражение"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "нельзя взять адрес от %<this%>, поскольку это rvalue-выражение"
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "запрошен адрес регистровой переменной %qs"
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, fuzzy, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "взятие адреса от %qD, объявленного как `register'"
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "инициализатор для %qT должен быт заключен в фигурные скобки"
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s - список выражений рассматривается как составное выражение"
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s - список выражений рассматривается как составное выражение"
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s - список выражений рассматривается как составное выражение"
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s - список выражений рассматривается как составное выражение"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "преобразование из %qT в %qT отменяет квалификаторы"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, fuzzy, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "некорректное применение static_cast от типа %qT к типу %qT"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "некорректное применение static_cast от типа %qT к типу %qT"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %qT"
 msgstr "нелокальная функция %q#D использует локальный тип %qT"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "некорректное применение static_cast от типа %qT к типу %qT"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "преобразование из %qT в %qT"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, fuzzy, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "некорректное применение reinterpret_cast от rvalue-выражения типа %qT к типу %qT"
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr "reinterpret_cast от %qT к %qT снижает точность"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "приведение от %qT к %qT увеличивает размер выравнивания для указуемого типа"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ не поддерживает приведение типа указателя на функцию к указателю на объект"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "некорректное применение const_cast от типа %qT к типу %qT"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "некорректное применение const_cast с типом %qT, не являющимся ни указателем, ни ссылкой, ни  указателем на элемент данных"
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "некорректное применение const_cast с типом %qT, являющимся указателем или ссылкой на функцию"
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "некорректное применение const_cast от rvalue-выражения типа %qT к типу %qT"
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "некорректное применение const_cast от типа %qT к типу %qT"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ не поддерживает приведение к типу массива %qT"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "некорректное приведение к типу функции %qT"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  в вычислении %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "неконстантный индекс массива в инициализаторе"
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "несовместимые типы в присваивании %qT -> %qT"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "некорректный инициализатор массива"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "некорректная левая часть в присваивании"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   в преобразовании указателя на элемент-функцию"
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "преобразование указателя к элементу через виртуальную базу %qT"
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   в преобразовании указателя на элемент"
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "некорректное преобразование к типу %qT от типа %qT"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "ошибка преобразования %qT в %qT для аргумента `%P' функции %qD"
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "ошибка преобразования %qT в %qT для аргумента `%P' функции %qD"
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "ошибка преобразования %qT в %qT в %s"
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "ошибка преобразования %qT в %qT в %s"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "ошибка преобразования %qT в %qT в %s"
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "ошибка преобразования %qT в %qT в %s"
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "ошибка преобразования %qT в %qT в %s"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "тип результата %q#T неполный"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "аргументу %d %qE, вероятно, можно назначить атрибут format"
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "тип результата, вероятно, может быть задан с атрибутом format"
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Предупреждать о функциях, которым можно назначить атрибут format"
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "Предупреждать о функциях, которым можно назначить атрибут format"
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "левой части присваивания, вероятно, можно назначить атрибут format"
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "при передаче аргумента %P функции `%+D'"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "возврат ссылки на временную переменную"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "возвращена ссылка на не-lvalue-выражение"
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr "возвращена ссылка на локальную переменную %q+D"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %q+D returned"
 msgstr "возвращен адрес локальной переменной %q+D"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr "возвращен адрес локальной переменной %q+D"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "возвращен результат деструктора"
@@ -43128,45 +43165,45 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "возврат в обработчике try-блока конструктора"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "возврат результата конструктора"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return без значения в функции, возвращающей %qT"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "фигурные скобки вокруг скалярного инициализатора"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "return со значением в функции, возвращающей 'void'"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> не должен возвращать NULL, если только он не декларирован %<throw()%> (или задан ключ -fcheck-new)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -43397,125 +43434,125 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr "преобразование %qE из %qT в %qT неоднозначно"
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, fuzzy, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "преобразование %qE из %qT в %qT неоднозначно"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "инициализация массива int строкой не широких символов"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, fuzzy, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "инициализация массива int строкой не широких символов"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "слишком длинная строка инициализации для символьного массива"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "отсутствует инициализатор для элемента %qD"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "элемент %qD - неинициализированная ссылка"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "элемент %qD - неинициализированная ссылка"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "в инициализируемом объединении нет поля %qD"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "значение индекса вместо имени поля в инициализаторе объединения"
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "обнаружено циклическое делегирование указателей"
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "базовый операнд `->' имеет неуказательный тип %qT"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "результат %<operator->()%> не является указателем"
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "базовый операнд %<->%> не является указателем"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE не может использоваться как элемент, поскольку имеет тип %qT"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "недопустимое взятие элемента %qE от %qE, который имеет неагрегатный тип %qT"
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, fuzzy, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "тип элемента `%T::' несовместим с типом объекта %qT"
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "в арифметическом выражении использован указатель на элемент-функцию"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "в арифметическом выражении использован указатель на элемент-функцию"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "некорректное приведение к типу функции %qT"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "инициализация по умолчанию для `%#D', имеющего тип ссылки"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "вызов функции %qD, которая вызывает исключение неполного типа `%#T'"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "вызов функции, которая вызывает исключение неполного типа `%#T'"
@@ -43693,8 +43730,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -43829,7 +43866,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr "Спецификация нулевого размера в %0 некорректна"
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -43945,7 +43982,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "аргумент `asm' - не константная строка"
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "аргумент `asm' - не константная строка"
@@ -44533,12 +44570,12 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "аргумент `asm' - не константная строка"
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "аргумент `asm' - не константная строка"
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "аргумент `asm' - не константная строка"
@@ -44809,6 +44846,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "аргумент `asm' - не константная строка"
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -44816,7 +44858,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -45036,401 +45078,401 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "недопустимая инициализация многомерного массива при помощи инициализатора"
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "синтаксическая ошибка в списке параметров макроса"
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Компонент в %C должен иметь атрибут POINTER"
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "повторная инициализация %qD"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "Function name %qs not allowed at %C"
 msgstr "атрибут section для %q+D недопустим"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "недопустимая инициализация многомерного массива при помощи инициализатора"
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "повторная инициализация %D"
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "повторная инициализация %qD"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "инициализация по умолчанию для `%#D', имеющего тип ссылки"
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, fuzzy, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Отсутствует открывающая скобка"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "режим округления для поддерживается для плавающих вычислений VAX"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Отсутствует открывающая скобка"
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "режим округления для поддерживается для плавающих вычислений VAX"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "стандартные преобразования в данном контексте недопустимы"
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Имя типа '%s' в %C неоднозначно"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "оператор PUBLIC или PRIVATE в %1 несовместим с оператором PUBLIC или PRIVATE в %0"
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "синтаксическая ошибка при разборе `%s'"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Отсутствует спецификатор %A в операторе в %0"
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Отсутствует спецификатор %A в операторе в %0"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "повторное употребление `restrict'"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "атрибуты не допускаются при определении функции"
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "атрибуты не допускаются при определении функции"
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "атрибуты не допускаются при определении функции"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%Jатрибут section для `%D' недопустим"
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "повторное употребление `restrict'"
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "%Jinline функция %qD с атрибутом noinline"
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "%Jinline функция %qD с атрибутом noinline"
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, fuzzy, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "%Jвнутренняя функция `%D' декларирована как не функция"
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "отмена декларации %qD в пространстве имён %qD"
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "отмена декларации %qD в пространстве имён %qD"
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "%Jвнутренняя функция `%D' декларирована как не функция"
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "конструктор не может быть статической элементом-функцией"
@@ -45437,796 +45479,801 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Отсутствует спецификатор %A в операторе в %0"
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "отсутствует число"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "синтаксическая ошибка в списке параметров макроса"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "отсутствует аргумент ключа %qs"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "`%D' не является элементом типа `%T'"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Неожиданное окончание строки формата"
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Неожиданное окончание строки формата"
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Некорректный мусор после определения в %C"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "оператор SAVE или атрибут в %1 несовместим с оператором SAVE или атрибутом в %0"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Функция '%s' в %C уже имеет тип %s"
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Недопустимое число в операторе FORMAT в %0"
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Предупреждать о декларациях, встретившихся после операторов"
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Недопустимое число в операторе FORMAT в %0"
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "синтаксическая ошибка при разборе `%s'"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "В определении в %C ожидается формальный список аргументов"
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/decl.c:5597
-#, gcc-internal-format
-msgid "gfc_match_entry(): Bad state"
-msgstr ""
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Unexpected ENTRY statement at %C"
+msgstr "ожидалось имя типа"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Пропущена запятая в операторе FORMAT в %0"
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Спецификация нулевого размера в %0 некорректна"
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Отсутствует формальный параметр"
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "Недопустимое число в операторе FORMAT в %0"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "ожидалось имя типа"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Нет определения метки для оператора FORMAT в %0"
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Нет определения метки для оператора FORMAT в %0"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Отсутствует спецификатор %A в операторе в %0"
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr ""
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Отсутствует спецификатор %A в операторе в %0"
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Предупреждать о декларациях, встретившихся после операторов"
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, fuzzy, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "предикат должен быть идентификатором"
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Предупреждать о декларациях, встретившихся после операторов"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Недопустимое число в операторе FORMAT в %0"
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Недопустимый знак в операторе FORMAT в %0"
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Предупреждать о декларациях, встретившихся после операторов"
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "строка инициализации усечена в соответствии с размером переменной в %L"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Предупреждать о декларациях, встретившихся после операторов"
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Недопустимое число в операторе FORMAT в %0"
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Недопустимое число в операторе FORMAT в %0"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Недопустимое число в операторе FORMAT в %0"
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Недопустимое число в операторе FORMAT в %0"
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Внешняя процедура `%A' передана как фактический аргумент в %0, но не декларирована явно как EXTERNAL"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qD не может быть локально-поточным, поскольку имеет не-POD тип %qT"
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Имя типа в %0 не совпадает с именем, заданным в %1"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Функция '%s' в %C уже имеет тип %s"
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "определение %qD уже есть в %qT"
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "перед `*' должно быть имя типа"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "после предыдущей спецификации в `%#D'"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "повторное употребление `restrict'"
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "  ожидался шаблон класса, обнаружено %qT"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "атрибут packed не требуется"
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, fuzzy, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Ожидался идентификатор"
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "  ожидался тип, обнаружено %qE"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Спецификация нулевого размера в %0 некорректна"
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "Спецификация нулевого размера в %0 некорректна"
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Ожидается другая размерность массива в определении %C"
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Malformed GENERIC statement at %C"
+msgstr "Неподдерживаемый VXT-оператор в %0"
+
+#: fortran/decl.c:8526
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Предупреждать о декларациях, встретившихся после операторов"
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, fuzzy, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "ошибка в аргументах spec-функции '%s'"
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "передано %qT для %s %P в %qD"
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Неизвестный оператор '%s' в %%L"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Предупреждать о декларациях, встретившихся после операторов"
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Недопустимое число в операторе FORMAT в %0"
@@ -46506,343 +46553,343 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "%q+D не является функцией,"
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "несовместимые типы в операторе %qs"
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "несовместимые типы в операторе %qs"
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "некорректное преобразование из %qT в %qT"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "некорректное преобразование из %qT в %qT"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Conversion from %qs to %qs at %L"
 msgstr "преобразование из %s в %s в %L"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Несовместимые типы в присваивании в %L, %s к %s"
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "после предыдущей спецификации в `%#D'"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Несовместимые типы при присваивании указателей в %L"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Функция-оператор `%A', определенная в %0, не используется"
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, fuzzy, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Функция-оператор `%A', определенная в %0, не используется"
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Функция-оператор `%A', определенная в %0, не используется"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Внешняя процедура `%A' передана как фактический аргумент в %0, но не декларирована явно как EXTERNAL"
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Внешняя процедура `%A' передана как фактический аргумент в %0, но не декларирована явно как EXTERNAL"
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Внешняя процедура `%A' передана как фактический аргумент в %0, но не декларирована явно как EXTERNAL"
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Несовместимые типы при присваивании указателей в %L"
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Несовместимые типы при присваивании указателей в %L"
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Присваивание указателя не к указателю в %L"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "стандартные преобразования в данном контексте недопустимы"
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Компонент в %C должен иметь атрибут POINTER"
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Компонент в %C должен иметь атрибут POINTER"
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "аргумент `asm' - не константная строка"
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "аргумент `asm' - не константная строка"
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "аргумент `asm' - не константная строка"
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "ошибка открытия входного файла %qs"
@@ -46864,27 +46911,27 @@
 msgid "Removing call to function %qs at %L"
 msgstr "%Jвнутренняя функция `%D' декларирована как не функция"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, fuzzy, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "некорректный операнд в инструкции"
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr ""
@@ -46939,592 +46986,597 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr ""
+
+#: fortran/interface.c:353
+#, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr ""
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr ""
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr ""
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr ""
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr ""
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr ""
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr ""
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
 msgstr "Внешняя процедура `%A' передана как фактический аргумент в %0, но не декларирована явно как EXTERNAL"
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, gcc-internal-format
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr ""
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, fuzzy, gcc-internal-format
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "ссылка %qs неоднозначна: имеется в интерфейсе %qs и в интерфейсе %qs"
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "`%D' не является элементом типа `%T'"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, fuzzy, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Альтернативный спецификатор возврата в %0 внутри главной программы"
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "неверный аргумент для %qs"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "несоответствия типа/значения в аргументе %d в списке параметров шаблона для %qD"
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "передано %qT для %s %P в %qD"
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "передано %qT для %s %P в %qD"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Функция-оператор `%A', определенная в %0, не используется"
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "некорректное адресное выражение"
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "передано %qT для %s %P в %qD"
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "передано %qT для %s %P в %qD"
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "передано %qT для %s %P в %qD"
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "передано %qT для %s %P в %qD"
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "передано %qT для %s %P в %qD"
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "передано %qT для %s %P в %qD"
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "передано %qT для %s %P в %qD"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "передано %qT для %s %P в %qD"
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "%q+D - алиас неопределенного символа %qs"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, fuzzy, gcc-internal-format
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr "Не удалось преобразовать %s в %s в %L"
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
@@ -47935,12 +47987,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
@@ -47950,7 +48002,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
@@ -47975,776 +48027,776 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "оператор-выражение имеет неполный тип"
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr ""
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "повторная инициализация %D"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "повторная инициализация %D"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "дважды задан ключ -I-"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "Пропущена запятая в операторе FORMAT в %0"
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "некорректное преобразование из %qT в %qT"
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "метка %qD используется, но не определяется"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "метка %qD используется, но не определяется"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "метка %qD используется, но не определяется"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "метка %qD используется, но не определяется"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "синтаксическая ошибка в списке параметров макроса"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Лишняя запятая в операторе FORMAT в %0"
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Предупреждать о декларациях, встретившихся после операторов"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "синтаксическая ошибка при разборе `%s'"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "пространство имён %qD не допускается в using-декларации"
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Лишняя запятая в операторе FORMAT в %0"
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
 msgstr ""
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "перед `*' должно быть имя типа"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "перед `*' должно быть имя типа"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr "Целое в %0 слишком велико"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr ""
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 msgid "Label name %qs at %C is ambiguous"
 msgstr "использование `%D' неоднозначно"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, fuzzy, gcc-internal-format
 msgid "Duplicate construct label %qs at %C"
 msgstr "дублирование метки `%D'"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr "Символьная константа нулевой длины в %0"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr ""
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr ""
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr "не параметрический %qs не может содержать параметры"
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr ""
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr ""
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr "синтаксическая ошибка в списке параметров макроса"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, gcc-internal-format, gfc-internal-format
 msgid "gfc_match(): Bad match code %c"
 msgstr ""
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr "Пропущена запятая в операторе FORMAT в %0"
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr "переполнение при вычислении целочисленного выражения"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr "Нет определения метки для оператора FORMAT в %0"
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr ""
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "метка %qD определена, но не используется"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr ""
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr "Лишняя запятая в операторе FORMAT в %0"
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in association at %C"
 msgstr "после предыдущей спецификации в `%#D'"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, fuzzy, gcc-internal-format
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "некорректный тип аргумента"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "синтаксическая ошибка в списке параметров макроса"
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "Нет определения метки для оператора FORMAT в %0"
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "оператор continue вне цикла"
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "оператор continue вне цикла"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "оператор continue вне цикла"
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "оператор continue вне цикла"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "оператор break вне цикла или оператора switch"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, fuzzy, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "оператор break вне цикла или оператора switch"
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "оператор break вне цикла или оператора switch"
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "оператор continue вне цикла"
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "Начало или конец подстроки в %0 вне диапазона, заданного в определении"
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "предикат должен быть идентификатором"
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "Некорректная операция с указателем в PURE процедуре в %L"
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "Функция-оператор `%A', определенная в %0, не используется"
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "тип элемента `%T::' несовместим с типом объекта %qT"
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "Функция-оператор `%A', определенная в %0, не используется"
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "некорректное адресное выражение"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "передано %qT для %s %P в %qD"
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "синтаксическая ошибка в списке параметров макроса"
@@ -48752,147 +48804,147 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr ""
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, fuzzy, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "Функция '%s' в %C уже имеет тип %s"
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Альтернативный спецификатор возврата в %0 некорректен внутри функции"
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Расширение COMMON-области по сравнению с исходным размером посредством оператора EQUIVALENCE для `%A'"
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Лишняя запятая в операторе FORMAT в %0"
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "Функция-оператор `%A', определенная в %0, не используется"
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "Функция-оператор `%A', определенная в %0, не используется"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Ожидалась бинарная операция между выражениями в %0 и в %1"
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, fuzzy, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "  ожидался шаблон класса, обнаружено %qT"
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Недопустимое число в операторе FORMAT в %0"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Спецификация нулевого размера в %0 некорректна"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Спецификация нулевого размера в %0 некорректна"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Спецификация нулевого размера в %0 некорректна"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -49041,169 +49093,169 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Метка %A уже определена в %1 а затем переопределена в %0"
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, fuzzy, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Элемент массива в %0 вне диапазона, заданного в определении"
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "%s: ошибка открытия файла '%s' на чтение: %s\n"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: ошибка записи файла '%s': %s\n"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: ошибка удаления файла '%s': %s\n"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: ошибка переименования файла '%s' в '%s': %s\n"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: ошибка удаления вспомогательного файла '%s': %s\n"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is already declared in this scope"
 msgid "Symbol %qs already declared"
 msgstr "в этой области видимости уже есть декларация %qD"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "ожидалось имя типа"
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: ошибка открытия файла '%s' на чтение: %s\n"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr ""
@@ -49498,7 +49550,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -50191,367 +50243,362 @@
 msgid "Unexpected %s statement at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/parse.c:2428
+#: fortran/parse.c:2438
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr "ожидалось имя типа"
-
-#: fortran/parse.c:2439
-#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "Оператор в %0 некорректен в контексте, установленном оператором в %1"
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr "Неожиданное окончание строки формата"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "предикат должен быть идентификатором"
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, fuzzy, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "Имя типа в %0 не совпадает с именем, заданным в %1"
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr ""
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "Оператор в %0 некорректен в программной единице BLOCK DATA в %1"
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "Оператор в %0 некорректен в программной единице BLOCK DATA в %1"
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "ошибка в аргументах spec-функции '%s'"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, fuzzy, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Альтернативный спецификатор возврата в %0 некорректен внутри функции"
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "оператор PUBLIC или PRIVATE в %1 несовместим с оператором PUBLIC или PRIVATE в %0"
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr "ожидалось имя типа"
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "использование `%D' неоднозначно"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "оператор RETURN в %0 недопустим внутри главной программы"
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "ожидалось имя типа"
@@ -50559,7 +50606,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -51254,7 +51301,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Метка %A уже определена в %1 а затем переопределена в %0"
@@ -51309,364 +51356,364 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "Внешняя процедура `%A' передана как фактический аргумент в %0, но не декларирована явно как EXTERNAL"
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, fuzzy, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "ошибка в аргументах spec-функции '%s'"
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, fuzzy, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "ошибка в аргументах spec-функции '%s'"
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "%Jвнутренняя функция `%D' декларирована как не функция"
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "%Jвнутренняя функция `%D' декларирована как не функция"
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "%Jвнутренняя функция `%D' декларирована как не функция"
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%q+D не является функцией,"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, fuzzy, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "Недопустимое число в операторе FORMAT в %0"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, fuzzy, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "%s: ошибка при определении адреса перегруженной функции"
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Функция '%s' в %C уже имеет тип %s"
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, fuzzy, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "ошибка в аргументах spec-функции '%s'"
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "ошибка в аргументах spec-функции '%s'"
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, fuzzy, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, fuzzy, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "%s: ошибка при определении адреса перегруженной функции"
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "shared и mdll несовместимы"
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Элемент массива в %0 вне диапазона, заданного в определении"
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Элемент массива в %0 вне диапазона, заданного в определении"
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Элемент массива в %0 вне диапазона, заданного в определении"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Элемент массива в %0 вне диапазона, заданного в определении"
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Элемент массива в %0 вне диапазона, заданного в определении"
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Элемент массива в %0 вне диапазона, заданного в определении"
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Элемент массива в %0 вне диапазона, заданного в определении"
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Элемент массива в %0 вне диапазона, заданного в определении"
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "отсутствует индекс массива"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "отсутствует индекс массива"
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "индекс размерности %d выходит за границы в %L"
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%qD не является элементом типа %qT"
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "Пустой элемент в %0 в обращении к массиву в %1"
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Массив `%A' в %0 слишком велик"
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Начало или конец подстроки в %0 вне диапазона, заданного в определении"
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Начало или конец подстроки в %0 вне диапазона, заданного в определении"
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Начало или конец подстроки в %0 вне диапазона, заданного в определении"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "Пустой элемент в %0 в обращении к массиву в %1"
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Функция-оператор `%A', определенная в %0, не используется"
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Функция-оператор `%A', определенная в %0, не используется"
@@ -51675,12 +51722,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Функция-оператор `%A', определенная в %0, не используется"
@@ -51689,248 +51736,248 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Начало или конец подстроки в %0 вне диапазона, заданного в определении"
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "некорректное адресное выражение"
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%qD не является элементом типа %qT"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Выход за границы в подстроке или обращении к массиву для `%A' в операторе в %0"
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Выход за границы в подстроке или обращении к массиву для `%A' в операторе в %0"
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Нет определения метки для оператора FORMAT в %0"
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Нет определения метки для оператора FORMAT в %0"
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Нет определения метки для оператора FORMAT в %0"
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Оператор в %0 некорректен в контексте, установленном оператором в %1"
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -51939,188 +51986,188 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "оператор-выражение имеет неполный тип"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "оператор-выражение имеет неполный тип"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "оператор-выражение имеет неполный тип"
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "предикат должен быть идентификатором"
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "предикат должен быть идентификатором"
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "некорректное адресное выражение"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "маска должна быть непосредственным значением"
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Оператор в %0 некорректен в контексте, установленном оператором в %1"
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -52127,12 +52174,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "оператор continue вне цикла"
@@ -52140,158 +52187,158 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Оператор в %0 некорректен в контексте, установленном оператором в %1"
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%s по отношению к переменной %qs, доступной только на чтение"
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr ""
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%s по отношению к переменной %qs, доступной только на чтение"
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%s по отношению к переменной %qs, доступной только на чтение"
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr "%s по отношению к переменной %qs, доступной только на чтение"
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "несовместимые типы в операторе %qs"
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "оператор SAVE или атрибут в %1 несовместим с оператором SAVE или атрибутом в %0"
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr ""
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -52298,7 +52345,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -52306,57 +52353,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr ""
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "размер массива %qs слишком велик"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Альтернативный спецификатор возврата в %0 некорректен внутри функции"
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
@@ -52363,422 +52410,422 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr "Функция-оператор `%A', определенная в %0, не используется"
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Функция-оператор `%A', определенная в %0, не используется"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "%Jвнутренняя функция `%D' декларирована как не функция"
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "%Jвнутренняя функция `%D' декларирована как не функция"
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "%Jвнутренняя функция `%D' декларирована как не функция"
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "%Jвнутренняя функция `%D' декларирована как не функция"
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "%Jвнутренняя функция `%D' декларирована как не функция"
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "аргумент `asm' - не константная строка"
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "%qD должен иметь ровно один аргумент"
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "оператор-выражение имеет неполный тип"
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "аргумент `asm' - не константная строка"
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "аргумент `asm' - не константная строка"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "аргумент `%s' должен быть 2-битным беззнаковым литеральным значением"
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "аргумент `asm' - не константная строка"
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Компонент в %C должен иметь атрибут POINTER"
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, fuzzy, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Альтернативный спецификатор возврата в %0 некорректен внутри функции"
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -52785,397 +52832,397 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "несовместимые типы в операторе `%s'"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Альтернативный спецификатор возврата в %0 внутри главной программы"
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "Пустой аргумент в %0 в вызове функции-оператора в %1"
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Компонент в %C должен иметь атрибут POINTER"
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Компонент в %C должен иметь атрибут POINTER"
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "не параметрический %qs не может содержать параметры"
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "%qD не является элементом типа %qT"
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%s не может присутствовать в константном выражении"
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "метка %qD определена, но не используется"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "метка %qD определена, но не используется"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "%qD не является элементом типа %qT"
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "%Jфинальное поле '%D', возможно, не было инициализировано"
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "аргумент `asm' - не константная строка"
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "конструктор не может быть статической элементом-функцией"
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Предупреждать о неявных декларациях функций"
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -53205,47 +53252,47 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr ""
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr ""
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr "Инициализация пустого общего блока в %0"
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "Символьная константа нулевой длины в %0"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr "Лишняя запятая в операторе FORMAT в %0"
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
 msgstr ""
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr "Лишняя запятая в операторе FORMAT в %0"
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr ""
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr "неверная директива препроцессора #%s"
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 msgid "Can't open file %qs"
 msgstr "ошибка открытия входного файла %qs"
@@ -53511,52 +53558,52 @@
 msgid "Reshaped array too large at %C"
 msgstr "Целое в %0 слишком велико"
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, fuzzy, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr "переполнение при вычислении константного выражения"
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "функция возвращает агрегатное значение"
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "неверный аргумент для %qs"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -53634,313 +53681,318 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "Компонент в %C должен иметь атрибут POINTER"
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "Внешняя процедура `%A' передана как фактический аргумент в %0, но не декларирована явно как EXTERNAL"
+
+#: fortran/symbol.c:489
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "Недопустимое число в операторе FORMAT в %0"
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, fuzzy, gcc-internal-format
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute with %s attribute at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, fuzzy, gcc-internal-format
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "%Jinline функция %qD с атрибутом noinline"
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "%Jinline функция %qD с атрибутом noinline"
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "оператор SAVE или атрибут в %1 несовместим с оператором SAVE или атрибутом в %0"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "%Jinline функция %qD с атрибутом noinline"
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "%Jinline функция %qD с атрибутом noinline"
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "%Jinline функция %qD с атрибутом noinline"
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "%Jinline функция %qD с атрибутом noinline"
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "атрибут %qs допустим только для переменных"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "%Jinline функция %qD с атрибутом noinline"
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "%Jinline функция %qD с атрибутом noinline"
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "Неподдерживаемый VXT-оператор в %0"
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Функция '%s' в %C уже имеет тип %s"
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Функция '%s' в %C уже имеет тип %s"
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "%Jфинальное поле %qD, возможно, не было инициализировано"
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr ""
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr "Функция '%s' в %C уже имеет тип %s"
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "использование `%D' неоднозначно"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "предикат должен быть идентификатором"
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "`%D' не является элементом типа `%T'"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Инициализация пустого общего блока в %0"
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Функция '%s' в %C уже имеет тип %s"
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "%Jвнутренняя функция `%D' декларирована как не функция"
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "отмена декларации %qD в пространстве имён %qD"
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "отмена декларации %qD в пространстве имён %qD"
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "некорректное преобразование из %qT в %qT"
@@ -54200,7 +54252,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr "Некорректный базовый тип ввода-вывода (%d)"
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -56273,6 +56325,9 @@
 #~ msgid "%qD has no member named %qE"
 #~ msgstr "%qD не имеет элемента с именем '%E'"
 
+#~ msgid "ISO C++ forbids subscripting non-lvalue array"
+#~ msgstr "ISO C++ не поддерживает индексирование массива, не являющегося левой частью присваивания"
+
 #, fuzzy
 #~ msgid "  since type %qT has pure virtual functions"
 #~ msgstr "  поскольку тип %qT имеет абстрактные виртуальные функции"
Index: gcc/po/sv.po
===================================================================
--- gcc/po/sv.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/sv.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -14,10 +14,10 @@
 # rank			ordning
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 5.1.0\n"
+"Project-Id-Version: gcc 5.2.0\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
-"PO-Revision-Date: 2015-07-04 11:22+0200\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
+"PO-Revision-Date: 2015-07-30 10:38+0200\n"
 "Last-Translator: Göran Uddeborg <goeran@uddeborg.se>\n"
 "Language-Team: Swedish <tp-sv@listor.tp-sv.se>\n"
 "Language: sv\n"
@@ -202,13 +202,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "flyttalskonstant felanvänd"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1401,7 +1401,7 @@
 msgid "options enabled: "
 msgstr "aktiverade flaggor: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2593,97 +2593,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "ogiltig operandprefix ”%%%c”"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "”%%&” använt utan någon lokal dynamisk TLS-referens"
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "ogiltigt %%H-värde"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "ogiltigt %%J-värde"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "ogiltigt %%r-värde"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "ogiltigt %%R-värde"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "ogiltigt %%N-värde"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "ogiltigt %%P-värde"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "ogiltigt %%h-värde"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "ogiltigt %%L-värde"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "ogiltigt %%m-värde"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "ogiltigt %%M-värde"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "ogiltigt %%U-värde"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "ogiltigt %%s-värde"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "ogiltigt %%C-värde"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "ogiltigt %%E-värde"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "okänd avspecifikation av omlokalisering"
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ogiltig %%xn-kod"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, c-format
 msgid "invalid operand address"
 msgstr "ogiltig operandadress"
@@ -2731,7 +2731,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "ogiltig operand i utmatningskod"
@@ -2889,8 +2889,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3110,62 +3110,62 @@
 msgid "bad output_condmove_single operand"
 msgstr "felaktig operand till output_condmove_single"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ogiltig UNSPEC som operand"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ogiltig operandstorlek för operandkod ”O”"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ogiltig operandstorlek för operandkod ”z”"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ogiltig operandtyp vid operandkod ”Z”"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ogiltig operandstorlek för operandkod ”Z”"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operanden är inte en villkorskod, ogiltig operandkod ”Y”"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand är inte en villkorskod, ogiltig operandkod ”D”"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand är inte en villkorskod, ogiltig operandkod ”%c”"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand är inte en justerbar minnesreferens, ogiltig operandkod ”H”"
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ogiltig operandkod ”%c”"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ogiltig begränsning för operand"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "okänt instruktionsläge"
 
@@ -3205,7 +3205,7 @@
 msgid "invalid %%P operand"
 msgstr "ogiltig %%P-operand"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "ogiltigt %%p-värde"
@@ -3269,7 +3269,7 @@
 msgstr "efterinkrementeringsadress är inte ett register"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "felaktig adress"
 
@@ -3431,99 +3431,99 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory är inte tillgängligt i läget med omvänd byteordning"
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 msgid "bad move"
 msgstr "felaktig förflyttning"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, c-format
 msgid "invalid %%e value"
 msgstr "ogiltigt %%e-värde"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "ogiltigt %%f-värde"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "ogiltigt %%F-värde"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "ogiltigt %%G-värde"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "ogiltig %%j-kod"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "ogiltig %%J-kod"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "ogiltigt %%k-värde"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "ogiltigt %%K-värde"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "ogiltigt %%O-värde"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "ogiltigt %%q-värde"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "ogiltigt %%S-värde"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "ogiltigt %%T-värde"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "ogiltigt %%u-värde"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "ogiltig %%v-kod"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "ogiltigt %%x-värde"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ogiltigt %%y-värde, försök använda ”Z”-begränsningen"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argument skickat till funktion utan prototyp"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 msgid "Could not generate addis value for fusion"
 msgstr "Kunde inte generera addis-värde för sammanslagning"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 msgid "Unable to generate load offset for fusion"
 msgstr "Kan inte generera laddningsavstånd för sammanslagning"
 
@@ -3617,60 +3617,60 @@
 msgid "invalid operand to %%S"
 msgstr "ogiltig operand till %%R"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr "skapad och använd med olika arkitekturer/ABI:er"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr "skapad och använd med olika ABI:er"
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr "skapad och använd med olika byteordning"
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "ogiltig %%Y-operand"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "ogiltig %%A-operand"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "ogiltig %%B-operand"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, c-format
 msgid "invalid %%C operand"
 msgstr "ogiltig %%C-operand"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, c-format
 msgid "invalid %%D operand"
 msgstr "ogiltig %%D-operand"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "ogiltig %%f-operand"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "ogiltig %%s-operand"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "long long-konstant inte en giltig omedelbar operand"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "flyttalskonstant inte en giltig omedelbar operand"
@@ -3875,7 +3875,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> förväntades"
@@ -3891,15 +3891,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> förväntades"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> förväntades"
@@ -3921,8 +3921,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> förväntades"
@@ -3929,8 +3929,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> förväntades"
@@ -3939,13 +3939,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "%<;%>, %<,%> eller %<)%> förväntades"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> förväntades"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> förväntades"
@@ -3952,8 +3952,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> förväntades"
@@ -3974,7 +3974,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr "Cilk-vektornotation kan inte användas som villkor till en while-sats"
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> förväntades"
@@ -3991,34 +3991,34 @@
 msgid "expected %<.%>"
 msgstr "%<.%> förväntades"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> förväntades"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> förväntades"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> eller %<)%> förväntades"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> förväntades"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> eller %<}%> förväntades"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> förväntades"
@@ -4027,11 +4027,11 @@
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
@@ -4245,11 +4245,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%r%s:%d:%R   i expansion av konstantuttryck i från %qs"
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "kandidater är:"
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "kandidat är:"
@@ -4295,48 +4295,48 @@
 msgid "source type is not polymorphic"
 msgstr "källtypen är inte polymorfisk"
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "fel typ på argument till unärt minus"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "fel typ på argument till unärt plus"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "fel typ på argument till bitkomplement"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "fel typ på argument till abs"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "fel typ på argument till konjunktion"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 msgid "in argument to unary !"
 msgstr "i argument till unärt !"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 msgid "no pre-increment operator for type"
 msgstr "ingen pre-ökningsoperator för typen"
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr "ingen post-ökningsoperator för typen"
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 msgid "no pre-decrement operator for type"
 msgstr "ingen pre-minskningsoperator för typen"
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr "ingen post-minskningsoperator för typen"
 
@@ -4431,7 +4431,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "För stort heltalsvärde i uttryck vid %C"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 msgid "array assignment"
 msgstr "vektortilldelning"
 
@@ -4455,7 +4455,7 @@
 msgid "Driving:"
 msgstr "Driver:"
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "aktuellt argument till INTENT = OUT/INOUT"
 
@@ -4521,13 +4521,13 @@
 msgid "%s tag"
 msgstr "%s-tagg"
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr "intern enhet i WRITE"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s-tagg med INQUIRE"
@@ -4605,7 +4605,7 @@
 msgid "Bad type in constant expression"
 msgstr "Felaktig typ i konstant uttryck"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 msgid "Unexpected end of module"
 msgstr "Oväntat modulslut"
 
@@ -4633,11 +4633,11 @@
 msgid "implied END DO"
 msgstr "implicerat END DO"
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr "tilldelning"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 msgid "pointer assignment"
 msgstr "pekartilldelning"
 
@@ -4653,189 +4653,189 @@
 msgid "internal function"
 msgstr "intern funktion"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 msgid "elemental procedure"
 msgstr "elementär procedur"
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 msgid "allocatable argument"
 msgstr "allokerbart argument"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 msgid "asynchronous argument"
 msgstr "asynkront argument"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 msgid "optional argument"
 msgstr "valfritt argument"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 msgid "pointer argument"
 msgstr "pekarargument"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 msgid "target argument"
 msgstr "målargument"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 msgid "value argument"
 msgstr "värdeargument"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 msgid "volatile argument"
 msgstr "volatilt argument"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 msgid "assumed-shape argument"
 msgstr "argument med antagen form"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 msgid "assumed-rank argument"
 msgstr "argument med antagen ordning"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 msgid "coarray argument"
 msgstr "co-vektorargument"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 msgid "parametrized derived type argument"
 msgstr "parametriserat härlett typargument"
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 msgid "polymorphic argument"
 msgstr "polymorft argument"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr "attributet NO_ARG_CHECK"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 msgid "assumed-type argument"
 msgstr "argument med antagen typ"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr "vektorresultat"
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 msgid "pointer or allocatable result"
 msgstr "pekare eller allokerbart resultat"
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 msgid "result with non-constant character length"
 msgstr "resultat med teckenlängd som inte är konstant"
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 msgid "bind(c) procedure"
 msgstr "bind(c)-procedur"
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Ogiltigt sammanhang för NULL()-pekare vid %%L"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr "Operand till unär numerisk operator ”%s” vid %%L är %s"
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr "Operander till binär numerisk operator ”%s” vid %%L är %s/%s"
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operanderna till strängkonkateneringsoperatorn vid %%L är %s/%s"
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr "Operanderna till logiska operatorn ”%s” vid %%L är %s/%s"
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operand till operatorn .not. vid %%L är %s"
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX-kvantiteter kan inte jämföras vid %L"
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logiska vid %%L måste jämföras med %s istället för %s"
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr "Operanderna till jämförelseoperatorn ”%s” vid %%L är %s/%s"
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr "Okänd operator ”%s” vid %%L"
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr "Operanderna till användaroperatorn ”%s” vid %%L är %s"
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr "Operanderna till användaroperatorn ”%s” vid %%L är %s/%s"
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Inkonsistenta ordningar för operator vid %%L och %%L"
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr "Slingvariabel"
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 msgid "iterator variable"
 msgstr "iteratorvariabel"
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 msgid "Start expression in DO loop"
 msgstr "Startuttryck i DO-slinga"
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 msgid "End expression in DO loop"
 msgstr "Slututtryck i DO-slinga"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 msgid "Step expression in DO loop"
 msgstr "Steguttryck i DO-slinga"
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE-objekt"
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 msgid "ALLOCATE object"
 msgstr "ALLOCATE-objekt"
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr "STAT-variabel"
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr "ERRMSG-variabel"
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr "objekt i READ"
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK-variabel"
 
@@ -5228,16 +5228,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr "rx200-cpu har inte FPU-hårdvara"
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr "överväg att använda ”-pg” istället för ”-p” med gprof(1)"
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr "överväg att använda ”-pg” istället för ”-p” med gprof(1)"
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr "stödjer inte multilib"
@@ -5250,6 +5240,10 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "-Xbind-now och -Xbind-lazy är inkompatibla"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+msgid "profiling not supported with -mg"
+msgstr "profilering stödjs inte med -mg"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "-mhard-float stödjs inte"
@@ -5258,10 +5252,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "-msingle-float och -msoft-float kan inte båda anges"
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr "m210 har inte stöd för omvänd byteordning"
-
 #: config/cris/cris.h:184
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "ange inte både -march=... och -mcpu=..."
@@ -5290,6 +5280,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr "Du behöver en C-uppstartsfil för -msys-crt0="
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr "överväg att använda ”-pg” istället för ”-p” med gprof(1)"
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5296,6 +5292,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr "går inte att använda både -m32 och -m64"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr "överväg att använda ”-pg” istället för ”-p” med gprof(1)"
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr "static stödjs inte på TPF-OS"
@@ -5308,6 +5308,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian och -mlittle-endian får inte användas tillsammans"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr "m210 har inte stöd för omvänd byteordning"
+
 #: config/avr/specs.h:68
 msgid "shared is not supported"
 msgstr "shared stödjs inte"
@@ -5333,17 +5337,19 @@
 msgid "no processor type specified for linking"
 msgstr "ingen processortyp angiven för länkning"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr "varning: överväg att länka med ”-static” eftersom systembibliotek med"
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr "  profileringsstöd endast finns i arkivformat"
 
@@ -5379,10 +5385,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "flaggan -shared stödjs för närvarande inte för VAX ELF"
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-msgid "profiling not supported with -mg"
-msgstr "profilering stödjs inte med -mg"
-
 #: fortran/lang.opt:146
 msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgstr "-J<katalog>\tLägg MODULE-filer i ”katalog”"
@@ -5561,9 +5563,9 @@
 msgstr "Tillåt dollartecken i entitetsnamn"
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Gör ingenting.  Bevarad för bakåtkompatibilitet."
 
@@ -5767,10 +5769,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Gör ingenting.  Bevarad för bakåtkompatibilitet."
 
@@ -5816,7 +5818,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr "filnamn saknas efter %qs"
@@ -6151,7 +6153,7 @@
 
 #: c-family/c.opt:527
 msgid "Warn when a jump misses a variable initialization"
-msgstr "Varna när ett hopp missare en variabelinitiering"
+msgstr "Varna när ett hopp missar en variabelinitiering"
 
 #: c-family/c.opt:531
 msgid "Warn when a string or character literal is followed by a ud-suffix which does not begin with an underscore."
@@ -7665,44 +7667,48 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr "Sätt att gå runt ARM Cortex-A53:s errata nummer 835796"
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr "Sätt att gå runt ARM Cortex-A53:s errata nummer 843419"
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr "Antag att mål-CPU:n är konfigurerad med omvänd byteordning"
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 msgid "Specify the code model"
 msgstr "Ange kodmodellen"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr "Anta inte att ojusterade åtkomster hanteras av systemet"
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr "Utelämna rampekaren i lövfunktioner"
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr "Ange TLS-dialekt"
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr "-march=ARK\tAnvänd funktioner i arkitekturen ARK"
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr "-mcpu=CPU\tAnvänd funktioner i och optimera för angiven CPU"
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr "-mtune=CPU\tOptimera för CPU"
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr "-mabi=ABI\tGenerera kod som följer det angivna ABI:et"
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr "Kända AArch64-ABI:er (att användas med flaggan -mabi=):"
 
@@ -8024,7 +8030,7 @@
 
 #: config/epiphany/epiphany.opt:128
 msgid "Split unaligned 8 byte vector moves before post-modify address generation."
-msgstr "Dela ojusterade 8-bytes vektorerförflyttningar före adressgenerering efter ändring."
+msgstr "Dela ojusterade 8-bytes vektorförflyttningar före adressgenerering efter ändring."
 
 #: config/epiphany/epiphany.opt:132
 msgid "Use the floating point unit for integer add/subtract."
@@ -8771,10 +8777,14 @@
 msgstr "Stöd MPX-kodgenerering "
 
 #: config/i386/i386.opt:864
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "Stöd inbyggda MWAITX- och MONITORX-funktioner och -kodgenerering"
+
+#: config/i386/i386.opt:868
 msgid "Use given stack-protector guard"
 msgstr "Använd angiven stackskyddsvakt"
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr "Kända stackskyddsvakter (att användas med flaggan -mstack-protector-guard=):"
 
@@ -9102,7 +9112,7 @@
 
 #: config/avr/avr.opt:79
 msgid "Accumulate outgoing function arguments and acquire/release the needed stack space for outpoing function arguments in function prologue/epilogue.  Without this option, outgoing arguments are pushed before calling a function and popped afterwards.  This option can lead to reduced code size for functions that call many functions that get their arguments on the stack like, for example printf."
-msgstr "Samla utgående funktionsargument och ta/släpp det nödvändiga stackutrymmet för utgående funktionsargument i funktionsprologen/-epilogen.  Utan denna flagga trycks utgående argment på stacken före anrop av en funktion och plockas efteråt.  Denna flagga kan medföra reducerad kodstorlek för funktioner som anropar många funktioner som får sina argument på stacken som, till exempel printf."
+msgstr "Samla utgående funktionsargument och ta/släpp det nödvändiga stackutrymmet för utgående funktionsargument i funktionsprologen/-epilogen.  Utan denna flagga trycks utgående argument på stacken före anrop av en funktion och plockas efteråt.  Denna flagga kan medföra reducerad kodstorlek för funktioner som anropar många funktioner som får sina argument på stacken som, till exempel printf."
 
 #: config/avr/avr.opt:83
 msgid "When accessing RAM, use X as imposed by the hardware, i.e. just use pre-decrement, post-increment and indirect addressing with the X register.  Without this option, the compiler may assume that there is an addressing mode X+const similar to Y+const and Z+const and emit instructions to emulate such an addressing mode for X."
@@ -9121,8 +9131,8 @@
 msgstr "Tillåt avhuggning istället för avrundning mot 0 för decimalheltalstyper"
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
-msgstr "Länka inte mot det enhetsspecifika biblioteket libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
+msgstr "Länka inte mot det enhetsspecifika biblioteket lib<MCU>.a"
 
 #: config/m32r/m32r.opt:34
 msgid "Compile for the m32rx"
@@ -9268,7 +9278,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr "Ange grenkostnaden för villkorliga greninstruktioner.  Rimliga"
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 msgid "Use LRA instead of reload"
 msgstr "Använd LRA istället för omladdning"
@@ -9393,7 +9403,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr "Tillåt schemaläggning av en funktions prologsekvens"
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr "Ladda inte PIC-registret i funktionsprologer"
 
@@ -9711,299 +9721,299 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "Använd vektor-/skalärinstruktioner (VSX)"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr "Generera inte load/store-instruktioner med uppdatering"
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr "Generera load/store-instruktioner med uppdatering"
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr "Undvik att generera indexerade load/store-instruktioner så långt möjligt"
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "Märk __tls_get_addr-anrop med argumentinformation"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr "Schemalägg början och slutet av proceduren"
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr "Returnera alla strukturer i minnet (standard för AIX)"
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr "Returnera små strukturer i register (standard för SVR4)"
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr "Följ mer noga IBM XLC:s semantik"
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr "Generera inversdivision och kvadratrot i programvara för bättre genomströmning."
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr "Antag att de ömsesidiga uppskattningsinstruktionerna ger mer precision."
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr "Placera inte flyttalskonstanter i TOC"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr "Placera flyttalskonstanter i TOC"
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "Placera inte symbol+avstånd-konstanter i TOC"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr "Placera symbol+avstånd-konstanter i TOC"
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr "Använd endast en TOC-post per procedur"
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr "Placera allting i den vanliga TOC"
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr "Generera VRSAVE-instruktioner när AltiVec-kod genereras"
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr "Undanbedd flagga.  Använd -mno-vrsave istället"
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr "Undanbedd flagga.  Använd -mvrsave istället"
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr "Ange hur många byte som bör flyttas inline före anrop av memcpy/memmove"
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 msgid "Generate isel instructions"
 msgstr "Generera isel-instruktioner"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr "Undanbedd flagga.  Använd -mno-isel istället"
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 msgid "Deprecated option.  Use -misel instead"
 msgstr "Undanbedd flagga.  Använd -misel istället"
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr "Generera SPE SIMD-instruktioner för E500"
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "Generera PPC750CL:s par-singel-instruktioner"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr "Undanbedd flagga.  Använd -mno-spe istället"
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 msgid "Deprecated option.  Use -mspe instead"
 msgstr "Undanbedd flagga.  Använd -mspe istället"
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 msgid "-mdebug=\tEnable debug output"
 msgstr "-mdebug=\tAktivera felsökningsutdata"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 msgid "Use the AltiVec ABI extensions"
 msgstr "Använd ABI-utökningarna AltiVec"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "Använd inte ABI-utökningarna AltiVec"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 msgid "Use the SPE ABI extensions"
 msgstr "Använd ABI-utökningarna SPE"
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 msgid "Do not use the SPE ABI extensions"
 msgstr "Använd inte ABI-utökningarna SPE"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 msgid "Use the ELFv1 ABI"
 msgstr "Använd ELFv1 ABI"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 msgid "Use the ELFv2 ABI"
 msgstr "Använd ELFv2 ABI"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 msgid "using darwin64 ABI"
 msgstr "använder ABI darwin64"
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 msgid "using old darwin ABI"
 msgstr "använder gammalt darwin-ABI"
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr "använder long double med IEEE:s utökade precision"
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr "använder long double med IBM:s utökade precision"
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr "-mcpu=\tAnvänd funktioner i och schemalägg kod för angiven CPU"
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "-mtune=\tSchemalägg kod för en given CPU"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr "-mtraceback=\tVälj fullständig, partiell, eller ingen bakåtspårningstabell"
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr "Undvik alla avståndsgränser vid anropsinstruktioner"
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 msgid "Generate Cell microcode"
 msgstr "Generera Cell-mikrokod"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "Varna när en Cell-mikrokodsinstruktion avges"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr "Varna för användning av AltiVec-typen ”vector long ...” som bör undvikas"
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr "-mfloat-gprs=\tVälj GPR-flyttalsmetod"
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Giltiga argument till -mfloat-gprs=:"
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr "-mlong-double-<n>\tAnge storlek på long double (64 eller 128 bitar)"
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr "Ange vilka beroenden mellan instruktioner som skall anses dyra"
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr "Ange metod att tillämpa för inskjutande av nop efter schemaläggning"
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr "Ange justering av postfält till default/natural"
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 msgid "Valid arguments to -malign-:"
 msgstr "Giltiga argument till -malign-:"
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr "Ange schemaläggningsprioritet för begränsade instruktioner för avsändningsfack"
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 msgid "Single-precision floating point unit"
 msgstr "Enkelprecisions flyttalsenhet"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 msgid "Double-precision floating point unit"
 msgstr "Dubbelprecisions flyttalsenhet"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 msgid "Floating point unit does not support divide & sqrt"
 msgstr "Flyttalsenheten stödjer inte division & kvadratrot"
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr "-mfpu=\tAnge FP (sp, dp, sp-lite, dp-lite) (implicerar -mxilinx-fpu)"
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 msgid "Specify Xilinx FPU."
 msgstr "Ange Xilinx-FPU."
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr "Använd/använd inte r11 för att hålla den statiska länken i anrop till funktioner via pekare."
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr "Bestäm huruvida vi sparar TOC:en i prologen för indirekta anrop eller genererar sparandet inline"
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr "Tillåt 128-bitars heltal i VSX-register"
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr "Smält samman vissa heltalsoperationer för bättre prestanda på power8"
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 msgid "Allow sign extension in fusion operations"
 msgstr "Tillåt teckenutökning i sammanslagningsoperationer"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr "Använd/använd inte vektor och skalära instruktioner som lades till i ISA 2.07."
 
-#: config/rs6000/rs6000.opt:562
-msgid "Use ISA 2.07 crypto instructions"
-msgstr "Använd ISA 2.07 kryptoinstruktioner"
+#: config/rs6000/rs6000.opt:566
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr "Använd ISA 2.07 instruktioner Category:Vector.AES och Category:Vector.SHA2"
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr "Använd ISA 2.07:s direkta förflyttning mellan GPR- och VSX-registerinstruktioner"
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr "Använd ISA 2.07 transaktionsminnesinstruktioner (HTM)"
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Generera fyrords minnesinstruktioner (lq/stq)."
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr "Generera atomära minnesinstruktioner för quad-ord (lqarx/stqcx)."
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr "Generera kod för att skicka aggregerade parametrar med som mes 64-bitars justering."
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr "Tillåt double-variabler i övre register med -mcpu=power7 eller -mvsx"
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr "Tillåt flyttalsvariabler i övre register med -mcpu=power8 eller mpower8-vector"
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr "Tillåt float/double-variabler i övre register om cpu:n tillåter det"
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr "Analysera och ta bort dubbelordsbyten från VSX-beräkningar."
 
@@ -10353,7 +10363,7 @@
 
 #: config/nios2/nios2.opt:178
 msgid "Do not use the floatis custom instruction"
-msgstr "Använd inte den anpassade instruktionen  floatis"
+msgstr "Använd inte den anpassade instruktionen floatis"
 
 #: config/nios2/nios2.opt:182
 msgid "Integer id (N) of floatis custom instruction"
@@ -10369,7 +10379,7 @@
 
 #: config/nios2/nios2.opt:194
 msgid "Do not use the fcmpeqd custom instruction"
-msgstr "Använd inte den anpassade instruktionen  fcmpeqd"
+msgstr "Använd inte den anpassade instruktionen fcmpeqd"
 
 #: config/nios2/nios2.opt:198
 msgid "Integer id (N) of fcmpeqd custom instruction"
@@ -10777,7 +10787,7 @@
 
 #: config/rx/rx.opt:93
 msgid "Generate assembler output that is compatible with the Renesas AS100 assembler.  This may restrict some of the compiler's capabilities.  The default is to generate GAS compatible syntax."
-msgstr "Genereara assemblerutdatat som är kompatibel med Renesas AS100-assembler.  Detta kan begränsa några av kompilatorns egenskaper.  Standard är att generera GAS-kopatibel sysntax."
+msgstr "Genereara assemblerutdatat som är kompatibel med Renesas AS100-assembler.  Detta kan begränsa några av kompilatorns egenskaper.  Standard är att generera GAS-kompatibel syntax."
 
 #: config/rx/rx.opt:99
 msgid "Enable linker relaxation."
@@ -12783,1542 +12793,1542 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr "-dumpdir <kat>\tAnge katalognamn att användas för dumpar"
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr "Versionen av C++-ABI:et som används"
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr "Optimera aggressivt slingor med användning av språkbegränsningar"
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "Justera starten av funktioner"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr "Justera etiketter som bara nås via hopp"
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr "Justera alla etiketter"
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "Justera starten av slingor"
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr "Välj vad som skall saneras"
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr "-fasan-shadow-offset=<tal>\tAnvänd anpassat avstånd till skuggminne."
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr "Efter att diagnosticera odefinierat beteende, försök fortsätta körningen"
 
-#: common.opt:906
+#: common.opt:909
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr "Denna flagga bör undvikas, använd -fsanitize-recover= istället"
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr "Använd trap istället för en biblioteksfunktion för sanering av odefinierat beteende"
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr "Generera tabeller för upprullning som är exakta vid varje instruktionsgräns"
 
-#: common.opt:918
+#: common.opt:921
 msgid "Generate auto-inc/dec instructions"
 msgstr "Generera auto-inc/dec-instruktioner"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr "Använd samplingprofilinformation till anropsgrafers nodvikter.  Standard profilfil är fbdata.afdo i ”pwd”."
 
-#: common.opt:927
+#: common.opt:930
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr "Använd samplingsprofilinformation till anropsgrafers nodvikter.  Profilen"
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "Generera kod för att kontrollera gränser före indexering i vektorer"
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr "Ersätt addition, jämförelse, grena med gren vid räknarregister"
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr "Använd profileringsinformation för grensannolikheter"
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr "Utför optimering av grenmålsinläsning före prolog-/epilogtrådning"
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr "Utför optimering av grenmålsinläsning efter prolog-/epilogtrådning"
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr "Begränsa migration av målinläsning till att inte återanvända register i något grundblock"
 
-#: common.opt:960
+#: common.opt:963
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr "-fcall-saved-<register>\tMarkera att <register> bevaras mellan funktioner"
 
-#: common.opt:964
+#: common.opt:967
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr "-fcall-used-<register>\tMarkera att <register> förstörs av funktionsanrop"
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr "Spara register runt funktionsanrop"
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr "Jämför resultaten av flera analyserare av databeroende."
 
-#: common.opt:979
+#: common.opt:982
 msgid "Check the return value of new in C++"
 msgstr "Kontrollera returvärdet av new i C++"
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "Söker efter möjligheter att minska stackjusteringar och stackreferenser."
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr "Lägg inte oinitierade globala i den gemensamma sektionen"
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr "-fcompare-debug[=<flgr>]\tKompilera med och utan t.ex. -gtoggle, och jämför slutinstruktionsdumpen"
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr "Kör endast den andra kompileringen av -fcompare-debug"
 
-#: common.opt:1003
+#: common.opt:1006
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr "Utför eliminering av jämförelser efter registertilldelningen har avslutats"
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr "Utför inte optimeringar som märkbart ökar stackanvändningen"
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr "Utför ett optimeringspass för kopieringspropagering av register"
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr "Utför optimering för korshopp"
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr "När CSE körs, följ hopp till deras mål"
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr "Uteslut intervallreduktionssteget när komplex division görs"
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr "Komplex multiplikation och division följer Fortranregler"
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr "Placera dataobjekt i sin egen sektion"
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Lista alla tillgängliga felsökningsräknare med deras gränser och värden."
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr "-fdbg-cnt=<räknare>:<gräns>[,<räknare>:<gräns>,...]\tSätt gränsen för felsökningsräknare.   "
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr "Översätt ett katalognamn till ett annat i felsökningsinformation"
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "Mata ut en .debug_types-sektion när DWARF v4 felsökningsinformation används."
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr "Senarelägg borttagandet av funktionsargument från stacken"
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr "Försök fylla fördröjningsfack av greninstruktioner"
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr "Ta bort döda instruktioner som kan kasta undantag"
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr "Ta bort onödiga nollpekarkontroller"
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr "Strömma extra data för att stödja mer aggressiv avvirtualisering i lokaltransformationsläge i LTO"
 
-#: common.opt:1077
+#: common.opt:1080
 msgid "Perform speculative devirtualization"
 msgstr "Utför spekulativ avvirtualisering"
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr "Försök att konvertera virtuella anrop till direkta."
 
-#: common.opt:1085
+#: common.opt:1088
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr "-fdiagnostics-show-location=[once|every-line]\tAnger hur ofta källkodspositioner skall skrivas ut i början av utskrift vid radbrytning"
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr "Visa källkodsrader med en cirkumflex som indikerar kolumnen"
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr "-fdiagnostics-color=[never|always|auto]\tFärglägg felmeddelanden"
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr "Lägg till lämpliga diagnostiska meddelanden till kommandoradsflaggan som styr dem"
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr "-fdisable-[tree|rtl|ipa]-<pass>=intrvl1+intrvl2 avaktiverar ett optimeringspass"
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr "-fenable-[tree|rtl|ipa]-<pass>=intrvl1+intrvl2 aktiverar ett optimeringspass"
 
-#: common.opt:1142
+#: common.opt:1145
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr "-fdump-<typ>\tSkriv ut diverse intern kompilatorinformation till en fil"
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr "-fdump-final-insns=filnamn\tSkriv instruktionerna vid slutet av översättningen till filnamn"
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr "-fdump-go-spec=filnamn\tSkriv alla deklarationer till fil som Go-kod"
 
-#: common.opt:1157
+#: common.opt:1160
 msgid "Suppress output of addresses in debugging dumps"
 msgstr "Undertryck utskrift av adresser i felsökningsutskrifter"
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr "Samla och skriv ut felsökningsinformation till en temporärfil om ICE sker i C/C++-kompilatorn."
 
-#: common.opt:1166
+#: common.opt:1169
 msgid "Dump optimization passes"
 msgstr "Dumpa optimeringspass"
 
-#: common.opt:1170
+#: common.opt:1173
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr "Undertryck utskrift av instruktionsantal, radnummernoteringar och -adresser i felsökningsutskrifter"
 
-#: common.opt:1174
+#: common.opt:1177
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr "Undertryck utskrift föregående och nästa instruktionsnummer i felsökningsutskrifter"
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Aktivera CFI-tabeller via GAS-assemblerdirektiv."
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr "Utför tidig inline:ing"
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr "Utför dubbletteliminering i DWARF2"
 
-#: common.opt:1190
+#: common.opt:1193
 msgid "Perform interprocedural reduction of aggregates"
 msgstr "Utför interprocedurell reduktion av aggregat"
 
-#: common.opt:1194
+#: common.opt:1197
 msgid "Perform unused symbol elimination in debug info"
 msgstr "Utför eliminering av oanvända symboler i felsökningsinformation"
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr "Utför eliminering av oanvända typer i felsökningsinformation"
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr "Undertryck inte felsökningsinformation för C++-klasser."
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "Aktivera undantagshantering"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr "Utför ett antal smärre, dyra optimeringar"
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr "-fexecc-precision=[fast|standard]\tAnge hantering av överskjutande precision på flyttal"
 
-#: common.opt:1217
+#: common.opt:1220
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr "okänd stil för överskjutande precision %qs"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "Mata ut lto-objekt som innehåller både mellanspråket och binärutdata."
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr "Anta att inga NaN:er eller oändligheter genereras"
 
-#: common.opt:1238
+#: common.opt:1241
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr "-ffixed-<register>\tMarkera <register> som ej tillgängligt för kompilatorn"
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr "Allokera inte float och double i register med utökad precision"
 
-#: common.opt:1250
+#: common.opt:1253
 msgid "Perform a forward propagation pass on RTL"
 msgstr "Utför ett framåtpropageringspass på RTL"
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr "-ffp-contract=[off|on|fast] Utför kontraktion av flyttalsuttryck."
 
-#: common.opt:1257
+#: common.opt:1260
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "okänd stil för flyttalssammandragning %qs"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr "Tillåt att funktionsadresser läggs i register"
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr "Placera varje funktion i sin egen sektion"
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr "Utför global eliminering av gemensamma deluttryck"
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr "Utför förbättrad förflyttning av inläsning under global eliminering av gemensamma deluttryck"
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr "Utför förflyttning av lagring efter global eliminering av gemensamma deluttryck"
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr "Utför eliminering av överflödig inläsning efter lagring i globala gemensamma deluttryck"
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr "Utför global eliminering av gemensamma deluttryck efter registertilldelning"
 
-#: common.opt:1305
+#: common.opt:1308
 msgid "Enable in and out of Graphite representation"
 msgstr "Aktivera in och ut från Graphite-representation"
 
-#: common.opt:1309
+#: common.opt:1312
 msgid "Enable Graphite Identity transformation"
 msgstr "Aktivera Graphite-identitetstransformation"
 
-#: common.opt:1313
+#: common.opt:1316
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr "Aktivera närliggande lyftningslast för att uppmuntra generering av villkorliga förflyttningar."
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr "Markera alla slingor som parallella"
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr "Aktivera transformationen utgrävning av remsor (strip mining) i slingor"
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr "Aktivera transformationen utbyte (interchange) i slingor"
 
-#: common.opt:1330
+#: common.opt:1333
 msgid "Enable Loop Blocking transformation"
 msgstr "Aktivera slingblockeringstransformation"
 
-#: common.opt:1334
+#: common.opt:1337
 msgid "Enable Loop Unroll Jam transformation"
 msgstr "Aktivera transformationen av utrullningsstockningar i slingor"
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr "Aktivera stöd för GNU:s transationsminne"
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr "Använd STB_GNU_UNIQUE om det stödjs av assemblern"
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr "Aktevera den ISL-baserade optimeraren av slingnästning"
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr "Tvinga bitfältsåtkomster att matcha sin typbredd"
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr "Aktivera att grensannolikheter gissas"
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr "Hantera #ident-direktiv"
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr "Utför konvertering av villkorliga hopp till grenlösa motsvarigheter"
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr "Utför konvertering av villkorliga hopp till villkorlig exekvering"
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr "-fstack-reuse=[all|named_vars|none] Ställ in stackåteranvändningsnivån för lokala variabler."
 
-#: common.opt:1381
+#: common.opt:1384
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "okänd stackåteranvändningsmodell %qs"
 
-#: common.opt:1394
+#: common.opt:1397
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr "Konvertera villkorliga hopp i innersta slingor till grenlösa motsvarigheter"
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr "Även if-convert villkorliga hopp som innehåller minnesskrivningar"
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr "Generera inte .size-direktiv"
 
-#: common.opt:1410
+#: common.opt:1413
 msgid "Perform indirect inlining"
 msgstr "Utför indirekt inline:ing"
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr "Aktivera inline:ing av funktioner deklarerade ”inline”, avslaget avaktiveras all inline:ing"
 
-#: common.opt:1420
+#: common.opt:1423
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "Integrera funktioner i deras anropare när det är klart att kodstorleken inte växer"
 
-#: common.opt:1424
+#: common.opt:1427
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "Integrera funktioner deklarerade ”inline” i deras anropare när det lönar sig"
 
-#: common.opt:1428
+#: common.opt:1431
 msgid "Integrate functions only required by their single caller"
 msgstr "Integrera funktioner som endast behövs av deras enda anropare"
 
-#: common.opt:1435
+#: common.opt:1438
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr "-finline-limit=<tal>\tBegränsa storlek på inline-funktioner till <tal>"
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "Inline:a __atomic-operationer när en låsningsfri instruktionssekvens är tillgänglig."
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr "Instrumentera funktionsingång och -utgång med profileringsanrop"
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr "-finstrument-functions-exclude-function-list=namn,...  Instrumentera inte uppräknade funktioner"
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr "-finstrument-functions-exclude-file-list=filenamn,...  Instrumentera inte funktioner uppräknade i filerna"
 
-#: common.opt:1455
+#: common.opt:1458
 msgid "Perform interprocedural constant propagation"
 msgstr "Utför konstantpropagering mellan procedurer"
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr "Utför kloning för att göra konstantpropagering mellan procedurer starkare"
 
-#: common.opt:1463
+#: common.opt:1466
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr "Utför upptäckt och propagering av justering för att göra konstantpropagering mellan procedurer starkare"
 
-#: common.opt:1467
+#: common.opt:1470
 msgid "Perform interprocedural profile propagation"
 msgstr "Utför profileringspropagering mellan procedurer"
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr "Utför pekar-på-analyser mellan procedurer"
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr "Upptäck pure- och const-funktioner"
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr "Fäll ihop identisk kod för funktioner och endast läsbara variabler"
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr "Fäll ihop identisk kod för funktioner"
 
-#: common.opt:1487
+#: common.opt:1490
 msgid "Perform Identical Code Folding for variables"
 msgstr "Utför ihopfällning av identiskt kod för variabler"
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr "Upptäck endast läsbara och icke adresserbara statiska variabler"
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr "-fira-algorithm=[CB|priority] Bestäm den använda IRA-algoritmen"
 
-#: common.opt:1506
+#: common.opt:1509
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "okänd IRA-algoritm %qs"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr "-fira-region=[one|all|mixed] Sätt regioner för IRA"
 
-#: common.opt:1519
+#: common.opt:1522
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr "okänd IRA-region %qs"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr "Använd IRA-baserad registertryckberäkning"
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr "Dela fack för att spara olika hårda register."
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Dela stackfack för spillda pseudoregister."
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<tal>\tStyr IRA:ns nivå på diagnostikmeddelanden."
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr "Optimera induktionsvariabler på träd"
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "Använd hopptabeller för tillräckligt stora switch-satser"
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr "Generera kod för funktioner även om de är fullständigt inline:ade"
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr "Mata ut static const-variabler även om de inte används"
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr "Ge externa symboler ett inledande understrykningstecken"
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr "Gör CFG-känsliga återmaterialiseringar i LRA"
 
-#: common.opt:1582
+#: common.opt:1585
 msgid "Enable link-time optimization."
 msgstr "Aktivera länkningsoptimeringar."
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Optimeringar vid länktillfället med flera parallella jobb eller jobbserver."
 
-#: common.opt:1589
+#: common.opt:1592
 #, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "okänd LTO-partitioneringsmodell %qs"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr "Ange algoritmen för att dela upp symboler och variabler vid länktillfället"
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr "-flto-compression-level=<tal>\tAnvänd zlib-komprimering på nivå <tal> för IL"
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr "Slå samman C++-typer med endefinitionsregeln"
 
-#: common.opt:1621
+#: common.opt:1624
 msgid "Report various link-time optimization statistics"
 msgstr "Rapportera diverse optimeringsstatistik från länkningen"
 
-#: common.opt:1625
+#: common.opt:1628
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr "Rapportera diverse optimeringsstatistik från länkningen endast för WPA."
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr "Sätt errno efter inbyggda matematikfunktioner"
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr "-fmax-errors=<antal>\tMaximalt antal fel som skall rapporteras"
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr "Rapportera om permanent minnesallokering"
 
-#: common.opt:1641
+#: common.opt:1644
 msgid "Report on permanent memory allocation in WPA only"
 msgstr "Rapportera bara om permanent minnesallokering i WPA"
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr "Försök slå samman identiska konstanter och konstanta variabler"
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr "Försök slå samman identiska konstanter mellan kompileringsenheter"
 
-#: common.opt:1656
+#: common.opt:1659
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr "Försök slå samman identiska felsökningssträngar mellan kompileringsenheter"
 
-#: common.opt:1660
+#: common.opt:1663
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr "-fmessage-length=<antal>\tBegränsa felmeddelandens längd till <antal> tecken per rad.  0 stänger av radbrytning"
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr "Utför SMS-baserad modulo-schemaläggning före det första schemaläggningspasset"
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr "Utför SMS-baserad modulo-schemaläggning med tillåten registerförflyttning"
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr "Flytta slinginvarianta beräkningar ut från slingor"
 
-#: common.opt:1676
+#: common.opt:1679
 msgid "Use the RTL dead code elimination pass"
 msgstr "Använd passet på RTL för eliminering av död kod"
 
-#: common.opt:1680
+#: common.opt:1683
 msgid "Use the RTL dead store elimination pass"
 msgstr "Använd passet på RTL för eliminering av död lagring"
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr "Aktivera/deaktivera den traditionella schemaläggningen i slingor som redan passerat modulo-schemaläggning"
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr "Stöd synkrona icke-anropsundantag"
 
-#: common.opt:1691
+#: common.opt:1694
 #, c-format
 msgid "options or targets missing after %qs"
 msgstr "flaggor eller mål saknas efter %qs"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr "-foffload=<mål>=<flaggor>  Ange mål att lasta av till och flaggor för dem"
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr "-foffload-abi=[lp64|ilp32]     Ange ABI:et att använda i en avlastningskompilator"
 
-#: common.opt:1699
+#: common.opt:1702
 #, c-format
 msgid "unknown offload ABI %qs"
 msgstr "okänd avlastnings-ABI %qs"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr "Låt bli att generera stackramar när det är möjligt"
 
-#: common.opt:1713
+#: common.opt:1716
 msgid "Enable all optimization info dumps on stderr"
 msgstr "Aktivera alla optimeringsinformationsdumpar på standard fel"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr "-fopt-info[-<type>=filenamn]\tSkriv ut kompilatoroptimeringsdetaljer"
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr "Optimera syskon- och svansrekursiva anrop"
 
-#: common.opt:1729
+#: common.opt:1732
 msgid "Perform partial inlining"
 msgstr "Utför partiell inline:ing"
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr "Rapportera minnesallokering för interprocedurella optimeringar"
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr "Packa ihop postmedlemmar utan hål"
 
-#: common.opt:1745
+#: common.opt:1748
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr "-fpack-struct=<tal>\tAnge initial maximal justering för postmedlemmar"
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr "Returnera små aggregat i minne, inte register"
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr "Utför slingavskalning"
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr "Aktivera maskinspecifika nyckelhålsoptimeringar"
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr "Aktivera ett RTL-nyckelhålspass före sched2"
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr "Generera positionsoberoende kod om möjligt (stort läge)"
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr "Generera positionsoberoende kod för körbara program om möjligt (stort läge)"
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr "Generera positionsoberoende kod om möjligt (litet läge)"
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr "Generera positionsoberoende kod för körbara program om möjligt (litet läge)"
 
-#: common.opt:1781
+#: common.opt:1784
 msgid "Specify a plugin to load"
 msgstr "Ange en instickmodul att läsa in"
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr "-fplugin-arg-<namn>-<nyckel>[=<värde>]\tAnge argument <nyckel>=<värde> för insticksmodul <namn>"
 
-#: common.opt:1789
+#: common.opt:1792
 msgid "Run predictive commoning optimization."
 msgstr "Kör optimeringar för predikativ gemensamning."
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr "Generera förhandshämtningsinstruktioner (prefetch), om tillgängliga, för vektorer i slingor"
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr "Aktivera grundläggande programprofileringskod"
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr "Lägg in bågbaserad programprofileringskod"
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr "Sätt toppnivåkatalogen för att spara profildata."
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr "Aktivera korrigering av profilindata med inkonsistent flöde"
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr "Aktivera vanliga flaggor för att generera profileringsinformation för optimeringar styrda av återmatad profil"
 
-#: common.opt:1818
+#: common.opt:1821
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Aktivera vanliga flaggor för att generera profileringsinformation för optimeringar styrda av återmatad profil, och sätt -fprofile-dir="
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr "Aktivera vanliga flaggor för att utföra optimeringar styrda av återmatad profil"
 
-#: common.opt:1826
+#: common.opt:1829
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Aktivera vanliga flaggor för att utföra optimeringar styrda av återmatad profil, och sätt -fprofile-dir="
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr "Lägg in kod för att profilera värden av uttryck"
 
-#: common.opt:1834
+#: common.opt:1837
 msgid "Report on consistency of profile"
 msgstr "Rapportera om intern konsistens hos profilen"
 
-#: common.opt:1838
+#: common.opt:1841
 msgid "Enable function reordering that improves code placement"
 msgstr "Aktivera omflyttning av funktioner för att förbättra kodplacering"
 
-#: common.opt:1845
+#: common.opt:1848
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr "-frandom-seed=<tal>\tGör kompileringen reproducerbar med <tal>"
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr "Notera gcc:s kommandoradsflaggor i objektfilen."
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr "Returnera små poster i register"
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr "Berätta för DSE att lagringen för ett C++-objekt är dött när konstrueraren"
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr "Lättnad av registertryck genom minskning av aktivt intervall"
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr "Utför ett optimeringspass med registernamnbyten"
 
-#: common.opt:1880
+#: common.opt:1883
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr "Utför ett optimeringspass med målberoende instruktionssammanslagning"
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr "Flytta om grundblock för att förbättra kodplacering"
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr "Flytta om grundblock och partitioner till varma och kalla sektioner"
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr "Flytta om funktioner för att förbättra kodplacering"
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr "Lägg till ett pass för eliminering av gemensamma deluttryck efter slingoptimeringar"
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr "Avaktivera optimeringar som antar standardmässig avrundningsbeteende för FP"
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr "Aktivera schemaläggning mellan grundblock"
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr "Aktivera registertryckskänslig instruktionsschemaläggning"
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr "Tillåt spekulativ förflyttning av icke-inläsningar"
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr "Tillåt spekulativ förflyttning av några inläsningar"
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr "Tillåt spekulativ förflyttning av fler inläsningar"
 
-#: common.opt:1928
+#: common.opt:1931
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr "-fsched-verbose=<tal>\tAnge hur mångordig schemaläggaren skall vara"
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr "Om schemaläggning efter omläsning, gör superblockschemaläggning"
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr "Schemalägg om instruktioner före registertilldelning"
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr "Schemalägg om instruktioner efter registertilldelning"
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr "Använd selektive schemaläggningsalgoritm för schemaläggning av instruktioner"
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr "Kör selektiv schemaläggning efter omläsning"
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr "Utför programvarurörläggning av inre slingor under selektiv schemaläggning"
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr "Utför programvarurörläggning av yttre slingor under selektiv schemaläggning"
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr "Schemalägg om rörlagda regioner utan rörläggning"
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr "Tillåt funktioner (eller variabler) som står emellan för sådana med annan semantik (respektive initierare) i den dynamiska länkaren"
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr "Tillåt förtida schemaläggning av köade instruktioner"
 
-#: common.opt:1981
+#: common.opt:1984
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr "-fsched-stalled-insns=<antal>\tAnge antalet köade instruktioner som kan schemaläggas i förtid"
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr "Sätt beroendeavståndet som kontrolleras i förtida schemaläggning av köade instruktioner"
 
-#: common.opt:1993
+#: common.opt:1996
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr "-fsched-stalled-insns-dep=<antal>\tSätt beroendeavståndet som kontrolleras i förtida schemaläggning av köade instruktioner"
 
-#: common.opt:1997
+#: common.opt:2000
 msgid "Enable the group heuristic in the scheduler"
 msgstr "Aktivera gruppheuristiken i schemaläggaren"
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr "Aktivera heuristiken för kritisk väg i schemaläggaren"
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr "Aktivera den spekulativa instruktionsheuristiken i schemaläggaren"
 
-#: common.opt:2009
+#: common.opt:2012
 msgid "Enable the rank heuristic in the scheduler"
 msgstr "Aktivera ordningsheuristiken i schemaläggaren"
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr "Aktivera heuristiken för sista instruktion i schemaläggaren"
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr "Aktivera heuristiken för beroende antal i schemaläggaren"
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr "Nå data i samma sektion från delade förankringspunkter"
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "Slå på passet för eliminering av redundanta utökningar."
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr "Visa kolumnnummer i felmeddelanden, när de är tillgängliga.  Normalt på"
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr "Mata ut funktionsprologer bara före delar av funktionen som behöver det,"
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr "Avaktivera optimeringar som kan observeras av IEEE signalerande NAN:ar"
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr "Avaktivera flyttalsoptimeringar som ignorera IEEE:s tecken på noll"
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr "Konvertera flyttalskonstanter till konstanter med enkel precision"
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr "Dela livstiden på induktionsvariabler när slingor rullas ut"
 
-#: common.opt:2062
+#: common.opt:2065
 msgid "Generate discontiguous stack frames"
 msgstr "Generera osammanhängande stackramar"
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr "Dela upp breda typer i oberoende register"
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr "Optimera villkorliga mönster med SSA PHI-noder"
 
-#: common.opt:2074
+#: common.opt:2077
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr "Optimera mängden stdarg-register som sparas på stacken vid starten av en funktion"
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr "Tillämpa variabelexpansion när slingor rullas ut"
 
-#: common.opt:2082
+#: common.opt:2085
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "-fstack-check=[no|generic|specific]\tLägg in stackkontrollkod i programmet"
 
-#: common.opt:2086
+#: common.opt:2089
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "Lägg in stackkontrollkod i programmet.  Samma som -fstack-check=specific"
 
-#: common.opt:2093
+#: common.opt:2096
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr "-fstack-limit-register=<register>\tFånga om stacken går förbi <register>"
 
-#: common.opt:2097
+#: common.opt:2100
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr "-fstack-limit-symbol=<namn>\tFånga om stacken går förbi symbolen <namn>"
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr "Använd propolice som en metod att skydda stacken"
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr "Använd en metod att skydda stacken för varje funktion"
 
-#: common.opt:2109
+#: common.opt:2112
 msgid "Use a smart stack protection method for certain functions"
 msgstr "Använd en smart metod att skydda stacken för vissa funktioner"
 
-#: common.opt:2113
+#: common.opt:2116
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr "Använd en metod att skydda stacken endast för funktioner med attributet stack_protect"
 
-#: common.opt:2117
+#: common.opt:2120
 msgid "Output stack usage information on a per-function basis"
 msgstr "Skriv ut information om stackanvändning för varje funktion"
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr "Anta att strikta aliasregler gäller"
 
-#: common.opt:2133
+#: common.opt:2136
 msgid "Treat signed overflow as undefined"
 msgstr "Behandla spill med tecken som odefinierat"
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr "Implementera __atomic-operationer med biblioteksanrop till äldre __sync-funktioner"
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr "Leta efter syntaxfel, stoppa sedan"
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr "Skapa datafiler som behövs av ”gcov”"
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr "Utför hopptrådningsoptimeringar"
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr "Rapportera tiden som går åt för varje kompilatorpass"
 
-#: common.opt:2157
+#: common.opt:2160
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tAnge normal kodgenereringsmodell för trådlokal lagring"
 
-#: common.opt:2160
+#: common.opt:2163
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "okänd TLS-modell %qs"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr "Ordna om toppnivåfunktioner, variabler och asm:ar"
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr "Utför superblockformering via svansduplicering"
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr "Anta att flyttalsoperationer kan utlösa fällor"
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr "Fånga teckenspill i addition, subtraktion och multiplikation"
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr "Aktivera SSA-CCP-optimering av träd"
 
-#: common.opt:2199
+#: common.opt:2202
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr "Aktivera SSA-BIT-CCP-optimering av träd"
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr "Aktivera slinghuvudkopiering av träd"
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr "Aktivera sammanläggning av kopieringsrelaterade användarvariabler som är inline:ade"
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr "Aktivera sammanläggning av alla kopierelaterade användarvariabler"
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr "Ersätt SSA-temporärer med bättre namn i kopieringar"
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr "Aktivera kopiepropagering i träd"
 
-#: common.opt:2231
+#: common.opt:2234
 msgid "Transform condition stores into unconditional ones"
 msgstr "Transformera villkorliga lagringar till ovillkorliga"
 
-#: common.opt:2235
+#: common.opt:2238
 msgid "Perform conversions of switch initializations."
 msgstr "Utför konvertering av switch-initieringar."
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr "Aktivera eliminering av död kod i SSA-optimeringen i träd"
 
-#: common.opt:2243
+#: common.opt:2246
 msgid "Enable dominator optimizations"
 msgstr "Aktivera dominatoroptimeringar"
 
-#: common.opt:2247
+#: common.opt:2250
 msgid "Enable tail merging on trees"
 msgstr "Aktivera svanssammanslagning av träd"
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr "Aktivera eliminering av död lagring"
 
-#: common.opt:2255
+#: common.opt:2258
 msgid "Enable forward propagation on trees"
 msgstr "Aktivera framåtpropagering på träd"
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr "Aktivera fullständig överflödseliminering (FRE) i träd"
 
-#: common.opt:2263
+#: common.opt:2266
 msgid "Enable string length optimizations on trees"
 msgstr "Aktivera stränglängdsoptimering av träd"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr "Detektera sökvägar som orsakar felaktigt eller odefinierat beteenden på grund av"
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr "Detektera vägar som orsakar felaktigt eller odefinierat beteende på grund av ett null-värde"
 
-#: common.opt:2280
+#: common.opt:2283
 msgid "Enable loop distribution on trees"
 msgstr "Aktivera slingdistribution i träd"
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr "Aktivera slingdistribution för mönster transformerade till biblioteksanrop"
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr "Aktivera förflyttning av slingoberoende delar i träd"
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr "Aktivera transformationen utbyte (interchange) i slingor.  Samma som -floop-interchange"
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr "Skapa kanoniska induktionsvariabler i slingor"
 
-#: common.opt:2300
+#: common.opt:2303
 msgid "Enable loop optimizations on tree level"
 msgstr "Aktivera slingoptimeringar på trädnivå"
 
-#: common.opt:2304
+#: common.opt:2307
 msgid "Enable automatic parallelization of loops"
 msgstr "Aktivera automatisk parallellisering av slingor"
 
-#: common.opt:2308
+#: common.opt:2311
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Aktivera lyftningslast från villkorliga pekare."
 
-#: common.opt:2312
+#: common.opt:2315
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "Aktivera SSA-PRE-optimeringar i träd"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr "I SSA-PRE-optimering på träd, aktivera eliminering av partiell-partiell redundans"
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Utför funktionslokala pekar-på-analyser i träd"
 
-#: common.opt:2324
+#: common.opt:2327
 msgid "Enable reassociation on tree level"
 msgstr "Aktivera återassociering på trädnivå"
 
-#: common.opt:2332
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
 msgstr "Aktivera SSA-kodsänkning i träd"
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr "Utför rätlinjig styrkereduktion"
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr "Utför skalärersättning av aggregat"
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr "Ersätt tillfälliga uttryck i passet SSA->normal"
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr "Utför livstidsuppdelning under passet SSA->normal"
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr "Utför propagering av värdeintervall i träd"
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr "Kompilera en hel kompileringsenhet åt gången"
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr "Utför slingutrullning när iterationsantalet är känt"
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr "Utför slingutrullning för alla slingor"
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr "Tillåt slingoptimeringar att anta att slingorna beter sig normalt"
 
 # Avhugget p.g.a. http://gcc.gnu.org/bugzilla/show_bug.cgi?id=34352
 # Hela meddelandet är översatt
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr "Tillåt optimeringar för flyttalsaritmetik som kan ändra resultatet av operationen på grund av avrundning"
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Samma som -fassociative-math för uttryck som inkluderar division."
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr "Tillåt matematikoptimeringar som kan strida mot IEEE- eller ISO-standarder"
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr "Utför slingavväxling"
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr "Generera bara upprullningstabeller för undantagshantering"
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr "Använd bfd-länkaren istället för standardlänkaren"
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr "Använd gold-länkaren istället för standardlänkaren"
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr "Utför variabelspårning"
 
-#: common.opt:2424
+#: common.opt:2427
 msgid "Perform variable tracking by annotating assignments"
 msgstr "Utför variabelspårning genom att annotera tilldelningar"
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr "Växla -fvar-tracking-assignments"
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr "Utför variabelspårning och tagga också variabler som är oinitierade"
 
-#: common.opt:2442
+#: common.opt:2445
 msgid "Enable vectorization on trees"
 msgstr "Aktivera vektorisering av träd"
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr "Aktivera slingvektorisering i träd"
 
-#: common.opt:2454
+#: common.opt:2457
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr "Aktivera grundblocksvektorisering (SLP) i träd"
 
-#: common.opt:2458
+#: common.opt:2461
 msgid "Specifies the cost model for vectorization"
 msgstr "Anger kostnadsmodellen för vektorisering"
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr "Anger kostnadsmodellen för vektorisering för kod markerad med ett simd-direktiv"
 
-#: common.opt:2465
+#: common.opt:2468
 #, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "okänd kostnadsmodell för vektorisering %qs"
 
-#: common.opt:2478
+#: common.opt:2481
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Aktivera den dynamiska kostnadsmodellen för vektoriseraren.  Bevarad för bakåtkompatibilitet."
 
-#: common.opt:2482
+#: common.opt:2485
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Aktivera den obegränsade kostnadsmodellen för vektoriseraren.  Bevarad för bakåtkompatibilitet."
 
-#: common.opt:2490
+#: common.opt:2493
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Aktivera kopiepropagering av skalärutvecklingsinformation."
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr "Lägg till extra kommentarer till assemblerutdata"
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr "-fvisibility=[default|internal|hidden|protected]\tAnge standardvärde för symbolsynlighet"
 
-#: common.opt:2507
+#: common.opt:2510
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "okänt synlighetsvärde %qs"
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr "Validera vtable-pekare före de används."
 
-#: common.opt:2526
+#: common.opt:2529
 #, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "okänd initieringsprioritet för vtable-verifiering %qs"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr "Mata ut verifieringsräknare för vtable."
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr "Mata ut information om verifieringspekaruppsättningar för vtable."
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr "Använd uttrycksvärdeprofiler i optimeringar"
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr "Konstruera nät och dela orelaterade användningar av en enskild variabel"
 
-#: common.opt:2555
+#: common.opt:2558
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr "Aktivera villkorlig eliminering av död för inbyggda anrop"
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr "Utför optimering av hela program"
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr "Anta att spill vid teckenaritmetik slår runt"
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr "Lägg nollinitierad data i bss-sektionen"
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr "Generera felsökningsinformation i standardformat"
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr "Generera felsökningsinformation i COFF-format"
 
-#: common.opt:2579
+#: common.opt:2582
 msgid "Generate debug information in default version of DWARF format"
 msgstr "Generera felsökningsinformation i standardversion av DWARF-formatet"
 
-#: common.opt:2583
+#: common.opt:2586
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr "Generera felsökningsinformation i DWARF v2-format (eller senare)"
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr "Generera felsökningsinformation i normalt utökat format"
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Generera inte DWARF-sektionerna pubnames och pubtypes."
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Generera DWARF-sektionerna pubnames och pubtypes."
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Generera DWARF-sektionerna pubnames och pubtypes med GNU-utvidgningar."
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Notera inte gcc:s kommandoradsflaggor i DWARF DW_AT_producer."
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Notera gcc:s kommandoradsflaggor i DWARF DW_AT_producer."
 
-#: common.opt:2611
+#: common.opt:2614
 msgid "Don't generate debug information in separate .dwo files"
 msgstr "Generera inte felsökningsinformation i separata .dwo-filer"
 
-#: common.opt:2615
+#: common.opt:2618
 msgid "Generate debug information in separate .dwo files"
 msgstr "Generera felsökningsinformation i separata .dwo-filer"
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr "Generera felsökningsinformation i STABS-format"
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr "Generera felsökningsinformation i utökat STABS-format"
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr "Mata ut DWARF-tillägg utöver vald version"
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr "Mata inte ut DWARF-tillägg utöver vald version"
 
-#: common.opt:2635
+#: common.opt:2638
 msgid "Toggle debug information generation"
 msgstr "Växla generering av felsökningsinformation"
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr "Generera felsökningsinformation i VMS-format"
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr "Generera felsökningsinformation i XCOFF-format"
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr "Generera felsökningsinformation i utökat XCOFF-format"
 
-#: common.opt:2665
+#: common.opt:2668
 msgid "Generate compressed debug sections"
 msgstr "Generera komprimerade felsökningssektioner"
 
-#: common.opt:2669
+#: common.opt:2672
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr "-gz=<format>\tGenerera komprimerade felsökningssektioner i formatet <format>"
 
-#: common.opt:2676
+#: common.opt:2679
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr "-iplugindir=<kat>\tSätt <kat> att vara standardbibliotek för insticksmoduler"
 
-#: common.opt:2680
+#: common.opt:2683
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr "-imultiarch <kat>\tSätt <kat> att vara inkluderingsunderbiblioteket för multiarkitekturer"
 
-#: common.opt:2702
+#: common.opt:2705
 msgid "-o <file>\tPlace output into <file>"
 msgstr "-o <fil>\tSkriv utdata i <fil>"
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr "Aktivera funktionsprofilering"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr "Som -pedantic men ange dem som fel"
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr "Visa inte kompilerade funktioner eller tiden som förbrukats"
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr "Aktivera utförlig utskrift"
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr "Visa kompilatorns version"
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "Undertryck varningar"
 
-#: common.opt:2806
+#: common.opt:2809
 msgid "Create a shared library"
 msgstr "Skapa ett delat bibliotek"
 
-#: common.opt:2851
+#: common.opt:2854
 msgid "Create a position independent executable"
 msgstr "Skapa ett positionsoberoende körbart program"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr "Använd anroparens sparregister mellan anrop om möjligt"
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "beräknat värde används inte"
@@ -14348,221 +14358,221 @@
 msgid "expected integer or boolean type"
 msgstr "heltal eller boolesk typ förväntades"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 msgid "invalid comparison of nil with nil"
 msgstr "ogiltig jämförelsekod av nil med nil"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 msgid "incompatible types in binary expression"
 msgstr "inkompatibla typer i binärt uttryck"
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 msgid "integer division by zero"
 msgstr "heltalsdivision med noll"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 msgid "shift of non-integer operand"
 msgstr "skift med operand som inte är heltal"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 msgid "shift count not unsigned integer"
 msgstr "skiftantal är inte teckenlöst heltal"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 msgid "negative shift count"
 msgstr "negativt skiftantal"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 msgid "object is not a method"
 msgstr "objektet är inte en metod"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 msgid "method type does not match object type"
 msgstr "metodtypen stämmer inte med objekttypen"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 msgid "invalid use of %<...%> with builtin function"
 msgstr "ogiltig användning av %<...%> med inbyggd funktion"
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "ogiltig användning av metodvärde som argument till Offsetof"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr "argument till Offsetof implicerar indirektion till ett inbäddat fält"
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 msgid "not enough arguments"
 msgstr "inte tillräckligt med argument"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 msgid "too many arguments"
 msgstr "för många argument"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 msgid "argument 1 must be a map"
 msgstr "argument 1 måste vara en avbildning"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 msgid "invalid type for make function"
 msgstr "ogiltigt typ för make-funktion"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr "en längd behövs när en skiva allokeras"
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr "len är större än cap"
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 msgid "too many arguments to make"
 msgstr "för många argument till make"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 msgid "argument must be array or slice or channel"
 msgstr "argumentet måste vara en vektor eller skiva eller kanal"
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr "argumentet måste vara en sträng eller vektor eller skiva eller avbildning eller kanal"
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 msgid "unsupported argument type to builtin function"
 msgstr "argumenttyp som inte stödjs till inbyggd funktion"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 msgid "argument must be channel"
 msgstr "argumentet måste vara en kanal"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr "kan inte stänga en kanal endast för mottagning"
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 msgid "argument must be a field reference"
 msgstr "argumentet måste vara en fältreferens"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 msgid "left argument must be a slice"
 msgstr "vänstra argumentet måste vara en skiva"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr "elementtyper måste vara samma"
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 msgid "first argument must be []byte"
 msgstr "första argumentet måste vara []byte"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 msgid "second argument must be slice or string"
 msgstr "andra argumentet måste vara en skiva eller sträng"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 msgid "argument 2 has invalid type"
 msgstr "parameter 2 har ogiltig typ"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 msgid "argument must have complex type"
 msgstr "argumentet måste ha komplex typ"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 msgid "complex arguments must have identical types"
 msgstr "komplexa argument måste ha identiska typer"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 msgid "complex arguments must have floating-point type"
 msgstr "komplexa argument måste ha flyttalstyp"
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 msgid "expected function"
 msgstr "en funktion förväntades"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 msgid "multiple-value argument in single-value context"
 msgstr "flervärt argument i sammanhang för enstaka värde"
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 msgid "invalid use of %<...%> with non-slice"
 msgstr "ogiltig användning av %<...%> med annat än skiva"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 msgid "function result count mismatch"
 msgstr "funktionsresultatsräknare stämmer inte"
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 msgid "incompatible type for receiver"
 msgstr "inkompatibel typ för mottagare"
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "ogiltig användning av %<.%> i en funktion som inte är variadisk"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 msgid "number of results does not match number of values"
 msgstr "antalet resultat stämmer inte med antalet värden"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 msgid "index must be integer"
 msgstr "indexet måste vara ett heltal"
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 msgid "slice end must be integer"
 msgstr "skivslut måste vara ett heltal"
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 msgid "slice capacity must be integer"
 msgstr "skivkapacitet måste vara ett heltal"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr "inverterat skivintervall"
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr "skiva av oadresserbart värde"
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 msgid "incompatible type for map index"
 msgstr "inkompatibel typ för avbildningsindex"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr "gränssnitt eller pekare till gränssnitt förväntades"
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 msgid "too many expressions for struct"
 msgstr "för många uttryck för post"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 msgid "too few expressions for struct"
 msgstr "för få argument för post"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 msgid "type assertion only valid for interface types"
 msgstr "typförsäkran är endast giltigt för gränssnittstyper"
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr "omöjlig typförsäkran: typen implementerar inte ett gränssnitt"
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 msgid "expected channel"
 msgstr "kanal förväntades"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr "ogiltig receive på kanal endast för sändning"
 
@@ -14672,71 +14682,71 @@
 msgid "cannot use type %s as type %s"
 msgstr "det går inte att använda typ %s som typ %s"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 msgid "different receiver types"
 msgstr "olika mottagartyper"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 msgid "different number of parameters"
 msgstr "olika antal parametrar"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 msgid "different parameter types"
 msgstr "olika parametertyper"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr "olika varargs"
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr "olika antal resultat"
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 msgid "different result types"
 msgstr "olika resultattyper"
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "en explicit konvertering behövs, metoden %s%s%s saknas"
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "inkompatibel typ för metoden %s%s%s"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "inkompatibel typ för metoden %s%s%s (%s)"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr "pekare till gränssnittstyp har inga metoder"
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 msgid "type has no methods"
 msgstr "typen har inga metoder"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "tvetydig metod %s%s%s"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "metoden saknas %s%s%s"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "metoden %s%s%s kräver en pekarmottagare"
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr "metoden %s%s%s är märkt go:nointerface"
@@ -14856,7 +14866,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "ogiltigt tredje argument till %<__builtin_prefetch%>; använder noll"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "För många argument till funktionen %<va_start%>"
@@ -15037,12 +15047,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kförsök att frigöra ett icke-heap-objekt"
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "funktionsanrop har sammansatt värde"
 
-#: calls.c:3179
+#: calls.c:3195
 #, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "skickar för många argument på stacken"
@@ -15602,242 +15612,247 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "antal gb-noter i instruktionskedjan (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr "antal anropande bågar är negativt"
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr "frekvensen för anropande båge är negativ"
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr "frekvensen anropande båge är för stor"
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "aux-fält satt för båge %s->%s"
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, gcc-internal-format
 msgid "execution count is negative"
 msgstr "exekveringsräknare är negativ"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "inline-klon i samma comdat-grupplista"
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "lokala symboler måste vara definierade"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "externt synlig inline-klon"
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "inline-klon som man tar adressen till"
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "inline-klon tvingas till utdata"
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "aux-fält satt för indirekt båge från %s"
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "En indirektbåge från %s är inte markerad som indirekt eller har associerad indirect_info, motsvarande sats är: "
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "comdat-lokal funktion anropad av %s utanför dess comdat"
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to-pekare är fel"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "flera inline-anropare"
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "inlined_to-pekare angiven för noninline-anropare"
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr "anropsbåges frekvens %i stämmer inte med GB-frekvens %i"
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr "indirekt anrops frekvens %i stämmer inte med GB-frekvens %i"
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "inlined_to-pekare är angivet men inga företrädare finns"
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "inlined_to-pekare refererar till sig själv"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "cgraph_node har fel clone_of"
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "cgraph_node har fel klonlista"
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "cgraph_node är i klonlistan men den är inte en klon"
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "cgraph_node har fel prev_clone-pekare"
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "dubbellänkad lista av kloner trasig"
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Alias har anropsbågar"
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Alias har icke-alias-referens"
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Alias har mer än en aliasreferens"
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "Analyserat alias har ingen referens"
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr "Instrumenteringsklonen refererar inte originalnoden"
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "Oinstrumenterad nod har en originaldeklaration som inte är NULL"
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr "Instrumenterad not har felaktig originaldeklaration"
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr "Noden har mer än en chkp-referens"
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr "Fel nod refereras med en chkp-referens"
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr "Analyserad nod har ingen referens till en instrumenterad version"
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr "En aliaskedja för en instrumenterad not är bruten"
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Ingen båge ut från snuttnod"
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Mer än en båge ut från en snuttnod"
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Snuttar får inte ha en kropp"
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr "Instrumenteringssnutten har fel anropande båge"
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "delat anropssats:"
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "bågpekare till fel deklaration:"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "ett indirekt båge med okänd anropsmål motsvarande ett call_stmt med en känd deklaration:"
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "anropsgrafsbåge saknas för anropssats:"
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "referens till död sats"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "båge %s->%s har ingen motsvarande anropssats"
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "en indirekt båge från %s har inget motsvarande call_stmt"
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node misslyckades"
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "%s sektion %s saknas"
@@ -15967,7 +15982,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER måste vara satt"
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, gcc-internal-format
 msgid "atexit failed"
@@ -16208,17 +16223,17 @@
 msgid "          %s"
 msgstr "          %s"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr "gemensam symbolfelsökningsinformation är inte strukturerad som symbol+avstånd"
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "globala destruerare stödjs inte på denna målarkitektur"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "globala konstruerare stödjs inte för denna målarkitektur"
@@ -16263,12 +16278,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "multipla EH-personligheter stödjs endast med assemblerare som stödjer direktivet .cfi.personality."
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "odelegitimerad UNSPEC %s (%d) funnen på variabelplats"
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr "-feliminate-dwarf2-dups är trasig för C++, ignorerar"
@@ -16463,7 +16478,7 @@
 msgid "total size of local objects too large"
 msgstr "total storlek på lokala objekt är för stor"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "omöjlig begränsning i %<asm%>"
@@ -16910,9 +16925,9 @@
 msgstr "kan inte skriva PCH-fil"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, gcc-internal-format
 msgid "declared here"
 msgstr "deklarerad här"
@@ -16927,152 +16942,147 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr "gimple-kontroll: %s(%s) förväntades, har %s(%s) i %s, vid %s:%d"
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "använder resultat från funktion som returnerar %<void%>"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "ogiltigt l-värde i asm-utdata %d"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "icke-minnesindata %d måste stanna i minnet"
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "minnesindata %d är inte direkt adresserbar"
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "trådprivat variabel %qE använd i målregion"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "omgivande målregion"
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "trådprivat variabel %qE använd i obunden uppgift"
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "omgivande uppgift"
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "%qD refererad i målregion som inte har en avbildbar typ"
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr "%qE inte angiven i omgivande parallel"
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr "omgivande parallel"
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr "%qE inte angiven i omgivande uppgift"
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr "%qE inte angiven i omgivande teams-konstruktion"
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr "omgivande teams-konstruktion"
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "iterationsvariabel %qE är förutbestämt linjär"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "instansvariabel %qE skall vara privat"
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "iterationsvariabel %qE får inte vara firstprivate"
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "iterationsvariabel %qE får inte vara reduction"
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "iterationsvariabel %qE får inte vara lastprivate"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "instansvariabel %qE får inte vara privat"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "copyprivate-variabel %qE är inte privat threadprivate eller private i yttre sammanhang"
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s-variabel %qE är privat i yttre sammanhang"
 
-#: gimplify.c:7001
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, gcc-internal-format
-msgid "lastprivate variable %qE is private in outer context"
-msgstr "lastprivate-variabel %qE är privat i yttre sammanhang"
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
-#, gcc-internal-format
 msgid "directive not yet implemented"
 msgstr "direktivet är inte implementerat ännu"
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "%<_Cilk_spawn%> förväntades före %<_Cilk_sync%>"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification misslyckades"
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "första argumentet till %<va_arg%> är inte av typen %<va_list%>"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT konverteras till %qT när det skickas via %<...%>"
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(alltså skall du skicka %qT och inte %qT till %<va_arg%>)"
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "om denna kod nås, kommer programmet att avbryta"
@@ -17272,7 +17282,7 @@
 #: ipa-devirt.c:1206
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
-msgstr "en uppräkningstyptyp med andra värden är definierad i en annan översättningsenhet"
+msgstr "en uppräkningstyp med andra värden är definierad i en annan översättningsenhet"
 
 #: ipa-devirt.c:1214
 #, gcc-internal-format
@@ -17337,12 +17347,12 @@
 #: ipa-devirt.c:1436
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
-msgstr "ett fält med ett annat namn är definerat i en annan översättningsenhet"
+msgstr "ett fält med ett annat namn är definierat i en annan översättningsenhet"
 
 #: ipa-devirt.c:1449
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
-msgstr "ett fält med samma namn men annan typ är definerat i en annan översättningsenhet"
+msgstr "ett fält med samma namn men annan typ är definierat i en annan översättningsenhet"
 
 #: ipa-devirt.c:1462
 #, gcc-internal-format
@@ -17486,47 +17496,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr "Maximalt antal genererade omladdningsinstruktioner per instruktion uppnått (%d)\n"
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "bytekodström: hittade multipla instanser av cgraph-nod med uid %d"
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "bytekodström: ingen anropare funnen när båge lästes"
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "bytekodström: ingen anropad funnen när båge lästes"
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "bytekodström: tom cgraph-nod funnen"
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "Som mest %i profilkörningar stödjs.  Kanske en skadad profil?"
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "Profilinformation i %s är skadad"
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "det går inte att hitta LTO-cgraph %s"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "det går inte att hitta LTO-avsnittsreferenser i %s"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "ogiltig avlastningstabell i %s"
@@ -17607,47 +17617,47 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "felformaterad COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr "Flaggan %s inte konsekvent använd i alla LTO-indatafiler"
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr "problem med att bygga målavbild för %s\n"
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, gcc-internal-format
 msgid "reading input file"
 msgstr "läser indatafiler"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, gcc-internal-format
 msgid "writing output file"
 msgstr "skriver utdatafil"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr "installationsfel, kan inte hitta crtoffloadend.o"
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr "installationsfel, kan inte hitta crtoffloadbegin.o"
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "miljövariabeln COLLECT_GCC måste vara satt"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "miljövariabeln COLLECT_GCC_OPTIONS måste vara satt"
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen: %s: %m"
@@ -17782,28 +17792,28 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr "setjmp/longjmp inuti simd-konstruktion"
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "ogiltig utgång från strukturerat %s-block"
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "ogiltig ingång till strukturerat %s-block"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr "ogiltig gren till/från strukturerat %s-block"
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, gcc-internal-format
 msgid "ignoring large linear step"
 msgstr "ignorerar stort linjärt steg"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr "ignorera linjärt steg noll"
@@ -18324,8 +18334,8 @@
 msgstr "det går inte att använda %qs som ett fast register"
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "okänt registernamn: %s"
@@ -18765,7 +18775,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld returnerade avslutningsstatus %d"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F är använd men inte definierad"
@@ -19743,42 +19753,42 @@
 msgid "memory access check always fail"
 msgstr "minnesåtkomstkontrollen misslyckas alltid"
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr "-fcheck-pointer-bounds kräver ”%s”-stöd för intern användning"
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr "pekargränserna gick förlorade på grund av det oväntade uttrycket %s"
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr "chkp_get_bounds_by_definition: Oväntad variabel av typen %s"
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr "chkp_get_bounds_by_definition: Oväntad GIMPLE-kod %s"
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr "chkp_make_addressed_object_bounds: Oväntad trädkod %s"
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr "chkp_find_bounds: Oväntad trädkod %s"
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr "chkp_find_bounds: Kan inte hitta gränserna för pekare"
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr "chkp_walk_pointer_assignments: oväntad RHS-typ: %s"
@@ -20159,47 +20169,47 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr "vektorisering hände inte för en simd-slinga"
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, gcc-internal-format
 msgid "array subscript is outside array bounds"
 msgstr "vektorindex är utanför vektorgränserna"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, gcc-internal-format
 msgid "array subscript is above array bounds"
 msgstr "vektorindex är ovanför vektorgränsen"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, gcc-internal-format
 msgid "array subscript is below array bounds"
 msgstr "vektorindex är under vektorgränsen"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr "antar att teckenspill inte förekommer vid förenkling av villkor till konstant"
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr "antar att teckenspill inte förekommer vid förenkling av villkor"
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr "jämförelsen är alltid falsk på grund av begränsat intervall för datatypen"
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr "jämförelsen är alltid sann på grund av begränsat intervall för datatypen"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr "antar att teckenspill inte förekommer vid förenkling av %</%> eller %<%%%> till %<>>%> eller %<&%>"
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr "antar att teckenspill inte förekommer vid förenkling av %<abs (X)%> till %<X%> eller %<-X%>"
@@ -20243,9 +20253,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -20476,7 +20486,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "begärd justering för %q+D är större än implementerad justering av %wu"
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "lagringsstorlek på %q+D är okänd"
@@ -20624,27 +20634,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "stränglängden %qd är större än den längden %qd som ISO C%d kompilatorer skall stödja"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "vänstershiftoperanden är negativ"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "högershiftoperanden är negativ"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "vänstershiftoperanden ≥ storleken på typen"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "högershiftoperanden ≥ storleken på typen"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "spill i konstant uttryck"
@@ -20974,12 +20984,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "adressen till %qD kommer alltid beräknas till %<true%>"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "föreslår parenteser runt tilldelning som används som sanningsvärde"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "ogiltigt användning av %<restrict%>"
@@ -21426,12 +21436,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "ogiltig vektortyp för attributet %qE"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "vektorstorleken är inte en hel multipel av komponentstorleken"
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "vektorstorlek noll"
@@ -21441,22 +21451,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr "antal komponenter i vektorn inte en tvåpotens"
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "attributet nonnull utan argument på en icke-prototyp"
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "argument till nonnull har ett ogiltigt värde (argument %lu)"
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "nonnull-argument med felaktigt operandnummer (argument %lu, operand %lu)"
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "nonnull-argument refererar icke-pekar-operand (argument %lu, operand %lu)"
@@ -21496,12 +21506,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "attributet %qE är bara tillämplig på funktioner med variabelt antal argument"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "den begärda positionen är inte en heltalskonstant"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "begärd position är mindre än noll"
@@ -21581,7 +21591,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "det går inte att använda %<offsetof%> på en icke-konstant adress"
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "försök att ta adressen till en medlemmen %qD i en bitfältspost"
@@ -21997,7 +22007,7 @@
 msgstr "indexvärdet är utanför gränsen"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "konvertering av skalären %qT till vektorn %qT innebär avhuggning"
@@ -22453,7 +22463,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> använder två olika variabler till minne"
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ogiltig typ för iterationsvariabeln %qE"
@@ -22463,22 +22473,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE är inte initierad"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "styrpredikat saknas"
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "ogiltigt styrpredikat"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "utelämnat ökningsuttryck"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ogiltigt ökningsuttryck"
@@ -23013,6 +23023,11 @@
 msgid "too many input files"
 msgstr "för många indatafiler"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, gcc-internal-format
+msgid "-mcpu string too large"
+msgstr "strängen till -mcpu är för stor"
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -23038,47 +23053,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s har ogiltig kiselversion"
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops är föråldrat, använd -falign-loops"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d är inte mellan 0 och %d"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps är föråldrat, använd -falign-jumps"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d är inte mellan 0 och %d"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions är föråldrat, använd -falign-functions"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d är inte mellan 0 och %d"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d är inte mellan 0 och 5"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> stödjs för närvarande bara på GNU/Linux"
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> kräver assemblerstöd för CFI-direktiv"
@@ -23388,7 +23403,7 @@
 #: config/aarch64/aarch64-builtins.c:1021
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
-msgstr "%Ktotal storlek och elementstorlek måste vara en konstant omedelbar"
+msgstr "%Ktotal storlek och elementstorlek måste vara en konstant omedelbar skild från noll"
 
 #: config/aarch64/aarch64.c:6643
 #, gcc-internal-format
@@ -23460,63 +23475,63 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr "bana %ld utanför intervallet %ld - %ld"
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "felaktigt värde %qs till flaggan -mtrap-precision"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "felaktigt värde %qs till flaggan -mfp-rounding-mode"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "felaktigt värde %qs till flaggan -mfp-trap-mode"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr "felaktigt värde %qs till flaggan -mcpu"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, gcc-internal-format
 msgid "bad value %qs for -mtune switch"
 msgstr "felaktigt värde %qs till flaggan -mtune"
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr "fp-mjukvarukomplettering kräver -mtrap-precision=i"
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "avrundningsläge stödjs inte för VAX-flyttal"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "läge för fällor (trap mode) stödjs inte för VAX-flyttal"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr "128-bitars long double stödjs inte för VAX-flyttal"
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr "L%d-cachelatens okänd för %s"
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr "felaktigt värde %qs till flaggan -memory-latency"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -23990,14 +24005,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, gcc-internal-format
 msgid "%qE attribute only applies to functions"
@@ -24636,376 +24651,392 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "det går inte att sätta position i PCH-fil: %m"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong arg %s to option %s"
 msgstr "felaktiga argument %s till flaggan %s"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr "storleksintervall till flaggan %s skall vara ökande"
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "felaktigt stringop-strateginamn %s angivet till flaggan %s"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
 #, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr "stringop-strateginamn %s angivet till flaggan %s stödjs inte i 32-bitars kod"
+
+#: config/i386/i386.c:3012
+#, gcc-internal-format, gfc-internal-format
 msgid "unknown alignment %s specified for option %s"
 msgstr "okänd justering %s angiven till flaggan %s"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr "maxvärdet för den sista storleksintervallet skall vara -1 för flaggan %s"
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, gcc-internal-format, gfc-internal-format
 msgid "too many size ranges specified in option %s"
 msgstr "för många storleksintervall angivna i flaggan %s"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "Okänd parameter till flaggan -mtune-ctrl: %s"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr "%stune=x86-64%s bör undvikas.  Använd istället det som passar av %stune=k8%s och %stune=generic%s"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte stödjs inte för 32-bitarskod"
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "adressläget %qs stödjs inte i %s-bitsläge"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "kodmodellen %qs stödjs inte i %s-bitsläge"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodmodellen %qs stödjs inte i x32-läge"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "kodmodellen %s stödjer inte PIC-läge"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel stödjs inte i denna konfiguration"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-bitsläge inte inkompilerat"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU:n du valde stödjer inte instruktionsuppsättningen x86-64"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "Intel MPX stödjer inte x32"
 
 # "generic" är bokstavligt argument till flaggan
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr "generic CPU kan användas endast till %stune=%s %s"
 
 # "intel" är bokstavligt argument till flaggan
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr "intel CPU kan användas endast till %stune=%s %s"
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "felaktigt värde (%s) till %sarch=%s %s"
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "felaktigt värde (%s) till %stune=%s %s"
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm ignoreras i 64-bitsläge"
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d är inte mellan 0 och %d"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr "%srtd%s ignoreras i 64-bitsläge"
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mprefetch-stack-boundary stödjs inte för denna målarkitektur"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d är inte mellan %d och %d"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d är inte mellan %d och 12"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount är inte kompatibelt med denna målarkitektur"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount är inte implementerat för -fPIC"
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr "%ssseregparm%s använd utan SSE aktiverat"
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "instruktionsuppsättningen SSE avaktiverad, använder 387-aritmetik"
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "instruktionsuppsättningen 387 avaktiverad, använder SSE-aritmetik"
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr "utrullning av tabeller kräver antingen en rampekare eller %saccumulate-outgoing-args%s för att bli korrekt"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry stödjs inte för 32 bitar i kombination med -fpic"
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry är inte kompatibelt med SEH"
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "okänt alternativ till -mrecip=%s"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "argument till attribut %<target%> är inte en sträng"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(”%s”)) är okänt"
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(”%s”) var redan angivet"
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attributen fastcall och regparm är inte kompatibla"
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attributen regparam och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "attributet %qE kräver en heltalskonstant som argument"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument till attributet %qE är större än %d"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attributen fastcall och cdecl är inte kompatibla"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attributen fastcall och stdcall är inte kompatibla"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attributen fastcall och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attributen stdcall och cdecl är inte kompatibla"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attributen stdcall och fastcall är inte kompatibla"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attributen stdcall och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attributen cdecl och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "attributet %qE används för annat än klassmetod"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "anrop av %qD med attributet sseregparm utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "anrop av %qT med attributet sseregparm utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.c:5923
+#: config/i386/i386.c:6235
 #, gcc-internal-format
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr "anrop av %qD med SSE-anropskonvention utan SSE/SSE2 aktiverat"
-
-#: config/i386/i386.c:6210
-#, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 stödjer inte attributet ms_abi"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue är inte kompatibelt med nästade funktioner"
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX512F-vektorargument utan AVX512F aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX512F-vektorretur utan AVX512F aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX-vektorargument utan AVX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX-vektorretur utan AVX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE-vektorargument utan SSE aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE-vektorretur utan SSE aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX-vektorargument utan MMX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX-vektorretur utan MMX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI:et för att skicka en post med en flexibel vektormedlem har ändrats i GCC 4.4"
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI:et för att skicka unioner med long double har ändrats i GCC 4.4"
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI:et för att skicka en post med complex float medlem har ändrats i GCC 4.4"
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE-registerretur med SSE avaktiverat"
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE-registerargument med SSE avaktiverat"
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87-registerretur med x87 avaktiverat"
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, gcc-internal-format
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr "anrop av %qD med SSE-anropskonvention utan SSE/SSE2 aktiverat"
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr "detta är ett fel i GCC som kan gås runt genom att lägga till attributet used till den anropade funktionen"
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI:et för att skicka parametrar med %d-bytejustering har ändrats i GCC 4.6"
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
 #, gcc-internal-format
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr "anrop av %qD med SSE-anropskonvention utan SSE/SSE2 aktiverat"
+
+#: config/i386/i386.c:11378
+#, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "attributet ms_hook_prologue är inte kompatibelt med -mfentry i 32-bitsläge"
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack stödjer inte fastcall med nästade funktioner"
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack stödjer inte 2 registerparametrar för en nästad funktion"
@@ -25012,252 +25043,252 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack stödjer inte 3 registerparametrar"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "utökade register har inga höga halvor"
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ej stödd operandstorlek för utökat register"
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "operand som inte är heltal använt med operandkod ”z”"
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "Ingen avsändare funnen för versionsattributen"
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Ingen avsändare funnen för %s"
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "Ingen avsändare funnen för versionsattributen: %s"
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Funktionsversioner kan inte markeras som gnu_inline, kropparna måste vara genererade"
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionering av virtuell funktion stödjs inte"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr "saknat attribut %<target%> för flerversioners %D"
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "tidigare deklaration av %D"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "multiversionering behöver ifunc som inte stödjs på detta mål"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Parameter till inbyggd måste vara en strängkonstant eller -literal"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "Parameter till inbyggd är inte giltig: %s"
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "det sista argumentet måste vara en 2-bitars omedelbar"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "det femte argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "det tredje argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "det sista argumentet måste vara en 1-bits omedelbar"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "det sista argumentet måste vara en 3-bitars omedelbar"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "det sista argumentet måste vara en 4-bitars omedelbar"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "det sista argumentet måste vara en 1-bits omedelbar"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "det sista argumentet måste vara en 5-bitars omedelbar"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "det näst sista argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "det sista argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "det tredje argumentet måste vara en jämförelsekonstant"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "felaktigt jämförelsesätt"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "felaktig avrundningsoperand"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 4-bitars omedelbar"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 5-bitars omedelbar"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "det sista argumentet måste vara en 32-bitars omedelbar"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "selektor måste vara en heltalskonstant i intervallet 0..%wi"
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE behöver en okänd isa-flagga"
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE behöver isa-flaggan %s"
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "sista argumentet måste vara en omedelbar"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "det sista argumentet ha skala 1, 2, 4, 8"
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "det fjärde argumentet ha skala 1, 2, 4, 8"
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "felaktig tipsoperand"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "argumentet till xabort måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attributet %qE är bara tillgängligt för 32 bitar"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumentet till attributet %qE är varken noll eller ett"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "attributen ms_abi och sysv_abi är inte kompatibla"
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibelt attribut ignorerat"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr "Okänd arkitekturspecifik minnesmodell"
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE används inte med ACQUIRE eller starkare minnesmodell"
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE används inte med RELEASE eller starkare minnesmodell"
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "ej stödd simdlen: %d"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr "returtyp %qT stödjs ej för simd\n"
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "argumenttyp %qT som inte stödjs till simd\n"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr "Pekarkontrolleraren kräver stöd för MPX på detta mål.  Använd flaggan -mmpx för att aktivera MPX."
@@ -25348,13 +25379,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "attributet %qE kräver en strängkonstant som argument"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr "värdet av -mfixed-range måste ha formen REG1-REG2"
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -25426,7 +25457,7 @@
 msgstr "attributet %qE stödjs inte för denna målarkitekturen R8C"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, gcc-internal-format
 msgid "%qE attribute argument not an integer constant"
 msgstr "argumentet till attribut %qE är inte en heltalskonstant"
@@ -25486,7 +25517,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread är tillgängligt endast för fido"
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "stackgränsuttryck stödjs inte"
@@ -26336,16 +26367,11 @@
 msgid "-g option disabled"
 msgstr "flaggan -g är avslagen"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "justering (%u) för %s överskrider maximal justering för globala common-data.  Använder %u"
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr "flaggan -munix=98 krävs för funktioner från C89 tillägg 1.\n"
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, gcc-internal-format
@@ -26603,307 +26629,312 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "målattribut eller pragma ändrar dubbel precisions flyttal"
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "layouten av aggregat som innehåller vektorer med %d-bytejustering har ändrats i GCC 5"
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-vektor returnerad som referens: icke-standard ABI-utökning utan kompatibilitetsgaranti"
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "det går inte att returnera värde i vektorregister för att altivec-instruktioner är avaktiverade, använd -maltivec för att aktivera dem"
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI:et för att skicka aggregat med %d-bytejustering har ändrats i GCC 5"
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "det går inte att skicka argument i vektorregister för att altivec-instruktioner är avaktiverade, använd -maltivec för att aktivera dem"
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI:et för att skicka homogena flyttalsaggregat har ändrats i GCC 5"
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-vektor skickad som referens: icke-standard ABI-utökning utan kompatibilitetsgaranti"
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "internt fel: den inbyggda funktionen %s redan bearbetad"
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argument 1 måste vara ett 8-bitars fältvärde"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argument 1 måste vara en 5-bitars literal med tecken"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argument 2 måste vara en 5-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "argumentet 1 till __builtin_altivec_predicate måste vara en konstant"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "argument 1 till __builtin_altivec_predicate är utanför sitt intervall"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
 #, gcc-internal-format, gfc-internal-format
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr "inbyggd %s är endast giltigt i 64-bitsläge"
+
+#: config/rs6000/rs6000.c:12763
+#, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "argument %d måste vara en literal utan tecken"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argument %d är en literal utan tecken som är utanför sitt intervall"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argument 3 måste vara en 4-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argument 3 måste vara en 2-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argument 3 måste vara en 1-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "argument 1 måste vara 0 eller 2"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argument 1 måste vara en 1-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argument 2 måste vara en 6-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "argument 2 måste vara 0 eller 1"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "argument 3 måste vara i intervallet 0..15"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argument till %qs måste vara en 2-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "ej upplöst överlagring för inbyggd Altivec %qF"
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "argument till dss måste vara en 2-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "argument 1 till __builtin_paired_predicate måste vara en konstant"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "argument 1 till __builtin_paired_predicate är utanför sitt intervall"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "argument 1 till __builtin_spe_predicate måste vara en konstant"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "argument 1 till __builtin_spe_predicate är utanför sitt intervall"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "Den inbyggda funktionen %s är endast giltig för cell-processorn"
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mvsx"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mhtm"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -maltivec"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mpaired"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mspe"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "Den inbyggda funktionen %s behöver flaggorna -mhard-dfp och -mpower8-vector"
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mhard-dfp"
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mpower8-vector"
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "Den inbyggda funktionen %s behöver flaggorna -mhard-float och -mlong-double-128"
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mhard-float"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "Den inbyggda funktionen %s stödjs inte med de aktuella flaggorna"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had no type"
 msgstr "internt fel: inbyggd funktion %s har ingen typ"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "internt fel: inbyggd funktion %s hade en oväntad returtyp %s"
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "internt fel: inbyggd funktion %s, argument %d har en oväntad argumenttyp %s"
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "för stor stackram"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering av 64-bitskod för detta ABI"
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Du kan inte ta adressen till en nästad funktion om du använder flaggan -mno-pointers-to-nested-functions"
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "användning av %<long double%> i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "användning av booleaner i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "användning av %<complex%> i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "användning av decimala flyttalstyper i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "användning av %<long%> i AltiVec-typer är ogiltigt för 64-bitskod utan -mvsx"
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "användning av %<long%> i AltiVec-typer bör undvikas, använd %<int%>"
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "användning av %<long long%> i AltiVec-typer är ogiltigt utan -mvsx"
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "användning av %<double%> i AltiVec-typer är ogiltigt utan -mvsx"
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "matar ut mikrokodsinstruktion %s\t[%s] nr %d"
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "matar ut villkorlig mikrokodsinstruktion %s\t[%s] nr %d"
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "felaktig cpu ”%s” för %s”%s”%s"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s”%s”%s är inte tillåtet"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s”%s”%s är ogiltigt"
@@ -27154,88 +27185,88 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "begärt attribut %qE är inte ett kommaseparerat par av ickenegativa heltalskonstanter eller för stort (max. %d)"
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "totala storleken på lokala variabler överskrider arkitekturens gräns"
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "ramstorleken för funktionen %qs är %wd byte vilket överskrider användarens valda stackgräns på %d byte.  En ovillkorlig fälla läggs till."
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "ramstorleken för funktionen %qs är %wd byte vilket är mer än hälften av stackstorleken.  Den dynamiska kontrollen skulle inte vara pålitlig.  Ingen kontroll läggs ut för denna funktion."
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "ramstorlek på %qs är %wd byte"
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs använder dynamisk stackallokering"
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr "Inbyggda för transaktionsvis körning är inte aktiverade (-mhtm)\n"
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argumenten till %qs skall vara ickenegativa heltal"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argumentet till %qs är för stort (max. %d)"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/Architecture-läge stödjs inte på %s"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bits ABI stödjs inte i ESA/390-läge"
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "hårdvaruinstruktioner för decimala flyttal är inte tillgängliga på %s"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "hårdvaruinstruktioner för decimalflyttal är inte tillgängliga i läget ESA/390"
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp kan inte användas tillsammans med -msoft-float"
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float stödjs inte i kombination"
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "stackstorlek måste vara större än stackvaktsvärdet"
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "stackstorlek får inte vara större än 64 k"
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard implicerar användning av -mstack-size"
@@ -27250,53 +27281,53 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr "utrullningstabeller kräver för närvarande antingen en rampekare eller -maccumulate-outgoing-args för att bli korrekt"
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "__builtin_saveregs stödjs inte på denna målunderarkitektur"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, gcc-internal-format
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "attributet %qE är bara tillämpligt på avbrottsfunktioner"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, gcc-internal-format
 msgid "%qE attribute is supported only for SH2A"
 msgstr "attributet %qE stödjs endast för SH2A"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr "attributet interrupt_handler är inte kompatibelt -m5-compact"
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, gcc-internal-format
 msgid "%qE attribute only applies to SH2A"
 msgstr "attributet %qE är bara tillämpligt på SH2A"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, gcc-internal-format
 msgid "%qE attribute argument should be between 0 to 255"
 msgstr "argument till attribut %qE skall vara mellan 0 och 255"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, gcc-internal-format
 msgid "%qE attribute argument not a string constant"
 msgstr "argument till attribut %qE är inte en strängkonstant"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr "r0 behöver vara tillgängligt som ett anropsöverskrivet register"
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, gcc-internal-format
 msgid "need a second call-clobbered general purpose register"
 msgstr "behöver ett andra generellt anropsöverskrivet register"
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr "behöver ett anropsöverskrivet målregister"
@@ -27677,43 +27708,43 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr "underprogrammet %q+F är inte markerat Inline"
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "ogiltig elementtyp för attributet %qs"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr "antal komponenter i vektorn inte en tvåpotens"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "attributet %qs ignorerat"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "attributet %qs kräver prototyper med namngivna argument"
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "attributet %qs fungerar bara på funktioner med variabelt antal argument"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "attributet %qE har ingen effekt"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "attributet %qs är bara tillämpbart på vektortyper"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -27771,7 +27802,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "värdet av typen void ignoreras inte vilket bör göras"
@@ -27801,62 +27832,62 @@
 msgid "GCC supports only %u nested scopes"
 msgstr "GCC stödjer endast %u nästade definitionsområden"
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "etikett %q+D använd men är inte definierad"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "nästad funktion %q+D är deklarerad men aldrig definierad"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr "inline:ad funktion %q+D är deklarerad men aldrig definierad"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "oanvänd variabel %q+D"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, gcc-internal-format
 msgid "variable %qD set but not used"
 msgstr "variabeln %qD sätts men används inte"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
-msgstr "den kompletterade typen på vektor %q+D är okompatibel med implicit initiering"
+msgstr "den kompletterade typen på vektor %q+D är inkompatibel med implicit initiering"
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "ursprungligen definierad här"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr "en parameterlista med ellips kan inte matcha en tom parameternamnlistdeklaration"
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr "en argumenttyp med en standardkonvertering kan inte matcha en tom parameternamnlistdeklaration"
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "prototypen för %q+D deklarerar fler argument än tidigare gammaldags definition"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "prototypen för %q+D deklarerar färre argument än tidigare gammaldags definition"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr "prototypen för %q+D deklarerar argument %d med inkompatibel typ"
@@ -27863,42 +27894,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "prototyp för %q+D följer på en icke-prototypdefinition"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "tidigare definition av %q+D var här"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "tidigare implicit deklaration av %q+D var här"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "tidigare deklaration av %q+D var här"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "%q+D omdeklarerad som en annan sorts symbol"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "inbyggd funktion %q+D deklarerad som icke-funktion"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "deklaration av %q+D skuggar en inbyggd funktion"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "omdeklaration av uppräkningstyp %q+D"
@@ -27906,340 +27937,340 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "motstridiga typer på inbyggd funktion %q+D"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "motstridiga typer på %q+D"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr "motstridiga namngivna adressrymder (generisk respektive %s) för %q+D"
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr "motstridiga namngivna adressrymder (%s respektive generisk) för %q+D"
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr "motstridiga namngivna adressrymder (%s respektive %s) för %q+D"
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "motstridiga typkvalificerare för %q+D"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
-msgstr "omdefiniering av typedef %q+D med annan typ"
+msgstr "omdefinition av typedef %q+D med annan typ"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "omdefinition av typedef %q+D med variabelt modifierad typ"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D"
-msgstr "omdefiniering av typedef %q+D"
+msgstr "omdefinition av typedef %q+D"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, gcc-internal-format
 msgid "redefinition of %q+D"
-msgstr "omdefiniering av %q+D"
+msgstr "omdefinition av %q+D"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "statisk deklaration av %q+D följer på icke-statisk deklaration"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "icke-statisk deklaration av %q+D följer på statisk deklaration"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr "attribut %<gnu_inline%> finns på %q+D"
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, gcc-internal-format
 msgid "but not here"
 msgstr "men inte här"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "trådlokal deklaration av %q+D följer på icke trådlokal deklaration"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "icke trådlokal deklaration av %q+D följer på trådlokal deklaration"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "extern deklaration av %q+D följer på deklaration utan länkklass"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "deklaration av %q+D utan länkklass följer på extern deklaration"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "omdeklaration av %q+D utan länkklass"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr "omdeklaration av %q+D med annan synlighet (gammal synlighet bevarad)"
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "inline-deklaration av %qD följer på deklaration med attributet noinline"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "deklaration av %q+D med attributet noinline följer på inline-deklaration"
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "deklarationen av %q+D med attributet %qs följer på en deklaration med attributet %qs "
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, gcc-internal-format
 msgid "redefinition of parameter %q+D"
-msgstr "omdefiniering av parametern %q+D"
+msgstr "omdefinition av parametern %q+D"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "redundant omdeklaration av %q+D"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "deklaration av %q+D skuggar tidigare icke-variabel"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr "deklaration av %q+D skuggar en parameter"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "deklaration av %qD skuggar en global deklaration"
 
 # local, det kan vara både lokal variabel och lokal funktionsdeklartion
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "deklaration av %q+D skuggar en tidigare lokal deklaration"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "skuggad deklaration är här"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "nästad extern-deklaration av %qD"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "implicit deklaration av funktionen %qE"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "inkompatibel implicit deklaration av inbyggd funktion %qD"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "inkludera %qs eller ge en deklaration av %qD"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "inkompatibel implicit deklaration av funktionen %qD"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE är odeklarerad här (inte i en funktion)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE är odeklarerad (första förekomsten i denna funktion)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "varje odeklarerad identifierare rapporteras bara en gång för varje funktion den förekommer i"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "etikett %qE är refererad till utanför någon funktion"
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "hopp in i räckvidd för identifierare med variabel typ"
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "hoppar över variabelinitiering"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "etikett %qD är definierad här"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD är deklarerad här"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "hopp in i satsuttryck"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "dubbel deklaration av etikett %qE"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "dubblerad etikett %qD"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "traditionell C saknar en separat namnrymd för etiketter, identifierare %qE står i konflikt"
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "switch hoppar över variabelinitieringar"
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "switch börjar här"
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "switch hoppar in i satsuttryck"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE definierad som fel sorts tagg"
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "odöpt struktur/union som inte har någon instans"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "tom deklaration med specificerare av lagringsklass deklarerar inte om tagg"
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "tom deklaration med typkvalificerare deklarerar inte om en tagg"
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "tom deklaration med %<_Alignas%> deklarerar inte om en tagg"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "oanvändbart typnamn i tom deklaration"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> i tom deklaration"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<_Noreturn%> i tom deklaration"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> tom deklaration på filnivå"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> i tom deklaration på filnivå"
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "oanvändbar specificerare av lagringsklass i tom deklaration"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "oanvändbar %qs i tom deklaration"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "oanvändbar typkvalificerare i tom deklaration"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "oanvändbar %<_Alignas%> i tom deklaration"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "tom deklaration"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 stödjer inte %<static%> eller typkvalificerare i parametervektordeklarerare"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 stödjer inte %<[*]%>-vektordeklarerare"
@@ -28247,38 +28278,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> är inte tillåtet annat än inom en funktionsprototyp"
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr "%q+D i blockräckvidd inuti ett deklarationsmålsdirektiv"
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D i deklarationsmålsdirektiv har inte en avbildbar typ"
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D är vanligtvis en funktion"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "typedef %qD är initierad (använd __typeof__ istället)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "funktionen %qD är initierad som en variabel"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "parametern %qD är initierad"
@@ -28287,257 +28318,257 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "objekt med variabel storlek kan inte initieras"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "variabeln %qD har initierare men ofullständig typ"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "inline-funktionen %q+D har fått attributet noinline"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "oinitierad const-medlem i %qT är ogiltigt i C++"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD borde initieras"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "initierare misslyckas med att bestämma storleken på %q+D"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "vektorstorlek saknas i %q+D"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "noll eller negativ storlek på vektorn %q+D"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "lagringsstorlek på %q+D är inte konstant"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "ignorerar asm-specificerare för ickestatisk lokal variabel %q+D"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "kan inte lägga objekt med volatile-fält i register"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, gcc-internal-format
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "oinitierad const %qD är ogiltig i C++"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C förbjuder framåtdeklaration av parametrar"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "att definiera en typ i en sammansatt literal är ogiltigt i C++"
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "bredden på bitfältet %qs är inte en heltalskonstant"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "bredden på bitfältet %qs är inte ett konstant heltalsuttryck"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "negativ storlek i bitfält %qs"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "storlek noll på bitfält %qs"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "bitfältet %qs har ogiltig typ"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "typen på bitfältet %qs är en GCC-utvidgning"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "bredden på %qs är större än sin typ"
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs är smalare än värdena av sin typ"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 förbjuder vektor %qE vars storlek inte kan beräknas"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 förbjuder vektorer vars storlek inte kan beräknas"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 förbjuder vektor %qE med variabel längd"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 förbjuder vektorer med variabel längd"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "variabelt ändrad %qE i filräckvidd"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "variabelt ändrat fält i filräckvidd"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "typen sätts skönsmässigt till %<int%> i deklarationen av %qE"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "typen sätts skönsmässigt till %<int%> i typnamnet"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "dubblerat %<const%>"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "dubblerad %<restrict%>"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "dubblerad %<volatile%>"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "dubblerad %<_Atomic%>"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "motstridande namngivna adressrymder (%s respektive %s)"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "%<_Atomic%>-kvalificerad vektortyp"
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "funktionsdefinition deklarerad som %<auto%>"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "funktionsdefinition deklarerad som %<register%>"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "funktionsdefinition deklarerad som %<typedef%>"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "funktionsdefinition deklarerad som %qs"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "lagringsklass angiven för postfält %qE"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "lagringsklass angiven för postfält"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "lagringsklass angiven för parameter %qE"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "lagringsklass angiven för namnlös parameter"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "lagringsklass angiven för typnamn"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE initierad och deklarerad %<extern%>"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE har både %<extern%> och initierare"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "filnivådeklaration av %qE anger %<auto%>"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "filnivådeklaration av %qE anger %<register%>"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "nästad funktion %qE är deklarerad %<extern%>"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "%qE i funktions definitionsområde är implicit auto och deklarerad %qs"
@@ -28545,683 +28576,683 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static- eller typkvalificerare i vektordeklarerare som inte är parameter"
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "deklaration av %qE som en vektor av void"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "deklaration av typnamn som en vektor av void"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "deklaration av %qE som en vektor av funktioner"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "deklaration av typnamn som en vektor av funktioner"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ogiltig användning av post med flexibel vektormedlem"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "storlek på vektorn %qE är inte av heltalstyp"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "storlek på en namnlös vektor är inte av heltalstyp"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C förbjuder vektor %qE med storlek noll"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C förbjuder vektorer med storlek noll"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "storleken på vektorn %qE är negativ"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "storleken på en namnlös vektor är negativ"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "storleken på vektorn %qE är för stor"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "storleken på en namnlös vektor är för stor"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 stödjer inte flexibla vektormedlemmar"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> är inte i en deklaration"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "vektortyp har ofullständig elementtyp %qT"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE är deklarerad som en funktion som returnerar en funktion"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "typnamn är deklarerat som en funktion som returnerar en funktion"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE är deklarerad som en funktion som returnerar en vektor"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "typnamn är deklarerat som en funktion som returnerar en vektor"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "funktionsdefinition som har kvalificerad void-returtyp"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typkvalificerare ignoreras för funktions returtyp"
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "%<_Atomic%>-kvalificerad funktionstyp"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C förbjuder kvalificerade funktionstyper"
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs kombinerad med %<auto%>-kvalificerare för %qE"
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs kombinerat med %<register%>-kvalificerare för %qE"
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs angiven för auto-variabel %qE"
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs angiven för parameter %qE"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs angiven för namnlös parameter"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs angiven för postfält %qE"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs angiven för postfält"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "bitfältet %qE har atomär typ"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "bitfältet har atomär typ"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "minnesjustering angiven för typedef %qE"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "minnesjustering angiven för %<register%>-objekt %qE"
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "minnesjustering angiven för parameter %qE"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "minnesjustering angiven för namnlös parameter"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "minnesjustering angiven för bitfältet %qE"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "minnesjustering angiven för namnlöst bitfält"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "minnesjustering angiven för funktionen %qE"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "%<_Alignas%>-specificerare kan inte reducera justeringen hos %qE"
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "%<_Alignas%>-specificerare kan inte reducera justeringen för namnlösa fält"
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typdef %q+D deklarerad %<inline%>"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D deklarerad %<_Noreturn%>"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C förbjuder const- eller volatile-funktionstyper"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "en medlem av an post eller union får inte ha variabel typ"
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabel eller fält %qE deklarerad void"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "attribut i parametervektordeklarerare ignoreras"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "parametern %q+D deklarerad %<inline%>"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "parametern %q+D deklarerad %<_Noreturn%>"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "fältet %qE deklarerat som en funktion"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "fält %qE har ofullständig typ"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "namnlöst fält har ofullständig typ"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "ogiltig lagringsklass för funktionen %qE"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "kan inte inline:a funktionen %<main%>"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> deklarerad %<_Noreturn%>"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 stödjer inte %<_Noreturn%>"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 stödjer inte %<_Noreturn%>"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "variabel tidigare deklarerad %<static%> omdeklarerad som %<extern%>"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "variabeln %q+D deklarerad %<inline%>"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "variabeln %q+D deklarerad %<_Noreturn%>"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "onästad funktion med variabelt modifierad typ"
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "objekt med variabel typ får inte ha länkklass"
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "funktionsdeklarationen är inte en prototyp"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "parameternamn (utan typer) i funktionsdeklaration"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "parameter %u (%q+D) har ofullständig typ"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "parameter %u har ofullständig typ"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "parameter %u (%q+D) har void-typ"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "parameter %u har void-typ"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> som enda parameter kan inte kvalificeras"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> måste vara den enda parametern"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "parameter %q+D har endast en framåtdeklaration"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "%<%s %E%> deklarerad inuti parameterlista"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "anonym %s deklarerad inuti parameterlista"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "dess scope-område är endast denna definition eller deklaration, vilket troligen inte är vad du vill."
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "enum-typ definierad här"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "post definierad här"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "union definierad här"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "omdefinition av %<union %E%>"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "omdefinition av %<struct %E%>"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "nästad omdefinition av %<union %E%>"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "nästad omdefinition av %<struct %E%>"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "att definiera en typ i %qs-uttryck är ogiltigt i C++"
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "deklaration som inte deklarerar något"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 stödjer inte namnlösa strukturer/unioner"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 stödjer inte namnlösa strukturer/unioner"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "dubblerad medlem %q+D"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "unionen har inga namngivna medlemmar"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "unionen har inga medlemmar"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "posten har inga namngivna medlemmar"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "posten har inga medlemmar"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibel vektormedlem i union"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "flexibel vektormedlem inte vid slutet av post"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr "flexibel vektor medlem i i övrigt tom post"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "typen %qT är för stor"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "unionen kan inte göras transparent"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "nästad omdefinition av %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "omdeklaration av %<enum %E%>"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "uppräkningsvärden överskrider gränsen för största heltal"
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "angiven sort för liten för uppräkningvärden"
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "uppräkningsvärde för %qE är inte en heltalskonstant"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "uppräkningsvärde för %qE är inte ett konstant heltalsuttryck"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "överspill i uppräkningsvärden"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C begränsar uppräkningsvärden till intervallet hos %<int%>"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "inline-funktionen %qD har fått attributet noinline"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "returtypen är en ofullständig typ"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "returtyp sätts skönsmässigt till %<int%>"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "ingen tidigare prototyp för %qD"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD användes utan någon prototyp före sin definition"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidigare deklaration av %qD"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD användes utan någon deklaration före sin definition"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "returtypen för %qD är inte %<int%>"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "%<_Atomic%>-kvalificerad returtyp till för %qD"
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD är normalt en icke-statisk funktion"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "gammaldags parameterdeklarationer i funktionsdefinition med prototyp"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "traditionell C tillåter inte ISO C:s stil av funktionsdefinitioner"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "parameternamn utelämnat"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "gammaldags funktionsdefinition"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "parameternamn saknas i parameterlista"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD deklarerad som en icke-parameter"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "flera parametrar med namnet %qD"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "parameter %qD deklarerad med typen void"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "typen på %qD sätts skönsmässigt till %<int%>"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "parametern %qD har ofullständig typ"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "deklaration av parameter %qD med det finns ingen sådan parameter"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "antalet argument stämmer inte med inbyggd prototyp"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "antalet argument stämmer inte med prototypen"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "prototypdeklaration"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "befordrat argument %qD stämmer inte med inbyggd prototyp"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "befordrat argument %qD stämmer inte med prototypen"
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argument %qD stämmer inte med inbyggd prototyp"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qD stämmer inte med prototypen"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen retursats i funktion som returnerar icke-void"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametern %qD sätts men används inte"
@@ -29229,197 +29260,197 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%>-slinga med startdeklaration är endast tillåtet i C99- och C11-läge"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "använd flaggan -std=c99, -std=gnu99, -std=c11 eller -std=gnu11 för att kompilera din kod"
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av statisk variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av %<extern%>-variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av icke-variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "inkompatibla adressrymdskvalificerare %qs och %qs"
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "dubblerad %qE"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "två eller fler datatyper i deklaration av specificerare"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> är för långt för GCC"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 stödjer inte %<long long%>"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 stödjer inte komplexa typer"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C stödjer inte mättning av typer"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C stödjer inte typen %<__int%d%>"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> stödjs inte för denna målarkitektur"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 stödjer inte booleska typer"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C stödjer inte decimala flyttal"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "fixdecimaltyper stödjs inte för denna målarkitektur"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C stödjer inte fixdecimaltyper"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "C++-uppslagning av %qD skulle returnera ett fält, inte en typ"
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE är varken en typedef eller en inbyggd typ"
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE är inte i början av deklarationen"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE använd med %<auto%>"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE använd med %<register%>"
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE använd med %<typedef%>"
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 stödjer inte %qE"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 stödjer inte %qE"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> före %<extern%>"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> före %<static%>"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "dubblerat %<_Thread_local%> eller %<__thread%>"
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "flera lagringsklasser i deklarationsspecificerare"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs använd med %qE"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> används utan %<_Fract%> eller %<_Accum%>"
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C stödjer inte bara %<complex%> i meningen %<double complex%>"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C stödjer inte komplexa heltalstyper"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%>-kombinerare refererar variabeln %qD som inte är varken %<omp_out%> eller %<omp_in%>"
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%>-initierare refererar till variabeln %qD som inte är varken %<omp_priv%> eller %<omp_orig%>"
@@ -29429,7 +29460,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr "identifieraren %qE står i konflikt med ett nyckelord i C++"
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "oväntat radslut"
@@ -29449,8 +29480,8 @@
 msgid "unknown type name %qE"
 msgstr "okänt typnamn %qE"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "deklarationsspecificerare förväntades"
@@ -29465,7 +29496,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, identifierare eller %<(%> förväntades"
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "prefixattribut ignoreras för metoder"
@@ -29541,7 +29572,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 stödjer inte %<_Static_assert%>"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "strängkonstant förväntades"
@@ -29598,14 +29629,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "identifierare förväntades"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma i slutet av uppräkningslista"
@@ -30054,32 +30085,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr "ingen typ eller lagringsklass kan anges här,"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "okänt egenskapsattribut"
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<=%> saknas (efter attributet %<getter%>)"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<=%> saknas (efter attributet %<setter%>)"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "attributet %<setter%> kan bara anges en gång"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter-namn måste avslutas med %<:%>"
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "attributet %<getter%> kan bara anges en gång"
@@ -30089,47 +30120,47 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr "%<#pragma acc update%> får bara användas i sammansatta satser"
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> får bara användas i sammansatta satser"
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> får bara användas i sammansatta satser"
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> får bara användas i sammansatta satser"
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr "%<#pragma omp taskyield%> får bara användas i sammansatta satser"
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr "%<#pragma omp cancel%> får bara användas i sammansatta satser"
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr "%<#pragma omp cancellation point%> får bara användas i sammansatta satser"
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> får bara användas i %<#pragma omp sections%>-konstruktion"
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- eller do-sats förväntades"
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> måste komma först"
@@ -30144,12 +30175,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "%<#pragma grainsize%> måste vara inuti en funktion"
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "för många %qs-klausuler"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "heltalsuttryck förväntades före ”)”"
@@ -30159,27 +30190,27 @@
 msgid "expression must be integral"
 msgstr "uttrycket måste vara ett heltal"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, gcc-internal-format
 msgid "%qD is not a constant"
 msgstr "%qD är inte en konstant"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD är inte en variabel"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD är inte en pekarvariabel"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "collapse-argument behöver ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> eller %<shared%> förväntades"
@@ -30211,17 +30242,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> eller %<max%> förväntades"
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "%<runtime%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "%<auto%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ogiltig schedule-sort"
@@ -30241,12 +30272,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<thread_limit%>-värdet måste vara positivt"
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%<aligned%>-klausulens justeringsuttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr "att använda parametrar för %<linear%>-steg stödjs inte än"
@@ -30266,17 +30297,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%<simdlen%>-klausulens uttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ogiltig depend-sort"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "ogiltig map-sort"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ogiltig dist_schedule-sort"
@@ -30286,57 +30317,57 @@
 msgid "invalid proc_bind kind"
 msgstr "ogiltig proc_bind-sort"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "%<#pragma acc%>-klausul förväntades"
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs är inte giltigt för %qs"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs måste vara den första klausulen i %qs"
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%<#pragma omp%>-klausul förväntades"
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr "%<data%> förväntades i %<#pragma acc enter data%>"
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, gcc-internal-format
 msgid "invalid pragma"
 msgstr "ogiltigt pragma"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr "%<#pragma acc enter data%> har ingen dataflyttningsklausul"
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr "%<#pragma acc update%> måste innehålla åtminstone en %<device%>- eller %<host/self%>-klausul"
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ogiltig form på %<#pragma omp atomic%>"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ogiltig operator för %<#pragma omp atomic%>"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> använder två olika uttryck till minne"
@@ -30346,17 +30377,17 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> eller filslut förväntades"
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for-sats förväntades"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "_Cilk_for-sats förväntades"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "iterationsdeklaration eller initiering förväntades"
@@ -30366,237 +30397,237 @@
 msgid "not enough perfectly nested loops"
 msgstr "inte tillräckligt med perfekt nästade slingor"
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "kollapsade slingor inte perfekt nästade"
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterationsvariabel %qD får inte vara firstprivate"
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> förväntades efter %qs"
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> förväntades"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr "%<#pragma omp target update%> får bara användas i sammansatta satser"
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
-msgstr "%<#pragma omp target update måste innehålla åtminstone en %<from%>- eller %<to%>-klausul"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
+msgstr "%<#pragma omp target update%> måste innehålla åtminstone en %<from%>- eller %<to%>-klausul"
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr "%<#pragma omp declare simd%> måste följas av funktionsdeklaration eller -definition eller en annan %<#pragma omp declare simd%>"
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> måste följas av en funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr "%<#pragma omp declare simd%> kan inte användas i samma funktion som är markerad som en Cilk Plus SIMD-aktiverad funktion"
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%> som inte omedelbart följs av en funktionsdefinition eller -deklaration"
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%> som inte omedelbart följs av en ensam funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> förväntades"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> förväntades"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> utan en motsvarande %<#pragma omp declare target%>"
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "%<#pragma omp declare reduction%> inte på file- eller blockräckvidd"
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> eller identifierare förväntades"
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr "fördeklarerad aritmetisk typ i %<#pragma omp declare reduction%>"
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr "funktions- eller vektortyp i %<#pragma omp declare reduction%>"
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr "const-, volatile- eller restrict-kvalificerad typ i %<#pragma omp declare reduction%>"
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr "omdeklaration av %qs %<#pragma omp declare reduction%> för typen %qT"
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "tidigare %<#pragma omp declare reduction%>"
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "%<omp_priv%> eller funktionsnamn förväntades"
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "funktionsnamn %<(%> förväntades"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "en av initierarens anropsargument skall vara %<&omp_priv%>"
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<simd%> eller %<reduction%> eller %<target%> förväntades"
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE är deklarerad %<threadprivate%> efter första användningen"
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatisk variabel %qE kan inte vara %<threadprivate%>"
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE har ofullständig typ"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr "pragma simd ignoreras för att -fcilkplus inte är aktiverat"
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, gcc-internal-format
 msgid "pragma simd must be inside a function"
 msgstr "pragma simd måste vara inuti en funktion"
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "vektorlängd måste vara en heltalskonstant"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr "vektorlängd måste vara en potens av 2"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "stegstorleken måste vara ett konstant heltalsuttryck eller en heltalsvariabel"
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "%<#pragma simd%>-klausul förväntades"
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma cilk grainsize%> följs inte av %<_Cilk_for%>"
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> utan att stöd för transaktionsminne är aktiverat"
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> inom en %<__transaction_relaxed%>"
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "yttre %<__transaction_cancel%> som inte är inom en yttre %<__transaction_atomic%>"
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  eller en %<transaction_may_cancel_outer%>-funktion"
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> inte inom %<__transaction_atomic%>"
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, gcc-internal-format
 msgid "base of array section must be pointer or array type"
 msgstr "basen av vektorsektionen måste vara en pekar- eller vektortyp"
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "%<:%> eller tal förväntades"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr "startindex och längdfält är nödvändiga för att använda vektornotationer i pekare"
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, gcc-internal-format
 msgid "array notations cannot be used with function type"
 msgstr "vektornotationer kan inte användas med en funktionstyp"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr "startindex och längdfält är nödvändiga för att använda vektornotationer i dimensionslösa vektorer"
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr "startindex och längdfält är nödvändiga för att använda vektornotationer i vektorer med variabel längd"
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, gcc-internal-format
 msgid "expected array notation expression"
 msgstr "vektornotationsuttryck förväntades"
@@ -30606,7 +30637,7 @@
 msgid "%qD has an incomplete type"
 msgstr "%qD har en ofullständig typ"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ogiltig användning av void-uttryck"
@@ -30712,7 +30743,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indexerat värde är varken en vektor eller pekare"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "fältindex är inte ett heltal"
@@ -30835,7 +30866,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "skickar argument %d till %qE med tecken på grund av prototyp"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "implicit konvertering från %qT till %qT när argument skickas till en funktion"
@@ -30865,7 +30896,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmetik på pekare till ofullständig typ"
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "aritmetik på pekare till ett tomt aggregat"
@@ -30950,7 +30981,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "icke-l-värde-vektor i villkorsuttryck"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "implicit konvertering från %qT till %qT för att stämma med andra resultat i villkor"
@@ -30985,7 +31016,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "pekar-/heltalstyper stämmer inte  i villkorsuttryck"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr "ett avynglat funktionsanrop får inte finnas i ett kommauttryck"
@@ -31068,7 +31099,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "typkonvertering från funktionsanrop av typ %qT till typ %qT matchar inte"
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "typkonvertering till pekare från heltal med annan storlek"
@@ -31221,7 +31252,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "vänsterhandssida av initiering kan vara en kandidat för ett formatattribut"
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "returtypen kan vara en kandidat för ett formatattribut"
@@ -31358,7 +31389,7 @@
 msgid "initialization of a flexible array member"
 msgstr "initiering av medlem som är en flexibel vektor"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-vektor initierad från bred sträng"
@@ -31404,7 +31435,7 @@
 msgid "invalid initializer"
 msgstr "ogiltig initierare"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "ogenomskinliga vektortyper kan inte initieras"
@@ -31549,7 +31580,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C förbjuder %<goto *expr;%>"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "funktion deklarerad %<noreturn%> har en %<return%>-sats"
@@ -31559,7 +31590,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "vektornotationsuttryck kan inte användas som ett returvärde"
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr "användning av %<_Cilk_spawn%> i en retursats är inte tillåtet"
@@ -31664,17 +31695,17 @@
 msgid "expression statement has incomplete type"
 msgstr "uttryckssats har ofullständig typ"
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "jämför vektorer med skilda elementtyper"
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "jämför vektorer med olika antal element"
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "jämföra flyttal med == eller != är osäkert"
@@ -31725,12 +31756,12 @@
 msgstr "ordningsjämförelse av pekare med nollpekare"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "ordningsjämförelse av pekare med heltalet noll"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "implicit konvertering från %qT till %qT för att matcha den andra operanden i binärt uttryck"
@@ -31755,85 +31786,85 @@
 msgid "used vector type where scalar is required"
 msgstr "vektortyp använd där skalär krävs"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD är inte en variabel i en %qs-klausul"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE är inte en variabel i en %qs-klausul"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD är en trådprivat variabel i en %qs-klausul"
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "undre gränsen %qE i vektorsektion har inte heltalstyp"
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "längden %qE i vektorsektion har inte heltalstyp"
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "för en vektor med okänd gräns måste ett längduttryck anges"
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "negativ nedre gräns i vektorsektion i %qs-klausul"
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "negativ längd i vektorsektion i en %qs-klausul"
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "nedre gränsen %qE över storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "längden %qE över storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "övre gräns %qE ovanför storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "för pekartyper måste ett längduttryck anges"
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "vektorsektionen är inte sammanhängande i %qs-klausulen"
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE har inte pekar- eller vektortyp"
@@ -31843,17 +31874,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE har ogiltig typ för %<reduction(%s)%>"
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr "ingen användardefinierad reduktion funnen för %qD"
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "en %<nowait%>-klausul får inte användas tillsammans med %<copyprivate%>"
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE måste vara %<threadprivate%> för %<copyin%>"
@@ -31863,7 +31894,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr "en linjär klausul använd på variabel som inte är heltal och inte pekare med typen %qT"
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE är inte en variabel i klausul %qs"
@@ -31873,17 +31904,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE förekommer mer än en gång i dataklausuler"
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE är inte en variabel i klausul %<firstprivate%>"
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE är inte en variabel i klausul %<lastprivate%>"
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE är inte en variabel i %<aligned%>-klausul"
@@ -31898,47 +31929,47 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE förekommer mer än en gång i %<aligned%>-klausuler"
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE är inte en variabel i en %<depend%>-klausul"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "vektorsektionen har inte en avbildbar typ i %qs-klausulen"
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD har inte en avbildbar typ i %qs-klausul"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD förekommer mer än en gång i rörelseklausuler"
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD förekommer mer än en gång i avbildningsklausuler"
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD är inte en ett argument i en %<uniform%>-klausul"
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE är inte ett argument i en %<uniform%>-klausul"
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "en %<inbranch%>-klausul är inkompatibel med %<notinbranch%>"
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE är förutbestämd som %qs för %qs"
@@ -31949,33 +31980,33 @@
 msgstr "C++ kräver en befordrad typ, inte en uppräkningstyp, i %<va_arg%>"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "  att skicka %qT som %<this%>-argument kastar kvalificerare"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr "  ingen känd konvertering för implicit %<this%>-parameter från %qT till %qT"
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "  konvertering av argument %d vore felformaterat:"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, gcc-internal-format
 msgid "  no known conversion from %qT to %qT"
 msgstr "  ingen känd konvertering från %qT till %qT"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, gcc-internal-format
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "  ingen känd konvertering för argument %d från %qT till %qT"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -31982,83 +32013,83 @@
 msgstr[0] "  kandidaten förväntade sig %d argument, %d fanns"
 msgstr[1] "  kandidaten förväntade sig %d argument, %d fanns"
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, gcc-internal-format
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr "%s%D(%T, %T, %T) <inbyggd>"
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, gcc-internal-format
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "%s%D(%T, %T) <inbyggd>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, gcc-internal-format
 msgid "%s%D(%T) <built-in>"
 msgstr "%s%D(%T) <inbyggd>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, gcc-internal-format
 msgid "%s%T <conversion>"
 msgstr "%s%T <konvertering>"
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr "%s%#D <nära träff>"
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr "%s%#D <raderad>"
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr "%s%#D"
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr "  returtypen %qT för en explicit konverteringsfunktion kan inte konverteras till %qT utan en kvalificerarkonvertering"
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr "  konvertering från returtypen %qT för specialiceringen av mallkonverteringsfunktionen till %qT är inte en exakt matchning"
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr "  substituering av härledda mallargument resulterade i felen som visas ovan"
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "  mallargumentshärledning/-substitution misslyckades:"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr "  en konstruerare som tar ett ensamt argument av sin egen klasstyp är felaktig"
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "konvertering från %qT till %qT är tvetydig"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, gcc-internal-format
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr "konvertering från %qT till %qT övervägs inte för mallargument som inte är en typ"
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "ingen funktion som stämmer för anrop av %<%D(%A)%>"
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "anrop av överlagrad %<%D(%A)%> är tvetydigt"
@@ -32065,457 +32096,457 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr "pekar-på-medlem-funktion %E kan inte anropas utan ett objekt, överväg att använda .* eller ->*"
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "ingen träff för anrop till %<(%T) (%A)%>"
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "anrop av %<(%T) (%A)%> är tvetydigt"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "tvetydig överlagring för "
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, gcc-internal-format
 msgid "no match for "
 msgstr "ingen matchning för "
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (operandtyper är %qT, %qT och %qT)"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (operandtyper är %qT och %qT)"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (operandtyp är %qT)"
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "treställig %<operator?:%>"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "treställig %<operator?:%> i %<%E ? %E : %E%>"
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> i %<%E%s%>"
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> i %<%E[%E]%>"
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs i %<%s %E%>"
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> i %<%E %s %E%>"
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> i %<%s%E%>"
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ förbjuder uteslutande av mittersta termen i ett ?: uttryck"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr "den härledda skalära typen %qT är inte en heltals- eller flyttalstyp av samma storlek som %qT"
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "inkompatibla vektortyper i villkorsuttryck: %qT, %qT och %qT"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "andra operanden till villkorsoperatorn är av typ %<void%>, men den tredje operanden är varken ett throw-uttryck eller av typ %<void%>"
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "tredje operanden till villkorsoperatorn är av typ %<void%>, men den andra operanden är varken ett throw-uttryck eller av typ %<void%>"
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "operander till ?: har olika typer %qT och %qT"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr "  och båda typerna kan konverteras till den andra"
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "uppräkningsmissmatch i villkorsuttryck: %qT kontra %qT"
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "uppräknings- och inte uppräkningstyp i villkorsuttryck"
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "ingen %<%D(int)%> deklarerad för postfix %qs, försöker med prefixoperator istället"
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "ingen %<%D(int)%> deklarerad för postfix %qs"
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "jämförelse mellan %q#T och %q#T"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, gcc-internal-format
 msgid "non-placement deallocation function %q+D"
 msgstr "avallokeringsfunktion utan placering %q+D"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr "vald för placerad delete"
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "ingen motsvarande avallokeringsfunktion för %qD"
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "ingen passande %<operator %s%> för %qT"
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr "%q+#D är privat"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr "%q+#D är skyddad"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr "%q+#D är oåtkomlig"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr "i denna kontext"
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "skickar NULL till icke-pekarargument %P till %qD"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "konverterar till icke-pekartyp %qT från NULL"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "konverterar %<false%> till pekartyp för argument %P till %qD"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "konverterar %<false%> till pekartyp %qT"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "för många klamrar runt initierare för %qT"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, gcc-internal-format
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr "konvertering till %qT från %qT behöver en direktinitiering"
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, gcc-internal-format
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "ogiltig användardefinierad konvertering från %qT till %qT"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  initierar argument %P till %qD"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "ogiltig konvertering från %qT till %qT"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "att konvertera till %qT från initierarlista skulle använda den explicita konstrueraren %qD"
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, gcc-internal-format
 msgid "  initializing argument %P of %q+D"
 msgstr "  initierar argument %P till %q+D"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, gcc-internal-format
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "det går inte att binda l-värde %qT till %qT"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "ogiltig initiering av icke konstant referens av typ %qT från ett r-värde av typ %qT"
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, gcc-internal-format
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "att binda %qT till referens till typen %qT kastar kvalificerare"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "det går inte att binda bitfält %qE till %qT"
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "det går inte att binda packat fält %qE till %qT"
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "det går inte att binda rvalue %qE till %qT"
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr "enum %qT med räckvidd skickad vidare … som %qT före -fabi-version=6, %qT efter"
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "att skicka objekt av ej trivialt kopierbar typ %q#T via %<...%> är villkorligt stött"
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "det går inte att referera typen %qT via %<...%>"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "att ta emot objekt av ej trivialt kopierbar typ %q#T via %<...%> är villkorligt stött"
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "rekursiv beräkning av standardargument till %q#D"
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "anrop till %qD använder standardargumentet för parameter %P, vilket inte definierats ännu"
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "argument till funktionsanrop kan vara en kandidat för ett formatattribut"
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "användning av multiversionsfunktion utan ett standardfall"
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "att skicka %qT som %<this%>-argument kastar kvalificerare"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  i anrop till %qD"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT är inte en åtkomlig bas till %qT"
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "härleder %qT som %qT"
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, gcc-internal-format
 msgid "  in call to %q+D"
 msgstr "  i anrop till %q+D"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (du kan avaktivera detta med -fno-deduce-init-list)"
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr "kunde inte hitta class$-fält i java-gränssnittstyp %qT"
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "konstruerare delegerar till sig själv"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "anrop av icke-funktion %qD"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan inte anropa konstrueraren %<%T::%D%> direkt"
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "för en typkonvertering i funktionsstil, ta bort det överflödiga %<::%D%>"
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "ingen matchande funktion för anrop av %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr "ingen matchande funktion för anrop av %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "ingen funktion som stämmer för anrop av %<%s(%A)%>"
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "anrop av överlagrad %<%s(%A)%> är tvetydigt"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "pure virtual %q#D anropad från initierare av ickestatisk datamedlem"
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "det går inte att anropa medlemsfunktion %qD utan ett objekt"
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "att skicka %qT väljer %qT framför %qT"
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "väljer %qD framför %qD"
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  för konvertering från %qT till %qT"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  för att konverteringssekvensen för argumentet är bättre"
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "standardargument stämmer inte överens i upplösning av överlagring"
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr " kandidat 1: %q+#F"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr " kandidat 2: %q+#F"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ säger att dessa är tvetydiga, trots att den sämsta konverteringen för den första är bättre än den sämsta konverteringen för den andra:"
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "kunde inte konvertera %qE från %qT till %qT"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "en temporär bunden till %qD består endast tills konstrueraren avslutar"
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "ogiltig initiering av referens av typ %qT från uttryck av typ %qT"
@@ -32671,7 +32702,7 @@
 msgid "  by %q+D"
 msgstr "  av %q+D"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D ogiltig, en anonym union kan bara ha ickestatiska datamedlemmar"
@@ -32681,7 +32712,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D ogiltig, en anonym post kan bara ha ickestatiska datamedlemmar"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr "privat medlem %q+#D i anonym union"
@@ -32691,7 +32722,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "privat medlem %q+#D i anonym post"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr "skyddad medlem %q+#D i anonym union"
@@ -32821,67 +32852,77 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  men ersätter inte %<operator=(const %T&)%>"
 
-#: cp/class.c:4538
+#: cp/class.c:4300
 #, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr "justeringen av %qD ökade i -fabi-version=9 (GCC 5.2)"
+
+#: cp/class.c:4303
+#, gcc-internal-format
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr "justering av %qD kommer öka med -fabi-version=9"
+
+#: cp/class.c:4557
+#, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "initierare angiven för icke-virtuell metod %q+D"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "metoden åsidosätter både metoderna %<transaction_pure%> och %qE"
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "metod deklarerad %qE åsidosätter %qE-metod"
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "omslutande klass till constexpr icke-statisk medlemsfunktion %q+#D är inte en literal typ"
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T är inte literal för att:"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T har en icke-trivial destruerare"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr "  %q+T är inte ett aggregat, har inte en trivial standardkonstruerare och har ingen constexpr-konstruerare som inte är en kopierings- eller flyttningskonstruerare"
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  basklassen %qT till %q+T är inte literal"
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, gcc-internal-format
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "  den icke-statiska datamedlemmen %q+D har icke-literal typ"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, gcc-internal-format
 msgid "  non-static data member %q+D has volatile type"
 msgstr "  den icke-statiska datamedlemmen %q+D har volatile typ"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "basklassen %q#T har en åtkomlig icke-virtuell destruerare"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr "icke-statisk referens %q+#D i klass utan en konstruerare"
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr "icke-statisk const-medlem %q+#D i klass utan en konstruerare"
@@ -32888,102 +32929,102 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D deklarerad att ta const-referens, men implicit deklaration skulle ta icke-const"
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkt bas %qT är oåtkomlig i %qT på grund av tvetydighet"
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuell bas %qT är oåtkomlig i %qT på grund av tvetydighet"
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr "förskjutningen av %q+D följer inte ABI:et och kan ändras i en framtida version av GCC"
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "omdefinition av %q#T"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T har virtuella funktioner och åtkomlig ickevirtuell destruerare"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "typgenomskinliga %q#T har inga fält"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "den typgenomskinliga klassen %qT har basklasser"
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "den typgenomskinliga klassen %qT har virtuella funktioner"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "typtransparenta %q#T kan inte göras transparent eftersom typen på första fältet har ett annat ABI än klassen som helhet"
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "definitionen av std::initializer_list matchar inte #include <initializer_list>"
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "försökte avsluta post, men hoppade ut på grund av tidigare parsningsfel"
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "språksträng %<”%E”%> känns inte igen"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "det går inte att lösa upp överlagrad funktion %qD baserat på konvertering till typ %qT"
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "ingen match som konverterar funktionen %qD till typen %q#T"
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "konvertering av överlagrad funktion %qD till typ %q#T är tvetydig"
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "antar pekare till medlem %qD"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(en pekare på medlem kan bara skapas med %<&%E%>)"
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "inte tillräcklig typinformation"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "kan inte konvertera %qE från typ %qT till typ %qT"
@@ -32993,12 +33034,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "deklaration av %q#D"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr "byter betydelse av %qD från %q+#D"
@@ -33038,254 +33079,254 @@
 msgid "constexpr constructor does not have empty body"
 msgstr "constexpr-konstruerare har inte tom kropp"
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr "kroppen av %<constexpr%>-konstruerare kan inte vara ett function-try-block"
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "%<constexpr%>-konstrueraren för unionen %qT måste initiera precis en icke statisk datamedlem"
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "medlemmen %qD måste initieras av en mem-initierare i %<constexpr%>-konstruerare"
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "kroppen i constexpr-funktionen %qD är inte en retursats"
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr "%q+D är inte användbar som en constexpr-funktion eftersom:"
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, gcc-internal-format
 msgid "call to internal function"
 msgstr "anrop av intern funktion"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "uttrycket %qE anger inte en constexpr-funktion"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "anrop av icke-constexpr-funktion %qD"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD anropad i ett konstant uttryck"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD användes före sin definition"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "anrop har cirkulärt beroende"
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "beräkning av constexpr överskrider maxvärdet på %d (använd -fconstexpr-depth= för att öka maxvärdet)"
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr "constexpr-anrop flödar förbi slutet på funktionen"
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E är inte ett konstant uttryck"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "höger operand av skiftuttrycket %q+E är negativ"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr "högra operanden av skiftuttrycket %q+E är ≥ precisionen på den vänstra operanden"
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "vänster operand av skiftuttrycket %q+E är negativ"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "skiftuttrycket %q+E spiller över"
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "array subscript out of bound"
 msgstr "vektorindex är utanför gränserna"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, gcc-internal-format
 msgid "negative array subscript"
 msgstr "negativt vektorindex"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "muterbar %qD är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "använder medlem %qD istället för initierad medlem %qD i ett konstant uttryck"
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "använder oinitierad medlem %qD"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "använder värdet av %qE genom ett %qT-glvalue i ett konstant uttryck"
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "värdet på %qD är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD använd i sin egen initierare"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D är inte const"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q+#D är volatile"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD initierades inte med ett konstant uttryck"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD deklarerades inte %<constexpr%>"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD har inte heltals- eller uppräkningstyp"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, gcc-internal-format
 msgid "modification of %qE is not a constant-expression"
 msgstr "ändring av %qE är inte ett konstantuttryck"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporär av den ej literala typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast från heltal till pekare"
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr "uttrycket %qE är inte ett konstantuttryck"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, gcc-internal-format
 msgid "statement is not a constant-expression"
 msgstr "satsen är inte ett konstantuttryck"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "oväntat uttryck %qE av sorten %s"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE är inte ett konstant uttryck eftersom det har referenser till muterbara delobjekt av %qT"
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr "konvertering från pekartypen %qT till den aritmetiska typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "uttrycket %qE har sidoeffekter"
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "adress-av på ett objekt %qE med trådlokal eller automatisk lagring är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%<this%> används i ett konstant uttryck"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-uttryck är inte ett konstant uttryck eftersom %qE har polymorf typ"
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, gcc-internal-format
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "skillnaden mellan två pekaruttryck är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr "pekarjämförelseuttryck är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "typkonvertering till %qT som inte är en heltalstyp i ett konstant uttryck"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, gcc-internal-format
 msgid "division by zero is not a constant-expression"
 msgstr "division med noll är inte ett konstantuttryck"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "ickekonstant vektorinitierare"
 
 # ast = abstract syntax tree
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "oväntat AST av sorten %s"
@@ -33356,7 +33397,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr "try-satser är inte tillåtna inuti slingor markerade med #pragma simd"
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr "%qE som implicit bestämts som %<firstprivate%> har referenstyp"
@@ -33396,7 +33437,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "konvertering från %qT till %qT kastar kvalificerare"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "typkonvertering av %qT till %qT derefererar inte pekare"
@@ -33406,292 +33447,292 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "kan inte konvertera typ %qT till typ %qT"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "konvertering från %q#T till %q#T"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "resultatet av konverteringen är odefinierad eftersom %qE är utanför intervallet för typen %qT"
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T använt där %qT förväntades"
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "kunde inte konvertera %qE från %<void%> till %<bool%>"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "%q#T använt där ett flyttalsvärde förväntades"
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "konvertering från %qT till icke-skalär typ %qT begärd"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "pseudodestruerare anropas inte"
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "konvertering till void kommer inte använda objekt av ofullständig typ %qT"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "indirektion kommer inte att använda objekt med ofullständig typ %qT i andra operanden av villkorligt uttryck"
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i tredje operand till villkorligt uttryck"
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i högeroperanden till kommaoperatorn"
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i vänstra operand av kommaoperatorn"
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i sats"
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i ökningsuttryck"
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "konvertering till void kommer inte använda objekt av typ %qT"
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i andra operanden av villkorligt uttryck"
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "implicita avreferens kommer inte att använda objekt av typ %qT i tredje operanden till villkorligt uttryck"
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "implicita avreferens kommer inte att använda objekt av typ %qT i högeroperanden till kommaoperatorn"
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "implicita avreferens kommer inte att använda objekt av typ %qT i vänstra operanden av kommaoperatorn"
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i satsen"
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "implicit avrefrens kommer inte att använda objekt av typ %qT i for-ökningsuttryck"
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "konvertering till void kommer inte använda objekt av ej trivialt kopierbar typ %qT"
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "indirektion kommer inte att använda objekt av icke trivialt kopierbar typ %qT i andra operanden av villkorligt uttryck"
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "en indirektion kommer inte att använda ett objekt av ej trivialt kopierbar typ %qT i tredje operanden av ett villkorsuttryck"
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "en indirektion kommer inte att använda ett objekt av ej trivialt kopierbar typ %qT i högra operanden av en kommaoperator"
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "en indirektion kommer inte använda ett objekt av ej trivialt kopierbar typ %qT i vänstra operanden av en kommaoperator"
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "en indirektion kommer inte använda ett objekt av ej trivialt kopierbar typ %qT i sats"
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "en indirektion kommer inte använda ett objekt av ej trivialt kopierbar typ %qT i for-ökningsuttryck"
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "konvertering till void kommer inte använda objekt %qE av ofullständig typ %qT"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i andra operanden av ett villkorsuttryck"
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i tredje operanden av ett villkorsuttryck"
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i högra operanden av en kommaoperator"
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i vänstra operanden av en kommaoperator"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i en sats"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i for-ökningsuttryck"
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "konvertering till void kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "andra operanden i villkorsuttryck kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "tredje operanden i villkorsuttryck kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "högra operanden av kommaoperator kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "vänstra operanden av kommaoperator kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "en sats kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "for-ökningsuttryck kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "andra operanden av villkorsuttryck är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "tredje operanden av villkorsuttryck är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "högra operanden av kommaoperator är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "vänstra operanden av kommaoperator är en referens, inte ett anrop, till funktion %qE"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "sats är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "for-ökningsuttryck är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "andra operanden av villkorsuttryck har ingen effekt"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "tredje operanden av villkorsuttryck har ingen effekt"
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "höger operand av kommaoperator har ingen effekt"
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "vänster operand av kommaoperator har ingen effekt"
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "satsen har ingen effekt"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "for-ökningsuttryck har ingen effekt"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "konvertera av NULL till icke-pekartyp"
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "standardtypkonvertering kan inte härleda mallargumentet för %qD"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "tvetydig standardtypkonvertering från %qT"
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  kandidater till konvertering är %qD och %qD"
@@ -34102,238 +34143,238 @@
 msgid "template parameters do not match template %qD"
 msgstr "mallparametrar stämmer inte med mallen %qD"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr "en anonym post kan inte ha funktionsmedlemmar"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr "en anonym union kan inte ha funktionsmedlemmar"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med konstruerare inte tillåten i anonymt aggregat"
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med destruerare inte tillåten i anonymt aggregat"
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med kopieringstilldelningsoperator är inte tillåten i anonymt aggregat"
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribut ignoreras i deklaration av %q#T"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "attribut för %q#T måste komma efter nyckelordet %qs"
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "flera typer i en deklaration"
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "omdeklaration av inbyggd C++-typ %qT"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> kan endast anges för variabler eller funktionsdeklarationer"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typnamn saknas i typedef-deklaration"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ förbjuder anonyma poster"
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr "%qs kan endast anges för funktioner"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> kan endast anges inuti en klass"
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> kan endast anges för konstruerare"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "en lagringsklass kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr "kvalificerare kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> ignorerades i denna deklaration"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%> kan inte användas för typdeklarationer"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "attribut ignoreras i explicit instansiering av %q#T"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "inget attribut kan användas på en explicit instansiering"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "ignorerar attribut använda på klasstypen %qT utanför dess definition"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "ignorerar attribut använda på beroende typ %qT utan en associerad deklaration"
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD är initierad (använd decltype istället)"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "deklarationen av %q#D har %<extern%> och är initierad"
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "definitionen av %q#D är markerad %<dllimport%>"
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D är inte en statisk datamedlem i %q#T"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "icke-medlemsmalldeklaration av %qD"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "stämmer inte med medlemsmalldeklarationen här"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tillåter inte %<%T::%D%> att definieras som %<%T::%D%>"
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "dubblerad initierare av %qD"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr "%qD är deklarerad %<constexpr%> utanför sin klass"
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "deklaration av %q#D utanför en klass är inte en definition"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qD är deklarerad %<thread_local%> i en %<constexpr%>-funktion"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%qDF är deklarerad %<static%> i en %<constexpr%>-funktion"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabeln %q#D har initierare men ofullständig typ"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementen i vektorn %q#D har ofullständig typ"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarationen av %q#D har ingen initierare"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "aggregatet %q#D har ofullständig typ och kan inte definieras"
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD är deklarerad som en referens men inte initierad"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "namn använt i en designerad initierare i GNU-stil för en vektor"
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "namnet %qD använt i en designerad initierare i GNU-stil för en vektor"
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "icketriviala designerade initierare stödjs inte"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99-beteckningen %qE är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "initierare misslyckas med att bestämma storleken på %qD"
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "vektorstorlek saknas i %qD"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "vektor med storlek noll %qD"
@@ -34341,824 +34382,824 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "lagringsstorlek på %qD är inte känd"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "lagringsstorlek på %qD är inte konstant"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "tyvärr: semantiken för inline-funktioners statiska data %q#D är felaktig (du kommer få flera exemplar)"
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "du kan gå runt detta genom att ta bort initieraren"
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "oinitierade const %qD"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "oinitierad variabel %qD i %<constexpr%>-funktion"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T har ingen användardefinierad standardkonstruerare"
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "konstrueraren är inte användarens egna eftersom den är uttryckligen standarddefinierad i klasskroppen"
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr "och den implicit definierade konstrueraren initierar inte %q+#D"
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "ogiltig typ %qT som initierare för en vektor med typ %qT"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "initierare för %qT måste vara inom klamrar"
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> använt i en designerad initierare i GNU-stil för klassen %qT"
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT har ingen icke-statisk medlem med namnet %qD"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ogiltigt initierare för %q#D"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-beteckningen %qE utanför aggregatinitierare"
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "för många initierare för %qT"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "klamrar runt skalär initierare för typen %qT"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "klamrar saknas runt initierare för %qT"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "element i vektorn %q#T har ofullständig typ"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "sammansatta literal med variabel storlek"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D har ofullständig typ"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalärt objekt %qD kräver ett element i initieraren"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "i C++98 måste %qD initieras med en konstruerare, inte med %<{...}%>"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "vektor %qD initierad från strängkonstant inom parentes %qE"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "initierare är ogiltig för statisk medlem med konstruerare"
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ej konstant initiering inom klassen av statisk medlem %qD"
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(en initiering utanför klassen krävs)"
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "referensen %qD initieras med sig själv"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "tilldelning (inte initiering) i deklaration"
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "skuggar tidigare typdeklaration av %q#D"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr "Javaobjekt %qD är inte allokerat med %<new%>"
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr "icke-statisk datamedlem %qD har Javaklasstyp"
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen %q#D är initierad som en variabel"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "ickelokal variabel %qD deklarerad %<__thread%> behöver dynamisk initiering"
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "den icke-lokala variabeln %qD deklarerad %<__thread%> har en icke-trivial destruerare"
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "C++11 %<thread_local%> tillåter dynamisk initialisering och destruktion"
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "initierare misslyckas med att bestämma storleken på %qT"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "vektorstorlek saknas i %qT"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "vektor med storlek noll %qT"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruerare för främmande class %qT kan inte vara en medlem"
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruerare för främmande klass %qT kan inte vara en medlem"
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD deklarerad som en %<virtual%>-variabel"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> variable"
 msgstr "%qD deklarerad som en %<inline%>-variabel"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i variabeldeklaration"
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD deklarerad som en %<virtual%>-parameter"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD deklarerad som en %<inline%>-parameter"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i parameterdeklaration"
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD deklarerad som en %<virtual%>-typ"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD deklarerad som en %<inline%>-typ"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i typdeklaration"
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD deklarerat som ett %<virtual%>-fält"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD deklarerat som ett %<inline%>-fält"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i fältdeklaration"
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D deklarerad som en vän"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D deklarerad med en undantagsspecifikationer"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definitionen av %qD är inte i en namnrymd som innesluter %qT"
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion %q#D deklarerad med typkvalificerare"
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definierar explicit specialisering %qD i vändeklaration"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ogiltig användning av mall-id %qD i deklaration av primär mall"
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "standardargument är inte tillåtna i deklaration av vänmallspecialisering %qD"
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> är inte tillåtet i deklaration av vänmallspecialisering %qD"
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, gcc-internal-format
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<constexpr%> är inte tillåtet i deklaration av vänmallspecialisering %qD"
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "det går inte att deklarera %<::main%> som en mall"
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "det går inte att deklarera %<::main%> som inline"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "det går inte att deklarera %<::main%> som constexpr"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "det går inte att deklarera %<::main%> som static"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "statisk medlemsfunktion %qD kan inte ha cv-kvalificerare"
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "icke-medlemsfunktion %qD kan inte ha cv-kvalificerare"
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "statisk medlemsfunktion %qD kan inte ha ref-kvalificerare"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "icke-medlemsfunktion %qD kan inte ha ref-kvalificerare"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "literal operator med C-länkning"
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD har en ogiltig argumentlista"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr "heltalssuffixet %<%s%> skuggas av implementationen"
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr "flyttalssuffixet %<%s%> skuggas av implementationen"
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD måste vara en icke-medlems-funktion"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> måste returnera %<int%>"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "omdefinition av implicit deklarerad %qD"
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definition av explicit standarddefinierad %q+D"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, gcc-internal-format
 msgid "%q+#D explicitly defaulted here"
 msgstr "%q+#D explicit standarddefinierad här"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "ingen medlemsfunktion %q#D deklarerad i klassen %qT"
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "initiering i klassen av statisk datamedlem %q#D med icke literal typ"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> behövs för initiering i klassen av statisk datamedlem med icke heltaltyp %q#D"
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "initiering i klassen av statisk datamedlem med icke heltaltyp %q#D"
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ogiltig initiering i klassen av statisk datamedlem med icke heltaltyp %qT"
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ förbjuder initiering inom klassen av icke-konstant statisk medlem %qD"
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ förbjuder initiering av medlemskonstant %qD av icke heltalstyp %qT"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "storlek på vektorn %qD av typen %qT är inte en heltalstyp"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "storlek på vektorn av typen %qT är inte en heltalstyp"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "storleken på vektorn %qD är negativ"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "storleken på vektorn är negativ"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ förbjuder vektor %qD med storlek noll"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ förbjuder vektor med storlek noll"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "storlek på vektorn %qD är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "storlek på vektorn är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ förbjuder vektor %qD med variabel längd"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ förbjuder vektor med variabel längd"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "vektor %qD med variabel längd används"
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "vektor med variabel längd används"
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "spill i vektordimension"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD är deklarerad som en vektor av %qT"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "deklaration av %qD som en vektor av void"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "skapar vektor av void"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "deklaration av %qD som en vektor av funktioner"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "skapar vektor av funktioner"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "deklaration av %qD som en vektor av referenser"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "skapar vektor av referenser"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "deklaration av %qD som en vektor av funktionsmedlemmar"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "skapar vektor av funktionsmedlemmar"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklaration av %qD som flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "en returtypsspecifikation för konstruerare är ogiltig"
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "specifikation av returtyp för destruerare är ogiltigt"
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "returtyp angiven för %<operator %T%>"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "namnlös variabel eller fält deklarerad void"
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel eller fält deklarerad void"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ogiltigt användning av kvalificerat namn %<::%D%>"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<%T::%D%>"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<%D::%D%>"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T är inte en klass eller namnrymd"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklaration av %qD som en icke-funktion"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "deklaration av %qD som icke-medlem"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "deklarerar-id saknas, använder reserverat ord %qD"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "funktionsdefinition deklarerar inte parametrar"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "deklaration av %qD som %<typedef%>"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "deklaration av %qD som en parameter"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> kan inte förekomma i en typedef-deklaration"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "två eller fler datatyper i deklaration av %qs"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "motstridande specificerare i deklarationen av %qs"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ stödjer inte bara %<complex%> i meningen %<double complex%>"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ förbjuder deklaration av %qs utan typ"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> stödjs inte på denna målarkitektur"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ stödjer inte %<__int%d%> för %qs"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> eller %<unsigned%> är ogiltigt för %qs"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> och %<unsigned%> givna tillsammans för %qs"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> ogiltig för %qs"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> ogiltig för %qs"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> ogiltig för %qs"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> eller %<short%> ogiltig för %qs"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%> eller %<char%> ogiltig för %qs"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> eller %<short%> angiven med char för %qs"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> och %<short%> angivna tillsammans för %qs"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> eller %<long%> ogiltig för %qs"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed eller unsigned använd felaktigt för %qs"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex ogiltig för %qs"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "kvalificerare är inte tillåtna på deklaration av %<operator %T%>"
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr "medlem %qD kan inte deklareras både virtual och static"
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-deklaration ogiltig i parameterdeklaration"
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "lagringsklass angiven för mallparameter %qs"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "specificerare av lagringsklass ogiltig i parameterdeklarationer"
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "en parameter kan inte deklareras %<constexpr%>"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> utanför klassdeklaration"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "flera lagringsklasser i deklaration av %qs"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "lagringsklass angiven för %qs"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "lagringsklass angiven för parameter %qs"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "nästad funktion %qs är deklarerad %<extern%>"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "toppnivådeklaration av %qs anger %<auto%>"
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "funktionsdefinitionsområde %qs implicit auto och deklarerat %<__thread%>"
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "ogiltig specificerare av lagringsklass i vänfunktionsdeklarationer"
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs är deklarerad som en funktion som returnerar en funktion"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs är deklarerad som en funktion som returnerar en vektor"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "funktionen %qs använder typspecificeraren %<auto%> utan avslutande returtyp"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "härledd returtyp är endast tillgänglig med -std=c++14 eller -std=gnu++14"
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuell funktion kan inte ha härledd returtyp"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "funktionen %qs med avslutande returtyp har %qT som sin typ istället för bara %<auto%>"
@@ -35165,470 +35206,470 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "avslutande returtyp är endast tillgänglig med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "funktionen %qs med avslutande returtyp är inte deklarerad med typspecificeraren %<auto%>"
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "destruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "konstruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "destruerare får inte vara ref-kvalificerade"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr "konstruerare kan inte deklareras virtual"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuella funktioner kan inte vara vänner"
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "vändeklaration är inte i klassdefinition"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "det går inte att definiera vänfunktion %qs i en lokal klassdefinition"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruerare får inte ha parametrar"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "det går inte att deklarera pekare till %q#T"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "det går inte att deklarera referens till %q#T"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "det går inte att deklarera pekare medlem av %q#T"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "det går inte att deklarera en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "det går inte att deklarera en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "det går inte att deklarera en referens till %q#T, som inte är ett typedef- eller ett malltypargument"
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "mall-id %qD använd som en deklarerare"
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner är implicit vänner till sin klass"
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "extra kvalifikation %<%T::%> på medlem %qs"
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "det går inte att definiera medlemsfunktion %<%T::%s%> inuti %<%T%>"
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "det går inte att deklarera medlemsfunktionen %<%T::%s%> inuti %<%T%>"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "det går inte att deklarera medlem %<%T::%s%> inuti %qT"
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "icke-parameter %qs kan inte vara ett parameterpaket"
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "storleken på vektorn %qs är för stor"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem får inte ha variabel typ %qT"
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter får inte ha variabel typ %qT"
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> utanför klassdeklaration"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> i vändeklaration"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "endast deklarationer av konstruerare och konverteringsoperatorer kan vara %<explicit%>"
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "icke-medlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "icke-objektmedlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "statiska %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "referensen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef deklarerad %<auto%>"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-namn får inte vara en nästad-namnspecificerare"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ förbjuder nästad typ %qD med samma namn som en omgivande klass"
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr "typkvalificerare angivna för vänklassdeklaration"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> angivet för vänklassdeklaration"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "mallparametrar kan inte vara vänner"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend class %T::%D%>"
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend %#T%>"
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "försöker göra klassen %qT en vän med global räckvidd"
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ogiltiga kvalificerare på typ som inte är medlemsfunktion"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt deklarerare %qT använd som deklaration"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "det går inte att använda %<::%> i parameterdeklaration"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "en %<auto%>-parameter är tillåten i detta sammanhang"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametern deklarerad %<auto%>"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, gcc-internal-format
 msgid "non-static data member declared %<auto%>"
 msgstr "ej statisk datamedlem deklarerad %<auto%>"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ogiltigt användning av %<::%>"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "deklaration av funktionen %qD i ogiltig kontext"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "funktionen %qD deklarerad virtuell inuti en union"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr "%qD kan inte deklareras virtuell, eftersom den redan är statisk"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för destruerare %qD"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklaration av %qD som medlem av %qT"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "en destruerare kan inte vara %<constexpr%>"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för konstruerare %qD"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering av variabelmall %qD deklarerad som en funktion"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabelmallen är deklarerad här"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "fältet %qD har den ofullständiga typen %qT"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "namnet %qT har ofullständig typ"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE är varken en funktion eller medlemsfunktion, kan inte deklareras som vän"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr "statisk constexpr-datamedlemmen %qD måste ha en initierare"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "ickestatisk datamedlem %qE deklarerad %<constexpr%>"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen %<auto%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen %<register%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen %<__thread%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen %<thread_local%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specificerare i %qs är inte tillåtet utanför en klassdefinition"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr "specificerare %<static%> är ogiltigt för funktion %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "specificerare %<inline%> är ogiltig för funktionen %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuell icke klassfunktion %qs"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs definierad utan att vara i klassräckvidd"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs deklarerad utan att vara i klassräckvidd"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "det går inte deklarera medlemsfunktionen %qD att ha statisk länkklass"
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan inte deklarera en statisk funktion i en annan funktion"
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> får inte användas vid definition (till skillnad mot deklaration) av statisk datamedlem"
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem %qD deklarerad %<register%>"
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "det går inte att deklarera medlem %q#D att ha extern länkklass"
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, gcc-internal-format
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "deklarationen av constexpr-variabeln %qD är inte en definition"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initierad och deklarerad %<extern%>"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs har både %<extern%> och initierare"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "standardargument %qE använder %qD"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardargument %qE använder lokal variabel %qD"
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "felaktig användning av cv-kvalificerad typ %qT i en parameterdeklaration"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "felaktig användning av typen %<void%> i en parameterdeklaration"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "parametern %qD har Javaklasstyp"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD ogiltigt deklarerad metodtyp"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar pekare till vektor %qT med okänd gräns"
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar referens till vektor %qT med okänd gräns"
@@ -35648,173 +35689,173 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ogiltig konstruerare, du menade förmodligen %<%T (const %T&)%>"
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD är kanske inte deklarerad i en namnrymd"
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD får inte deklareras som statisk"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr "%qD är som en vanlig (icke placerande) avallokeringsfunktion i C++14 (eller med -fsized-deallocation)"
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD måste vara en icke-statisk medlemsfunktion"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD måste vara antingen en medlemsfunktion som inte är statisk eller funktion som inte är medlem"
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD måste ha ett argument med klass- eller uppräkningstyp"
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "konvertering till en referens till void kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "konvertering till void kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering till en referens till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "konvertering till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "konvertering till en referens till en basklass kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "konvertering till en basklass kommer aldrig använda en typkonverteringsoperator"
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ förhindrar överlagring av operatorn ?:"
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD får inte ha variabelt antal argument"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr "postfix %qD måste ta %<int%> som sitt argument"
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr "postfix %qD måste ta %<int%> som sitt andra argument"
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr "%qD måste ta antingen noll eller ett argument"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr "%qD måste ta antingen ett eller två argument"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD skall returnera %qT"
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD skall returnera %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr "%qD måste ta %<void%>"
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr "%qD måste ta exakt ett argument"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "%qD måste ta exakt två argument"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "användardefinierad %qD beräknar alltid båda argumenten"
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD skall returnera som värde"
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kan inte ha standardargument"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "malltypparametern %qT används efter %qs"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "användning av aliasmallspecialisering %qT efter %qs"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-namnet %qD används efter %qs"
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD har en tidigare deklaration här"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT refererad till som %qs"
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "%q+T har en tidigare deklaration här"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT refererad till som enum"
@@ -35826,88 +35867,88 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "mallargument krävs för %<%s %T%>"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD har samma namn som klassen den är deklarerad i"
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referens till %qD är tvetydig"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "enum %q#D används utan tidigare deklaration"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "omdeklaration av %qT som en icke-mall"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "tidigare deklaration %q+D"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "härledd unionen %qT ogiltig"
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr "Javaklass %qT kan inte ha flera baser"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr "Javaklass %qT kan inte ha virtuella baser"
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "bastyp %qT är ingen post- eller klasstyp"
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiv typ %qT odefinierad"
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "upprepat bastyp %qT ogiltig"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "uppräkningstyp med/utan räckviddsbegränsning stämmer inte överens för enum %q#T"
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidigare definition här"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "underliggande typ stämmer inte överens i enum %q#T"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "olika underliggande typ i enum %q#T"
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr "underliggande typ %<%T%> till %<%T%> måste vara en heltalstyp"
@@ -35916,87 +35957,87 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ingen heltalstyp kan representera alla uppräkningsvärdena i %qT"
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "uppräkningsvärde för %qD är inte en heltalskonstant"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ökat uppräkningsvärde är för stort för %<unsigned long%>"
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "överspill i uppräkningsvärden vid %qD"
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr "uppräkningsvärdet %E är utanför intervallet för den underliggande typen %<%T%>"
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "returtypen %q#T är ofullständig"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr "returtypen har Javaklasstyp %q#T"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> skall returnera en referens till %<*this%>"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "ingen tidigare deklaration av %q+D"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "ogiltig funktionsdeklaration"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "parameter %qD deklarerad void"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "inga retursatser i funktion som returnerar %qT"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "endast enkel returtyp %<auto%> kan härledas till %<void%>"
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, gcc-internal-format
 msgid "parameter %q+D set but not used"
 msgstr "parametern %q+D sätts men används inte"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "ogiltig medlemsfunktionsdeklaration"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD är redan definierad i klassen %qT"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "användning av %qD före härledning av %<auto%>"
@@ -36036,7 +36077,7 @@
 msgid "deleting %qT is undefined"
 msgstr "radera %qT är odefinierat"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "malldeklaration av %q#D"
@@ -36059,7 +36100,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "destrueraren %qD deklarerad som medlemsmall"
@@ -36149,27 +36190,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "bredden på bitfältet %qD har icke-heltalstyp %qT"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "den statiska datamedlemmen %q+D är inuti deklarationsmålsdirektiv"
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonym post som inte är inuti en namngiven typ"
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "anonyma aggregat med namnrymdsräckvidd måste vara statiska"
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonym union utan medlemmar"
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> måste returnera typ %qT"
@@ -36178,47 +36219,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "andra parametern till %<operator new%> kan inte ha standardargument"
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> tar typen %<size_t%> (%qT) som första parameter"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> måste returnera typ %qT"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> tar typen %qT som första parameter"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT har ett fält %qD vars typ använder den anonyma namnrymden"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT är deklarerad med större synlighet än typen för dess fält %qD"
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT har en bas %qT vars typ använder den anonyma namnrymden"
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT är deklarerad med större synlighet än sin bas %qT"
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, gcc-internal-format
 msgid "%q#D, declared using anonymous type, is used but never defined"
 msgstr "%q#D, deklarerad med en anonym typ, används men är aldrig definierad"
@@ -36227,47 +36268,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr "anonym typ utan länkklass används för att deklarera variabeln %q#D med länkklass"
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr "anonym typ utan länkklass används för att deklarera funktionen %q#D med länkklass"
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D refererar inte till den okvalificerade typen, så den används int för länkklass"
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D, deklarerad med en lokal typ %qT, används men är aldrig definierad"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "typen %qT utan länkklass använd för att deklarera variabeln %q#D med länkklass"
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "typen %qT utan någon länkklass använd för att deklarera funktionen %q#D med länkklass"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "programmet borde även definiera %qD"
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "inline-funktion %q+D använd men aldrig definierad"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "standardargumentet saknas för parameter %P till %q+#D"
@@ -36274,12 +36315,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr "konverterar lambda som använder %<...%> till funktionspekare"
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "användning av borttagen funktion %qD"
@@ -36856,42 +36897,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "varken destrueraren eller den klasspecifika operatorn delete [] kommer anropas, även om de är deklarerade när klassen definieras"
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "initierare tar slut i förtid"
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr "det går inte att initiera en flerdimensionell vektor med initierare"
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "okänd vektorstorlek i delete"
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "möjligt problem upptäckt vid anrop av operatorn delete:"
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "varken destrueraren eller den klasspecifika operatorn delete kommer anropas, även om de är deklarerade när klassen definieras"
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr "radering av objekt av den abstrakta klasstypen %qT som har en ej virtuell destruerare kommer medföra odefinierat beteende"
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr "radering av objekt av den polymorfa klasstypen %qT som har en ej virtuell destruerare kommer medföra odefinierat beteende"
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "typ till vektor-delete är varken pekar- eller vektortyp"
@@ -37021,17 +37062,17 @@
 msgid "string literal in function template signature"
 msgstr "strängliteral i funktionsmallsignatur"
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "en senare -fabi-version= (eller =0) undviker detta fel med en ändring av manglingen"
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, gcc-internal-format
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "det manglade namnet för %q+D ändrades mellan -fabi-version=%d (%D) och -fabi-version=%d (%D)"
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, gcc-internal-format
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "det manglade namnet för %q+D ändras mellan -fabi-version=%d (%D) och -fabi-version=%d (%D)"
@@ -37445,7 +37486,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr "identifieraren %qE är ett nyckelord i C++11"
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> som inte omedelbart följs av en funktionsdeklaration eller -definition"
@@ -37470,7 +37511,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "begäran av medlem %qE i typ %qT som inte är en klasstyp"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> har inte deklarerats"
@@ -37535,7 +37576,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(kanske ett semikolon saknas efter definitionen av %qT)"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT är inte en mall"
@@ -37560,7 +37601,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "en flyttalsliteral får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "en typomvandling till en annan typ än en heltals- eller uppräkningstyp kan inte förekomma i ett konstantuttryck"
@@ -37828,7 +37869,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "literala operatorsuffix som inte föregås av %<_%> är reserverade för framtida standardisering"
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "okvalificerat id förväntades"
@@ -38003,7 +38044,7 @@
 msgid "capture of non-variable %qD "
 msgstr "fångst av en icke-variabel %qD"
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, gcc-internal-format
 msgid "%q+#D declared here"
 msgstr "%q+#D är deklarerad här"
@@ -38063,7 +38104,7 @@
 msgid "compound-statement in constexpr function"
 msgstr "sammansatt sats i en constexpr-funktion"
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "selektionssats förväntades"
@@ -38093,7 +38134,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "inkonsistenta start-/sluttyper i intervallbaserat %<for%>-sats: %qT och %qT"
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "iterationssats förväntades"
@@ -38124,12 +38165,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ förbjuder beräknade goto"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "hoppsats förväntades"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "extra %<;%>"
@@ -38176,7 +38217,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "klassdefinition kan inte deklareras som en vän"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "mallar får inte vara %<virtual%>"
@@ -38267,12 +38308,12 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "nyckelordet %<export%> är inte implementerat och kommer ignoreras"
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "mallparameterpaket %qD kan inte ha ett standardargument"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "mallparameterpaket kan inte ha ett standardargument"
@@ -38287,7 +38328,7 @@
 msgid "expected template-id"
 msgstr "mall-id förväntades"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> förväntades"
@@ -38364,208 +38405,208 @@
 msgid "expected type specifier"
 msgstr "typspecificerare förväntades"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "användning av %<auto%> i lambdaparameterdeklarationer är endast tillgängligt med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "användning av %<auto%> i parameterdeklarationer är endast tillgängligt med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C++ förbjuder användning av %<auto%> i en parameterdeklaration"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "mall-id för typ förväntades"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "typnamn förväntades"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr "beräknad typspecifikation för en enum med räckvidd får inte använda nyckelordet %<%D%>"
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "deklaration %qD deklarerar inte något"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "attributet ignorerat på oinstansierad typ"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "attribut ignoreras vid mallinstansiering"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "attribut ignoreras för bearbetade typspecificerare som inte är en framåtdeklaration"
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD är en uppräkningsmall"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, gcc-internal-format
 msgid "%qD is not an enumerator-name"
 msgstr "%qD är inte ett uppräkningsnamn"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr "enum med anonym räckvidd är inte tillåtet"
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> eller %<{%> förväntades"
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "det går inte att lägga till en uppräkningslista till en mallinstansiering"
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "deklaration av %qD i namnrymd %qD som inte innesluter %qD"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "deklaration av %qD i %qD som inte innesluter %qD"
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "fler definitioner av %q#T"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, gcc-internal-format
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C++ förbjuder tomma anonyma enum"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "ogenomskinlig enum-specifikation utan namn"
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "en ogenomskinlig enum-specifikation måste använda en enkel identifierare"
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD är inte ett namnrymdsnamn"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "namnrymdsnamn förväntades"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-definition är inte tillåten här"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "ett mall-id får inte förekomma i en using-deklaration"
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "åtkomstdeklarationer bör undvikas till förmån för using-deklarationer; förslag: lägg till nyckelordet %<using%>"
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "typer får inte definieras i aliasmalldeklarationer"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%<asm%> i %<constexpr%>-funktion"
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "en funktionsdefinition är inte tillåten här"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "en asm-specifikation är inte tillåten på en funktionsdefinition"
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "attribut är inte tillåtna vid en funktionsdefinition"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "konstruerare, destruerare eller typkonvertering förväntades"
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "initierare förväntades"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "initierare angiven för funktion"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "attribut efter initierare inom parentes ignoreras"
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "icke-funktionen %qD deklarerad som implicit mall"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "vektorgräns är inte en heltalskonstant"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "det går inte att definiera medlem av beroende typedef %qT"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> är inte en typ"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ogiltig användning av konstruerare som en mall"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "använd %<%T::%D%> istället för %<%T::%D%> för att namnge konstrueraren i ett kvalificerat namn"
@@ -38574,7 +38615,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ogiltig deklarator"
@@ -38581,292 +38622,292 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "kvalificerad id i deklaration"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "deklarator förväntades"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD är en namnrymd"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "kan inte skapa en pekare till medlem av %q#T som inte är en klass"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "oväntad pekaroperator"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "upprepade cv-kvalificerare"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "upprepade ref-kvalificerare"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "upprepade virt-specificerare"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, gcc-internal-format
 msgid "invalid use of %<auto%>"
 msgstr "ogiltigt användning av %<auto%>"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "typer får inte definieras i mallargument"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "felaktig användning av %<auto%> i mallargument"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "typspecificerare förväntades"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> eller %<...%> förväntades"
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "typer får inte definieras i parametertyper"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr "användning av standardargument för parametrar till annat än funktioner bör undvikas"
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "standardargument är endast tillåtna för funktionsparametrar"
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "parameterpaket %qD kan inte ha ett standardargument"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "parameterpaket kan inte ha ett standardargument"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ tillåter inte designerade initierare"
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tillåter inte C99:s designerade initierare"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "klassnamn förväntades"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> förväntades efter klassdefinition"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> förväntades efter postdefinition"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> förväntades efter uniondefinition"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> eller %<:%> förväntades"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "det går inte att ange %<override%> för en klass"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "globala kvalificering av klassnamn är ogiltigt"
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "kvalificerat namn namnger inte en klass"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "ogiltigt klassnamn i deklaration av %qD"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "extra kvalifikation inte tillåten"
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "en explicit specialisering måste föregås av %<template <>%>"
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "funktionsmall %qD omdeklarerad som en klassmall"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "det gick inte att lösa upp typnamnstyp"
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr "föregående definition av %q+#T"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "klassnyckel förväntades"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr "ISO C++ förbjuder nyckelordet typename i mall-mall-parameter; använd -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> eller %<typename%> förväntades"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "i C++03 måste en klassnyckel användas när en vän deklareras"
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "vändeklaration som inte namnger en klass eller funktion"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "en lagringklass på ett anonymt aggregat i klassräckvidd tillåts inte"
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "pure-specificerare på funktionsdefinition"
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "överblivet %<,%> vid slutet av medlemsdeklaration"
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> förväntades vid slutet av medlemsdeklaration"
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "ogiltig pure-specificerare (endast %<= 0%> är tillåtet)"
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "en klammeromsluten initierare är inte tillåten här"
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr "%<virtual%> anges mer än en gång i basspecificerade"
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr "mer än en åtkomstspecifikation i basspecificerade"
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "nyckelordet %<typename%> är inte tillåtet utanför mallar"
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "nyckelordet %<typename%> är inte tillåtet i detta sammanhang (basklassen är implicit en typ)"
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "typer får inte definieras i en undantagsspecifikation"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr "dynamiska undantagsspecifikationer undanbedes i C++0x, använd %<noexcept%> istället"
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%<try%> i %<constexpr%>-funktion"
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "typer får inte definieras i undantagsdeklarationer"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "en identifierare förväntades som attributnamn"
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr "%<deprecated%> är en funktion i C++14; använd %<gnu::deprecated%>"
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "specialisering av medlem %<%T::%E%> kräver %<template<>%>-syntax"
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ogiltig omdeklaration av %<%T::%E%>"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "för få mallparameterlistor"
@@ -38875,533 +38916,533 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "för många mallparameterlistor"
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "namngivna returvärden stödjs inte längre"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ogiltig deklaration av medlemsmall i lokal klass"
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "mall med C-länkning"
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ogiltig explicit specifikation"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "den literala operatormallen %qD har ogiltig parameterlista.  Ett mallargument som inte är en typ pack <char...> eller <typename CharT, CharT...> förväntades"
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "den literala operatormallen %qD har ogiltig parameterlista.  Ett mallargument som inte är en typ pack <char...> förväntades"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "malldeklaration av %<typedef%>"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explicit mallspecialisering kan inte ha en lagringsklass"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> skulle vara %<> >%> inuti en nästad mallargumentlista"
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "vilsekommet %<>>%>, använd %<>%> för att avsluta en mallargumentlista"
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "argument till %<sizeof...%> måste omges av parenteser"
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ogiltig användning av %qD i länkklasspecifikation"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> före %qD"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 stödjer inte %<long long%>"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "både %<__thread%> och %<thread_local%> angivna"
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "dubblerad %qD"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "dubblerad %qs"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> förväntades"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> förväntades"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> förväntades"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> förväntades"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> förväntades"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> förväntades"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> förväntades"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> förväntades"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> förväntades"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> förväntades"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> förväntades"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> förväntades"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> förväntades"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> förväntades"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> förväntades"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> förväntades"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> förväntades"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<synchronized%> förväntades"
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> förväntades"
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> förväntades"
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction _relaxed%> förväntades"
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> förväntades"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> förväntades"
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> förväntades"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> förväntades"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> eller %<::%> förväntades"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> eller %<template%> förväntades"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs-tagg använd vid namngivning av %q#T"
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T deklarerades tidigare här"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD omdeklarerad med annan åtkomst"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "i C++98 är %<template%> (för att lösa upp tvetydighet) är endast tillåtet inuti mallar"
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "filen slutar i standardargument"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "felplacerad Objective-C++-konstruktion %<@%D%>"
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++-meddelandemottagare förväntades"
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++-meddelandeargument förväntades"
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> måste ange en typ som ett argument"
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "ogiltigt Objective-C++-selekterarnamn"
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
-msgstr "metodeklaration i objective-c++ förväntades"
+msgstr "metoddeklaration i objective-c++ förväntades"
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "metodattribut måste anges på slutet"
 
 # %qs blir "{" eller "}"
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "vilsekommet %qs mellan Objective-C++ metoder"
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ogiltig typ för iterationsvariabel"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "identifierare förväntades efter %<@protocol%>"
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "attribut får inte anges före Objective-C++-nyckelordet %<@%D%>"
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefixattribut ignoreras före %<@%D%>"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ogiltigt typ på egenskap"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected positive integer expression"
 msgstr "positivt heltalsuttryck förväntades"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%>-uttryck måste vara heltal"
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ogiltig reduktionsidentifierare"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "initiering i parenteser är inte tillåtet i en OpenMP-%<for%>-slinga"
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "initiering i parenteser är inte tillåtet i en for-slinga"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr "%<_Cilk_for%> tillåter ett uttryck istället för en deklaration endast i C, inte i C++"
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterationsvariabel %qD skall inte vara reduction"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, gcc-internal-format
 msgid "not enough collapsed for loops"
 msgstr "inte tillräcklig kollapsat för slingor"
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "vektorattribut som inte omedelbart följs av en ensam funktionsdeklaration eller -definition"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ogiltig initierarklausul"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "id-uttryck förväntades (argument)"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "en av initieraranropets argument skall vara %<omp_priv%> eller %<&omp_priv%>"
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> eller identifierare förväntades"
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "typer får inte definieras i en declare reduction-typlista"
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "en fördeklarerad aritmetisk typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "funktions- eller vektortyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "referenstyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "const-, volatile- eller __restrict-kvalificerad typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "skräp vid slutet av %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr "ogiltig kornstorlek för _Cilk_for"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> måste vara inuti en funktion"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "%<#pragma simd%> måste vara inuti en funktion"
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "%<#pragma cilk grainsize%> måste vara inuti en funktion"
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr "-fcilkplus måste vara aktiverat för att använda %<#pragma cilk grainsize%>"
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "intermoduloptimeringar inte implementerade för C++"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, gcc-internal-format
 msgid "expected variable-name"
 msgstr "variabelnamn förväntades"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "%<,%> eller %<)%> förväntades efter %qE"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "implicita mallar får inte vara %<virtual%>"
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "datamedlem %qD kan inte vara en medlemsmall"
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "ogiltig medlemsmalldeklaration %qD"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "explicit specialisering som inte är i namnrymdsområde %qD"
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "inneslutande klassmallar är inte explicit specialiserade"
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "specialisering av %qD i förekomma i namnrymdsräckvidd"
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "specialisering av %qD i en annan namnrymd"
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr "  än definitionen av %q+#D"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "explicit instansiering av %qD i namnrymden %qD (som inte omsluter namnrymden %qD)"
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "namn på klass skuggar mallmallparameter %qD"
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "specialisering av aliasmall %qD"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "explicit specialisering av icke-mall %qT"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "specialisering av %qT efter instansiering"
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "specialiserar %q#T i en annan namnrymd"
@@ -39408,67 +39449,67 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "specialisering %qT efter instansiering %qT"
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "mallspecialisering av %qD är inte tillåten av ISO C++"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "specialisering av %qD efter instansiering"
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, gcc-internal-format
 msgid "candidate is: %#D"
 msgstr "kandidat är: %#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %#D"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD är inte en funktionsmall"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD är inte en variabelmall"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "mall-id %qD för %q+D stämmer inte med någon malldeklaration"
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "såg %d %<template<>%>, behöver %d för specialisering av medlemsfunktionsmall"
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "tvetydig mallspecialisering %qD för %q+D"
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "variabelmallar är endast tillgängliga med -std=c++14 eller -std=gnu++14"
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, gcc-internal-format
 msgid "too many template headers for %D (should be %d)"
 msgstr "fel antal mallhuvuden för %D (skulle vara %d)"
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "medlemmar av en explicit specialiserad klass definieras utan ett mallhuvud"
@@ -39475,57 +39516,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "mall-id %qD i deklaration av primär mall"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "mallparameterlista använd i explicit instansiering"
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "definition given för explicit instansiering"
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "för många mallparameterlistor i deklarationen av %qD"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "för få mallparameterlistor i deklarationen av %qD"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "explicit specialisering av %qD måste inledas av %<template <>%>"
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "partiell specialisering som inte är en typ av %qD är inte tillåten"
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "partiell specialisering som inte är en klass eller variabel av %qD är inte tillåten"
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "standardargument angivet i explicit specialisering"
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD är inte en mallfunktion"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "%qD inte deklarerad i %qD"
@@ -39538,92 +39579,92 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "specialisering av implicit deklarerad specialmedlemsfunktion"
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "ingen medlemsfunktion %qD är deklarerad i %qT"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr "basinitierarexpansionen %<%T%> innehåller inga parameterpaket"
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr "expansionsmönster %<%T%> innehåller inga argumentpaket"
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr "expansionsmönster %<%E%> innehåller inga argumentpaket"
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parameterpaket expanderas inte med %<...%>:"
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonym>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "deklaration av %q+#D"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr " skuggar mallparameter %q+#D"
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "mallparameter är inte härledbara i partiell specialisering:"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr "partiell specialisering %qD specialiserar inte något mallargument"
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "partiell specialisering är inte mer specialiserad än huvudmallen eftersom den ersätter flera parametrar med en paketexpansion"
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "huvudmall här"
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameterpaketargument %qE måste vara vid slutet av mallens argumentlista"
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameterpaketargument %qT måste vara vid slutet av mallens argumentlista"
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "mallargument %qE berör mallparametrar"
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -39630,12 +39671,12 @@
 msgstr[0] "typ %qT för mallargument %qE beror på en mallparameter"
 msgstr[1] "typ %qT för mallargument %qE beror på mallparametrar"
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "partiell specialisering %qD efter instansiering av %qD"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "inget standardargument för %qD"
@@ -39643,42 +39684,42 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameterpaket %q+D måste vara vid slutet av mallens parameterlista"
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "standardmallargument får inte användas i vänomdeklaration av funktionsmall"
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr "standardmallargument får inte användas i vändeklarerade funktionsmallar"
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "standarmallargument får inte användas i funktionsmallar utan -std=c++11 eller -std=gnu++11"
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "standardmallargument får inte användas i partiella specialiseringar"
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "standardargumentet för mallparameter för klass om omsluter %qD"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "mallklass utan ett namn"
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "medlemsmallen %qD kan inte ha virt-specificerare"
@@ -39688,57 +39729,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "ogiltig malldeklaration av %qD"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "malldefinition av icke-mall %q#D"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d nivåer av mallparametrar förväntades till %q#D, %d fanns"
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "fick %d mallparametrar till %q#D"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "fick %d mallparametrar till %q#T"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  men %d behövs"
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "mallargument till %qD stämmer inte med originalmallen %qD"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr "använd template<> för en explicit specialisering"
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT är inte en malltyp"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "mallspecificerare inte angivna i deklarationen av %qD"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -39745,7 +39786,7 @@
 msgstr[0] "omdeklarerad med %d mallparameter"
 msgstr[1] "omdeklarerad med %d mallparametrar"
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, gcc-internal-format
 msgid "previous declaration %q+D used %d template parameter"
 msgid_plural "previous declaration %q+D used %d template parameters"
@@ -39752,12 +39793,12 @@
 msgstr[0] "tidigare deklaration av %q+D använde %d mallparameter"
 msgstr[1] "tidigare deklaration av %q+D använde %d mallparametrar"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "mallparameter %q+#D"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "omdeklarerad här som %q#D"
@@ -39766,102 +39807,102 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "omdefinition av standardargument till %q#D"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "ursprunglig definition fanns här"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "det måste vara adressen till en funktion med extern lagringsklass"
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "det måste vara namnet på en funktion med extern lagringsklass"
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom %qD inte har någon länkklass"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qD inte har extern länkklass"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "det måste vara en pekare-till-medlem på formen %<&X::Y%>"
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "  kunde inte härleda mallparametrar %qD"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  typerna %qT och %qT har inkompatibla cv-kvalificerare"
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  typerna %qT och %qT stämmer inte överens"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "mallparameter %qD är inte ett parameterpaket, men argunet %qD är det"
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  mallargument %qE stämmer inte med pekare till medlem-konstanten %qE"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE är inte ekvivalent med %qE"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  inkonsistent härledning av parameterpaket med %qT och %qT"
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  härledda typer i konflikt för parametern %qT (T%qT och %qT)"
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  härledda värden i konflikt för icke-typ-parametern %qE (%qE och %qE)"
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  vektortypen %qT med variabel storlek är inte ett giltigt mallargument"
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  medlemsfunktionstypen %qT är inte ett giltigt mallargument"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -39868,172 +39909,172 @@
 msgstr[0] "  kandidaten förväntade sig åtminstone %d argument, %d fanns"
 msgstr[1] "  kandidaten förväntade sig åtminstone %d argument, %d fanns"
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  kan inte konvertera %qE (typen %qT) till typ %qT"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT är en tvetydig basklass till %qT"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT är inte härledd från %qT"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  mallparametrarna till ett mallmallargument är inkonsistenta med andra härledda mallargument"
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "  det går inte att härleda en mall för %qT från typen %qT som inte är en mall"
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qD"
 msgstr "  mallargument %qE stämmer inte med %qD"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, gcc-internal-format
 msgid "  could not resolve address from overloaded function %qE"
 msgstr "  kunde inte lösa upp adressen från en överlagrad funktion %qE"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom strängkonstanter aldrig kan användas i detta sammanhang"
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, gcc-internal-format
 msgid "in template argument for type %qT "
 msgstr "i mallargument för typen %qT"
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD är inte ett giltigt mallargument för att %qD är en variabel, inte adressen till en variabel"
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE är inte ett giltigt mallargument till %qT för det är inte adressen till en variabel"
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qE inte är en variabel"
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE är inte ett giltigt mallargument av typ %qT eftersom %qD inte har extern länkklass"
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qD inte har någon länkklass"
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom det står i konflikt med cv-kvalificeringar"
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom inte är ett l-värde"
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D är inte ett giltigt mallargument till typen %qT eftersom en referensvariabel inte har en konstant adress"
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det inte är ett objekt med extern länkklass"
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom objekt %qD inte har extern länkklass"
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är en pekare"
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "försök att använda %qE istället"
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är av typen %qT"
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "standardkonverteringar är inte tillåtna i denna kontext"
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "ignorerar attribut på mallargumentet %qT"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "inskjutet klassnamn %qD använt som mallmallargument"
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ogiltig användning av destrueraren %qE som en typ"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "för att referera till en typmedlem av en mallparameter, använd %<typename %E%>"
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "typ/värde stämmer inte vid argument %d i mallparameterlistan till %qD"
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  förväntade en konstant av typen %qT, fick %qT"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  förväntade en klassmall, fick %qE"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  förväntade en typ, fick %qE"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  förväntade en typ, fick %qT"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  förväntade en klassmall, fick %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  förväntade en mall av typen %qD, fick %qT"
@@ -40040,77 +40081,77 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "typer stämmer inte i icke-typs parameterpaket"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr "kunde inte konvertera mallargument %qE till %qT"
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "mallargument %d är ogiltigt"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "fel antal mallargument (%d, skulle vara %d)"
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "fel antal mallargument (%d, skulle vara åtminstone %d)"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "angivna till %q+D"
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "pack-expansionsargument för icke-pack-parametern %qD till aliasmall %qD"
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "så varje instansiering med ett icke-tomt parameterpaket vore felformulerad"
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D är inte en funktionsmall"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "icke-malltyp %qT använd som en mall"
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "för malldeklaration %q+D"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d (använd -ftemplate-depth= för att öka maxvärdet)"
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %<%T%>"
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %<%E%>"
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "  vid instansiering av standardargument för anrop av %D"
@@ -40128,266 +40169,266 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabeln %qD har funktionstyp"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ogiltig parametertyp %qT"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "i deklaration %q+D"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "funktion som returnerar en vektor"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion som returnerar en funktion"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "skapar pekare till medlemsfunktion i typ %qT som inte är en klass"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formar referens till void"
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formar pekare till en referenstyp %qT"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formar referens till en referenstyp %qT"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formerar en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formerar en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "skapar pekare till medlem av typ %qT som inte är en klass"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "skapar pekare till medlemsreferenstyp %qT"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "skapar pekare till medlem av typ void"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "skapar vektor av %qT"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT är inte en klass-, post- eller unionstyp"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT slås upp till %qT som inte är en uppräkningstyp"
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT löses upp till %qT, som inte är en klasstyp"
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "användning av %qs i mall"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "kvalificerande typ %qT matchar inte destruerarnamnet ~%qT"
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "namnet %qE i den beroende tolkas som något annat än en typ, men instansiering ger en typ"
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "säg %<typename %E%> om en typ avses"
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "användning av ogiltigt fält %qD"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ogiltig användning av paketexpansionsuttryck"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "använd %<...%>  för att expandera argumentpaket"
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD har inte deklarerats i denna räckvidd, och inga deklarationer hittades vid argumentberoende uppslagning vid instansieringspunkten"
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "deklarationer i beroende bas %qT hittas inte av en okvalificerad uppslagning"
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "använd %<this->%D%> istället"
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "använd %<%T::%D%> istället"
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, gcc-internal-format
 msgid "%q+D declared here, later in the translation unit"
 msgstr "%q+D är deklarerad här, senare i översättningsenheten"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT är inte en klass eller namnrymd"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD är inte en klass eller namnrymd"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr "%qT är/använder en anonym typ"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "mallargumentet för %qD använder lokal typ %qT"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT är en variabel typ"
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "heltalsuttryck %qE är inte konstant"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  försöker instansiera %qD"
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig mallinstansiering av %q#T"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig mallinstansiering av %q#D"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 msgid "%s %#S"
 msgstr "%s %#S"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explicit instansieringar av icke-mall %q#D"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD är inte en statisk datamedlem i en klassmall"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "det finns ingen matchande mall för %qD"
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "typ %qT för explicit instansiering %qD stämmer inte med deklarerad typ %qT"
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explicit instansiering av %q#D"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "dubblerad explicit instansiering av %q#D"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 förbjuder användning av %<extern%> vid explicita instansieringar"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklass %qD tillämpad på mallinstansiering"
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explicit instansieringar av mallen %q#D som inte är en klass"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explicit instansieringar av icke-malltyp %qT"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explicit instansiering av %q#T före definitionen av mallen"
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ förbjuder användning av %qE vid explicita instansieringar"
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "dubblerad explicit instansiering av %q#T"
@@ -40399,62 +40440,62 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explicit instansiering av %qD men ingen definition tillgänglig"
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d vid instansiering av %q+D, möjligen från generering av virtuell tabell (använd -ftemplate-depth= för att öka maxvärdet)"
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ogiltig mallparameter som inte är en typ"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T är inte en giltig typ för en mallparameter som inte är en typ"
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "härledning från klammeromgiven initierarlista kräver #include <initializer_list>"
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direkt listinitiering av %<auto%> tar precis ett element"
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "för härledning till %<std::initializer_list%>, använd kopielistinitiering (d.v.s. lägg till %<=%> före %<{%>)"
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT som en typ snarare en enkel %<decltype(auto)%>"
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "kan inte härleda lambdareturtyp från %qE"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan inte härleda %qT från %qE"
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "inkonsistenta typer %qT och %qT härledda för lambda-returtypen"
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "inkonsistent härledning för %qT: %qT och sedan %qT"
@@ -40691,260 +40732,260 @@
 msgid "invalid base-class specification"
 msgstr "ogiltig basklasspecifikation"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "kan inte fånga medlemmen %qD i anonym union"
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD är inte fångad"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "lambdat har ingen standardfångst"
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "lambda i lokal klass %q+T kan inte fånga variabler från det omgivande sammanhanget"
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "användning av lokal variabel med automatisk lagringsklass från en kringliggande funktion"
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "användning av parameter från den kringliggande funktionen"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "mallparameter %qD av typ %qT är inte tillåten i ett konstant heltalsuttryck eftersom den inte är av heltals- eller uppräkningstyp"
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "användning av namnrymden %q+D som uttryck"
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "användning av klassmall %qT som uttryck"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "begäran av medlem %qD är tvetydig i gitter av multipelt arv"
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD får inte finnas i ett konstantuttryck"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "typen på %qE är okänd"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT är inte ett uppräkningstyp"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Parameterpakets-__bases är endast giltiga i malldeklarationer"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "det går inte att applicera %<offsetof%> på destrueraren %<~%T%>"
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr "andra operanden till %<offsetof%> är varken en ensam identifierare eller en sekvens av medlemsåtkomster och vektorreferenser"
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "det går inte att använda %<offsetof%> på medlemsfunktion %qD"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr "offsetof inom icke-standardlayouttypen %qT är odefinierat"
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "användardefinierad reduktionsuppslagning är tvetydig"
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "%qE har ogiltig typ för %<reduction%>"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "användardefinierad reduktion med konstruerarinitierare för basklassen %qT"
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "linjär klausul tillämpad på en variabel som inte är heltal och inte pekare med typen %qT"
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "ett linjärt steguttryck måste vara ett heltal"
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD är inte en variabel i klausul %qs"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD förekommer mer än en gång i dataklausuler"
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD är inte en variabel i klausul %<firstprivate%>"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD är inte en variabel i klausul %<lastprivate%>"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr "num_threads-uttryck måste vara heltal"
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "uttryck för styckesstorlek för schemaläggning måste vara heltal"
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "%qs-längduttryck måste vara ett heltal"
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%qs längduttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, gcc-internal-format
 msgid "%<num_teams%> expression must be integral"
 msgstr "%<num_teams%>-uttryck måste vara heltal"
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%>-uttryck måste vara heltal"
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%>-uttryck måste vara heltal"
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "%<device%>-id måste vara ett heltal"
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "%<dist_schedule%> styckesstorleksuttryck måste vara heltal"
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD är inte en variabel i %<aligned%>-klausul"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE i %<aligned%>-klausul är varken en pekare eller en vektor eller en referens till pekare eller vektor"
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD förekommer mer än en gång i %<aligned%>-klausuler"
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "%<aligned%>-klausuls justeringsuttryck måste vara heltal"
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD är inte en variabel i %<depend%>-klausul"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr "%qE har referenstyp för %qs"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD är inte fil-, namnrymds- eller blockräckviddsvariabel"
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE-direktiv inte i %qT-definition"
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "skillnaden mellan %qE och %qD har inte heltalstyp"
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> använd med klassiterationsvariabeln %qE"
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> använder två olika uttryck för minne"
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "statisk försäkran misslyckades: %s"
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "icke-konstant villkor i statisk deklaration"
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "argument till decltype måste vara ett uttryck"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype kan inte lösa upp adressen till en överlagrad funktion"
@@ -40959,117 +41000,117 @@
 msgid "lambda-expression in a constant expression"
 msgstr "lambdauttryck i ett konstantuttryck"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "attributet %qE kan bara användas på klassdefinitioner i Java"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "attributet %qE kan bara användas på klassdefinitioner"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr "%qE är föråldrad, g++-vtabeller är nu COM-kompatibla som standard"
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "begärd init_priority är inte en heltalskonstant"
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "det går bara att använda attributet %qE på definitioner av objekt- eller klasstyp med filräckvidd"
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "begärd init_priority är utanför sitt intervall"
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "begärt init_priority är reserverad för internt bruk"
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "attributet %qE stödjs inte på denna plattform"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "omdeklaration av %qD lägger till abi-taggen %E"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "tidigare deklaration här"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "attributet %qE behöver argument"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argumenten till attributet %qE måste vara smala strängkonstanter"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argumenten till attributet %qE måste innehålla giltiga identifierare"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> är inte ett giltigt första tecken för en identifierare"
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> är inte ett giltig bokstav i en identifierare"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "attributet %qE använt på typen %qT som inte är en klass eller uppräkningstyp"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "attributet %qE använt på %qT efter dess definition"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "ignorerar attributet %qE använt på mallinstansieringen %qT"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "ignorerar attributet %qE använt på mallspecialiseringen %qT"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attributet %qE tillämpat på %qD som inte är en funktion eller variabel"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attributet %qE tillämpat på extern \"C\"-deklaration %qD"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "noll som en nollpekarkonstant"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_*-kontroll: misslyckades i %s, vid %s:%d"
@@ -41259,564 +41300,559 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr "ordningen på vektorns index är större än 1"
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr "ISO C++ förbjuder indexering av icke-lvalue-vektor"
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "indexering av vektor deklarerad %<register%>"
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indexerat värde är varken en vektor eller pekare"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objekt saknas i användning av %qE"
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ förbjuder anrop av %<::main%> inifrån program"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "man måste använda %<.*%> eller %<->*%> för att anropa en pekare-till-medlems-funktion i %<%E (...)%>, t.ex. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE kan inte användas som en funktion"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD kan inte användas som en funktion"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "uttryck kan inte användas som en funktion"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "för många argument till konstrueraren %q#D"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "för få argument till konstrueraren %q#D"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "för många argument till medlemsfunktionen %q#D"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "för få argument till medlemsfunktionen %q#D"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "för många argument till funktionen %q#D"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "för få argument till funktionen %q#D"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "för många argument till metoden %q#D"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "för få argument till metoden %q#D"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "för många argument till funktion"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "för få argument till funktion"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter %P till %qD har ofullständig typ %qT"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametern %P har ofullständig typ %qT"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "antar typkonvertering till %qT från överlagrad funktion"
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL använd i aritmetik"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "längd att rotera till vänster är negativ"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "längd att rotera till höger är negativ"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "längd att rotera till vänster ≥ storleken på typen"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "längd att rotera till höger ≥ storleken på typen"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr "jämförelse med strängkonstant resulterar i odefinierat beteende"
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "adressen till %qD kommer aldrig vara NULL"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ förbjuder jämförelse mellan pekare och heltal"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "operandtyper är %qT och %qT"
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "det går inte att hitta en heltalstyp med samma storlek som %qT"
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "oordnad jämförelse av argument som inte är flyttal"
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ogiltiga operander av typ %qT och %qT till binär %qO"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare av typ %<void *%> i subtraktion"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare till en funktion i subtraktion"
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare till en metod i subtraktion"
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ogiltig användning av en pekare till en ofullständig typ i pekararitmetik"
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, gcc-internal-format
 msgid "taking address of constructor %qE"
 msgstr "tar adressen till konstrueraren %qE"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, gcc-internal-format
 msgid "taking address of destructor %qE"
 msgstr "tar adressen till destrueraren %qE"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ogiltig användning av %qE för att skapa en pekare-till-medlem-funktion"
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  ett kvalificerat id krävs"
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parenteser runt %qE kan inte användas för att skapa en pekare-till-medlem-funktion"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ förbjuder att ta adressen till en okvalificerad eller parentetiserad icke-statisk medlemsfunktion för att skapa en pekare till en medlemsfunktion.  Säg %<&%T::%D%>"
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ förbjuder att ta adressen till en bunden medlemsfunktion för att skapa en pekare till medlemsfunktion.  Säg %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "tar adress till något temporärt"
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "tar adressen till xvalue (rvalue-referens)"
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ förbjuder att ta adressen till funktionen %<::main%>"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr "ISO C++ förbjuder att ta adressen till en typkonvertering till ett icke-lvärde-uttryck"
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "kan inte skapa pekare till referensmedlem %qD"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ förbjuder ökning av enum"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ förbjuder minskning av enum"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "det går inte att öka en pekare på en ofullständig typ %qT"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "det går inte att minska en pekare på en ofullständig typ %qT"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ förbjuder ökning av pekare på typ %qT"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ förbjuder minskning av pekare på typ %qT"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "ogiltigt användning av Booleskt uttryck som operand till %<operator--%>"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan inte ta adressen till %<this%>, som är ett rvalue-uttryck"
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adress till explicit registervariabel %qD begärd"
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adress begärd till %qD, som är deklarerad %<register%>"
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "listinitierare för en typ som inte är en klass får inte vara inom parenteser"
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "uttryckslista behandlas som sammansatt uttryck i initierare"
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "uttryckslista behandlas som sammansatt uttryck i medlemsinitierare"
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "uttryckslista behandlas som sammansatt uttryck i funtionstypkonvertering"
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "uttryckslistan %s behandlas som sammansatt uttryck"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "ingen kontext för att lösa upp typen på %qE"
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "konvertering från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, gcc-internal-format
 msgid "useless cast to type %qT"
 msgstr "oanvändbar konvertering till typen %qT"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "ogiltig static_cast från typ %qT till typ %qT"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "konvertering från %qT till %qT"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "ogiltig typkonvertering av ett rvärdeuttryck av typ %qT till typ %qT"
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr "konvertering från %qT till %qT förlorar precision"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "typkonvertering från %qT till %qT ökar kravet på justering för måltypen"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "typkonvertering mellan pekare-till-funktion och pekare-till-objekt stödjs villkorligt"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ogiltig konvertering från typ %qT till typ %qT"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ogiltig användning av const_cast med typ %qT, som inte är en pekare, referens, eller pekare-till-datamedlem-typ"
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "ogiltig användning av const_cast med typ %qT, som är en pekare eller referens till en funktionstyp"
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "ogiltig const_cast av ett rvärde av typ %qT till typ %qT"
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "ogiltig const_cast från typ %qT till typ %qT"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ förbjuder typkonvertering till en vektortyp %qT"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ogiltig konvertering till funktionstyp %qT"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  i beräkningen av %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "tilldelning till en vektor från en initierarlista"
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "inkompatibla typer i tilldelning av %qT till %qT"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "vektor använd som initierare"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "ogiltig vektortilldelning"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   i konvertering av pekare till medlemsfunktion"
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "konvertering av pekare till medlem via virtuell bas %qT"
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   i konvertering av pekare till medlem"
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ogiltig konvertering till typ %qT från typ %qT"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "kan inte konvertera %qT till %qT för argument %qP till %qD"
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "det går inte att konvertera %qT till %qT i standardargument"
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "det går inte att konvertera %qT till %qT när argument skickas"
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "det går inte att konvertera %qT till %qT"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "det går inte att konvertera %qT till %qT i initiering"
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "det går inte att konvertera %qT till %qT i retur"
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "det går inte att konvertera %qT till %qT i tilldelning"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "returtypen %qT är ofullständig"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "parameter %qP till %qD kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "parameter kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "målet för konvertering kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "målet för initialisering kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "vänsterhandssida av tilldelning kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "när argument %P till %q+D skickades"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "returnerar referens till en temporär"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "referens till annat än lvärde returnerad"
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr "referens till lokal variabel %q+D returnerad"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, gcc-internal-format
 msgid "address of label %q+D returned"
 msgstr "adressen till etiketten %q+D returnerad"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr "adress till lokal variabel %q+D returnerad"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "returnerar ett värde från en destruktor"
@@ -41823,45 +41859,45 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "det går inte att returnerar från en hanterare i ett funktions-try-block eller en konstruerare"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "returnerar ett värde från en konstruerare"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return-sats utan värde i funktion som returnerar %qT"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "returnerar en initierarlista"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "return-sats med värde i funktion som returnerar ”void”"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> får inte returnera NULL om den inte är deklarerad %<throw()%> (eller -fcheck-new är aktivt)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "använder temporär som lvärde"
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "hjälp xvärde (rvärdesreferens) som lvärde"
@@ -42087,122 +42123,122 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr "avsmalnande konvertering av %qE från %qT till %qT inuti { } är felaktig i C++11"
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "avsmalnande konvertering av %qE från %qT till %qT inuti { }"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-vektor initierad från icke-bred sträng"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-vektor initierad från inkompatibel bred sträng"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "initierarsträng för vektor av tecken är för stor"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "det går inte att initiera aggregat med typ %qT med en sammansatt literal"
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "vektorer måste initieras med en initierare inom klamrar"
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "initierare saknas för medlem %qD"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "medlem %qD är oinitierad referens"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlem %qD med oinitierade referensfält"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "inget fält %qD finns i unionen som initieras"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indexvärde istället för fältnamn i unioninitierare"
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "cirkulär pekardelegering detekterad"
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "basoperanden till %<->%> har icke-pekartyp %qT"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet av %<operator->()%> ger annat än pekare"
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "basoperanden till %<->%> är inte en pekare"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kan inte användas som en medlemspekare eftersom den är av typen %qT"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "det går inte att applicera medlemspekare %qE på %qE, som är av typ %qT som inte är en klass"
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "pekare-på-medlemstyp %qT är inkompatibel med objekttyp %qT"
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pekare-till-medlemsfunktionstyp %qT kräver ett r-värde"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pekare-till-medlemsfunktiontyp %qT kräver ett l-värde"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionell konvertering till vektortypen %qT"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ogiltig värdeinitiering av referenstyper"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "anrop till funktion %qD som kastar ofullständig typ %q#T"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "anrop till funktion som kastar ofullständig typ %q#T"
@@ -42379,8 +42415,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr "Co-vektorer avaktiverade vid %C, använd %<-fcoarray=%> för att aktivera"
@@ -42515,7 +42551,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr "Vektorkonstruerare med typspecifikation vid %C"
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Typspecifikation vid %L kan inte innehålla ha en fördröjd typparameter"
@@ -42631,7 +42667,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara INTEGER eller PROCEDURE"
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara en konstant"
@@ -43218,12 +43254,12 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "%<source%>-argumentet till inbyggd %<shape%> vid %L får inte vara en vektor med antagen storlek"
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "Argument %qs till inbyggd %qs vid %L får inte vara en procedur"
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "Argumentet %qs till inbyggd %qs vid %L skall inte vara TYPE(*)"
@@ -43493,6 +43529,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara INTEGER eller LOGICAL"
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr "Den inbyggda funktionen NULL vid %L kan inte vara ett aktuellt argument till STORATE_SIZE, eftersom den returnerar en disassocierad pekare"
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -43500,7 +43541,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "Maximal utökningsnivå nådd med typen %qs vid %L"
@@ -43720,399 +43761,399 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Variabeln %qs vid %C med en initierare finns redan i en DATA-sats"
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "Det går inte att initiera en vektor med antagen form vid %L med en skalär"
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Lägre gräns som inte är konstant i förmodat formad deklaration vid %L"
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Komponent vid %C måste ha attributet POINTER"
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Vektorkomponent i post vid %C måste ha fördröjd form"
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Pekarvektorkomponent i post vid %C måste ha fördröjd form"
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Allokerbar komponent i post vid %C måste ha fördröjd form"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Vektorkomponent i post vid %C måste ha uttrycklig form"
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL()-initiering vid %C är tvetydig"
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "NULL()-initiering vid %C kan inte ha MOLD"
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Initiering av pekare vid %C är inte tillåtet i en PURE-procedur"
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Fel i pekarinitiering vid %C"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "annan pekarinitiering än NULL vid %C"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, gcc-internal-format
 msgid "Function name %qs not allowed at %C"
 msgstr "Funktionsnamnet %qs är inte tillåtet vid %C"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr "Icke-PARAMETER-symbolen %qs vid %L kan inte ha antagen form"
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Vektor med antagen form vid %L"
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Dubblerad vektorspecifikation för Cray-utpekad vid %C"
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr "Kunde inte sätta utpekads vektorspecifikation."
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Gammaldags initiering vid %C"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "Felaktig gammaldags initiering av härledd typkomponent vid %C"
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Initieringen vid %C är inte för en pekarvariabel"
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Pekarinitiering vid %C kräver %<=>%>, inte %<=%>"
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Ett initieringsuttryck förväntades vid %C"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Initiering av variabel vid %C är inte tillåtet i en PURE-procedur"
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Initiering av allokerbar komponent vid %C är inte tillåtet"
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Gammaldags typdeklaration %s*%d stödjs inte vid %C"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Typdeklaration ej enligt standard %s*%d vid %C"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Saknad högerparentes vid %C"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Initieringsuttryck förväntades vid %C"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Ett skalärt initieringsuttryck förväntades vid %C"
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Sorten %d stödjs inte för typen %s vid %C"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Parameter med sort C är för typ %s men typen vid %L är %s"
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Högerparentes eller komma saknas vid %C"
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Sorten %d stödjs inte för typen CHARACTER vid %C"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Syntaxfel i CHARACTER-deklaration vid %C"
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "BYTE-typ vid %C"
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "BYTE-typ använd vid %C är inte tillgänglig på målmaskinen"
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Förmodad typ vid %C är inte tillåtet för komponenter"
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Antagen typ vid %C"
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "TYPE med inbyggd typspecifikation vid %C"
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "DOUBLE COMPLEX vid %C"
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "CLASS-sats vid %C"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Typnamnet %qs vid %C är tvetydigt"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "Typnamnet ”%s” vid %C står i konflikt med tidigare deklarerad enhet vid %L, som har samma namn"
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Dubblerad IMPLICIT NONE-sats vid %C"
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr "IMPORT NONE med specifikationslista vid %C"
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Teckenintervall saknas i IMPLICIT vid %C"
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Bokstäver måste vara i alfabetisk ordning i IMPLICIT-sats vid %C"
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "IMPLICIT-sats vid %C följer en IMPLICIT NONE (type)-sats"
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Tom IMPLICIT-sats vid %C"
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "IMPORT-sats vid %C endast tillåten inuti en INTERFACE-kropp"
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "IMPORT-sats vid %C"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Lista med namngivna entiteter förväntades vid %C"
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "Det går inte att IMPORT:era %qs från värdräckviddsenhet vid %C — finns inte."
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "%qs är redan IMPORT:erad från värdräckviddsenhet vid %C."
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Syntaxfel i IMPORT-sats vid %C"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Co-dimensionsspecifikation saknas vid %C"
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Dimensionsspecifikation saknas vid %C"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Dubblerat %s-attribut vid %L"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Attributet ALLOCATABLE vid %C i en TYPE-definition"
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Attribut vid %L är inte tillåtet i en TYPE-definition"
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attributet %s vid %L i en TYPE-definition"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s-attribut vid %L är inte tillåtet utanför specifikationsdelen av en modul"
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Attributet ASYNCHRONOUS vid %C"
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Attributet CONTIGUOUS vid %C"
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED vid %C är endast tillåtet i specifikation av en del av en modul"
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Attributet PROTECTED vid %C"
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Attributet VALUE vid %C"
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Attributet VOLATILE vid %C"
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Felaktigt attribut"
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Flera identifierare angivna med en ensam NAME=-specificerare vid %C"
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "Implicit deklarerad BIND(C)-funktion %qs vid %L kan inte vara C-interoperativ"
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Variabeln %qs i common-blocket %qs vid %L får inte vara en sort interoperativ med C men common-blocket %qs är BIND(C)"
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Typdeklaration %qs vid %L är inte C-interoperativ men den är BIND(C)"
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Variabeln %qs vid %L får inte ha en C-interoperativ sort men den är BIND(C)"
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Variabeln %qs i common-blocket %qs vid %L får inte deklareras med BIND(C) eftersom den inte är en global"
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Variabeln %qs vid %L får inte ha både attributet POINTER och BIND(C)"
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Variabeln %qs vid %L får inte ha både attributet ALLOCATABLE och BIND(C)"
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Returtyp till BIND(C)-funktion %qs vid %L kan inte vara en vektor"
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "Returtyp till BIND(C)-funktion %qs vid %L kan inte vara en teckensträng"
@@ -44119,795 +44160,800 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Symbolen %qs vid %L är markerad PRIVATE men har getts bindningsetiketten %qs"
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Det behövs antingen entitet- eller common-blocknamn för attributspecifikationssatsen vid %C"
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Entitets- eller common-blocknamn saknas till attributspecifikationssats vid %C"
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Symbol saknas"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "BIND(C)-sats vid %C"
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Härledd typ vid %C har inte definierats tidigare och kan därför inte förekomma i en härledd typdefinition"
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Syntaxfel i datadeklaration vid %C"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "IMPURE-procedur vid %C"
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE och IMPURE får inte båda finnas vid %C"
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "Alternativt returargument vid %C"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Namnet %qs vid %C är namnet på proceduren"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Oväntat skräp i formell argumentlista vid %C"
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Dubblerad symbol %qs i formell argumentlista vid %C"
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT-variabel vid %C måste vara skilt från funktionsnamnet"
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Oväntat skräp efter funktionsdeklaration vid %C"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Attributet BIND(C) vid %L kan inte anges för en intern procedur"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "Attribut BIND(C) vid %C kräver ett gränssnitt med BIND(C)"
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "BIND(C)-procedur med NAME får inte ha attributet POINTER vid %C"
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Attrapprocedur vid %C kan inte ha attributet BIND(c) tillsammans med NAME"
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Proceduren %qs vid %L har redan en grundtyp %s"
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Syntaxfel i PROCEDURE-sats vid %C"
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%<::%> förväntades efter bindningsattribut vid %C"
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS eller explicit gränssnitt krävs vid %C"
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Procedurpekarkomponent vid %C"
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Syntaxfel i procedurpekarkomponent vid %C"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE vid %C måste vara i ett generiskt gränssnitt"
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "dubbelkolon i MODULE PROCEDURE-sats vid %L"
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "PROCEDURE-sats vid %C"
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Formell argumentlista förväntades i funktionsdefinitionen vid %C"
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "Attribut BIND(C) vid %L kan endast användas för variabler och common-block"
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "ENTRY-sats vid %C"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett PROGRAM"
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti en MODULE"
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett BLOCK DATA"
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett INTERFACE"
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti en ett DERIVED TYPE-block"
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett IF-THEN-block"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett DO-block"
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett SELECT-block"
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett FORALL-block"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett WHERE-block"
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett inneslutet underprogram"
 
-#: fortran/decl.c:5597
-#, gcc-internal-format
-msgid "gfc_match_entry(): Bad state"
-msgstr "gfc_match_entry(): Felaktigt tillstånd"
+#: fortran/decl.c:5595
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected ENTRY statement at %C"
+msgstr "Oväntad ENTRY-sats vid %C"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "ENTRY-sats vid %C kan inte förekomma i en innesluten procedur"
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Nödvändig parentes saknas före BIND(C) vid %C"
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Ogiltig C-identifierare i NAME=-specificerare vid %C"
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Syntaxfel i NAME=-specifikation för att binda etikett vid %C"
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "NAME=-specificerare vid %C skall vara ett konstant uttryck"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr "NAME=-specificerare vid %C skall vara en skalär av standardteckensort"
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Slutparentes saknas för att binda etikett vid %C"
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Inget bindningsnamn är tillåtet i BIND(C) vid %C"
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "För attrapprocedur %s är inget bindningsnamn tillåtet i BIND(C) vid %C"
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME är inte tillåtet på BIND(C) för ABSTRACT INTERFACE vid %C"
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Oväntad END-sats vid %C"
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "END-sats istället för %s-sats vid %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-sats förväntades vid %L"
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "%s-sats förväntades vid %L"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Blocknamn på %qs i %s-sats förväntades vid %L"
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Avslutande namn förväntades vid %C"
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Etikett %qs för %s-sats förväntades vid %C"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Vektorspecifikation saknas vid %L i DIMENSION-sats"
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr "Dimensioner angivna för %s vid %L efter dess initiering"
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Vektorspecifikation saknas vid %L i CODIMENSION-sats"
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Vektorspecifikation måste vara fördröjd vid %L"
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Oväntat tecken i variabellista vid %C"
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> förväntades vid %C"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Variabelnamn förväntades vid %C"
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray-pekare vid %C måste vara ett heltal"
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray-pekare vid %C har %d bytes precision, minnesadresser kräver %d byte"
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "”,” förväntades vid %C"
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr "Kunde inte sätta Cray-utpekad vektorspecifikation."
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "”)” förväntades vid %C"
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%<,%> eller slut på sats förväntades vid %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT är inte tillåtet inuti BLOCK vid %C"
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL är inte tillåtet inuti BLOCK vid %C"
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Cray-pekardeklaration vid %C kräver flaggan -fcray-pointer"
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "CONTIGUOUS-sats vid %C"
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Åtkomstspecifikation av operatorn %s vid %C har redan angivits"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Åtkomstspecifikation för operatorn .%s. vid %C har redan angivits"
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "PROTECTED-sats vid %C"
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaxfel i PROTECTED-sats vid %C"
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PRIVATE-sats vid %C får endast förekomma i specifikationsdelen av en modul"
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PUBLIC-sats vid %C får endast förekomma i specifikationsdelen av en modul"
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Variabelnamn förväntades vid %C i PARAMETER-sats"
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "=-tecken i PARAMETER-sats förväntades vid %C"
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Uttryck förväntades vid %C i PARAMETER-sats"
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initierar redan initierad variabel vid %C"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Oväntade tecken i PARAMETER-sats vid %C"
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Allmän SAVE-sats vid %C följer tidigare SAVE-sats"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "SAVE-sats vid %C följer allmän SAVE-sats"
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Syntaxfel i SAVE-sats vid %C"
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE är inte tillåtet inuti BLOCK vid %C"
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "VALUE-sats vid %C"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Syntaxfel i VALUE-sats vid %C"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "VOLATILE-sats vid %C"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "VOLATILE anges för co-vektorvariabel %qs vid %C, vilket är use-/host-associerat"
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Syntaxfel i VOLATILE-sats vid %C"
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "ASYNCHRONOUS-sats vid %C"
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Syntaxfel i ASYNCHRONOUS-sats vid %C"
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE vid %C måste vara i ett generiskt modulgränssnitt"
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Den inbyggda proceduren vid %L kan inte vara en MODULE PROCEDURE"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Tvetydig symbol i TYPE-definition vid %C"
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Symbolen %qs vid %C har inte definierats tidigare"
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "%qs i EXTENDS-uttryck vid %C är inte en härledd typ"
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%qs kan inte utökas vid %C för att den är BIND(C)"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qs kan inte utökas vid %C eftersom det är en SEQUENCE-typ"
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Härledd typ vid %C kan endast vara PRIVATE i specifikationsdelen av en modul"
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Härledd typ vid %C kan endast vara PUBLIC i specifikationsdelen av en modul"
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "ABSTRACT typ vid %C"
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ":: förväntades i TYPE-definition vid %C"
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typnamnet %qs vid %C kan inte vara samma som en inbyggd typ"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Härlett typnamn %qs vid %C har redan en grundtyp %s"
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Härledd typdefinition %qs vid %C har redan definierats"
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray-utpekad vid %C kan inte vara förmodat formad vektor"
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM och ENUMERATOR vid %C"
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Uppräkningstypen överskrider C:s heltalstyp vid %C"
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L är inte initierad med ett heltalsuttryck"
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM-definitionssats förväntades före %C"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Syntaxfel i ENUMERATOR-definition vid %C"
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Dubblerad åtkomstspecifikation vid %C"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Bindningsattribut anger redan passing, otillåten NOPASS vid %C"
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Bindningsattribut anger redan passing, otillåten PASS vid %C"
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Dubblerat POINTER-attribut vid %C"
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Dubblerad NON_OVERRIDABLE vid %C"
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Dubblerad DEFERRED vid %C"
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Åtkomstspecificerare förväntades vid %C"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Bindningsattribut förväntades vid %C"
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE och DEFERRED kan inte båda finnas vid %C"
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "POINTER-attribut krävs för procedurpekarkomponenten vid %C"
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Gränssnittsnamn förväntades efter %<(%> vid %C"
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> förväntades vid %C"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Gränssnitt måste anges för DEFERRED bindning vid %C"
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) vid %C skulle vara deklarerat DEFERRED"
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Bindningsnamn förväntades vid %C"
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "PROCEDURE-lista vid %C"
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> mål%> är ogiltigt för DEFERRED-bindning vid %C"
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%<::%> behövs i PROCEDURE-bindning med explicit mål vid %C"
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Bindningsmål förväntades efter %<=>%> vid %C"
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "Typen %qs som innehåller en DEFERRED-bindning vid %C är inte ABSTRACT"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Det finns redan en procedur med bindningsnamnet %qs för den härledda typen %qs vid %C"
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC vid %C måste vara inuti en härledd typs CONTAINS"
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> förväntades vid %C"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Generiskt namn eller operatorbeskrivare förväntades vid %C"
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, gcc-internal-format, gfc-internal-format
+msgid "Malformed GENERIC statement at %C"
+msgstr "Felformad GENERIC-sats vid %C"
+
+#: fortran/decl.c:8526
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "%<=>%> förväntades vid %C"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Det finns redan en icke-generisk procedur med bindningsnamnet %qs för den härledda typen %qs vid %C"
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Bindning vid %C måste ha samma åtkomst som den redan definierade bindningen %qs"
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Specifikt bindningsnamn förväntades vid %C"
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%qs är redan definierat som en specifik bindning för den generiska %qs vid %C"
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Skräp efter GENERIC-bindning vid %C"
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "FINAL-deklaration vid %C måste vara inuti en härledd typs CONTAINS-sektion"
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Härledd typdeklaration med FINAL vid %C måste vara med i specifikationsdelen av en MODULE"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Tom FINAL vid %C"
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Modulprocedurnamn förväntades vid %C"
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> förväntades vid %C"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Okänt procedurnamn %qs vid %C"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "%qs vid %C är redan definierad som FINAL procedur"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Okänt attribut i !GCC$ ATTRIBUTES-sats vid %C"
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Syntaxfel i !GCC$ ATTRIBUTES-sats vid %C"
@@ -45187,342 +45233,342 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "Olika form för %s vid %L på dimension %d (%d och %d)"
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "%qs vid %L är inte ett VALUE"
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Inkompatibla ordningar %d och %d i tilldelning vid %L"
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "Variabeltypen är OKÄND i tilldelning vid %L"
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "NULL finns på högersidan i tilldelning vid %L"
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "POINTER-värd funktion förekommer på högersidan av tilldelning vid %L"
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "BOZ-literal vid %L används för att initiera icke-heltalsvariabeln %qs"
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "BOZ-literal vid %L utanför en DATA-sats och utanför INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "BOZ-literal vid %L är bitvis överförd icke-heltalssymbol %qs"
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetiskt underspill av bitvis överförd BOZ vid %L.  Denna kontroll kan avaktiveras med flaggan %<-fno-range-check%>"
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetiskt överspill vid bitvis överförd BOZ vid %L.  Denna kontroll kan avaktiveras med flaggan %<-fno-range-check%>"
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetisk NaN vid bitvis överförd BOZ vid %L.  Denna kontroll kan avaktiveras med flaggan %<-fno-range-check%>"
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, gcc-internal-format
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "Ändring av värde vid konvertering från %qs till %qs vid %L"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, gcc-internal-format
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "Möjlig ändring av värde vid konvertering från %qs till %qs vid %L"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, gcc-internal-format
 msgid "Conversion from %qs to %qs at %L"
 msgstr "Konvertering från %qs till %qs vid %L"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Inkompatibla typer i DATA-sats vid %L, försökte med konvertering av %s till %s"
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Pekartilldelningsmålet är inte en POINTER vid %L"
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "%qs i pekartilldelningen vid %L kan inte vara ett l-värde eftersom det är en procedur"
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Begränsningsspecifikation för %qs förväntades vid %L"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Begränsningsspecifikation för %qs i pekartilldelning vid %L"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr "Undre gräns måste finnas vid %L"
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Steg får inte finnas vid %L"
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr "Antingen alla eller ingen av de övre gränserna måste anges vid %L"
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Pekarobjektet vid %L kan inte ha ett co-index"
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Ogiltig procedurpekartilldelning vid %L"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Funktionsresultatet %qs är ogiltigt i proc-mål i procedurpekartilldelning vid %L"
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Abstrakt gränssnitt %qs är ogiltigt i procedurpekartilldelning vid %L"
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Satsfunktion %qs är ogiltigt i procedurpekartilldelning vid %L"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intern procedur %qs är ogiltigt i procedurpekartilldelning vid %L"
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Inbyggd %qs vid %L är ogiltigt i procedurpekartilldelning"
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Den ej inbyggda elementära proceduren %qs är ogiltig i procedurpekartilldelning vid %L"
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "Det stämmer inte i procedurpekartilldelningen vid %L: anropskonventionen stämmer inte"
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Explicit gränssnitt krävs för %qs vid %L: %s"
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Gränssnitten stämmer inte överens i procedurpekartilldelning vid %L: %s"
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr "Procedurpekarmålet %qs vid %L måste vara antingen en inbyggd, värd, värd- eller användningsassocierad, refererad eller ha attributet EXTERNAL"
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr "Datapekarobjekt &L måste vara obegränsat polymorft, en sekvens härledd typ eller av en typ med attibutet BIND-tilldelning vid %L för att vara kompatibel med ett obegränsat polymorft mål"
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Olika typer i pekartilldelning vid %L, försökte med tilldelning av %s till %s"
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Olika sorters typparametrar i pekartilldelning vid %L"
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Olika ordning i pekartilldelning vid %L"
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "Målet för översättning av ordningen är mindre än storleken på pekaren (%ld < %ld) vid %L"
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "Målet för översättning av målet måste ha ordning 1 eller vara enkelt sammanhängande vid %L"
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Målet för översättning av ordning är inte av ordning 1 vid %L"
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Måluttryck i pekartilldelning vid %L måste leverera ett pekarresultat"
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Pekartilldelningsmål är vare sig TARGET eller POINTER vid %L"
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Felaktigt mål i pekartilldelning i PURE-procedur vid %L"
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Pekartilldelning med vektorindexering på högersidan vid %L"
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Pekartilldelningsmålet har attributet PROTECTED vid %L"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "Datamålet vid %L får inte ha co-index"
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Pekare vid %L i pekartilldelning kan överleva pekarmålet"
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Pekarinitieringsmål vid %L får inte vara ALLOCATABLE"
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Målet för pekarinitieringen vid %L måste ha attributet TARGET"
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Pekarinitieringsmål vid %L måste ha attributet SAVE"
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Procedurpekarinitieringsmål vid %L får inte vara en procedurpekare"
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Pekarfunktioner i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Icke variabelt uttryck i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Namngiven konstant %qs i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs i variabeldefinitionssammanhang (%s) vid %L är inte en variabel"
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Icke-POINTER i pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Attrappargument %qs med INTENT(IN) i pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Attrappargument %qs med INTENT(IN) i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Variabeln %qs är PROTECTED och kan inte förekomma i ett pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "Variabeln %qs är PROTECTED och kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variabeln %qs kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "%qs vid %L som är associerad med vektorindexerat mål kan inte användas i ett variabeldefinitionssammanhang (%s)"
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "%qs vid %L som är associerad med uttryck kan inte användas i ett variabeldefinitionssammanhang (%s)"
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Associationsnamn ”%s” kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L eftersom dess mål vid %L inte heller kan"
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Element med samma värde vid %L och %L i vektorindex i ett variabeldefinitionssammanhang (%s)"
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "Kan inte öppna indatafil: %s"
@@ -45544,27 +45590,27 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Tar bort anrop av funktionen %qs vid %L"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "otillåten OP i optimize_comparison"
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr "Variabeln ”%s” vid %L satt till odefinierad inuti en slinga som börjar vid %L är argument INTENT(OUT) till subrutin ”%s”"
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr "Variabeln ”%s” vid %L ej definierbar inuti slingan som börjar vid %L är argument INTENT(INOUT) till subrutin ”%s”"
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr "Variabeln ”%s” vid %L satt till odefinierad inuti slingan som börjar vid %L är argument INTENT(OUT) till funktionen ”%s”"
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr "Variabeln ”%s” vid %L ej definierbar inuti slingan som börjar vid %L är argument INTENT(INOUT) till funktionen ”%s”"
@@ -45619,592 +45665,597 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr "%<END INTERFACE ASSIGNMENT (=)%> förväntades vid %C"
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr "%<END INTERFACE OPERATOR (%s)%> förväntades vid %C"
+
+#: fortran/interface.c:353
+#, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr "%<END INTERFACE OPERATOR (%s)%> förväntades vid %C, men fick %s"
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr "%<END INTERFACE OPERATOR (.%s.)%> förväntades vid %C"
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr "%<END INTERFACE %s%> förväntades vid %C"
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr "Alternativ retur får inte förekomma i operatorgränssnitt vid %L"
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr "Gränssnitt för tilldelningsoperator vid %L måste ha två argument"
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr "Operatorgränssnitt vid %L har fel antal argument"
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr "Gränssnitt för tilldelningsoperator vid %L måste vara en SUBROUTINE"
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr "Gränssnitt för tilldelningsoperator vid %L får inte omdefiniera en INTRINSIC-typtilldelning"
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr "Gränssnitt för inbyggd operator vid %L måste vara en FUNCTION"
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr "Första argumentet till definierad tilldelning vid %L måste vara INTENT(OUT) eller INTENT(INOUT)"
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Andra argumentet av definierad tilldelning vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Första argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Andra argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr "Operatorgränssnitt vid %L står i konflikt med inbyggt gränssnitt"
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr "check_dummy_characteristics: Oväntat resultat %i från gfc_dep_compare_expr"
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr "check_result_characteristics (1): Oväntat resultat %i från gfc_dep_compare_expr"
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr "check_result_characteristics (2): Oväntat resultat %i från gfc_dep_compare_expr"
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr "Proceduren %qs i %s vid %L har inget explicit gränssnitt"
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr "Proceduren %qs i %s vid %L är varken en funktion eller subrutin"
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr "I %s vid %L måste procedurerna antingen alla vara SUBROUTINE eller alla vara FUNCTION"
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr "I %s vid %L måste alla procedurerna vara FUNCTION eftersom det generiska namnet också är namnet på en härledd typ"
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
 msgstr "Intern procedur %qs i %s vid %L"
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, gcc-internal-format
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr "Tvetydiga gränssnitt %qs och %qs i %s vid %L"
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, gcc-internal-format
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "Fast orefererad har %qs tvetydiga gränssnitt vid %L"
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "%qs vid %L är inte en modulprocedur"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Vektor med antagen ordning vid %L kräver att attrappargumentet %qs har antagen ordning"
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Ordning stämmer inte i argument %qs vid %L (skalär och ordning %d)"
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Ordning stämmer inte i argument %qs vid %L (ordning %d och skalär)"
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Ordning stämmer inte i argument %qs vid %L (ordning %d och ordning %d)"
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Ogiltigt procedurargument vid %L"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Gränssnitt stämmer inte överens i attrapprocedur %qs vid %L: %s"
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "Aktuellt argument till sammanhängande pekareattrapp %qs vid %L måste vara enkelt sammanhängande"
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Typ stämmer inte i argument %qs vid %L; skickade %s till %s"
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Aktuellt argument med antagen typ vid %L kräver att attrappargumentet %qs har antagen typ"
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Aktuellt argument till %qs vid %L måste vara polymorft"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Aktuellt argument till %qs vid %L måste ha samma deklarerade typ"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "Aktuella argument till %qs vid %L måste vara obegränsat polymorfa eftersom det formella argumentet är en pekare eller allokerbar obegränsat polymorf enhet [F2008: 12.5.2.5]"
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Aktuellt argument till %qs vid %L måste vara en co-vektor"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Co-ordning stämmer inte i argument %qs vid %L (%d och %d)"
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "Aktuellt argument till %qs vid %L måste vara enkelt sammanhängande"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Aktuellt argument till icke-INTENT(INOUT)-attrappen %qs vid %L, som är LOCK_TYPE eller har en LOCK_TYPE-komponent"
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "Attrappargument %qs måste vara en pekare, vektor med antagen form eller ordning utan attributet CONTIGUOUS - eftersom det aktuella argumentet vid %L inte är enkelt sammanhängande och båda är ASYNCHRONOUS eller VOLATILE"
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Skickar co-vektor vid %L till allokerbart, icke co-vektor, INTENT(OUT) attrappargument %qs"
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Skickar co-vektor vid %L till allokerbart, icke co-vektor attrappargument %qs, som är ogiltigt om allokeringsstatusen ändras"
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Polymorf skalär skickad till vektorattrappargument %qs vid %L"
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr "Element av vektor med antagen form eller pekare skickat till vektorattrappargument %qs vid %L"
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Utökning: Skalärt CHARACTER-argument som inte är av standardsort och inte C_CHAR-sort med vektorattrappargument %qs vid %L"
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Aktuellt skalärt CHARACTER-argument med attrappargument som är vektor %qs vid %L"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Nyckelordsargument %qs vid %L finns inte i proceduren"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Nyckelordsargumentet %qs vid %L är redan associerat med ett annat aktuellt argument"
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Fler aktuella än formella argument i proceduranrop vid %L"
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Alternativ returspecifikation saknas i subrutinanrop vid %L"
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr "Oväntad alternativ returspecifikation i subrutinanrop vid %L"
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Oväntad inbyggd NULL() vid %L till attrapp %qs"
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Nollpekare vid %L till icke-pekareattrapp %qs"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr "Aktuellt argument vid %L till attrapp med antagen typ är av en härledd typ med typgräns eller FINAL-procedurer"
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Teckenlängd stämmer inte (%ld/%ld) mellan aktuellt argument och pekare eller allokerbart attrappargument %qs vid %L"
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Teckenlängd stämmer inte (%ld/%ld) mellan aktuellt argument och attrappargument med antagen form %qs vid %L"
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "Aktuellt argument vid %L till allokerbart eller pekarattrappargument %qs måste ha en fördröjd längdtypparameter om och endast om attrappen har en"
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Teckenlängden på aktuellt argument är kortare än attrappargumentet %qs (%lu/%lu) vid %L"
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Aktuellt argument innehåller för få element för attrappargument %qs (%lu/%lu) vid %L"
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "En procedurpekare förväntade som argument %qs vid %L"
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Förväntade en procedur som argument %qs vid %L"
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Aktuellt argument till %qs kan inte vara en vektor med antagen storlek vid %L"
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Aktuellt argument till %qs skall vara en pekare vid %L"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Aktuellt argument som inte är en pekare vid %L till pekarattrapp %qs"
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Co-indexerat faktiskt argument vid %L till pekareattrapp %qs"
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Co-indexerat aktuellt argument vid %L till allokerbar attrapp %qs kräver INTENT(IN)"
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Co-indexerat ASYNCHRONOUS eller VOLATILE aktuellt argument vid %L kräver att attrappen %qs varken har ASYNCHRONOUS eller VOLATILE"
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Co-indexerat faktiskt argument vid %L med allokerbar slutlig komponent till attrappen %qs kräver antingen VALUE eller INTENT(IN)"
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Aktuellt CLASS-vektorargument till %qs måste vara en fullständig vektor vid %L"
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Aktuellt argument till %qs skall vara en ALLOCATABLE vid %L"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Vektorsektion som aktuellt argument med vektorindex vid %L är inte kompatibelt med attributet INTENT(OUT), INTENT(INOUT), VOLATILE eller ASYNCHRONOUS på attrappargumentet %qs"
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Aktuellt argument med antagen form vid %L är inte kompatibel med attrappargumentet %qs utan antagen form på grund av attributet VOLATILE"
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Vektorsektion som aktuellt argument vid %L är inkompatibelt med attrappargumentet %qs utan antagen form på grund av attributet VOLATILE"
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Pekarvektor som aktuellt argument vid %L kräver ett attrappargument %qs med antagen form eller pekarvektor på grund av attributet VOLATILE"
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Aktuellt argument saknas för argument %qs vid %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Felaktig komponentkod"
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Listor stämmer inte"
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr "check_some_aliasing(): trasig data"
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Samma aktuella argument associerat med INTENT(%s)-argument %qs och INTENT(%s)-argument %qs vid %L"
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Listor stämmer inte"
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Procedurargument vid %L är lokalt i en PURE-procedur och har attributet POINTER"
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Co-indexerat aktuellt argument vid %L i en PURE-procedur skickas till ett INTENT(%s)-argument"
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Co-indexerat aktuell argument vid %L i en PURE-procedur skickas till ett POINTER-attrappargument"
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Co-indexerat polymorft aktuellt argument vid %L skickas ett polymorft attrappargument %qs"
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Proceduren %qs anropad vid %L är inte explicit deklarerad"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Procedur %qs anropad med ett implicit gränssnitt vid %L"
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Pekarobjektet %qs vid %L måste ha ett explicit funktionsgränssnitt eller deklareras som vektor"
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Det allokerbara objektet %qs vid %L måste ha ett explicit funktionsgränssnitt eller deklareras som vektor"
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Allokerbar funktion %qs vid %L måste ha ett explicit funktionsgränssnitt"
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Nyckelordsargument kräver explicit gränssnitt för proceduren %qs vid %L"
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Argumentet ”%s” med antagen typ vid %L kräver ett explicit gränssnitt"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Aktuellt argument till LOCK_TYPE eller med LOCK_TYPE-komponent vid %L kräver ett explicit gränssnitt för proceduren %qs"
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "MOLD-argumentet till NULL krävs vid %L"
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Argumentet med antagen ordning kräver ett explicit gränssnitt vid %L"
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Procedurpekarkomponent %qs anropad med ett implicit gränssnitt vid %L"
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Nyckelordsargument kräver explicit gränssnitt för procedurpekarkomponent %qs vid %L"
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "MOLD= krävs i NULL()-argument vid %L: Tvetydighet mellan de specifika funktionerna %s och %s"
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Kan inte hitta symbolen %qs"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Entiteten %qs vid %L finns redan i gränssnittet"
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Felaktig gränssnittstyp"
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, gcc-internal-format
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr "Det går inte att skriva över GENERIC %qs vid %L"
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%qs vid %L åsidosätter en procedurbindning deklarerad NON_OVERRIDABLE"
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%qs vid %L får inte vara DEFERRED eftersom det åsidosätter en ej DEFERRED bindning"
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%qs vid %L åsidosätter en PURE-procedur och måste också vara PURE"
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs vid %L åsidosätter en ELEMENTAL-procedur och måste också vara ELEMENTAL"
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs vid %L åsidosätter en icke-ELEMENTAL-procedur och får inte heller vara ELEMENTAL"
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%qs vid %L åsidosätter en SUBROUTINE och måste också vara en SUBROUTINE"
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs vid %L åsidosätter en FUNCTION och måste också vara en FUNCTION"
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Resultaten stämmer inte överens för den åsidosättande proceduren %qs vid %L: %s"
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%qs vid %L åsidosätter en PURE-procedur och får inte vara PRIVATE"
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Attrappargument %qs till %qs vid %L skulle ha namnet %qs för att stämma med motsvarande argument i den åsidosatta proceduren"
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Argument stämmer inte överens för den åsidosättande proceduren %qs vid %L: %s"
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%qs vid %L måste ha samma antal formella argument som den åsidosatta proceduren"
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs vid %L åsidosätter en NOPASS-bindning och måste också vara NOPASS"
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%qs vid %L åsidosätter en bindning med PASS och måste också vara PASS"
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Attrappargument för pass-objekt till %qs vid %L måste vara på samma position som attrappargumentet för pass-objektet i den åsidosatta proceduren"
@@ -46614,12 +46665,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "ASYNCHRONOUS= vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "BLANK= vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "DECIMAL= vid %C är inte tillåtet i Fortran 95"
@@ -46629,7 +46680,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "ENCODING= vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "ROUND= vid %C är inte tillåtet i Fortran 95"
@@ -46654,776 +46705,776 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "UNIT-tal i CLOSE-sats vid %L måste vara ickenegativt"
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s-sats är inte tillåtet i PURE-procedur vid %C"
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "UNIT-tal i sats vid %L måste vara ickenegativt"
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "FLUSH-sats vid %C"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "Dubblerad UNIT-specifikation vid %C"
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Dubblerad formatspecifikation vid %C"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "Symbolen %qs i namnlistan %qs är INTENT(IN) vid %C"
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Dubblerad NML-specifikation vid %C"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "Symbolen %qs vid %C måste vara ett NAMELIST-gruppnamn"
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "END-tagg vid %C är inte tillåten i utmatningssats"
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "UNIT inte angivet vid %L"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "UNIT-specifikation vid %L måste vara ett INTEGER-uttryck eller en CHARACTER-variabel"
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "Ogiltig form av WRITE-sats vid %L, UNIT krävs"
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "Intern enhet med vektorindex vid %L"
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "Extern IO UNIT får inte vara en vektor vid %L"
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr "NAMELIST %qs i READ-sats vid %L innehåller symbolen %qs som inte får stå i ett variabeldefinitionssammanhang"
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "Komma före i/o-elementlista vid %L"
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR-taggetikett %d vid %L inte definierad"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END-taggetikett %d vid %L inte definierad"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR-taggetikett %d vid %L inte definierad"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT-etikett %d vid %L inte definierad"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr "io_kind_name(): felaktig I/O-sort"
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Syntaxfel i I/O-iterator vid %C"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Variabel förväntades i READ-sats vid %C"
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Förväntade uttryck i %s-sats vid %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaxfel i %s-sats vid %C"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr "Intern fil vid %L med namnlista"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "ASYNCHRONOUS=-specificerare vid %L måste vara ett initieringsuttryck"
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "PAD= vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "DELIM= vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "PRINT-namnlista vid %C är en utökning"
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Komma förväntades i I/O-lista vid %C"
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT-sats vid %C är inte tillåten inuti PURE-procedur"
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE-sats är inte tillåten i PURE-procedur vid %C"
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENGTH-tagg ogiltig i INQUIRE-sats vid %C"
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "INQUIRE-sats vid %L får inte innehålla både FILE- och UNIT-specificerare"
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "INQUIRE-sats vid %L kräver antingen FILE- eller UNIT-specificerare"
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr "UNIT-tal i INQUIRE-sats vid %L får inte vara -1"
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "INQUIRE-sats vid %L kräver en PENDING=-specificerare med ID=-specificeraren"
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "WAIT vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "WAIT-sats är inte tillåtet i PURE-procedur vid %C"
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
 msgstr "gfc_op2string(): Felaktig kod"
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, gcc-internal-format
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "%<)%> saknas i sats vid eller före %L"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, gcc-internal-format
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "%<(%> saknas i sats vid eller före %L"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr "För stort heltal vid %C"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "För många siffror i satsetikett vid %C"
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr "Satsetikett vid %C är noll"
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, gcc-internal-format
 msgid "Label name %qs at %C is ambiguous"
 msgstr "Etikettnamnet %qs vid %C är tvetydigt"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, gcc-internal-format
 msgid "Duplicate construct label %qs at %C"
 msgstr "Dubblerad konstruktionsetikett %qs vid %C"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr "Felaktigt tecken i namn vid %C"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr "Namn vid %C är för långt"
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr "Ogiltigt tecken %<$%> vid %L.  Använd %<-fdollar-ok%> för att tillåta det som en utökning"
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr "Slingvariabel vid %C får inte vara en co-vektor"
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr "Slingvariabel vid %C får inte vara en subkomponent"
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr "Ett stegvärde förväntades i iterator vid %C"
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr "Syntaxfel i iterator vid %C"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, gcc-internal-format, gfc-internal-format
 msgid "gfc_match(): Bad match code %c"
 msgstr "gfc_match(): Felaktig matchningskod %c"
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr "Ogiltig form på PROGRAM-sats vid %C"
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %C"
 msgstr "Aritmetisk IF-sats vid %C"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr "Syntaxfel i IF-uttryck vid %C"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr "Blocketikett är inte tillämplig för aritmetisk IF-sats vid %C"
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr "Blocketikett är inte tillämplig för IF-sats vid %C"
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr "Det går inte att tilldela till en namngiven konstant vid %C"
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr "Oklassificerbar sats i IF-klausul vid %C"
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr "Syntaxfel i IF-klausul vid %C"
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr "Oväntat skräp efter ELSE-sats vid %C"
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "Etiketten %qs vid %C stämmer inte med IF-etikett %qs"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr "Oväntat skräp efter ELSE-IF-sats vid %C"
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr "Bildstyrningssats CRITICAL vid %C i PURE-procedur"
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr "Bildstyrningssats CRITICAL vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
 msgstr "CRITICAL-sats vid %C"
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr "Nästade CRITICAL-block vid %C"
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr "Associationslista förväntades vid %C"
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr "Association förväntade vid %C"
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, gcc-internal-format
 msgid "Duplicate name %qs in association at %C"
 msgstr "Dubblerat namn %qs i association vid %C"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr "Associationsmålet vid %C får inte vara co-indexerat"
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, gcc-internal-format
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "%<)%> eller %<,%> förväntades vid %C"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr "Skräp efter ASSOCIATE-sats vid %C"
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, gcc-internal-format
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "Härledd typ %qs vid %L får inte vara ABSTRACT"
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "Ogiltig typspecifikation vid %C"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "Syntaxfel i FORALL-iterator vid %C"
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr "DO CONCURRENT-konstruktion vid %C"
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "Namnet %qs i %s-sats vid %C är okänt"
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "Namnet %qs i %s-sats vid %C är inte ett konstruktionsnamn"
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "%s-sats vid %C lämnar CRITICAL-konstruktion"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "%s-sats vid %C lämnar DO CONCURRENT-konstruktion"
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "%s-sats vid %C är inte inne i en konstruktion"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "%s-sats vid %C är inte inne i konstruktionen %qs"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "CYCLE-sats vid %C är inte tillämpbar på icke-slingkonstruktionen %qs"
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "EXIT-sats utan något do-konstruktionsnamn vid %C"
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "%s-sats vid %C är inte i tillämpbar på konstruktionen %qs"
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "%s-sats vid %C lämnar ett OpenACC-strukturerat block"
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "EXIT-sats vid %C avslutar !$ACC LOOP-slinga"
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "CYCLE vid %C till kollapsad !ACC LOOP-slinga som inte är innerst"
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "EXIT-sats vid %C avslutar !$OMP DO-slinga"
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "CYCLE vid %C till kollapsad !$OMP DO-slinga som inte är innerst"
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr "%s-sats vid %C i PURE-procedur"
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr "Bildkontrollsatsen STOP vid %C i CRITICAL-block"
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "Bildkontrollsatsen STOP vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "STOP-kod vid %L måste antingen vara av INTEGER- eller CHARACTER-typ"
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "STOP-kod vid %L måste vara skalär"
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr "STOP-koden vid %L måste vara standard tecken-KIND=%d"
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "STOP-kod vid %L måste vara standard heltal KIND=%d"
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "PAUSE-sats vid %C"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "ERROR STOP-sats vid %C"
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "Bildstyrsats %s vid %C i PURE-procedur"
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "Bildkontrollsatsen %s vid %C i CRITICAL-block"
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "Bildkontrollsatsen %s vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr "Överflödig STAT-tagg funnen vid %L "
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr "Överflödig ERRMSG-tagg funnen vid %L "
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr "Överflödig ACQUIRED_LOCK-tagg funnen vid %L "
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "LOCK-sats vid %C"
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "UNLOCK-sats vid %C"
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "Bildstyrsats SYNC vid %C i PURE-procedur"
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "SYNC-sats vid %C"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr "Bildkontrollsatsen SYNC vid %C i CRITICAL-block"
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "Bildkontrollsatsen SYNC vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "ASSIGN-sats vid %C"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "Tilldelad GOTO-sats vid %C"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "Satsetikettlistan i GOTO vid %C får inte vara tom"
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "Beräknat GOTO vid %C"
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "Fel i typspecifikation vid %L"
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr "typspecifikation i ALLOCATE vid %L"
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "Felaktigt allokeringsobjekt vid %C för en PURE-procedur"
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "ALLOCATE av co-vektor vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr "ALLOCATE av co-vektor vid %C i CRITICAL-block"
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "Allokeringsobjekt vid %L är varken en datapekare eller en allokerbar variabel"
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "Entitetens typ vid %L är typinkompatibel med typspecifikationen"
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr "Sorttypparameter för enheten vid %L skiljer sig från sorttypparametern i typspecifikationen"
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "Formspecifikation för allokerbar skalär vid %C"
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "ERRMSG-tagg vid %L"
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "SOURCE-tagg vid %L"
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr "Överflödig SOURCE-tagg funnen vid %L "
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr "SOURCE-taggen vid %L står i konflikt med typespecifikationen vid %L"
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr "SOURCE-tagg vid %L med mer än ett ensamt allokeringsobjekt"
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "MOLD-tagg vid %L"
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr "Överflödig MOLD-tagg funnen vid %L "
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr "MOLD-taggen vid %L står i konflikt med typespecifikationen vid %L"
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "MOLD-taggen vid %L står i konflikt med SOURCE-taggen vid %L"
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Allokeringsobjekt vid %L med en fördröjd typparameter behöver antingen en typspecifikation eller en SOURCE-tagg eller en MOLD-tagg"
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Obegränsat polymorft allokeringsobjekt vid %L behöver en typspecifikation eller en SOURCE-tagg eller en MOLD-tagg"
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "Pekarobjektet vid %C kan inte vara co-indexerat"
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "Otillåtet allokeringsobjekt vid %C för en PURE-procedur"
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "DEALLOCATE av co-vektor vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr "DEALLOCATE av co-vektor vid %C i CRITICAL-block"
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "Allokeringsobjekt vid %C är varken en pekare på annat än procedur eller en allokerbar variabel"
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "ERRMSG vid %L"
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr "Bildkontrollsatsen RETURN vid %C i CRITICAL-block"
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "Bildkontrollsatsen RETURN vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "Alternativ RETURN-sats vid %C är bara tillåten inuti en SUBROUTINE"
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr "RETURN-sats i huvudprogram vid %C"
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Komponentreferens förväntades vid %C"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "Skräp efter CALL vid %C"
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Typbunden procedurreferens eller procedurpekarkomponent förväntades vid %C"
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "Syntaxfel i common-blocknamn vid %C"
@@ -47431,147 +47482,147 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr "Variabel ”%s” vid %L i common-block ”%s” vid %C måste deklareras med en C-interoperativ sort eftersom common-block ”%s” är bind(c)"
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr "Variabel %qs i common-block %qs vid %C får inte vara bind(c) eftersom det inte är globalt"
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Symbolen %qs vid %C är redan i ett COMMON-block"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "Initierad symbol %qs vid %C kan endast vara COMMON i BLOCK DATA"
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "Vektorspecifikation för symbolen %qs i COMMON vid %C måste vara explicit"
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "Symbolen %qs i COMMON vid %C får inte vara en POINTER-vektor"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "Symbolen %qs, i COMMON-block %qs vid %C är indirekt gjort ekvivalent med ett annat COMMON-block %qs"
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "Namnlistegruppnamnet %qs vid %C har redan grundtypen %s"
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "Namnlistegruppnamn %qs vid %C är redan USE-associerat och får inte specificeras om."
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Vektor %qs med antagen storlek i namnlistan %qs vid %C är inte tillåtet"
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "Härledd typkomponent %C är inte en tillåten EQUIVALENCE-medlem"
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "Vektorreferens i EQUIVALENCE vid %C får inte vara en vektorsektion"
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "EQUIVALENCE vid %C kräver två eller flera objekt"
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Försök att indirekt överlappa COMMON-block %s och %s med EQUIVALENCE vid %C"
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Komma förväntades i EQUIVALENCE vid %C"
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "Satsfunktion vid %L är rekursiv"
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "Satsfunktion vid %C"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Initieringsuttryck förväntades i CASE vid %C"
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Blocknamnet %qs förväntades av SELECT-konstruktionen vid %C"
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "parsningsfel i SELECT TYPE-sats vid %C"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Väljare i SELECT TYPE vid %C är inte en namngiven variabel, använd associationsnamn =>"
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Oväntad CASE-sats vid %C"
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Syntaxfel i CASE-specifikation vid %C"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Oväntad TYPE IS-sats vid %C"
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "Typspecifikationen skall inte specificera en sekvens härledd typ eller en typ med attributet BIND i SELECT TYPE vid %C [F2003:C815]"
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Syntaxfel i TYPE IS-specifikation vid %C"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Syntaxfel i CLASS IS-specifikation vid %C"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "ELSEWHERE-sats vid %C inte innesluten i WHERE-block"
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "Etiketten %qs vid %C stämmer inte med WHERE-etikett %qs"
@@ -47717,168 +47768,168 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Namnlistan %s får inte namnändras av USE-association till %s"
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "Tvetydig !$OMP DECLARE REDUCTION från modulen %s vid %L"
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "Tidigare !$OMP DECLARE REDUCTION från modulen %s vid %L"
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "%qs i modulen %qs, importerad vid %C, är också namnet på den aktuella programenheten"
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Symbolen %qs refererad från %L finns inte i modulen %qs"
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Användaroperatorn %qs refererad från %L finns inte i modulen %qs"
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Inbyggd operator %qs refererad från %L finns inte i modulen %qs"
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): felaktig modulsymbol %qs"
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Symbolen inte skriven"
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Kan inte öppna modulfilen %qs för skrivning vid %C: %s"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Fel när modulfilen %qs skrevs: %s"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "Kan inte radera modulfilen %qs: %s"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Kan inte ändra namn på modulfilen %qs till %qs: %s"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Kan inte radera temporär modulfil %qs: %s"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Symbolen %qs är redan deklarerad"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): Kan inte skapa en symbol för %s"
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Symbolen %qs, refererad vid %L, finns inte i den valda standarden"
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Symbolen %qs refererad från %L hittas inte i den inbyggda modulen ISO_C_BINDING"
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Användning av inbyggd modul %qs vid %C står i konflikt med namn på ej inbyggd modul använd tidigare"
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Användning av namngiven NUMERIC_STORAGE_SIZE-konstant från inbyggd modul ISO_FORTRAN_ENV vid %L är inte kompatibelt med flaggan %qs"
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Användning av namngiven NUMERIC_STORAGE_SIZE-konstant från inbyggd modul ISO_FORTRAN_ENV vid %C är inte kompatibelt med flaggan %s"
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Symbolen %qs refererad vid %L hittas inte i den inbyggda modulen ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "USE-sats vid %C har ingen ONLY-kvalificerare"
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "inbyggd modul ISO_FORTRAN_ENV vid %C"
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "ISO_C_BINDING-modul vid %C"
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "Det finns ingen inbyggd modul med namnet %qs vid %C"
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "IEEE_FEATURES-modul vid %C"
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "IEEE_EXCEPTIONS-modul vid %C"
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "IEEE_ARITHMETIC-modul vid %C"
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Kan inte öppna modulfilen %qs för läsning vid %C: %s"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Användning av ej inbyggd modul %qs vid %C står i konflikt med namn på inbyggd modul använd tidigare"
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Filen %qs öppnad vid %C är inte en GNU Fortran-modulfil"
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr "Kan inte läsa modulfilen %qs öppnad vid %C, eftersom den skapades av en annan version av GNU Fortran"
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr "Det går inta att USE samma modul vi bygger!"
@@ -48173,7 +48224,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr "Den implicit deklarerade subrutinen %s används i !$OMP DECLARE REDUCTION vid %L "
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-klausul vid %L kräver ett skalärt LOGICAL-uttryck"
@@ -48865,367 +48916,362 @@
 msgid "Unexpected %s statement at %C"
 msgstr "Oväntad %s-sats vid %C"
 
-#: fortran/parse.c:2428
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr "Oväntad %s-sats i verify_st_order() vid %C"
-
-#: fortran/parse.c:2439
-#, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "%s-sats vid %C får inte följa efter %s-sats vid %L"
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr "Oväntat filslut i %qs"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "Härledd typ %qs med SEQUENCE får inte ha en CONTAINS-sektion vid %C"
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "Härledd typ %qs med BIND(C) får nte ha en CONTAINS-sektion vid %C"
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "Komponenter i TYPE vid %C måste föregå CONTAINS"
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "Typbunden procedur vid %C"
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "GENERIC-bindning vid %C"
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "FINAL-procedurdeklaration vid %C"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Härledd typdefinition vid %C med tom CONTAINS-sektion"
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "PRIVATE-sats i TYPE vid %C måste vara inuti en MODULE"
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "PRIVATE-sats vid %C måste föregå procedurbindningar"
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Dubblerad PRIVATE-sats vid %C"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "SEQUENCE-sats vid %C måste föregå CONTAINS"
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "Redan inuti ett CONTAINS-block vid %C"
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "FINAL-deklaration vid %C måste vara inuti CONTAINS"
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr "Härledd typdefinition vid %C utan komponenter"
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "PRIVATE-sats vid %C måste föregå strukturkomponenter"
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "SEQUENCE-sats vid %C måste föregå strukturkomponenter"
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "SEQUENCE-attribut vid %C är redan angett i TYPE-sats"
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Dubblerad SEQUENCE-sats vid %C"
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr "CONTAINS-block i härledd typdefinition vid %C"
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "Komponenten %s vid %L av typen LOCK_TYPE måste ha en co-dimension eller vara en delkomponent till en co-vektor, vilket inte är möjligt eftersom komponenten har pekarattributet"
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "Pekarkomponenten %s vid %L har en icke co-vektordelkomponent av typen LOCK_TYPE, som måste ha en co-dimension eller vara en delkomponent av en co-vektor"
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "Allokerbar komponent %s vid %L av typen LOCK_TYPE måste ha en co-dimension"
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr "Den allokerbara komponenten %s vid %L måste ha en co-dimension eftersom den har en icke co-vektordelkomponent av typen LOCK_TYPE"
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "Icke co-vektorkomponenten %s vid %L av typen LOCK_TYPE eller med en underkomponent av typen LOCK_TYPE måste ha en co-dimension eller vara en underkomponent av en co-vektor.  (Variabler av typen %s får inte ha en co-dimension eftersom det redan finns en co-vektorunderkomponent)"
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "Icke co-vektorkomponenten %s vid %L av typen LOCK_TYPE eller med en underkomponent av typen LOCK_TYPE måste ha en co-dimension eller vara en underkomponent till en co-vektor.  (Variabler av typen %s får inte ha en co-dimension eftersom %s vid %L har en co-dimension eller en co-vektorunderkomponent)"
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "ENUM-deklaration vid %C har inga ENUMERATORS"
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Oväntad %s-sats i INTERFACE-block vid %C"
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "Namnet %qs i ABSTRACT INTERFACE vid %C kan inte vara samma som en inbyggd typ"
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Oväntad %s-sats vid %C i INTERFACE-kropp"
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "INTERFACE-procedur %qs vid %L har samma namn som den inneslutande proceduren"
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "%s-sats är inte tillåten inuti BLOCK vid %C"
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "%s-sats är inte tillåten inuti BLOCK DATA vid %C"
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "%s-sats måste vara i en MODULE"
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "%s-sats vid %C följer på en annan åtkomstspecifikation"
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "Fel sorts uttryck för funktionen %qs vid %L"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Typen på funktionen %qs vid %L är inte tillgänglig"
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "ELSEWHERE-sats vid %C följer tidigare omaskerat ELSEWHERE"
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Oväntad %s-sats i WHERE-block vid %C"
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Oväntad %s-sats i FORALL-block vid %C"
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "ELSE IF-sats vid %C kan inte följa ELSE-sats vid %L"
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Dubblerad ELSE-sats vid %L och %C"
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "En CASE- eller END SELECT-sats förväntades följa efter SELECT CASE vid %C"
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "En TYPE IS-, CLASS IS- eller END SELECT-sats förväntades följa efter SELECT TYPE vid %C"
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr "Variabeln ”%s” vid %C får inte definieras om inuti slingan som börjar vid %L"
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "Slut på DO-sats utan block vid %C är inuti ett annat block"
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "Slut på DO-sats utan block vid %C är sammanvävt med en annan DO-slinga"
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr "CRITICAL-block i unuti OpenACC-region vid %C"
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "Satsetikett i END CRITICAL vid %C stämmer inte med CRITICAL-etikett"
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "BLOCK-konstruktion vid %C"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "ASSOCIATE-konstruktion vid %C"
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "Satsetikett i ENDDO vid %C stämmer inte med DO-etikett"
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "Namngivet DO-block vid %L kräver matchande ENDDO-namn"
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr "!$OMP END ATOMIC saknas efter !$OMP ATOMIC CAPTURE vid %C"
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr "OpenACC-direktiv inuti CRITICAL-block vid %C"
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr "%s förväntades vid %C"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr "DO-slinga förväntades vid %C"
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr "Överflödig !$ACC END LOOP vid %C"
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "Namn efter !$omp critical och !$omp end critical matchar inte vid %C"
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "%s-sats vid %C kan inte avsluta en DO-slinga utan block"
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr "DATA-sats vid %C efter den första körbara satsen"
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "Innesluten procedur %qs vid %C är redan tvetydig"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Oväntad %s-sats i CONTAINS-sektion vid %C"
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr "CONTAINS-sats utan FUNCTION- eller SUBROUTINE-sats vid %C"
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "CONTAINS-sats vid %C är redan i en innesluten programenhet"
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr "gfc_global_used(): Felaktig typ"
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr "Globalt bindningsnamn ”%s” vid %L används redan som en %s vid %L"
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr "Globalt namn ”%s” vid %L används redan som en %s vid %L"
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "Blank BLOCK DATA vid %C står i konflikt med tidigare BLOCK DATA vid %L"
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Oväntad %s-sats i BLOCK DATA vid %C"
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Oväntad %s-sats i MODULE vid %C"
@@ -49233,7 +49279,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "Två huvud-PROGRAM vid %L och %C"
@@ -49928,7 +49974,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Icke RECURSIVE procedur %qs vid %L anropar kanske sig själv rekursivt.  Deklarera den RECURSIVE eller använd %<-frecursive%>."
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Etikett %d som refereras vid %L är aldrig definierad"
@@ -49983,363 +50029,363 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Att skicka intern procedur som plats vid %L är inte tillåtet"
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL icke INTRINSIC procedur %qs är inte tillåten som aktuellt argument vid %L"
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Co-indexerat aktuellt argument vid %L med slutlig pekarkomponent"
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "%qs vid %L är en vektor och OPTIONAL.  OM DEN SAKNAS kan den inte vara det aktuella argumentet i en ELEMENTAL-procedur om det inte finns ett ej valfritt argument med samma ordning (12.4.1.5)"
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "Aktuellt argument vid %L för INTENT(%s)-attrapp %qs av ELEMENTAL-subrutin %qs är en skalär, men ett annat aktuellt argument är en vektor"
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Returtypen stämmer inte för funktionen %qs vid %L (%s/%s)"
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr "Gränssnitt stämmer inte överens i den globala proceduren %qs vid %L: %s"
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Det finns ingen specifik funktionen för den generiska %qs vid %L"
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Generisk funktion %qs vid %L är inte konsistent med ett specifikt inbyggt gränssnitt"
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Funktionen %qs vid %L är INTRINSIC men är inte kompatibel med en inbyggd"
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Kan inte slå upp den specifika funktionen %qs vid %L"
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ"
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "Referens till den orena funktionen %qs vid %L är inuti ett FORALL-%s"
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "Referens till den orena funktionen %qs vid %L är inuti ett DO CONCURRENT-%s"
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Referens till den orena funktionen %qs vid %L inuti en PURE-procedur"
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs vid %L är inte en funktion"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT INTERFACE %qs får inte refereras vid %L"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Funktionen %qs är deklarerad CHARACTER(*) och får inte användas vid %L eftersom det inte är ett attrappargument"
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "resolve_function(): felaktig funktionstyp"
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Användardefinierad ej ELEMENTAL funktion %qs vid %L är inte tillåten i WORKSHARE-konstruktion"
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "ENTRY %qs vid %L får inte anropas rekursivt, eftersom funktionen %qs inte är RECURSIVE"
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Funktion %qs vid %L får inte anropas rekursivt, eftersom den inte är RECURSIVE"
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Subrutinanrop till %qs i FORALL-block vid %L är inte PURE"
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Subrutinanrop till %qs i DO CONCURRENT-block vid %L är inte PURE"
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Subrutinanrop till %qs vid %L är inte PURE"
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Det finns ingen specifik subrutinen för den generiska %qs vid %L"
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Generisk subrutin %qs vid %L är inte konsistent med ett inbyggt subrutingränssnitt"
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Subrutin %qs vid %L är INTRINSIC men är inte kompatibel med en inbyggd"
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Kan inte slå upp den specifika subrutinen %qs vid %L"
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr "”%s” vid %L har en typ som inte är konsistent med CALL vid %L"
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "ENTRY %qs vid %L är får inte anropas rekursivt, eftersom subrutinen %qs inte är RECURSIVE"
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE %qs vid %L får inte anropas rekursivt, eftersom den inte är RECURSIVE"
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "resolve_subroutine(): felaktig funktionstyp"
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Formerna för operanderna vid %L och %L är inte konforma"
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Felaktig inbyggd"
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "compare_bound_int(): Felaktigt uttryck"
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld < %ld) i co-dimension %d"
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld > %ld) i co-dimension %d"
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Otillåtet steg på noll vid %L"
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Undre vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Undre vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Övre vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Övre vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Felaktig vektorreferens"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Högraste övre gränsen av en sektion av vektor med antagen storlek inte angiven vid %L"
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Ordning stämmer inte i vektorreferens vid %L (%d/%d)"
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Co-indexordning stämmer inte i vektorreferens vid %L (%d/%d)"
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Co-index i co-dimension %d måste vara en skalär vid %L"
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Vektorindex vid %L måste vara skalärt"
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Vektorindex vid %L måste ha INTEGER-typ, fann %s"
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "REAL-vektorindex vid %L"
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Dim-argumentet vid %L måste vara skalärt"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Dim-argumentet vid %L måste ha INTEGER-typ"
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "find_array_spec(): Specifikation saknas"
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): oanvänd as(1)"
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): oanvänd as(2)"
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Vektorindex vid %L är en vektor med ordning %d"
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Startindex för delsträng vid %L måste typen INTEGER"
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Startindex för delsträng vid %L måste vara skalärt"
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
-msgstr "Substrängs startindex vid %L är mindre än ett"
+msgstr "Delsträngs startindex vid %L är mindre än ett"
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Slutindex för delsträng vid %L måste ha typen INTEGER"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Slutsträng för delsträng vid %L måste vara skalärt"
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Slutindex för delsträng vid %L överstiger strängens längd"
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Slutindex för delsträng vid %L är för stort"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Felaktig vektorreferens"
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponent till den högra av en delreferens med ordning skild från noll får inte ha attributet POINTER vid %L"
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponent till den högra av en delreferens med ordning skild från noll får inte ha attributet ALLOCATABLE vid %L"
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Två eller flera delreferenser med ordning skild från noll får inte anges vid %L"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr "expression_rank(): Två vektorspecifikationer"
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får bara användas som ett aktuellt argument"
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Variabeln %s med antagen typ vid %L får bara användas som ett aktuellt argument"
@@ -50348,12 +50394,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variabel med antagen typ %s vid %L som aktuellt argument till en frågefunktion skall vara det första argumentet"
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Variabeln %s med antagen ordning vid %L kan bara användas som ett aktuellt argument"
@@ -50362,248 +50408,248 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variabel med antagen ordning %s vid %L som aktuellt argument till en frågefunktion skall vara det första argumentet"
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall inte ha en subobjektreferens"
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Variabeln %s med antagen typ vid %L skall inte ha en subobjektreferens"
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Variabeln %s med antagen ordning vid %L skall inte ha en subobjektreferens"
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel %qs, använd i ett specifikationsuttryck, refereras vid %L före ENTRY-satsen i vilken den är en parameter"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel %qs används vid %L före ENTRY-satsen i vilken den är en parameter"
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorft subobjekt till co-indexerat objekt vid %L"
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Co-indexerat objekt med polymorf allokerbar delkomponent vid %L"
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Skickat objekt vid %L måste vara skalär"
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för procedurpekarkomponentanrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för typbundet proceduranrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basobjekt för typbundet NOPASS-proceduranrop vid %L måste vara skalärt"
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Hittade ingen matchande specifik bindning för anropet till GENERIC %qs vid %L"
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs vid %L skulle vara en SUBROUTINE"
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs vid %L skulle vara en SUBROUTINE"
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Felaktig uttryckstyp"
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s vid %L måste vara en skalär"
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s vid %L måste vara ett heltal"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s vid %L måste vara INTEGER"
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Steguttryck i DO-slinga vid %L får inte vara noll"
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-slinga vid %L kommer köras noll gånger"
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-indexnamn vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-steguttryck vid %L måste vara en skalär %s"
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-steguttryck vid %L får inte vara noll"
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-index %qs får inte förekomma i triplettspecifikation vid %L"
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allokeringsobjekt vid %L måste vara ALLOCATABLE eller en POINTER"
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Co-indexerat allokerbart objekt vid %L"
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Källuttryck vid %L måste vara skalärt eller ha samma ordning som allokeringsobjektet vid %L"
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Källuttryck vid %L och allokeringsobjekt vid %L måste ha samma form"
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typen på enheten vid %L är typinkompatibel med källuttrycket vid %L"
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Allokeringsobjektet vid %L och källuttrycket vid %L skall ha samma sorts typparameter"
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Källuttrycket vid %L skall varken vara av typen LOCK_TYPE eller ha en LOCK_TYPE-komponent om det allokerbara objektet vid %L är en co-vektor"
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Allokering %s av ABSTRACT bastyp vid %L behöver en typspecifikation eller source-uttryck"
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Allokerar %s vid %L med typspecifikation kräver samma teckenlängdsparameter som i deklarationen"
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Co-vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Felaktig vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs får inte förekomma i vektorspecifikationen vid %L i samma ALLOCATE-sats där den själv allokeras"
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "”*” förväntades i co-indexspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Felaktig co-vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Statvariabel vid %L måste vara en INTEGER-variabel"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Statvariabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG vid %L är oanvändbart utan en STAT-tagg"
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "Errmsg-variabeln vid %L måste vara en skalär CHARACTER-variabel"
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allokeringsobjekt vid %L förekommer också vid %L"
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allokeringsobjekt vid %L är underobjekt till objekt vid %L"
@@ -50612,188 +50658,188 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-etikett vid %L överlappar med CASE-etikett vid %L"
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "uttryck i CASE-sats vid %L måste vara av typ %s"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Uttryck i CASE-sats vid %L måste ha sort %d"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Uttryck i CASE-sats vid %L måste vara skalärt"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Valuttryck i beräknad-GOTO-sats vid %L måste vara ett skalärt heltalsuttryck"
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument till SELECT-sats vid %L kan inte vara %s"
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumentet till SELECT-satsen vid %L måste vara ett skalärt uttryck"
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Uttryck i CASE-sats vid %L ligger inte i intervallet %s"
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE vid %L får inte följas av ett andra DEFAULT CASE vid %L"
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logiskt intervall CASE-sats vid %L är inte tillåtet"
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstant logiskt värde i CASE-sats upprepas vid %L"
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Intervallspecifikationen vid %L kan aldrig matchas"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logiskt SELECT CASE-block vid %L har mer än två fall"
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associationsnamn %qs vid %L används som en vektor"
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-väljare vid %L behöver en temporär som inte är implementerad ännu"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektorer skall vara polymorfiska i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektorn vid %L får inte vara co-indexerad"
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Härledd typ %qs vid %L måste vara utökningsbar"
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Härledd typ %qs vid %L måste vara en utökning av %qs"
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Oväntad inbyggd typ %qs vid %L"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Typspecifikationen vid %L skall ange att varje längdtypparameter är antagen"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Dubbelt CLASS IS-block i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ogiltigt sammanhang för inbyggd NULL () vid %L"
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte vara polymorft om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha POINTER-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Dataöverföringselement vid %L får inte ha procedurpekarkomponenter"
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha ALLOCATABLE-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Dataöverföringselement vid %L får inte ha PRIVATE-komponenter"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Dataöverföringselement vid %L får inte vara en full referens till en vektor med antagen storlek"
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Låsvariabel vid %L måste vara en skalär av typen LOCK_TYPE"
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=-argumentet vid %L måste vara en skalär INTEGER-variabel"
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=-variabeln vid %L måste vara en skalär CHARACTER-variabel"
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=-argumentet vid %L måste vara en skalär LOGICAL-variabel"
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Bildmängdsargument vid %L måste vara ett skalärt eller ordning-1-uttryck"
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Bildmängdsargument vid %L måste vara mellan 1 och num_images()"
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sats vid %L är inte en giltig grenmålssats för grensatsen vid %L"
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Gren vid %L kan orsaka en oändlig slinga"
@@ -50800,12 +50846,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar CRITICAL-konstruktion för etikett vid %L"
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar DO CONCURRENT-konstruktion för etikett vid %L"
@@ -50813,158 +50859,158 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Etiketten vid %L är inte i samma block som GOTO-satsen vid %L"
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-mask vid %L har inkonsistent form"
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-tilldelningsmål vid %L har inkonsistent form"
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Ej ELEMENTAL användardefinierad tilldelning i WHERE vid %L"
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ej stödd sats inuti WHERE vid %L"
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Tilldelning till en FORALL-indexvariabel vid %L"
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL med index %qs används inte på vänster sida av en tilldelning vid %L och kan därför orsaka multipla tilldelningar till detta objekt"
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "En yttre FORALL-konstruktion har redan ett index med detta namn %L"
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE-klausul vid %L kräver en LOGICAL-vektor"
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Felaktig blocktyp"
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr "CHARACTER-uttryck kommer att huggas av i tilldelning (%d/%d) vid %L"
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Co-indexerat uttryck vid %L är tilldelat till en härledd typvariabel med en POINTER-komponent i en PURE-procedur"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Den orena variabeln vid %L är tilldelad till en härledd typvariabel med en POINTER-komponent i en PURE-procedur (12.6)"
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Tilldelning till en co-indexerad variabel vid %L i en PURE-procedur"
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Tilldelning till en polymorf co-vektor vid %L är inte tillåtet"
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L"
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L kräver %<-frealloc-lhs%>"
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr "Tilldelning till allokerbar polymorf variabel vid %L stödjs inte ännu"
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "Ej allokerbar variabel får inte vara polymorf i inbyggd tilldelning vid %L - kontrollera att det finns en matchande specifik subrutin för operatorn ”=”"
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Co-indexerad variabel får inte ha en allokerbar yttersta komponent i tilldelningen vid %L"
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "ATT GÖRA: typbegränsad definierad tilldelning vid %L inte gjord för att multipla delvektorreferenser skulle uppträda i intermediära uttryck."
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "ASSIGNED GOTO-sats vid %L kräver en INTEGER-variabel"
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabeln %qs har inte tilldelats någon måletikett vid %L"
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternativ RETURN-sats vid %L kräver en SCALAR-INTEGER-returspecificerare"
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-sats vid %L kräver en skalär standard-INTEGER-variabel"
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr "Aritmetisk IF-sats vid %L kräver ett numeriskt uttryck"
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Inget uttryck i DO WHILE"
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Avslutsvillkor i DO WHILE-slinga vid %L måste vara ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-maskklausul vid %L kräver ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Felaktig satskod"
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr "Variabeln %s med bindningsetiketten ”%s” vid %L använder samma globala identifierare som en enhet vid %L"
@@ -50971,7 +51017,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr "Variabeln %s från modulen %s med bindningsetikett %s vid %L använder samma globala identifierare som enheten vid %L från modulen %s"
@@ -50979,57 +51025,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr "Proceduren %s med bindningsetiketten ”%s” vid %L använder samma globala identifierare som enheten vid %L"
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr "CHARACTER-variabel vid %L har negativ längd %d, längden har satts till noll"
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Stränglängden vid %L är för stor"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Den allokerbara vektorn %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalärt objekt %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Vektorpekaren %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Vektor %qs vid %L kan inte ha en fördröjd form"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typen %qs på CLASS-variabeln %qs vid %L är inte utvidgningsbar"
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-variabel %qs vid %L måste vara en attrapp, allokerbar eller pekare"
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Typen ”%s” kan inte vara värdassocierad vid %L för att den blockeras av ett inkompatibelt objekt med samma namn deklarerat vid %L"
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Implicerad SAVE för modulvariabeln %qs vid %L, behövs på grund av standardinitieringar"
@@ -51036,422 +51082,422 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr "Modul- eller huvudprogramvektorn ”%s” vid %L måste ha konstant form"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr "Enheten %qs vid %L har en fördröjd typparameter och kräver antingen attributet pointer eller allocatable"
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entitet med antagen teckenlängd vid %L måste vara ett attrappargument eller en PARAMETER"
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr "”%s” vid %L måste ha konstant teckenlängd i detta sammanhang"
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-variabeln %qs vid %L måste ha konstant teckenlängd"
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Allokerbar %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Extern %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Attrapp-%qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Inbyggd %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsresultat %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisk vektor %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Teckenvärd satsfunktion %qs vid %L måste ha konstant längd"
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs är av en PRIVATE-typ och kan inte vara ett attrappargument till %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Proceduren %qs i PUBLIC-gränssnittet %qs vid %L tar attrappargument för %qs som är PRIVATE"
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externt objekt %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktion %qs vid %L måste ha ett skalärt resultat"
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Satsfunktionen %qs vid %L får inte ha attributet pointer eller allocatable"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha vektorvärde"
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha pekarvärde"
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara pure"
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara rekursiv"
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-funktionen %qs vid %L"
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Procedurpekaren %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Attrapprocedur %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med SAVE-attribut i %qs vid %L"
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med INTENT-attribut i %qs vid %L"
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med RESULT-attribut i %qs vid %L"
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribut i konflikt med FUNCTION-attribut i %qs vid %L"
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Procedurpekarresultat %qs vid %L saknar pekarattributet"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-procedur %qs vid %L är inte en SUBROUTINE"
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-procedur vid %L måste ha precis ett argument"
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument till FINAL-procedur vid %L måste ha typen %qs"
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument till FINAL-procedur vid %L får inte vara en POINTER"
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument till FINAL-procedur vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument till FINAL-procedur vid %L får inte vara OPTIONAL"
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument till FINAL-procedur vid %L får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Ickeskalär FINAL-procedur vid %L skulle ha argument med antagen form"
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "FINAL-procedur %qs deklarerad vid %L har samma ordning (%d) som %qs"
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Endast vektor-FINAL-procedurer deklarerade för den härledda typen %qs definierade vid %L, föreslår även en skalär"
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs och %qs kan inte blandad FUNCTION/SUBROUTINE för GENERIC %qs vid %L"
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs och %qs för GENERIC %qs vid %L är tvetydiga"
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Odefinierad specifik bindning %qs som mål för GENERIC %qs vid %L"
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs vid %L måste ha som mål en specifik bindning, %qs är också GENERIC"
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "GENERIC %qs vid %L kan inte åsidosätta en specifik bindning med samma namn"
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "Typgränsoperator vid %L kan inte vara NOPASS"
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs måste vara en modulprocedur eller en extern procedur med ett explicit gränssnitt vid %L"
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Proceduren %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Procedur %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Ickepolymorfa attrappargument för pass-objekt till %qs vid %L"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Skickat objekt-attrappargument till %qs vid %L måste vara skalärt"
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara POINTER"
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Procedur %qs vid %L har samma namn som en komponent i %qs"
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proceduren %qs vid %L har samma namn som den ärvd komponent i %qs"
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Härledd typ %qs deklarerad vid %L måste vara ABSTRACT för att %qs är DEFERRED och inte åsidosatt"
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Eftersom utvidgningen av %qs vid %L har en co-vektorkomponent, skall föräldratypen %qs också ha en"
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Ej utvidgningsbar härledd typ %qs vid %L får inte vara ABSTRACT"
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Co-vektorkomponent %qs vid %L måste vara allokerbar med fördröjd form"
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponenten %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponenten %qs vid %L med co-vektorkomponent skall skalär som inte är en pekare eller allokerbar"
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Component %qs vid %L har attributet CONTIGUOUS men är inte en vektorpekare"
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Procedurpekarkomponent %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Procedurpekarkomponent %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste vara skalärt"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte ha attributet POINTER"
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponent %qs i %qs vid %L har samma namn som en ärvd typbunden procedur"
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Teckenlängd på komponent %qs behöver vara ett konstant specifikationsuttryck vid %L"
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Teckenkomponent %qs av %qs vid %L med fördröjd längd måste vara en POINTER eller ALLOCATABLE"
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "komponenten %qs är en PRIVATE-typ och kan inte vara en komponent i %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorf komponent %s vid %L i SEQUENCE- eller BIND(C)-typ %s"
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponent %s av SEQUENCE-typ deklarerad vid %L har inte attributet SEQUENCE"
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Pekarkomponenten %qs av %qs vid %L är en typen som inte har deklarerats"
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr "Procedur %qs med CLASS vid %L måste vara allokerbar eller en pekare"
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr "Det generiska namnet ”%s” på funktionen ”%s” vid %L är samma namn som den härledda typen vid %L"
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Vektor %qs med antagen storlek i namnlistan %qs vid %L är inte tillåtet"
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med antagen form i namnlistan %qs vid %L"
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant form in namnlistan %qs vid %L"
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant längd i namnlistan %qs vid %L"
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-objekt %qs i namnlistan %qs vid %L är polymorf och behöver en definierad input/output-procedur"
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST-objektet %qs i namnlistan %qs vid %L med ALLOCATABLE- eller POINTER-komponenter"
@@ -51458,397 +51504,397 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr "NAMELIST-objekt %qs i namnlistan %qs vid %L har ALLOCATABLE- eller POINTER-komponenter och behöver därför en definierad input/output-procedur"
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs deklarerades PRIVATE och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har användningsassociativa PRIVATE-komponenter och kan inte vara medlem av namnlistan %qs vid %L"
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har PRIVATE-komponenter och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med NAMELIST-attribut i %qs vid %L"
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametervektor %qs vid %L kan inte ha automatisk eller fördröjd form"
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implicit typad PARAMETER %qs vid %L matchar inte en senare IMPLICIT-typ"
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Inkompatibel härledd typ i PARAMETER vid %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attributet PROTECTED står i konflikt med attributet EXTERNAL vid %L"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attributet PROCEDURE står i konflikt med attributet PROTECTED vid %L"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs vid %L har attributet CONTIGUOUS, men är inte en vektorpekare eller en vektor med antagen form eller antagen ordning"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Vektor med antagen storlek vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Vektor med antagen form vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Vektor med antagen ordning vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Vektor med antagen ordning vid %L kan inte ha attributet VALUE eller CODIMENSION"
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol vid %L är inte en DUMMY-variabel"
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs vid %L kan inte ha attributet VALUE eftersom det inte är ett attrappargument"
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Teckenvärd attrappvariabel %qs vid %L med attributet VALUE måste ha konstant längd"
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-interoperativ teckenattrappvariabel %qs vid %L med attributet VALUE måste ha längd ett"
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Den härledda typen %qs vid %L har typen %qs, som inte har definierats"
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall vara ett attrappargument"
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall ha typen TYPE(*) eller en numerisk inbyggd typ"
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall antingen vara en skalär eller en vektor med förmodad storlek"
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Den antagna typen på variabeln %s vid %L är bara tillåten för attrappvariabler"
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variabeln %s med antagen typ vid %L får inte vara en vektor med explicit form"
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel %qs vid %L kan inte vara BIND(C) eftersom den varken är ett COMMON-block eller deklarerad med räckvidd modulnivå"
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs vid %L har PRIVATE härledd typ %qs"
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen LOCK_TYPE eller med en delkomponent av typen LOCK_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT)-attrappargumentet %qs vid %L har ASSUMED SIZE och kan därför inte ha en standardinitierare"
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av LOCK_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsresultat %qs vid %L skall inte vara en co-vektor eller ha en co-vektorkomponent"
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variabeln %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variabeln %qs vid %L med co-vektorkomponent skall vara en skalär som inte är en pekare eller allokerbar och inte en co-vektor"
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variabeln %qs vid %L är en co-vektor och är inte ALLOCATABLE, SAVE eller ett attrappargument"
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Co-vektorvariabeln %qs vid %L skall inte ha co-dimensioner med fördröjd form"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allokerbar co-vektorvariabel %qs vid %L måste ha en fördröjd form"
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variabeln %qs vid %L är INTENT(OUT) och kan alltså inte vara en allokerbara co-vektor eller har co-vektorkomponenter"
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Co-attrappvariabeln %qs vid %L är inte tillåten i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-attrappargumentet %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-resultatvariabeln %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Trådprivat vid %L är inte SAVE:ad"
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "!$OMP DECLARE TARGET-variabeln %qs vid %L är inte SAVE:ad"
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr "check_data_variable(): Felaktigt uttryck"
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA-element %qs vid %L måste vara i COMMON"
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-vektor %qs vid %L måste anges i en tidigare deklaration"
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-elementet %qs vid %L kan inte ha ett co-index"
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-element %qs vid %L är en pekare och måste då vara en fullständig vektor"
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Ickekonstant vektorsektion vid %L i DATA-sats."
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-sats vid %L har fler variabler än värden"
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "början av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "slutet av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "steget i implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-sats vid %L har fler värden än variabler"
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Etiketten %d vid %L är definierad men inte använd"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Etiketten %d vid %L är definierad men kan inte användas"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L måste ha attributet SEQUENCE för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L kan inte ha ALLOCATABLE-komponenter för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Härledd typvariabel %qs vid %L med standardinitiering kan inte vara i EQUIVALENCE med en variabel i COMMON"
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L med pekarkomponent(er) kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfel i EQUIVALENCE-sats vid %L"
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Antingen alla eller inget av objekten i EQUIVALENCE-mängden vid %L kan ha attributet PROTECTED"
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Common-blockmedlem %qs vid %L kan inte vara ett EQUIVALENCE-objekt i den rena proceduren %qs"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Namngiven konstant %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Vektor %qs vid %L med icke-konstanta gränser kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Postkomponent %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Delsträng vid %L har längden noll"
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-funktionen %qs vid %L har PRIVATE typ %qs"
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs vid %L har ingen IMPLICIT-typ"
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Användaroperatorprocedur %qs vid %L måste vara en FUNCTION"
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Användaroperatorprocedur %qs vid %L får inte ha antagen teckenlängd"
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Användaroperatorprocedur %qs vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Första argumentet till operatorgränssnitt vid %L får inte vara frivilligt"
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Andra argumentet till operatorgränssnitt vid %L får inte vara valfritt"
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorgränssnitt vid %L måste ha, högst, två argument"
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Innesluten procedur %qs vid %L i en PURE-procedur måste också vara PURE"
@@ -51878,47 +51924,47 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr "!$OMP vid %C inleder en kommentarrad eftersom det varken följs av en blank eller en fortsättningsrad"
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr "Rad avhuggen vid %L"
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr "Gränsen på %d fortsättningar överskrids i sats vid %C"
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, gcc-internal-format
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "%<&%> saknas i fortsatt teckenkonstant vid %C"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr "Ej konformt tabulatortecken vid %C"
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
 msgstr "%<&%> är inte tillåtet ensamt på rad %d"
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr "Ej konformt tabulatortecken i kolumn %d på rad %d"
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr "%s:%d: gått ifrån men inte till filen %s"
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr "%s:%d: Ogiltigt preprocessordirektiv"
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, gcc-internal-format
 msgid "Can't open file %qs"
 msgstr "Kan inte öppna filen %qs"
@@ -52184,52 +52230,52 @@
 msgid "Reshaped array too large at %C"
 msgstr "Omformad vektor är för stor vid %C"
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "Resultat av SCALE spiller över sin sort vid %L"
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Felaktig typ i gfc_simplify_sign"
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr "i gfc_simplify_sin(): Felaktig typ"
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr "Misslyckades att bestämma längden på en konstant vektor."
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "Argument till SQRT vid %L har ett negativt värde"
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "ogiltigt argument till SQRT vid %L"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr "Utanför gränserna i IMAGE_INDEX vid %L för dimension %d, SUB har %ld och COARRAY nedre gräns är %ld)"
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr "Utanför gränserna i IMAGE_INDEX vid %L för dimension %d, SUB har %ld och COARRAY övre gräns är %ld)"
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_convert_constant(): Oväntad typ"
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr "Tecknet %qs i sträng vid %L kan inte konverteras till tecken av sort %d"
@@ -52307,252 +52353,257 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "Namnlistegruppnamnet vid %L kan inte ha attributet SAVE"
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
 #, gcc-internal-format, gfc-internal-format
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "den interna proceduren ”%s” vid %L står i konflikt med DUMMY-argument"
+
+#: fortran/symbol.c:489
+#, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "Procedurpekare vid %C"
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "%s-attribut applicerat på %s %s vid %L"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) applicerat på %s %s vid %L"
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "%s-attribut i konflikt med %s-attribut vid %L"
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, gcc-internal-format
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr "%s-attribut i konflikt med %s-attribut i %qs vid %L"
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute with %s attribute at %L"
 msgstr "%s-attribut med %s-attribut vid %L"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, gcc-internal-format
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr "%s-attribut med %s-attribut i %qs vid %L"
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "Det går inte att ändra attribut på USE-associerad symbol vid %L"
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "Det går inte att ändra attribut på USE-associerad symbol %s vid %L"
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Dubblerat %s-attribut angivna vid %L"
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "ALLOCATABLE angiven utanför INTERFACE-kropp vid %L"
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "CODIMENSION angiven för %qs utanför dess INTERFACE-kropp vid %L"
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "DIMENSION angiven för %qs utanför dess INTERFACE-kropp vid %L"
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "Cray-utpekad vid %L förekommer i flera pointer()-satser"
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Dubblerat PROTECTED-attribut angivet vid %L"
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "SAVE-attribut vid %L kan inte anges i en PURE-procedur"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "Dubblerat SAVE-attribut angivet vid %L"
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Dubblerat VALUE-attribut angivet vid %L"
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Dubblerat VOLATILE-attribut angivet vid %L"
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Dubblerat ASYNCHRONOUS-attribut angivet vid %L"
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s-attribut på %qs i konflikt med %s-attribut vid %L"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "Proceduren ”%s” vid %L är redan deklarerad som %s-procedur"
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) står i konflikt med INTENT(%s) vid %L"
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "ACCESS-specifikation vid %L var redan angiven"
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Dubblerat BIND-attribut angivna vid %L"
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) vid %L"
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Dubblerat EXTENDS-attribut angivet vid %L"
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS vid %L"
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Symbolen %qs vid %L har redan ett explicit gränssnitt"
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "%qs vid %L har attribut angivna utanför dess INTERFACE-kropp"
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr "Symbolen ”%s” vid %L står i konflikt med symbolen från modulen ”%s”, användningsassocierad vid %L"
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Symbolen %qs vid %L har redan grundtypen %s"
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Procedur %qs vid %L får inte ha grundtypen %s"
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Symbolen %qs vid %L kan inte ha en typ"
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr "Komponenten ”%s” vid %C är redan deklarerad vid %L"
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr "Komponenten ”%s” vid %C finns redan i föräldratypen vid %L"
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Symbolen %qs vid %C är tvetydig"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Härledd typ %qs vid %C används före den är definierad"
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Komponent %qs vid %C är en PRIVATE-komponent i %qs"
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs vid %C är inte en medlem av posten %qs"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Dubblerad satsetikett %d vid %L och %L"
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Etikett %d vid %C är redan refererad som ett grenmål"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Etiketten %d vid %C är redan refererad som en formatetikett"
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "DO avslutningssats som inte är END DO eller CONTINUE med etikett %d vid %C"
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Etikett %d vid %C användes tidigare som en FORMAT-etikett"
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Etikett %d vid %C användes tidigare som ett grenmål"
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Delad DO-avslutningsetikett %d vid %C"
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr "new_symbol(): Symbolnamnet är för långt"
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Namnet %qs vid %C är en tvetydig referens till %qs från modulen %qs"
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Namnet %qs vid %C är en tvetydig referens till %qs från den aktuella programenheten"
@@ -52559,62 +52610,62 @@
 
 # Vad är "host associated"?
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Symbolen %qs vid %C har redan blivit host-associerad"
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): Den angivna symbolen är oväntat NULL"
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Härledd typ %qs deklarerad vid %L måste ha attributet BIND för att vara ett C-interoperativ"
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Härledd typ %qs med attributet BIND(C) vid %L är tom, och kan vara otillgängliga av C-följeslagarprocessorn"
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr "Komponent ”%s” vid %L får inte ha attributet POINTER eftersom det är en medlem av den BIND(C)-härledda typen ”%s” vid %L"
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr "Procedurpekarkomponenten ”%s” vid %L kan inte vara en medlem av den BIND(C)-härledda typen ”%s” vid %L"
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr "Komponent ”%s” vid %L får inte ha attributet ALLOCATABLE eftersom det är en medlem av den BIND(C)-härledda typen ”%s” vid %L"
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Komponent %qs i härledd typ %qs vid %L får inte vara C-interoperativ, trots att den härledda typen %qs är BIND(C)"
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Komponent %qs i härledd typ %qs vid %L får inte vara C-interoperativ"
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "Härledd typ %qs vid %L kan inte deklareras med både attributet PRIVATE och BIND(C)"
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Härledd typ %qs vid %L kan inte ha attributet SEQUENCE för att den är BIND(C)"
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Symbolen %qs används före den har fått sin typ vid %L"
@@ -52873,7 +52924,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr "Felaktig IO-bastyp (%d)"
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr "gfc_trans_omp_workshare(): Felaktig satskod"
Index: gcc/po/de.po
===================================================================
--- gcc/po/de.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/de.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -10,7 +10,7 @@
 msgstr ""
 "Project-Id-Version: gcc 5.1.0\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2015-07-10 12:41+0200\n"
 "Last-Translator: Roland Illig <roland.illig@gmx.de>\n"
 "Language-Team: German <translation-team-de@lists.sourceforge.net>\n"
@@ -197,13 +197,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "Gleitkommakonstante falsch benutzt"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1407,7 +1407,7 @@
 msgid "options enabled: "
 msgstr "angeschaltete Optionen: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2616,97 +2616,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "ungültiger Operandenpräfix »%%%c«"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "»%%&« ohne lokale dynamische TLS-Referenzen verwendet"
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "ungültiger %%H-Wert"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "ungültiger %%J-Wert"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "ungültiger %%r-Wert"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "ungültiger %%R-Wert"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "ungültiger %%N-Wert"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "ungültiger %%P-Wert"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "ungültiger %%h-Wert"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "ungültiger %%L-Wert"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "ungültiger %%m-Wert"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "ungültiger %%M-Wert"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "ungültiger %%U-Wert"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "ungültiger %%s-Wert"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "ungültiger %%C-Wert"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "ungültiger %%E-Wert"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "Unbekanntes relocation unspec"
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ungültiger %%xn-Code"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 #| msgid "invalid operand"
 msgid "invalid operand address"
@@ -2759,7 +2759,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "Ungültiger Operanden-Ausgabecode"
@@ -2914,8 +2914,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3135,62 +3135,62 @@
 msgid "bad output_condmove_single operand"
 msgstr "Falscher Operand für output_condmove_single"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ungültiges UNSPEC als Operand"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ungültige Operandengröße für Operandencode »O«"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ungültige Operandengröße für Operandencode »z«"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ungültiger Operandentyp mit Operandencode »Z« verwendet"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ungültige Operandengröße für Operandencode »Z«"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »Y«"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »D«"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »%c«"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "Operand ist keine ausgleichbare Speicherreferenz, ungültiger Operandencode »H«"
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ungültiger Operandencode »%c«"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ungültige Bedingungen für Operand"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "unbekannter Befehlsmodus"
 
@@ -3230,7 +3230,7 @@
 msgid "invalid %%P operand"
 msgstr "ungültiger %%P-Operand"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "ungültiger %%p-Wert"
@@ -3294,7 +3294,7 @@
 msgstr "Post-Increment-Adresse ist kein Register"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "Falsche Adresse"
 
@@ -3462,102 +3462,102 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "Code im »Little Endian«-Modus erzeugen"
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 msgid "bad move"
 msgstr "ungültige Bewegung"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "ungültiger %%H-Wert"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "ungültiger %%f-Wert"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "ungültiger %%F-Wert"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "ungültiger %%G-Wert"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "ungültiger %%j-Code"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "ungültiger %%J-Code"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "ungültiger %%k-Wert"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "ungültiger %%K-Wert"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "ungültiger %%O-Wert"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "ungültiger %%q-Wert"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "ungültiger %%S-Wert"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "ungültiger %%T-Wert"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "ungültiger %%u-Wert"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "ungültiger %%v-Wert"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "ungültiger %%x-Wert"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ungültiger %%y-Wert, bitte »Z«-Bedingung probieren"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-Argument an Funktion ohne Prototyp übergeben"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 #| msgid "Do not generate char instructions"
 msgid "Could not generate addis value for fusion"
 msgstr "Keine Zeichenbefehle erzeugen"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load offset for fusion"
@@ -3653,60 +3653,60 @@
 msgid "invalid operand to %%S"
 msgstr "ungültiger Operand für %%S"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr "erzeugt und mit anderen Architekturen / ABIs verwendet"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr "erzeugt und mit anderen ABIs verwendet"
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr "erzeugt und mit anderer Bytereihenfolge verwendet"
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "ungültiger %%Y-Operand"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "ungültiger %%A-Operand"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "ungültiger %%B-Operand"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, c-format
 msgid "invalid %%C operand"
 msgstr "ungültiger %%C-Operand"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, c-format
 msgid "invalid %%D operand"
 msgstr "ungültiger %%D-Operand"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "ungültiger %%f-Operand"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "ungültiger %%s-Operand"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "»long long«-Konstante ist kein gültiger direkter Operand"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "Gleitkommakonstante ist kein gültiger direkter Operand"
@@ -3919,7 +3919,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> erwartet"
@@ -3935,15 +3935,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> erwartet"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> erwartet"
@@ -3965,8 +3965,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> erwartet"
@@ -3973,8 +3973,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> erwartet"
@@ -3983,13 +3983,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "%<;%>, %<,%> oder %<)%> erwartet"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> erwartet"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> erwartet"
@@ -3996,8 +3996,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> erwartet"
@@ -4020,7 +4020,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> erwartet"
@@ -4037,34 +4037,34 @@
 msgid "expected %<.%>"
 msgstr "%<.%> erwartet"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> erwartet"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> erwartet"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> oder %<)%> erwartet"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> erwartet"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> oder %<}%> erwartet"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> erwartet"
@@ -4073,11 +4073,11 @@
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "Kandidat 1:"
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "Kandidat 2:"
 
@@ -4303,11 +4303,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%s:%d:   in constexpr-Ersetzung von %qs"
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "Kandidaten sind:"
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "Kandidat ist:"
@@ -4353,48 +4353,48 @@
 msgid "source type is not polymorphic"
 msgstr "Quellentyp ist nicht polymorph"
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "Argument falschen Typs für unäres Minus"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "Argument falschen Typs für unäres Plus"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "Argument falschen Typs für Bit-Komplement"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "Argument falschen Typs für abs"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "Argument falschen Typs für Konjugation"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 msgid "in argument to unary !"
 msgstr "in Argument für unäres !"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 msgid "no pre-increment operator for type"
 msgstr "kein Präinkrementoperator für Typ"
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr "kein Postinkrementoperator für Typ"
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 msgid "no pre-decrement operator for type"
 msgstr "kein Prädekrementoperator für Typ"
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr "kein Postdekrementoperator für Typ"
 
@@ -4489,7 +4489,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "Ganzzahlwert zu groß in Ausdruck bei %C"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 msgid "array assignment"
 msgstr "Feld-Zuweisung"
 
@@ -4512,7 +4512,7 @@
 msgid "Driving:"
 msgstr "Angesteuert:"
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "effektives Argument für INTENT = OUT/INOUT"
 
@@ -4582,13 +4582,13 @@
 msgid "%s tag"
 msgstr "%s Symbol"
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr "interne Einheit in WRITE"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s-Symbol mit INQUIRE"
@@ -4666,7 +4666,7 @@
 msgid "Bad type in constant expression"
 msgstr "Falscher Typ in Konstanten-Ausdruck"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 msgid "Unexpected end of module"
 msgstr "Unerwartetes Modulende"
 
@@ -4694,11 +4694,11 @@
 msgid "implied END DO"
 msgstr "impliziertes END DO"
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr "Zuweisung"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 msgid "pointer assignment"
 msgstr "Zeigerzuweisung"
 
@@ -4714,221 +4714,221 @@
 msgid "internal function"
 msgstr "interne Funktion"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 msgid "elemental procedure"
 msgstr "Elementares Unterprogramm"
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "ungültiges Typargument"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 #| msgid "not enough arguments"
 msgid "asynchronous argument"
 msgstr "Nicht genug Argumente"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 #| msgid "invalid PHI argument"
 msgid "optional argument"
 msgstr "ungültiges PHI-Argument"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "Zeigerzuweisung"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 #| msgid "too many arguments"
 msgid "target argument"
 msgstr "zu viele Argumente"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "ungültiges Typargument"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "Keine Argumente"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-shape argument"
 msgstr "unpassende Argumente"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 #| msgid "Assumed-rank array at %C"
 msgid "assumed-rank argument"
 msgstr "Feld mit vermutetem Rang bei %C"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 #| msgid "array assignment"
 msgid "coarray argument"
 msgstr "Feld-Zuweisung"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "parametrized derived type argument"
 msgstr "ungültiges Typargument"
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "Keine Argumente"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "ungültiges Typargument"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 #, fuzzy
 #| msgid "Coindexed allocatable object at %L"
 msgid "pointer or allocatable result"
 msgstr "Koindiziertes reservierbares Objekt bei %L"
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 #, fuzzy
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "result with non-constant character length"
 msgstr "COMMON-Variable »%s« bei %L muss konstante Zeichenlänge haben"
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 #, fuzzy
 #| msgid "module procedure"
 msgid "bind(c) procedure"
 msgstr "Modulprozedur"
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Ungültiger Kontext für NULL()-Zeiger bei %%L"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr "Operand des unären numerischen Operators »%s« bei %%L ist %s"
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr "Operanden des binären numerischen Operators »%s« bei %%L sind %s/%s"
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operanden des Zeichenkettenverkettungsoperators bei %%L sind %s/%s"
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr "Operanden des logischen Operators »%s« bei %%L sind %s/%s"
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operand des Operators .not. bei %%L ist %s"
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX-Größen können nicht bei %L verglichen werden"
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logische Werte bei %%L müssen mit %s statt mit %s verglichen werden"
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr "Operanden des Vergleichsoperators »%s« bei %%L sind %s/%s"
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr "Unbekannter Operator »%s« bei %%L"
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr "Operand des Benutzeroperators »%s« bei %%L ist %s"
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr "Operanden des Benutzeroperators »%s« bei %%L sind %s/%s"
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Ränge für Operator bei %%L und %%L stimmen nicht überein"
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr "Schleifenvariable"
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 msgid "iterator variable"
 msgstr "Iteratorvariable"
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 msgid "Start expression in DO loop"
 msgstr "Anfangs-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 msgid "End expression in DO loop"
 msgstr "End-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 msgid "Step expression in DO loop"
 msgstr "Schrittausdruck in DO-Schleife"
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE Objekt"
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 msgid "ALLOCATE object"
 msgstr "ALLOCATE Objekt"
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr "STAT-Variable"
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr "ERRMSG-Variable"
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr "Element in READ"
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr "Variable ACQUIRED_LOCK"
 
@@ -5352,16 +5352,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr "CPU RX200 hat keine FPU-Hardware"
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr "evtl. »-pg« statt »-p« mit gprof(1) verwendet"
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr "evtl. »-pg« statt »-p« mit gprof(1) verwenden"
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr "unterstützt nicht multilib"
@@ -5374,6 +5364,10 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "-Xbind-now und -Xbind-lazy sind unverträglich"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+msgid "profiling not supported with -mg"
+msgstr "Profiling wird mit -mg nicht unterstützt"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "-mhard-float wird nicht unterstützt"
@@ -5382,10 +5376,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "-msingle-float und -msoft-float können nicht zusammen angegeben werden"
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr "der m210 hat keine Little-Endian-Unterstützung"
-
 #: config/cris/cris.h:184
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "nicht gleichzeitig -march=... und -mcpu=... angeben"
@@ -5414,6 +5404,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr "evtl. »-pg« statt »-p« mit gprof(1) verwendet"
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5420,6 +5416,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr "-m32 und -m64 können nicht zusammen angegeben werden"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr "evtl. »-pg« statt »-p« mit gprof(1) verwenden"
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr "static wird auf TPF-OS nicht unterstützt"
@@ -5432,6 +5432,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian und -mlittle-endian dürfen nicht zusammen verwendet werden"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr "der m210 hat keine Little-Endian-Unterstützung"
+
 #: config/avr/specs.h:68
 #, fuzzy
 #| msgid "-fpic is not supported"
@@ -5461,17 +5465,19 @@
 msgid "no processor type specified for linking"
 msgstr "kein Prozessortyp zum Binden angegeben"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr "Warnung: Evtl. mit »-static« linken, da Systembibliotheken mit"
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr "  Profiling-Unterstützung nur im Archivformat unterstützt werden"
 
@@ -5507,10 +5513,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "Die Option -shared wird derzeit nicht für VAX ELF unterstützt"
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-msgid "profiling not supported with -mg"
-msgstr "Profiling wird mit -mg nicht unterstützt"
-
 #: fortran/lang.opt:146
 msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgstr "-J<Verzeichnis>\tMODULE-Dateien in »Verzeichnis« ablegen"
@@ -5694,9 +5696,9 @@
 msgstr "Dollarzeichen in Entity-Namen erlauben"
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Tut nichts. Für Rückwärtskompatibilität erhalten."
 
@@ -5908,10 +5910,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Tut nichts. Für Rückwärtskompatibilität erhalten."
 
@@ -5957,7 +5959,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr "fehlender Dateiname hinter %qs"
@@ -7867,46 +7869,50 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr "Ziel-CPU als »little endian«-konfiguriert annehmen"
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 msgid "Specify the code model"
 msgstr "Codemodell angeben"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr "Nicht annehmen, dass nicht ausgerichtete Zugriffe vom System behandelt werden"
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr "Rahmenzeiger in Blattfunktionen auslassen"
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr "TLS-Dialekt angeben"
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr "-march=ARCH\tEigenschaften der angegebenen Architektur ARCH verwenden"
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr "-mcpu=CPU\tEigenschaften der angegebenen CPU verwenden und dafür optimieren"
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr "-mtune=CPU\tFür CPU optimieren"
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 #, fuzzy
 #| msgid "-mabi=ABI\tGenerate code that conforms to the given ABI"
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr "-mabi=ABI\tCode erzeugen, der zum angegebenen ABI passt"
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 #, fuzzy
 #| msgid "Known ARM ABIs (for use with the -mabi= option):"
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
@@ -9008,10 +9014,16 @@
 msgstr "Eingebaute BMI-Funktionen und Codeerzeugung unterstützen"
 
 #: config/i386/i386.opt:864
+#, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "Eingebaute MMX- und SSE-Funktionen und Codeerzeugung unterstützen"
+
+#: config/i386/i386.opt:868
 msgid "Use given stack-protector guard"
 msgstr "Angegebenen Stapelschutz-Wächter verwenden"
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 #, fuzzy
 #| msgid "Known ARM architectures (for use with the -march= option):"
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
@@ -9367,7 +9379,9 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+#, fuzzy
+#| msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr "Nicht gegen die Geräte-spezifische Bibliothek libdev.a binden"
 
 #: config/m32r/m32r.opt:34
@@ -9516,7 +9530,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr "Sprungkosten für bedingte Sprungbefehle setzen. Sinnvoll"
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
@@ -9649,7 +9663,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr "Planung einer Funktionsprologsequenz erlauben"
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr "PIC-Register nicht in Funktionsprolog verschieben"
 
@@ -9974,311 +9988,311 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "Vektor-/skalare (VSX) Befehle verwenden"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr "Kein Laden/Speichern mit Aktualisierungsbefehlen erzeugen"
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr "Laden/Speichern mit Aktualisierungsbefehlen erzeugen"
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr "Erzeugung indizierter Laden/Speichern-Befehle verhindern, wo möglich"
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "__tls_get_addr-Aufrufe mit Argumentinfo markieren"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr "Anfang und Ende der Prozedur planen"
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr "Alle Strukturen über Speicher zurückgeben (AIX-Standard)"
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr "Kleine Strukturen über Register zurückgeben (SVR4-Standard)"
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr "Näher der IBM XLC-Semantik entsprechen"
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr "Reziproke Division und Quadratwurzel in Software für besseren Durchsatz erzeugen."
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr "Annahme, dass die reziproken abschätzenden Befehle höhere Genauigkeit bieten."
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr "Gleitkommakonstanten nicht ins TOC legen"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr "Gleitkommakonstanten ins TOC legen"
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "Symbol+Offset-Konstanten nicht ins TOC legen"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr "Symbol+Offset-Konstanten ins TOC legen"
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr "Nur einen TOC-Eintrag pro Prozedur verwenden"
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr "Alles in reguläres TOC legen"
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr "Beim Erzeugen von AltiVec-Code VRSAVE-Befehle erzeugen"
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr "Veraltete Option. Stattdessen -mno-vrsave verwenden"
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr "Veraltete Option. Stattdessen -mvrsave verwenden"
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr "Angabe, wie viele Bytes inline bewegt werden, bevor memcpy/memmove aufgerufen wird"
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 msgid "Generate isel instructions"
 msgstr "isel-Befehle erzeugen"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr "Veraltete Option. Stattdessen -mno-isel verwenden"
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 msgid "Deprecated option.  Use -misel instead"
 msgstr "Veraltete Option. Stattdessen -misel verwenden"
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr "SPE SIMD Befehle auf E500 erzeugen"
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "Paarweise-Einzel-Befehle für PPC750CL erzeugen"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr "Veraltete Option. Stattdessen -mno-spe verwenden"
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 msgid "Deprecated option.  Use -mspe instead"
 msgstr "Veraltete Option. Stattdessen -mspe verwenden"
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 msgid "-mdebug=\tEnable debug output"
 msgstr "-mdebug=\tAusgaben zur Fehlersuche einschalten"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 msgid "Use the AltiVec ABI extensions"
 msgstr "Die AltiVec-ABI-Erweiterungen verwenden"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "AltiVec-ABI-Erweiterungen nicht verwenden"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 msgid "Use the SPE ABI extensions"
 msgstr "Die SPE-ABI-Erweiterungen verwenden"
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 msgid "Do not use the SPE ABI extensions"
 msgstr "Die SPE-ABI-Erweiterungen nicht verwenden"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv1 ABI"
 msgstr "EABI verwenden"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv2 ABI"
 msgstr "EABI verwenden"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 msgid "using darwin64 ABI"
 msgstr "darwin64-ABI wird verwendet"
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 msgid "using old darwin ABI"
 msgstr "Altes darwin-ABI wird verwendet"
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr "IEEE long double mit erweiterter Genauigkeit wird verwendet"
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr "IBM long double mit erweiterter Genauigkeit wird verwendet"
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr "-mcpu=\tEigenschaften der gegebenen CPU verwenden und entsprechend Code planen"
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "-mtune=\tCode für die gegebene CPU planen"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr "-mtraceback=\tVoll-, Teil- oder keine Traceback-Tabelle"
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr "Alle Bereichsgrenzen bei Aufrufbefehlen vermeiden"
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 msgid "Generate Cell microcode"
 msgstr "Cell-Mikrocode erzeugen"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "Warnen, wenn mikrocodierte Cell-Befehle ausgegeben werden"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr "Vor der Verwendung des veralteten AltiVec-Typen »vector long ...« warnen"
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr "-mfloat-gprs=\tGPR-Gleitkommamethode auswählen"
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Gültige Argumente für -mfloat-gprs=:"
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr "-mlong-double-<n>\tGröße von »long double« angeben (64 oder 128 Bits)"
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr "Feststellen, welche Abhängigkeiten zwischen Befehlen als teuer angesehen werden"
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr "Angeben, welches Schema zum Einfügen von nops nach der Planung angewendet werden soll"
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr "Ausrichtung der Strukturfelder als Standard/natürlich angeben"
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 msgid "Valid arguments to -malign-:"
 msgstr "Gültige Argumente für -malign-:"
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr "Planungspriorität für Verteilschlitz-beschränkte Befehle angeben"
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 msgid "Single-precision floating point unit"
 msgstr "Gleitkommaeinheit mit einfacher Genauigkeit"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 msgid "Double-precision floating point unit"
 msgstr "Gleitkommaeinheit mit doppelter Genauigkeit"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 msgid "Floating point unit does not support divide & sqrt"
 msgstr "Gleitkommaeinheit unterstützt nicht Division und Quadratwurzel"
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr "-mfpu=\tFP angeben (sp, dp, sp-lite, dp-lite) (schließt -mxilinx-fpu ein)"
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 msgid "Specify Xilinx FPU."
 msgstr "Xilinx-FPU angeben"
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr "r11 verwenden/nicht verwenden, um die statische Bindung in Funktionsaufrufen über Zeiger zu speichern"
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr "TOC wird im Prolog für indirekte Sprünge gespeichert, oder die Sicherung »inline« erzeugen"
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr "128-Bit-Ganzzahlen in VSX-Registern zulassen"
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 #, fuzzy
 #| msgid "Align destination of the string operations"
 msgid "Allow sign extension in fusion operations"
 msgstr "Ziel der Zeichenkettenoperationen ausrichten"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
+#: config/rs6000/rs6000.opt:566
 #, fuzzy
-#| msgid "Use SmartMIPS instructions"
-msgid "Use ISA 2.07 crypto instructions"
-msgstr "SmartMIPS-Befehle verwenden"
+#| msgid "Use vector/scalar (VSX) instructions"
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr "Vektor-/skalare (VSX) Befehle verwenden"
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 #, fuzzy
 #| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr "Vektor-/skalare (VSX) Befehle verwenden"
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Laden/Speichern mehrerer Befehle erzeugen"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -13318,1597 +13332,1597 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr "-dumpdir <Verzeichnis>\tDen Basis-Verzeichnisnamen für Ausgaben setzen"
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr "Aggressive Schleifenoptimierungen mit Zwangsbedingungen der Sprache"
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "Funktionsanfänge ausrichten"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr "Marken ausrichten, die nur mit Sprüngen erreicht werden können"
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr "Alle Marken ausrichten"
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "Schleifenanfänge ausrichten"
 
-#: common.opt:894
+#: common.opt:897
 #, fuzzy
 #| msgid "Select the runtime"
 msgid "Select what to sanitize"
 msgstr "Laufzeitumgebung auswählen"
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr "Dieser Schalter ist veraltet; stattdessen -Wextra verwenden"
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr "Abwicklungstabellen erzeugen, die genau an jeder Befehlsgrenze liegen"
 
-#: common.opt:918
+#: common.opt:921
 msgid "Generate auto-inc/dec instructions"
 msgstr "auto-inc/dec-Befehle erzeugen"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr "Profilierungsinformationen für Verzweigungswahrscheinlichkeiten verwenden"
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "Code zur Überprüfung der Grenzen vor Feldindizierung erzeugen"
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr "Addieren, Vergleichen, Verzweigen mit Verzweigung anhand des Zählregisters ersetzen"
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr "Profilierungsinformationen für Verzweigungswahrscheinlichkeiten verwenden"
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr "Ladeoptimierungen für Sprungziele vor Prolog/Epilog-Behandlung ausführen"
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr "Ladeoptimierung für Sprungziele nach Prolog/Epilog-Behandlung ausführen"
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr "In Basis-Blöcken keine Register bei der Ziel-Lade-Bewegung wiederverwenden"
 
-#: common.opt:960
+#: common.opt:963
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr "-fcall-saved-<Register>\t<Register> als über Funktionsgrenzen hinweg reserviert markieren"
 
-#: common.opt:964
+#: common.opt:967
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr "-fcall-used-<Register>\t<Register> als durch Funktionsaufrufe beschädigt markieren"
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr "Register bei Funktionsaufrufen sichern"
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr "Die Ergebnisse mehrerer Datenabhängigkeitsanalysen vergleichen."
 
-#: common.opt:979
+#: common.opt:982
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++"
 msgstr "Rückgabewert von new prüfen"
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "Sucht Möglichkeiten, Stapel-Anpassungen und Stapel-Referenzen zu reduzieren."
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr "Keine uninitialisierten globalen Symbole in gemeinsamen Abschnitt legen"
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr "-fcompare-debug[=<Optionen>]\tMit und ohne z.B. -gtoggle kompilieren, und den Dump der finalen Anweisungen vergleichen"
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr "Nur die zweite Kompilierung von -fcompare-debug laufen lassen"
 
-#: common.opt:1003
+#: common.opt:1006
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr "Beseitigung von Vergleichen nach Registerreservierung durchführen"
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr "Keine Optimierungen durchführen, die die Stapelverwendung deutlich erhöhen"
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr "Optimierungsdurchlauf zur Kopierübertragung von Registern durchführen"
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr "Optimierung zum Kreuzsprung durchführen"
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr "Beim Durchlaufen von CSE: Sprüngen zu ihren Zielen folgen"
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr "Schritt zur Bereichsverkleinerung auslassen, wenn komplexe Division durchgeführt wird"
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr "Komplexe Multiplikation und Division folgen Fortran-Regeln"
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr "Datenstücke in ihren eigenen Abschnitt legen"
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Alle verfügbaren Fehleranalysezähler mit ihren Grenzen und Werten auflisten."
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr "-fdbg-cnt=<Zähler>:<Grenze>[,<Zähler>:<Grenze>,...]\tGrenze des Fehlersuchzählers setzen."
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr "In Fehlersuchinfo einen Verzeichnisnamen auf einen anderen abbilden"
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ".debug_types-Abschnitt ausgeben, wenn DWARF v4-Debuginfo verwendet wird"
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr "Zurückholen der Funktionsargumente vom Stapel bis auf weiteres hinauszögern"
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr "Versuch, die Verzögerungsschlitze der Sprungbefehle auszufüllen"
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr "Unerreichbare Befehle löschen, die Ausnahmen werfen können"
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr "Unnötige Nullzeigerprüfungen löschen"
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization"
 msgstr "Superblockerzeugung über Ende-Vervielfältigung durchführen"
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr "Versuchen, virtuelle Sprünge in direkte umzuwandeln."
 
-#: common.opt:1085
+#: common.opt:1088
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr "-fdiagnostics-show-location=[once|every-line]\tWie oft die Quelltext-Position am Zeilenanfang ausgegeben wird, wenn die Diagnose über mehrere Zeilen geht"
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr "Quellzeile mit Einschaltungszeichen anzeigen, um die Spalte zu kennzeichnen"
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr "Die geeignete Diagnosemeldung mit der Kommandozeilenoption erweitern, die sie steuert"
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr "-fdisable-[tree|rtl|ipa]-<Durchgang>=range1+range2 schaltet einen Optimierungsdurchgang aus"
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr "-fenable-[tree|rtl|ipa]-<Durchgang>=range1+range2 schaltet einen Optimierungsdurchgang ein"
 
-#: common.opt:1142
+#: common.opt:1145
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr "-fdump-<type>\tVerschiedene compilerinterne Informationen in eine Datei abziehen"
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr "-fdump-final-insns=<Datei>\tDie Befehle am Ende der Übersetzung in Datei abziehen"
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr "-fdump-go-spec=<Datei>\tAlle Deklarationen als Go-Code in <Datei> schreiben"
 
-#: common.opt:1157
+#: common.opt:1160
 msgid "Suppress output of addresses in debugging dumps"
 msgstr "Ausgabe von Adressen in Fehlersuch-Auszügen unterdrücken"
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 msgid "Dump optimization passes"
 msgstr "Optimierungsdurchläufe ausgeben"
 
-#: common.opt:1170
+#: common.opt:1173
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr "Ausgabe von Befehlszahlen, Zeilennummernangaben und Adressen in Fehlersuch-Auszügen unterdrücken"
 
-#: common.opt:1174
+#: common.opt:1177
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr "Ausgabe der vorigen und nächsten Befehlszahlen in Fehlersuch-Auszügen unterdrücken"
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "CFI-Tabellen über GAS-Assembler-Anweisungen einschalten"
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr "Frühes Inlining durchführen"
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr "DWARF2-Wiederholungsbeseitigung durchführen"
 
-#: common.opt:1190
+#: common.opt:1193
 msgid "Perform interprocedural reduction of aggregates"
 msgstr "Zwischenprozedurale Reduktion von Aggregaten durchführen"
 
-#: common.opt:1194
+#: common.opt:1197
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info"
 msgstr "Beseitigung ungenutzter Typen in Info zur Fehlersuche durchführen"
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr "Beseitigung ungenutzter Typen in Info zur Fehlersuche durchführen"
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr "Keine Fehlersuchinformationen für C++-Klassen unterdrücken"
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "Ausnahmebehandlung einschalten"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr "Eine Reihe kleiner, aber teurer, Optimierungen durchführen"
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr "-fexcess-precision=[fast|standard]\tBehandlung überschüssiger Gleitkommagenauigkeit bestimmen"
 
-#: common.opt:1217
+#: common.opt:1220
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr "unbekannte Art überschüssiger Genauigkeit %qs"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "LTO-Objekte ausgeben, die sowohl Zwischensprache als auch Binärausgabe enthalten"
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr "Annahme, dass keine NaNs oder Unendlichkeiten erzeugt werden"
 
-#: common.opt:1238
+#: common.opt:1241
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr "-ffixed-<Register>\t<Register> als für den Compiler nicht verfügbar markieren"
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr "Keine floats und doubles in Registern erweiterter Genauigkeit reservieren"
 
-#: common.opt:1250
+#: common.opt:1253
 msgid "Perform a forward propagation pass on RTL"
 msgstr "Schritt zur Vorwärts-Übertragung auf RTL durchführen"
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr "-ffp-contract=[off|on|fast] Schrumpfung von Gleitkommaausdrücken durchführen"
 
-#: common.opt:1257
+#: common.opt:1260
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "unbekannte Art der Gleitkomma-Kürzung %qs"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr "Vorhalten von Funktionsadressen in Registern erlauben"
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr "Jede Funktion in ihren eigenen Abschnitt platzieren"
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr "Beseitigung globaler gemeinsamer Teilausdrücke durchführen"
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr "Erweiterte Ladebewegung während Beseitigung globaler gemeinsamer Teilausdrücke durchführen"
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr "Speicherbewegung nach Beseitigung globaler gemeinsamer Teilausdrücke durchführen"
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr "Beseitigung überflüssigen Ladens nach dem Abspeichern in globalem gemeinsamem Teilausdruck durchführen"
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr "Beseitigung globaler gemeinsamer Teilausdrücke nach Registerreservierung durchführen"
 
-#: common.opt:1305
+#: common.opt:1308
 msgid "Enable in and out of Graphite representation"
 msgstr "Ein- und Ausgabe der Graphite-Repräsentierung einschalten"
 
-#: common.opt:1309
+#: common.opt:1312
 msgid "Enable Graphite Identity transformation"
 msgstr "Transformation der Graphite Identität einschalten"
 
-#: common.opt:1313
+#: common.opt:1316
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr "Herausziehen aufeinanderfolgender Ladeoperationen einschalten, um Erzeugung bedingter Kopieroperationen zu fördern"
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr "Alle Schleifen als parallel markieren"
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr "Transformation des Loop Strip Mining einschalten"
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr "Transformation des Loop Interchange einschalten"
 
-#: common.opt:1330
+#: common.opt:1333
 msgid "Enable Loop Blocking transformation"
 msgstr "Transformation des Loop Blocking einschalten"
 
-#: common.opt:1334
+#: common.opt:1337
 #, fuzzy
 #| msgid "Enable Loop Interchange transformation"
 msgid "Enable Loop Unroll Jam transformation"
 msgstr "Transformation des Loop Interchange einschalten"
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr "Unterstützung für GNU-Transaktionsspeicher einschalten"
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr "ISL-basierten Optimierer für Schleifenschachtelungen einschalten"
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr "Bitfeld-Zugriffe zwingen, zu ihrer Typbreite zu passen"
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr "Erraten der Sprungwahrscheinlichkeiten einschalten"
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr "#ident-Anweisungen verarbeiten"
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr "Umwandlung bedingter Sprünge in zweiglose Äquivalente durchführen"
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr "Umwandlung bedingter Sprünge in bedingte Ausführung durchführen"
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr "-fstack-reuse=[all|named_vars|none] Stufe der Stapel-Wiederverwendung für lokale Variablen setzen"
 
-#: common.opt:1381
+#: common.opt:1384
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "Unbekannte Stufe %qs für Stapel-Wiederverwendung"
 
-#: common.opt:1394
+#: common.opt:1397
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr "Umwandlung bedingter Sprünge in innersten Schleifen in zweiglose Äquivalente durchführen"
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr "Ebenso if-umwandeln bedingter Sprünge, die Speicherschreiboperationen enthalten"
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr "Keine .size-Anweisungen erzeugen"
 
-#: common.opt:1410
+#: common.opt:1413
 msgid "Perform indirect inlining"
 msgstr "Indirektes Inlining durchführen"
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr "Aktivieren des Inlining von »inline«-Funktionen, ansonsten wird jegliches Inlining deaktiviert"
 
-#: common.opt:1420
+#: common.opt:1423
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "Funktionen in ihre Aufrufer einfügen, wenn Codegröße als nicht wachsend bekannt ist"
 
-#: common.opt:1424
+#: common.opt:1427
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "Nicht als »inline« deklarierte Funktionen in ihre Aufrufer einfügen, wenn gewinnbringend"
 
-#: common.opt:1428
+#: common.opt:1431
 msgid "Integrate functions only required by their single caller"
 msgstr "Nur an einer Stelle aufgerufene Funktionen in ihre Aufrufer einfügen"
 
-#: common.opt:1435
+#: common.opt:1438
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr "-finline-limit=<Zahl>\tGröße von »inline«-Funktionen auf <Zahl> beschränken"
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "__atomic-Operationen »inline« erzeugen, wenn Lock-freie Befehlssequenz verfügbar ist"
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr "Ein- und Austritte von Funktionen beim Profilieren von Aufrufen verwenden"
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr "-finstrument-functions-exclude-function-list=name,...  Aufgezählte Funktionen nicht verwenden"
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr "-finstrument-functions-exclude-file-list=filename,...  In Dateien aufgezählte Funktionen nicht verwenden"
 
-#: common.opt:1455
+#: common.opt:1458
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation"
 msgstr "Zwischenprozedurale Konstantenweitergabe durchführen"
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr "Kopien erzeugen, um zwischenprozedurale Konstantenweitergabe zu verstärken"
 
-#: common.opt:1463
+#: common.opt:1466
 #, fuzzy
 #| msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr "Kopien erzeugen, um zwischenprozedurale Konstantenweitergabe zu verstärken"
 
-#: common.opt:1467
+#: common.opt:1470
 msgid "Perform interprocedural profile propagation"
 msgstr "Zwischenprozedurale Profilweitergabe durchführen"
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr "Zwischenprozedurale Zeigeranalyse durchführen"
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr "Reine und konstante Funktionen entdecken"
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables"
 msgstr "Schleifenabwicklung für alle Schleifen durchführen"
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr "Nur-lese und nicht-adressierbare statische Variablen entdecken"
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr "-fira-algorithm=[CB|priority] Verwendeten IRA-Algorithmus setzen"
 
-#: common.opt:1506
+#: common.opt:1509
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "unbekannter IRA-Algorithmus %qs"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr "-fira-region=[one|all|mixed] Regionen für IRA setzen"
 
-#: common.opt:1519
+#: common.opt:1522
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr "unbekannte IRA-Region %qs"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr "IRA-basierte Registerdruckkalkulation verwenden"
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr "Schlitze gemeinsam verwenden, um verschiedene harte Register zu sichern."
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Stapel-Schlitze für übergelaufene Pseudo-Register gemeinsam verwenden."
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<Zahl<\tStufe der IRA Diagnosemeldungen steuern."
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr "Induktionsvariablen auf Bäumen optimieren"
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "Sprungtabellen für hinreichend große switch-Anweisungen verwenden"
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr "Code für Funktionen erzeugen, auch wenn sie vollständig »inline« sind"
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr "Statische konstante Variablen erzeugen, auch wenn sie nicht verwendet werden"
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr "Externen Symbolen einen führenden Unterstrich geben"
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 msgid "Enable link-time optimization."
 msgstr "Optimierungen zur Bindezeit einschalten"
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Optimierungen zur Bindezeit mit Anzahl paralleler Jobs oder Jobserver."
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "unbekanntes TLS-Modell %qs"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr "-flto-compression-level=<Stufe>\tZlib-Kompressionsstufe <Stufe> für IL verwenden"
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 msgid "Report various link-time optimization statistics"
 msgstr "Verschiedene Statistiken über Linkzeit-Optimierung ausgeben"
 
-#: common.opt:1625
+#: common.opt:1628
 #, fuzzy
 #| msgid "Report various link-time optimization statistics"
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr "Verschiedene Statistiken über Linkzeit-Optimierung ausgeben"
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr "Nach eingebauten Mathematikfunktionen errno setzen"
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr "-fmax-errors=<Anzahl>\tHöchstzahl der zu meldenden Fehler"
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr "Über dauerhafte Speicherreservierung berichten"
 
-#: common.opt:1641
+#: common.opt:1644
 msgid "Report on permanent memory allocation in WPA only"
 msgstr "Nur in WPA über dauerhafte Speicherreservierung berichten"
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr "Versuchen, identische Konstanten und konstante Variablen zu verschmelzen"
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr "Versuchen, identische Konstanten über Übersetzungseinheiten hinweg zu verschmelzen"
 
-#: common.opt:1656
+#: common.opt:1659
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr "Versuchen, identische Zeichenketten zur Fehlersuche über Übersetzungseinheiten hinweg zu verschmelzen"
 
-#: common.opt:1660
+#: common.opt:1663
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr "-fmessage-length=<Anzahl>\tDiagnosemeldungen auf <Anzahl> Zeichen pro Zeile beschränken. 0 unterdrückt Zeilenumbruch"
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr "SMS-basierte modulo-Planung vor erstem Planungsdurchlauf durchführen"
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr "SMS-basierte modulo-Planung mit erlaubten Register-Bewegungen durchführen"
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr "Berechnung der Schleifeninvarianten außerhalb der Schleifen legen"
 
-#: common.opt:1676
+#: common.opt:1679
 msgid "Use the RTL dead code elimination pass"
 msgstr "Den RTL-Schritt zur Entfernung toten Codes verwenden"
 
-#: common.opt:1680
+#: common.opt:1683
 msgid "Use the RTL dead store elimination pass"
 msgstr "Den RTL-Schritt zur Entfernung toter Speicherbereiche verwenden"
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr "Traditionelle Planung in Schleifen, die bereits Modulo-Planung unterzogen wurden, einschalten/ausschalten"
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr "Synchrone Nicht-Aufruf-Ausnahmen unterstützen"
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 #| msgid "path name missing after %s"
 msgid "options or targets missing after %qs"
 msgstr "Pfadname fehlt hinter %s"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown offload ABI %qs"
 msgstr "unbekanntes TLS-Modell %qs"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr "Wenn möglich, keine Stapelrahmen erzeugen"
 
-#: common.opt:1713
+#: common.opt:1716
 msgid "Enable all optimization info dumps on stderr"
 msgstr "Alle Informationen über Optimierungen auf stderr einschalten"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr "-fopt-info[-<Typ>=Dateiname]\tOptimierungsdetails des Compilers ausgeben"
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr "Geschwister- und endrekursive Aufrufe optimieren"
 
-#: common.opt:1729
+#: common.opt:1732
 msgid "Perform partial inlining"
 msgstr "Teilweises Inlining durchführen"
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr "Über Speicherbelegung vor zwischenprozeduraler Optimierung berichten"
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr "Strukturelemente ohne Lücken zusammenpacken"
 
-#: common.opt:1745
+#: common.opt:1748
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr "-fpack-struct=<Zahl>\tAnfängliche größte Ausrichtung für Strukturelemente festlegen"
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr "Kleine Aggregate über Speicher, nicht Register, zurückgeben"
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr "Schleifen-Schälung durchführen"
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr "Maschinenspezifische Guckloch-Optimierungen einschalten"
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr "Einen RTL-Guckloch-Durchlauf vor sched2 einschalten"
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr "Wenn möglich, lageunabhängigen Code erzeugen (large mode)"
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr "Wenn möglich, lageunabhängigen Code für ausführbare Dateien erzeugen (large mode)"
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr "Wenn möglich, positionsunabhängigen Code erzeugen (small mode)"
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr "Wenn möglich, positionsunabhängigen Code für ausführbare Dateien erzeugen (small mode)"
 
-#: common.opt:1781
+#: common.opt:1784
 msgid "Specify a plugin to load"
 msgstr "Zu ladendes Plugin angeben"
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr "-fplugin-arg-<Name>-<Schlüssel>[=<Wert>]\tArgument <Schlüssel>=<Wert> für Plugin <Name> angeben"
 
-#: common.opt:1789
+#: common.opt:1792
 msgid "Run predictive commoning optimization."
 msgstr "Vorhersehende vereinheitlichende Optimierung durchlaufen."
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr "Wenn verfügbar, Prefetch-Befehle für Felder in Schleifen erzeugen"
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr "Einfachen Programm-Profilierungscode einschalten"
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr "Arc-basierten Programm-Profilierungscode einfügen"
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr "Übergeordnetes Verzeichnis zum Speichern der Profildaten setzen"
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr "Korrektur fluss-unstimmiger Profildateneingabe einschalten"
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr "Allgemeine Optionen zum Erzeugen von Profil-Info für Profil-Feedback-gerichtete Optimierungen einschalten"
 
-#: common.opt:1818
+#: common.opt:1821
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Allgemeine Optionen zum Erzeugen von Profil-Info für Profil-Feedback-gerichtete Optimierungen einschalten, und -fprofile-dir= setzen"
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr "Allgemeine Optionen zum Durchführen von Profil-Feedback-gerichteten Optimierungen einschalten"
 
-#: common.opt:1826
+#: common.opt:1829
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Allgemeine Optionen zum Durchführen von Profil-Feedback-gerichteten Optimierungen einschalten, und -fprofile-dir= setzen"
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr "Code in Profilwerte von Ausdrücken einfügen"
 
-#: common.opt:1834
+#: common.opt:1837
 msgid "Report on consistency of profile"
 msgstr "Über Konsistenz des Profils berichten"
 
-#: common.opt:1838
+#: common.opt:1841
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement"
 msgstr "Funktionen umsortieren, um Codeplatzierung zu verbessern"
 
-#: common.opt:1845
+#: common.opt:1848
 #, fuzzy
 #| msgid "-frandom-seed=<string>\tMake compile reproducible using <string>"
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr "-frandom-seed=<Zeichenkette>\tÜbersetzung mit <Zeichenkette> reproduzierbar machen"
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr "GCC-Kommandozeilenschalter in Objektdateien aufzeichnen."
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr "Kleine Aggregate über Register zurückgeben"
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 #, fuzzy
 #| msgid "Enable register pressure sensitive insn scheduling"
 msgid "Relief of register pressure through live range shrinkage"
 msgstr "Registerdruckempfindliche Befehlsplanung einschalten"
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr "Einen Optimierungsdurchgang zur Registerumbenennung durchführen"
 
-#: common.opt:1880
+#: common.opt:1883
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr "Einen Optimierungsdurchgang zur Registerumbenennung durchführen"
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr "Basisblöcke umsortieren, um Codeplatzierung zu verbessern"
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr "Basisblöcke und Partition in heiße und kalte Abschnitte umordnen"
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr "Funktionen umsortieren, um Codeplatzierung zu verbessern"
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr "Einen gemeinsamen Durchlauf zur Entfernung von Teilausdrücken nach Schleifenoptimierungen hinzufügen"
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr "Optimierungen, die Standard-Rundungsverhalten für Gleitkomma annehmen, ausschalten"
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr "Planung über Basisblöcke hinaus einschalten"
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr "Registerdruckempfindliche Befehlsplanung einschalten"
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr "Spekulative Bewegung beim Nicht-Laden erlauben"
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr "Spekulative Bewegung bei einigen Ladeoperationen erlauben"
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr "Spekulative Bewegung bei mehr Ladeoperationen erlauben"
 
-#: common.opt:1928
+#: common.opt:1931
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr "-fsched-verbose=<Stufe>\tStufe der Wortfülle des Planers angeben"
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr "Wenn Planung nach dem Neuladen, dann Superblock-Planung"
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr "Befehle vor Registerbelegung neu planen"
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr "Befehle nach Registerbelegung neu planen"
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr "Befehle mit selektivem Planungs-Algorithmus einplanen"
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr "Ausgewählte Planung nach Neuladen laufen lassen"
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr "Während selektiver Planung Software-Pipelining innerer Schleifen durchführen"
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr "Während selektiver Planung Software-Pipelining äußerer Schleifen durchführen"
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr "Regionen mit Pipelining ohne Pipelining neu planen"
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr "Nicht ausgereifte Planung von eingereihten Befehlen erlauben"
 
-#: common.opt:1981
+#: common.opt:1984
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr "-fsched-stalled-insns=<Anzahl>\tAnzahl der eingereihten Befehle setzen, die unausgereift geplant werden können"
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr "Prüfung der Abhängigkeitsentfernung in nicht ausgereifter Planung von eingereihten Befehlen setzen"
 
-#: common.opt:1993
+#: common.opt:1996
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr "-fsched-stalled-insns-dep=<Zahl>\tPrüfung der Abhängigkeitsentfernung in nicht ausgereifter Planung von eingereihten Befehlen setzen"
 
-#: common.opt:1997
+#: common.opt:2000
 msgid "Enable the group heuristic in the scheduler"
 msgstr "Gruppenheuristik im Planer einschalten"
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr "Critical-Path-Heuristik im Planer einschalten"
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr "Heuristik für spekulative Befehle im Planer einschalten"
 
-#: common.opt:2009
+#: common.opt:2012
 msgid "Enable the rank heuristic in the scheduler"
 msgstr "Rang-Heuristik im Planer einschalten"
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr "Heuristik für letzte Befehle im Planer einschalten"
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr "Abhängige Zähl-Heuristik bei Planung einschalten"
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr "Auf Daten im gleichen Abschnitt von gemeinsam benutzten Ankerpunkten zugreifen"
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "Redundante Erweiterungsentfernung einschalten"
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr "Spaltenzahlen in Diagnose zeigen, wenn verfügbar. Standard: Ein"
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr "Funktionsprologe nur vor Teilen der Funktion erzeugen, die diese benötigt"
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr "Von IEEE-Signalisierungs-NaNs wahrnehmbare Optimierungen ausschalten"
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr "Gleitkommaoptimierungen ausschalten, die die IEEE-Vorzeichenbehaftung von Null nicht beachten"
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr "Gleitkommakonstanten in Konstanten einfacher Genauigkeit umwandeln"
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr "Lebensdauer von Induktionsvariablen aufteilen, wenn Schleifen abgerollt werden"
 
-#: common.opt:2062
+#: common.opt:2065
 msgid "Generate discontiguous stack frames"
 msgstr "Nicht zusammenhängende Stapelrahmen erzeugen"
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr "Breite Typen in unabhängige Register aufteilen"
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 #, fuzzy
 #| msgid "fixed register %s used to pass parameter to function"
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr "festes Register %s zur Parameterübergabe an Funktion verwendet"
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr "Variablenerweiterung anwenden, wenn Schleifen abgerollt werden"
 
-#: common.opt:2082
+#: common.opt:2085
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "-fstack-check=[no|generic|specific]\tStapelprüfung in das Programm einfügen"
 
-#: common.opt:2086
+#: common.opt:2089
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "Stapelprüfung in das Programm einfügen. Dasselbe wie -fstack-check=specific"
 
-#: common.opt:2093
+#: common.opt:2096
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr "-fstack-limit-register=<Register>\tWenn der Stapel über <Register> hinausgeht, abfangen (»trap«)"
 
-#: common.opt:2097
+#: common.opt:2100
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr "-fstack-limit-symbol=<Name>\tWenn der Stapel über das Symbol <Name> hinausgeht, abfangen (»trap«)"
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr "Propolice als Stapelschutzmethode verwenden"
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr "Eine Stapelschutzmethode für jede Funktion verwenden"
 
-#: common.opt:2109
+#: common.opt:2112
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions"
 msgstr "Eine Stapelschutzmethode für jede Funktion verwenden"
 
-#: common.opt:2113
+#: common.opt:2116
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr "Eine Stapelschutzmethode für jede Funktion verwenden"
 
-#: common.opt:2117
+#: common.opt:2120
 msgid "Output stack usage information on a per-function basis"
 msgstr "Information über Stapelbenutzung auf Funktionsbasis ausgeben"
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr "Annehmen, dass strenge Alias-Regeln gelten"
 
-#: common.opt:2133
+#: common.opt:2136
 msgid "Treat signed overflow as undefined"
 msgstr "Vorzeichenbehafteten Überlauf als undefiniert behandeln"
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr "__atomic-Operationen über Bibliotheksaufrufe alter __sync-Funktionen durchführen"
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr "Auf Syntaxfehler prüfen und anhalten"
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr "Von »gcov« benötigte Dateien anlegen"
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr "Sprung-Threading-Optimierungen durchführen"
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr "Benötigte Zeit für jeden Compilerdurchlauf ausgeben"
 
-#: common.opt:2157
+#: common.opt:2160
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tDas standardmäßige Codeerzeugungsmodell für Thread-lokalen Speicher angeben"
 
-#: common.opt:2160
+#: common.opt:2163
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "unbekanntes TLS-Modell %qs"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr "Funktionen, Variablen und asms höchster Ebene umordnen"
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr "Superblockerzeugung über Ende-Vervielfältigung durchführen"
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr "Annehmen, dass Gleitkommaoperationen abgefangen werden können (»trap«)"
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr "Vorzeichenbehafteten Überlauf in Addition, Subtraktion und Multiplikation abfangen (»trap«)"
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr "SSA-CCP-Optimierungen auf Bäumen einschalten"
 
-#: common.opt:2199
+#: common.opt:2202
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr "SSA-BIT-CCP-Optimierungen auf Bäumen einschalten"
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr "Kopieren des Schleifenkopfes auf Bäumen einschalten"
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr "Verbinden kopierbezogener »inline«-Benutzervariablen einschalten"
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr "Verbinden kopierbezogener Benutzervariablen einschalten"
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr "Vorübergehende SSA-Speicherbereiche in Kopien mit besseren Namen ersetzen"
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr "Kopieweitergabe auf Bäumen einschalten"
 
-#: common.opt:2231
+#: common.opt:2234
 msgid "Transform condition stores into unconditional ones"
 msgstr "Bedingte Speicherbefehle in unbedingte umwandeln"
 
-#: common.opt:2235
+#: common.opt:2238
 msgid "Perform conversions of switch initializations."
 msgstr "Umwandlungen von »switch«-Initialisierungen durchführen."
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr "Beseitigungsoptimierung für toten SSA-Code auf Bäumen einschalten"
 
-#: common.opt:2243
+#: common.opt:2246
 msgid "Enable dominator optimizations"
 msgstr "Beherrscher-Optimierungen einschalten"
 
-#: common.opt:2247
+#: common.opt:2250
 msgid "Enable tail merging on trees"
 msgstr "Enden-Zusammenfassung auf Bäumen einschalten"
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr "Entfernung toter Speicherbereiche einschalten"
 
-#: common.opt:2255
+#: common.opt:2258
 msgid "Enable forward propagation on trees"
 msgstr "Vorwärts-Übertragung auf Bäumen einschalten"
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr "Vollständige Redundanzentfernung (FRE) auf Bäumen einschalten"
 
-#: common.opt:2263
+#: common.opt:2266
 msgid "Enable string length optimizations on trees"
 msgstr "Zeichenkettenlängen-Optimierungen auf Bäumen einschalten"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 msgid "Enable loop distribution on trees"
 msgstr "Schleifenverteilung auf Bäumen einschalten"
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr "Schleifenverteilung für in Bibliotheksaufruf umgewandelte Muster einschalten"
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr "Bewegung der Schleifeninvariante auf Bäumen einschalten"
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr "Umwandlungen mit Schleifenaustausch einschalten. Das Gleiche wie -floop-interchange"
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr "Kanonische Induktionsvariablen in Schleifen erzeugen"
 
-#: common.opt:2300
+#: common.opt:2303
 msgid "Enable loop optimizations on tree level"
 msgstr "Schleifenoptimierungen auf Baumebene einschalten"
 
-#: common.opt:2304
+#: common.opt:2307
 msgid "Enable automatic parallelization of loops"
 msgstr "Automatische Parallelisierung von Schleifen einschalten"
 
-#: common.opt:2308
+#: common.opt:2311
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Herausziehen von Ladeoperationen aus bedingten Zeigern einschalten"
 
-#: common.opt:2312
+#: common.opt:2315
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "SSA-PRE-Optimierungen auf Bäumen einschalten"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr "In SSA-PRE-Optimierungen auf Bäumen Teils-Teils-Redundanz eliminieren"
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Funktionslokale Analyse von Zeigerzielen auf Bäumen durchführen."
 
-#: common.opt:2324
+#: common.opt:2327
 msgid "Enable reassociation on tree level"
 msgstr "Neuverbindung auf Baumebene einschalten"
 
-#: common.opt:2332
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
 msgstr "SSA-Codeversenkung auf Bäumen einschalten"
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr "Stärkereduktion gerader Strecken durchführen"
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr "Skalarersetzung von Aggregaten durchführen"
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr "Vorübergehende Ausdrücke im SSA-Normaldurchlauf ersetzen"
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr "Lebensdaueraufteilung während des SSA-Normaldurchlaufs durchführen"
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr "Wertebereichsweitergabe auf Bäumen durchführen"
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr "Ganze Übersetzungseinheit auf einmal übersetzen"
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr "Schleifenabwicklung durchführen, wenn Anzahl der Wiederholungen bekannt ist"
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr "Schleifenabwicklung für alle Schleifen durchführen"
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr "Bei Schleifenoptimierungen annehmen, dass sich die Schleifen normal verhalten"
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr "Optimierung für Gleitkommaarithmetik erlauben, bei möglicher Änderung von"
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Das gleiche wie -fassociative-math für Ausdrücke, die Division enthalten."
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr "Mathematische Optimierungen erlauben, die IEEE- oder ISO-Standards verletzen könnten"
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr "Schleifenausschaltung durchführen"
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr "Einfach Abwicklungstabellen für Ausnahmebehandlung erzeugen"
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr "BFD-Linker statt Standardlinker verwenden"
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr "Gold-Linker statt Standardlinker verwenden"
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr "Variablenverfolgung durchführen"
 
-#: common.opt:2424
+#: common.opt:2427
 msgid "Perform variable tracking by annotating assignments"
 msgstr "Variablenverfolgung durch Zuweisungsanmerkungen durchführen"
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr "-fvar-tracking-assignments umschalten"
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr "Variablenverfolgung durchführen und auch Variablen markieren, die uninitialisiert sind"
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees"
 msgstr "Schleifenvektorisierung auf Bäumen einschalten"
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr "Schleifenvektorisierung auf Bäumen einschalten"
 
-#: common.opt:2454
+#: common.opt:2457
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr "Vektorisierung von Basisblöcken (SLP) auf Bäumen einschalten"
 
-#: common.opt:2458
+#: common.opt:2461
 #, fuzzy
 #| msgid "Specify the model for atomic operations"
 msgid "Specifies the cost model for vectorization"
 msgstr "Das Modell für atomare Operationen angeben"
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 #| msgid "unknown pointer size model %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "unbekanntes Zeigergrößenmodell %qs"
 
-#: common.opt:2478
+#: common.opt:2481
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Tut nichts. Für Rückwärtskompatibilität erhalten."
 
-#: common.opt:2482
+#: common.opt:2485
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Tut nichts. Für Rückwärtskompatibilität erhalten."
 
-#: common.opt:2490
+#: common.opt:2493
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Kopieweitergabe von Informationen über Skalar-Evolution einschalten."
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr "Zusätzlichen Kommentar an Assemblerausgabe anfügen"
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr "-fvisibility=[default|internal|hidden|protected]\tStandard-Symbolsichtbarkeit setzen"
 
-#: common.opt:2507
+#: common.opt:2510
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "unbekannter Sichtbarkeitswert %qs"
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(nahe der Initialisierung für %qs)"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr "Profile von Ausdruckswerten in Optimierungen verwenden"
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr "Netze konstruieren und nicht zusammenhängende Verwendungen einzelner Variablen aufteilen"
 
-#: common.opt:2555
+#: common.opt:2558
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr "Beseitigung von bedingt totem Code für Aufrufe eingebauter Funktionen einschalten"
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr "Gesamtprogrammoptimierung durchführen"
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr "Annehmen, dass vorzeichenbehaftete arithmetische Überläufe regulär überschlagen"
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr "Null-initialisierte Daten in den bss-Abschnitt legen"
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr "Fehlersuchinformationen im Standardformat erzeugen"
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr "Fehlersuchinformationen im COFF-Format erzeugen"
 
-#: common.opt:2579
+#: common.opt:2582
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format"
 msgstr "Fehlersuchinformationen im Standardformat erzeugen"
 
-#: common.opt:2583
+#: common.opt:2586
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr "Fehlersuchinformationen im DWARFv2-Format (oder neuer) erzeugen"
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr "Fehlersuchinformationen im erweiterten Standardformat erzeugen"
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Keine DWARF-Abschnitte für Pubnames und Pubtypes erzeugen"
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "DWARF-Abschnitte für Pubnames und Pubtypes erzeugen"
 
-#: common.opt:2599
+#: common.opt:2602
 #, fuzzy
 #| msgid "Generate DWARF pubnames and pubtypes sections."
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "DWARF-Abschnitte für Pubnames und Pubtypes erzeugen"
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr "GCC-Kommandozeilenschalter nicht in DWARF DW_AT_producer aufzeichnen."
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "GCC-Kommandozeilenschalter in DWARF DW_AT_producer aufzeichnen."
 
-#: common.opt:2611
+#: common.opt:2614
 msgid "Don't generate debug information in separate .dwo files"
 msgstr "Keine Fehlersuchinformationen in eigenen .dwo-Dateien erzeugen"
 
-#: common.opt:2615
+#: common.opt:2618
 msgid "Generate debug information in separate .dwo files"
 msgstr "Fehlersuchinformationen in eigenen .dwo-Dateien erzeugen"
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr "Fehlersuchinformationen im STABS-Format erzeugen"
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr "Fehlersuchinformationen im erweiterten STABS-Format erzeugen"
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr "DWARF-Ergänzungen über gewählte Version hinaus ausgeben"
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr "Keine DWARF-Ergänzungen über gewählte Version hinaus ausgeben"
 
-#: common.opt:2635
+#: common.opt:2638
 msgid "Toggle debug information generation"
 msgstr "Erzeugung von Fehlersuchinformationen umschalten"
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr "Fehlersuchinformationen im VMS-Format erzeugen"
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr "Fehlersuchinformationen im XCOFF-Format erzeugen"
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr "Fehlersuchinformationen im erweiterten XCOFF-Format erzeugen"
 
-#: common.opt:2665
+#: common.opt:2668
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections"
 msgstr "isel-Befehle erzeugen"
 
-#: common.opt:2669
+#: common.opt:2672
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr "Fehlersuchinformationen im Standardformat erzeugen"
 
-#: common.opt:2676
+#: common.opt:2679
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr "-iplugindir=<Verz>\t<Verz> als Standard-Plugin-Verzeichnis setzen"
 
-#: common.opt:2680
+#: common.opt:2683
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr "-imultiarch <Verzeichnis>\t<Verzeichnis> als Multiarch-include-Verzeichnis setzen"
 
-#: common.opt:2702
+#: common.opt:2705
 msgid "-o <file>\tPlace output into <file>"
 msgstr "-o <Datei>\tAusgabe in <Datei> schreiben"
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr "Funktionsprofilierung einschalten"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr "Wie -pedantic, aber als Fehler ausgeben"
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr "Nicht übersetzte Funktionen oder gestoppte Zeit ausgeben"
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr "Wortreiche Ausgabe einschalten"
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr "Compiler-Version anzeigen"
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "Warnungen unterdrücken"
 
-#: common.opt:2806
+#: common.opt:2809
 msgid "Create a shared library"
 msgstr "Shared Library erzeugen"
 
-#: common.opt:2851
+#: common.opt:2854
 msgid "Create a position independent executable"
 msgstr "Eine lageunabhängige ausführbare Datei erzeugen"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "berechneter Wert ist unbenutzt"
@@ -14938,231 +14952,231 @@
 msgid "expected integer or boolean type"
 msgstr "Ganzzahlausdruck oder boolescher Typ erwartet"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 msgid "invalid comparison of nil with nil"
 msgstr "ungültiger Vergleich von nil mit nil"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 msgid "incompatible types in binary expression"
 msgstr "inkompatible Typen in binärem Ausdruck"
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 #| msgid "division by zero"
 msgid "integer division by zero"
 msgstr "Division durch Null"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 msgid "shift of non-integer operand"
 msgstr "Schiebeoperation eines Nicht-Ganzzahloperanden"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 msgid "shift count not unsigned integer"
 msgstr "Schiebeweite ist keine vorzeichenlose Ganzzahl"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 msgid "negative shift count"
 msgstr "negative Schiebeweite"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 msgid "object is not a method"
 msgstr "Objekt ist keine Methode"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 msgid "method type does not match object type"
 msgstr "Methodentyp passt nicht zum Objekttyp"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 msgid "invalid use of %<...%> with builtin function"
 msgstr "ungültige Verwendung von %<...%> mit eingebauter Funktion"
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 #, fuzzy
 #| msgid "invalid use of template-name %qE without an argument list"
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "ungültige Verwendung des Template-Namens %qE ohne eine Argumentliste"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 msgid "not enough arguments"
 msgstr "Nicht genug Argumente"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 msgid "too many arguments"
 msgstr "zu viele Argumente"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 msgid "argument 1 must be a map"
 msgstr "Argument 1 muss eine Abbildung sein"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 msgid "invalid type for make function"
 msgstr "ungültiger Typ für »make«-Funktion"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr "Bei Reservierung einer Scheibe wird Länge benötigt"
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr "Länge größer als Cap"
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 msgid "too many arguments to make"
 msgstr "zu viele Argumente für make"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 msgid "argument must be array or slice or channel"
 msgstr "Argument muss Feld oder Scheibe oder Kanal sein"
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr "Argument muss Zeichenkette oder Feld oder Scheibe oder Abbildung oder Kanal sein"
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 msgid "unsupported argument type to builtin function"
 msgstr "nicht unterstützter Argumenttyp für eingebaute Funktion"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 msgid "argument must be channel"
 msgstr "Argument muss ein Kanal sein"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr "Nur-Empfangs-Kanal kann nicht geschlossen werden"
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 msgid "argument must be a field reference"
 msgstr "Argument muss eine Feldreferenz sein"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 msgid "left argument must be a slice"
 msgstr "linkes Argument muss eine Scheibe sein"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr "Elementtypen müssen dieselben sein"
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 msgid "first argument must be []byte"
 msgstr "erstes Argument muss []byte sein"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 msgid "second argument must be slice or string"
 msgstr "zweites Argument muss eine Scheibe oder Zeichenkette sein"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 msgid "argument 2 has invalid type"
 msgstr "Argument 2 hat ungültigen Typen"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 msgid "argument must have complex type"
 msgstr "Argument muss komplexen Typen haben"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 msgid "complex arguments must have identical types"
 msgstr "komplexe Argumente müssen identische Typen haben"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 msgid "complex arguments must have floating-point type"
 msgstr "komplexe Argumente müssen Gleitkommatyp haben"
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 msgid "expected function"
 msgstr "Funktion erwartet"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 #, fuzzy
 #| msgid "multiple-value function call in single-value context"
 msgid "multiple-value argument in single-value context"
 msgstr "Funktionsaufruf mit mehreren Werten in Kontext mit einem Wert"
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 msgid "invalid use of %<...%> with non-slice"
 msgstr "ungültige Verwendung von %<...%> mit Nicht-Slice"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 #, fuzzy
 #| msgid "Function return value not set"
 msgid "function result count mismatch"
 msgstr "Rückgabewert der Funktion nicht gesetzt"
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 msgid "incompatible type for receiver"
 msgstr "inkompatible Typen für Empfänger"
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "ungültige Verwendung von %<this%> bei Aufruf einer nicht-variadischen Funktion"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 msgid "number of results does not match number of values"
 msgstr "Anzahl der Ergebnisse passt nicht zur Anzahl der Werte"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 msgid "index must be integer"
 msgstr "Index muss eine Ganzzahl sein"
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 msgid "slice end must be integer"
 msgstr "Scheibenende muss eine Ganzzahl sein"
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 #| msgid "slice end must be integer"
 msgid "slice capacity must be integer"
 msgstr "Scheibenende muss eine Ganzzahl sein"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr "umgekehrter Scheibenbereich"
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr "Scheibe ohne adressierbaren Wert"
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 msgid "incompatible type for map index"
 msgstr "inkompatible Typen für Abbildungsindex"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr "Schnittstelle oder Zeiger auf Schnittstelle erwartet"
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 msgid "too many expressions for struct"
 msgstr "zu viele Ausdrücke für Struktur"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 msgid "too few expressions for struct"
 msgstr "zu wenige Ausdrücke für Struktur"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 msgid "type assertion only valid for interface types"
 msgstr "Typbehauptung nur gültig für Schnittstellentypen"
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr "unmögliche Typenbehauptung: Typ implementiert nicht Schnittstelle"
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 msgid "expected channel"
 msgstr "Kanal erwartet"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr "ungültiges Empfangen auf Nur-Sende-Kanal"
 
@@ -15272,71 +15286,71 @@
 msgid "cannot use type %s as type %s"
 msgstr "Typ %s kann nicht als Typ %s verwendet werden"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 msgid "different receiver types"
 msgstr "unterschiedliche Empfängertypen"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 msgid "different number of parameters"
 msgstr "unterschiedliche Parameteranzahl"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 msgid "different parameter types"
 msgstr "unterschiedliche Parametertypen"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr "unterschiedliche variable Argumente"
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr "unterschiedliche Ergebnisanzahl"
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 msgid "different result types"
 msgstr "unterschiedliche Ergebnistypen"
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "explizite Umwandlung nötig; Methode %s%s%s fehlt"
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "Inkompatibler Typ für Methode %s%s%s"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "Inkompatibler Typ für Methode %s%s%s (%s)"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr "Zeiger auf Schnittstellentyp hat keine Methoden"
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 msgid "type has no methods"
 msgstr "Typ hat keine Methoden"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "mehrdeutige Methode %s%s%s"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "fehlende Methode %s%s%s"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "Methode %s%s%s erfordert einen Zeigerempfänger"
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr "Methode %s%s%s ist als go:nointerface gekennzeichnet"
@@ -15461,7 +15475,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "Ungültiges drittes Argument für %<__builtin_prefetch%>; es wird Null verwendet"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "Zu wenige Argumente für %<va_start%>"
@@ -15643,12 +15657,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%KVersuch, Nicht-Heap-Objekt freizugeben"
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "Funktionsaufruf hat zusammengesetzten Wert"
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT for argument %P to %qD"
 msgid "passing too large argument on stack"
@@ -16214,254 +16228,259 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "Anzahl der bb-Vermerke in Befehlskette (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr "Rufer-Kantenzähler ist negativ"
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr "Rufer-Kantenhäufigkeit ist negativ"
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr "Rufer-Kantenhäufigkeit ist zu groß"
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "Aux-Feld für Kante %s->%s gesetzt"
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, gcc-internal-format
 msgid "execution count is negative"
 msgstr "Ausführungszähler ist negativ"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "»inline«-Clone in gleicher Comdat-Gruppenliste"
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, fuzzy, gcc-internal-format
 #| msgid "no symbol table found"
 msgid "local symbols must be defined"
 msgstr "keine Symboltabelle gefunden"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "extern sichtbare Inline-Kopie"
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "Inline-Kopie mit Adresse genommen"
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "Ausgabe für Inline-Kopie erzwungen"
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "Aux-Feld für indirekte Kante %s von gesetzt"
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Eine indirekte Kante von %s ist nicht als indirekt markiert und hat keine zugeordnete indirect_info, die zugehörige Anweisung ist:"
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to-Zeiger ist falsch"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "mehrere Inline-Aufrufer"
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "inlined_to-Zeiger für Nicht-Inline-Aufrufer gesetzt"
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr "Rufer-Kantenhäufigkeit %i passt nicht zur BB-Häufigkeit %i"
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "caller edge frequency %i does not match BB frequency %i"
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr "Rufer-Kantenhäufigkeit %i passt nicht zur BB-Häufigkeit %i"
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "inlined_to-Zeiger gesetzt, aber keine Vorgänger gefunden"
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "Inlined_to-Zeiger verweist auf sich selbst"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, fuzzy, gcc-internal-format
 #| msgid "node has wrong clone_of"
 msgid "cgraph_node has wrong clone_of"
 msgstr "Knoten hat falsches clone_of"
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, fuzzy, gcc-internal-format
 #| msgid "node has wrong clone list"
 msgid "cgraph_node has wrong clone list"
 msgstr "Knoten hat falsche Clone-Liste"
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "node is in clone list but it is not clone"
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "Knoten ist in Clone-Liste, aber es ist kein Clone"
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, fuzzy, gcc-internal-format
 #| msgid "node has wrong prev_clone pointer"
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "Knoten hat falschen Zeiger prev_clone"
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "doppelt verkettete Liste des Clones ist beschädigt"
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Alias hat Aufruf-Kanten"
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Alias hat Nicht-Alias-Referenz"
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Alias hat mehr als eine Alias-Reference"
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "Analysierter Alias hat keine Referenz"
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "Ausrichtung von %qD ist größer als ursprüngliche Deklaration"
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "Instrumented node has wrong original declaration"
 msgstr "Ausrichtung von %qD ist größer als ursprüngliche Deklaration"
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, fuzzy, gcc-internal-format
 #| msgid "Alias has more than one alias reference"
 msgid "Node has more than one chkp reference"
 msgstr "Alias hat mehr als eine Alias-Reference"
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, fuzzy, gcc-internal-format
 #| msgid "forming reference to reference type %qT"
 msgid "Wrong node is referenced with chkp reference"
 msgstr "Referenz auf Referenztyp %qT wird geformt"
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, fuzzy, gcc-internal-format
 #| msgid "Analyzed alias has no reference"
 msgid "Analyzed node has no reference to instrumented version"
 msgstr "Analysierter Alias hat keine Referenz"
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Keine Kante aus Thunk-Knoten"
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Mehr als eine Kante aus Thunk-Knoten"
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Thunk sollte keinen Körper haben"
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "Gemeinsam genutztes call_stmt:"
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "Kante zeigt auf falsche Deklaration:"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "eine indirekte Kante mit unbekanntem Aufrufziel korrespondiert mit einem call_stmt mit einer unbekannten Deklaration:"
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "Fehlende Aufrufgraph-Kante für call stmt:"
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "Anweisung erwartet"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "Kante %s->%s hat keine passende call_stmt"
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "eine indirekte Kante von %s hat kein passendes call_stmt"
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph gescheitert"
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "%s: Abschnitt %s fehlt"
@@ -16592,7 +16611,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER muss gesetzt sein"
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, gcc-internal-format
 msgid "atexit failed"
@@ -16835,17 +16854,17 @@
 msgid "          %s"
 msgstr "          %s"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr "Gemeinsame Symbol-Debuginfo ist nicht als Symbol+Offset strukturiert"
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "globale Destruktoren werden für dieses Ziel nicht unterstützt"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "globale Konstruktoren werden für dieses Ziel nicht unterstützt"
@@ -16890,12 +16909,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "Mehrere EH-Persönlichkeiten werden nur mit Assemblern unterstützt, die die Direktive .cfi_personality unterstützen"
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "Nicht-Delegitimiertes UNSPEC %s (%d) am Variablenort gefunden"
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -17092,7 +17111,7 @@
 msgid "total size of local objects too large"
 msgstr "Gesamtgröße der lokalen Objekte zu hoch"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "unmögliche Bedingung in »asm«"
@@ -17546,9 +17565,9 @@
 msgstr "PCH-Datei kann nicht geschrieben werden"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, gcc-internal-format
 msgid "declared here"
 msgstr "hier deklariert"
@@ -17563,163 +17582,157 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr "GIMPLE-Prüfung: %s(%s) erwartet, haben %s(%s) in %s, bei %s:%d"
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "Ergebnis einer %<void%> zurückgebenden Funktion verwendet"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "ungültiger L-Wert in asm-Ausgabe %d"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "Eingabe von Nicht-Speicher %d muss im Speicher bleiben"
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "Speichereingabe %d ist nicht direkt adressierbar"
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, fuzzy, gcc-internal-format
 #| msgid "threadprivate variable %qE used in untied task"
 msgid "threadprivate variable %qE used in target region"
 msgstr "threadprivate Variable %qE in unverknüpfter Task verwendet"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "umgebende Zielregion"
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "threadprivate Variable %qE in unverknüpfter Task verwendet"
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "umgebende Task"
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr "%qE in umgebender Parallele nicht angegeben"
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr "umgebende Parallele"
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, fuzzy, gcc-internal-format
 #| msgid "%qE not specified in enclosing parallel"
 msgid "%qE not specified in enclosing task"
 msgstr "%qE in umgebender Parallele nicht angegeben"
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, fuzzy, gcc-internal-format
 #| msgid "%qE not specified in enclosing parallel"
 msgid "%qE not specified in enclosing teams construct"
 msgstr "%qE in umgebender Parallele nicht angegeben"
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing task"
 msgid "enclosing teams construct"
 msgstr "umgebende Task"
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 #| msgid "%Hiteration variable %qE is unsigned"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%HSchleifenvariable %qE ist vorzeichenlos"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "Schleifenvariable %qE sollte »private« sein"
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "Schleifenvariable %qE sollte nicht »firstprivate« sein"
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "Schleifenvariable %qE sollte nicht Reduktion sein"
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qE should not be firstprivate"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "Schleifenvariable %qE sollte nicht »firstprivate« sein"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qE should be private"
 msgid "iteration variable %qE should not be private"
 msgstr "Schleifenvariable %qE sollte »private« sein"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qE is private in outer context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s Variable %qE ist im äußeren Kontext »private«"
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s Variable %qE ist im äußeren Kontext »private«"
 
-#: gimplify.c:7001
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, fuzzy, gcc-internal-format
-#| msgid "%s variable %qE is private in outer context"
-msgid "lastprivate variable %qE is private in outer context"
-msgstr "%s Variable %qE ist im äußeren Kontext »private«"
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
-#, fuzzy, gcc-internal-format
 #| msgid "Finalization at %L is not yet implemented"
 msgid "directive not yet implemented"
 msgstr "Finalisierung bei %L ist noch nicht implementiert"
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "%<}%> vor %<else%> erwartet"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "Gimplifikation gescheitert"
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "Erstes Argument für %<va_arg%> nicht vom Typ %<va_list%>"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT auf %qT erweitert beim Durchlaufen von %<...%>"
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(Es sollte also %qT statt %qT an %<va_arg%> übergeben werden)"
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "Wenn dieser Code erreicht wird, wird das Programm abgebrochen"
@@ -18162,48 +18175,48 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr "Höchstzahl der erzeugten Neuladeanweisungen pro Anweisung ist erreicht (%d)\n"
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "bytecode stream: found multiple instances of cgraph node %d"
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "Bytecode-Strom: Mehrere Instanzen des Cgraph-Knoten %d gefunden"
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "Bytecode-Strom: Kein Aufrufer beim Lesen der Kante gefunden"
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "Bytecode-Strom: Kein Gerufener beim Lesen der Kante gefunden"
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "Bytecode-Strom: Leeren Cgraph-Knoten gefunden"
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "Es werden höchstens %i Profildurchläufe unterstützt. Evtl. beschädigte Datei?"
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "Profilinformation in %s ist beschädigt"
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "LTO cgraph kann nicht in %s gefunden werden"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "LTO-Abschnittsreferenzen können nicht in %s gefunden werden"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -18291,49 +18304,49 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "ungültige COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr "Option %s nicht konsistent in allen LTO-Eingabedateien verwendet"
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "keine Eingabedateien"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing output file '%s'\n"
 msgid "writing output file"
 msgstr "Fehler beim Schreiben der Ausgabedatei »%s«\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "Umgebungsvariable COLLECT_GCC muss gesetzt sein"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "Umgebungsvariable COLLECT_GCC_OPTIONS muss gesetzt sein"
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s: %m"
 msgid "fopen: %s: %m"
@@ -18474,13 +18487,13 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid exit from OpenMP structured block"
 msgid "invalid exit from %s structured block"
 msgstr "ungültiger Ausgang von strukturiertem OpenMP-Block"
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid entry to OpenMP structured block"
 msgid "invalid entry to %s structured block"
@@ -18487,19 +18500,19 @@
 msgstr "ungültiger Eintritt in strukturierten OpenMP-Block"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid branch to/from an OpenMP structured block"
 msgid "invalid branch to/from %s structured block"
 msgstr "ungültiger Zweig zu/von strukturiertem OpenMP-Block"
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "ignoring large linear step"
 msgstr "doppeltes Verzeichnis »%s« wird ignoriert\n"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -19034,8 +19047,8 @@
 msgstr "%qs kann nicht als ein festes Register verwendet werden"
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "unbekannter Registername: %s"
@@ -19483,7 +19496,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld gab %d als Ende-Status zurück"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F verwendet, aber nirgendwo definiert"
@@ -20469,43 +20482,43 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fixed-point types not supported for this target"
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr "Festkommatypen werden für dieses Ziel nicht unterstützt"
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -20886,47 +20899,47 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, gcc-internal-format
 msgid "array subscript is outside array bounds"
 msgstr "Feldindex ist außerhalb der Feldgrenzen"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, gcc-internal-format
 msgid "array subscript is above array bounds"
 msgstr "Feldindex ist oberhalb der Feldgrenzen"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, gcc-internal-format
 msgid "array subscript is below array bounds"
 msgstr "Feldindex ist unterhalb der Feldgrenzen"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Bedingung zu Konstante vereinfacht wird"
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf bei Vereinfachung der Bedingung nicht auftritt"
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr "Vergleich ist durch beschränkten Wertebereich des Datentyps stets »unwahr«"
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr "Vergleich ist durch beschränkten Wertebereich des Datentyps stets »wahr«"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn %</%> oder %<%%%> auf %<>>%> oder %<&%> vereinfacht wird"
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn %<abs (X)%> auf %<X%> oder %<-X%> vereinfacht wird"
@@ -20970,9 +20983,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21207,7 +21220,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "angeforderte Ausrichtung für %q+D ist größer als die implementierte Ausrichtung von %wu"
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "Speichergröße von %q+D ist unbekannt"
@@ -21364,27 +21377,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "Zeichenkettenlänge %qd ist größer als die Länge %qd, die von ISO-C%d-Compilern unterstützt werden muss"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "Links-Schiebe-Weite ist negativ"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "Rechts-Schiebe-Weite ist negativ"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "Links-Schiebe-Weite >= Breite des Typs"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "Rechts-Schiebe-Weite >= Breite des Typs"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "Überlauf in Konstanten-Ausdruck"
@@ -21716,12 +21729,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "Die Adresse von %qD wird immer zu %<wahr%> auswerten"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "Um Zuweisung, die als Wahrheitswert verwendet wird, werden Klammern empfohlen"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "Ungültige Verwendung von %<restrict%>"
@@ -22178,12 +22191,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "Ungültiger Vektortyp für Attribut %qE"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "Vektorgröße kein ganzzahliges Vielfaches der Komponentengröße"
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "Vektorgröße Null"
@@ -22193,22 +22206,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr "Komponentenanzahl des Vektors ist keine Zweierpotenz"
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "Nicht-Null-Attribut ohne Argumente für einen Nicht-Prototyp"
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "Nicht-Null-Argument hat ungültige Operandenzahl (Argument %lu)"
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "Nicht-Null-Argument mit Operandenzahl außerhalb des Wertebereiches (Argument %lu, Operand %lu)"
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "Nicht-Null-Argument referenziert Nicht-Zeiger-Operanden (Argument %lu, Operand %lu)"
@@ -22248,12 +22261,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "Attribut %qE gilt nur für variadische Funktionen"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "Angeforderte Position ist keine Ganzzahlkonstante"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "Angeforderte Position ist kleiner als Null"
@@ -22337,7 +22350,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "%<offsetof%> kann nicht auf nicht-konstante Adresse angewandt werden"
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "Versuch, die Adresse des Bitfeldstrukturelements %qD zu ermitteln"
@@ -22756,7 +22769,7 @@
 msgstr "Indexwert ist außerhalb der Grenzen"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "Umwandlung von Skalar %qT in Vektor %qT führt zum Abschneiden"
@@ -23212,7 +23225,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> verwendet zwei unterschiedliche Variablen für Speicher"
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ungültiger Typ für Schleifenvariable %qE"
@@ -23222,22 +23235,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE ist nicht initialisiert"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Steuerprädikat fehlt"
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Steuerprädikat ungültig"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "Erhöhungsausdruck fehlt"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Erhöhungsausdruck ungültig"
@@ -23781,6 +23794,12 @@
 msgid "too many input files"
 msgstr "zu viele Eingabedateien"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+#| msgid "stack frame too large"
+msgid "-mcpu string too large"
+msgstr "Stapelrahmen zu groß"
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -23807,47 +23826,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s hat ungültige Silizium-Revision"
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops ist veraltet, Ersatz: -falign-loops"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d ist nicht zwischen 0 und %d"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps ist veraltet, Ersatz: -falign-jumps"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d ist nicht zwischen 0 und %d"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions ist veraltet, Ersatz: -falign-functions"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d ist nicht zwischen 0 und %d"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d ist nicht zwischen 0 und 5"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> wird derzeit nur auf GNU/Linux unterstützt"
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> erfordert Assemblerunterstützung für CFI-Anweisungen"
@@ -24237,63 +24256,63 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr "Spur ist außerhalb des Wertebereiches"
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "falscher Wert %qs für Schalter -mtrap-precision"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "Falscher Wert %qs für Schalter -mfp-rounding-mode"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "Falscher Wert %qs für Schalter -mfp-trap-mode"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr "Falscher Wert %qs für Schalter -mcpu"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, gcc-internal-format
 msgid "bad value %qs for -mtune switch"
 msgstr "Falscher Wert %qs für Schalter -mtune"
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr "FP-Software-Vervollständigung benötigt -mtrap-precision=i"
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "Rundungsmodus für VAX-Floats nicht unterstützt"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "Trap-Modus für VAX-Floats nicht unterstützt"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr "128-bit long double nicht unterstützt für VAX floats"
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr "L%d Cache-Wartezeit unbekannt für %s"
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr "Falscher Wert %qs für -mmemory-latency"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -24774,14 +24793,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, gcc-internal-format
 msgid "%qE attribute only applies to functions"
@@ -25436,390 +25455,408 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "Position in PCH-Datei kann nicht gesetzt werden: %m"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-Werror=%s: no option -%s"
 msgid "wrong arg %s to option %s"
 msgstr "-Werror=%s: Keine Option -%s"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "the range of selector should be in 0 to 7"
 msgid "size ranges of option %s should be increasing"
 msgstr "der Wertebereich des Selektors sollte 0 bis 7 sein"
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "für %q+D wurde kein Registername angegeben"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "register name not specified for %q+D"
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr "für %q+D wurde kein Registername angegeben"
+
+#: config/i386/i386.c:3012
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "alignment specified for function %qE"
 msgid "unknown alignment %s specified for option %s"
 msgstr "Ausrichtung für Funktion %qE angegeben"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid range %s in option %s"
 msgid "too many size ranges specified in option %s"
 msgstr "Ungültiger Bereich %s in Option %s"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown argument list function at %L"
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "Unbekannte Argumentlistenfunktion bei %L"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr "%stune=x86-64%s ist veraltet; stattdessen entsprechend %stune=k8%s oder %stune=generic%s verwenden"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte wird für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "Adressmodus %qs wird im %s-Bit-Modus nicht unterstützt"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "Codemodell %qs wird im %s-Bit-Modus nicht unterstützt"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "Codemodell %qs wird im x32-Modus nicht unterstützt"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "Codemodell %s unterstützt keinen PIC-Modus"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel wird in dieser Konfiguration nicht unterstützt"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-Bit-Modus nicht einkompiliert"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "Die ausgewählte CPU unterstützt nicht den x86-64 Befehlssatz"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support APCS-26"
 msgid "Intel MPX does not support x32"
 msgstr "Ziel-CPU unterstützt nicht APCS-26"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr "generische CPU kann nur für %stune=%s %s verwendet werden"
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr "generische CPU kann nur für %stune=%s %s verwendet werden"
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "falscher Wert (%s) für %sarch=%s %s"
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "Falscher Wert (%s) für %stune=%s %s"
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d ist nicht zwischen 0 und %d"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr "%srtd%s wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary wird für dieses Ziel nicht unterstützt"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d ist nicht zwischen %d und %d"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d ist nicht zwischen %d und 12"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mno-fentry ist nicht mit SEH verträglich"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "Optimierungen zwischen Modulen noch nicht implementiert für C++"
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr "%ssseregparm%s ohne aktiviertes SSE verwendet"
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-Befehlssatz ausgeschaltet, es wird 387-Arithmetik verwendet"
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-Befehlssatz ausgeschaltet, es wird SSE-Arithmetik verwendet"
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr "Stapel-Überprüfung erfordert %saccumulate-outgoing-args%s für Korrektheit"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry wird für 32 Bit in Kombination mit -fpic nicht unterstützt"
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry ist nicht mit SEH verträglich"
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "unbekannte Option für -mrecip=%s"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "Argument für Attribut %<target%> ist keine Zeichenkette"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) ist unbekannt"
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") wurde bereits spezifiziert"
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "Attribute fastcall und regparm sind nicht verträglich"
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "Attribute regparam und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "Attribut %qE benötigt eine Ganzzahlkonstante als Argument"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "Argument für Attribut %qE ist größer als %d"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "Attribute fastcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "Attribute fastcall und stdcall sind nicht verträglich"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "Attribute fastcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "Attribute stdcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "Attribute stdcall und fastcall sind nicht verträglich"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "Attribute stdcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "Attribute cdecl und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "Attribut %qE wird für für Nicht-Klassen-Methode verwendet"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Aufruf von %qD mit Attribut sseregparam ohne SSE/SSE2 aktiviert"
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Aufruf von %qT mit Attribut sseregparam ohne SSE/SSE2 aktiviert"
 
-#: config/i386/i386.c:5923
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
-#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr "Aufruf von %qD mit Attribut sseregparam ohne SSE/SSE2 aktiviert"
-
-#: config/i386/i386.c:6210
-#, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "unterstützt nicht multilib"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue ist mit geschachtelter Funktion nicht verträglich"
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX-Vektorargument ohne eingeschaltetes AVX ändert das ABI"
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX-Vektorargument ohne eingeschaltetes AVX ändert das ABI"
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX-Vektorargument ohne eingeschaltetes AVX ändert das ABI"
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX-Vektorargument ohne eingeschaltetes AVX ändert das ABI"
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE-Vektorargument ohne eingeschaltetes SSE ändert das ABI"
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE-Vektorrückgabe ohne eingeschaltetes SSE ändert das ABI"
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX-Vektorargument ohne eingeschaltetes MMX ändert das ABI"
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX-Vektorrückgabe ohne eingeschaltetes MMX ändert das ABI"
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "Das ABI der Struct-Übergabe mit einem flexiblen Feldelement hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "Das ABI der Union-Übergabe mit »long double« hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "Das ABI der Strukturübergabe mit komplexem Gleitkommaelement hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE-Registerrückgabe mit SSE ausgeschaltet"
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE-Registerargument mit SSE ausgeschaltet"
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87-Registerrückgabe mit ausgeschaltetem x87"
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, fuzzy, gcc-internal-format
+#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr "Aufruf von %qD mit Attribut sseregparam ohne SSE/SSE2 aktiviert"
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "Das ABI der Parameterübergabe mit %d-Byte-Ausrichtung hat sich in GCC 4.6 geändert"
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
+#, fuzzy, gcc-internal-format
+#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr "Aufruf von %qD mit Attribut sseregparam ohne SSE/SSE2 aktiviert"
+
+#: config/i386/i386.c:11378
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "Attribut ms_hook_prologue ist mit -mfentry für 32 Bit nicht verträglich"
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack unterstützt nicht fastcall mit geschachtelter Funktion"
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 2 register  parameters for a nested function"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -25827,265 +25864,265 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack unterstützt nicht 3 Registerparameter"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "erweiterte Register haben keine oberen Hälften"
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "nicht unterstützte Operandengröße für erweitertes Register"
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "Nicht-Ganzzahl-Operand mit Operandencode »z« verwendet"
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "Kein Dispatcher für versionierte Attribute gefunden"
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Kein Dispatcher für %s gefunden"
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "Kein Dispatcher für versionierte Attribute gefunden: %s"
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Funktionsversionen können nicht als gnu_inline markiert werden, Körper müssen generiert werden"
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionierung virtueller Funktionen wird nicht unterstützt"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr "Attribut %<target%> fehlt für multiversioniertes %D"
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "vorherige Deklaration von %D"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 #| msgid "multiversioning needs ifunc which is not supported in this configuration"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "Multiversionierung erfordert ifunc, was in dieser Konfiguration nicht unterstützt wird"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Parameter für eingebaute Funktion muss Zeichenkettenkonstante oder Literal sein"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "Parameter für eingebaute Funktion ist ungültig: %s"
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "Das letzte Argument muss ein 2-Bit-Immediate sein"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "fünftes Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "drittes Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "Das letzte Argument muss ein 1-Bit-Immediate sein"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 32-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "Das letzte Argument muss ein 32-Bit-Immediate sein"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "Das letzte Argument muss ein 4-Bit-Immediate sein"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "Das letzte Argument muss ein 1-Bit-Immediate sein"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "Das letzte Argument muss ein 5-Bit-Immediate sein"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "Das vorletzte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "Das letzte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "Argument muss eine Konstante sein"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect comparison mode"
 msgstr "falscher gemeinsame Verwendung von Baumknoten"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "falscher gemeinsame Verwendung von Baumknoten"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "Das letzte Argument muss ein 4-Bit-Immediate sein"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "Das letzte Argument muss ein 5-Bit-Immediate sein"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "Das letzte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "Das letzte Argument muss ein 32-Bit-Immediate sein"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "Selektor eine Ganzzahlkonstante im Bereich 0..%wi sein"
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE erfordert unbekannte ISA-Option"
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE erfordert ISA-Option %s"
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "das letzte Argument muss ein Immediate sein"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be scale 1, 2, 4, 8"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "letztes Argument muss Skalierung 1, 2, 4, 8 sein"
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be scale 1, 2, 4, 8"
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "letztes Argument muss Skalierung 1, 2, 4, 8 sein"
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "Falscher Befehl:"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "Das Argument für xabort muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Attribut %qE nur für 32 Bit verfügbar"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Argument des Attributes %qE ist weder Null noch Eins"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "Attribute ms_abi und sysv_abi sind nicht verträglich"
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibles Attribut wird ignoriert"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr "Unbekanntes architekturspezifisches Speichermodell«"
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE nicht mit ACQUIRE oder stärkerem Speichermodell verwendet"
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE nicht mit RELEASE oder stärkerem Speichermodell verwendet"
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported defining stmt"
 msgid "unsupported simdlen %d"
 msgstr "nicht unterstützte Definitionsanweisung"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "nicht unterstützter Argumenttyp für eingebaute Funktion"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -26181,13 +26218,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "Attribut %qE erfordert eine Zeichenkettenkonstante als Argument"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr "Wert von -mfixed-range muss die Form REG1-REG2 haben"
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -26259,7 +26296,7 @@
 msgstr "Attribut %qE wird für Ziel R8C nicht unterstützt"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, gcc-internal-format
 msgid "%qE attribute argument not an integer constant"
 msgstr "Attributargument %qE ist keine Ganzzahlkonstante"
@@ -26319,7 +26356,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread ist nur auf Fido verfügbar"
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "Ausdruck der Stapelgrenze wird nicht unterstützt"
@@ -27205,16 +27242,11 @@
 msgid "-g option disabled"
 msgstr "Option -g ausgeschaltet"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "Ausrichtung (%u) für %s überschreitet maximale Ausrichtung für globale gemeinsame Daten. Es wird %u verwendet"
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr "Option -munix=98 für Eigenschaften des C89 Amendment 1 erforderlich.\n"
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, fuzzy, gcc-internal-format
@@ -27481,324 +27513,330 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "Ziel-Attribut oder Pragma ändert Gleitkomma mit doppelter Genauigkeit"
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "Das ABI der Parameterübergabe mit %d-Byte-Ausrichtung hat sich in GCC 4.6 geändert"
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-Vektor per Referenz zurückgegeben: Nicht-Standard-ABI-Erweiterung ohne Kompatibilitätsgarantie"
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "Wert kann nicht in Vektorregister zurückgegeben werden, da AltiVec-Befehle ausgeschaltet sind; -maltivec schaltet sie ein"
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "Das ABI der Parameterübergabe mit %d-Byte-Ausrichtung hat sich in GCC 4.6 geändert"
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "Argument kann nicht in Vektorregister übergegeben werden, da AltiVec-Befehle ausgeschaltet sind; -maltivec schaltet sie ein"
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "Das ABI der Strukturübergabe mit komplexem Gleitkommaelement hat sich in GCC 4.4 geändert"
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-Vektor per Referenz übergegeben: Nicht-Standard-ABI-Erweiterung ohne Kompatibilitätsgarantie"
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "interner Fehler: Eingebaute Funktion %s bereits verarbeitet"
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "Argument 1 muss ein vorzeichenbehaftetes 5-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "Argument 1 muss ein vorzeichenbehaftetes 5-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 5-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "Argument 1 von __builtin_altivec_predicate muss eine Konstante sein"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "Argument 1 von __builtin_altivec_predicate ist außerhalb des Wertebereiches"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "%srtd%s is ignored in 64bit mode"
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr "%srtd%s wird im 64-Bit-Modus ignoriert"
+
+#: config/rs6000/rs6000.c:12763
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 5-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "Argument 1 von __builtin_spe_predicate ist außerhalb des Wertebereiches"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 4-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 2-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 1-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a map"
 msgid "argument 1 must be 0 or 2"
 msgstr "Argument 1 muss eine Abbildung sein"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 1-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 5-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "Zahl muss 0 oder 1 sein"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument 3 must be in the range 0..15"
 msgstr "Argument %d von %qE muss im Bereich %d...%d liegen"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "Argument für %qs muss ein vorzeichenloses 2-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "ungelöste Überladung des eingebauten Altivec %qF"
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "Argument für dss muss ein vorzeichenloses 2-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "Argument 1 von __builtin_paired_predicate muss eine Konstante sein"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "Argument 1 von __builtin_paired_predicate ist außerhalb des Wertebereiches"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "Argument 1 von __builtin_spe_predicate muss eine Konstante sein"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "Argument 1 von __builtin_spe_predicate ist außerhalb des Wertebereiches"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "Eingebaute Funktion %s ist nur für den Cell-Prozessor gültig"
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mvsx"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mvsx"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "Eingebaute Funktion %s erfordert die Option -maltivec"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mpaired"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mspe"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mpaired option"
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "Eingebaute Funktion %s erfordert die Option -mpaired"
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mpaired option"
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mpaired"
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mspe option"
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mspe"
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -maltivec option"
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "Eingebaute Funktion %s erfordert die Option -maltivec"
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mpaired option"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mpaired"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "Eingebaute Funktion %s wird mit den aktuellen Optionen nicht unterstützt"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had no type"
 msgstr "interner Fehler: eingebaute Funktion %s hatte keinen Typ"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "interner Fehler: eingebaute Funktion %s hatte unerwarteten Rückgabetyp %s"
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "interner Fehler: Eingebaute Funktion %s, Argument %d hatte unerwarteten Argumenttypen %s"
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "Stapelrahmen zu groß"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "kein Profiling von 64-bit-Code für dieses ABI"
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Bei Verwendung der Option -mno-pointers-to-nested-functions kann nicht die Adresse einer geschachtelten Funktion verwendet werden."
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "Verwendung von %<long double%> in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "Verwendung boolescher Typen in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "Verwendung von %<complex%> in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "Verwendung dezimaler Gleitkommatypen in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist für 64-Bit-Code ohne -mvsx ungültig"
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist veraltet; %<int%> verwenden"
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "Verwendung von %<long long%> in AltiVec-Typen ist ohne -mvsx ungültig"
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "Verwendung von %<double%> in AltiVec-Typen ist ohne -mvsx ungültig"
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "Ausgabe der Mikrocode-Anweisung %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "Ausgabe der bedingten Mikrocode-Anweisung %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "ungültige CPU »%s« für %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s\"%s\"%s ist nicht erlaubt"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s\"%s\"%s ist ungültig"
@@ -28049,90 +28087,90 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Gesamtgröße der lokalen Variablen übersteigt Grenze der Architektur"
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "Rahmengröße der Funktion %qs ist %wd Bytes, größer als benutzerdefinierte Stapelgrenze von %d Bytes. Eine unbedingte Falle wird gesetzt."
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "Rahmengröße der Funktion %qs ist %wd Bytes, mehr als die Hälfte der Stapelgröße. Dynamische Prüfung wäre nicht zuverlässig. Für diese Funktion wird keine Prüfung ausgegeben."
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "Rahmengröße von %qs ist %wd Bytes"
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs verwendet dynamische Stapelanforderung"
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "Argument von %qs sollte eine nicht-negative Ganzzahl sein"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "Argument für Attribut %qE ist größer als %d"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/Architektur-Modus nicht unterstützt auf %s"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-Bit-ABI nicht unterstützt im ESA/390-Modus"
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Dezimale Hardware-Gleitkomma-Befehle sind auf %s nicht verfügbar"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Dezimale Hardware-Gleitkomma-Befehle sind im ESA/390-Modus nicht verfügbar"
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp kann nicht in Verbindung mit -msoft-float verwendet werden"
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float werden in dieser Kombination nicht unterstützt"
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "Stapelgröße muss größer als der Stapel-Überwachungswert sein"
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "Stapelgröße darf nicht größer als 64k sein"
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard bringt -mstack-size mit sich"
@@ -28147,53 +28185,53 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr "Abwicklungstabellen erfordern derzeit entweder einen Rahmenzeiger oder -maccumulate-outgoing-args für Korrektheit"
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "__builtin_saveregs wird für dieses Teilziel nicht unterstützt"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, gcc-internal-format
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "Attribut %qE bezieht sich nur auf Interruptfunktionen"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, gcc-internal-format
 msgid "%qE attribute is supported only for SH2A"
 msgstr "Attribut %qE wird nur auf SH2A unterstützt"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr "Attribut interrupt_handler ist mit -m5-compact unverträglich"
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, gcc-internal-format
 msgid "%qE attribute only applies to SH2A"
 msgstr "Attribut %qE gilt nur für SH2A"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, gcc-internal-format
 msgid "%qE attribute argument should be between 0 to 255"
 msgstr "Argument des Attributs %qE sollte zwischen 0 und 255 sein"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, gcc-internal-format
 msgid "%qE attribute argument not a string constant"
 msgstr "Argument des Attributs %qE ist keine Zeichenkettenkonstante"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr "r0 muss als aufrufzerstörtes Register verfügbar sein"
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, gcc-internal-format
 msgid "need a second call-clobbered general purpose register"
 msgstr "ein zweites aufrufzerstörtes Mehrzweckregister wird benötigt"
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr "aufrufzerstörtes Zielregister erforderlich"
@@ -28571,44 +28609,44 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "ungültiger Elementtyp für Attribut %qs"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "Komponentenanzahl des Vektors ist keine Zweierpotenz"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "Attribut %qs wird ignoriert"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "Attribut %qs benötigt Prototypen mit benannten Argumenten"
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "Attribut %qs gilt nur für variadische Funktionen"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "Attribut %qE hat keinen Effekt"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "Attribut %qs bezieht sich nur auf Feldtypen"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
@@ -28672,7 +28710,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void-Wert nicht ignoriert wie es sein sollte"
@@ -28702,62 +28740,62 @@
 msgid "GCC supports only %u nested scopes"
 msgstr "GCC unterstützt nur %u geschachtelte Gültigkeitsbereiche"
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "Marke %q+D verwendet, aber nicht definiert"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "Geschachtelte Funktion %q+D deklariert, aber nirgendwo definiert"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr "Inline-Funktion %q+D deklariert, aber nirgendwo definiert"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "Variable %q+D wird nicht verwendet"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, gcc-internal-format
 msgid "variable %qD set but not used"
 msgstr "Variable %qD gesetzt, aber nicht verwendet"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "Typ des Feldes %q+D vervollständigt Unverträglichkeit mit impliziter Initialisierung"
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "ursprünglich hier definiert"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr "Eine Parameterliste mit Auslassung passt nicht zu einer leeren Parameternamenslistendeklaration"
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr "Ein Argumenttyp mit Standard-Promotion passt nicht zu leerer Parameternamenslistendeklaration"
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "Prototyp für %q+D deklariert mehr Argumente als vorherige Definition im alten Stil"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "Prototyp für %q+D deklariert weniger Argumente als vorherige Definition im alten Stil"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr "Prototyp für %q+D deklariert Argument %d mit inkompatiblem Typen"
@@ -28764,42 +28802,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "Prototyp für %q+D folgt einer Nicht-Prototyp-Definition"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "Vorherige Definition von %q+D war hier"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "Vorherige implizite Deklaration von %q+D war hier"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "Vorherige Deklaration von %q+D war hier"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "%q+D als andere Symbolart redeklariert"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "Eingebaute Funktion %q+D als Nicht-Funktion deklariert"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "Deklaration von %q+D überdeckt eine eingebaute Funktion"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "Redeklaration von Aufzählung %q+D"
@@ -28807,342 +28845,342 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "In Konflikt stehende Typen für eingebaute Funktion %q+D"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "In Konflikt stehende Typen für %q+D"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr "in Konflikt stehende benannte Adressräume (generisch und %s) für %q+D"
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr "in Konflikt stehende benannte Adressräume (%s und generisch) für %q+D"
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr "in Konflikt stehende benannte Adressräume (%s und %s) für %q+D"
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "In Konflikt stehende Typqualifizierer für %q+D"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
 msgstr "Redefinition des typedef %q+D mit anderem Typ"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "Redefinition des typedef %q+D mit variabel modifiziertem Typ"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "Redefinition des typedef %q+D"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "Redefinition von %q+D"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "Statische Deklaration von %q+D folgt nicht-statischer Deklaration"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "Nicht-statische Deklaration von %q+D folgt statischer Deklaration"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr "Attribut %<gnu_inline%> vorhanden bei %q+D"
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, gcc-internal-format
 msgid "but not here"
 msgstr "aber nicht hier"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "Thread-lokale Deklaration von %q+D folgt nicht-Thread-lokaler Deklaration"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "Nicht-Thread-lokale Deklaration von %q+D folgt Thread-lokaler Deklaration"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "extern-Deklaration von %q+D folgt Deklaration ohne Bindung"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "Deklaration von %q+D ohne Bindung folgt einer extern-Deklaration"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "Redeklaration von %q+D ohne Bindung"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr "Redeklaration von %q+D mit anderer Sichtbarkeit (alte Sichtbarkeit beibehalten)"
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "inline-Deklaration von %qD folgt Deklaration mit Attribut noinline"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "Deklaration von %q+D mit Attribut noinline folgt inline-Deklaration "
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "Deklaration von %q+D mit Attribut noinline folgt inline-Deklaration "
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "Redefinition des Parameters %q+D"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "Redundante Redeklaration von %q+D"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "Deklaration von %q+D überdeckt eine vorhergehende Nicht-Variable"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr "Deklaration von %q+D überdeckt einen Parameter"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "Deklaration von %qD überdeckt eine globale Deklaration"
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "Deklaration von %q+D überdeckt einen vorhergehenden lokalen Bezeichner"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "verdeckte Deklaration ist hier"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "Geschachtelte extern-Deklaration von %qD"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "Implizite Deklaration der Funktion %qE"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "Unverträgliche implizite Deklaration der eingebauten Funktion %qD"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "ungültige Redeklaration von %q+D"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "Unverträgliche implizite Deklaration der Funktion %qD"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE ist hier nicht deklariert (nicht in einer Funktion)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE nicht deklariert (erste Benutzung in dieser Funktion)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "jeder nicht deklarierte Bezeichner wird nur einmal für jede Funktion, in der er vorkommt, gemeldet"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "Marke %qE außerhalb einer Funktion referenziert"
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "in Gültigkeitsbereich des Bezeichners mit variabel modifiziertem Typen springen"
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "Sprung lässt Variableninitialisierung aus"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "Marke %qD hier definiert"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD hier deklariert"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "Sprung in Anweisungs-Ausdruck"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "Doppelte Markendeklaration %qE"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "doppelte Marke %qD"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "traditionelles C bietet keinen separaten Namensraum für Marken an, Bezeichner %qE steht in Konflikt"
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "switch springt über Variableninitialisierung"
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "switch beginnt hier"
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "switch springt in Anweisungs-Ausdruck"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE als falsche Symbolart definiert"
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "Unbenannte struct/union, die keine Instanzen definiert"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "Leere Deklaration mit Speicherklassenangabe redeklariert nicht Symbol"
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "Leere Deklaration mit Typqualifizierer redeklariert nicht Symbol"
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "Leere Deklaration mit %<_Alignas%> redeklariert nicht Symbol"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "Nutzloser Typname in leerer Deklaration"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> in leerer Deklaration"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<_Noreturn%> in leerer Deklaration"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> in leerer Deklaration im Datei-Gültigkeitsbereich"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> in leerer Deklaration im Datei-Gültigkeitsbereich"
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "Nutzlose Speicherklassenangabe in leerer Deklaration"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "useless %<_Alignas%> in empty declaration"
 msgid "useless %qs in empty declaration"
 msgstr "nutzloses %<_Alignas%> in leerer Deklaration"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "Nutzloser Typqualifizierer in leerer Deklaration"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "nutzloses %<_Alignas%> in leerer Deklaration"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "Leere Deklaration"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO-C90 unterstützt kein %<static%> oder Typkennzeichner in Parameterfelddeklaratoren"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO-C90 unterstützt nicht %<[*]%>-Felddeklaratoren"
@@ -29150,38 +29188,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> außerhalb des Bereichs des Funktionsprototypen nicht erlaubt"
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D ist üblicherweise eine Funktion"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "typedef %qD ist initialisiert (stattdessen lieber __typeof__ verwenden)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "Funktion %qD ist wie eine Variable initialisiert"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "Parameter %qD ist initialisiert"
@@ -29190,257 +29228,257 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "Objekt variabler Größe darf nicht initialisiert werden"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "Variable %qD hat Initialisierung, aber unvollständigen Typ"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "inline-Funktion %q+D wurde das Attribut »noinline« gegeben"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "nicht initialisiertes konstantes Element %qT ist in C++ ungültig"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD sollte initialisiert werden"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "Initialisierung gibt nicht die Größe von %q+D an"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "Feldgröße fehlt in %q+D"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "Feldgröße von %q+D ist null oder negativ"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "Speichergröße von %q+D ist nicht konstant"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "asm-Symbol für nicht-statische lokale Variable %q+D wird ignoriert"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "Objekt mit volatile-Feld kann nicht in Register geladen werden"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, gcc-internal-format
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "nicht initialisiertes const %qD ist in C++ ungültig"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO-C verbietet Vorwärtsdeklaration für Parameter"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "Definition eines Typs in einem zusammengesetzten Literal ist in C++ ungültig"
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "Breite des Bitfeldes %qs ist keine Ganzzahlkonstante"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "Breite des Bitfeldes %qs ist kein Ganzzahlkonstantenausdruck"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "Negative Breite in Bitfeld %qs"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "Breite Null für Bitfeld %qs"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "Bitfeld %qs hat ungültigen Typen"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "Typ des Bitfeldes %qs ist eine Erweiterung des GCC"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "Breite von %qs überschreitet dessen Typen"
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs ist schmaler als die Werte seines Typs"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO-C90 verbietet Feld %qE, dessen Größe nicht ausgewertet werden kann"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO-C90 verbietet Feld, dessen Größe nicht ausgewertet werden kann"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO-C90 verbietet Feld %qE variabler Größe"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO-C90 verbietet Feld variabler Größe"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "variabel modifiziertes %qE im Dateibereich"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "variabel modifiziertes Feld im Dateibereich"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "%<int%> ist Standardtyp in Deklaration von %qE"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "%<int%> ist Standardtyp in Typ-Deklaration"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "doppeltes %<const%>"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "doppeltes %<restrict%>"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "doppeltes %<volatile%>"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "doppeltes %<_Atomic%>"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "in Konflikt stehende benannte Adressräume (%s und %s)"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "Funktionsdefinition deklarierte %<auto%>"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "Funktionsdefinition deklarierte %<register%>"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "Funktionsdefinition deklarierte %<typedef%>"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "Funktionsdefinition deklarierte %qs"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "Speicherklasse für Strukturfeld %qE angegeben"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "Speicherklasse für Strukturfeld angegeben"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "Speicherklasse für Parameter %qE angegeben"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "Speicherklasse für unbenannten Parameter angegeben"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "Speicherklasse für Typnamen angegeben"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE initialisiert und als %<extern%> deklariert"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE hat sowohl %<extern%> als auch Initialisierung"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "Deklaration von %qE in Datei-Sichtbarkeitsbereich spezifiziert %<auto%>"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "Deklaration von %qE in Datei-Sichtbarkeitsbereich spezifiziert %<register%>"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "geschachtelte Funktion %qE als %<extern%> deklariert"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope %qE implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -29449,684 +29487,684 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "»static« oder Typkennzeichner in Nicht-Parameter-Felddeklarator"
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "Deklaration von %qE als Feld von voids"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "Deklaration eines Typnamen als Feld von voids"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "Deklaration von %qE als Feld von Funktionen"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "Deklaration eines Typnamen als Feld von Funktionen"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ungültige Verwendung einer Struktur mit flexiblem Feldelement"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "Feldgröße von %qE hat Nicht-Ganzzahltyp"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "Feldgröße eines unbenannten Feldes hat Nicht-Ganzzahltyp"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO-C verbietet Feld %qE der Größe null"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO-C verbietet Feld der Größe null"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "Größe des Feldes %qE ist negativ"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "Größe des unbenannten Feldes ist negativ"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "Feldgröße von %qE ist zu groß"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "Größe des unbenannten Feldes ist zu groß"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO-C90 unterstützt keine flexiblen Felder als Elemente"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> nicht in einer Deklaration"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "Feldtyp hat unvollständigen Elementtypen %qT"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE als Funktion, die eine Funktion zurückgibt, deklariert"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "Typname als Funktion, die eine Funktion zurückgibt, deklariert"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE als Funktion, die ein Feld zurückgibt, deklariert"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "Typname als Funktion, die ein Feld zurückgibt, deklariert"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "Funktionsdefinition hat qualifizierten void-Rückgabetypen"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "Typkennzeichner an Funktions-Rückgabewert ignoriert"
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "%<_Atomic%>-qualifizierter Funktionstyp"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO-C verbietet qualifizierte Funktionstypen"
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs mit Qualifizierer %<auto%> für %qE kombiniert"
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs mit Qualifizierer %<register%> für %qE kombiniert"
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs für »auto«-Variable %qE angegeben"
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs für Parameter %qE angegeben"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs für unbenannten Parameter angegeben"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs für Strukturfeld %qE angegeben"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs für Strukturfeld angegeben"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "Bitfeld %qE hat atomaren Typen"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "Bitfeld hat atomaren Typen"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "Ausrichtung für typedef %qE angegeben"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "Ausrichtung für %<register%>-Objekt %qE angegeben"
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "Ausrichtung für Parameter %qE angegeben"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "Ausrichtung für unbenannten Parameter angegeben"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "Ausrichtung für Bitfeld %qE angegeben"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "Ausrichtung für unbenanntes Bitfeld angegeben"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "Ausrichtung für Funktion %qE angegeben"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "%<_Alignas%>-Spezifizierer können nicht die Ausrichtung von %qE reduzieren"
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "%<_Alignas%>-Spezifizierer können nicht die Ausrichtung eines unbenannten Feldes reduzieren"
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D als %<inline%> deklariert"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D als %<_Noreturn%> deklariert"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO-C verbietet const- oder volatile-Funktionstypen"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "Ein Element einer Struktur oder Union kann nicht variabel modifizierten Typ haben"
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "Variable oder Feld %qE als »void« deklariert"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "Attribute in Parameterfelddeklarator ignoriert"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "Parameter %q+D als %<inline%> deklariert"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "Parameter %q+D als %<_Noreturn%> deklariert"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "Feld %qE als Funktion deklariert"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "Feld %qE hat unvollständigen Typen"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "unbenanntes Feld hat unvollständigen Typen"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "ungültige Speicherklasse für Funktion %qE"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "%<main%> ist nicht als »inline« möglich"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> als %<_Noreturn%> deklariert"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO-C99 unterstützt nicht %<_Noreturn%>"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO-C90 unterstützt nicht %<_Noreturn%>"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "als %<extern%> redeklarierte Variable war bereits als %<static%> deklariert"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "Variable %q+D als %<inline%> deklariert"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "Variable %q+D als %<_Noreturn%> deklariert"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "nicht geschachtelte Funktion mit variabel modifiziertem Typen"
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "Objekt mit variabel geändertem Typ darf keine Bindung haben"
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "Funktionsdeklaration ist kein Prototyp"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "Parameternamen (ohne Typen) in Funktionsdeklaration"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "Parameter %u (%q+D) hat unvollständigen Typen"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "Parameter %u hat unvollständigen Typen"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "Parameter %u (%q+D) hat void-Typen"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "Parameter %u hat void-Typen"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> kann nicht als einzelner Parameter qualifiziert werden"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> muss der einzige Parameter sein"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "Parameter %q+D hat nur eine Vorwärtsdeklaration"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "%<%s %E%> innerhalb Parameterliste deklariert"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "anonymes %s innerhalb Parameterliste deklariert"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "sein Gültigkeitsbereich umfasst nur diese Definition bzw. Deklaration, was Sie wahrscheinlich nicht wollten"
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "»enum«-Typ hier definiert"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "»struct« wurde hier definiert"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "»union« wurde hier definiert"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "Redefinition von %<union %E%>"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "Redefinition von %<struct %E%>"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "Verschachtelte Redefinition von %<union %E%>"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "Verschachtelte Redefinition von %<struct %E%>"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "Typdefinition in Ausdruck %qs ist in C++ ungültig"
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "Deklaration deklariert nichts"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO-C99 unterstützt keine namenlosen structs/unions"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO-C90 unterstützt keine namenlosen structs/unions"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "doppeltes Element %q+D"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "Union hat keine benannten Elemente"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "Union hat keine Elemente"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct hat keine benannten Elemente"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct hat keine Elemente"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibles Feldelement in Union"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "flexibles Feld-Element nicht am Ende von struct"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr "flexibles Feld-Element in ansonsten leerem struct"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "type %qT is too large"
 msgstr "%s ist zu groß"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union kann nicht transparent gemacht werden"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "Verschachtelte Redefinition von %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "Redeklaration von %<enum %E%>"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "Aufzählungswerte überschreiten Wertebereich des größten Ganzzahltypen"
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "angegebener Modus zu klein für Aufzählungswerte"
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "Aufzählungswert für %qE ist keine Ganzzahlkonstante"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "Aufzählungswert für %qE ist kein Ganzzahlkonstantenausdruck"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "Überlauf in Aufzählungswerten"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO-C beschränkt Aufzählungswerte auf Bereich von %<int%>"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "inline-Funktion %qD wurde das Attribut »noinline« gegeben"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "Rückgabetyp ist unvollständig"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "Rückgabetyp ist auf %<int%> voreingestellt"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "kein vorheriger Prototyp für %qD"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD wurde vor seiner Definition ohne Prototyp verwendet"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "keine vorherige Deklaration für %qD"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD wurde vor seiner Definition ohne Deklaration verwendet"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "Rückgabetyp von %qD ist nicht %<int%>"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD ist normalerweise eine nicht-statische Funktion"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "Parameterdeklarationen alten Stils in Prototyp-Funktionsdeklaration"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "traditionelles C weist Funktionsdefinitionen im ISO-C-Stil zurück"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "Parametername ausgelassen"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "Funktionsdefinition im alten Stil"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "Parametername fehlt in Parameterliste"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD als Nicht-Parameter deklariert"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "mehrere Parameter wurden %qD genannt"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "Parameter %qD als void deklariert"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "Typ von %qD ist auf %<int%> voreingestellt"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "Parameter %qD hat unvollständigen Typen"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "Deklaration für nicht vorhandenen Parameter %qD"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "Anzahl der Argumente passt nicht zum eingebauten Prototypen"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "Anzahl der Argumente passt nicht zum Prototypen"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "Prototyp-Deklaration"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "weitergegebenes Argument %qD passt nicht zu eingebautem Prototypen"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "weitergegebenes Argument %qD passt nicht zum Prototypen"
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "Argument %qD passt nicht zu eingebautem Prototypen"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "Argument %qD passt nicht zum Prototypen"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "keine return-Anweisung in nicht void zurückgebender Funktion"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "Parameter %qD gesetzt, jedoch nicht verwendet"
@@ -30134,206 +30172,206 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "Anfangsdeklarationen in %<for%>-Schleifen sind nur im C99-Modus erlaubt"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99 or -std=gnu99 to compile your code"
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "-std=c99 oder -std=gnu99 verwenden, um den Code zu übersetzen"
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der »static«-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der %<extern%>-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der Nicht-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "Inkompatible Adressraumkennzeichen %s und %s"
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "doppeltes %qE"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "zwei oder mehr Datentypen in Deklaration"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> ist für GCC zu lang"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO-C90 unterstützt nicht %<long long%>"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO-C90 unterstützt keine komplexen Typen"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO-C unterstützt keine sättigenden Typen"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int128%> type"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO-C unterstützt nicht den Typen %<__int128%>"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported for this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "<__int128%> wird für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO-C90 unterstützt keine komplexen Typen"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO-C unterstützt kein dezimales Gleitkomma"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "Festkommatypen werden für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO-C unterstützt keine Ganzzahltypen"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "Nachschlagen von %qD würde in C++ ein Feld, keinen Typen zurückgeben"
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE ist kein typedef oder eingebauter Typ"
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE ist nicht am Anfang einer Deklaration"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> mit %<auto%> verwendet"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> mit %<register%> verwendet"
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> mit %<typedef%> verwendet"
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO-C99 unterstützt nicht %qE"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO-C90 unterstützt nicht %qE"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> vor %<extern%>"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> vor %<static%>"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "mehrere Speicherklassen in Deklaration"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs used with %qE"
 msgstr "%qs muss mit %qs verwendet werden"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> ohne %<_Fract%> oder %<_Accum%> verwendet"
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO-C unterstützt nicht %<double complex%> bedeutendes einfaches %<complex%>"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO-C unterstützt keine komplexen Ganzzahltypen"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -30343,7 +30381,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr "Bezeichner %qE steht mit C++-Schlüsselwort in Konflikt"
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "Zeilenende erwartet"
@@ -30363,8 +30401,8 @@
 msgid "unknown type name %qE"
 msgstr "unbekannter Typname: %qE"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "Deklarationsspezifizierer erwartet"
@@ -30380,7 +30418,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, Bezeichner oder %<(%> erwartet"
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "Präfixattribute werden für Methoden ignoriert"
@@ -30460,7 +30498,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO-C90 unterstützt nicht %<_Static_assert%>"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "Zeichenkettenliteral erwartet"
@@ -30520,14 +30558,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "Bezeichner erwartet"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "Komma am Ende der Aufzählungsliste"
@@ -30990,32 +31028,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr "hier darf kein Typ oder Speicherklasse angegeben werden,"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "unbekanntes Eigenschaftsattribut"
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "fehlendes %<=%> (hinter Attribut %<getter%>)"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "fehlendes %<=%> (hinter Attribut %<setter%>)"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "das %<setter%>-Attribut darf nur einmal angegeben werden"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "Setter-Name muss mit %<:%> beendet werden"
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "das %<getter%>-Attribut darf nur einmal angegeben werden"
@@ -31026,49 +31064,49 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr "%<#pragma omp taskyield%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr "%<#pragma omp taskyield%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> darf nur in %<#pragma omp sections%>-Konstrukt verwendet werden"
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- oder do-Anweidung erwartet"
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> muss zuerst kommen"
@@ -31083,12 +31121,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "%<#pragma grainsize%> muss innerhalb einer Funktion sein"
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "zu viele %qs-Klauseln"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "Ganzzahlausdruck vor »)« erwartet"
@@ -31098,27 +31136,27 @@
 msgid "expression must be integral"
 msgstr "Ausdruck muss ganzzahlig sein"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, gcc-internal-format
 msgid "%qD is not a constant"
 msgstr "%qD ist nicht konstant"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD ist keine Variable"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD ist keine Zeigervariable"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "Collapse-Argument erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> oder %<shared%> erwartet"
@@ -31152,17 +31190,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> oder %<max%> erwartet"
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<runtime%> akzeptiert keinen Parameter %<chunk_size%>"
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<auto%> akzeptiert keinen Parameter %<chunk_size%>"
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ungültige Ablaufart"
@@ -31185,13 +31223,13 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr "Wert von %<num_threads%> muss positiv sein"
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "Collapse-Argument erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "using parameters for %<linear%> step is not supported yet"
@@ -31215,19 +31253,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "Collapse-Argument erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "ungültige Ablaufart"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "ungültige Maske"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -31239,61 +31277,61 @@
 msgid "invalid proc_bind kind"
 msgstr "ungültige Ablaufart"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "Klausel %<#pragma omp%> erwartet"
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs ist für %qs ungültig"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs muss mit %qs verwendet werden"
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "Klausel %<#pragma omp%> erwartet"
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr "hinter %<#pragma message%> wird eine Zeichenkette erwartet"
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid pragma"
 msgstr "ungültiges #pragma %s"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ungültige Form von %<#pragma omp atomic%>"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ungültiger Operator für %<#pragma omp atomic%>"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
@@ -31304,18 +31342,18 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> oder Zeilenende erwartet"
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "für Anweisung erwartet"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "_Cilk_for statement expected"
 msgstr "für Anweisung erwartet"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "Schleifendeklaration oder Initialisierung erwartet"
@@ -31325,259 +31363,260 @@
 msgid "not enough perfectly nested loops"
 msgstr "nicht genügend perfekt geschachtelte Schleifen"
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "zusammengelegte Schleifen sind nicht perfekt geschachtelt"
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "Schleifenvariable %qD sollte nicht »firstprivate« sein"
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<operator%> erwartet"
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<using%>"
 msgid "expected %<point%>"
 msgstr "%<using%> erwartet"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:13854 cp/parser.c:31398
-#, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
-msgstr ""
+#: c/c-parser.c:13851 cp/parser.c:31433
+#, fuzzy, gcc-internal-format
+#| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
+msgstr "%<#pragma omp taskwait%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> muss vor der Deklaration von %D auftreten, ignoriert"
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<try%>"
 msgid "expected %<target%>"
 msgstr "%<try%> erwartet"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "%<decltype%> erwartet"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma GCC pop_options%> ohne zugehöriges %<#pragma GCC push_options%>"
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, fuzzy, gcc-internal-format
 #| msgid "a template declaration cannot appear at block scope"
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "eine Template-Deklaration kann nicht im Block-Gültigkeitsbereich auftreten"
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> oder %<max%> erwartet"
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration"
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "vorherige Deklaration"
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<omp_priv%> or function-name"
 msgstr "%<(%> oder Zeilenende erwartet"
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 #| msgid "expected function"
 msgid "expected function-name %<(%>"
 msgstr "Funktion erwartet"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<#pragma omp section%> oder %<}%> erwartet"
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE nach erster Benutzung als %<threadprivate%> deklariert"
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatische Variable %qE kann nicht %<threadprivate%> sein"
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE hat unvollständigen Typen"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC optimize ist nicht innerhalb von Funktionen erlaubt"
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "vectorlength must be an integer constant"
 msgstr "Selektor eine Ganzzahlkonstante im Bereich 0..%wi sein"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "Stapelgröße muss eine exakte Zweierpotenz sein"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "Selektor eine Ganzzahlkonstante im Bereich 0..%wi sein"
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma simd%> clause"
 msgstr "Klausel %<#pragma omp%> erwartet"
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma%> ist hier nicht erlaubt"
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> ohne eingeschaltete Unterstützung für transaktionsbasierten Speicher"
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> innerhalb eines %<__transaction_relaxed%>"
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "äußeres %<__transaction_cancel%> nicht innerhalb des äußeren %<__transaction_atomic%>"
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  oder einer %<transaction_may_cancel_outer%>-Funktion"
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> nicht innerhalb von %<__transaction_atomic%>"
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "base of array section must be pointer or array type"
 msgstr "Größe des Feldes bei »new« muss Ganzzahltyp haben"
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<:%> or numeral"
 msgstr "%<:%> oder %<::%> erwartet"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "array notations cannot be used with function type"
 msgstr "»new« kann nicht auf Funktionstyp angewendet werden"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 #| msgid "expected boolean expression"
 msgid "expected array notation expression"
@@ -31588,7 +31627,7 @@
 msgid "%qD has an incomplete type"
 msgstr "%qD hat unvollständigen Typ"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "falsche Benutzung eines void-Ausdruckes"
@@ -31697,7 +31736,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indizierter Wert ist weder Feld noch Zeiger noch Vektor"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "Feldindex ist keine Ganzzahl"
@@ -31820,7 +31859,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "Übergabe des Arguments %d von %qE als vorzeichenbehaftet aufgrund des Prototyps"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "implizite Umwandlung von %qT in %qT bei Übergabe von Argument an Funktion"
@@ -31850,7 +31889,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "Arithmetik mit Zeiger auf unvollständigen Typen"
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -31938,7 +31977,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "Nicht-L-Wert-Feld in bedingtem Ausdruck"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "implizite Umwandlung von %qT in %qT um an anderes Ergebnis von Bedingung anzupassen"
@@ -31974,7 +32013,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "Zeiger-/Ganzzahltyp passt nicht in bedingtem Ausdruck"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, fuzzy, gcc-internal-format
 #| msgid "a function call cannot appear in a constant-expression"
 msgid "spawned function call cannot be part of a comma expression"
@@ -32061,7 +32100,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "Typumwandlung von Funktionsaufruf des Typs %qT in unpassenden Typen %qT"
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "Typkonvertierung in Zeiger von Ganzzahl anderer Breite"
@@ -32215,7 +32254,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "Linke-Initialisierung könnte Kandidat für Formatattribut sein"
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "Rückgabetyp könnte Kandidat für Formatattribut sein"
@@ -32352,7 +32391,7 @@
 msgid "initialization of a flexible array member"
 msgstr "Initialisierung eines flexiblen Feld-Elements"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-Feld mit wide-Zeichenkette initialisiert"
@@ -32398,7 +32437,7 @@
 msgid "invalid initializer"
 msgstr "ungültige Initialisierung"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opake Vektortypen können nicht initialisiert werden"
@@ -32543,7 +32582,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO-C verbietet %<goto *expr;%>"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> deklarierte Funktion hat %<return%>-Anweisung"
@@ -32554,7 +32593,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "Ausdruck kann nicht als Funktion verwendet werden"
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
@@ -32664,17 +32703,17 @@
 msgid "expression statement has incomplete type"
 msgstr "Ausdrucksanweisung hat unvollständigen Typ"
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "Vergleich von Vektoren mit verschiedenen Element-Typen"
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "Vergleich von Vektoren mit unterschiedlicher Elementanzahl"
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "Vergleich von Gleitkomma mit == oder != ist unsicher"
@@ -32725,12 +32764,12 @@
 msgstr "geordneter Vergleich von Zeiger mit Null-Zeiger"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "geordneter Vergleich von Zeiger mit Ganzzahlnull"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "implizite Umwandlung von %qT in %qT zur Anpassung an anderen Operanden des Binärausdrucks"
@@ -32755,93 +32794,93 @@
 msgid "used vector type where scalar is required"
 msgstr "Vektortyp verwendet, wo Skalars benötigt wird"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD ist in Klausel %qs keine Variable"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE ist in Klausel %qs keine Variable"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD ist in Klausel %qs keine Variable"
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "Größe des Feldes bei »new« muss Ganzzahltyp haben"
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "Größe des Feldes bei »new« muss Ganzzahltyp haben"
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "Feld variabler Größe wird verwendet"
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, fuzzy, gcc-internal-format
 #| msgid "for increment expression has no effect"
 msgid "for pointer type length expression must be specified"
 msgstr "Erhöhungsausdruck hat keinen Effekt"
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Feldabschnitte bei Prozedureintritt in einen zusammenhängenden Block kopieren"
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qE does not have pointer or array type"
@@ -32852,17 +32891,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE hat ungültigen Typ für %<reduction(%s)%>"
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE muss für %<copyin%> %<threadprivate%> sein"
@@ -32872,7 +32911,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE ist in Klausel %qs keine Variable"
@@ -32882,17 +32921,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE tritt in dieser Datenklausel mehrfach auf"
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE ist in Klausel %<firstprivate%> keine Variable"
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE ist in Klausel %<lastprivate%> keine Variable"
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -32910,54 +32949,54 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE tritt in dieser Datenklausel mehrfach auf"
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE ist in Klausel %qs keine Variable"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, fuzzy, gcc-internal-format
 #| msgid "Array section not permitted in '%s' call at %L"
 msgid "array section does not have mappable type in %qs clause"
 msgstr "Feldabschnitt bei »%s«-Aufruf bei %L nicht erlaubt"
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD ist in Klausel %qs keine Variable"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD tritt in Datenklausel mehrfach auf"
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD tritt in Datenklausel mehrfach auf"
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD ist in Klausel %qs keine Variable"
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE ist in Klausel %qs keine Variable"
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE ist vorbestimmt %qs für %qs"
@@ -32968,33 +33007,33 @@
 msgstr "C++ erfordert weitergegebenen Typ, nicht Enum-Typ, in %<va_arg%>"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "  Die Übergabe von %qT als %<this%>-Argument streicht Qualifizierer"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr "  keine bekannte Umwandlung für impliziten %<this%>-Parameter von %qT nach %qT"
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "  Umwandlung von Argument %d wäre unzulässig:"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, gcc-internal-format
 msgid "  no known conversion from %qT to %qT"
 msgstr "  keine bekannte Umwandlung von %qT nach %qT"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, gcc-internal-format
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "  keine bekannte Umwandlung für Argument %d von %qT nach %qT"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -33001,83 +33040,83 @@
 msgstr[0] "  Kandidat erwartet %d Argument, %d angegeben"
 msgstr[1] "  Kandidat erwartet %d Argumente, %d angegeben"
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, gcc-internal-format
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr "%s%D(%T, %T, %T) <eingebaut>"
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, gcc-internal-format
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "%s%D(%T, %T) <eingebaut>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, gcc-internal-format
 msgid "%s%D(%T) <built-in>"
 msgstr "%s%D(%T) <eingebaut>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, gcc-internal-format
 msgid "%s%T <conversion>"
 msgstr "%s%T <Umformung>"
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr "%s%#D <nahe Übereinstimmung>"
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr "%s%#D <gelöscht>"
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr "%s%#D"
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr " Rückgabetyp %qT der expliziten Umwandlungsfunktion kann nicht mit Qualifizierungsänderung in %qT umgewandelt werden"
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr " Umwandlung von Rückgabetyp %qT der Spezialisierung der Template-Umwandlungsfunktion in %qT passt nicht exakt"
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr " Ersetzung der ermittelten Templateargumente führte zu obigen Fehlern"
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "  Herleitung/Ersetzung von Templateargument gescheitert:"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr " Ein Konstruktor, der ein einzelnes Argument seines eigenen Klassentyps hat, ist ungültig"
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "Umformung von %qT in %qT ist nicht eindeutig"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, gcc-internal-format
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr "Umwandlung von %qT in %qT für Nicht-Typ-Templateargument nicht betrachtet"
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "keine passende Funktion für Aufruf von %<%D(%A)%>"
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "Aufruf des überladenen %<%D(%A)%> ist nicht eindeutig"
@@ -33084,467 +33123,467 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr "Zeiger auf Elementfunktion %E kann nicht ohne Objekt aufgerufen werden; Beispiele: .* oder ->*"
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "keine Übereinstimmung für Aufruf von %<(%T) (%A)%>"
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "Aufruf von %<(%T) (%A)%> ist nicht eindeutig"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "mehrdeutiges Überladen für "
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, gcc-internal-format
 msgid "no match for "
 msgstr "keine Übereinstimmung für "
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (Operandentypen sind %qT, %qT und %qT)"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (Operandentypen sind %qT und %qT)"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (Operandentyp ist %qT)"
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "ternärer %<operator?:%>"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "ternärer %<operator?:%> in %<%E ? %E : %E%>"
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> in %<%E%s%>"
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> in %<%E[%E]%>"
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs in %<%s %E%>"
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> in %<%E %s %E%>"
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> in %<%s%E%>"
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO-C++ verbietet das Auslassen des mittleren Terms eines »?:«-Ausdruckes"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "unverträgliche Vektortypen in bedingtem Ausdruck: %qT, %qT und %qT"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "zweiter Operand für Bedingungsoperator ist vom Typ %<void%>, aber der dritte Operand ist weder ein Throw-Ausdruck noch vom Typ %<void%>"
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "dritter Operand für Bedingungsoperator ist vom Typ %<void%>, aber der zweite Operand ist weder ein Throw-Ausdruck noch vom Typ %<void%>"
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "Operanden für ?: haben verschiedene Typen: %qT und %qT"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "Aufzählungsfehler in bedingtem Ausdruck: %qT vs. %qT"
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "Aufzählungs- und Nicht-Aufzählungstyp in bedingtem Ausdruck"
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "kein %<%D(int)%> für Suffix %qs deklariert, stattdessen wird Präfixoperator versucht"
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "kein %<%D(int)%> für Suffix %qs deklariert"
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "Vergleich zwischen %q#T und %q#T"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, gcc-internal-format
 msgid "non-placement deallocation function %q+D"
 msgstr "nicht-platzierende Freigabefunktion %q+D"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr "für Platzierungs-Löschen ausgewählt"
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "keine passende Freigabefunktion für %qD"
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "kein geeignetes %<operator %s%> für %qT"
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr "%q+#D ist privat"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr "%q+#D ist geschützt"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr "%q+#D ist unzugänglich"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr "in diesem Zusammenhang"
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "Übergabe von NULL an Nicht-Zeiger-Argument %P von %qD"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "Konvertierung in Nicht-Zeiger-Typ %qT von NULL"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "%<false%> wird für Argument %P von %qD in Zeigertyp umgewandelt"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "%<false%> wird in Zeigertyp %qT umgewandelt"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "zu viele geschweifte Klammern um Initialisierung für %qT"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr "%qT kann nicht nach %qT in Initialisierung umgewandelt werden"
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, gcc-internal-format
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "ungültige benutzerdefinierte Umwandlung von %qT in %qT"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  Argument %P von %qD wird initialisiert"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "ungültige Umwandlung von %qT in %qT"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "Umwandlung in %qT von Initialisierungsliste würde expliziten Konstruktor %qD verwenden"
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, gcc-internal-format
 msgid "  initializing argument %P of %q+D"
 msgstr "  Argument %P von %q+D wird initialisiert"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, gcc-internal-format
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "L-Wert %qT kann nicht mit %qT verbunden werden"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "ungültige Initialisierung einer nicht-konstanten Referenz des Typs %qT von R-Wert des Typs %qT"
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "Die Übergabe von %qT als %<this%>-Argument von %q#D streicht Qualifizierer"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "das Bitfeld %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "das gepackte Feld %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "der R-Wert %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-trivially-copyable type %q#T through %<...%>"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "Objekte des nicht trivial kopierbaren Typs %q#T können nicht über %<...%> übergeben werden"
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "Objekte des nicht trivial kopierbaren Typs %q#T können nicht über %<...%> empfangen werden; "
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "Objekte des nicht trivial kopierbaren Typs %q#T können nicht über %<...%> empfangen werden; "
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "rekursive Auswertung des Standardarguments für %q#D"
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "Aufruf von %qD verwendet das Standardargument für Parameter %P, der noch nicht definiert wurde"
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "Argument des Funktionsaufrufs könnte Kandidat für Formatattribut sein"
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "Verwendung einer multiversionierten Funktion ohne Standardargument"
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "Die Übergabe von %qT als %<this%>-Argument von %q#D streicht Qualifizierer"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  in Aufruf von %qD"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT ist keine erreichbare Basis von %qT"
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "%qT ermittelt als %qT"
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, gcc-internal-format
 msgid "  in call to %q+D"
 msgstr "  in Aufruf von %q+D"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (dies kann mit -fno-deduce-init-list abgeschaltet werden)"
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr "class$-Feld konnte nicht im Java-Schnittstellentyp %qT gefunden werden"
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, fuzzy, gcc-internal-format
 #| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "Konstante verweist auf sich selbst"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "Aufruf der Nicht-Funktion %qD"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "Konstruktor %<%T::%D%> kann nicht direkt aufgerufen werden"
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, fuzzy, gcc-internal-format
 #| msgid "  for a function-style cast, remove the redundant %<::%D%>"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  für Umwandlung im Funktions-Stil muss das überflüssige %<::%D%> entfernt werden"
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "keine passende Funktion für Aufruf von %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr "keine passende Funktion für Aufruf von %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "keine passende Funktion für Aufruf von %<%D(%A)%>"
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "Aufruf des überladenen %<%s(%A)%> ist mehrdeutig"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "Initialisierung nicht-statischer Datenelemente"
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "Elementfunktion %qD kann nicht ohne Objekt aufgerufen werden"
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "Übergabe von %qT wählt %qT statt %qT"
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "Wahl von %qD statt %qD"
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  für Umwandlung von %qT in %qT"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  denn die Umwandlungsfolge für das Argument ist besser"
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "Zuordnungsfehler der Standardargumente in Überladungsauflösung"
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr " Kandidat 1: %q+#F"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr " Kandidat 2: %q+#F"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ besagt, dass diese mehrdeutig sind, auch wenn die schlechteste Umwandlung für das erste besser ist als die schlechteste Umwandlung für das zweite:"
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "%qE konnte nicht von %qT nach %qT umgewandelt werden"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "eine vorübergehende Bindung an %qD besteht nur, bis der Konstruktor beendet ist"
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "ungültige Initialisierung einer Referenz des Typs %qT von Ausdruck des Typs %qT"
@@ -33711,7 +33750,7 @@
 msgid "  by %q+D"
 msgstr "  von %q+D"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D ungültig; eine anonyme Union kann nur nicht-statische Datenelemente haben"
@@ -33721,7 +33760,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D ungültig; eine anonyme struct kann nur nicht-statische Datenelemente haben"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr "privates Element %q+#D in anonymer Union"
@@ -33731,7 +33770,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "privates Element %q+#D in anonymer struct"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr "geschütztes Element %q+#D in anonymer Union"
@@ -33865,69 +33904,80 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  aber überschreibt nicht %<operator=(const %T&)%>"
 
-#: cp/class.c:4538
+#: cp/class.c:4300
 #, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, fuzzy, gcc-internal-format
+#| msgid "alignment of %qD is bigger than original declaration"
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr "Ausrichtung von %qD ist größer als ursprüngliche Deklaration"
+
+#: cp/class.c:4557
+#, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "Initialisierung für nicht-virtuelle Methode %q+D angegeben"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "Methode überschreibt Methoden %<transaction_pure%> und %qE"
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "als %qE deklarierte Methode überschreibt Methode %qE"
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "umschließende Klasse der nicht-statischen Elementfunktion %q+#D als konstanter Ausdruck ist kein Literaltyp"
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T ist kein Literal, denn: "
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T hat einen nicht-trivialen Destruktor"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr " %q+T ist kein Aggregat, hat keinen trivialen Standardkonstruktor und hat keinen Konstruktor mit konstantem Ausdruck, der kein Kopier- oder Bewegungskonstruktor ist"
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  Basisklasse %qT von %q+T ist kein Literal"
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, gcc-internal-format
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "  nicht-statisches Datenelement %q+D hat nicht-literalen Typ"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %q+D has non-literal type"
 msgid "  non-static data member %q+D has volatile type"
 msgstr "  nicht-statisches Datenelement %q+D hat nicht-literalen Typ"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "Basisklasse %q#T hat einen nicht-virtuellen Destruktor"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr "nicht-statische Referenz %q+#D in Klasse ohne Konstruktor"
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr "nicht-statisches const-Element %q+#D in Klasse ohne einen Konstruktor"
@@ -33934,103 +33984,103 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D mit Eingabe einer konstanten Referenz deklariert, aber implizite Deklaration würde nicht-Konstante annehmen"
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkte Basis %qT ist in %qT durch Mehrdeutigkeit unzugänglich"
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuelle Basis %qT ist in %qT durch Mehrdeutigkeit unzugänglich"
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr "Versatz von %q+D ist ABI-unverträglich und kann sich in zukünftigen GCC-Versionen ändern"
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "Redefinition von %q#T"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T hat virtuelle Funktionen und erreichbaren nicht-virtuellen Destruktor"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "typtransparentes %q#T hat keine Felder"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "typtransparente Klasse %qT hat Basisklassen"
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "typtransparente Klasse %qT hat virtuelle Funktionen"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "typtransparentes %q#T kann nicht transparent gemacht werden, weil der Typ des ersten Feldes anderes ABI als gesamte Klasse hat"
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "Ermittlung aus geschweift geklammerter Initialisierungsliste erfordert #include <initializer_list>"
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "Lesen der struct konnte wegen Syntaxfehlern nicht beendet werden"
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "Sprachen-Zeichenkette %<\"%E\"%> nicht erkannt"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "überladene Funktion %qD konnte nicht durch Umwandlung in Typ %qT aufgelöst werden"
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "bei der Umwandlung der Funktion %qD in den Typ %q#T gab es keine Übereinstimmungen"
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "Umwandung der überladenen Funktion %qD in den Typ %q#T ist mehrdeutig"
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "Zeiger auf Element %qD wird angenommen"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(ein Zeiger auf ein Element kann nur mit %<»&%E%> erzeugt werden)"
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "zu wenig Typinformationen"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE kann nicht vom Typ %qT in den Typ %qT umgewandelt werden"
@@ -34040,12 +34090,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "Deklaration von %q#D"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr "verändert die Bedeutung von %qD von %q+#D"
@@ -34087,265 +34137,265 @@
 msgid "constexpr constructor does not have empty body"
 msgstr "Konstruktor mit konstantem Ausdruck hat keinen leeren Körper"
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr "Körper des %<constexpr%>-Konstruktor kann kein Funktions-»try«-Block sein"
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "%<constexpr%>-Konstruktor für Union %qT muss genau ein nicht-statisches Datenelement initialisieren"
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "nicht initialisiertes Element %qD in %<constexpr%>-Konstruktor"
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "Körper der Funktion %qD mit konstantem Ausdruck ist keine Rückgabeanweisung"
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr "%q+D ist nicht als Funktion mit konstantem Ausdruck verwendbar, denn:"
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
 msgid "call to internal function"
 msgstr "interne Funktion"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "Ausdruck %qE bezeichnet keine Funktion mit konstantem Ausdruck"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "Aufruf der Funktion %qD, die kein konstanter Ausdruck ist"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD in konstantem Ausdruck aufgerufen"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD vor seiner Definition verwendet"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "Aufruf hat ringförmige Abhängigkeit"
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "Auswertungstiefe des konstanten Ausdrucks überschreitet Höchstwert %d (-fconstexpr-depth= verwenden, um dies zu erhöhen)"
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "Rechts-Schiebe-Weite ist negativ"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "linker Operand des Komma-Ausdrucks hat keinen Effekt"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "Ganzzahlausdruck %qE ist nicht konstant"
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "array subscript out of bound"
 msgstr "Feldindex ist außerhalb der Feldgrenzen"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "negative array subscript"
 msgstr "Feldindex erwartet bei %C"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "veränderliches %qD ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "Zugriff auf Element %qD statt auf initialisiertes Element %qD in Konstantenausdruck"
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "Initialisierung für Element %qD fehlt"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "auf Wert von %qE wird über ein %qT GL-Wert in Konstantenausdruck zugegriffen"
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "der Wert von %qD ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD in seiner eigenen Initialisierung verwendet"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D ist nicht konstant"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D ist volatile"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD wurde nicht mit konstantem Ausdruck initialisiert"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD wurde nicht als %<constexpr%> definiert"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD hat keinen Ganzzahl- oder Aufzählungstyp"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "modification of %qE is not a constant-expression"
 msgstr "Division durch Null ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "Zwischenergebnis des nicht-literalen Typs %qT in konstantem Ausdruck"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "ungültiges reinterpret_cast vom Typ »%T« in Typ »%T«"
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr "Ausdruck %qE ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant-expression"
 msgstr "Initialisierungselement ist nicht konstant"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "unerwarteter Ausdruck %qE der Art %s"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT kann nicht der Typ eines vollständigen konstanten Ausdrucks sein, da es veränderliche Sub-Objekte hat"
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr "Umwandlung des Zeigertyps %qT in arithmetischen Typ %qT in konstantem Ausdruck"
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "Ausdruck %qE hat Seiteneffekte"
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "Adresse eines Objektes %qE mit thread-lokalem oder automatischem Speicher ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "Typeid-Ausdruck ist kein konstanter Ausdruck, da %qE polymorphen Typ hat"
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, gcc-internal-format
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "Unterschied zweier Zeigerausdrücke ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr "Zeigervergleichsausdruck ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Umwandlung in Nicht-Ganzzahltyp %qT in konstantem Ausdruck"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, gcc-internal-format
 msgid "division by zero is not a constant-expression"
 msgstr "Division durch Null ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "nicht konstante Feldinitialisierung"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "unerwarteter AST der Art %s"
@@ -34420,7 +34470,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr "%s-Anweisung ist innerhalb eines BLOCKs bei %C nicht erlaubt"
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr "implizit als %<firstprivate%> ermitteltes %qE hat Referenztyp"
@@ -34460,7 +34510,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "Umwandlung von %qT in %qT löscht Qualifizierer"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "Umwandlung von %qT in %qT dereferenziert nicht den Zeiger"
@@ -34470,293 +34520,293 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "Typ %qT kann nicht in den Typ %qT umgewandelt werden"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "Umwandlung von %q#T nach %q#T"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "das Ergebnis der Umwandlung ist nicht spezifiziert, da %qE außerhalb des Wertebereichs des Typs %qT liegt"
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T verwendet, wo %qT erwartet wurde"
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "%qE konnte nicht von %<void%> nach %<bool%> umgewandelt werden"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "%q#T verwendet, wo ein Gleitkommawert erwartet wurde"
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "Umwandlung von %qT in nicht-skalaren Typen %qT angefordert"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "Pseudo-Destruktor wird nicht aufgerufen"
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "Umwandlung in void greift nicht auf Objekt des unvollständigen Typs %qT zu"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in zweitem Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in drittem Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in rechtem Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in linkem Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in Anweisung zu"
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in Erhöhungsausdruck zu"
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "Umwandlung in void greift nicht auf Objekt des Typs %qT zu"
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in zweitem Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in drittem Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in rechtem Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in linkem Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in Anweisung zu"
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in Erhöhungsausdruck zu"
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "Umwandlung in void greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT zu"
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT im zweiten Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT im dritten Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT im rechten Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT im linken Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT in Anweisung zu"
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT in Erhöhungsausdruck zu"
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "Umwandlung in void greift nicht auf Objekt %qE des unvollständigen Typs %qT zu"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird nicht im zweiten Operanden des bedingten Ausdrucks zugegriffen"
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird nicht im dritten Operanden des bedingten Ausdrucks zugegriffen"
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird nicht im rechten Operanden des Kommaoperators zugegriffen"
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird nicht im linken Operanden des Kommaoperators zugegriffen"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird in Anweisung nicht zugegriffen"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird in Erhöhungsausdruck nicht zugegriffen"
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "Umwandlung in void kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "zweiter Operand des bedingten Ausdrucks kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "dritter Operand des bedingten Ausdrucks kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "rechter Operand des Komma-Operators kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "linker Operand des Komma-Operators kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "Anweisung kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "Erhöhungsausdruck kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "zweiter Operand des bedingten Ausdrucks ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "dritter Operand des bedingten Ausdrucks ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "rechter Operand des Komma-Operators ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "linker Operand des Komma-Operators ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "Anweisung ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "Erhöhungsausdruck ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "zweiter Operand des bedingten Ausdrucks hat keinen Effekt"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "dritter Operand des bedingten Ausdrucks hat keinen Effekt"
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "rechter Operand des Komma-Operators hat keinen Effekt"
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "linker Operand des Komma-Operators hat keinen Effekt"
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "Anweisung hat keinen Effekt"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "Erhöhungsausdruck hat keinen Effekt"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "Umwandlung von NULL in Nicht-Zeiger-Typ"
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 #| msgid "  couldn't deduce template parameter %qD"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr " Template-Parameter %qD konnte nicht ermittelt werden"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "mehrdeutige Standard-Typumwandlung von %qT"
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  in Frage kommende Umwandlungen beziehen %qD und %qD ein"
@@ -35191,244 +35241,244 @@
 msgid "template parameters do not match template %qD"
 msgstr "Template-Parameter passen nicht zum Template"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr "eine anonyme struct kann keine Funktionselemente haben"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr "eine anonyme Union kann keine Funktionselemente haben"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Konstruktor in anonymem Aggregat nicht erlaubt"
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Destruktor in anonymem Aggregat nicht erlaubt"
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Zuweisungsoperator ist in anonymem Aggregt nicht erlaubt"
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "Attribut in Deklaration von %q#T ignoriert"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "Attribut für %q#T muss dem Schlüsselwort %qs folgen"
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "mehrere Typen in einer Deklaration"
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "Redeklaration des eingebauten C++-Typs %qT"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> kann nur für Variablen oder Funktionsdeklarationen angegeben werden"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "fehlender Typname in typedef-Deklaration"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO-C++ verbietet anonyme structs"
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr "%qs kann nur für Funktionen angegeben werden"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> kann nur innerhalb einer Klasse angegeben werden"
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> kann nur für Konstruktoren angegeben werden"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "eine Speicherklasse kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr "Qualifizierer können nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> wurde in dieser Deklaration ignoriert"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%> kann nicht für Typdeklarationen verwendet werden"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "Attribut in expliter Instanziierung %q#T ignoriert"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "auf explizite Instanziierung kann kein Attribut angewendet werden"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "auf Klassentyp %qT angewandte Attribute außerhalb einer Definition werden ignoriert"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "auf abhängigen Typ %qT angewandte Attribute ohne zugehörige Deklaration werden ignoriert"
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD ist initialisiert (stattdessen decltype verwenden)"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "Deklaration von %q#D hat %<extern%> und ist initialisiert"
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "Definition von %q#D ist als »dllimport« markiert"
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D ist kein Nicht-static-Datenelement von %qT"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "Templatedeklaration von %q#D"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "ungültige Elementtemplatedeklaration %qD"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO-C++ erlaubt nicht, %<%T::%D%> als %<%T::%D%> zu definieren"
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "doppelte Initialisierung von %qD"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr "%qD außerhalb seiner Klasse als %<constexpr%> deklariert"
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "Deklaration von %q#D außerhalb einer Klasse ist keine Definition"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<thread_local%> invalid for function %qs"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "Speicherklasse %<thread_local%> ungültig für Funktion %qs"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F als %<static%> deklariert, aber nirgendwo definiert"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "Variable %q#D hat Initialisierung, aber unvollständigen Typ"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "Elemente des Feldes %q#D haben unvollständigen Typ"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "Deklaration von %q#D hat keine Initialisierung"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "Aggregat %q#D hat unvollständigen Typ und kann nicht definiert werden"
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD als Referenz deklariert, aber nicht initialisiert"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "Name in benannter Initialisierung im GNU-Stil für ein Feld verwendet"
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "Name %qD in benannter Initialisierung im GNU-Stil für ein Feld verwendet"
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "nicht-trivial markierte Initialisierungen nicht unterstützt"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "Größe des Feldes %qD ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "Initialisierung gibt nicht die Größe von %qD an"
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "Feldgröße fehlt in %qD"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "Feld %qD der Größe null"
@@ -35436,838 +35486,838 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "Speichergröße von %qD ist unbekannt"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "Speichergröße von %qD ist nicht konstant"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "Entschuldigung: Semantik der statischen Daten %q+#D der inline-Funktion ist falsch (mehrere Kopien wären die Folge)"
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, fuzzy, gcc-internal-format
 #| msgid "  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "  dies kann durch das Löschen der Initialisierung umgangen werden"
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "nicht initialisiertes const %qD"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "nicht initialisiertes Element %qD in %<constexpr%>-Konstruktor"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T hat keinen benutzerdefinierten Default-Konstruktor"
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "Konstruktor ist nicht benutzerdefiniert, da er im Klassenkörper ausdrücklich standardisiert ist"
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr "und der implizit definierte Konstruktor initialisiert nicht %q+#D"
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "Ungültiger Typ %qT als Initialisierung für einen Vektor des Typs %qT"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "Initialisierung für %qT muss geklammert sein"
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> in benannter Initialisierung im GNU-Stil für Klasse %qT verwendet"
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT hat kein nicht-statisches Datenelement namens %qD"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ungültige Initialisierung für %q#D"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-Bezeichner %qE außerhalb von Aggregatinitialisierung"
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "zu viele Initialisierer für %qT"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "geschweifte Klammern um skalare Initialisierung für Typ %qT"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "geschweifte Klammern fehlen um Initialisierung für %qT"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "Elemente des Feldes %q#T haben unvollständigen Typ"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "zusammengesetztes Literal variabler Größe"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D hat unvollständigen Typ"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalares Objekt %qD erfordert ein Element in Initialisierung"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "in C++98 muss %qD mit Konstruktor initialisiert werden, nicht mit %<{...}%>"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "Feld %qD mit geklammerter Zeichenkettenkonstante %qE initialisiert"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "Initialisierung ungültig für statisches Element mit Konstruktor"
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "Initialisierung des nicht konstanten statischen Elements %qD in der Klasse ist ungültig"
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(eine Initialisierung außerhalb der Klasse ist erforderlich)"
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is initialized with itself"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD wird mit sich selbst initialisiert"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "Zuweisung (nicht Initialisierung) in Deklaration"
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "vorherige Typdeklaration von %q#D wird überschattet"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr "Java-Objekt %qD nicht mit %<new%> reserviert"
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr "nicht-statisches Datenelement %qD hat Java-Klassentyp"
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "Funktion %q#D ist wie eine Variable initialisiert"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "nicht-lokale %<__thread%>-Variable %qD erfordert dynamische Initialisierung"
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "nicht-lokale %<__thread%>-Variable %qD hat einen nicht-trivialen Destruktor"
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "%<thread_local%> in C++11 erlaubt dynamische Initialisierung und Zerstörung"
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Initialisierung gibt nicht die Größe von %qT an"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "Feldgröße fehlt in %qT"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "Feld %qT der Größe null"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "Destruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "Konstruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD als eine %<virtual%> Variable deklariert"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> variable"
 msgstr "%qD als eine %<inline%> Variable deklariert"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Variablendeklaration"
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD als ein %<virtual%> Parameter deklariert"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD als ein %<inline%> Parameter deklariert"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Parameterdeklaration"
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD als ein %<virtual%> Typ deklariert"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD als ein %<inline%> Typ deklariert"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Typdeklaration"
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD als ein %<virtual%> Feld deklariert"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD als ein %<inline%> Feld deklariert"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Felddeklaration"
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D als »friend« deklariert"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D mit einer Ausnahmespezifikation deklariert"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "Deklaration von %qD ist nicht in einem Namensbereich um %qT"
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statische Elementfunktion %q#D mit Typqualifizierern deklariert"
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "Definition der expliziten Spezialisierung %qD in friend-Deklaration"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ungültige Verwendung der Template-ID %qD in Deklaration des ursprünglichen Templates"
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "Standardargumente sind nicht in Deklaration der friend-Template-Spezialisierung %qD erlaubt"
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> ist nicht in Deklaration der friend-Template-Spezialisierung %qD erlaubt"
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> ist nicht in Deklaration der friend-Template-Spezialisierung %qD erlaubt"
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> kann nicht als Template deklariert werden"
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> kann nicht inline deklariert werden"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "%<::main%> kann nicht inline deklariert werden"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> kann nicht statisch deklariert werden"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "statische Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "Nicht-Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "statische Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "Nicht-Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "literaler Operator mit C-Bindung"
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD hat ungültige Argumentliste"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr "Ganzzahl-Suffix %<%s%> durch Implementierung überdeckt"
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr "Gleitkomma-Suffix %<%s%> durch Implementierung überdeckt"
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD muss eine Nicht-Elementfunktion sein"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> muss %<int%> zurückgeben"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "Definition des implizit deklarierten %qD"
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "Definition des explizit standardisierten %q+D"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, gcc-internal-format
 msgid "%q+#D explicitly defaulted here"
 msgstr "%q+#D wurde ausdrücklich hier standardisiert"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "keine Elementfunktion %q#D in Klasse %qT deklariert"
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit unvollständigem Typ"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> erforderlich für Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit nicht eingebautem Typ"
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit nicht eingebautem Typ"
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ungültige Initialisierung innerhalb der Klasse des statischen Datenelements vom nicht eingebauten Typen %qT"
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO-C++ verbietet Initialisierung des nicht konstanten statischen Elements %qD in der Klasse"
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO-C++ verbietet Initialisierung der Elementkonstante %qD vom nicht eingebauten Typen %qT"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "Feldgröße von %qD hat nicht-ganzzahligen Typen %qT"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "Feldgröße hat nicht-ganzzahligen Typen %qT"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "Größe des Feldes %qD ist negativ"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "Größe des Feldes ist negativ"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO-C++ verbietet Feld %qD der Größe null"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO-C++ verbietet Feld der Größe null"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "Größe des Feldes %qD ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "Größe des Feldes ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO-C++ verbietet Feld %qD variabler Länge"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO-C++ verbietet Feld variabler Länge"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "Feld %qD variabler Länge wird verwendet"
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "Feld variabler Größe wird verwendet"
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "Überlauf in Feldgröße"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D als »friend« deklariert"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "Deklaration von %qD als Feld von voids"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "Feld von void wird erzeugt"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "Deklaration von %qD als Feld von Funktionen"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "Feld von Funktionen wird erzeugt"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "Deklaration von %qD als Feld von Referenzen"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "Feld von Referenzen wird erzeugt"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "Deklaration von %qD als Feld von Funktionselementen"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "Feld von Funktionselementen wird erzeugt"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "Deklaration von %qD als multidimensionales Feld muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "multidimensionales Feld muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "Angabe des Rückgabetyps für Konstruktor ist ungültig"
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "Angabe des Rückgabetyps für Destruktor ist ungültig"
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "Rückgabetyp für %<operator %T%> angegeben"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "unbenannte Variable oder Feld als »void« deklariert"
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "Variable oder Feld als »void« deklariert"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<::%D%>"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<%T::%D%>"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<%D::%D%>"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T ist keine Klasse oder Namensbereich"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "Deklaration von %qD als Nicht-Funktion"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "Deklaration von %qD als Nicht-Element"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "Deklarator-ID fehlt: reserviertes Wort %qD wird verwendet"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "Funktionsdefinition deklariert keine Parameter"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "Deklaration von %qD als %<typedef%>"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "Deklaration von %qD als Parameter"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> kann nicht in typedef-Deklaration auftreten"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "zwei oder mehr Datentypen in Deklaration von %qs"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "in Konflikt stehende Spezifikationen für Deklaration von %qs"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO-C unterstützt nicht %<double complex%> bedeutendes einfaches %<complex%>"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO-C++ verbietet Deklaration von %qs ohne Typ"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int128%> wird von diesem Ziel nicht unterstützt"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO-C++ unterstützt nicht %<__int128%> for %qs"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> oder %<unsigned%> ungültig für %qs"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> und %<unsigned%> für %qs gleichzeitig angegeben"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> ungültig für %qs"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> ungültig für %qs"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> ungültig für %qs"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> oder %<short%> ungültig für %qs"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%> oder %<char%> ungültig für %qs"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> oder %<short%> mit »char« für %qs angegeben"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> und %<short%> für %qs gleichzeitig angegeben"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> oder %<long%> ungültig für %qs"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed oder unsigned ungültig verwendet für %qs"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex ungültig für %qs"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "Qualifizierer sind bei Deklaration von %<operator %T%> nicht erlaubt"
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr "Element %qD kann nicht gleichzeitig virtuell und statisch deklariert werden"
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "»typedef«-Deklaration in Parameterdeklaration ungültig"
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "Speicherklasse für Template-Parameter %qs angegeben"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "Speicherklassenangaben sind in Parameterdeklarationen ungültig"
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "ein Parameter kann nicht als %<constexpr%> deklariert sein"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> außerhalb einer Klassendeklaration"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "mehrere Speicherklassen in Deklaration von %qs"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "Speicherklasse %qs angegeben"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "Speicherklasse für Parameter %qs angegeben"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "geschachtelte Funktion %qs als %<extern%> deklariert"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "Deklaration höchster Ebene von %qs gibt %<auto%> an"
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "Funktions-Gültigkeitsbereich %qs ist implizit auto und deklarierte %<__thread%>"
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "Speicherklassenangaben sind in friend-Funktionsdeklarationen ungültig"
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs als Funktion, die eine Funktion zurückgibt, deklariert"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs als Funktion, die ein Feld zurückgibt, deklariert"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "Funktion %qs verwendet Typspezifikation %<auto%> ohne folgenden Rückgabetypen"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "folgender Rückgabetyp nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "virtuelle Funktionen können keine friends sein"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "Funktion %qs mit folgendem Rückgabetypen hat %qT als seinen Typ statt einfaches %<auto%>"
@@ -36274,480 +36324,480 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "folgender Rückgabetyp nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "Funktion %qs mit folgendem Rückgabetypen nicht mit Typspezifikation %<auto%> deklariert"
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "Destruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "Konstruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "Destruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "Konstruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "Destruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr "Konstruktoren können nicht als virtuell deklariert werden"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuelle Funktionen können keine friends sein"
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-Deklaration nicht in Klassendefinition"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "friend-Funktion %qs kann nicht in einer lokalen Klassendefinition definiert werden"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "Destruktoren dürfen keine Parameter haben"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "Zeiger auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Referenz auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "Zeiger auf Element %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Referenz auf %q#T kann nicht deklariert werden, da letzteres weder Typedef noch Templatetyp-Argument ist"
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "Template-ID %qD als Deklarator verwendet"
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "Elementfunktionen sind implizite »friends« ihrer Klasse"
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "zusätzliche Qualifizierung %<%T::%> an Element %qs"
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "Elementfunktion %<%T::%s%> innerhalb von %<%T%> kann nicht definiert werden"
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "Elementfunktion %<%T::%s%> kann nicht in %<%T%> deklariert werden"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "Element %<%T::%s%> kann nicht in %qT deklariert werden"
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "Nicht-Parameter %qs kann kein Parameterpack sein"
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "Feldgröße von %qs ist zu groß"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "Datenelement darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "Parameter darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> außerhalb einer Klassendeklaration"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> in leerer Deklaration"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "nur Deklarationen von Konstruktoren können %<explicit%> sein"
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Objekt-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Funktion %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "statisches %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "Konstante %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Referenz %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "»typedef« als %<auto%> deklariert"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-Name darf kein Spezifizierer mit geschachteltem Namen sein"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO-C++ verbietet geschachtelten Typen %qD mit gleichem Namen wie umschließende Klasse"
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr "Typkennzeichner für friend-Klassen-Deklaration angegeben"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> für friend-Klassen-Deklaration angegeben"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "Template-Parameter können keine »friends« sein"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend class %T::%D%>"
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend %#T%>"
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "Versuch, die Klasse %qT zu einem »friend« des globalen Gültigkeitsbereiches zu machen"
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ungültige Qualifizierer an Nicht-Element-Funktionstyp"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakter Deklarator %qT als Deklaration verwendet"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "%<::%> kann nicht in Parameterdeklaration verwendet werden"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> darf in diesem Kontext nicht verwendet werden"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "Parameter als %<auto%> deklariert"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, gcc-internal-format
 msgid "non-static data member declared %<auto%>"
 msgstr "nicht-statisches Datenelement als %<auto%> deklariert"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ungültige Verwendung von %<::%>"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "Deklaration der Funktion %qD in ungültigem Kontext"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "Funktion %qD als virtuell innerhalb einer Union deklariert"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr "%qD kann nicht als virtuell deklariert werden, da es immer statisch ist"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Destruktor %qD erwartet"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "Deklaration von %qD als Element %qT"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "Destruktor kann nicht %<constexpr%> sein"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Konstruktor %qD erwartet"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of alias template %qD"
 msgid "specialization of variable template %qD declared as function"
 msgstr "Spezialisierung des Alias-Template %qD"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 #| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "ursprünglicher Typ hier deklariert"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "Feld %qD hat unvollständigen Typen"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "Name %qT hat unvollständigen Typen"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ist weder eine Funktion noch Elementfunktion; kann nicht als »friend« deklariert werden"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr "statisches Datenelement %qD (constexpr) muss Initialisierung haben"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "nicht-statisches Datenelement %qE als %<constexpr%> deklariert"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "Speicherklasse %<auto%> ungültig für Funktion %qs"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "Speicherklasse %<register%> ungültig für Funktion %qs"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "Speicherklasse %<__thread%> ungültig für Funktion %qs"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "Speicherklasse %<thread_local%> ungültig für Funktion %qs"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-Spezifikation in %qs ist außerhalb einer Klassendefinition nicht erlaubt"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr "%<static%> ungültig für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs"
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> ungültig für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs"
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuelle Nicht-Klassen-Funktion %qs"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs nicht in Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs in einem Nicht-Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "Elementfunktion %qD kann nicht deklariert werden, statische Bindung zu haben"
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statische Funktion innerhalb anderer Funktion kann nicht deklariert werden"
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> darf nicht bei der Definition (im Gegensatz zu Deklaration) eines statischen Datenelementes verwendet werden"
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisches Element %qD als %<register%> deklariert"
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "Element %q#D kann nicht explizit deklariert werden, externe Bindung zu haben"
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, gcc-internal-format
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "Deklaration der constexpr-Variable %qD ist keine Definition"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initialisiert und als %<extern%> deklariert"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hat sowohl %<extern%> als auch Initialisierung"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Standardargument %qE verwendet %qD"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Standardargument %qE verwendet lokale Variable %qD"
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ungültige Verwendung von %<virtual%> in Templatedeklaration von %q#D"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ungültige Verwendung von %<virtual%> in Templatedeklaration von %q#D"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "Parameter %qD hat Java-Klassentyp"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "Parameter %qD deklariert ungültigerweise Methodentyp"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Zeiger auf Feld mit unbekannter Grenze %qT ein"
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Referenz auf Feld mit unbekannter Grenze %qT ein"
@@ -36767,173 +36817,173 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ungültiger Konstruktor; wahrscheinlich war %<%T (const %T&)%> gemeint"
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD darf nicht innerhalb eines Namensbereiches definiert werden"
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD darf nicht als »static« deklariert werden"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD muss eine nichtstatische Elementfunktion sein"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD muss entweder eine nichtstatische Elementfunktion oder eine Nicht-Element-Funktion sein"
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD muss ein Argument von einem Klassen- oder Aufzählungstyp haben"
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "Umwandlung in Referenz auf void wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "Umwandlung in void wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "Umwandlung in Referenz auf gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "Umwandlung in gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "Umwandlung in Referenz auf Basisklasse wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "Umwandlung in Basisklasse wird nie einen Typumwandlungsoperator verwenden"
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO-C++ verbietet Überladen des Operators ?:"
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "»%qD« darf keine variable Argumentanzahl haben"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr "Suffix-%qD muss %<int%> als sein Argument nehmen"
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr "Suffix-%qD muss %<int%> als sein zweites Argument nehmen"
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr "%qD muss entweder null oder ein Argument nehmen"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr "»%D« muss entweder ein oder zwei Argumente nehmen"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "Präfix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "Suffix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr "%qD muss %<void%> nehmen"
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr "%qD muss genau ein Argument nehmen"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "%qD muss genau zwei Argumente nehmen"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "benutzerdefiniertes %qD wertet immer beide Argumente aus"
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD sollte Wert zurückgeben"
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kann keine Standardargumente haben"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "Templatetyp-Parameter %qT wird nach %qs verwendet"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "Templatespezialisierung alias %qT hinter %qs wird verwendet"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-Name %qD wird nach %qs verwendet"
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD hat eine vorherige Deklaration hier"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT als %qs verwendet"
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "%q+T hat eine vorherige Deklaration hier"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT als enum verwendet"
@@ -36945,88 +36995,88 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "Template-Argument für %<%s %T%> benötigt"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD hat den gleichen Namen wie die Klasse, in der es deklariert wurde"
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "Referenz auf %qD ist mehrdeutig"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "Verwendung des enum %q#D ohne vorherige Deklaration"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Redeklaration von %qT als Nicht-Template"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "vorherige Deklaration %q+D"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "abgeleitete Union %qT ist ungültig"
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr "Java-Klasse %qT kann nicht mehrere Basen haben"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr "Java-Klasse %qT kann keine virtuellen Basen haben"
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "Basistyp %qT ist kein struct- oder Klassentyp"
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiver Typ %qT nicht definiert"
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "doppelter Basistyp %qT ungültig"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "falsche Zuordnung zwischen innerhalb und außerhalb eines Gültigkeitsbereiches in enum %q#T"
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "vorherige Definition hier"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "falsche Zuordnung des zugrunde liegenden Typs in enum %q#T"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "anderer zugrunde liegender Typ in enum %q#T"
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr "zugrunde liegender Typ %<%T%> von %<%T%> muss ein eingebauter Typ sein"
@@ -37035,88 +37085,88 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "kein Ganzzahltyp kann alle Aufzählungswerte für %qT darstellen"
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Aufzählungswert für %qD ist keine Ganzzahlkonstante"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "erhöhter Aufzählungswert ist zu groß für %<unsigned long%>"
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "Überlauf in Aufzählungswerten bei %qD"
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr "Aufzählungswert %E ist zu groß für zugrunde liegenden Typ %<%T%>"
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "Rückgabetyp %q#T ist unvollständig"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr "Rückgabetyp hat Java-Klassentyp %q#T"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> sollte eine Referenz auf %<*this%> zurückgeben"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "keine vorherige Deklaration für %q+D"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "ungültige Funktionsdeklaration"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "Parameter %qD leer definiert"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "keine return-Anweisungen in %qT zurückgebender Funktion"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "nur einfacher Rückgabetyp %<auto%> kann zu %<void%> hergeleitet werden"
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, gcc-internal-format
 msgid "parameter %q+D set but not used"
 msgstr "Parameter %q+D gesetzt, aber nicht verwendet"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "ungültige Elementfunktionsdeklaration"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ist bereits in Klasse %qT definiert"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "Verwendung von %qD vor Herleitung von %<auto%>"
@@ -37156,7 +37206,7 @@
 msgid "deleting %qT is undefined"
 msgstr "Löschen von %qT ist nicht definiert"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "Templatedeklaration von %q#D"
@@ -37179,7 +37229,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "Destruktor %qD als Element-Template deklariert"
@@ -37272,28 +37322,28 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "Breite des Bit-Feldes %qD hat Nicht-Ganzzahl-Typ %qT"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a static data member of a class template"
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD ist kein statisches Datenelement eines Klassentemplates"
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonymes struct nicht innerhalb eines benannten Typs"
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "anonymes Aggregat im Gültigkeitsbereich eines Namespace muss statisch sein"
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonyme Union ohne Element"
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> muss Typ %qT zurückgeben"
@@ -37302,47 +37352,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "der erste Parameter von %<operator_new%> kann nicht das Standardargument haben"
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> nimmt Typ %<size_t%> (%qT) als ersten Parameter"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> muss Typ %qT zurückgeben"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> nimmt Typ %qT als ersten Parameter"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT hat ein Feld %qD, dessen Typ den anonymen Namensbereich verwendet"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT mit bedeutenderer Sichtbarkeit als der Typ seines Feldes %qD deklariert"
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT hat Basis %qT, dessen Typ den anonymen Namensbereich verwendet"
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT mit bedeutenderer Sichtbarkeit als seine Basis %qT deklariert"
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using anonymous type, is used but never defined"
 msgid "%q#D, declared using anonymous type, is used but never defined"
@@ -37352,49 +37402,49 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr "anonymer Typ ohne Bindung verwendet, um Variable %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr "anonymer Typ ohne Bindung verwendet, um Funktion %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D verweist nicht auf den unqualifizierten Typen, also wird es nicht zum Binden verwendet"
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using local type %qT, is used but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "mit lokalem Typ %2$qT deklariertes %1$q+#D wird verwendet, aber nirgendwo definiert"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "Typ %qT ohne Bindung verwendet, um Variable %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "Typ %qT ohne Bindung für Funktionsdeklaration %q#D mit Bindung deklariert"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "inline-Funktion %q+D verwendet, aber nirgendwo definiert"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "Standardargument fehlt für Parameter %P von %q+#D"
@@ -37401,12 +37451,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr "%<...%> verwendendes Lambda wird in Funktionszeiger umgewandelt"
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "gelöschte Funktion %qD wird verwendet"
@@ -37998,42 +38048,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "weder der Destruktor noch der klassenspezifische Operator »delete« wird aufgerufen, auch wenn sie bei der Klassendefinition deklariert werden"
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "Initialisierung endet vorzeitig"
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr "mehrdimensionales Feld kann nicht initialisiert werden"
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "unbekannte Feldgröße in »delete«"
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "mögliches Problem bei Aufruf des »delete«-Operators erkannt"
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "weder der Destruktor noch der klassenspezifische Operator »delete« wird aufgerufen, auch wenn sie bei der Klassendefinition deklariert werden"
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr "Löschen des Objekts mit abstraktem Klassentyp %qT mit nicht-virtuellem Destruktor bewirkt undefiniertes Verhalten"
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr "Löschen des Objekts mit polymorphem Klassentyp %qT mit nicht-virtuellem Destruktor bewirkt möglicherweise undefiniertes Verhalten"
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "Typ für Vektor-»delete« ist weder Zeiger- noch Feldtyp"
@@ -38165,17 +38215,17 @@
 msgid "string literal in function template signature"
 msgstr "Zeichenkettenliteral in Signatur des Funktionstemplate"
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "Eine spätere Option -fabi-version= (oder =0) verhindert diesen Fehler mit einer Änderung im Mangeln"
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, gcc-internal-format
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "der gemangelte Name von %q+D hat sich zwischen -fabi-version=%d (%D) und -fabi-version=%d (%D) geändert"
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, gcc-internal-format
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "der gemangelte Name von %q+D ändert sich zwischen -fabi-version=%d (%D) und -fabi-version=%d (%D)"
@@ -38594,7 +38644,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr "Bezeichner %qE wird in C++11 zum Schlüsselwort"
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -38619,7 +38669,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "Abfrage des Elementes %qE in Nicht-Klassentyp %qT"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> wurde nicht deklariert"
@@ -38684,7 +38734,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(vielleicht fehlt ein Semikolon hinter der Definition von %qT)"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ist kein Template"
@@ -38709,7 +38759,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "Gleitkommaliteral kann nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "Eine Typumwandlung, die weder zu ganzzahligen noch Aufzählungstypen führt, kann nicht in einem Konstantenausdruck auftreten"
@@ -38982,7 +39032,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "Literale Operator-Suffixe ohne vorangehendes %<_%> sind für zukünftige Standardisierungen reserviert"
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "unqualifizierte ID erwartet"
@@ -39163,7 +39213,7 @@
 msgid "capture of non-variable %qD "
 msgstr "Erfassung von Nicht-Variable %qD"
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, gcc-internal-format
 msgid "%q+#D declared here"
 msgstr "%q+#D hier deklariert"
@@ -39224,7 +39274,7 @@
 msgid "compound-statement in constexpr function"
 msgstr "zusammengesetzte Anweisung in Funktion als konstantem Ausdruck"
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "Auswahl-Anweisung erwartet"
@@ -39254,7 +39304,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "unvereinbare Anfang-/Ende-Typen in bereichsbasierter %<for%>-Anweisung: %qT und %qT"
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "Iterationsanweisung erwartet"
@@ -39289,12 +39339,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO-C++ verbietet berechnete Gotos"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "Sprunganweisung erwartet"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "zusätzliches %<;%>"
@@ -39342,7 +39392,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "Klassendefinition darf nicht als »friend« deklariert sein"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "Templates dürfen nicht %<virtual%> sein"
@@ -39436,12 +39486,12 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "Schlüsselwort %<export%> nicht implementiert, und wird ignoriert"
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "Templateparameterpack %qD kann kein Standardargument haben"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "Templateparameterpack kann kein Standardargument haben"
@@ -39456,7 +39506,7 @@
 msgid "expected template-id"
 msgstr "Template-ID erwartet"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<%> erwartet"
@@ -39533,214 +39583,214 @@
 msgid "expected type specifier"
 msgstr "Typspezifizierer erwartet"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "Standard- und gelöschte Funktionen nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "Standard- und gelöschte Funktionen nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO-C verbietet Vorwärtsdeklaration für Parameter"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "Template-ID für Typ erwartet"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "Typ-Name erwartet"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr "ausführliche Typ-Spezifikation für einen enum mit Gültigkeitsbereich darf nicht das Schlüsselwort %<%D%> verwenden"
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "Deklaration %qD deklariert nichts"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "Attribute an instanziiertem Typen ignoriert"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "Attribute an Templateinstanziierung ignoriert"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "Attribute an Spezifizierer ausführlichen Typs ignoriert, der keine Vorwärtsdeklaration ist"
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD ist ein Aufzählungstemplate"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, gcc-internal-format
 msgid "%qD is not an enumerator-name"
 msgstr "%qD ist kein Aufzählungsname"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> oder %<{%> erwartet"
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aufzählungsliste kann nicht zu Template-Instanziierung hinzugefügt werden"
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "Deklaration von %qD in Namensraum %qD, der nicht %qD einschließt"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "Deklaration von %qD in %qD, das nicht %qD einschließt"
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "mehrfache Definition von %q#T"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO-C++ verbietet erhöhen einer Aufzählung"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "intransparente Enum-Spezifikation ohne Namen"
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "intransparente Enum-Spezifikation muss einfachen Bezeichner verwenden"
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD ist kein Namensbereichs-Name"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "Namensraumname erwartet"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-Definition ist hier nicht erlaubt"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "eine Template-ID darf nicht in »using«-Deklaration auftreten"
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "Zugriffsdeklarationen sind zugunsten von %<using%>-Deklarationen veraltet; Vorschlag: %<using%> hinzufügen"
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "Typen dürfen nicht in Alias-Templatedeklarationen definiert werden"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "zusammengesetzte Anweisung in Funktion als konstantem Ausdruck"
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "eine Funktionsdefinition ist hier nicht erlaubt"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "asm-Spezifikation ist bei Funktionsdefinition nicht erlaubt"
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "bei einer Funktionsdefinition sind keine Attribute erlaubt"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "Konstruktor, Destruktor oder Typumwandlung erwartet"
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "Initialisierung erwartet"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "Initialisierung für Funktion bereitgestellt"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "Attribute hinter geklammerter Initialisierung werden ignoriert"
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "Funktion %q+D als inline redeklariert"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "Feldgrenze ist keine Ganzzahlkonstante"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "Element des abhängigen Typedef %qT kann nicht definiert werden"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> ist kein Typ"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ungültige Benutzung des Konstruktors als Template"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "%<%T::%D%> statt %<%T::%D%> verwenden, um den Konstruktor mit qualifiziertem Namen zu benennen"
@@ -39749,7 +39799,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ungültiger Deklarator"
@@ -39756,297 +39806,297 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased declaration"
 msgid "qualified-id in declaration"
 msgstr "Alias-Deklaration %q+D"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "Deklarator erwartet"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD ist ein Namensbereich"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "Zeiger auf Element der Nicht-Klasse %q#T kann nicht erzeugt werden"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "Ptr-Operator erwartet"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "doppelter CV-Qualifizierer"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "doppelter CV-Qualifizierer"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "doppelter Virt-Spezifizierer"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, gcc-internal-format
 msgid "invalid use of %<auto%>"
 msgstr "ungültige Verwendung von %<auto%>"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "in Template-Argumenten dürfen keine Typen definiert werden"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ungültige Verwendung von »%E« als ein Nicht-Typ-Templateargument"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "Typspezifikation erwartet"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> oder %<...%> erwartet"
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "Typen dürfen nicht in Parametertypen definiert werden"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr "veraltete Verwendung des Standardarguments für Parameter einer Nicht-Funktion"
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "Standardargumente sind nur für Funktionsparameter zugelassen"
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "Parameterpack %qD kann kein Standardargument haben"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "Parameterpack kann kein Standardargument haben"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO-C++ erlaubt keine benannten Initialisierungen"
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO-C++ erlaubt keine benannten Initialisierungen von C99"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "Klassenname erwartet"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> hinter Klassendefinition erwartet"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> hinter Strukturdefinition erwartet"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> hinter Uniondefinition erwartet"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> oder %<:%> erwartet"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "für eine Klasse kann kein %<override%> angegeben werden"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "globale Qualifizierung von Klassenname ist ungültig"
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "qualifizierter Name benennt keine Klasse"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "ungültiger Klassenname in Deklaration von %qD"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "zusätzliche Qualifizierung nicht erlaubt"
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "einer expliziten Spezialisierung muss %<template <>%> vorausgehen"
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "Funktions-Template %qD als Klassentemplate redeklariert"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "Typnamen-Typ kann nicht aufgelöst werden"
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr "vorherige Definition von %q+#T"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "Klassenschlüssel erwartet"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%>, %<typename%> oder %<template%> erwartet"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "in C++03 muss bei Deklaration eines »friend« ein Klassenschlüssel verwendet werden"
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "»friend«-Deklaration benennt keine Klasse oder Funktion"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "Speicherklasse an anonymem Aggregat im Klassenbereich ist nicht erlaubt"
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "reiner Spezifizierer bei Funktionsdefinition"
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "überflüssiges %<,%> am Ende der Elementdeklaration"
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> am Ende von Elementdeklaration erwartet"
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "ungültige reine Spezifikation (nur %<= 0%> ist erlaubt)"
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "eine geschweift geklammerte Initialisierung ist hier nicht erlaubt"
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr "%<virtual%> mehr als einmal in Basisspezifikation angegeben"
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr "mehr als ein Zugriff in Basisspezifikation angegeben"
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "Schlüsselwort %<typename%> nicht außerhalb von Templates erlaubt"
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "Schlüsselwort %<typename%> nicht erlaubt in diesem Kontext (die Basisklasse ist implizit ein Typ)"
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "Typen dürfen nicht in einer Ausnahmespezifikation definiert werden"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr "dynamische Ausnahmespezifikationen sind in C++0x veraltet; stattdessen %<noexcept%> verwenden"
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not %<constexpr%>"
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%qD ist nicht %<constexpr%>"
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "Typen dürfen nicht in Ausnahmedeklarationen definiert werden"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "Bezeichner für den Attributnamen erwartet"
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "spezialisierendes Element %<%T::%E%> erfordert Syntax %<template<>%>"
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ungültige Deklaration von  %<%T::%E%>"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "zu wenige Templateparameterlisten"
@@ -40055,550 +40105,550 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "zu viele Templateparameterlisten"
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "benannte Rückgabewerte werden nicht mehr unterstützt"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ungültige Deklaration eines Elementtemplates in lokaler Klasse"
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "Template mit C-Bindung"
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ungültige explizite Spezialisierung"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, fuzzy, gcc-internal-format
 #| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "Literales Operatortemplate %qD hat ungültige Parameterliste. Template für Nicht-Typ Argumentpack <char...> erwartet"
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "Literales Operatortemplate %qD hat ungültige Parameterliste. Template für Nicht-Typ Argumentpack <char...> erwartet"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "Templatedeklaration von %<typedef%>"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explizite Template-Spezialisierung kann keine Speicherklasse haben"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> sollte innerhalb einer geschachtelten Templateargumentliste %<> >%> sein"
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "falsches %<>>%>; %<>%> verwenden, um eine Templateargumentliste zu beenden"
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "Argument von %<sizeof...%> muss mit Klammern umschlossen werden"
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ungültige Verwendung von %qD in Spezifizierung der Bindung"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vor %qD"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO-C++ 1998 unterstützt nicht %<long long%>"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sowohl %<__thread%> als auch %<thread_local%> angegeben"
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "doppeltes %qD"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "doppeltes %qs"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> erwartet"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> erwartet"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> erwartet"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> erwartet"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> erwartet"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> erwartet"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> erwartet"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> erwartet"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> erwartet"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> erwartet"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> erwartet"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> erwartet"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> erwartet"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> erwartet"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> erwartet"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> erwartet"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> erwartet"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> erwartet"
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> erwartet"
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> erwartet"
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> erwartet"
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> erwartet"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> erwartet"
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> erwartet"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> erwartet"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> oder %<::%> erwartet"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> oder %<template%> erwartet"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Markierung %qs bei Benennung von %q#T verwendet"
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T wurde vorher hier deklariert"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD mit anderem Zugriff redeklariert"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "in C++98 ist %<template%> (zum eindeutig machen) nur innerhalb von Templates erlaubt"
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "Datei endet in Standardargument"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "unpassendes Objective-C++-Konstrukt %<@%D%>"
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c++ message argument(s) are expected"
 msgid "objective-c++ message receiver expected"
 msgstr "Objective-C++ Nachrichtenargument(e) erwartet"
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "Objective-C++ Nachrichtenargument(e) erwartet"
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> muss als Argument einen Typen angeben"
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Ungültiger Objective-C++-Selektorname"
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "Objective-C++ Methodendeklaration erwartet"
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "Methodenattribute müssen am Ende angegeben werden"
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "überflüssiges %qs zwischen Objective-C++ Methoden"
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ungültiger Typ für Instanzvariable"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Bezeichner nach %<@protocol%> erwartet"
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "Attribute dürfen nicht vor dem Objective-C++-Schlüsselwort %<@%D%> angegeben werden"
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "Präfix-Attribute vor %<@%D%> werden ignoriert"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ungültiger Typ für Eigenschaft"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected positive integer expression"
 msgstr "Ganzzahlausdruck erwartet"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads-Ausdruck muss bestimmt sein"
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "ungültige Initialisierung"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "geklammerte Initialisierung ist in OpenMP-%<for%>-Schleife nicht erlaubt"
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "geklammerte Initialisierung ist in OpenMP-%<for%>-Schleife nicht erlaubt"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "Schleifenvariable %qD sollte nicht Reduktion sein"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, gcc-internal-format
 msgid "not enough collapsed for loops"
 msgstr "zu wenig zusammengefallen für Schleifen"
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "bei einer Funktionsdefinition sind keine Attribute erlaubt"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "ungültige Initialisierung"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 #| msgid "expected id-expression"
 msgid "expected id-expression (arguments)"
 msgstr "ID-Ausdruck erwartet"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> oder %<max%> erwartet"
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "neue Typen dürfen nicht in einem Rückgabetyp definiert werden"
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "Ausschuss am Ende von %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "ungültige Bedingungen für Operand"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize ist nicht innerhalb von Funktionen erlaubt"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC optimize ist nicht innerhalb von Funktionen erlaubt"
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize ist nicht innerhalb von Funktionen erlaubt"
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "Optimierungen zwischen Modulen noch nicht implementiert für C++"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "Variablennamen bei %C erwartet"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "%<,%> oder %<)%> erwartet"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "Templates dürfen nicht %<virtual%> sein"
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "Datenelement %qD kann kein Elementtemplate sein"
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "ungültige Elementtemplatedeklaration %qD"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "explizite Spezialisierung in Gültigkeitsbereich des Nicht-Namensbereiches %qD"
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "einschließende Klassentemplates werden nicht explizit spezialisiert"
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "Spezialisierung von %qD muss im Gültigkeitsbereich des Namensbereiches auftreten"
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "Spezialisierung von %qD in anderem Namensbereich"
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr "  aus Definition von %q+#D"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "explizite Instanziierung von %qD in Namensbereich %qD (das nicht Namensbereich %qD einschließt)"
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "Name der Klasse verdeckt Template-Templateparameter %qD"
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "Spezialisierung des Alias-Template %qD"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "explizite Spezialisierung des Nicht-Templates %qT"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "Spezialisierung von %qT hinter Instanziierung"
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "%q#T wird in anderem Namensbereich spezialisiert"
@@ -40605,69 +40655,69 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "Spezialisierung %qT hinter Instanziierung %qT"
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "Templatespezialisierung von %qD durch ISO C++ nicht erlaubt"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "Spezialisierung von %qD nach Instanziierung"
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, gcc-internal-format
 msgid "candidate is: %#D"
 msgstr "Kandidat ist: %#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %#D"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD ist kein Funktionstemplate"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD ist keine Variable"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "Template-ID %qD für %q+D passt zu keiner Templatedeklaration"
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "%d %<template<>%> gefunden, %d werden für Spezialisierung eines Elementfunktionstemplates benötigt"
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "mehrdeutige Templatespezialisierung %qD für %q+D"
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "variadische Templates nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, gcc-internal-format
 msgid "too many template headers for %D (should be %d)"
 msgstr "zu viele Templateheader für %D (sollte %d sein)"
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "Elemente einer explizit spezialisierten Klasse sind ohne Templateheader definiert"
@@ -40674,59 +40724,59 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "Template-ID %qD in Deklaration des ersten Templates"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "Templateparameterliste in expliziter Instanziierung verwendet"
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "Definition für explizite Instanziierung angegeben"
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "zu viele Templateparameterlisten in Deklaration von %qD"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "zu wenige Templateparameterlisten in Deklaration von %qD"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "der expliziten Spezialisierung von %D muss %<template <>%> vorausgehen"
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "Teilspezialisierung %qD des Funktionstemplates ist nicht erlaubt"
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "Teilspezialisierung %qD des Funktionstemplates ist nicht erlaubt"
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "Standardargument in expliziter Spezialisierung angegeben"
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD ist keine Templatefunktion"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "%qD in %qD nicht deklariert"
@@ -40739,94 +40789,94 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "Spezialisierung der implizit deklarierten speziellen Elementfunktion"
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "keine Elementfunktion %qD in %qT deklariert"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr "Auflösung der Basisinitialisierung %<%T%> enthält keine Parameterpacks"
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr "Auflösungsmuster %<%T%> enthält keine Argumentpacks"
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr "Auflösungsmuster %<%E%> enthält keine Argumentpacks"
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "Parameterbündel nicht mit %<...%> aufgelöst:"
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonym>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "Deklaration von %q+#D"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr " überdeckt Templateparameter %q+#D"
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "nicht in partieller Spezialisierung verwendete Templateparameter:"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr "Teilspezialisierung %qT spezialisiert keine Templateargumente"
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "partielle Spezialisierung ist nicht näher spezialisiert als das ursprüngliche Template, da es mehrere Parameter mit einer »pack«-Erweiterung ersetzt"
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "ursprüngliches Template hier"
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "Argument %qE für Parameterpack muss am Ende der Templateargumentliste sein"
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "Argument %qT für Parameterpack muss am Ende der Templateargumentliste sein"
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "Templateargument %qE betrifft Templateparameter"
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -40833,13 +40883,13 @@
 msgstr[0] "Typ %qT des Templatearguments %qE hängt von Templateparameter ab"
 msgstr[1] "Typ %qT des Templatearguments %qE hängt von Templateparametern ab"
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of %qT after instantiation of %qT"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "teilweise Spezialisierung von %qT hinter Instanziierung von %qT"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "kein Standard-Argument für %qD"
@@ -40847,43 +40897,43 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "Parameterpack %qE muss am Ende der Templateparameterliste sein"
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "Standardtemplateargumente dürfen in friend-Redeklaration eines Funktionstemplates nicht verwendet werden"
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr "Standardtemplateargumente dürfen in friend-Deklaration eines Funktionstemplates nicht verwendet werden"
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "Standardtemplateargumente dürfen in Funktionstemplates nicht ohne -std=c++11 und -std=gnu++11 verwendet werden"
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "Standardtemplateargumente dürfen in teilweiser Spezialisierung nicht verwendet werden"
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "Standardargument für Template-Parameter für %qD umschließende Klasse"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "Templateklasse ohne Namen"
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -40894,57 +40944,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "ungültige Templatedeklaration von %qD"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "Template-Definition eines Nicht-Templates %q#D"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d Ebenen von Template-Parametern für %q#D erwartet, %d erhalten"
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "%d Template-Parameter für %q#D erhalten"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%d Template-Parameter für %q#T erhalten"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  aber %d benötigt"
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "Template-Argumente für %qD passen nicht zum ursprünglichen Template %qD"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr "template<> für eine explizite Spezialisierung verwenden"
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT ist kein Template-Typ"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "keine Templatespezifizierer in Deklaration von %qD angegeben"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -40951,7 +41001,7 @@
 msgstr[0] "mit %d Template-Parameter redeklariert"
 msgstr[1] "mit %d Template-Parametern redeklariert"
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, gcc-internal-format
 msgid "previous declaration %q+D used %d template parameter"
 msgid_plural "previous declaration %q+D used %d template parameters"
@@ -40958,12 +41008,12 @@
 msgstr[0] "vorherige Deklaration %q+D verwendete %d Template-Parameter"
 msgstr[1] "vorherige Deklaration %q+D verwendete %d Template-Parameter"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "Template-Parameter %q+#D"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "hier als %q#D redeklariert"
@@ -40972,102 +41022,102 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "Redefinition des Standardarguments für %q#D"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "ursprüngliche Definition trat hier auf"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "es muss die Adresse einer Funktion mit externer Bindung sein"
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "es muss der Name einer Funktion mit externer Bindung sein"
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine Bindung hat"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine externe Bindung hat"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "es muss ein Zeiger auf ein Element der Form %<&X::Y%> sein"
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr " Template-Parameter %qD konnte nicht ermittelt werden"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr " Typen %qT und %qT haben unverträgliche CV-Qualifizierer"
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr " unpassende Typen %qT und %qT"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr " Templateparameter %qD ist kein Parameterpack wie Argument %qD"
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr " Templateargumente %qE passt nicht zum konstanten Zeiger auf Element %qE"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr " %qE entspricht nicht %qE"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr " unpassende Herleitung von Parameterpack mit %qT und %qT"
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr " hergeleitete Typen für Parameter %qT stehen in Konflikt (%qT und %qT)"
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr " hergeleitete Werte für Nicht-Typ-Parameter %qE stehen in Konflikt (%qE und %qE)"
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr " Feldtyp %qT mit veränderlicher Größe ist kein gültiges Templateargument"
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr " Typ %qT von Elementfunktion ist kein gültiges Templateargument"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -41076,173 +41126,173 @@
 msgstr[0] "  Kandidat erwartet %d Argument, %d angegeben"
 msgstr[1] "  Kandidat erwartet %d Argumente, %d angegeben"
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr " %qE (Typ %qT) kann nicht in den Typ %qT umgewandelt werden"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr " %qT ist mehrdeutige Basisklasse von %qT"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr " %qT ist nicht vom Typ %qT abgeleitet"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr " Templateparameter eines Template-Templatearguments sind mit anderen hergeleiteten Templateargumenten unverträglich"
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr " für %qT kann kein Template aus Nicht-Templatetyp %qT hergeleitet werden"
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qD"
 msgstr " Template-Argument %qE passt nicht zu %qD"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, gcc-internal-format
 msgid "  could not resolve address from overloaded function %qE"
 msgstr " Adresse von überladener Funktion %qE konnte nicht aufgelöst werden"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, da Zeichenkettensymbole in diesem Zusammenhang nicht verwendet werden können"
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, gcc-internal-format
 msgid "in template argument for type %qT "
 msgstr "in Templateargument für Typ %qT"
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD ist kein gültiges Templateargument, weil %qD eine Variable und nicht die Adresse einer Variable ist"
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD ist kein gültiges Templateargument, weil %qD eine Variable und nicht die Adresse einer Variable ist"
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qE keine Variable ist"
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE ist kein gültiges Templateargument des Typs %qT, weil %qD keine externe Bindung hat"
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine Bindung hat"
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, da es in CV-Qualifikation in Konflikt steht"
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es kein L-Wert ist"
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D ist kein gültiges Templateargument für Typ %qT, weil eine Referenzvariable keine konstante Adresse hat"
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es kein Objekt mit externer Bindung ist"
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil Objekt %qD keine externe Bindung hat"
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es ein Zeiger ist"
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "stattdessen %qE verwenden"
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es vom Typ %qT ist"
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "Standardumwandlungen sind in diesem Kontext nicht erlaubt"
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "Attribute an Templateargument %qT werden ignoriert"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "eingegebener Klassenname %qD als Template-Templateargument verwendet"
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ungültige Benutzung des Destruktors %qE als Typ"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "um auf ein Typelement eines Templateparameters zu verweisen, %<typename %E%> verwenden"
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "Typ/Wert des Arguments %d passt nicht in Template-Parameterliste für %qD"
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  Konstante des Typs %qT erwartet, %qT erhalten"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  Klassentemplate erwartet, %qE erhalten"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  einen Typ erwartet, %qE erhalten"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  einen Typ erwartet, %qT erhalten"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  Klassentemplate erwartet, %qT erhalten"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ein Template des Typs %qD erwartet, %qT erhalten"
@@ -41249,80 +41299,80 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "Typ passt nicht in Nichttypen-Parameterbündel"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr "Templateargument %qE konnte nicht in %qT umgewandelt werden"
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "Templateargument %d ist ungültig"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte %d sein)"
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte %d sein)"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "für %q+D bereitgestellt"
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "Standardargument für Template-Parameter für %qD umschließende Klasse"
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D ist kein Funktionstemplate"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "Nicht-Template-Typ %qT als Template verwendet"
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "Für Template-Deklaration %q+D"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum) substituting %qS"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d (-ftemplate-depth= verwenden, um dies zu erhöhen) bei Ersetzung von %qS"
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "Argumentpacklängen passen nicht bei Auflösung von %<%T%>"
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "Argumentpacklängen passen nicht bei Auflösung von %<%E%>"
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "  bei Instanziierung des Standardarguments für Aufruf von %D"
@@ -41340,272 +41390,272 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Variable %qD hat Funktionstyp"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ungültiger Parametertyp %qT"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "in Deklaration %q+D"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "Funktion gibt ein Feld zurück"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "Funktion gibt eine Funktion"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "Erzeugung eines Zeigers auf Elementfunktion des Nicht-Klassentyps %qT"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "Referenz auf »void« wird gebildet"
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "Zeiger auf Referenztyp %qT wird geformt"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "Referenz auf Referenztyp %qT wird geformt"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "Zeiger auf Element des Nicht-Klassentypen %qT wird erzeugt"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "Zeiger auf Elementreferenztyp %qT wird erzeugt"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "Zeiger auf Element mit Typ »void« wird erzeugt"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "Feld von %qT wird erzeugt"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ist kein Klassen-, Struktur- oder Union-Typ"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT wird in %qT aufgelöst, was kein Aufzählungstyp ist"
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT wird in %qT aufgelöst, was kein Klassentyp ist"
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "Verwendung von %qs in Template"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "qualifizierender Typ %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "Abhängigenname %qE wird als Nicht-Typ erkannt, aber die Instanziierung liefert einen Typ"
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "%<typename %E%> sagen, wenn ein Typ gemeint ist"
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ungültiges Feld %qD wird verwendet"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "falsche Benutzung eines Packauflösungs-Ausdruckes"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> verwenden, um Argumentpack aufzulösen"
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD wurde in diesem Gültigkeitsbereich nicht deklariert, und bei argumentabhängiger Suche am Ort der Instanziierung wurden keine Deklarationen gefunden"
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "Deklarationen in abhängiger Basis %qT wurden bei unqualifizierter Suche nicht gefunden"
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "stattdessen %<this->%D%> verwenden"
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "stattdessen %<%T::%D%> verwenden"
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, gcc-internal-format
 msgid "%q+D declared here, later in the translation unit"
 msgstr "%q+D hier deklariert, später in Übersetzungseinheit"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ist keine Klasse oder Namensbereich"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ist keine Klasse oder Namensbereich"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr "%qT ist/verwendet anonymen Typen"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Templateargument für %qD verwendet lokalen Typ %qT"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT ist ein variabel modifizierter Typ"
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "Ganzzahlausdruck %qE ist nicht konstant"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  Versuch, %qD zu instanziieren"
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "mehrdeutige Klassentemplate-Instanziierung für %q#T"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "mehrdeutige Klassentemplate-Instanziierung für %q#T"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 #| msgid "%s %#D"
 msgid "%s %#S"
 msgstr "%s %#D"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explizite Instanziierung des Nicht-Templates %q#D"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD ist kein statisches Datenelement eines Klassentemplates"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "kein passendes Template für %qD gefunden"
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "Typ %qT für explizite Instanziierung %qD passt nicht zum deklarierten Typ %qT"
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explizite Instanziierung von %q#D"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "doppelte explizite Instanziierung von %q#D"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO-C++ 1998 verbietet die Verwendung von %<extern%> bei expliziten Instanziierungen"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "Speicherklasse %qD auf Templateinstanziierung angewendet"
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explizite Instanziierung des Nicht-Klassen-Templates %qD"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explizite Instanziierung des Nicht-Templatetyps %qT"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explizite Instanziierung von %q#T vor Definition des Templates"
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO-C++ verbietet die Verwendung von %qE bei expliziten Instanziierungen"
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "doppelte explizite Instanziierung von %q#T"
@@ -41617,62 +41667,62 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explizite Instanziierung von %qD, aber keine Definition verfügbar"
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d (-ftemplate-depth= verwenden, um dies zu erhöhen) bei Instanziierung von %q+D, möglicherweise von Erzeugung der virtuellen Tabelle"
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ungültiger Nicht-Typ-Parameter für Template"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T ist kein gültiger Typ für einen Nicht-Typ-Parameter eines Templates"
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "Ermittlung aus geschweift geklammerter Initialisierungsliste erfordert #include <initializer_list>"
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Lambda-Rückgabewert von %qE kann nicht hergeleitet werden"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qT kann nicht aus %qE hergeleitet werden"
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "widersprüchliche Typen %qT und %qT für Lambda-Rückgabetypen hergeleitet"
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "widersprüchliche Herleitung für %qT: %qT und dann %qT"
@@ -41911,249 +41961,249 @@
 msgid "invalid base-class specification"
 msgstr "ungültige Spezifizierung der Basisklasse"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD ist nicht aufgefangen"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "Verwendung lokaler Variable mit automatischer Speicherklasse aus enthaltender Funktion"
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "Verwendung eines Parameters aus enthaltender Funktion"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "Templateparameter %qD vom Typ %qT ist in ganzzahligem Konstantenausdruck nicht erlaubt, da er nicht Ganzzahl- oder Aufzählungstyp hat"
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "Verwendung des Namensbereiches %qD als Ausdruck"
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "Verwendung des Klassentemplates %qT als Ausdruck"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "Abfrage des Elementes %qD ist im Gitter der Mehrfachvererbung mehrdeutig"
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD kann nicht in Konstanten-Ausdruck auftreten"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "Typ von %qE ist unbekannt"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT ist kein Aufzählungstyp"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Parameterpack __bases nur in Templatedeklaration gültig"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "%<offsetof%> kann nicht auf Destruktor %<~%T%> angewandt werden"
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "%<offsetof%> kann nicht auf Elementfunktion %qD angewandt werden"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "%qE hat ungültigen Typ für %<reduction%>"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD ist in Klausel %qs keine Variable"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD tritt in Datenklausel mehrfach auf"
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD ist in Klausel %<firstprivate%> keine Variable"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD ist in Klausel %<lastprivate%> keine Variable"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr "num_threads-Ausdruck muss bestimmt sein"
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "Plan-Teilgrößenausdruck muss bestimmt sein"
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%qs-Längenausdruck muss eine positive, konstante Ganzzahl sein"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_teams%> expression must be integral"
 msgstr "num_threads-Ausdruck muss bestimmt sein"
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "num_threads-Ausdruck muss bestimmt sein"
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads-Ausdruck muss bestimmt sein"
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<device%> id must be integral"
 msgstr "Scheibenende muss eine Ganzzahl sein"
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "Plan-Teilgrößenausdruck muss bestimmt sein"
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD ist in Klausel %qs keine Variable"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD tritt in Datenklausel mehrfach auf"
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "Plan-Teilgrößenausdruck muss bestimmt sein"
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD ist in Klausel %qs keine Variable"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr "%qE hat Referenztyp für %qs"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD ist nicht Datei-, Namens- oder Blockbereichsvariable"
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "Direktive %<threadprivate%> %qE nicht in Definition von %qT"
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "Unterschied zwischen %qE und %qD hat keinen Ganzzahltyp"
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp atomic update%> verwendet zwei unterschiedliche Variablen für Speicher"
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
@@ -42160,22 +42210,22 @@
 msgstr "%<#pragma omp atomic update%> verwendet zwei unterschiedliche Variablen für Speicher"
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "statische Erklärung gescheitert: %s"
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "Nicht-konstante Bedingung für statische Behauptung"
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "Argument für decltype muss ein Ausdruck sein"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype kann die Adresse der überladenen Funktion nicht auflösen"
@@ -42191,126 +42241,126 @@
 msgid "lambda-expression in a constant expression"
 msgstr "Ausdruck %qE ist kein konstanter Ausdruck"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "Attribut %qE kann nur auf Java-Klassendefinitionen angewendet werden"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "Attribut %qE kann nur auf Klassendefinitionen angewendet werden"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr "%qE ist veraltet; g++-vtables sind jetzt standardmäßig COM-verträglich"
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "angefordertes init_priority ist keine Ganzzahlkonstante"
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "nur Attribut %qE kann für Definitionen von Objekten eines Klassentyps im Datei-Gültigkeitsbereich verwendet werden"
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "angefordertes init_priority ist außerhalb des Wertebereiches"
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "angefordertes init_priority ist für interne Verwendung reserviert"
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "Attribut %qE wird auf dieser Plattform nicht unterstützt"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "Redeklaration von %qD fügt ABI-Marke %E hinzu"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "vorherige Deklaration hier"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "Attribut %qD erfordert ein einzelnes NTBS-Argument"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "Argument des Attributes %qE ist keine Zeichenkettenkonstante"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "Argument des Attributes %qE ist keine Zeichenkettenkonstante"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, fuzzy, gcc-internal-format
 #| msgid "%.*s is not a valid universal character"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "»%.*s« ist kein gültiges universelles Zeichen"
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> ist kein gültiger Deklarator"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "Attribut %qE auf Nicht-Klassen-, Nicht-Enum-Typ %qT angewendet"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "Attribut %qE auf %qT nach seiner Definition angewendet"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "auf %qT nach einer Definition angewandte Attribute werden ignoriert"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "auf %qT nach einer Definition angewandte Attribute werden ignoriert"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute applied to non-function %qD"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "Attribut %qE auf Nicht-Funktion %qD angewendet"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute applied to extern \"C\" function %qD"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "Attribut %qE auf »extern \"C\"«-Funktion %qD angewendet"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "Null als Null-Zeigerkonstante"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "Überprüfung von lang_*: in %s, bei %s:%d gescheitert"
@@ -42503,568 +42553,563 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr "Ausrichtung der Feldelemente ist größer als Elementgröße"
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr "ISO-C++ verbietet Indizierung eines Nicht-L-Wert-Feldes"
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "Indizierung eines als %<register%> deklarierten Feldes"
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indizierter Wert ist weder ein Feld noch ein Zeiger"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "bei Verwendung von %qE fehlt Objekt"
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO-C++ verbietet den Aufruf von %<::main%> vom Programm aus"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "%<.*%> oder %<->*%> muss verwendet werden, um Zeiger auf Element als Funktion in %<%E (...)%> aufzurufen, z.B. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "Ausdruck kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "zu viele Argumente für Konstruktor %q#D"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "zu wenige Argumente für Konstruktor %q#D"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "zu viele Argumente für Elementfunktion %q#D"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "Zu wenige Argumente für Elementfunktion %q#D"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "zu viele Argumente für Funktion %q#D"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "zu wenige Argumente für Funktion %q#D"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "zu viele Argumente für Methode %q#D"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "zu wenige Argumente für Methode %q#D"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "zu viele Argumente für Funktion"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "zu wenige Argumente für Funktion"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "Parameter %P von %qD hat unvollständigen Typen %qT"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "Parameter %P hat unvollständigen Typen %qT"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "Umwandlung in Typ %qT von überladener Funktion wird angenommen"
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL in Arithmetik verwendet"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "linker Rotationszähler ist negativ"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "rechter Rotationszähler ist negativ"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "linker Rotationszähler >= Breite des Typs"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "rechter Rotationszähler >= Breite des Typs"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr "Vergleich mit Zeichenkettenliteral führt zu undefiniertem Verhalten"
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "Die Adresse von %qD wird nie NULL sein"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO-C++ verbietet Vergleich zwischen Zeiger und Ganzzahl"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "Operandentypen sind %qT und %qT"
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, fuzzy, gcc-internal-format
 #| msgid "could not find interface for class %qE"
 msgid "could not find an integer type of the same size as %qT"
 msgstr "Schnittstelle für Klasse %qE kann nicht gefunden werden"
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "ungeordneter Vergleich mit Nicht-Gleitkomma-Argument"
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ungültige Operanden der Typen %qT und %qT für binäres %qO"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers des Typs %<void *%> in Subtraktion"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers auf eine Funktion in Subtraktion"
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers auf Methode in Subtraktion"
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ungültige Verwendung eines Zeigers auf einen unvollständigen Typen in Zeigerarithmetik"
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, gcc-internal-format
 msgid "taking address of constructor %qE"
 msgstr "Adresse des Konstruktors %qE wird genommen"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, gcc-internal-format
 msgid "taking address of destructor %qE"
 msgstr "Adresse des Destruktors %qE wird genommen"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ungültige Verwendung von %qE um Zeiger auf Elementfunktion zu erzeugen"
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  eine qualifizierte ID ist erforderlich"
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "Klammern um %qE können nicht verwendet werden, einen Zeiger auf Elementfunktion zu erzeugen"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse einer nicht qualifizierten oder geklammerten nicht-statischen Elementfunktion, um einen Zeiger auf Elementfunktion zu erzeugen. Stattdessen %<&%T::%D%> verwenden"
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse einer gebundenen Elementfunktion, um einen Zeiger auf Elementfunktion zu erzeugen. Stattdessen %<&%T::%D%> verwenden"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "Adresse eines temporären Wertes wird ermittelt"
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "Adresse eines X-Wertes (R-Wert-Referenz) wird genommen"
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse der Funktion %<::main%>"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse einer Umwandlung in einen Nicht-L-Wert-Ausdruck"
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "Zeiger auf Referenzelement %qD kann nicht erzeugt werden"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO-C++ verbietet erhöhen einer Aufzählung"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO-C++ verbietet verringern einer Aufzählung"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "Zeiger auf unvollständigen Typen %qT kann nicht erhöht werden"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "Zeiger auf unvollständigen Typen %qT kann nicht verringert werden"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO-C++ verbietet Erhöhen eines Zeigers vom Typ %qT"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO-C++ verbietet Verringern eines Zeigers vom Typ %qT"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "ungültige Verwendung eines booleschen Ausdrucks als Operand für %<operator--%>"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "Adresse von %<this%> kann nicht ermittelt werden, das ein R-Wert-Ausdruck ist"
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "Adresse der Register-Variablen %qD angefordert"
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "Adresse für %qD angefordert, was als %<register%> deklariert ist"
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "Listeninitialisierung für Nicht-Klassentyp darf nicht geklammert sein"
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in Initialisierung behandelt"
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in Speicherinitialisierung behandelt"
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in funktionaler Umwandlung behandelt"
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s Ausdrucksliste als zusammengesetzten Ausdruck behandelt"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "kein Kontext, um Typ von %qE aufzulösen"
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "Umwandlung des Typs %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast des Typs %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast des Typs %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, gcc-internal-format
 msgid "useless cast to type %qT"
 msgstr "nutzlose Umwandlung in Typ %qT"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "ungültiges static_cast vom Typ %qT in den Typ %qT"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "Umwandlung von %qT nach %qT"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "ungültige Typumwandlung eines R-Wert-Ausdrucks des Typs %qT in Typ %qT"
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr "Typumwandlung von %qT nach %qT verliert Genauigkeit"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "Umwandlung von %qT in %qT erhöht erforderliche Ausrichtung des Zieltyps"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO-C++ verbietet Umwandlung zwischen Zeiger auf Funktion und Zeiger auf Objekt"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ungültige Umwandlung von Typ %qT in Typ %qT"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ungültige Verwendung von const_cast mit Typ %qT, das weder Zeiger, Referenz, noch vom Typ eines Zeigers auf Datenelement ist"
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "ungültige Verwendung von const_cast mit Typ %qT, das ein Zeiger oder Referenz auf Funktionstyp ist"
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "ungültiges const_cast eines R-Wertes des Typs %qT in Typ %qT"
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "ungültiges const_cast von Typ %qT in Typ %qT"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO-C++ verbietet Umwandlung in Feldtyp %qT"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ungültige Umwandlung in Funktionstyp %qT"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  in Auswertung von %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "Zuweisung an Feld von Initialisierungsliste"
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "unverträgliche Typen in Zuweisung von %qT an %qT"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "Feld als Initialisierung verwendet"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Ungültiger Feldzuweisung"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   in Umwandlung in Zeiger auf Elementfunktion"
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "Umwandlung in Zeiger auf Element über virtuelle Basis %qT"
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   in Umwandlung in Zeiger auf Element"
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ungültige Umwandlung in Typ %qT von Typ %qT"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "%qT kann nicht nach %qT für Argument %qP nach %qD umgewandelt werden"
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "%qT kann nicht nach %qT im Standardargument umgewandelt werden"
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "%qT kann nicht nach %qT bei Argumentübergabe umgewandelt werden"
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "%qT kann nicht nach %qT umgewandelt werden"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "%qT kann nicht nach %qT in Initialisierung umgewandelt werden"
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "%qT kann nicht nach %qT in Rückgabe umgewandelt werden"
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "%qT kann nicht nach %qT in Zuweisung umgewandelt werden"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "Rückgabetyp %q#T ist unvollständig"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "Parameter %qP von %qD könnte Kandidat für Formatattribut sein"
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "Parameter könnte ein Kandidat für ein Formatattribut sein"
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Ziel der Umwandlung könnte Kandidat ein für ein Formatattribut sein"
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "Ziel der Initialisierung könnte ein Kandidat für Formatattribut sein"
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "linke Seite der Zuweisung könnte ein Kandidat für ein Formatattribut sein"
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "bei Übergabe des Arguments %P von %q+D"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "Referenz auf temporären Wert wird zurückgegeben"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "Referenz auf Nicht-L-Wert zurückgegeben"
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr "Referenz auf lokale Variable %q+D zurückgegeben"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %q+D returned"
 msgstr "Adresse der lokalen Variable %q+D zurückgegeben"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr "Adresse der lokalen Variable %q+D zurückgegeben"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "Wert von Destruktor zurückgegeben"
@@ -43071,45 +43116,45 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "vom Behandler eines Funktions-try-Blocks eines Konstruktors kann nicht zurückgekehrt werden"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "Rückgabe eines Wertes von einem Konstruktor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "Return-Anweisung ohne Wert, in %qT zurückgebender Funktion"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "Initialisierungsliste wird zurückgegeben"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "Return-Anweisung mit Wert in »void« zurückgebender Funktion"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> darf nicht NULL zurückgeben, außer es ist mit %<throw()%> deklariert (oder -fcheck-new ist eingeschaltet)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "temporärer Wert wird als L-Wert verwendet"
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "X-Wert (R-Wert-Referenz) wird als L-Wert verwendet"
@@ -43344,125 +43389,125 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr "verengende Umwandlung von %qE von %qT nach %qT in { } ist in C++11 ungültig"
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "verengende Umwandlung von %qE von %qT nach %qT in { }"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-Feld mit Nicht-wide-Zeichenkette initialisiert"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "Ganzzahlfeld mit unverträglicher wide-Zeichenkette initialisiert"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "Initialisierungs-Zeichenkette für char-Feld ist zu lang"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "Aggregat des Typs %qT kann nicht mit zusammengesetztem Literal initialisiert werden"
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "Feld muss mit Initialisierung mit umgebenden geschweiften Klammern initialisiert werden"
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "Initialisierung für Element %qD fehlt"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "Element %qD ist nicht initialisierte Referenz"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "Element %qD ist nicht initialisierte Referenz"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "kein Feld %qD in initialisierter Union gefunden"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "Indexwert statt Feldname in Union-Initialisierung"
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "ringförmige Zeigerdelegation erkannt"
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "Basisoperand von %<->%> hat Nicht-Zeiger-Typ %qT"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "Ergebnis von %<operator->()%> ergibt Nicht-Zeiger-Ergebnis"
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "Basisoperand von %<->%> ist kein Zeiger"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kann nicht als Elementzeiger verwendet werden, da es vom Typ %qT ist"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "Elementzeiger %qE kann nicht auf %qE angewandt werden, da letzteres vom Nicht-Klassen-Typ %qT ist"
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "Zeiger auf Elementtyp %qT mit Objekttyp %qT inkompatibel"
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "Zeiger auf Elementfunktion in Arithmetik verwendet"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "Zeiger auf Elementfunktion in Arithmetik verwendet"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionale Umwandlung in Feldtyp %qT"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ungültige Wert-Initialisierung von Referenztyp"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "Aufruf der Funktion %qD, die unvollständigen Typen %q#T wirft"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "Aufruf einer Funktion, die unvollständigen Typen %q#T wirft"
@@ -43648,8 +43693,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, fuzzy, gcc-internal-format
 #| msgid "Coarrays disabled at %C, use -fcoarray= to enable"
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
@@ -43790,7 +43835,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr "Feldkonstruktor mit Typspezifikation bei %C"
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Typspezifikation bei %L kann keine Parameter mit aufgeschobenem Typ haben"
@@ -43913,7 +43958,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "Argument »%s« für intrinsisches »%s« bei %L muss INTEGER oder PROCEDURE sein"
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -44581,13 +44626,13 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "Argument »source« des intrinsischen »shape« bei %L darf kein Feld impliziter Größe sein"
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L may not be a procedure"
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "Argument »%s« des intrinsischen »%s« bei %L darf keine Prozedur"
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
@@ -44897,6 +44942,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "Argument »%s« für intrinsisches »%s« bei %L muss INTEGER oder LOGICAL sein"
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -44904,7 +44954,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, fuzzy, gcc-internal-format
 #| msgid "Maximum extension level reached with type '%s' at %L"
 msgid "Maximum extension level reached with type %qs at %L"
@@ -45145,415 +45195,415 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Variable »%s« bei %C mit Initialisierung tritt bereits in einer DATA-Anweisung auf"
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "Feld mit implizierter Form bei %L kann nicht mit Skalar initialisiert werden"
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Nicht-konstante untere Grenze in Deklaration mit impliziter Form bei %L"
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Komponente bei %C muss ein POINTER-Attribut haben"
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Feldkomponente der Struktur bei %C muss explizite oder aufgeschobene Form haben"
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Zeigerfeld-Komponente der Struktur bei %C muss eine aufgeschobene Form haben"
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Allozierbare Komponente der Struktur bei %C muss eine aufgeschobene Form haben"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Feldkomponente der Struktur bei %C muss eine explizite Form haben"
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL()-Initialisierung bei %C ist mehrdeutig"
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "NULL()-Initialisierung bei %C könnte kein MOLD haben"
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Initialisierung des Zeigers bei %C ist nicht in einer PURE-Prozedur erlaubt"
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Fehler in Zeigerinitialisierung bei %C"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Nicht-NULL-Zeigerinitialisierung bei %C"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "Function name %qs not allowed at %C"
 msgstr "Funktionsname »%s« nicht erlaubt bei %C"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, fuzzy, gcc-internal-format
 #| msgid "Non-PARAMETER symbol '%s' at %L can't be implied-shape"
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr "Nicht-PARAMETER-Symbol »%s« bei %L kann nicht implizite Form haben"
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Feld mit impliziter Form bei %L"
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Doppelte Feldspezifikation für Cray-Zeigerende bei %C"
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Initialisierung im alten Stil bei %C"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid value-initialization of reference type"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "ungültige Wert-Initialisierung von Referenztyp"
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Initialisierung bei %C ist nicht für eine Zeigervariable"
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Zeigerinitialisierung bei %C benötigt »=>«, nicht »=«"
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Initialisierungsausdruck bei %C erwartet"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Initialisierung einer Variablen bei %C ist in einer PURE-Prozedur nicht erlaubt"
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Initialisierung einer allozierbaren Komponente bei %C ist nicht erlaubt"
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Deklaration %s*%d im alten Stil wird bei %C nicht unterstützt"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Nicht-Standard Typ-Deklaration %s*%d bei %C"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Fehlende rechte Klammer bei %C"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Initialisierungsausdruck bei %C erwartet"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Skalaren Initialisierungsausdruck bei %C erwartet"
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Die Art %d wird für Typ %s bei %C nicht unterstützt"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Typ-Parameter nach C-Art ist für Typ %s, aber Typ bei %L ist %s"
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Fehlende rechte Klammer oder Komma bei %C"
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Die Art %d wird für CHARACTER bei %C nicht unterstützt"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Syntaxfehler in CHARACTER-Deklaration bei %C"
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "BYTE-Typ bei %C"
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "Bei %C verwendeter BYTE-Typ ist auf der Zielmaschine nicht verfügbar"
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Vermuteter Typ bei %C ist für Komponenten nicht erlaubt"
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Vermuteter Typ bei %C"
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "TYPE mit intrinsischer Typspezifikation bei %C"
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "DOUBLE COMPLEX bei %C"
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "CLASS-Anweisung bei %C"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Typname »%s« bei %C ist mehrdeutig"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "Typname »%s« bei %C in Konflikt mit vorher deklarierter Entität bei %L, die den gleichen Namen hat"
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Doppelte IMPLICIT NONE-Anweisung bei %C"
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Fehlender Zeichenbereich in IMPLICIT bei %C"
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Buchstaben in IMPLICIT-Anweisung bei %C müssen in alphabetischer Reihenfolge sein"
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "SAVE-Anweisung bei %C folgt umfassender SAVE-Anweisung"
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Leere IMPLICIT-Anweisung bei %C"
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "IMPORT-Anweisung bei %C ist nur in einem INTERFACE-Körper erlaubt"
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "IMPORT-Anweisung bei %C"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Liste benannter Einträge bei %C erwartet"
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot IMPORT '%s' from host scoping unit at %C - does not exist."
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "IMPORT »%s« aus Host-Sichtbarkeitseinheit bei %C nicht möglich - existiert nicht."
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is already IMPORTed from host scoping unit at %C."
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "»%s« bereits aus Host-Sichtbarkeitseinheit bei %C IMPORTiert."
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Syntaxfehler in IMPORT-Anweisung bei %C"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Fehlende Kodimensionsangabe bei %C"
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Fehlende Dimensionsangabe bei %C"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Doppeltes Attribut %s bei %L"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Attribut ALLOCATABLE bei %C in einer TYPE-Definition"
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Attribut bei %L ist in TYPE-Definition nicht erlaubt"
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attribut %s bei %L in einer TYPE-Definition"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "Attribut %s bei %L ist außerhalb des Spezifikationsabschnitts eines Moduls nicht erlaubt"
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "ASYNCHRONOUS-Attribut bei %C"
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "CONTIGUOUS-Attribut bei %C"
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED bei %C nur in Spezifikationsabschnitts eines Moduls erlaubt"
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "PROTECTED-Attribut bei %C"
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "VALUE-Attribut bei %C"
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "VOLATILE-Attribut bei %C"
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Mehrere Bezeichner mit einzelner Spezifikation NAME= bei %C angegeben"
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly declared BIND(C) function '%s' at %L may not be C interoperable"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "Spezifikationsfunktion »%s« bei %L kann keine interne Funktion sein"
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L may not be a C interoperable kind though common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Variable »%s« in gemeinsamem Block »%s« bei %L könnte inkompatibel mit C sein, obwohl gemeinsamer Block »%s« BIND(C) ist"
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, fuzzy, gcc-internal-format
 #| msgid "Type declaration '%s' at %L is not C interoperable but it is BIND(C)"
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Typdeklaration »%s« bei %L ist nicht C-kompatibel, aber sie ist BIND(C)"
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L may not be a C interoperable kind but it is bind(c)"
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Variable »%s« bei %L könnte mit C inkompatibel sein, aber sie ist BIND(C)"
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L cannot be declared with BIND(C) since it is not a global"
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Variable »%s« in gemeinsamem Block »%s« bei %L kann nicht mit BIND(C) deklariert werden da sie nicht global ist"
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Variable »%s« bei %L kann nicht gleichzeitig die Attribute POINTER und BIND(C) haben"
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Variable »%s« bei %L kann nicht gleichzeitig die Attribute ALLOCATABLE und BIND(C) haben"
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Rückgabetyp der BIND(C)-Funktion »%s« bei %L kann kein Feld sein"
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -45561,834 +45611,840 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is marked PRIVATE but has been given the binding label '%s'"
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Symbol »%s« bei %L ist als PRIVATE markiert, aber wurde mit Bindung »%s« markiert"
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Entweder Eintrag oder gemeinsamer Blockname für Attribut-Spezifikationsanweisung bei %C erforderlich"
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Eintrag oder gemeinsamer Blockname für Attribut-Spezifikationsanweisung bei %C fehlt"
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "Missing name"
 msgid "Missing symbol"
 msgstr "Fehlender Name"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SYNC statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "SYNC-Anweisung bei %C"
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Abgeleiteter Typ bei %C wurde vorher nicht definiert und kann daher nicht in einer abgeleiteten Typdefinition auftreten"
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Syntaxfehler in Daten-Deklaration bei %C"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "IMPURE-Prozedur bei %C"
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE und IMPURE dürfen bei %C nicht gleichzeitig stehen"
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Alternative Rücksprungmarke bei %C erwartet"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Name »%s« bei %C ist der Name der Prozedur"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Unerwartete Angaben in formaler Argumentliste bei %C"
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Doppeltes Symbol »%s« in formaler Argumentliste bei %C"
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT-Variable bei %C muss vom Funktionsnamen verschieden sein"
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Unerwartete Angaben hinter Funktionsdeklaration bei %C"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "BIND(C)-Attribut bei %L kann nicht für eine interne Prozedur angegeben werden"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "BIND(C)-Attribut bei %C erfordert eine Schnittstelle mit BIND(C)"
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "BIND(C)-Prozedur mit NAME darf kein POINTER-Attribut bei %C haben"
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Scheinprozedur bei %C kann kein BIND(C)-Attribut mit NAME haben"
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Prozedur »%s« bei %L hat bereits grundlegenden Typen %s"
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Syntaxfehler in PROCEDURE-Anweisung bei %C"
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "»::« nach Bindeattributen bei %C erwartet"
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS oder explizite Schnittstelle bei %C erforderlich"
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Prozedurzeiger-Komponente bei %C"
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Syntaxfehler in Prozedurzeiger-Komponente bei %C"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE bei %C muss in einer allgemeinen Schnittstelle sein"
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "»::« in MODULE PROCEDURE-Anweisung bei %L"
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "PROCEDURE-Anweisung bei %C"
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Formale Argumentliste in Funktionsdefinition bei %C erwartet"
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "BIND(C)-Attribut bei %L kann nur für Variablen oder gemeinsame Blöcke verwendet werden"
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "ENTRY-Anweisung bei %C"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines PROGRAMmes auftreten"
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines MODULEs auftreten"
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb von BLOCK DATA auftreten"
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb von INTERFACE auftreten"
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines DERIVED TYPE Blockes auftreten"
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines IF-THEN-Blockes auftreten"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines DO-Blockes auftreten"
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines SELECT-Blockes auftreten"
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines FORALL-Blockes auftreten"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines WHERE-Blockes auftreten"
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines enthaltenen Subprogrammes auftreten"
 
-#: fortran/decl.c:5597
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
-msgid "gfc_match_entry(): Bad state"
-msgstr "gfc_trans_code(): Falscher Anweisungscode"
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Unexpected END statement at %C"
+msgid "Unexpected ENTRY statement at %C"
+msgstr "Unerwartete END-Anweisung bei %C"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "ENTRY-Anweisung bei %C kann nicht in einer enthaltenen Prozedur auftreten"
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Erforderte Klammern vor BIND(C) bei %C fehlen"
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid C name in NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Ungültiger C-Name in NAME=-Spezifizierung bei %C"
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Syntaxfehler in NAME=-Spezifikation für Bindungsmarke bei %C"
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Spezifikation ASYNCHRONOUS= bei %L muss ein Initialisierungsausdruck sein"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Schließende Klammer für Bindungsmarke bei %C fehlt"
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "In BIND(C) bei %C ist kein bindender Name erlaubt"
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "For Schein-Prozedur %s in BIND(C) bei %C ist kein bindender Name erlaubt"
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME nicht erlaubt bei BIND(C) für ABSTRACT INTERFACE bei %C"
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Unerwartete END-Anweisung bei %C"
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "END-Anweisung statt %s-Anweisung bei %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-Anweisung bei %L erwartet"
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "%s-Anweisung bei %C erwartet"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Blocknamen von »%s« in %s-Anweisung bei %C erwartet"
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Beendenden Namen bei %C erwartet"
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Marke »%s« für %s-Anweisung bei %C erwartet"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Fehlende Feldspezifikation bei %L in DIMENSION-Anweisung"
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr "Für %s bei %L wurden Dimensionen nach dessen Initialisierung angegeben"
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Feldspezifikation bei %L in CODIMENSION-Anweisung fehlt"
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Feldspezifikation muss bei %L aufgeschoben werden"
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Unerwartetes Zeichen in Variablenliste bei %C"
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "»(« bei %C erwartet"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Variablennamen bei %C erwartet"
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray-Zeiger bei %C muss eine Ganzzahl sein"
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray-Zeiger bei %C hat %d Bytes Genauigkeit; Speicheradressen benötigen %d Bytes"
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "»,« bei %C erwartet"
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "»)« bei %C erwartet"
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "»,« oder Ende der Anweisung bei %C erwartet"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT ist in BLOCK bei %C nicht erlaubt"
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL ist in BLOCK bei %C nicht erlaubt"
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Cray-Zeiger-Deklaration bei %C benötigt den Schalter -fcray-pointer"
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "CONTIGUOUS-Anweisung bei %C"
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Zugriffsspezifikation des Operators %s bei %C wurde bereits spezifiziert"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Zugriffsspezifikation des Operators .%s. bei %C wurde bereits spezifiziert"
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "PROTECTED-Anweisung bei %C"
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaxfehler in PROTECTED-Anweisung bei %C"
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PRIVATE-Anweisung bei %C ist nur in Spezifikationsteil eines Moduls erlaubt"
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PUBLIC-Anweisung bei %C ist nur in Spezifikationsteil eines Moduls erlaubt"
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Variablennamen bei %C in PARAMETER-Anweisung erwartet"
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Zeichen »=« in PARAMETER-Anweisung bei %C erwartet"
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Ausdruck bei %C in PARAMETER-Anweisung erwartet"
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initialisierung einer bereits initialisierten Variablen bei %C"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Unerwartete Zeichen in PARAMETER-Anweisung bei %C"
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Umfassende SAVE-Anweisung bei %C folgt vorheriger SAVE-Anweisung"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "SAVE-Anweisung bei %C folgt umfassender SAVE-Anweisung"
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Syntaxfehler in SAVE-Anweisung bei %C"
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE ist in BLOCK bei %C nicht erlaubt"
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "VALUE-Anweisung bei %C"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Syntaxfehler in VALUE-Anweisung bei %C"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "VOLATILE-Anweisung bei %C"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, fuzzy, gcc-internal-format
 #| msgid "Specifying VOLATILE for coarray variable '%s' at %C, which is use-/host-associated"
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "VOLATILE für Coarray-Variable »%s« bei »%C« angegeben, die use-/host-assoziiert ist"
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Syntaxfehler in VOLATILE-Anweisung bei %C"
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "ASYNCHRONOUS-Anweisung bei %C"
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Syntaxfehler in ASYNCHRONOUS-Anweisung bei %C"
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE bei %C muss in einer generischen Modulschnittstelle sein"
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Intrinsische Prozedur bei %L kann keine MODULE PROCEDURE sein"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Mehrdeutiges Symbol in TYPE-Definition bei %C"
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Symbol »%s« bei %C wurde bereits mit Host verbunden"
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in EXTENDS expression at %C is not a derived type"
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "»%s« in EXTENDS-Ausdruck bei %C ist kein abgeleiteter Typ"
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is BIND(C)"
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "»%s« kann bei %C nicht erweitert werden, da es BIND(C) ist"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is a SEQUENCE type"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "»%s« kann bei %C nicht erweitert werden, da es ein SEQUENCE-Typ ist"
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Abgeleiteter Typ bei %C kann nur PRIVATE im Spezifikationsteil eines Moduls sein"
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Abgeleiteter Typ bei %C kann nur PUBLIC im Spezifikationsteil eines Moduls sein"
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "ABSTRACT-Typ bei %C"
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "»::« in TYPE-Definition bei %C erwartet"
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typname »%s« bei %C kann nicht der gleiche wie ein intrinsischer Typ sein"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Abgeleiteter Typname bei »%s« bei %C hat bereits einen Basistypen von %s"
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Abgeleitete Typdefinition von »%s« bei %C wurde bereits definiert"
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray-Zeigerende bei %C kann nicht Feld mit impliziter Form sein"
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM und ENUMERATOR bei %C"
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Zähler übersteigt den C-Ganzzahltyp bei %C"
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L nicht mit Ganzzahlausdruck initialisiert"
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Anweisung zur ENUM-Definition vor %C erwartet"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Syntaxfehler in ENUMERATOR-Definition bei %C"
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Doppelte Zugriffsspezifikation bei %C"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Bindeattribute legen bereits Durchleitung fest, unzulässiges NOPASS bei %C"
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Bindeattribute legen bereits Durchleitung fest, unzulässiges PASS bei %C"
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Doppeltes POINTER-Attribut bei %C"
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Doppeltes NON_OVERRIDABLE bei %C"
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Doppeltes DEFERRED bei %C"
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Zugriffsspezifikation bei %C erwartet"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Bindeattribut bei %C erwartet"
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE und DEFERRED können nicht gleichzeitig bei %C auftreten"
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "POINTER-Attribut ist für Prozedurzeiger-Komponente bei %C erforderlich"
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, fuzzy, gcc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Schnittstellenname nach »(« bei %C erforderlich"
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected at %C"
 msgid "%<)%> expected at %C"
 msgstr "»)« bei %C erwartet"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Schnittstelle muss für DEFERRED-Bindung bei %C angegeben werden"
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(Schnittstelle) bei %C sollte als DEFERRED deklariert sein"
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Bindungsname bei %C erwartet"
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "PROCEDURE-Liste bei %C"
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format
 #| msgid "'=> target' is invalid for DEFERRED binding at %C"
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "»=> target« ist ungültig für DEFERRED-Bindung bei %C"
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, fuzzy, gcc-internal-format
 #| msgid "'::' needed in PROCEDURE binding with explicit target at %C"
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "»::« in PROCEDURE-Bindung mit explizitem Ziel bei %C erforderlich"
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Bindungsziel hinter »=>« bei %C erforderlich"
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' containing DEFERRED binding at %C is not ABSTRACT"
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "Typ »%s« mit DEFERRED-Bindung bei %C ist nicht ABSTRACT"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, fuzzy, gcc-internal-format
 #| msgid "There is already a procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Es gibt bereits eine Prozedur mit Bindungsname »%s« für den abgeleiteten Typ »%s« bei %C"
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC bei %C muss innerhalb eines CONTAINS eines abgeleiteten Typs sein"
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "»::« bei %C erwartet"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Generischer Name oder Operatordeskriptor bei %C erwartet"
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY statement at %C"
+msgid "Malformed GENERIC statement at %C"
+msgstr "ENTRY-Anweisung bei %C"
+
+#: fortran/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '=>' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "»=>« bei %C erwartet"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a non-generic procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Es gibt bereits eine nicht-generische Prozedur mit Bindungsname »%s« für den abgeleiteten Typ »%s« bei %C"
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, fuzzy, gcc-internal-format
 #| msgid "Binding at %C must have the same access as already defined binding '%s'"
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Bindung bei %C muss den selben Zugriff wie bereits definierte Bindung »%s« haben"
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Spezifischer Bindungsname bei %C erwartet"
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' already defined as specific binding for the generic '%s' at %C"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "»%s« bereits als spezifische Bindung für das allgemeine »%s« bei %C definiert"
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Ausschuss hinter GENERIC-Bindung bei %C"
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "FINAL-Deklaration bei %C muss innerhalb eines CONTAINS-Abschnitts eines abgeleiteten Typs stehen"
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Deklaration abgeleiteten Typs mit FINAL bei %C muss im Spezifikationsteil eines Moduls sein"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Leeres FINAL bei %C"
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Prozedurname im Modul bei %C erwartet"
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "»,« bei %C erwartet"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "Unbekannter Prozedurname »%s« bei %C"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is already defined as FINAL procedure!"
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "»%s« bei %C ist bereits als FINAL-Prozedur definiert!"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Unbekanntes Attribut in !GCC$ ATTRIBUTES-Anweisung bei %C"
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Syntaxfehler in !GCC$ ATTRIBUTES-Anweisung bei %C"
@@ -46693,371 +46749,371 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "andere Form für %s bei %L für Dimension %d (%d und %d)"
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a VALUE"
 msgid "%qs at %L is not a VALUE"
 msgstr "'%s' bei %L ist kein WERT"
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Unverträgliche Ränge %d und %d in Zuweisung bei %L"
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "Unbekannter Variablentyp in Zuweisung bei %L"
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "Auf rechter Seite in Zuweisung bei %L tritt NULL auf"
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "POINTER-wertige Funktion tritt auf rechter Seite der Zuweisung bei %L auf"
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, fuzzy, gcc-internal-format
 #| msgid "BOZ literal at %L used to initialize non-integer variable '%s'"
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "BOZ-Literal bei %L verwendet, um Nicht-Ganzzahlvariable »%s« zu initialisieren"
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "BOZ-Literal bei %L außerhalb einer DATA-Anweisung und außerhalb von INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, fuzzy, gcc-internal-format
 #| msgid "BOZ literal at %L is bitwise transferred non-integer symbol '%s'"
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "BOZ-Literal bei %L ist bitweise übertragenes Nicht-Ganzzahlsymbol »%s«"
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetischer Unterlauf des bitweise übertragenen BOZ bei %L. Diese Überprüfung kann mit der Option -fno-range-check ausgeschaltet werden"
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetischer Überlauf des bitweise übertragenen BOZ bei %L. Diese Überprüfung kann mit der Option -fno-range-check ausgeschaltet werden"
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetisches NaN des bitweise übertragenen BOZ bei %L. Diese Überprüfung kann mit der Option -fno-range-check ausgeschaltet werden"
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from  %s to %s at %L"
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "Wertänderung bei Umwandlung von %s in %s bei %L"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 #| msgid "Possible change of value in conversion from %s to %s at %L"
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "Mögliche Wertänderung bei Umwandlung von %s in %s bei %L"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Conversion from %qs to %qs at %L"
 msgstr "Umwandlung von %s in %s bei %L"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Unverträgliche Typen in DATA-Anweisung bei %L; versuchte Umwandlung von %s an %s"
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Zeiger-Zuweisungsziel ist kein POINTER bei %L"
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "»%s« in Zeigerzuweisung bei %L kann kein L-Wert sein, da es eine Prozedur ist"
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "Expected bounds specification for '%s' at %L"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Grenzen für »%s« bei %L erwartet"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, fuzzy, gcc-internal-format
 #| msgid "Bounds specification for '%s' in pointer assignment at %L"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Grenzenangabe für »%s« in Zeigerzuweisung bei %L"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr "Bei %L muss untere Grenze vorhanden sein"
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Bei %L darf kein Schritt vorhanden sein"
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr "Bei %L müssen entweder alle oberen Grenzen oder keine obere Grenze angegeben werden"
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Zeigerobjekt bei %L sollte keinen Koindex haben"
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Ungültige Zuweisung eines Prozedurzeigers bei %L"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' is invalid as proc-target in procedure pointer assignment at %L"
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Funktionsergebnis »%s« ist als Prozedurziel in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Abstrakte Schnittstelle »%s« ist in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Anweisungsfunktion »%s« ist in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Interne Prozedur »%s« ist in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is invalid in procedure pointer assignment"
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Eingebautes »%s« ist in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, fuzzy, gcc-internal-format
 #| msgid "Nonintrinsic elemental procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Nichtintrinsische elementare Prozedur »%s« ist in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "Unpassende Zuweisung des Prozedurzeigers bei %L: Unpassende Aufrufkonvention"
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, fuzzy, gcc-internal-format
 #| msgid "NOPASS or explicit interface required at %C"
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "NOPASS oder explizite Schnittstelle bei %C erforderlich"
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Unpassende Schnittstellen bei Zuweisung des Prozedurzeigers bei %L: %s"
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr "Datenzeigerobjekt &L muss unbegrenzt polymorph sein, von Sequenz abgeleiteten Typ oder Typ mit Zuweisung eines BIND-Attributs bei %L haben, um zum unbegrenzt polymorphen Ziel zu passen"
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Verschiedene Typen in Zeigerzuweisung bei %L; Versuch der Zuweisung von %s an %s"
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Parameter verschiedener Typen in Zeigerzuweisung bei %L"
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Verschiedene Ränge in Zeigerzuweisung bei %L"
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "Ziel der Rang-Neuzuordnung ist kleiner als die Größe des Zeigers (%ld < %ld) bei %L"
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "Ziel der Rang-Neuzuordnung muss Rang 1 oder einfach fortlaufend bei %L sein"
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Ziel der Rang-Neuzuordnung ist nicht Rang 1 bei %L"
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Zielausdruck in Zeigerzuweisung bei %L muss ein Zeigerergebnis liefern"
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Zeiger-Zuweisungsziel bei %L ist weder TARGET noch POINTER"
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Falsches Ziel in Zeigerzuweisung in PURE-Prozedur bei %L"
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Zeigerzuweisung mit Vektorindex für rhs bei %L"
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Zeiger-Zuweisungsziel hat PROTECTED-Attribut bei %L"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "Datenziel bei %L sollte keinen Koindex haben"
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Zeiger bei %L in Zeigerzuweisung könnte Zeigerziel überdauern"
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Ziel der Zeigerinitialisierung bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Ziel der Zeigerinitialisierung bei %L muss das TARGET-Attribut haben"
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Ziel der Zeigerinitialisierung bei %L muss das SAVE-Attribut haben"
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Ziel der Zeigerinitialisierung für Prozedur bei %L darf kein Prozedurzeiger sein"
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Zeigerfunktionen in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Nicht-variabler Ausdruck in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' in variable definition context (%s) at %L"
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Benannte Konstante »%s« in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in variable definition context (%s) at %L is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "»%s« in Variablen-Definitionskontext (%s) bei %L ist keine Variable"
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Nicht-POINTER in Zeiger-Verbindungskontext (%s) bei %L"
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in pointer association context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Scheinargument »%s« mit INTENT(IN) in Zeiger-Verbindungskontext (%s) bei %L"
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in variable definition context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Scheinargument »%s« mit INTENT(IN) in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Variable »%s« ist PROTECTED und kann nicht in Zeiger-Verbindungskontext (%s) bei %L auftreten"
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "Variable »%s« ist PROTECTED und kann nicht in Variablen-Definitionskontext (%s) bei %L auftreten"
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variable »%s« kann nicht in Variablen-Definitionskontext (%s) bei %L in PURE-Prozedur auftreten"
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "»%s« ist bei %L mit vektorindiziertem Ziel verbunden und kann nicht in Variablen-Definitionskontext (%s) verwendet werden"
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "»%s« ist bei %L mit Ausdruck verbunden und kann nicht in Variablen-Definitionskontext (%s) verwendet werden"
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Verbundener Name »%s« kann nicht in Variablen-Definitionskontext (%s) bei %L auftreten, da sein Ziel bei %L es auch nicht kann"
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "»%s« ist bei %L mit Ausdruck verbunden und kann nicht in Variablen-Definitionskontext (%s) verwendet werden"
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "Eingabedatei »%s« kann nicht geöffnet werden"
@@ -47080,28 +47136,28 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Aufruf von Funktion »%s« bei %L wird entfernt"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "illegal OP in optimize_comparison"
 msgstr "ungültige Operanden in GIMPLE-Vergleich"
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr "Variable »%s« bei %L auf undefinierten Wert innerhalb der bei %L beginnenden Schleife gesetzt, als INTENT(OUT)-Argument für Unterprogramm »%s«"
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr "Variable »%s« bei %L kann nicht innerhalb der bei %L beginnenden Schleife als INTENT(INOUT)-Argument für Unterprogramm »%s« definiert werden"
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr "Variable »%s« bei %L auf undefinierten Wert innerhalb der bei %L beginnenden Schleife gesetzt, als INTENT(OUT)-Argument für Funktion »%s«"
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr "Variable »%s« bei %L kann nicht innerhalb der bei %L beginnenden Schleife als INTENT(INOUT)-Argument für Funktion »%s« definiert werden"
@@ -47158,676 +47214,682 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr "»END INTERFACE ASSIGNMENT (=)« bei %C erwartet"
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, fuzzy, gcc-internal-format
+#| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr "»END INTERFACE OPERATOR (.%s.)« bei %C erwartet"
+
+#: fortran/interface.c:353
+#, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (%s)' at %C, but got %s"
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr "»END INTERFACE OPERATOR (%s)« bei %C erwartet, aber %s erhalten"
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr "»END INTERFACE OPERATOR (.%s.)« bei %C erwartet"
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE %s' at %C"
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr "»END INTERFACE %s« bei %C erwartet"
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr "Alternative Rückgabe kann nicht in Operatorschnittstelle bei %L auftreten"
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr "Schnittstelle des Zuweisungsoperators bei %L muss zwei Argumente haben"
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr "Operatorschnittstelle bei %L hat falsche Argumentanzahl"
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr "Schnittstelle für Zuweisungsoperator bei %L muss eine SUBROUTINE sein"
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr "Schnittstelle des Zuweisungsoperators bei %L darf keine INTRINSIC Typzuweisung redefinieren"
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr "Schnittstelle des intrinsischen Operators bei %L muss eine FUNCTION sein"
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr "Erstes Argument der definierten Zuweisung bei %L muss INTENT(OUT) oder INTENT(INOUT) sein"
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Zweites Argument der definierten Zuweisung bei %L muss INTENT(IN)"
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr "Operatorschnittstelle bei %L steht mit intrinsischer Schnittstelle in Konflikt"
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr "Prozedur »%s« in %s bei %L hat keine explizite Schnittstelle"
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr "Prozedur »%s« in %s bei %L ist weder Funktion noch Subroutine"
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr "In %s bei %L müssen alle Prozeduren entweder SUBROUTINE oder FUNCTION sein"
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr "In %s bei %L müssen alle Prozeduren auch FUNCTIONs sein, da der allgemeine Name auch der Name des abgeleiteten Typs ist"
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' in %s at %L"
 msgid "Internal procedure %qs in %s at %L"
 msgstr "Interne Prozedur »%s« in %s bei %L"
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, fuzzy, gcc-internal-format
 #| msgid "Ambiguous interfaces '%s' and '%s' in %s at %L"
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr "Mehrdeutige Schnittstellen »%s« und »%s« in %s bei %L"
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, fuzzy, gcc-internal-format
 #| msgid "Although not referenced, '%s' has ambiguous interfaces at %L"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "Obwohl nicht referenziert, »%s« hat mehrdeutige Schnittstellen bei %L"
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a module procedure"
 msgid "%qs at %L is not a module procedure"
 msgstr "»%s« bei %L ist keine Modulprozedur"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, fuzzy, gcc-internal-format
 #| msgid "The assumed-rank array at %L requires that the dummy argument '%s' has assumed-rank"
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Feld mit vermutetem Rang bei %L erfordert Scheinargument »%s« mit vermutetem Rang"
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (scalar and rank-%d)"
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Unpassender Rang in Argument »%s« bei %L (Skalar und Rang-%d)"
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (rank-%d and scalar)"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Unpassender Rang in Argument »%s« bei %L (Rang-%d und Skalar)"
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (rank-%d and rank-%d)"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Unpassender Rang in Argument »%s« bei %L (Rang-%d und Rang-%d)"
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Ungültiges Argument für Prozedur bei %L"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in dummy procedure '%s' at %L: %s"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Schnittstelle in Scheinprozedur »%s« bei %L passt nicht: %s"
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to contiguous pointer dummy '%s' at %L must be simply contiguous"
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "Effektives Argument für fortlaufenden Schein-Zeiger »%s« bei %L muss einfach fortlaufend sein"
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, fuzzy, gcc-internal-format
 #| msgid "Type mismatch in argument '%s' at %L; passed %s to %s"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Unpassender Typ in Argument »%s« bei %L; übergab %s an %s"
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, fuzzy, gcc-internal-format
 #| msgid "The assumed-rank array at %L requires that the dummy argument '%s' has assumed-rank"
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Feld mit vermutetem Rang bei %L erfordert Scheinargument »%s« mit vermutetem Rang"
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be polymorphic"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Effektives Argument für »%s« bei %L muss polymorph sein"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must have the same declared type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Effektives Argument für »%s« bei %L muss den selben deklarierten Typ haben"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "Effektives Argument für »%s« bei %L muss unbegrenzt polymorph sein, da das formale Argument ein Zeiger oder reservierbare unbegrenzt polymorphe Entität ist [F2008: 12.5.2.5]"
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Effektives Argument für »%s« bei %L sein muss Koarray sein"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, fuzzy, gcc-internal-format
 #| msgid "Corank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Unpassender Korang in Argument »%s« bei %L (%d und %d)"
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be simply contiguous"
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "Effektives Argument für »%s« bei %L muss einfach fortlaufend sein"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to non-INTENT(INOUT) dummy '%s' at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Effektives Argument für Nicht-INTENT(INOUT)-Platzhalter »%s« bei %L mit Typ LOCK_TYPE oder einer Komponente LOCK_TYPE"
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' has to be a pointer or assumed-shape array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "Scheinargument »%s« muss Zeiger oder Feld mit angenommener Form ohne CONTIGUOUS-Attribut sein - da das effektive Argument bei %L nicht einfach fortlaufend ist und beide ASYNCHRONOUS oder VOLATILE sind"
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, fuzzy, gcc-internal-format
 #| msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument '%s'"
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Koarray bei %L wird an reservierbares, Nicht-Coarray, INTENT(OUT) Scheinargument »%s« übergeben"
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, fuzzy, gcc-internal-format
 #| msgid "Passing coarray at %L to allocatable, noncoarray dummy argument '%s', which is invalid if the allocation status is modified"
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Koarray bei %L wird an reservierbares, Nicht-Coarray-Scheinargument »%s« übergeben, das ungültig wird, wenn der Reservierungsstatus geändert wird"
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, fuzzy, gcc-internal-format
 #| msgid "Polymorphic scalar passed to array dummy argument '%s' at %L"
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Polymorphes Skalar wird an Feld-Scheinargument »%s« bei %L übergeben"
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument '%s' at %L"
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr "Element eines Feldes mit vermuteter Form oder Zeigerfeld wird an Feld-Scheinargument »%s« bei %L übergeben"
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Erweiterung: Skalares effektives nicht-standardartiges, nicht-C_CHAR CHARACTER-Argument mit Feld-Scheinargument »%s« bei %L"
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Skalares effektives CHARACTER-Argument mit Feld-Scheinargument »%s« bei %L"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Schlüsselwort-Argument »%s« bei %L ist nicht in der Prozedur"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Schlüsselwort-Argument »%s« bei %L ist bereits mit einem anderen effektiven Argument verbunden"
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Mehr effektive als formale Argumente in Prozeduraufruf bei %L"
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Fehlende alternative Rückgabespezifikation in Unterprogrammaufruf bei %L"
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr "Unerwartete alternative Rückgabespezifikation in Unterprogrammaufruf bei %L"
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Unerwartetes intrinsisches NULL() bei %L für Schein-»%s«"
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Null pointer at %L to non-pointer dummy '%s'"
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Nullzeiger bei %L an Nicht-Zeiger-Schein-»%s«"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr "Effektives Argument bei %L für Scheinparameter vermuteten Typs hat abgeleiteten Typ mit typgebundenen oder FINAL-Prozeduren"
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Zeichenlänge passt nicht (%ld/%ld) zwischen effektivem Argument und Zeiger oder reservierbarem Scheinargument »%s« bei %L"
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Zeichenlänge passt nicht (%ld/%ld) zwischen effektivem Argument und Scheinargument »%s« mit vermuteter Form bei %L"
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument at %L to allocatable or pointer dummy argument '%s' must have a deferred length type parameter if and only if the dummy has one"
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "Effektives Argument bei %L an reservierbares oder Zeiger-Scheinargument »%s« muss Parameter mit Typ aufgeschobener Länge haben, genau dann, wenn das Scheinargument einen solchen hat"
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of actual argument shorter than of dummy argument '%s' (%lu/%lu) at %L"
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Zeichenlänge des effektiven Arguments kürzer als das des Scheinarguments »%s« (%lu/%lu) bei %L"
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Effektives Argument enthält zuwenige Elemente für Scheinargument »%s« (%lu/%lu) bei %L"
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure pointer for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Prozedurzeiger für Argument »%s« bei %L erwartet"
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Prozedur für Argument »%s« bei %L erwartet"
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Effektives Argument für »%s« kann nicht Feld vermuteter Größe bei %L sein"
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Effektives Argument für »%s« muss ein Zeiger bei %L sein"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy '%s'"
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Effektives Nicht-Zeiger-Argument bei %L an Scheinzeiger »%s«"
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L to pointer dummy '%s'"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Koindiziertes effektives Argument bei %L an Scheinzeiger »%s«"
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L to allocatable dummy '%s' requires INTENT(IN)"
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Koindiziertes effektives Argument bei %L an scheinreservierbares »%s« erfordert INTENT(IN)"
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy '%s' has neither ASYNCHRONOUS nor VOLATILE"
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Koindiziertes effektives ASYNCHRONOUS- oder VOLATILE-Argument bei %L erfordert, dass Schein-»%s« weder ASYNCHRONOUS noch VOLATILE hat"
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy '%s' requires either VALUE or INTENT(IN)"
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Koindiziertes effektives Argument bei %L mit reservierbarer endgültiger Komponente für Schein-»%s« erfordert entweder VALUE oder INTENT(IN)"
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, fuzzy, gcc-internal-format
 #| msgid "Actual CLASS array argument for '%s' must be a full array at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Effektives CLASS-Feldargument für »%s« muss ein vollständiges Feld bei %L sein"
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Effektives Argument für »%s« muss ALLOCATABLE bei %L sein"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument '%s'"
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Feldbereich mit Vektorindex als effektives Argument bei %L ist unverträglich mit INTENT(OUT), INTENT(INOUT), VOLATILE- und ASYNCHRONOUS-Attribut des Scheinarguments »%s«"
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Effektives Argument mit vermuteter Form bei %L ist wegen VOLATILE-Attribut unverträglich mit dem Scheinargument ohne vermutete Form »%s«"
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Feldbereich als effektives Argument bei %L ist wegen VOLATILE-Attribut unverträglich mit dem Scheinargument ohne vermutete Form »%s«"
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument '%s' due to VOLATILE attribute"
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Zeigerfeld als effektives Argument bei %L erfordert wegen VOLATILE-Attribut ein Scheinargument »%s« mit vermuteter Form oder als Zeigerfeld"
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Fehlendes effektives Argument für Argument »%s« bei %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Gleiches effektives Argument mit INTENT(%s)-Argument »%s« und INTENT(%s)-Argument »%s« bei %L verbunden"
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Prozedurargument bei %L ist lokal für PURE-Prozedur und hat das POINTER-Attribut"
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Effektives koindiziertes Argument bei %L in PURE-Prozedur wird an INTENT(%s)-Argument übergeben"
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Effektives koindiziertes Argument bei %L in PURE-Prozedur wird an POINTER-Scheinargument übergeben"
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument '%s'"
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Koindiziertem polymorphen effektiven Argument bei %L wird polymorphes Scheinargument »%s« übergeben"
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called at %L is not explicitly declared"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Bei %2$L aufgerufend Prozedur »%1$s« ist nicht explizit deklariert"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Prozedur »%s« mit einer impliziten Schnittstelle bei %L aufgerufen"
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer object '%s' at %L must have an explicit function interface or be declared as array"
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Das Zeigerobjekt »%s« bei %L muss eine explizite Funktionsschnittstelle haben oder als Feld deklariert sein"
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "The allocatable object '%s' at %L must have an explicit function interface or be declared as array"
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Das reservierbare Objekt »%s« bei %L muss eine explizite Funktionsschnittstelle haben oder als Feld deklariert sein"
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable function '%s' at %L must have an explicit function interface"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Reservierbare Funktion »%s« bei %L muss eine explizite Funktionsschnittstelle haben"
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Schlüsselwort-Argument erfordert explizite Schnittstelle für Prozedur »%s« bei %L"
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Argument »%s« bei %L vermuteten Typs erfordert eine explizite Schnittstelle"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure '%s'"
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Effektives Argument mit LOCK_TYPE oder mit LOCK_TYPE-Komponente bei %L erfordert eine explizite Schnittstelle für Prozedur »%s«"
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "MOLD-Argument an NULL bei %L erforderlich"
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Argument vermuteten Ranges erfordert eine explizite Schnittstelle bei %L"
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Prozedur-Zeigerkomponente »%s« mit einer impliziten Schnittstelle bei %L aufgerufen"
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure pointer component '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Schlüsselwortargument erfordert explizite Schnittstelle für Prozedurzeigerkomponente »%s« bei %L"
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "In NULL()-Argument bei %L wird MOLD= benötigt: Mehrdeutig zwischen spezifischen Funktionen %s und %s"
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qE"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D als Alias für undefiniertes Symbol %qE"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Entität »%s« bei %L ist bereits in der Schnittstelle vorhanden"
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC '%s' at %L"
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr "GENERIC »%s« bei %L kann nicht überschrieben werden"
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "»%s« bei %L überschreibt eine Prozedurbindung, die als NON_OVERRIDABLE deklariert ist"
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "»%s« bei %L darf nicht DEFERRED sein, da es eine Nicht-DEFERRED-Bindung überschreibt"
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PURE procedure and must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "»%s« bei %L überschreibt eine PURE-Prozedur und muss auch PURE sein"
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "»%s« bei %L überschreibt eine ELEMENTAL-Prozedur und muss auch ELEMENTAL sein"
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "»%s« bei %L überschreibt eine Nicht-ELEMENTAL-Prozedur und darf ebenfalls nicht ELEMENTAL sein"
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "»%s« bei %L überschreibt eine SUBROUTINE und muss auch eine SUBROUTINE sein"
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a FUNCTION and must also be a FUNCTION"
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "»%s« bei %L überschreibt eine FUNCTION und muss auch eine FUNCTION sein"
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, fuzzy, gcc-internal-format
 #| msgid "Result mismatch for the overriding procedure '%s' at %L: %s"
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Unpassendes Ergebnis für die überschreibende Prozedur »%s« bei %L: %s"
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "»%s« bei %L überschreibt eine PUBLIC-Prozedur und darf nicht PRIVATE sein"
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' of '%s' at %L should be named '%s' as to match the corresponding argument of the overridden procedure"
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Scheinargument »%s« von »%s« bei %L sollte »%s« genannt werden, um zum zugehörigen Argument der überschriebenen Prozedur zu passen"
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, fuzzy, gcc-internal-format
 #| msgid "Argument mismatch for the overriding procedure '%s' at %L: %s"
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Unpassende Argumente für die überschreibende Prozedur »%s« bei %L: %s"
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have the same number of formal arguments as the overridden procedure"
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "»%s« bei %L muss die gleiche Anzahl formaler Argumente wie die überschriebene Prozedur haben"
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a NOPASS binding and must also be NOPASS"
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "»%s« bei %L überschreibt eine NOPASS-Bindung und muss ebenfalls NOPASS sein"
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a binding with PASS and must also be PASS"
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "»%s« bei %L überschreibt eine Bindung mit PASS und muss ebenfalls PASS sein"
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
@@ -48266,12 +48328,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "ASYNCHRONOUS= bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "BLANK= bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "DECIMAL= bei %C ist in Fortran 95 nicht erlaubt"
@@ -48281,7 +48343,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "ENCODING= bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "ROUND= bei %C ist in Fortran 95 nicht erlaubt"
@@ -48306,800 +48368,800 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "UNIT-Zahl in CLOSE-Anweisung bei %L muss nicht-negativ sein"
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s-Anweisung in PURE-Prozedur bei %C nicht erlaubt"
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "UNIT-Zahl in Anweisung bei %L muss nicht-negativ sein"
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "FLUSH-Anweisung bei %C"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "Doppelte UNIT-Spezifikation bei %C"
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Doppelte Format-Spezifikation bei %C"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "Symbol »%s« in Namensliste »%s« ist INTENT(IN) bei %C"
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Doppelte NML-Spezifikation bei %C"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C must be a NAMELIST group name"
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "Symbol »%s« bei %C muss ein NAMELIST-Gruppenname sein"
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "END-Tag bei %C in Ausgabe-Anweisung nicht erlaubt"
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "bei %L wurde kein UNIT angegeben"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "UNIT-Spezifikation bei %L muss ein INTEGER-Ausdruck oder eine CHARACTER-Variable sein"
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "Ungültige Form der WRITE-Anweisung bei %L, UNIT erforderlich"
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "Interne Einheit mit Vektor-Index bei %L"
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "Externe IO UNIT kann kein Feld bei %L sein"
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST '%s' in READ statement at %L contains the symbol '%s' which may not appear in a variable definition context"
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr "NAMELIST »%s« in READ-Anweisung bei %L enthält Symbol »%s«, das im Kontext zur Variablendefinition nicht auftreten darf"
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "Komma vor Ein-/Ausgabeelementliste bei %L"
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR-Marke %d bei %L nicht definiert"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END-Marke %d bei %L nicht definiert"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR-Marke %d bei %L nicht definiert"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT-Marke %d bei %L nicht definiert"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Syntaxfehler in E/A-Iterator bei %C"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Variable in READ-Anweisung bei %C erwartet"
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Ausdruck in %s-Anweisung bei %C erwartet"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaxfehler in Anweisung %s bei %C"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr "Interne Datei bei %L mit Namensliste"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "Spezifikation ASYNCHRONOUS= bei %L muss ein Initialisierungsausdruck sein"
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "PAD= bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "DELIM= bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "PRINT-Namensliste bei %C ist eine Erweiterung"
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Komma in E/A-Liste bei %C erwartet"
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT-Anweisung bei %C innerhalb PURE-Prozedur nicht erlaubt"
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE-Anweisung in PURE-Prozedur bei %C nicht erlaubt"
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENGTH-Markierung in INQUIRE-Anweisung bei %C ungültig"
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "INQUIRE-Anweisung bei %L kann nicht sowohl FILE- als auch UNIT-Spezifikationssymbole enthalten"
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "INQUIRE-Anweisung bei %L erfordert entweder FILE- oder UNIT-Spezifikationssymbol"
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT number in statement at %L must be non-negative"
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr "UNIT-Zahl in Anweisung bei %L muss nicht-negativ sein"
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "INQUIRE-Anweisung bei %L erfordert PENDING= mit Spezifizierung ID="
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "WAIT bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "WAIT-Anweisung ist in PURE-Prozedur bei %C nicht erlaubt"
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_op2string(): Bad code"
 msgstr "gfc_trans_code(): Falscher Anweisungscode"
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 #| msgid "Missing ')' in statement at or before %L"
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "Fehlendes »)« in Anweisung bei oder vor %L"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 #| msgid "Missing '(' in statement at or before %L"
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "Fehlendes »(« in Anweisung bei oder vor %L"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr "Ganzzahl bei %C zu groß"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "Zu viele Ziffern in Anweisungsmarke bei %C"
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr "Anweisungsmarke bei %C ist Null"
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 #| msgid "Label name '%s' at %C is ambiguous"
 msgid "Label name %qs at %C is ambiguous"
 msgstr "Markenname »%s« bei %C ist mehrdeutig"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Duplicate construct label %qs at %C"
 msgstr "Doppelte Aufbau-Marke »%s« bei %C"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr "Ungültiges Zeichen in Name bei %C"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr "Name bei %C ist zu lang"
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid character '$' at %C. Use -fdollar-ok to allow it as an extension"
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr "Ungültiges Zeichen »$« bei %C. -fdollar-ok verwenden, um es als Erweiterung zuzulassen"
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr "Schleifenvariable bei %C kann kein Koarray sein"
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr "Schleifenvariable bei %C kann keine Unter-Komponente sein"
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr "Schrittvariable in Iterator bei %C erwartet"
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr "Syntaxfehler in Iterator bei %C"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_match(): Bad match code %c"
 msgstr "gfc_trans_code(): Falscher Anweisungscode"
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr "Ungültige Form der PROGRAM-Anweisung bei %C"
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %C"
 msgstr "Arithmetische IF-Anweisung bei %C"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr "Syntaxfehler in IF-Ausdruck bei %C"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr "Blockmarke passt nicht zu arithmetischer IF-Anweisung bei %C"
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr "Blockmarke ist ungeeignet für IF-Anweisung bei %C"
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr "An benannte Konstante bei %C kann nicht zugewiesen werden"
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr "Anweisung in IF-Klausel bei %C nicht klassifizierbar"
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr "Syntaxfehler in IF-Klausel bei %C"
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr "Unerwartete Zeichen hinter ELSE-Anweisung bei %C"
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match IF label '%s'"
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "Marke »%s« bei %C passt nicht zur IF-Marke »%s«"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr "Unerwartete Zeichen hinter ELSE-IF-Anweisung bei %C"
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr "CRITICAL-Anweisung zur Image-Steuerung bei %C in PURE-Prozedur"
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr "CRITICAL-Anweisung zur Image-Steuerung bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
 msgstr "CRITICAL-Anweisung bei %C"
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr "Geschachtelter CRITICAL-Block bei %C"
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr "Verknüpfungsliste bei %C erwartet"
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr "Verknüpfung bei %C erwartet"
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate name '%s' in association at %C"
 msgid "Duplicate name %qs in association at %C"
 msgstr "Doppelter Name »%s« in Verknüpfung bei %C"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr "Verknüpfungsziel bei %C darf nicht koindiziert sein"
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, fuzzy, gcc-internal-format
 #| msgid "Expected ')' or ',' at %C"
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "»)« oder »,« bei %C erwartet"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr "Ausschuss hinter ASSOCIATE-Anweisung bei %C"
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L may not be ABSTRACT"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "Abgeleiteter Typ »%s« bei %L darf nicht ABSTRACT sein"
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "Ungültiges Typspezifikation bei %C"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "Syntaxfehler in FORALL-Iterator bei %C"
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr "DO CONCURRENT-Konstrukt bei %C"
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is unknown"
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "Name »%s« in %s-Anweisung bei %C ist unbekannt"
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a construct name"
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "Name »%s« in %s-Anweisung bei %C ist kein Konstruktname"
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "Anweisung %s bei %C hinterlässt CRITICAL-Konstrukt"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "Anweisung %s bei %C hinterlässt DO CONCURRENT-Konstrukt"
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "Anweisung %s bei %C ist nicht innerhalb eines Konstrukts"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within construct '%s'"
 msgid "%s statement at %C is not within construct %qs"
 msgstr "Anweisung %s bei %C nicht innerhalb des Konstrukts »%s«"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, fuzzy, gcc-internal-format
 #| msgid "CYCLE statement at %C is not applicable to non-loop construct '%s'"
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "CYCLE-Anweisung bei %C ist nicht auf Nicht-Schleifenkonstrukt »%s« anwendbar"
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "EXIT-Anweisung ohne DO-CONSTRUCT-Name bei %C"
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not applicable to construct '%s'"
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "Anweisung %s bei %C nicht auf Konstrukt »%s« anwendbar"
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "Anweisung %s bei %C hinterlässt OpenMP-strukturierten Block"
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "EXIT-Anweisung bei %C beendet !$OMP DO Schleife"
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "CYCLE-Anweisung bei %C für nicht-innerste eingestürzte !$OMP DO-Schleife"
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "EXIT-Anweisung bei %C beendet !$OMP DO Schleife"
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "CYCLE-Anweisung bei %C für nicht-innerste eingestürzte !$OMP DO-Schleife"
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Image control statement %s at %C in PURE procedure"
 msgid "%s statement at %C in PURE procedure"
 msgstr "Anweisung %s zur Image-Steuerung bei %C in PURE-Prozedur"
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr "STOP-Anweisung zur Image-Steuerung bei %C in CRITICAL-Block"
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "STOP-Anweisung zur Image-Steuerung bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "STOP-Code bei %L muss entweder INTEGER- oder CHARACTER-Typ haben"
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "STOP-Code bei %L muss Skalar sein"
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr "STOP-Code bei %L muss Standardzeichentyp KIND=%d sein"
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "STOP-Code bei %L muss Standardganzzahltyp KIND=%d sein"
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "PAUSE-Anweisung bei %C"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "ERROR STOP-Anweisung bei %C"
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "Anweisung %s zur Image-Steuerung bei %C in PURE-Prozedur"
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "Anweisung %s zur Image-Steuerung bei %C in CRITICAL-Block"
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "Anweisung %s zur Image-Steuerung bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr "Redundante STAT-Marke bei %L gefunden"
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr "Redundante ERRMSG-Marke bei %L gefunden"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr "Redundante ACQUIRED_LOCK-Marke bei %L gefunden"
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "LOCK-Anweisung bei %C"
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "UNLOCK-Anweisung bei %C"
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "SYNC-Anweisung zur Image-Steuerung bei %C in PURE-Prozedur"
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "SYNC-Anweisung bei %C"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr "SYNC-Anweisung zur Image-Steuerung bei %C in CRITICAL-Block"
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "SYNC-Anweisung zur Image-Steuerung bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "ASSIGN-Anweisung bei %C"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "Zugewiesene GOTO-Anweisung bei %C"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "Anweisungsmarkenliste in GOTO bei %C kann nicht leer sein"
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "Berechnetes GOTO bei %C"
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "Fehler in Typspezifikation bei %L"
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr "Typspezifikation in ALLOCATE bei %L"
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "Falsches Reservierungs-Objekt bei %C für eine PURE-Prozedur"
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "ALLOCATE von Koarray bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr "ALLOCATE von Koarray bei %C in CRITICAL-Block"
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "ALLOCATE-Objekt bei %L ist weder ein Datenzeiger noch eine reservierbare Variable"
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "Typ der Entität bei %L ist mit Typspezifikation unverträglich"
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr "Parameter mit KIND-Typ für Entität bei %L unterscheidet sich vom Parameter mit KIND-Typ der Typspezifikation"
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "Formspezifikation für reservierbares Skalar bei %C"
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "ERRMSG-Markierung bei %L"
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "SOURCE-Marke bei %L"
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr "Überflüssige SOURCE-Marke bei %L gefunden"
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr "SOURCE-Marke bei %L steht mit Typspezifikation bei %L in Konflikt"
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr "SOURCE-Marke bei %L mit mehr als einem reservierbaren Objekt"
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "MOLD-Marke bei %L"
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr "Überflüssige MOLD-Marke bei %L gefunden"
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr "MOLD-Marke bei %L steht mit Typspezifikation bei %L in Konflikt"
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "MOLD-Marke bei %L steht mit SOURCE-Marke bei %L in Konflikt"
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "ALLOCATE-Objekt bei %L mit Parameter aufgeschobenen Typs erfordert entweder eine Typspezifikation, SOURCE-Marke oder MOLD-Marke"
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Unbeschränkt polymorphes ALLOCATE-Objekt bei %L erfordert entweder eine Typspezifikation, SOURCE-Marke oder MOLD-Marke"
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "Zeigerobjekt bei %C sollte nicht koindiziert sein"
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "Unzulässiges ALLOCATE-Objekt bei %C für eine PURE-Prozedur"
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "DEALLOCATE von Koarray bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr "DEALLOCATE von Koarray bei %C in CRITICAL-Block"
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "Allocate-Objekt bei %C ist kein Nicht-Prozedur-Zeiger oder reservierbare Variable"
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "ERRMSG bei %L"
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr "RETURN-Anweisung zur Image-Steuerung bei %C in CRITICAL-Block"
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "PRINT-Anweisung zur Image-Steuerung bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "Alternative RETURN-Anweisung bei %C ist nur innerhalb einer SUBROUTINE erlaubt"
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr "RETURN-Anweisung im Hauptprogramm bei %C"
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Referenz auf Komponente bei %C erwartet"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "Ausschuss hinter CALL bei %C"
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Typgebundene Prozedur oder Prozedurzeiger-Komponente bei %C erwartet"
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "Syntaxfehler im allgemeinen Blocknamen bei %C"
@@ -49107,158 +49169,158 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr "Variable »%s« bei %L in Common-Block »%s« bei %C muss in einer C-kompatiblen Art deklariert sein, da Common-Block »%s« bind(c) ist"
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %C can not be bind(c) since it is not global"
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr "Variable »%s« in Common-Block »%s« bei %C kann nicht bind(c) sein, da sie nicht global ist"
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Symbol »%s« bei %C ist bereits in einem COMMON-Block"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, fuzzy, gcc-internal-format
 #| msgid "Initialized symbol '%s' at %C can only be COMMON in BLOCK DATA"
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "Initialisiertes Symbol »%s« bei %C kann nur COMMON in BLOCK DATA sein"
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "Array specification for symbol '%s' in COMMON at %C must be explicit"
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "Feldspezifikation für Symbol »%s« in COMMON bei %C muss explizit sein"
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in COMMON at %C cannot be a POINTER array"
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "Symbol »%s« in COMMON bei %C kann kein POINTER-Feld sein"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s', in COMMON block '%s' at %C is being indirectly equivalenced to another COMMON block '%s'"
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "Symbol »%s« in COMMON-Block »%s« bei %C ist indirekt äquivalent zu anderem COMMON-Block »%s«"
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already has a basic type of %s"
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "Gruppenname »%s« der Namensliste bei %C hat bereits einen Basistypen von »%s«"
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already is USE associated and cannot be respecified."
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "Gruppenname »%s« der Namensliste bei %C ist bereits USE-verbunden und kann nicht respezifiziert werden."
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Feld »%s« mit vermuteter Größe in Namensliste »%s« bei %C ist nicht erlaubt"
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "Komponente %C abgeleiteten Typs ist kein zulässiges EQUIVALENCE-Element"
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "Feldreferenz in EQUIVALENCE bei %C kann kein Feldabschnitt sein"
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "EQUIVALENCE bei %C erfordert zwei oder mehr Objekte"
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Versuch, die COMMON-Blöcke %s und %s durch EQUIVALENCE bei %C indirekt zu überschneiden"
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Komma in EQUIVALENCE bei %C erwartet"
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "Anweisungsfunktion bei %L ist rekursiv"
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "Anweisungsfunktion bei %C"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Erwarteter Initialisierungsausdruck in CASE bei %C"
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name '%s' of SELECT construct at %C"
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Blockname »%s« des SELECT-Konstrukts bei %C erwartet"
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROTECTED statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Syntaxfehler in PROTECTED-Anweisung bei %C"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Selektor in SELECT TYPE bei %C ist keine benannte Variable; associate-name=> verwendet"
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Unerwartete CASE-Anweisung bei %C"
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Syntaxfehler in CASE-Spezifikation bei %C"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Unerwartete TYPE IS-Anweisung bei %C"
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "Typspezifikation sollte keinen Sequenz-abgeleiteten Typ oder Typ mit BIND-Attribut in SELECT TYPE bei %C beschreiben [F2003:C815]"
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Syntaxfehler in TYPE IS-Spezifikation bei %C"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Syntaxfehler in CLASS IS-Spezifikation bei %C"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "ELSEWHERE-Anweisung bei %C nicht eingeschlossen in WHERE-Block"
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -49412,192 +49474,192 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Namensliste %s kann nicht mit USE-Verbindung in %s umbenannt werden"
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' of module '%s', imported at %C, is also the name of the current program unit"
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "Bei %3$C importiertes »%1$s« von Modul »%2$s« ist auch der Name der aktuellen Programmeinheit"
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Bei %2$L referenziertes Symbol »%1$s« nicht im Modul »%3$s« gefunden"
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, fuzzy, gcc-internal-format
 #| msgid "User operator '%s' referenced at %L not found in module '%s'"
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Bei %2$L referenzierter Benutzeroperator »%1$s« nicht im Modul »%3$s« gefunden"
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Bei %2$L referenzierter intrinsischer Operator »%1$s« nicht im Modul »%3$s« gefunden"
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Moduldatei »%s« kann bei %C nicht zum Schreiben geöffnet werden: %s"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Fehler beim Schreiben der Moduldatei »%s«: %s"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file '%s': %s"
 msgid "Can't delete module file %qs: %s"
 msgstr "Moduldatei »%s« kann nicht gelöscht werden: %s"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "Can't rename module file '%s' to '%s': %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Moduldatei »%s« kann nicht in »%s« umbenannt werden: %s"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete temporary module file '%s': %s"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Vorübergehende Moduldatei »%s« kann nicht gelöscht werden: %s"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs already declared"
 msgstr "Symbol »%s« bereits deklariert"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "The symbol '%s', referenced at %L, is not in the selected standard"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Das bei %2$L referenzierte Symbol »%1$s« ist nicht im gewählten Standard vorhanden"
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Bei %2$L referenziertes Symbol »%1$s« nicht im Modul ISO_C_BINDING gefunden"
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, fuzzy, gcc-internal-format
 #| msgid "Use of intrinsic module '%s' at %C conflicts with non-intrinsic module name used previously"
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Verwendung des intrinsischen Moduls »%s« bei »%C« steht mit nicht-intrinsischem vorher verwendetem Modulnamen in Konflikt"
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %s"
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Verwendung der Konstante NUMERIC_STORAGE_SIZE aus intrinsischem Modul ISO_FORTRAN_ENV bei %L ist mit Option %s unverträglich"
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Verwendung der Konstante NUMERIC_STORAGE_SIZE aus intrinsischem Modul ISO_FORTRAN_ENV bei %C ist mit Option %s unverträglich"
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Bei %2$L referenziertes Symbol »%1$s« nicht im intrinsischen Modul ISO_FORTRAN_ENV gefunden"
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PAUSE statement at %C"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "PAUSE-Anweisung bei %C"
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Intrinsisches Modul ISO_FORTRAN_ENV bei %C"
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Modul ISO_C_BINDING bei %C"
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, fuzzy, gcc-internal-format
 #| msgid "Can't find an intrinsic module named '%s' at %C"
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "Intrinsisches Modul »%s« bei %C nicht gefunden"
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "\"USE :: module\" at %C"
 msgid "IEEE_FEATURES module at %C"
 msgstr "\"USE :: module\" bei %C"
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ISO_C_BINDING module at %C"
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "Modul ISO_C_BINDING bei %C"
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ISO_C_BINDING module at %C"
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "Modul ISO_C_BINDING bei %C"
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Moduldatei »%s« kann bei %C nicht zum Lesen geöffnet werden: %s"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, fuzzy, gcc-internal-format
 #| msgid "Use of non-intrinsic module '%s' at %C conflicts with intrinsic module name used previously"
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Verwendung des nicht-intrinsischen Moduls »%s« bei %C steht mit vorher verwendetem intrinsischen Modulnamen in Konflikt"
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GNU Fortran module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Bei %2$C geöffnete Datei »%1$s« ist keine GNU Fortran-Moduldatei"
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot read module file '%s' opened at %C, because it was created by a different version of GNU Fortran"
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr "Bei %2$C geöffnete Moduldatei »%1$s« kann nicht gelesen werden, da sie von anderer Version von GNU Fortran erstellt wurde"
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr "Das gerade erzeugte Modul kann nicht gleichzeitig verwendet werden (USE)!"
@@ -49923,7 +49985,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-Klausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
@@ -50696,383 +50758,377 @@
 msgid "Unexpected %s statement at %C"
 msgstr "Unerwartete Anweisung %s bei %C"
 
-#: fortran/parse.c:2428
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected %s statement in MODULE at %C"
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr "Unerwartete Anweisung %s in MODULE bei %C"
-
-#: fortran/parse.c:2439
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "Anweisung %s bei %C kann nicht auf Anweisung %s bei %L folgen"
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "Unerwartetes Dateiende in »%s«"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with SEQUENCE must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "»%s« abgeleiteten Type mit SEQUENCE darf bei %C keinen CONTAINS-Abschnitt haben"
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with BIND(C) must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "»%s« abgeleiteten Type mit BIND(C) darf bei %C keinen CONTAINS-Abschnitt haben"
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "Komponenten in TYPE bei %C müssen CONTAINS vorausgehen"
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "Typgebundene Prozedur bei %C"
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "GENERIC-Bindung bei %C"
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "FINAL-Prozedurdeklaration bei %C"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Definition eines abgeleiteten Typs bei %C mit leerem CONTAINS-Abschnitt"
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "PRIVATE-Anweisung in TYPE bei %C muss innerhalb eines MODULEs sein"
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "PRIVATE-Anweisung bei %C muss Prozedurbindungen vorausgehen"
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Doppelte PRIVATE-Anweisung bei %C"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "SEQUENCE-Anweisung bei %C muss CONTAINS vorausgehen"
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "Bereits in CONTAINS-Block bei %C"
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "FINAL-Deklaration bei %C muss innerhalb von CONTAINS sein"
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr "Definition des abgeleiteten Typs bei %C ohne Komponenten"
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "PRIVATE-Anweisung bei %C muss Strukturkomponenten vorausgehen"
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "SEQUENCE-Anweisung bei %C muss Strukturkomponenten vorausgehen"
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "SEQUENCE-Attribut bei %C bereits in TYPE-Anweisung angegeben"
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Doppelte SEQUENCE-Anweisung bei %C"
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr "CONTAINS-Block in Definition des abgeleiteten Typs bei %C"
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "Komponente %s bei %L des Typs LOCK_TYPE muss eine Kodimension haben oder eine Subkomponente eines Koarrays sein, was wegen des Zeigerattributs der Komponente nicht möglich ist"
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "Zeigerkomponente %s bei %L hat eine Subkomponente als Nicht-Koarray des Type LOCK_TYPE, die eine Kodimension haben muss oder eine Subkomponente eines Koarrays sein muss"
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "Allozierbare Komponente %s bei %L des Typs LOCK_TYPE muss eine Kodimension haben"
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr "Allozierbare Komponente %s bei %L muss eine Kodimension haben, da es eine Subkomponente als Nicht-Koarray des Typs LOCK_TYPE hat"
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "Nicht-Koarray-Komponente %s bei %L des Typs LOCK_TYPE oder mit Subkomponente des Typs LOCK_TYPE muss eine Kodimension haben oder die Subkomponente eines Koarrays sein. (Variablen des Typs %s dürfen keine Kodimension haben, da es bereits eine Koarray-Subkomponente gibt.)"
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "Nicht-Koarray-Komponente %s bei %L des Typs LOCK_TYPE oder mit Subkomponente des Typs LOCK_TYPE muss eine Kodimension haben oder die Subkomponente eines Koarrays sein. (Variablen des Typs %s dürfen keine Kodimension haben, da %s bei %L eine Kodimension oder Koarray-Subkomponente hat.)"
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "ENUM-Deklaration bei %C hat keine ENUMERATORen"
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Unerwartete Anweisung %s in INTERFACE-Block bei %C"
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "Name »%s« des ABSTRACT INTERFACE bei %C kann nicht der gleiche wie ein intrinsischer Typ sein"
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Unerwartete Anweisung %s bei %C in INTERFACE-Körper"
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "Schnittstellenprozedur »%s« bei %L hat den selben Namen wie die umgebende Prozedur"
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "%s-Anweisung ist innerhalb eines BLOCKs bei %C nicht erlaubt"
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement is not allowed inside of BLOCK at %C"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "%s-Anweisung ist innerhalb eines BLOCKs bei %C nicht erlaubt"
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "Anweisung %s muss in einem MODULE auftreten"
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "Anweisung %s bei %C folgt einer anderen Zugriffsspezifikation"
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "Bad kind expression for function '%s' at %L"
 msgid "Bad kind expression for function %qs at %L"
 msgstr "Falscher Art-Ausdruck für Funktion »%s« bei %L"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, fuzzy, gcc-internal-format
 #| msgid "The type for function '%s' at %L is not accessible"
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Der Typ für Funktion »%s« bei %L ist nicht erreichbar"
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "Anweisung ELSEWHERE bei %C folgt zuvor unmaskiertem ELSEWHERE"
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Unerwartete Anweisung %s in WHERE-Block bei %C"
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Unerwartete Anweisung %s in FORALL-Block bei %C"
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "ELSE-IF-Anweisung bei %C kann nicht auf eine ELSE-Anweisung bei %L folgen"
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Doppelte ELSE-Anweisungen bei %L und %C"
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "CASE- oder END-SELECT-Anweisung hinter SELECT CASE bei %C erwartet"
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "TYPE IS-, CLASS IS- oder END SELECT-Anweisung hinter SELECT TYPE bei %C erwartet"
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr "Variable »%s« bei %C kann nicht innerhalb der bei %L beginnenden Schleife redefiniert werden"
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "Ende der DO-Anweisung ohne Block bei %C ist innerhalb eines anderen Blockes"
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "Ende der DO-Anweisung bei %C ist mit anderer DO-Schleife verwoben"
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CONTAINS block in derived type definition at %C"
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr "CONTAINS-Block in Definition des abgeleiteten Typs bei %C"
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "Anweisungsmarke in END CRITICAL bei %C passt nicht zur CRITICAL-Marke"
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "BLOCK-Konstrukt bei %C"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "ASSOCIATE-Konstrukt bei %C"
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "Anweisungsmarke in ENDDO bei %C passt nicht zum DO-Label"
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "Benanntes Block-DO bei %L erfordert passenden ENDDO-Namen"
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr "!$OMP END ATOMIC fehlt hinter !$OMP ATOMIC CAPTURE bei %C"
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Nested CRITICAL block at %C"
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr "Geschachtelter CRITICAL-Block bei %C"
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s at %C"
 msgstr "%s-Anweisung bei %C erwartet"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "»(« bei %C erwartet"
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr "Redundante ACQUIRED_LOCK-Marke bei %L gefunden"
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "Name hinter »!$omp critical« und »!$omp end critical« passt nicht bei %C"
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "Anweisung %s bei %C kann keine DO-Schleife ohne Block beenden"
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr "DATA-Anweisung bei %C hinter der ersten ausführbaren Anweisung"
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %C is already ambiguous"
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "Enthaltene Prozedur »%s« bei %C ist bereits mehrdeutig"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Unerwartete Anweisung %s in CONTAINS-Abschnitt bei %C"
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr "CONTAINS-Anweisung ohne FUNCTION- oder SUBROUTINE-Anweisung bei %C"
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "CONTAINS-Anweisung bei %C ist bereits in einer enthaltenen Programmeinheit"
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr "Globaler Name »%s« bei %L wird bereits als ein %s bei %L verwendet"
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr "Globaler Name »%s« bei %L wird bereits als ein %s bei %L verwendet"
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "Leeres BLOCK DATA bei %C steht in Konflikt mit vorherigem BLOCK DATA bei %L"
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Unerwartete Anweisung %s in BLOCK DATA bei %C"
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Unerwartete Anweisung %s in MODULE bei %C"
@@ -51080,7 +51136,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "Zwei Haupt-PROGRAMme bei %L und %C"
@@ -51852,7 +51908,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Nicht-RECURSIVE Prozedur »%s« bei %L ruft sich möglicherweise rekursiv selbst auf. Sollte als RECURSIVE oder mit -frecursive verwendet werden"
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Marke %d wird bei %L referenziert aber nirgendwo definiert"
@@ -51913,96 +51969,96 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Übergabe der eingebauten Prozedur über die Speicherstelle ist bei %L nicht erlaubt"
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "Elementare nicht-intrinsische Prozedur »%s« ist nicht als effektives Argument bei %L erlaubt"
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Koindiziertes effektives Argument bei %L mit endgültiger Zeigerkomponente"
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "»%s« bei %L ist ein Feld und optional; wenn es fehlt, kann es nicht das effektive Argument einer elementaren Prozedur sein, es sei denn, es gibt ein nicht-optionales Argument mit dem selben Rang (12.4.1.5)"
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument at %L for INTENT(%s) dummy '%s' of ELEMENTAL subroutine '%s' is a scalar, but another actual argument is an array"
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "Effektives Argument bei %L für INTENT(%s)-Dummy »%s« von ELEMENTAL-Unterprogramm »%s« ist skalar, aber ein anderes effektives Argument ist ein Feld"
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, fuzzy, gcc-internal-format
 #| msgid "Return type mismatch of function '%s' at %L (%s/%s)"
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Unpassender Rückgabetyp der Funktion »%s« bei %L (%s/%s)"
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in dummy procedure '%s' at %L: %s"
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr "Schnittstelle in Scheinprozedur »%s« bei %L passt nicht: %s"
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Es gibt keine spezifische Funktion für das allgemeine »%s« bei %L"
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Generische Funktion »%s« bei %L ist nicht mit spezifischer intrinsischer Schnittstelle vereinbar"
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Funktion »%s« bei %L ist INTRINSIC, aber nicht mit eingebauter Funktion verträglich"
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Spezifische Funktion »%s« bei %L kann nicht aufgelöst werden"
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktion »%s« bei %L hat IMPLICIT-Typ"
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, fuzzy, gcc-internal-format
 #| msgid "Reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "Referenz auf Nicht-PURE-Funktion »%s« bei %L innerhalb eines FORALL %s"
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, fuzzy, gcc-internal-format
 #| msgid "Reference to non-PURE function '%s' at %L inside a DO CONCURRENT %s"
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "Referenz auf Nicht-PURE-Funktion »%s« bei %L innerhalb eines DO CONCURRENT %s"
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, fuzzy, gcc-internal-format
 #| msgid "Reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Referenz auf Nicht-PURE-Funktion »%s« bei %L innerhalb eines FORALL %s"
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a function"
 msgid "%qs at %L is not a function"
 msgstr "»%s« bei %L ist keine Funktion"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "ABSTRACT INTERFACE '%s' must not be referenced at %L"
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
@@ -52009,300 +52065,300 @@
 msgstr "ABSTRACT INTERFACE »%s« darf bei %L nicht referenziert werden"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Funktion »%s« ist als CHARACTER(*) deklariert und kann nicht bei %L verwendet werden, da es kein Scheinargument ist"
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_function(): bad function type"
 msgstr "<unaufgelöster überladener Funktionstyp>"
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "User defined non-ELEMENTAL function '%s' at %L not allowed in WORKSHARE construct"
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Benutzerdefinierte nicht-elementare Funktion »%s« bei %L ist in WORKSHARE-Konstrukt nicht erlaubt"
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as function '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "Eintrag »%s« bei %L kann nicht rekursiv aufgerufen werden, da Funktion »%s« nicht RECURSIVE ist"
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Funktion »%s« bei %L kann nicht rekursiv aufgerufen werden, da sie nicht RECURSIVE ist"
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Unterprogrammaufruf von »%s« in FORALL-Block bei %L ist nicht PURE"
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in DO CONCURRENT block at %L is not PURE"
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Unterprogrammaufruf von »%s« in DO CONCURRENT-Block bei %L ist nicht PURE"
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Unterprogrammaufruf von »%s« bei %L ist nicht PURE"
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific subroutine for the generic '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Es gibt kein spezifisches Unterprogramm für allgemeines »%s« bei %L"
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Generisches Unterprogramm »%s« bei %L ist nicht mit intrinsischer Unterprogrammschnittstelle vereinbar"
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Unterprogramm »%s« bei %L ist INTRINSIC aber nicht mit eingebauter Funktion verträglich"
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Spezifisches Unterprogramm »%s« bei %L kann nicht aufgelöst werden"
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr "»%s« bei %L hat einen Typen, der nicht zum CALL bei %L passt"
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as subroutine '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "Eintrag »%s« bei %L kann nicht rekursiv aufgerufen werden, da Unterprogramm »%s« nicht RECURSIVE ist"
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE »%s« bei %L kann nicht rekursiv aufgerufen werden, da sie nicht RECURSIVE ist"
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_subroutine(): bad function type"
 msgstr "<unaufgelöster überladener Funktionstyp>"
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Formen der Operanden bei %L und %L stimmen nicht überein"
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld < %ld) in Kodimension %d"
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld > %ld) in Kodimension %d"
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Unzulässiger Schritt von Null bei %L"
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Untere Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Untere Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Obere Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Obere Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "Index fehlt in Feldreferenz"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Rechte obere Schranke des Feldabschnitts angenommener Größe nicht angegeben bei %L"
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Unpassende Ränge in Feldreferenz bei %L (%d/%d)"
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Unpassende Ränge des Koindex in Feldreferenz bei %L (%d/%d)"
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Koindex der Kodimension %d muss bei %L ein Skalar sein"
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Feldindex bei %L muss skalar sein"
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Feldindex bei %L muss INTEGER-Typ haben, %s gefunden"
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "REAL-Feld-Index bei %L"
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Argument dim bei %L muss skalar sein"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Argument dim bei %L muss INTEGER-Typ haben"
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Feldindex bei %L ist ein Feld mit Rang %d"
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L muss INTEGER-Typ haben"
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L muss skalar sein"
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L ist kleiner als Eins"
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "End-Index der Teilzeichenkette bei %L muss INTEGER-Typ haben"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "End-Index der Teilzeichenkette bei %L muss skalar sein"
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "End-Index der Teilzeichenkette bei %L überschreitet Zeichenkettenlänge"
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "End-Index der Teilzeichenkette bei %L ist zu groß"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Ungültige Feldreferenz bei %L"
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponente rechts einer Teilreferenz mit Rang größer Null darf kein POINTER-Attribut bei %L haben"
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponente rechts einer Teilreferenz mit Rang ungleich Null darf bei %L kein Attribut ALLOCATABLE haben"
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Zwei oder mehr Teilreferenzen mit Rang größer Null dürfen nicht bei %L angegeben werden"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Variable %s vermuteten Typs bei %L kann nur als effektives Argument verwendet werden"
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Variable %s vermuteten Typs bei %L kann nur als effektives Argument verwendet werden"
@@ -52311,12 +52367,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variable %s vermuteten Typs bei %L als effektives Argument für Abfragefunktion sollte das erste Argument sein"
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Variable %s vermuteten Ranges bei %L kann nur als effektives Argument verwendet werden"
@@ -52325,259 +52381,259 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variable %s vermuteten Ranges bei %L als effektives Argument für Abfragefunktion sollte das erste Argument sein"
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Variable %s vermuteten Typs bei %L sollte keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Variable %s vermuteten Typs bei %L sollte keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Variable »%s« vermuteten Ranges bei %L sollte keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "In Spezifikationsausdruck verwendete Variable »%s« wird bei %L vor Anweisung ENTRY referenziert, in der sie ein Parameter ist"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variable »%s« wird bei %L vor Anweisung ENTRY verwendet, in der sie ein Parameter ist"
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorphes Subobjekt des koindizierten Objektes bei %L"
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Koindiziertes Objekt mit polymorpher reservierbarer Subkomponente bei %L"
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Weitergegebenes Objekt bei %L muss Skalar sein"
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type '%s'"
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der Prozedurzeigerkomponente bei %L hat abstrakten Typ »%s«"
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for type-bound procedure call at %L is of ABSTRACT type '%s'"
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der typgebundenen Prozedur bei %L hat abstrakten Typ »%s«"
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basisobjekt für Aufruf der typgebundenen NOPASS-Prozedur bei %L muss skalar sein"
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Keine passende spezifische Bindung für Aufruf des GENERIC »%s« bei %L gefunden"
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' bei %L sollte eine SUBROUTINE sein"
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "»%s« bei %L sollte eine FUNCTION sein"
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Ausdruckstyp erwartet"
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s bei %L muss skalar sein"
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s bei %L muss ganzzahlig sein"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s bei %L muss INTEGER sein"
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Schrittausdruck in DO-Schleife bei %L kann nicht Null sein"
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-Schleife bei %L wird null mal ausgeführt"
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-Indexname bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Anfangsausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Endausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-Schrittausdruck bei %L muss skalares %s sein"
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-Schrittausdruck bei %L kann nicht Null sein"
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-Index »%s« kann nicht in Tripel-Spezifikation bei %L auftreten"
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "ALLOCATE-Objekt bei %L muss ALLOCATABLE oder ein POINTER sein"
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Koindiziertes reservierbares Objekt bei %L"
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Quell-Ausdruck bei %L muss skalar sein oder den selben Rang wie das ALLOCATE-Objekt bei %L haben"
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Quell-Ausdruck bei %L und ALLOCATE-Objekt bei %L müssen dieselbe Form haben"
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typ der Entität bei %L ist mit Quellausdruck bei %L typunverträglich"
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Das ALLOCATE-Objekt bei %L und der Quellausdruck bei %L sollten Typparameter der gleichen Art haben"
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Der Quellausdruck bei %L sollte weder LOCK_TYPE noch LOCK_TYPE-Komponente haben, wenn ALLOCATE-Objekt bei %L ein Koarray ist"
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Reservierung von %s mit ABSTRACT-Basistyp bei %L erfordert Typspezifikation oder Quellausdruck"
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Reservierung von %s bei %L mit Typspezifikation erfordert den selben Zeichenkettenlängenparameter wie in der Deklaration"
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "In ALLOCATE-Anweisung bei %L ist Feld-Spezifikation erforderlich"
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Koarray-Spezifikation in ALLOCATE-Anweisung bei %L erforderlich"
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Falsche Feldspezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "»%s« darf nicht bei %L in einer Feldspezifikation in der gleichen ALLOCATE-Anweisung auftreten, wo es selbst alloziert wird"
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "In Koindex-Spezifikation in ALLOCATE-Anweisung bei %L wird »*« erwartet"
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Falsche Koarray-Spezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-Variable bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-Variable bei %L sollte nicht %s innerhalb der gleichen %s-Anweisung sein"
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG bei %L ist ohne STAT-Marke nutzlos"
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG-Variable bei %L muss skalare CHARACTER-Variable sein"
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "ERRMSG-Variable bei %L sollte nicht »%s« innerhalb der selben »%s«-Anweisung sein"
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "ALLOCATE-Objekt bei %L tritt auch bei %L auf"
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "ALLOCATE-Objekt bei %L ist Subobjekt des Objekts bei %L"
@@ -52586,121 +52642,121 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-Marke bei %L überschneidet sich mit CASE-Marke bei %L"
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss Typ %s haben"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss von der Art %d sein"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss skalar sein"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Auswahlausdruck in berechneter GOTO-Anweisung bei %L muss ein skalarer Ganzzahlausdruck sein"
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument der SELECT-Anweisung bei %L kann nicht %s sein"
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argument der SELECT-Anweisung bei %L muss ein skalarer Ausdruck sein"
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L ist nicht im Bereich von %s"
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Der DEFAULT CASE bei %L kann nicht von zweitem DEFAULT CASE bei %L gefolgt werden"
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logischer Bereich in CASE-Anweisung bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstanter logischer Wert in CASE-Anweisung wird bei %L wiederholt"
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Bereichsspezifikation bei %L kann nie passen"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logischer SELECT CASE Block bei %L hat mehr als zwei Fälle"
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' at %L is used as array"
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Zugeordneter Name »%s« bei %L wird als Feld verwendet"
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-Selektor bei %L erfordert Zwischenspeicher, was noch nicht implementiert ist"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektor sollte in SELECT TYPE-Anweisung bei %L polymorph sein"
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektor bei %L darf nicht koindiziert sein"
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Abgeleiteter Typ »%s« bei %L muss erweiterbar sein"
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be an extension of '%s'"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Abgeleiteter Typ »%s« bei %L muss eine Erweiterung von »%s« sein"
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected intrinsic type '%s' at %L"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Unerwarteter intrinsischer Typ »%s« bei %L"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "In Typspezifikation bei %L sollten alle Parameter mit Längentyp vermutet sein"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Doppelter CLASS IS-Block in SELECT TYPE-Anweisung bei %L"
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
@@ -52707,72 +52763,72 @@
 msgstr "Ungültiger Kontext für NULL()-Zeiger bei %%L"
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Element zum Datenaustausch bei %L kann nicht polymorph sein, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine POINTER-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Datenübertragungselement bei %L kann keine Prozedurzeiger-Komponenten haben"
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine ALLOCATABLE-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Datenübertragungselement bei %L kann keine PRIVATE-Komponenten haben"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Datenübertragungselement bei %L kann keine vollständige Referenz auf Feld vermuteter Größe sein"
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Lock-Variable bei %L muss Skalar mit LOCK_TYPE sein"
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "»STAT=«-Argument bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "»ERRMSG=«-Argument bei %L muss skalare CHARACTER-Variable sein"
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "»ACQUIRED_LOCK=«-Argument bei %L muss skalare LOGICAL-Variable sein"
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argument für Imageset bei %L muss Skalar oder Rang-1-INTEGER-Ausdruck sein"
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argument für Imageset bei %L muss zwischen 1 und num_images() liegen"
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Anweisung bei %L ist keine gültige Sprungzielanweisung für Sprungziel bei %L"
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Sprung bei %L könnte Endlosschleife bewirken"
@@ -52779,12 +52835,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt CRITICAL-Konstrukt für Marke bei %L"
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt DO CONCURRENT-Konstrukt für Marke bei %L"
@@ -52792,166 +52848,166 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Marke bei %L ist nicht im gleichen Block wie GOTO-Anweisung bei %L"
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-Maske bei %L hat ungültige Form"
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-Zuweisungsziel bei %L hat ungültige Form"
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Benutzerdefinierte Nicht-ELEMENTAL-Zuweisung in WHERE bei %L"
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Nicht unterstützte Anweisung in WHERE bei %L"
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Zuweisung an FORALL-Indexvariable bei %L"
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "Das FORALL mit Index »%s« wird nicht auf der linken Seite der Zuweisung bei %L verwendet und könnte somit mehrere Zuweisungen an dieses Objekt auslösen"
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Ein äußeres FORALL-Konstrukt hat bereits einen Index mit Namen %L"
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Klausel WHERE/ELSEWHERE bei %L erfordert ein LOGICAL-Feld"
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr "CHARACTER-Ausdruck wird in Zuweisung (%d/%d) bei %L abgeschnitten"
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Koindizierter Ausdruck bei %L wird einer Variable abgeleiteten Typs mit einer POINTER-Komponente in einer PURE-Prozedur zugewiesen"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Die unreine Variable bei %L wird einer Variable abgeleiteten Typs mit einer POINTER-Komponente in einer PURE-Prozedur zugewiesen (12.6)"
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Zuweisung an koindizierte Variable bei %L in einer PURE-Prozedur"
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Polymorphic array at %C not yet supported"
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Polymorphes Feld bei %C wird noch nicht unterstützt"
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Zuweisung an FORALL-Indexvariable bei %L"
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Polymorphic array at %C not yet supported"
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr "Polymorphes Feld bei %C wird noch nicht unterstützt"
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "Variable darf in intrinsischer Zuweisung bei %L nicht polymorph sein - bitte prüfen, ob es ein passendes spezifisches Unterprogramm für den »=«-Operator gibt"
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coindexed variable must not be have an allocatable ultimate component in assignment at %L"
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Koindizierte Variable darf keine reservierbare endgültige Komponente in Zuweisung bei %L haben"
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "TODO: als typgebunden definierte Zuweisung(en) bei %L nicht durchgeführt, da Feldreferenzen mit mehreren Teilen in Audrücken als Zwischenergebnisse auftreten würden"
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "Anweisung ASSIGNED GOTO bei %L erfordert eine INTEGER-Variable"
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variable »%s« wurde keine Zielmarke bei %L zugewiesen"
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternative RETURN-Anweisung bei %L erfordert einen SCALAR-INTEGER-Spezifizierer als Rückgabe"
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-Anweisung bei %L erfordert eine skalare Standard-INTEGER-Variable"
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr "Arithmetische IF-Anweisung bei %L erfordert einen numerischen Ausdruck"
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Abbruchbedingung der DO WHILE-Schleife bei %L muss ein skalarer LOGICAL-Ausdruck sein"
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-Maskenklausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Falscher Anweisungscode"
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
@@ -52959,7 +53015,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -52967,64 +53023,64 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr "Binde-Marke »%s« bei %L kollidiert mit dem globalen Eintrag »%s« bei %L"
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr "CHARACTER-Variable bei %L hat negative Länge %d, die Länge wurde auf Null gesetzt"
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Zeichenkettenlänge bei %L ist zu groß"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape or assumed rank"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Reservierbares Feld »%s« bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalares Objekt »%s« bei %L kann nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape or assumed rank"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Feldzeiger »%s« bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Feld »%s« bei %L kann keine aufgeschobene Form haben"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' of CLASS variable '%s' at %L is not extensible"
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typ »%s« der CLASS-Variable »%s« bei %L ist nicht erweiterbar"
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable '%s' at %L must be dummy, allocatable or pointer"
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-Variable »%s« bei %L muss Attrappe, reservierbar oder Zeiger sein"
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Der Typ %s kann bei %L nicht mit Wirt verbunden werden, da er von unverträglichem bei %L definiertem Objekt mit gleichem Namen blockiert wird"
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, fuzzy, gcc-internal-format
 #| msgid "Implied SAVE for module variable '%s' at %L, needed due to the default initialization"
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
@@ -53032,492 +53088,492 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr "Das Feld »%s« im Modul oder Hauptprogramm bei %L muss konstante Form haben"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr "Entität »%s« bei %L hat Parameter mit aufgeschobenem Typ und benötgt entweder das POINTER- oder ALLOCATABLE-Attribut"
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entität mit vermuteter Zeichenlänge bei %L muss ein Scheinargument oder ein PARAMETER sein"
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr "»%s« bei %L muss in diesem Zusammenhang konstante Zeichenlänge haben"
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-Variable »%s« bei %L muss konstante Zeichenlänge haben"
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Zuordnungsfähiges »%s« bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Externes »%s« bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Schein-»%s« bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsisches »%s« bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsergebnis »%s« bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisches Feld »%s« bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Zeichenwertige Anweisungsfunktion »%s« bei %L muss konstante Länge haben"
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "»%s« hat PRIVATE-Typ und kann kein Scheinargument von »%s« sein, das PUBLIC bei %L ist"
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Prozedur »%s« in PUBLIC-Schnittstelle »%s« bei %L nimmt Scheinargumente von »%s«, das PRIVATE ist"
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion »%s« bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externes Objekt »%s« bei %L darf keine Initialisierung haben"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Elementare Funktion »%s« bei %L muss ein skalares Ergebnis haben"
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L may not have pointer or allocatable attribute"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Anweisungsfunktion »%s« bei %L darf nicht POINTER- oder ALLOCATABLE-Attribut haben"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-Funktion »%s« bei %L kann nicht Feld-wertig sein"
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-Funktion »%s« bei %L kann nicht Zeiger-wertig sein"
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-Funktion »%s« bei %L kann nicht pure sein"
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-Funktion »%s« bei %L kann nicht rekursiv sein"
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-Funktion »%s« bei %L"
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prozedur »%s« in %s bei %L hat keine explizite Schnittstelle"
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Scheinprozedur »%s« bei %C kann keine allgemeine Schnittstelle haben"
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut SAVE in »%s« bei %L in Konflikt"
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut INTENT in »%s« bei %L in Konflikt"
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut RESULT in »%s« bei %L in Konflikt"
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, fuzzy, gcc-internal-format
 #| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Attribut EXTERNAL steht mit Attribut FUNCTION in »%s« bei %L in Konflikt"
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer result '%s' at %L is missing the pointer attribute"
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Dem Ergebnis »%s« als Prozedurzeiger bei %L fehlt das POINTER-Attribut"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-Prozedur »%s« bei %L ist keine SUBROUTINE"
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-Prozedur bei %L muss genau ein Argument haben"
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument der FINAL-Prozedur bei %L muss Typ »%s« haben"
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument der FINAL-Prozedur bei %L darf kein POINTER sein"
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht OPTIONAL sein"
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Nicht-skalare FINAL-Prozedur bei %L sollte Argument mit vermuteter Form haben"
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Bei %2$L deklarierte FINAL-Prozedur »%1$s« hat den selben Rang (%3$d) wie »%4$s«"
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Bei %2$L wurde nur FINAL-Feldprozedur für abgeleiteten Typ »%1$s« definiert, skalare wird ebenfalls empfohlen"
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "»%s« und »%s« können nicht gemischte FUNCTION/SUBROUTINE für GENERIC »%s« bei %L sein"
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "»%s« und »%s« für GENERIC »%s« bei %L sind mehrdeutig"
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Undefinierte spezifische Bindung »%s« als Ziel des GENERIC »%s« bei %L"
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC »%s« bei %L muss auf spezifische Bindung abzielen, »%s« ist ebenfalls GENERIC"
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "GENERIC »%s« bei %L kann nicht spezifische Bindung mit gleichem Namen überschreiben"
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "Typgebundener Operator bei %L kann nicht NOPASS sein"
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "»%s« muss eine Modulprozedur oder eine externe Prozedur mit expliziter Schnittstelle bei %L sein"
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedur »%s« mit PASS(%s) bei %L hat kein Argument »%s«"
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prozedur »%s« mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 #| msgid "Non-polymorphic passed-object dummy argument of '%s' at %L"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Nicht-polymorphes Scheinargument von %s für weitergegebenes Objekt bei %L"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument »%s« von »%s« mit PASS(%s) bei %L muss abgeleiteten Typ »%s« haben"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Scheinargument von %s für weitergegebenes Objekt bei %L muss ein Skalar sein"
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Scheinargument von %s für weitergegebenes Objekt bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Scheinargument von %s für weitergegebenes Objekt bei %L darf nicht POINTER sein"
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prozedur »%s« bei %L hat den gleichen Namen wie eine Komponente von »%s«"
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prozedur »%s« bei %L hat den selben Namen wie eine vererbte Komponente von »%s«"
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' declared at %L must be ABSTRACT because '%s' is DEFERRED and not overridden"
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Bei %2$L deklarierter abgeleiteter Typ »%1$s« muss ABSTRACT sein, da »%3$s« DEFERRED und nicht überschrieben ist"
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, fuzzy, gcc-internal-format
 #| msgid "As extending type '%s' at %L has a coarray component, parent type '%s' shall also have one"
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Da der erweiterte Typ »%s« bei %L eine Koarray-Komponente hat, sollte der Elterntyp »%s« auch eine haben"
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Nicht-erweiterbarer abgeleiteter Typ »%s« bei %L darf nicht ABSTRACT sein"
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray component '%s' at %L must be allocatable with deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Koarray-Komponente »%s« bei %L muss reservierbar mit aufgeschobener Form sein"
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponente »%s« bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) sollte kein Koarray sein"
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponente »%s« bei %L mit Koarray-Komponente sollte ein Nicht-Zeiger und nicht-reservierbares Skalar sein"
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Komponente »%s« bei %L hat das CONTIGUOUS-Attribut, aber ist kein Feldzeiger"
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedurzeiger-Komponente »%s« mit PASS(%s) bei %L hat kein Argument »%s«"
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prozedurzeiger-Komponente »%s« mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument »%s« von »%s« mit PASS(%s) bei %L muss abgeleiteten Typ »%s« haben"
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Parameter »%s« von »%s« mit PASS(%s) bei %L muss skalar sein"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argument »%s« von »%s« mit PASS(%s) bei %L darf kein POINTER-Attribut haben"
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argument »%s« von »%s« mit PASS(%s) bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponente »%s« von »%s« bei %L hat den gleichen Namen wie eine geerbte typgebundene Prozedur"
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Zeichenlänge der Komponente »%s« muss ein konstanter Spezifikationsausdruck bei %L sein"
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, fuzzy, gcc-internal-format
 #| msgid "Character component '%s' of '%s' at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Zeichenkomponente »%s« von »%s« bei %L mit aufgeschobener Länge muss POINTER oder ALLOCATABLE sein"
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, fuzzy, gcc-internal-format
 #| msgid "the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Die Komponente »%s« ist ein PRIVATE-Typ und kann nicht Komponente von »%s« sein, die PUBLIC bei %L ist"
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphe Komponente %s bei %L in SEQUENCE oder BIND(C)-Typ %s"
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponente %s des bei %L deklarierten SEQUENCE-Typen hat kein SEQUENCE-Attribut"
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Die Zeigerkomponente »%s« bei »%s« bei %L hat nicht deklarierten Typ"
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr "Komponente »%s« mit CLASS bei %L muss allozierbar oder Zeiger sein"
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr "Allgemeiner Name »%s« der Funktion »%s« bei %L ist der gleiche wie der des abgeleiteten Typs bei %L"
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %L is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Feld »%s« mit vermuteter Größe in Namensliste »%s« bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' with assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt »%s« mit vermuteter Form in Namensliste »%s« bei %L"
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' with nonconstant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt »%s« ohne konstante Form in Namensliste »%s« bei %L"
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' with nonconstant character length in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-Objekt »%s« ohne konstante Zeichenlänge in Namensliste »%s« bei %L"
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' in namelist '%s' at %L is polymorphic and requires a defined input/output procedure"
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-Objekt »%s« in Namensliste »%s« bei %L ist polymorph und erfordert eine definierte Ein-/Ausgabeprozedur"
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -53525,442 +53581,442 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' in namelist '%s' at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr "NAMELIST-Objekt »%s« in Namensliste »%s« bei %L hat ALLOCATABLE- oder POINTER-Komponenten und erfordert daher eine definierte Ein-/Ausgabeprozedur"
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt »%s« wurde als PRIVATE deklariert und kann kein Element der PUBLIC-Namensliste »%s« bei %L sein"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-Objekt »%s« hat benutzungs-verbundene PRIVATE-Komponenten und kann kein Element der Namensliste »%s« bei %L sein"
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt »%s« hat PRIVATE-Komponenten und kann kein Element der PUBLIC-Namensliste »%s« bei %L sein"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut NAMELIST in »%s« bei %L in Konflikt"
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameterfeld »%s« bei %L kann nicht automatische oder vermutete Form haben"
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implizit angegebener PARAMETER »%s« bei %L passt nicht zu früherem IMPLICIT-Typ"
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Unverträglicher abgeleiteter Typ in PARAMETER bei %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attribut PROTECTED steht mit Attribut EXTERNAL bei %L in Konflikt"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut PROTECTED bei %L in Konflikt"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "»%s« bei %L hat Attribut CONTIGUOUS, aber ist kein Feldzeiger oder Feld vermuteter Größe oder Rang"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Größe bei %L muss ein Schein-Argument sein"
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Form bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Feld mit vermutetem Rang bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Feld mit vermutetem Rang bei %L darf kein Attribut VALUE oder CODIMENSION haben"
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol bei %L ist keine Scheinvariable"
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "»%s« bei %L kann nicht das VALUE-Attribut haben, da es kein Scheinargument ist"
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Zeichenwertige Scheinvariable »%s« bei %L mit VALUE-Attribut muss konstante Länge haben"
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-kompatible zeichenwertige Scheinvariable »%s« bei %L mit VALUE-Attribut muss Länge eins haben"
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Der abgeleitete Typ »%s« bei %L hat Typ »%s«, der nicht definiert wurde"
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Vermuteter Typ der Variable %s bei %L ist nur für Scheinvariablen erlaubt"
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variable %s vermuteten Typs bei %L sollte kein Feld mit ausdrücklicher Form sein"
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variable »%s« bei %L kann nicht BIND(C) sein, weil es weder ein COMMON-Block noch mit Sichtbarkeit auf Modulebene deklariert ist"
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s »%s« bei %L mit abgeleitetem PRIVATE-Typen »%s«"
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variable %s bei %L mit LOCK_TYPE oder mit Subkomponente mit LOCK_TYPE muss ein Koarray sein"
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Das INTENT(OUT)-Scheinargument »%s« bei %L hat vermutete Größe und kann damit keine Standardinitialisierung haben"
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument »%s« bei %L mit LOCK_TYPE sollte nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L shall not be a coarray or have a coarray component"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsergebnis »%s« bei %L sollte kein Koarray sein oder Koarray-Komponente haben"
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variable »%s« bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) sollte kein Koarray sein"
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variable »%s« bei %L mit Koarraykomponente sollte ein Nichtzeiger, nichtallozierbares Skalar sein"
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variable »%s« bei %L ist ein Koarray und ist weder ALLOCATABLE, SAVE, noch ein Scheinargument"
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Koarray-Variable »%s« bei %L sollte keine Kodimensionen mit aufgeschobener Form haben"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable coarray variable '%s' at %L must have deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Zuordnungsfähige Koarray-Variable »%s« bei %L muss aufgeschobene Form haben"
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variable '%s' bei %L ist INTENT(OUT) und kann daher kein reservierbares Coarray sein oder Coarray-Komponenten haben"
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray-Hilfsvariable '%s' bei %L in BIND(C)-Prozedur '%s' nicht erlaubt"
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, fuzzy, gcc-internal-format
 #| msgid "LOGICAL dummy argument '%s' at %L with non-C_Bool kind in BIND(C) procedure '%s'"
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Scheinargument '%s' bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur '%s'"
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, fuzzy, gcc-internal-format
 #| msgid "LOGICAL result variable '%s' at %L with non-C_Bool kind in BIND(C) procedure '%s'"
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Rückgabevariable '%s' bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur '%s'"
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate bei %L ist nicht SAVEd"
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA Element »%s« bei %L muss in COMMON sein"
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-Feld »%s« bei %L muss in vorheriger Deklaration angegeben werden"
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L cannot have a coindex"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-Element '%s' bei %L kann keinen Coindex haben"
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L is a pointer and so must be a full array"
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-Element '%s' bei %L ist ein Zeiger und muss daher ein vollständiges Feld sein"
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Abschnitt eines nicht konstanten Feldes bei %L in DATA-Anweisung"
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-Anweisung bei %L hat mehr Variablen als Werte"
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Anfang der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Ende der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Schritt der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-Anweisung bei %L hat mehr Werte als Variablen"
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Marke %d bei %L definiert, aber nicht verwendet"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Marke %d bei %L definiert, kann aber nicht verwendet werden"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Variable »%s« abgeleiteten Typs bei %L muss SEQUENCE-Attribut haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Variable »%s« abgeleiteten Typs bei %L kann keine ALLOCATABLE-Komponenten haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Variable »%s« abgeleiteten Typs bei %L mit Standardinitialisierung kann nicht in EQUIVALENCE mit einer Variablen in COMMON sein"
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Variable »%s« abgeleiteten Typs bei %L mit Zeigerkomponenten kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfehler in EQUIVALENCE-Anweisung bei %L"
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Entweder alle oder keines der Objekte in bei %L gesetztem EQUIVALENCE sollte das Attribut PROTECTED haben"
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Allgemeines Blockelement »%s« bei %L kann kein EQUIVALENCE-Objekt in PURE-Prozedur »%s« sein"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Benannte Konstante »%s« bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Feld »%s« bei %L mit nicht-konstanten Grenzen kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Strukturkomponente »%s« bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Teilzeichenkette bei %L hat Länge Null"
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-Funktion »%s« bei %L mit PRIVATE-Typen »%s«"
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY »%s« bei %L hat keinen IMPLICIT-Typ"
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prozedur für Benutzeroperator »%s« bei %L muss eine FUNKTION sein"
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prozedur für Benutzeroperator »%s« bei %L kann nicht vermutete Zeichenlänge haben"
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prozedur für Benutzeroperator »%s« bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorschnittstelle bei %L darf höchstens zwei Argumente haben"
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -53995,49 +54051,49 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr "!$OMP bei %C beginnt eine kommentierte Zeile, da es weder von Leerzeichen gefolgt wird noch eine Fortsetzungszeile ist"
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr "Zeile bei %L wird abgeschnitten"
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr "Grenze von %d Fortsetzungen in Anweisung bei %C überschritten"
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "Missing '&' in continued character constant at %C"
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "In fortgesetzter Zeichenkonstante bei %C fehlt »&«"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr "Tab-Zeichen bei %C passt nicht"
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "'&' not allowed by itself in line %d"
 msgid "%<&%> not allowed by itself in line %d"
 msgstr "»&« ist in Zeile %d selbst nicht erlaubt"
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr "Unpassendes Tab-Zeichen in Spalte %d der Zeile %d"
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr "%s:%d: Datei %s verlassen, aber nicht betreten"
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr "%s:%d: Ungültige Präprozessordirektive"
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open file '%s'"
 msgid "Can't open file %qs"
@@ -54306,55 +54362,55 @@
 msgid "Reshaped array too large at %C"
 msgstr "Ganzzahl bei %C zu groß"
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "Ergebnis von SCALE überschreitet seine Art bei %L"
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Falscher Typ in Konstanten-Ausdruck"
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "Argument von SQRT bei %L hat negativen Wert"
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid second argument of IBSET at %L"
 msgid "invalid argument of SQRT at %L"
 msgstr "Ungültiges zweites Argument von IBSET bei %L"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr "Außerhalb des Wertebereichs in IMAGE_INDEX bei %L für Dimension %d, SUB hat %ld und untere Grenze für COARRAY ist %ld"
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr "Außerhalb des Wertebereichs in IMAGE_INDEX bei %L für Dimension %d, SUB hat %ld und obere Grenze für COARRAY ist %ld"
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_conv_constant_to_tree(): invalid type: %s"
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): ungültiger Typ: %s"
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, fuzzy, gcc-internal-format
 #| msgid "Character '%s' in string at %L cannot be converted into character kind %d"
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
@@ -54440,267 +54496,273 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "Name der Namenslisten-Gruppe bei %L kann kein SAVE-Attribut haben"
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Internal procedure '%s' is used as actual argument at %L"
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "Interne Prozedur »%s« wird als effektives Argument bei %L verwendet"
+
+#: fortran/symbol.c:489
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "Prozedur-Zeiger bei %C"
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "Attribut %s auf %s %s bei %L angewendet"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) auf %s %s bei %L angewendet"
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "Attribut %s steht mit Attribut %s bei %L in Konflikt"
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr "Attribut %s steht mit Attribut %s in »%s« bei %L in Konflikt"
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute with %s attribute at %L"
 msgstr "Attribut %s mit Attribut %s bei %L"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute with %s attribute in '%s' at %L"
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr "Attribut %s mit Attribut %s in »%s« bei %L"
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "Attribute des USE-verbundenen Symbols bei %L können nicht verändert werden"
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "Attribute des USE-verbundenen Symbols %s bei %L können nicht verändert werden"
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Attribut %s doppelt angegeben bei %L"
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "ALLOCATABLE außerhalb des INTERFACE-Körpers bei %L angegeben"
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, fuzzy, gcc-internal-format
 #| msgid "CODIMENSION specified for '%s' outside its INTERFACE body at %L"
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "CODIMENSION für »%s« außerhalb seines INTERFACE-Körpers bei %L angegeben"
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, fuzzy, gcc-internal-format
 #| msgid "DIMENSION specified for '%s' outside its INTERFACE body at %L"
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "DIMENSION für »%s« außerhalb seines INTERFACE-Körpers bei %L angegeben"
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "Cray-Zeigerende bei %L tritt in mehreren pointer()-Anweisungen auf"
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Doppeltes PROTECTED-Attribut bei %L angegeben"
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "SAVE-Attribut bei %L kann nicht in einer PURE-Prozedur angegeben werden"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "SAVE-Attribut doppelt angegeben bei %L"
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Doppeltes VALUE-Attribut bei %L angegeben"
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Doppeltes VOLATILE-Attribut bei %L angegeben"
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Doppeltes ASYNCHRONOUS-Attribut bei %L angegeben"
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "Attribut %s von »%s« steht mit Attribut %s bei %L in Konflikt"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "Prozedur %s bei %L ist bereits als Prozedur %s deklariert"
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT(%s) steht mit INTENT(%s) bei %L in Konflikt"
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "ACCESS-Spezifikation bei %L wurde bereits spezifiziert"
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Doppeltes BIND-Attribut bei %L angegeben"
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) bei %L"
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Doppeltes EXTENDS-Attribut bei %L angegeben"
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS bei %L"
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Symbol »%s« bei %L hat bereits eine explizite Schnittstelle"
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has attributes specified outside its INTERFACE body"
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "»%s« bei %L hat außerhalb seines INTERFACE-Körpers spezifizierte Attribute"
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr "Symbol »%s« bei %L steht mit Symbol aus Modul »%s« in Konflikt, verbunden durch Verwendung bei %L"
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Symbol »%s« bei %L hat bereits grundlegenden Typen %s"
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Prozedur »%s« bei %L kann nicht grundlegenden Typen %s haben"
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Symbol »%s« bei %L kann keinen Typen haben"
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr "Komponente »%s« bei %C bereits bei %L deklariert"
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr "Komponente »%s« bei %C bereits im Elterntypen bei %L deklariert"
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Symbol »%s« bei %C ist mehrdeutig"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Abgeleiteter Typ »%s« bei %C wird benutzt bevor er definiert wird"
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Komponente »%s« bei %C ist eine PRIVATE-Komponente von »%s«"
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "»%s« bei %C ist kein Element der Struktur »%s«"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Doppelte Anweisungsmarke %d bei %L und %L"
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Marke %d bei %C bereits als Sprungziel referenziert"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Marke %d bei %C bereits als eine Formatmarke referenziert"
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "DO-Abbruchanweisung ist nicht »END DO« oder »CONTINUE« mit Marke %d bei %C"
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Marke %d bei %C vorher als FORMAT-Marke verwendet"
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Marke %d bei %C vorher als Sprungziel verwendet"
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Gemeinsam genutzte DO-Abbruchmarke %d bei %C"
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr "new_symbol(): Symbolname zu lang"
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Name »%s« bei %C ist eine mehrdeutige Referenz auf »%s« vom Modul »%s«"
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
@@ -54707,69 +54769,69 @@
 msgstr "Name »%s« bei %C ist eine mehrdeutige Referenz auf »%s« von aktueller Programmeinheit"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Symbol »%s« bei %C wurde bereits mit Host verbunden"
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' declared at %L must have the BIND attribute to be C interoperable"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Abgeleiteter Typ »%s«, bei %L deklariert, muss BIND-Attribut haben, um C-kompatibel zu sein"
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Abgeleiteter Typ »%s« mit Attribut BIND(C) bei %L ist leer und könnte für entsprechenden C-Prozessor unerreichbar sein"
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr "Komponente »%s« bei %L kann nicht POINTER-Attribut haben, da es Element des BIND(C)-abgeleiteten Typs »%s« bei %L ist"
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr "Komponente »%s« des Prozedurzeigers bei %L kann kein Element des BIND(C)-abgeleiteten Typs »%s« bei %L sein"
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr "Komponente »%s« bei %L kann nicht ALLOCATABLE-Attribut haben, da es Element des BIND(C)-abgeleiteten Typs »%s« bei %L ist"
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable, even though derived type '%s' is BIND(C)"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Komponente »%s« in abgeleiteten Typ »%s« bei %L könnte nicht C-kompatibel sein, obwohl abgeleiteter Typ »%s« BIND(C) ist"
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Komponente »%s« in abgeleitetem Typ »%s« bei %L könnte nicht C-kompatibel sein"
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "Abgeleiteter Typ »%s« bei %L kann nicht mit Attributen PRIVATE und BIND(C) deklariert werden"
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Abgeleiteter Typ »%s« bei %L kann nicht das SEQUENCE-Attribut haben, da es BIND(C) ist"
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Symbol %qs wird bei %L verwendet, bevor es typisiert wird"
@@ -55038,7 +55100,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr "Falscher IO-Basistyp (%d)"
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr "gfc_trans_omp_workshare(): Falscher Anweisungscode"
@@ -56586,6 +56648,32 @@
 msgid "creating selector for nonexistent method %qE"
 msgstr "für nicht existierende Methode %qE wird Selektor erzeugt"
 
+#, fuzzy
+#~| msgid "Use SmartMIPS instructions"
+#~ msgid "Use ISA 2.07 crypto instructions"
+#~ msgstr "SmartMIPS-Befehle verwenden"
+
+#, fuzzy
+#~| msgid "%s variable %qE is private in outer context"
+#~ msgid "lastprivate variable %qE is private in outer context"
+#~ msgstr "%s Variable %qE ist im äußeren Kontext »private«"
+
+#~ msgid "-munix=98 option required for C89 Amendment 1 features.\n"
+#~ msgstr "Option -munix=98 für Eigenschaften des C89 Amendment 1 erforderlich.\n"
+
+#~ msgid "ISO C++ forbids subscripting non-lvalue array"
+#~ msgstr "ISO-C++ verbietet Indizierung eines Nicht-L-Wert-Feldes"
+
+#, fuzzy
+#~| msgid "gfc_trans_code(): Bad statement code"
+#~ msgid "gfc_match_entry(): Bad state"
+#~ msgstr "gfc_trans_code(): Falscher Anweisungscode"
+
+#, fuzzy
+#~| msgid "Unexpected %s statement in MODULE at %C"
+#~ msgid "Unexpected %s statement in verify_st_order() at %C"
+#~ msgstr "Unerwartete Anweisung %s in MODULE bei %C"
+
 #~ msgid "optimizing for size and code size would grow"
 #~ msgstr "bei Optimierung nach Größe würde Codegröße wachsen"
 
Index: gcc/po/ja.po
===================================================================
--- gcc/po/ja.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/ja.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -19,7 +19,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.6.1\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2011-10-30 18:48+0900\n"
 "Last-Translator: Yasuaki Taniguchi <yasuakit@gmail.com>\n"
 "Language-Team: Japanese <translation-team-ja@lists.sourceforge.net>\n"
@@ -211,13 +211,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "浮動小数定数を使い損ねました"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1435,7 +1435,7 @@
 msgid "options enabled: "
 msgstr "有効オプション: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2659,97 +2659,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "無効な被演算子コード '%c' です"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "局所動的 TLS 参照無しで '%%&' が使用されました"
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "無効な %%H 値"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "無効な %%J 値"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "無効な %%r 値"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "無効な %%R 値"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "無効な %%N 値"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "無効な %%P 値"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "無効な %%h 値"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "無効な %%L 値"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "無効な %%m 値"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "無効な %%M 値"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "無効な %%U 値"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "無効な %%s 値"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "無効な %%C 値"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "無効な %%E 値"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr ""
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "無効な %%xn コード"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid operand address"
@@ -2802,7 +2802,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "無効な被演算子出力コード"
@@ -2965,8 +2965,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3186,68 +3186,68 @@
 msgid "bad output_condmove_single operand"
 msgstr "誤った output_condmove_single 被演算子"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "被演算子として無効な UNSPEC です"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, fuzzy, c-format
 #| msgid "invalid operand type used with operand code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "被演算子コード '%c' に無効な被演算子型が使用されました"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'Y' です"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "無効な被演算子コード '%c' です"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "演算子に対する無効な制約です"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "不明な命令モード"
 
@@ -3287,7 +3287,7 @@
 msgid "invalid %%P operand"
 msgstr "無効な %%P 被演算子です"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "無効な %%p 値です"
@@ -3351,7 +3351,7 @@
 msgstr "後置増分アドレスがレジスタではありません"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "誤ったアドレスです"
 
@@ -3517,102 +3517,102 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "リトルエンディアンモードでコードを生成する"
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 msgid "bad move"
 msgstr "誤った move です"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "無効な %%H 値"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "無効な %%f 値です"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "無効な %%F 値です"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "無効な %%G 値です"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "無効な %%j コードです"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "無効な %%J コードです"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "無効な %%k 値です"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "無効な %%K 値です"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "無効な %%O 値です"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "無効な %%q 値です"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "無効な %%S 値です"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "無効な %%T 値です"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "無効な %%u 値です"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "無効な %%v 値です"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "無効な %%x 値です"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無効な %%y 値です。'Z' 制約を使用してみてください"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "各関数で単一の終了点を生成しない"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 msgid "Unable to generate load offset for fusion"
 msgstr ""
 
@@ -3706,34 +3706,34 @@
 msgid "invalid operand to %%S"
 msgstr "%%S への無効な被演算子です"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr "作成時と使用時で アーキテクチャ/ABI が異なります"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr "作成時と使用時で ABI が異なります"
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr "作成時と使用時でエンディアンが異なります"
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "無効な %%Y 被演算子です"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "無効な %%A 被演算子です"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "無効な %%B 被演算子です"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
@@ -3740,28 +3740,28 @@
 msgid "invalid %%C operand"
 msgstr "無効な %%P 被演算子です"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
 msgid "invalid %%D operand"
 msgstr "無効な %%P 被演算子です"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "無効な %%f 被演算子です"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "無効な %%s 被演算子です"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "long long 定数は有効な即値被演算子ではありません"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "浮動小数定数は有効な即値被演算子ではありません"
@@ -3988,7 +3988,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> が予期されます"
@@ -4004,15 +4004,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> が予期されます"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> が予期されます"
@@ -4034,8 +4034,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> が予期されます"
@@ -4042,8 +4042,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> が予期されます"
@@ -4052,13 +4052,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> が予期されます"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> が予期されます"
@@ -4065,8 +4065,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> が予期されます"
@@ -4087,7 +4087,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> が予期されます"
@@ -4104,34 +4104,34 @@
 msgid "expected %<.%>"
 msgstr "%<.%> が予期されます"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> が予期されます"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> が予期されます"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> または %<)%> が予期されます"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> が予期されます"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> が予期されます"
@@ -4140,11 +4140,11 @@
 msgid "(anonymous)"
 msgstr "(無名)"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "候補 1:"
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "候補 2:"
 
@@ -4377,11 +4377,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%s:%d:%d:   %qs から実体化されました\n"
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "候補:"
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "候補:"
@@ -4426,48 +4426,48 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "単項マイナスへの引数の型が間違っています"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "単項プラスへの引数の型が間違っています"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "ビット反転への引数の型が間違っています"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs への引数の型が間違っています"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "複素共役(~)への引数の型が間違っています"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4564,7 +4564,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "%C の式内で整数値が大きすぎます"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 msgid "array assignment"
 msgstr "配列代入"
 
@@ -4588,7 +4588,7 @@
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4659,13 +4659,13 @@
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4749,7 +4749,7 @@
 msgid "Bad type in constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "予期しない型が `id' (%s) に指定されました"
@@ -4779,11 +4779,11 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr "代入"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 #, fuzzy
 msgid "pointer assignment"
 msgstr "代入"
@@ -4801,212 +4801,212 @@
 msgid "internal function"
 msgstr "内部エラー"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 #| msgid "no arguments"
 msgid "allocatable argument"
 msgstr "引数がありません"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 #| msgid "not enough arguments"
 msgid "asynchronous argument"
 msgstr "十分な引数がありません"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 #| msgid "invalid PHI argument"
 msgid "optional argument"
 msgstr "無効な PHI 引数です"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 msgid "pointer argument"
 msgstr "代入"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "引数がありません"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 #| msgid "invalid PHI argument"
 msgid "value argument"
 msgstr "無効な PHI 引数です"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "引数がありません"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-shape argument"
 msgstr "合っていない引数です"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-rank argument"
 msgstr "合っていない引数です"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 #| msgid "array assignment"
 msgid "coarray argument"
 msgstr "配列代入"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "引数がありません"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-type argument"
 msgstr "合っていない引数です"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr ""
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE オブジェクト"
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 msgid "ALLOCATE object"
 msgstr "ALLOCATE オブジェクト"
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr "STAT 変数"
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr "ERRMSG 変数"
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5427,18 +5427,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr "rx200 CPU にはハードウェア FPU がありません"
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr "gprof(1) を使うときは '-p' の代わりに '-pg' を使用してください"
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-#, fuzzy
-#| msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr "gprof(1) を使うときは '-p' の代わりに '-pg' を使用してください"
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr "multilib はサポートしません"
@@ -5451,6 +5439,10 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "-Xbind-now と -Xbind-lazy は併用できません"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+msgid "profiling not supported with -mg"
+msgstr "-mg でのプロファイルはサポートされていません"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "-mhard-float はサポートされていません"
@@ -5459,10 +5451,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "-msingle-float と -msoft-float は併用できません"
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr "m210 はリトルエンディアンサポートを行なえません"
-
 #: config/cris/cris.h:184
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "-march=... と -mcpu=... の両方を指定しないでください"
@@ -5495,6 +5483,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr "gprof(1) を使うときは '-p' の代わりに '-pg' を使用してください"
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5501,6 +5495,12 @@
 msgid "may not use both -m32 and -m64"
 msgstr "-m32 と -m64 の両方を使用することはできません"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+#, fuzzy
+#| msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr "gprof(1) を使うときは '-p' の代わりに '-pg' を使用してください"
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr "static は TPF-OS ではサポートされていません"
@@ -5515,6 +5515,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian と -mlittle-endian は併用できません"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr "m210 はリトルエンディアンサポートを行なえません"
+
 #: config/avr/specs.h:68
 #, fuzzy
 #| msgid "-fpic is not supported"
@@ -5544,17 +5548,19 @@
 msgid "no processor type specified for linking"
 msgstr "リンク用のプロセッサ型が指定されていません"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr "警告: システムライブラリとリンクする時は '-static' を指定することを検討してください"
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr "  プロファイリングサポートは書庫フォーマット内でのみ提供されます"
 
@@ -5590,10 +5596,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "-shared オプションは VAX ELF 用には現在はサポートされていません"
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-msgid "profiling not supported with -mg"
-msgstr "-mg でのプロファイルはサポートされていません"
-
 #: fortran/lang.opt:146
 msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgstr ""
@@ -5782,9 +5784,9 @@
 msgstr ""
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
 
@@ -5991,10 +5993,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
 
@@ -6042,7 +6044,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr "%qs の後にファイル名がありません"
@@ -7986,52 +7988,56 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr "ターゲット CPU がリトルエンディアンとして設定されているとみなす"
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 #, fuzzy
 #| msgid "Select code model"
 msgid "Specify the code model"
 msgstr "コードモデルを選択する"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr "末端の関数ではフレームポインタを省略する"
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 #, fuzzy
 #| msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr "-mcpu=\t与えられた CPU 用の機能とスケジュールコードを使用する"
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 #, fuzzy
 #| msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr "-mcpu=\t与えられた CPU 用の機能とスケジュールコードを使用する"
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 #, fuzzy
 #| msgid "-mabi=ABI\tGenerate code that conforms to the given ABI"
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr "-mabi=ABI\t与えられた ABI に準拠したコードを生成する"
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -9183,11 +9189,17 @@
 
 #: config/i386/i386.opt:864
 #, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "MMX と SSE の組み込み関数とコード生成をサポートする"
+
+#: config/i386/i386.opt:868
+#, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use given stack-protector guard"
 msgstr "スタック保護方法としてプロポリス (propolice) を使用する"
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr ""
 
@@ -9567,7 +9579,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -9716,7 +9728,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
@@ -9851,7 +9863,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr "関数のプロローグシーケンスのスケジューリングを許す"
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr "関数プロローグ内で PIC レジスタをロードしない"
 
@@ -10196,333 +10208,331 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "vector/scalar (VSX) 命令を使用する"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr "update 命令と一緒にロード/ストア命令を生成しない"
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr "update 命令と一緒にロード/ストア命令を生成する"
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr "すべての構造体をメモリ内で返す (AIX のデフォルト)"
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr "小さな構造体をレジスタ内で返す (SVR4 のデフォルト)"
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr "TOC 内に浮動小数点定数を配置しない"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr "TOC 内に浮動小数点定数を配置する"
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "TOC 内にシンボル+オフセット定数を配置しない"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr "TOC 内にシンボル+オフセット定数を配置する"
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr "全てを通常 TOC 内に配置する"
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr "AltiVec コードを生成しているときに VRSAVE 命令を生成する"
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 #, fuzzy
 #| msgid "-mvrsave=yes/no\tDeprecated option.  Use -mvrsave/-mno-vrsave instead"
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr "-mvrsave=yes/no\t廃止されたオプションです。代わりに -mvrsave/-mno-vrsave を使用してください"
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 #, fuzzy
 #| msgid "Deprecated.  Use -Os instead"
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr "廃止されました。代わりに -Os を使用してください"
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 msgid "Generate isel instructions"
 msgstr "isel 命令を生成する"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 #, fuzzy
 #| msgid "-misel=yes/no\tDeprecated option.  Use -misel/-mno-isel instead"
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr "-misel=yes/no\t廃止されたオプションです。代わりに -misel/-mno-isel を使用してください"
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 #, fuzzy
 #| msgid "Deprecated.  Use -Os instead"
 msgid "Deprecated option.  Use -misel instead"
 msgstr "廃止されました。代わりに -Os を使用してください"
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr "E500 上で SPE SIMD 命令を生成する"
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 msgid "Generate PPC750CL paired-single instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 #, fuzzy
 #| msgid "-mspe=yes/no\tDeprecated option.  Use -mspe/-mno-spe instead"
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr "-mspe=yes/no\t廃止されたオプションです。代わりに -mspe/-mno-spe を使用してください"
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 #, fuzzy
 #| msgid "Deprecated.  Use -Os instead"
 msgid "Deprecated option.  Use -mspe instead"
 msgstr "廃止されました。代わりに -Os を使用してください"
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 msgid "-mdebug=\tEnable debug output"
 msgstr "-mdebug=\tデバッグ出力を有効にする"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 #, fuzzy
 #| msgid "Use AltiVec instructions"
 msgid "Use the AltiVec ABI extensions"
 msgstr "AltiVec 命令を使用する"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 #, fuzzy
 #| msgid "Do not use the bit-field instructions"
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "ビットフィールド命令を使用しない"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 msgid "Use the SPE ABI extensions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 #, fuzzy
 #| msgid "Do not use the bit-field instructions"
 msgid "Do not use the SPE ABI extensions"
 msgstr "ビットフィールド命令を使用しない"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv1 ABI"
 msgstr "EABI を使用する"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv2 ABI"
 msgstr "EABI を使用する"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 msgid "using darwin64 ABI"
 msgstr "darwin64 ABI を使用しています"
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 msgid "using old darwin ABI"
 msgstr "古い darwin ABI を使用しています"
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr "IEEE 拡張精度 long double を使用しています"
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr "IBM 拡張精度 long double を使用しています"
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr "-mcpu=\t与えられた CPU 用の機能とスケジュールコードを使用する"
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "-mtune=\t与えられた CPU 用のスケジュールコードを使用する"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr "-mtraceback=\tトレースバック表を full、part、または no のいずれかにする"
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 msgid "Generate Cell microcode"
 msgstr "Cell マイクロコードを生成する"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "Cell マイクロコード命令が発行されたときに警告する"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr "廃止された 'vector long ...' AltiVec 型の使用について警告する"
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr "-mfloat-gprs=\t汎用レジスタ GPR の浮動小数点使用法を選択する"
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 #, fuzzy
 #| msgid "valid arguments to %qs are: %s"
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr "-mlong-double-<n>\tlong double のサイズを指定する (64 または 128 ビット)"
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 #, fuzzy
 #| msgid "valid arguments to %qs are: %s"
 msgid "Valid arguments to -malign-:"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 msgid "Single-precision floating point unit"
 msgstr "単精度浮動小数点ユニット"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 msgid "Double-precision floating point unit"
 msgstr "倍精度浮動小数点ユニット"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 msgid "Floating point unit does not support divide & sqrt"
 msgstr "浮動小数点ユニットが divide および sqrt をサポートしません"
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr "-mfpu=\t浮動小数点 (FP) を指定する (sp, dp, sp-lite, dp-lite) (暗黙的に -mxilinx-fpu も指定される)"
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 msgid "Specify Xilinx FPU."
 msgstr "Xilinx FPU を指定する。"
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 #, fuzzy
 #| msgid "Align destination of the string operations"
 msgid "Allow sign extension in fusion operations"
 msgstr "文字列操作の書込み先を整列する"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
-#, fuzzy
-#| msgid "Use SmartMIPS instructions"
-msgid "Use ISA 2.07 crypto instructions"
-msgstr "SmartMIPS 命令を使用する"
+#: config/rs6000/rs6000.opt:566
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr ""
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 #, fuzzy
 #| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr "vector/scalar (VSX) 命令を使用する"
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "複数命令のロード/ストアを生成する"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -13595,212 +13605,212 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr "-dumpdir <dir>\tダンプ用に使用されるディレクトリ名を設定する"
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "関数に開始を整列する"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr "ジャンプの到達先となるラベルのみ整列する"
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr "全てのラベルを整列する"
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "ループの開始を整列する"
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr ""
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr "このスイッチは廃止されました。代わりに -Wextra を使用してください"
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr ""
 
-#: common.opt:918
+#: common.opt:921
 msgid "Generate auto-inc/dec instructions"
 msgstr "自動増加/減少命令を生成する"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr "分岐経路推測用のプロファイル情報を利用する"
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "配列の添え字を使用する前に境界検査を行うコードを生成する"
 
-#: common.opt:940
+#: common.opt:943
 #, fuzzy
 msgid "Replace add, compare, branch with branch on count register"
 msgstr "加算、比較ブランチの代わりにカウントレジスタのブランチを使う"
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr "分岐経路推測用のプロファイル情報を利用する"
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr ""
 
-#: common.opt:960
+#: common.opt:963
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr "-fcall-saved-<register>  <register> が関数を通じて保全されるとマークする"
 
-#: common.opt:964
+#: common.opt:967
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr "-fcall-used-<register>\t<register> が関数呼び出しによって変更されるとマークする"
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr "関数呼び出しの前後でレジスタを保存する"
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr ""
 
-#: common.opt:979
+#: common.opt:982
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++"
 msgstr "new の戻り値を検査する"
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "スタック調整およびスタック参照を削減する機会を探す"
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr "初期化されない大域変数類を共通セクションに配置しない"
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr ""
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr ""
 
-#: common.opt:1003
+#: common.opt:1006
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr "レジスタは位置が完了した後に比較の除去を行う"
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr "スタック使用量を著しく増加させる最適化を行わない"
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr ""
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr "ジャンプをまたがった最適化を行う"
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr "CSE で動作するとき、それらのターゲットへのジャンプに追随する"
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr ""
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr "Fortran 規格に従った複素数の乗除算を行う"
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr "データ項目をそれら自身のセクションに配置する"
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tデバッグカウンタ制限を設定する。"
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr "デバッグ情報内のディレクトリー名を他のものにマップする"
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr "関数引数をスタックから pop するのを呼び出し後まで遅らせる"
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr "分岐命令の遅延スロットを使うことを試みる"
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr "無意味な null ポインタ検査を削除する"
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 #, fuzzy
 #| msgid "Perform DWARF2 duplicate elimination"
 msgid "Perform speculative devirtualization"
 msgstr "DWARF2 重複削除を行う"
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr "仮想呼び出しを直接呼び出しに変換することを試みる"
 
-#: common.opt:1085
+#: common.opt:1088
 #, fuzzy
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr ""
@@ -13807,1408 +13817,1408 @@
 "  -fdiagnostics-show-location=[once | every-line]  診断メッセージの改行の際に,\n"
 " ソース位置情報が行の最初に表示される頻度を指定する\n"
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1145
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr "-fdump-<type>\t様々なコンパイラ内部情報をファイルにダンプする"
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr "-fdump-final-insns=filename\t翻訳終了時に filename へ命令をダンプする"
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr "-fdump-go-spec=filename\t全ての宣言を Go コードとしてファイルに書き込む"
 
-#: common.opt:1157
+#: common.opt:1160
 msgid "Suppress output of addresses in debugging dumps"
 msgstr "デバッグダンプ内でアドレスの出力を抑止する"
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 #, fuzzy
 #| msgid "options passed: "
 msgid "Dump optimization passes"
 msgstr "渡されたオプション: "
 
-#: common.opt:1170
+#: common.opt:1173
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr "デバッグダンプ内で命令番号、行番号情報およびアドレスの出力を抑止する"
 
-#: common.opt:1174
+#: common.opt:1177
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr "デバッグダンプ内で前と次の命令番号の出力を抑止する"
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "GAS アセンブラ指示を経由して CFI 表を有効にする"
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr "DWARF2 重複削除を行う"
 
-#: common.opt:1190
+#: common.opt:1193
 msgid "Perform interprocedural reduction of aggregates"
 msgstr ""
 
-#: common.opt:1194
+#: common.opt:1197
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info"
 msgstr "デバッグ情報内で使用されていない型の除去を行う"
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr "デバッグ情報内で使用されていない型の除去を行う"
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr "C++ クラスデバッグ情報を抑止しない。"
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "例外処理を有効にする"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr "多くの、目立たないがコストが高い最適化を行う"
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr "-fexcess-precision=[fast|standard]\t余分な浮動小数点精度の取り扱いを指定する"
 
-#: common.opt:1217
+#: common.opt:1220
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr "不明な余分な精度スタイル %qs です"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr "NaN または無限大が生成されないと見なす"
 
-#: common.opt:1238
+#: common.opt:1241
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr "-ffixed-<register>\t<register> がコンパイラでは使用できないとマークする"
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr "拡張精度レジスタ内に float と double を配置しない"
 
-#: common.opt:1250
+#: common.opt:1253
 msgid "Perform a forward propagation pass on RTL"
 msgstr ""
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "不明な浮動小数短縮形 %qs です"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr "関数アドレスをレジスタに持たせる事を許可する"
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr "それぞれの関数をそれ自身のセクションに配置する"
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr "大域共通部分式の除去を行う"
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr ""
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr "レジスタ配置後に大域共通部分式の除去を行う"
 
-#: common.opt:1305
+#: common.opt:1308
 msgid "Enable in and out of Graphite representation"
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1312
 msgid "Enable Graphite Identity transformation"
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1316
 #, fuzzy
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr "条件的 move 命令の利用を有効にする"
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr "全てのループを並列としてマークする"
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr ""
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr ""
 
-#: common.opt:1330
+#: common.opt:1333
 msgid "Enable Loop Blocking transformation"
 msgstr ""
 
-#: common.opt:1334
+#: common.opt:1337
 msgid "Enable Loop Unroll Jam transformation"
 msgstr ""
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr "分岐可能性の推測を有効にする"
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr "#ident 指示を処理する"
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr ""
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr ""
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, fuzzy, c-format
 #| msgid "unknown architecture %qs"
 msgid "unknown Stack Reuse Level %qs"
 msgstr "不明なアーキテクチャ %qs です"
 
-#: common.opt:1394
+#: common.opt:1397
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr ""
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr ""
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr ".size 指示を生成しない"
 
-#: common.opt:1410
+#: common.opt:1413
 msgid "Perform indirect inlining"
 msgstr "間接インライン化を実行する"
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 #, fuzzy
 #| msgid "Integrate simple functions into their callers when code size is known to not growth"
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "コードサイズが増加しないと分かってる場合は単純な関数を呼び出し側に統合する"
 
-#: common.opt:1424
+#: common.opt:1427
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "一回だけ呼び出される関数を呼び出し側に統合する"
 
-#: common.opt:1428
+#: common.opt:1431
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions only required by their single caller"
 msgstr "一回だけ呼び出される関数を呼び出し側に統合する"
 
-#: common.opt:1435
+#: common.opt:1438
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr "  -finline-limit=<number> インライン関数のサイズを <number> に制限する"
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 #, fuzzy
 msgid "Instrument function entry and exit with profiling calls"
 msgstr "関数の入り口/出口でプロファイル呼び出しを生成する"
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1458
 msgid "Perform interprocedural constant propagation"
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1466
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1470
 msgid "Perform interprocedural profile propagation"
 msgstr ""
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr "純粋および定数関数を見つける"
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables"
 msgstr "全てのループでループ展開を行なう"
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr "読み取り専用およびアドレス付けできない静的変数を見つける"
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr "-fira-algorithm=[CB|priority] 使用する IRA アルゴリズムを設定する"
 
-#: common.opt:1506
+#: common.opt:1509
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "不明な IRA アルゴリズム %qs です"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr "-fira-region=[one|all|mixed] IRA 用の範囲を設定する"
 
-#: common.opt:1519
+#: common.opt:1522
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr "不明な IRA 範囲 %qs です"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "十分に大きな switch 文ではジャンプ表を使用する"
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr "完全にインライン化される場合でも関数用のコードを生成する"
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr "使用されない静的定数変数であっても出力する"
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr "外部シンボルの先頭に下線 (_) を付ける"
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 msgid "Enable link-time optimization."
 msgstr "リンク時最適化を有効にする"
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr ""
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 msgid "Report various link-time optimization statistics"
 msgstr "様々なリンク時最適化統計情報に関して報告する"
 
-#: common.opt:1625
+#: common.opt:1628
 #, fuzzy
 #| msgid "Report various link-time optimization statistics"
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr "様々なリンク時最適化統計情報に関して報告する"
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr "組み込み数学関数の後に errno をセットする"
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr "-fmax-errors=<number>\tエラー報告する最大数を <number> にする"
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr "永続的なメモリ確保に関して報告する"
 
-#: common.opt:1641
+#: common.opt:1644
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only"
 msgstr "永続的なメモリ確保に関して報告する"
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr "定数と定数変数の併合を試みる"
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr "コンパイル単位をまたがった同一の定数の併合を試みる"
 
-#: common.opt:1656
+#: common.opt:1659
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr "コンパイル単位をまたがった同一のデバッグ文字列の併合を試みる"
 
-#: common.opt:1660
+#: common.opt:1663
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr "-fmessage-length=<number>\t一行あたりの診断メッセージ文字数を <number> に制限する。0 の場合は改行しない"
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr "ループの中で変更がない計算をループの外に移動する"
 
-#: common.opt:1676
+#: common.opt:1679
 msgid "Use the RTL dead code elimination pass"
 msgstr "RTL 不要なコード (dead code) の除去過程を使用する"
 
-#: common.opt:1680
+#: common.opt:1683
 msgid "Use the RTL dead store elimination pass"
 msgstr "RTL 不要な記憶域 (dead store) 除去過程を使用する"
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr "同期非呼び出し例外をサポートする"
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "%qs の後にアサーションがありません"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown offload ABI %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr "可能な場合、スタックフレームを生成しない"
 
-#: common.opt:1713
+#: common.opt:1716
 #, fuzzy
 msgid "Enable all optimization info dumps on stderr"
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr "sibling 呼び出しや末尾再帰呼び出しを最適化する"
 
-#: common.opt:1729
+#: common.opt:1732
 msgid "Perform partial inlining"
 msgstr "部分的なインライン化を行う"
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr ""
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr "構造体メンバを穴が開かないようにパックする"
 
-#: common.opt:1745
+#: common.opt:1748
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr ""
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr "小さな集合体を (レジスタではなく) メモリで返す"
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr "ループの展開を行う"
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr ""
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr ""
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr "可能であれば位置非依存コードを生成する (large モード)"
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr "可能であれば実行可能な位置非依存コードを生成する (large モード)"
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr "可能であれば胃非値非損コードを生成する (small モード)"
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr "可能であれば実行可能な非値非依存コードを生成する (small モード)"
 
-#: common.opt:1781
+#: common.opt:1784
 msgid "Specify a plugin to load"
 msgstr "ロードするプラグインを指定する"
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr "-fplugin-arg-<name>-<key>[=<value>]\tプラグイン <name> 用に引数 <key>=<value> を指定する"
 
-#: common.opt:1789
+#: common.opt:1792
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr "ループ内の配列で、可能であればプリフェッチ命令を生成する"
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr "基本プログラムプロファイリングコードを有効にする"
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr "円弧ベースプログラムプロファイリングコードを挿入する"
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr "プロファイルデータ保存用の最上位ディレクリーを設定する"
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr "フロー一貫性が無いデータ入力の訂正を有効にする"
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1821
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1826
+#: common.opt:1829
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr "式の値をプロファイルするためのコードを挿入する"
 
-#: common.opt:1834
+#: common.opt:1837
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Report on consistency of profile"
 msgstr "内部一貫性がありません"
 
-#: common.opt:1838
+#: common.opt:1841
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement"
 msgstr "コード配置を改善するために関数を並べ替える"
 
-#: common.opt:1845
+#: common.opt:1848
 #, fuzzy
 #| msgid "-frandom-seed=<string>\tMake compile reproducible using <string>"
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr "-frandom-seed=<string>\t<string> を使用してコンパイルを再現可能にする"
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr "オブジェクトファイル内に gcc のコマンドラインスイッチを記録する。"
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr "小さな集合体をレジスタで返す"
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr ""
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr ""
 
-#: common.opt:1880
+#: common.opt:1883
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr ""
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr "コード配置を改善するために基本ブロックを並べ替える"
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr ""
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr "コード配置を改善するために関数を並べ替える"
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr "ループ最適化後に共通部分式を除去する過程を追加する"
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr "デフォルトの浮動小数点丸め動作と見なせる最適化を無効にする"
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr "基本ブロックをまたがるスケジューリングを有効にする"
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr "非ロードでの不確実な動作を許可する"
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr "いくつかのロードでの不確実な動作を許可する"
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr "より多くのロードでの不確実な動作を許可する"
 
-#: common.opt:1928
+#: common.opt:1931
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr "-fsched-verbose=<number>\tスケジューラの冗長レベルを設定する"
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr ""
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr "レジスタ確保の前に命令を並べ直す"
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr "レジスタ確保の後で命令を並べ直す"
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr ""
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr "再ロード後に選択的スケジューリングを実行する"
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr ""
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1981
+#: common.opt:1984
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr ""
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1993
+#: common.opt:1996
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1997
+#: common.opt:2000
 msgid "Enable the group heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2009
+#: common.opt:2012
 msgid "Enable the rank heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr ""
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr "診断内で利用可能な場合に列番号を表示する。デフォルトで有効"
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr ""
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr "浮動小数点定数を単精度定数に変換する"
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr ""
 
-#: common.opt:2062
+#: common.opt:2065
 msgid "Generate discontiguous stack frames"
 msgstr "不連続なスタックフレームを生成する"
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr "ワイド型を独立したレジスタに分割する"
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr ""
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr "ループを展開したときに変数の展開を行う"
 
-#: common.opt:2082
+#: common.opt:2085
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "-fstack-check=[no|generic|specific]\tプログラム内にスタック検査コードを挿入する"
 
-#: common.opt:2086
+#: common.opt:2089
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "プログラム内にスタック検査コードを挿入する。 -fstack-check=specific と同様"
 
-#: common.opt:2093
+#: common.opt:2096
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr "-fstack-limit-register=<register>\tスタックがレジスタ <register> より後に行った場合にトラップする"
 
-#: common.opt:2097
+#: common.opt:2100
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr "-fstack-limit-symbol=<name>\tスタックがシンボル <name> より後に行った場合にトラップする"
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr "スタック保護方法としてプロポリス (propolice) を使用する"
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr "それぞれの関数に関してスタック保護方法を使用する"
 
-#: common.opt:2109
+#: common.opt:2112
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions"
 msgstr "それぞれの関数に関してスタック保護方法を使用する"
 
-#: common.opt:2113
+#: common.opt:2116
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr "それぞれの関数に関してスタック保護方法を使用する"
 
-#: common.opt:2117
+#: common.opt:2120
 msgid "Output stack usage information on a per-function basis"
 msgstr "関数単位でスタック使用情報を出力する"
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr "厳密な別名規則を適用するとみなす"
 
-#: common.opt:2133
+#: common.opt:2136
 msgid "Treat signed overflow as undefined"
 msgstr "符号のオーバーフローを未定義として取り扱う"
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr "構文エラーを検査して、そこで停止する"
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr "\"gcov\" で必要となるデータファイルを作成する"
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr ""
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr "各コンパイル過程で費やした時間を報告する"
 
-#: common.opt:2157
+#: common.opt:2160
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tデフォルトのスレッド局所記憶域 (TLS) コード生成モデルを設定する"
 
-#: common.opt:2160
+#: common.opt:2163
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr "トップレベルの関数、変数、アセンブラを並べ替える"
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr ""
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr "浮動小数点操作をトラップできると見なす"
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr "加算、減算、乗算内での符号付きのオーバーフローをトラップする"
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr ""
 
-#: common.opt:2199
+#: common.opt:2202
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr ""
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr ""
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr ""
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr ""
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr ""
 
-#: common.opt:2231
+#: common.opt:2234
 msgid "Transform condition stores into unconditional ones"
 msgstr ""
 
-#: common.opt:2235
+#: common.opt:2238
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr ""
 
-#: common.opt:2243
+#: common.opt:2246
 msgid "Enable dominator optimizations"
 msgstr ""
 
-#: common.opt:2247
+#: common.opt:2250
 #, fuzzy
 msgid "Enable tail merging on trees"
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr "不要な記憶域 (dead store) の除去を行う"
 
-#: common.opt:2255
+#: common.opt:2258
 msgid "Enable forward propagation on trees"
 msgstr ""
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr ""
 
-#: common.opt:2263
+#: common.opt:2266
 #, fuzzy
 msgid "Enable string length optimizations on trees"
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 #, fuzzy
 msgid "Enable loop distribution on trees"
 msgstr "並列命令を有効にする"
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr ""
 
-#: common.opt:2288
+#: common.opt:2291
 #, fuzzy
 msgid "Enable loop invariant motion on trees"
 msgstr "ループ中に不変な計算をループの外に移動する"
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr ""
 
-#: common.opt:2296
+#: common.opt:2299
 #, fuzzy
 msgid "Create canonical induction variables in loops"
 msgstr "ループの中の全ての一般誘導変数を強度削減する"
 
-#: common.opt:2300
+#: common.opt:2303
 #, fuzzy
 msgid "Enable loop optimizations on tree level"
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2304
+#: common.opt:2307
 msgid "Enable automatic parallelization of loops"
 msgstr "ループの自動並列化を有効にする"
 
-#: common.opt:2308
+#: common.opt:2311
 #, fuzzy
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "条件的 move 命令の利用を有効にする"
 
-#: common.opt:2312
+#: common.opt:2315
 #, fuzzy
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2324
+#: common.opt:2327
 msgid "Enable reassociation on tree level"
 msgstr ""
 
-#: common.opt:2332
+#: common.opt:2335
 #, fuzzy
 msgid "Enable SSA code sinking on trees"
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr ""
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr ""
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr ""
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr "コンパイル単位全体を一回でコンパイルする"
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr "反復回数が既知のとき、ループ展開を行なう"
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr "全てのループでループ展開を行なう"
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr "ループが通常の方法で振る舞うと見なせる場合にループ最適化を許可する"
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr ""
 
-#: common.opt:2392
+#: common.opt:2395
 #, fuzzy
 msgid "Perform loop unswitching"
 msgstr "全てのループでループ展開を行なう"
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr "巻き戻しを行なう例外補足用テーブルを生成する"
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr "変数追跡を実施する"
 
-#: common.opt:2424
+#: common.opt:2427
 msgid "Perform variable tracking by annotating assignments"
 msgstr ""
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr ""
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr ""
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 msgid "Enable vectorization on trees"
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2450
+#: common.opt:2453
 #, fuzzy
 msgid "Enable loop vectorization on trees"
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2454
+#: common.opt:2457
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr ""
 
-#: common.opt:2458
+#: common.opt:2461
 #, fuzzy
 msgid "Specifies the cost model for vectorization"
 msgstr "条件的 move 命令の利用を有効にする"
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:2478
+#: common.opt:2481
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
 
-#: common.opt:2482
+#: common.opt:2485
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
 
-#: common.opt:2490
+#: common.opt:2493
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr "余分なコメントをアセンブラ出力に追加する"
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr "-fvisibility=[default|internal|hidden|protected]\tシンボル可視性のデフォルトを設定する"
 
-#: common.opt:2507
+#: common.opt:2510
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "認識できない可視性の値 %qs です"
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(%qs 用の初期化付近)"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr ""
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2558
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr "プログラム全体の最適化を実行する"
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr "符号付き計算オーバーフローが丸められると見なす"
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr "0 で初期化されるデータを bss セクション内に配置する"
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr "COFF 形式でデバッグ情報を生成する"
 
-#: common.opt:2579
+#: common.opt:2582
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format"
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:2583
+#: common.opt:2586
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr "DWARF v2 (またはそれ以降) 形式でデバッグ情報を生成する"
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr "デフォルト拡張形式でデバッグ情報を生成する"
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 #, fuzzy
 #| msgid "Record gcc command line switches in the object file."
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr "オブジェクトファイル内に gcc のコマンドラインスイッチを記録する。"
 
-#: common.opt:2607
+#: common.opt:2610
 #, fuzzy
 #| msgid "Record gcc command line switches in the object file."
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "オブジェクトファイル内に gcc のコマンドラインスイッチを記録する。"
 
-#: common.opt:2611
+#: common.opt:2614
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Don't generate debug information in separate .dwo files"
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:2615
+#: common.opt:2618
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files"
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr "STABS 形式でデバッグ情報を生成する"
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr "拡張 STABS 形式でデバッグ情報を生成する"
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2638
 msgid "Toggle debug information generation"
 msgstr "デバッグ情報生成の有効・無効を切り替える"
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr "VMS 形式でデバッグ情報を生成する"
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr "XCOFF 形式でデバッグ情報を生成する"
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr "拡張 XCOFF 形式でデバッグ情報を生成する"
 
-#: common.opt:2665
+#: common.opt:2668
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections"
 msgstr "isel 命令を生成する"
 
-#: common.opt:2669
+#: common.opt:2672
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:2676
+#: common.opt:2679
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr "-iplugindir=<dir>\tデフォルトのプラグインディレクトリを <dir> に設定する"
 
-#: common.opt:2680
+#: common.opt:2683
 #, fuzzy
 #| msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr "-iplugindir=<dir>\tデフォルトのプラグインディレクトリを <dir> に設定する"
 
-#: common.opt:2702
+#: common.opt:2705
 msgid "-o <file>\tPlace output into <file>"
 msgstr "-o <file>\t出力を <file> に配置する"
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr "関数プロファイルを有効にする"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr "-pedantic と同様だが、エラーとして出力する"
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr "コンパイルされた関数または費やした時間に関して出力しない"
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr "冗長な出力を有効にする"
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr "`コンパイラのバージョンを表示する"
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "警告を抑止する"
 
-#: common.opt:2806
+#: common.opt:2809
 msgid "Create a shared library"
 msgstr "共有ライブラリを作成する"
 
-#: common.opt:2851
+#: common.opt:2854
 msgid "Create a position independent executable"
 msgstr "位置非依存実行可能ファイルを生成する"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "計算された値が使用されません"
@@ -15240,244 +15250,244 @@
 msgid "expected integer or boolean type"
 msgstr "整数または真偽型が予期されます"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 #, fuzzy
 #| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of nil with nil"
 msgstr "gimple 条件内で無効な比較コードです"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 msgid "incompatible types in binary expression"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 #| msgid "division by zero"
 msgid "integer division by zero"
 msgstr "ゼロ除算が発生しました"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 msgid "shift of non-integer operand"
 msgstr "被演算子が非整数型のシフト演算です"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 msgid "shift count not unsigned integer"
 msgstr "シフト数が符号無し整数ではありません"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 msgid "negative shift count"
 msgstr "負のシフト数です"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 msgid "object is not a method"
 msgstr "オブジェクトがメソッドではありません"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 msgid "method type does not match object type"
 msgstr "メソッド型がオブジェクト型に一致しません"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 #, fuzzy
 #| msgid "invalid argument to built-in function"
 msgid "invalid use of %<...%> with builtin function"
 msgstr "組み込み関数への無効な引数です"
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 #, fuzzy
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 msgid "not enough arguments"
 msgstr "十分な引数がありません"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 msgid "too many arguments"
 msgstr "引数が多すぎます"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 #, fuzzy
 #| msgid "argument must be a constant"
 msgid "argument 1 must be a map"
 msgstr "引数は定数でなければいけません"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 msgid "invalid type for make function"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 #, fuzzy
 #| msgid "too many arguments to %qE"
 msgid "too many arguments to make"
 msgstr "%qE への引数が多すぎます"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 msgid "argument must be array or slice or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 msgid "unsupported argument type to builtin function"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 msgid "argument must be channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 msgid "argument must be a field reference"
 msgstr "引数はフィールド参照でなければいけません"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 msgid "left argument must be a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr "要素の型が同じでなければいけません"
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 #, fuzzy
 #| msgid "last argument must be an immediate"
 msgid "first argument must be []byte"
 msgstr "最後の引数は即値でなければいけません"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 #, fuzzy
 #| msgid "argument must be a constant"
 msgid "second argument must be slice or string"
 msgstr "引数は定数でなければいけません"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 #, fuzzy
 #| msgid "parameter %u has void type"
 msgid "argument 2 has invalid type"
 msgstr "仮引数 %u が void 型を持っています"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 msgid "argument must have complex type"
 msgstr "引数は複素数型でなければいけません"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 #, fuzzy
 msgid "complex arguments must have identical types"
 msgstr "引数は複素数型でなければいけません"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 #, fuzzy
 msgid "complex arguments must have floating-point type"
 msgstr "引数は複素数型でなければいけません"
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 msgid "expected function"
 msgstr "関数が予期されます"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 msgid "multiple-value argument in single-value context"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 #, fuzzy
 msgid "invalid use of %<...%> with non-slice"
 msgstr "トップレベルでの `this' の使用は無効です"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 msgid "function result count mismatch"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 msgid "incompatible type for receiver"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 #, fuzzy
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 msgid "number of results does not match number of values"
 msgstr "結果の数が値の数と一致しません"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 msgid "index must be integer"
 msgstr "添え字は整数でなければいけません"
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 msgid "slice end must be integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 #| msgid "index must be integer"
 msgid "slice capacity must be integer"
 msgstr "添え字は整数でなければいけません"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 msgid "incompatible type for map index"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr "インターフェースまたはインターフェースへのポインタが予期されます"
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 msgid "too many expressions for struct"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 msgid "too few expressions for struct"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 msgid "type assertion only valid for interface types"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 msgid "expected channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -15602,72 +15612,72 @@
 msgid "cannot use type %s as type %s"
 msgstr "型 %s を型 %s として使用できません"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 msgid "different receiver types"
 msgstr ""
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 msgid "different number of parameters"
 msgstr "引数の数が異なります"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 msgid "different parameter types"
 msgstr "引数の型が異なります"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr "結果の数が異なります"
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 msgid "different result types"
 msgstr "結果の型が異なります"
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "明示的な変換が必要です。存在しないメソッド %s%s%s です"
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "メソッド %s%s%s への互換性のない型です"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr ""
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr "インターフェース型へのポインタがメソッドを持っていません"
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 msgid "type has no methods"
 msgstr "型がメソッドを持っていません"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "曖昧なメソッド %s%s%s です"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "メソッド %s%s%s がありません"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, fuzzy, c-format
 #| msgid "method %s%s%s requires a pointer"
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "メソッド %s%s%s にはポインタが必要です"
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, fuzzy, c-format
 #| msgid "method %s%s%s requires a pointer"
 msgid "method %s%s%s is marked go:nointerface"
@@ -15792,7 +15802,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "無効な %<__builtin_prefetch%> の第三引数です。0 を使用します"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "関数 %<va_start%> への引数が少なすぎます"
@@ -15979,12 +15989,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%K ヒープではないオブジェクトを free する試みです"
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "関数呼び出しが集合体の値を持っています"
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to %qs"
 msgid "passing too large argument on stack"
@@ -16548,246 +16558,251 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "命令連鎖中の bb の数 (%d) が n_basic_blocks (%d) と違います"
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, fuzzy, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr "左シフト回数が負の数です"
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr ""
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr ""
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, gcc-internal-format
 msgid "execution count is negative"
 msgstr ""
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "シンボルが有効であると見なす"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "セクションポインタを欠いています"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, fuzzy, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "重複する `virtual' 指定子"
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "%qD の整列は元の宣言より大きいです"
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "Instrumented node has wrong original declaration"
 msgstr "%qD の整列は元の宣言より大きいです"
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, fuzzy, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr "参照を参照として宣言できません"
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "`%s' は宣言よりも先に使用されました"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "文が予期されます"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node に失敗しました"
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr ""
@@ -16919,7 +16934,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER が設定されなければいけません"
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, gcc-internal-format
 msgid "atexit failed"
@@ -17165,17 +17180,17 @@
 msgid "          %s"
 msgstr "          %s"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr "共通シンボルでバッグ情報がシンボル+オフセットの構造になっていません"
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "大域デストラクタはこのターゲットではサポートされていません"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "大域コンストラクタはこのターゲットではサポートされていません"
@@ -17221,12 +17236,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -17424,7 +17439,7 @@
 msgid "total size of local objects too large"
 msgstr "局所オブジェクトの総サイズが大きすぎます"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%> 内で制約を行うことは出来ません"
@@ -17877,9 +17892,9 @@
 msgstr "PCH ファイルを書き込めません"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, gcc-internal-format
 msgid "declared here"
 msgstr "ここで宣言されています"
@@ -17894,154 +17909,149 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr ""
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "%<void%> を返す関数の結果を使用しています"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr ""
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:7001
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, fuzzy, gcc-internal-format
-msgid "lastprivate variable %qE is private in outer context"
-msgstr "インスタンス変数 `%s' は private と宣言されています"
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
-#, fuzzy, gcc-internal-format
 msgid "directive not yet implemented"
 msgstr "Trampoline は、まだ実装されていません"
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "%<}%> が %<else%> の前に予期されます"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification に失敗しました"
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "%<va_arg%> の第一引数が %<va_list%> 型ではありません"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "このコードまで到達した場合、プログラムは中止されます"
@@ -18458,47 +18468,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr ""
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr ""
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -18585,49 +18595,49 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "誤った形式の COLLECT_GCC_OPTIONS です"
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "入力ファイルがありません"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 #| msgid "%s:error writing output file '%s'\n"
 msgid "writing output file"
 msgstr "%s: 出力ファイル '%s' を書き込み中にエラーが発生しました\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "環境変数 COLLECT_GCC が設定されていなければいけません"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "環境変数 COLLECT_GCC_OPTIONS が設定されていなければいけません"
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "fopen: %s"
 msgid "fopen: %s: %m"
@@ -18766,13 +18776,13 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid entry to OpenMP structured block"
 msgid "invalid exit from %s structured block"
 msgstr "OpenMP 構造化ブロックへの無効なエントリです"
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid entry to OpenMP structured block"
 msgid "invalid entry to %s structured block"
@@ -18779,19 +18789,19 @@
 msgstr "OpenMP 構造化ブロックへの無効なエントリです"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid branch to/from an OpenMP structured block"
 msgid "invalid branch to/from %s structured block"
 msgstr "OpenMP 構造化ブロックへ/からの無効な分岐です"
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "ignoring large linear step"
 msgstr "重複したディレクトリ \"%s\" を無視します\n"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -19331,8 +19341,8 @@
 msgstr "%qs を固定レジスタとして使用できません"
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "不明なレジスタ名です: %s"
@@ -19783,7 +19793,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld はステータス %d で終了しました"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F が使用されましたが定義されていません"
@@ -20791,42 +20801,42 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr ""
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -21214,47 +21224,47 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, gcc-internal-format
 msgid "array subscript is outside array bounds"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, gcc-internal-format
 msgid "array subscript is above array bounds"
 msgstr "配列の添字が配列の境界を上回っています"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, gcc-internal-format
 msgid "array subscript is below array bounds"
 msgstr "配列の添字が配列の境界を下回っています"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr ""
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr ""
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr "データ型の範囲制限により比較が常に偽 (false) となります"
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr "データ型の範囲制限により比較が常に真 (true) となります"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr "%</%> または %<%%%> を %<>>%> または %<&%> へ単純化するときに符号のオーバーフローが発生しないと見なしています"
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr "%<abs (X)%> を %<X%> または %<-X%> へ単純化するときに符号のオーバーフローが発生しないと見なしています"
@@ -21298,9 +21308,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21540,7 +21550,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "要求された %q+D 用の整列は実装されている整列 %wu より大きいです"
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D の記憶域サイズが不明です"
@@ -21695,27 +21705,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "文字列長 %qd は長さ %qd (ISO C%d コンパイラでサポートが要求される長さ) より長いです"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左シフト回数が負です"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右シフト回数が負です"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左シフト回数 >= 型の幅となっています"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右シフト回数 >= 型の幅となっています"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "定数式内でオーバーフローしました"
@@ -22048,12 +22058,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "真偽値として使われる代入のまわりでは、丸括弧の使用をお勧めします"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "%<restrict%> の誤った使用法です"
@@ -22515,12 +22525,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "%qE 属性用としては無効なベクトル型です"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "ベクトルのサイズが要素のサイズの整数倍ではありません"
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "ベクトルのサイズが 0 です"
@@ -22530,22 +22540,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr "ベクトルの要素の数が 2 の累乗ではありません"
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr ""
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr ""
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr ""
@@ -22585,12 +22595,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr ""
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr ""
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
@@ -22673,7 +22683,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "一定ではないアドレスへ %<offsetof%> を適用できません"
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "ビットフィールドである構造体のメンバ %qD のアドレスを取得しようとする試みです"
@@ -23100,7 +23110,7 @@
 msgstr ""
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -23559,7 +23569,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -23569,22 +23579,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE は初期化されていません"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "増分式がありません"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無効な増分式です"
@@ -24126,6 +24136,12 @@
 msgid "too many input files"
 msgstr "入力ファイルが多すぎます"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+#| msgid "stack frame too large"
+msgid "-mcpu string too large"
+msgstr "スタックフレームが大きすぎます"
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -24152,54 +24168,54 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-loops%s is obsolete, use -falign-loops%s"
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "%salign-loops%s は廃止予定です。-falign-loops%s を使用してください"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-jumps%s is obsolete, use -falign-jumps%s"
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "%salign-jumps%s は廃止予定です。-falign-jumps%s を使用してください"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-functions%s is obsolete, use -falign-functions%s"
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "%salign-functions%s は廃止予定です。-falign-functions%s を使用してください"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%sbranch-cost=%d%s is not between 0 and 5"
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "%sbranch-cost=%d%s が 0 と 5 の間ではありません"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> は現在のところ GNU/Linux 上でのみサポートされています"
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> はアセンブラが CFI 指示をサポートしている必要があります"
@@ -24596,63 +24612,63 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr ""
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "-mtrap-precision スイッチ用の間違った値 %qs です"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "-mfp-rounding-mode スイッチ用の間違った値 %qs です"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "-mfp-trap-mode スイッチ用の間違った値 %qs です"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr "-mcpu スイッチ用の間違った値 %qs です"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, gcc-internal-format
 msgid "bad value %qs for -mtune switch"
 msgstr "-mtune スイッチ用の間違った値 %qs です"
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr "浮動小数点ソフトウェア補完には -mtrap-precision=i が必要です"
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "VAX 浮動小数では丸めモードはサポートされていません"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "VAX 浮動小数ではトラップモードはサポートされていません"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr "128 ビット long double は VAX 浮動小数用にはサポートされていません"
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr "L%d キャッシュレイテンシは %s にとって不明です"
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr "-mmemory-latency 用の間違った値 %qs です"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -25139,14 +25155,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, gcc-internal-format
 msgid "%qE attribute only applies to functions"
@@ -25824,394 +25840,411 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "PCH ファイル内で位置を設定できません: %m"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-Werror=%s: no option -%s"
 msgid "wrong arg %s to option %s"
 msgstr "-Werror=%s: オプション -%s はありません"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "レジスタ名が %q+D 用に指定されていません"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
+#, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386.c:3012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %s specified for option %s"
 msgstr "%q+D 用の整列が指定されていないようです"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %s"
 msgstr "%qs にクラス名が指定されていません"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr "%stune=x86-64%s は廃止されました。代わりに %stune=k8%s または %stune=generic%s の適切な方を使用してください"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "コードモデル %s は PIC モードをサポートしません"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s はこの設定ではサポートされていません"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i ビットモードが使用できるようにコンパイルされていません"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "選択した CPU は x86-64 命令セットをサポートしていません"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s は %s をサポートしません"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, fuzzy, gcc-internal-format
 #| msgid "%sregparm%s is ignored in 64-bit mode"
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "%sregparm%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%sregparm=%d%s is not between 0 and %d"
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "%sregparm=%d%s が 0 と %d の間ではありません"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, fuzzy, gcc-internal-format
 #| msgid "%spreferred-stack-boundary%s is not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "%spreferred-stack-boundary%s はこのターゲットではサポートされていません"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and %d"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s が %d と %d の間ではありません"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d が %d と 12 の間ではありません"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "ret 命令は実装されていません"
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 命令セットが無効になっています。 387 数値演算を使用します"
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 命令セットが無効になっています。SSE 数値演算を使用します"
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "-mrecip=%s 用の不明なオプションです"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %qE argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "属性 %qE の引数が文字列ではありません"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") は既に指定されています"
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall と regparm 属性は併用できません"
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 属性には整数定数引数が必要です"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE 属性への引数が %d より大きいです"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall と cdecl 属性は併用できません"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall と stdcall 属性は併用できません"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall と fastcall 属性は併用できません"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 属性が非クラスメソッド用に使用されています"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qD を呼び出しています"
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qT を呼び出しています<"
 
-#: config/i386/i386.c:5923
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
-#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qD を呼び出しています"
-
-#: config/i386/i386.c:6210
-#, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "multilib はサポートしません"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE が有効でない状態での SSE ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE が有効でない状態での SSE ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "可変長配列メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "long double を持つ共用体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE が無効の状態で SSE レジスタを戻して (return) います"
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE が無効の状態で SSE レジスタ引数があります"
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 が無効な状態で x87 レジスタを戻して (return) います"
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, fuzzy, gcc-internal-format
+#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qD を呼び出しています"
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
+#, fuzzy, gcc-internal-format
+#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qD を呼び出しています"
+
+#: config/i386/i386.c:11378
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "ms_hook_prologue 属性は 32 ビット用の -mfentry と併用できません"
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fsplit-stack%> is not supported by this compiler configuration"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -26219,271 +26252,271 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand type used with operand code '%c'"
 msgid "non-integer operand used with operand code 'z'"
 msgstr "被演算子コード '%c' に無効な被演算子型が使用されました"
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, fuzzy, gcc-internal-format
 #| msgid "static linking is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "静的リンクはサポートされていません"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "前方での `%s' の宣言"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs への引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter %qD set but not used"
 msgid "Parameter to builtin not valid: %s"
 msgstr "仮引数 %qD が設定されましたが使用されません"
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "第五引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "第三引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 1-bit immediate"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最後の引数は 1 ビット即値でなければいけません"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 32-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最後の引数は 32 ビット即値でなければいけません"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最後の引数は 4 ビット即値でなければいけません"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最後の引数は 1 ビット即値でなければいけません"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最後の引数は 5 ビット即値でなければいけません"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "最後の引数の前の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "引数は定数でなければいけません"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "正しくない命令:"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect rounding operand"
 msgstr "正しくない命令:"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最後の引数は 4 ビット即値でなければいけません"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最後の引数は 5 ビット即値でなければいけません"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最後の引数は 32 ビット即値でなければいけません"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE は isa オプション %s が必要です"
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最後の引数は即値でなければいけません"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 2-bit immediate"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "第五引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "正しくない命令:"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "ms_abi と sysv_abi 属性は互換性がありません"
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "互換性がない %qE 属性は無視されました"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, fuzzy, gcc-internal-format
 #| msgid "unknown architecture %qs"
 msgid "Unknown architecture specific memory model"
 msgstr "不明なアーキテクチャ %qs です"
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "サポートされていない組み合わせです: %s"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -26578,13 +26611,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr "-mfixed-range の値は REG1-REG2 形式でなければいけません"
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -26656,7 +26689,7 @@
 msgstr "%qE 属性は R8C ターゲット用にはサポートされていません"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, gcc-internal-format
 msgid "%qE attribute argument not an integer constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
@@ -26717,7 +26750,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread は fido 上でのみ使用出来ます"
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "スタック制限式はサポートされていません"
@@ -27605,16 +27638,11 @@
 msgid "-g option disabled"
 msgstr "-g オプションが無効になりました"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr ""
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, fuzzy, gcc-internal-format
@@ -27878,331 +27906,337 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "target 属性または pragma が倍精度浮動小数点を変更します"
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "internal error: builtin function to %s already processed"
 msgid "internal error: builtin function %s already processed"
 msgstr "内部エラー: %s への組み込み関数は既に処理されています"
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "第一引数は 5 ビット符号付きリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "第一引数は 5 ビット符号付きリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "__builtin_altivec_predicate の第一引数は定数でなければいけません"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "__builtin_altivec_predicate の第一引数が範囲外です"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "%srtd%s is ignored in 64bit mode"
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr "%srtd%s は 64 ビットモードでは無視されます"
+
+#: config/rs6000/rs6000.c:12763
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate の第一引数が範囲外です"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "第三引数は 4 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "第三引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "第三引数は 1 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "数値は 0 または 1 でなければいけません"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "第三引数は 1 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "数値は 0 または 1 でなければいけません"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument 3 must be in the range 0..15"
 msgstr "%d 番目の %qE の引数は %d...%d の範囲でなければいけません"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs への引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "dss への引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "__builtin_paired_predicate の第一引数は定数でなければいけません"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "__builtin_paired_predicate の第一引数が範囲外です"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "__builtin_spe_predicate の第一引数は定数でなければいけません"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "__builtin_spe_predicate の第一引数が範囲外です"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "この組み込み関数は fr450 上でのみ利用できます"
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mspe option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ifunc is not supported in this configuration"
 msgid "Builtin function %s is not supported with the current options"
 msgstr "ifunc はこの設定ではサポートされていません"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had no type"
 msgstr "内部エラー: 組み込み関数 %s に型がありません"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "内部エラー: 組み込み関数 %s が予期しない戻り型 %s を持っています"
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "内部エラー: 組み込み関数 %s の第 %d 引数が予期しない引数型 %s を持っています"
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "スタックフレームが大きすぎます"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<long double%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec 型内での真偽型 (boolean) の使用は無効です"
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<complex%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "AltiVec 型内での十進浮動小数点の使用は無効です"
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "-mvsx 無しで 64 ビットコード用の AltiVec 型内での %<long%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec 型内での %<long%> の使用は廃止されました。%<int%> を使用してください"
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "-mvsx 無しで AltiVec 型内での %<long long%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "-mvsx 無しで AltiVec 型内での %<double%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "マイクロコード命令 %s\t[%s] #%d を発行しています"
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "条件付きマイクロコード命令 %s\t[%s] #%d を発行しています"
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "CPU \"%s\" は %s\"%s\"%s 用には無効です"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s\"%s\"%s は許可されていません"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s\"%s\"%s は無効です"
@@ -28459,91 +28493,91 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局所変数の合計サイズがアーキテクチャの制限を超過しています"
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "%qs のフレームサイズ: "
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs は動的スタック割り当てを使用します"
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "%qs への引数は非負整数であるべきです"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qE 属性への引数が %d より大きいです"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/Architecture モードは %s 上ではサポートされていません"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64 ビット ABI は ESA/390 モード内ではサポートされていません"
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "ハードウェア十進浮動小数点命令は ESA/390 モードでは使用出来ません"
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp は -msoft-float と併用できません"
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float の組み合わせはサポートされていません"
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "スタックサイズは 64k より大きくてはいけません"
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard は -mstack-size を暗黙的に使用します"
@@ -28558,53 +28592,53 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr ""
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr ""
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, gcc-internal-format
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "%qE 属性は割り込み関数へのみ適用されます"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, gcc-internal-format
 msgid "%qE attribute is supported only for SH2A"
 msgstr "%qE 属性は SH2A 用にのみサポートされています"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr "interrupt_handler 属性は -m5-compact と併用できません"
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, gcc-internal-format
 msgid "%qE attribute only applies to SH2A"
 msgstr "%qE 属性は SH2A へのみ適用されます"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, gcc-internal-format
 msgid "%qE attribute argument should be between 0 to 255"
 msgstr "%qE 属性引数は 0 と 255 の間であるべきです"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, gcc-internal-format
 msgid "%qE attribute argument not a string constant"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr "r0 は呼び出しによって上書きされるレジスタとして利用できる必要があります"
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, gcc-internal-format
 msgid "need a second call-clobbered general purpose register"
 msgstr ""
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr ""
@@ -28997,44 +29031,44 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "%qs 属性用の無効なエレメント型です"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "ベクトルの要素の数が 2 の累乗ではありません"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "%qs 属性が無視されました"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "%qs 属性は名前付き引数を持つプロトタイプが必要です"
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "%qE 属性は効果がありません"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "%qs 属性は配列型のみに適用できます"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
@@ -29097,7 +29131,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void の値が本来の意味通りに無視されませんでした"
@@ -29127,62 +29161,62 @@
 msgid "GCC supports only %u nested scopes"
 msgstr "GCC は %u 重の入れ子のスコープまでサポートします"
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "ラベル %q+D が使用されましたが、定義されていません"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "入れ子になった関数 %q+D が宣言されましたが定義されていません"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr "インライン関数 %q+D が宣言されましたが定義されていません"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "使用されない変数 %q+D です"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, gcc-internal-format
 msgid "variable %qD set but not used"
 msgstr "変数 %qD が設定されましたが使用されていません"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "元々はここで定義されました"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr ""
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr ""
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "%q+D 用のプロトタイプは前の古いスタイルの定義より多くの引数を宣言しています"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "%q+D 用のプロトタイプは前の古いスタイルの定義より少ない引数を宣言しています"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr ""
@@ -29189,42 +29223,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "非プロトタイプ定義に続いて %q+D 用のプロトタイプがあります"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "前の %q+D の宣言はここです"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "前の %q+D の暗黙的な宣言はここです"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "前の %q+D の宣言はここです"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "%q+D が異なる種類のシンボルとして再宣言されました"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "組み込み関数 %q+D が非関数として宣言されました"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "%q+D の宣言が組み込み関数を隠します"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "列挙型 %q+D の再宣言です"
@@ -29232,344 +29266,344 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "組み込み関数 %q+D と型が競合しています"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "%q+D と型が競合しています"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr "名前付き (generic と %s) の %q+D 用アドレス空間が競合しています"
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr "名前付き (%s と generic) の %q+D 用アドレス空間が競合しています"
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr "名前付き (%s vs %s) の %q+D 用アドレス空間が競合しています"
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "%q+D 用の型修飾子が競合しています"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
 msgstr "%q+D が異なる型で再定義されました"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "typedef %q+D が再定義されました"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "%q+D が再定義されました"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "%q+D は静的宣言の後に非静的宣言が続いています"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "%q+D は非静的宣言の後に静的宣言が続いています"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr "%q+D に関して %<gnu_inline%> 属性が存在します"
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, gcc-internal-format
 msgid "but not here"
 msgstr "しかし、ここにはありません"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "%q+D のスレッド局所宣言の後に非スレッド局所宣言があります"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "%q+D の非スレッド局所宣言の後にスレッド局所宣言があります"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "リンク無し宣言の後に %q+D の extern 宣言が続いています"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "extern 宣言の後にリンク無し %q+D の宣言が続いています"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "リンク無し %q+D の再定義です"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr "%q+D が異なる可視性で再定義されています (古い可視性が保護されます)"
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "%qD のインライン宣言の後に非インライン属性の宣言があります"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "%q+D の非インライン属性での宣言の後にインライン宣言があります"
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "%q+D の非インライン属性での宣言の後にインライン宣言があります"
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "仮引数 %q+D が再宣言されました"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "%q+D の冗長な再宣言です"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "%q+D の宣言は前の非変数を隠します"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "%q+D の再宣言は前の局所宣言を隠します"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "隠された宣言はここです"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "入れ子になった外部宣言 %qD です"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "関数 %qE の暗黙的な宣言です"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "組み込み関数 %qD の互換性がない暗黙的な宣言です"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "無効な宣言です"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "関数 %qD の互換性がない暗黙的な宣言です"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE が宣言されていません (この関数内での最初の使用)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "未宣言の識別子は出現した各関数内で一回のみ報告されます"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "ラベル %qE があらゆる関数の外側から参照されました"
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr ""
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "ラベル %qD はここで定義されています"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD はここで宣言されています"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr ""
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "重複したラベルの宣言 %qE です"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重複したラベル %qD です"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "伝統的な C ではラベルを名前空間で分離できません。識別子 %qE が競合します"
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr ""
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "switch がここから開始します"
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr ""
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE が誤った種類のタグとして宣言されました"
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "無名構造体/共用体が、そのインスタンスを定義していません"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, fuzzy, gcc-internal-format
 #| msgid "declaration %qD does not declare anything"
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "宣言 %qD が何も宣言していません"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "空の宣言内に無意味な型名があります"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "ファイルスコープの空の宣言内に %<auto%> があります"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "ファイルスコープの空の宣言内に %<register%> があります"
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "空の宣言内に無意味な記憶域クラス指定があります"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "useless type name in empty declaration"
 msgid "useless %qs in empty declaration"
 msgstr "空の宣言内に無意味な型名があります"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "空の宣言内に無意味な型修飾子があります"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 #| msgid "useless %<__thread%> in empty declaration"
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "空の宣言内に無意味な %<__thread%> があります"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "空の宣言です"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 は仮引数配列宣言内での %<static%> または型修飾子をサポートしません"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 は %<[*]%> 配列宣言をサポートしません"
@@ -29577,38 +29611,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> は関数プロトタイプスコープ以外では許可されていません"
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D は通常は関数です"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "typedef %qD が初期化されました (代わりに __typeof__ を使用してください)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "関数 %qD が変数のように初期化されました"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "仮引数 %qD が初期化されます"
@@ -29617,259 +29651,259 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "変数 %qD には初期化子がありますが不完全型です"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "noinline 属性が与えられたインライン関数 %q+D です"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "%qT 内の初期化されない定数メンバは C++ では無効です"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD は初期化されるべきです"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "初期化子が %q+D のサイズ特定に失敗しました"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "%q+D 内に配列のサイズがありません"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "0 または負のサイズの配列 %q+D です"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "%q+D の記憶域サイズが一定ではありません"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "非静的変数 %q+D 用のアセンブラ指定を無視しています"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "volatile フィールドがあるオブジェクトをレジスタに配置できません"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, gcc-internal-format
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "初期化されていない定数 %qD は C++ 内では無効です"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C は前方仮引数宣言を禁じます"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "複合リテラル内での型定義は C++ では無効です"
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "ビットフィールド %qs の幅が整数定数ではありません"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "ビットフィールド %qs の幅が整数定数式ではありません"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "ビットフィールド %qs の幅が負です"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "ビットフィールド %qs の幅が 0 です"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "ビットフィールド %qs が無効な型を持っています"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "ビットフィールド %qs の型は GCC 拡張です"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "%qs の幅がそのサイズを超えています"
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs の幅はその型の値より狭いです"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 はサイズを評価できない配列 %qE を禁止しています"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 はサイズが評価できない配列を禁止しています"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 は可変長の配列を禁止しています"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "ファイルスコープの可変 %qE です"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "ファイルスコープの可変フィールドです"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "型がデフォルトの %<int%> に %qE の宣言内でなります"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "型がデフォルトの %<int%> に型名内でなります"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "重複した %<const%> です"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "重複した %<restrict%> です"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "重複した %<volatile%> です"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "重複した %<restrict%> です"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "名前付きアドレス空間 (%s と %s) が競合しています"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "関数定義が %<auto%> と宣言されています"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "関数定義が %<register%> と宣言されています"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "関数定義が %<typedef%> と宣言されています"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "関数定義が %<auto%> と宣言されています"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "構造体フィールド %qE 用に記憶域クラスが指定されています"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "構造体フィールド用に記憶域クラスが指定されています"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "仮引数 %qE 用に記憶域クラスが指定されました"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "無名仮引数用に記憶域クラスが指定されました"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "型名用に記憶域クラスが指定されました"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE が初期化され、 %<extern%> として宣言されています"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE が %<extern%> と初期化子の両方を持っています"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "%qE のファイルスコープ宣言は %<auto%> を指定します"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "%qE のファイルスコープ宣言は %<register%> を指定します"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "入れ子になった関数 %qE が %<extern%> と宣言されています"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope %qE implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -29878,701 +29912,701 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "仮引数で無い配列宣言内の静的または型修飾子です"
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "void の配列としての %qE の宣言です"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "void の配列としての型名の宣言です"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "関数の配列としての %qE の宣言です"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "関数の配列としての型名の宣言です"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "配列 %qE のサイズが非整数型です"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "無名配列のサイズが非整数型です"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C はサイズが 0 の配列 %qE を禁止しています"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C はサイズが 0 の配列を禁止しています"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "配列 %qE のサイズが負です"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "無名配列のサイズが負です"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "配列 %qE のサイズが大きすぎます"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "無名配列のサイズが大きすぎます"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr ""
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "配列の型が不完全要素型を持っています"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE は関数を返す関数と宣言されています"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "型名は関数を返す関数として宣言されています"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE は配列を返す関数として宣言されています"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "型名は配列を返す関数として定義されています"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "関数定義が void 戻り型の修飾子を持っています"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C は関数型の修飾子を禁止しています"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C は関数型の修飾子を禁止しています"
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs が %<auto%> 修飾子と %qE 用に組み合わされています"
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs が %<register%> 修飾子と %qE 用に組み合わされています"
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs が自動変数 %qE 用に指定されています"
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs が仮引数 %qE 用に指定されています"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs が無名仮引数用に指定されました"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs が構造体フィールド %qE 用に指定されています"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs が構造体フィールド用に指定されています"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "ビットフィールド %qs が無効な型を持っています"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "ビットフィールド %qs が無効な型を持っています"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for typedef %qE"
 msgstr "%q+D 用の整列が指定されていないようです"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, fuzzy, gcc-internal-format
 #| msgid "%qs specified for parameter %qE"
 msgid "alignment specified for %<register%> object %qE"
 msgstr "%qs が仮引数 %qE 用に指定されています"
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, fuzzy, gcc-internal-format
 #| msgid "%qs specified for parameter %qE"
 msgid "alignment specified for parameter %qE"
 msgstr "%qs が仮引数 %qE 用に指定されています"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "%qs specified for unnamed parameter"
 msgid "alignment specified for unnamed parameter"
 msgstr "%qs が無名仮引数用に指定されました"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for bit-field %qE"
 msgstr "%q+D 用の整列が指定されていないようです"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 #| msgid "%qs specified for unnamed parameter"
 msgid "alignment specified for unnamed bit-field"
 msgstr "%qs が無名仮引数用に指定されました"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of function %qD"
 msgid "alignment specified for function %qE"
 msgstr "関数 %qD への代入です"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C は const や volatile の関数型を禁止しています"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "構造体または共用体のメンバは可変型を持つことは出来ません"
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "変数またはフィールド %qE が void と宣言されています"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "仮引数配列宣言内の属性が無視されました"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "フィールド %qE が関数として宣言されています"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "フィールド %qE が不完全型を持っています"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "無名フィールドが不完全型を持っています"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "関数 %qE 用の無効な記憶域クラスです"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "関数 %<main%> をインラインに出来ません"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, fuzzy, gcc-internal-format
 #| msgid "%qE initialized and declared %<extern%>"
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qE が初期化され、 %<extern%> として宣言されています"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C99 does not support %<_Static_assert%>"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 は %<_Static_assert%> をサポートしません"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "前に %<static%> と宣言された変数が %<extern%> と再宣言されています"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "変数 %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "変数 %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "可変型の入れ子になっていない関数です"
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "可変型のオブジェクトはリンクされてはいけません"
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "関数宣言がプロトタイプではありません"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "関数宣言中に（型の無い）仮引数名があります"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "仮引数 %u (%q+D) が不完全型を持っています"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "仮引数 %u が不完全型を持っています"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "仮引数 %u (%q+D) が void 型を持っています"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "仮引数 %u が void 型を持っています"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> は唯一の仮引数でなければいけません"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "仮引数 %q+D は直前に定義されています"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "仮引数リスト内で %<%s %E%> が宣言されています"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "無名 %s が仮引数リスト内で宣言されています"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "そのスコープはこの定義または宣言のみです。これは多分希望したものではないでしょう"
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "列挙型がここで定義されています"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "構造体がここで定義されています"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "共用体がここで定義されています"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%> の再定義です"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%> の再定義です"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "%<union %E%> の入れ子になった再定義です"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "%<struct %E%> の入れ子になった再定義です"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "%qs 式内での型定義は C++ では無効です"
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "宣言が何も宣言していません"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 は無名構造体/共用体をサポートしません"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 は無名構造体/共用体をサポートしません"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "重複したメンバ %q+D です"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "共用体に名前付きメンバがありません"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "共用体にメンバがありません"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "構造体に名前付きメンバがありません"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "構造体にメンバがありません"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "共用体に可変配列メンバがあります"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr "構造体に可変配列メンバ以外のメンバがありません"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "type %qT is too large"
 msgstr "配列 %qE のサイズが大きすぎます"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "共用体を透過的にできません"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "%<enum %E%> の入れ子になった再定義です"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> の再定義です"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "列挙値が整数の範囲の最大値を超えました"
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "指定したモードは列挙値用には小さすぎます"
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE 用の列挙値が整数定数ではありません"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "列挙値がオーバーフローしました"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "戻り値の型が不完全型です"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "戻り値の型をデフォルトの %<int%> にします"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "前に %qD 用のプロトタイプがありません"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD がプロトタイプ無しで、定義される前に使用されました"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "前に %qD 用の定義がありません"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD はその定義の前で宣言しないで使用されました"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%qD の戻り型が %<int%> ではありません"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD は通常は非静的関数です。"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "プロトタイプ関数宣言内で古いスタイルの仮引数宣言です"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "伝統的な C では ISO C スタイルの関数定義は拒否されます"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "仮引数名が省略されています"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "古いスタイルの関数定義です"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "仮引数リストに仮引数名がありません"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD は非仮引数として宣言されています"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "複数の仮引数が %qD という名前です"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "仮引数 %qD が void 型で宣言されています"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%qD の型をデフォルトの %<int%> にします"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "仮引数 %qD が不完全型を持っています"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "仮引数 %qD 用の宣言がありますが、そのような仮引数はありません"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "引数の数が組み込みプロトタイプと一致しません"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "引数の数がプロトタイプと一致しません"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "プロトタイプ宣言です"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "引数 %qD が組み込みプロトタイプと一致しません"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引数 %qD がプロトタイプと一致しません"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "仮引数 %qD が設定されましたが使用されません"
@@ -30580,208 +30614,208 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> ループ初期化宣言は C99 モード内でのみ許可されています"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99 or -std=gnu99 to compile your code"
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "オプション -std=c99 または -std=gnu99 をコードコンパイル時に使用してください"
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "静的変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "非変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "互換性のないアドレス空間修飾子 %qs と %qs です"
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE が重複しています"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "宣言指定内に二個またはそれ以上の型があります"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> は GCC にとって長すぎます"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 は複素数型をサポートしません"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr ""
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int128%> type"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C は %<__int128%> 型をサポートしません"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported for this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 は複素数型をサポートしません"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C は十進浮動小数点をサポートしません"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "固定小数点型はこのターゲットではサポートされていません"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C は固定小数点型をサポートしません"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE は宣言の開始ではありません"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> が %<auto%> と併せて使用されています"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> が %<register%> と併せて使用されています"
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s は %s をサポートしません"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> が %<extern%> の前にあります"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> が %<static%> の前にあります"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "宣言指定内に複数の記憶域クラスがあります"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs used with %qE"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> が %<_Fract%> または %<_Accum%> 無しで使用されています"
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C は単なる %<complex%> を %<double complex%> を意味するものとしてはサポートしません"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C は複素整数型をサポートしません"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -30791,7 +30825,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr "識別子 %qE は C++ 予約語と競合しています"
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "行末 (EOL) が予期されます"
@@ -30811,8 +30845,8 @@
 msgid "unknown type name %qE"
 msgstr "不明な型名 %qE です"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "宣言指定が予期されます"
@@ -30828,7 +30862,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>、識別子または %<(%> が予期されます"
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -30906,7 +30940,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 は %<_Static_assert%> をサポートしません"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "文字列リテラルが予期されます"
@@ -30966,14 +31000,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "識別子が予期されます"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "列挙型リストの最後にコンマがあります"
@@ -31442,32 +31476,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr "型または記憶域クラスがここで指定されていません、"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明な property 属性です"
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%<setter%> 属性は一回のみ指定できます"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 名は %<:%> で終端されなければいけません"
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%<getter%> 属性は一回のみ指定できます"
@@ -31478,51 +31512,51 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
@@ -31538,12 +31572,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -31555,29 +31589,29 @@
 msgid "expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not const"
 msgid "%qD is not a constant"
 msgstr "%q#D は const ではありません"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> または %<shared%> が予期されます"
@@ -31612,17 +31646,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<runtime%> は %<chunk_size%> 仮引数をとりません"
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<auto%> は %<chunk_size%> 仮引数をとりません"
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "`無効なスケジュールの種類です"
@@ -31645,12 +31679,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -31670,19 +31704,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "`無効なスケジュールの種類です"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "無効なマスクです"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -31694,62 +31728,62 @@
 msgid "invalid proc_bind kind"
 msgstr "`無効なスケジュールの種類です"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid pragma"
 msgstr "無効な #pragma %s です"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -31759,18 +31793,18 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "_Cilk_for statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -31780,256 +31814,256 @@
 msgid "not enough perfectly nested loops"
 msgstr "ループが完全な入れ子になっていません"
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<operator%> が予期されます"
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<using%>"
 msgid "expected %<point%>"
 msgstr "%<using%> が予期されます"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<try%>"
 msgid "expected %<target%>"
 msgstr "%<try%> が予期されます"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "%<decltype%> が予期されます"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma GCC pop_options%> に対応した %<#pragma GCC push_options%> がありません"
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, fuzzy, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "前方での `%s' の宣言"
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<omp_priv%> or function-name"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 #| msgid "expected function"
 msgid "expected function-name %<(%>"
 msgstr "関数が予期されます"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動変数 %qE は %<threadprivate%> になることは出来ません"
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE は不完全型を持っています"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "vectorlength must be an integer constant"
 msgstr "引数は定数でなければいけません"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "スタックサイズは 2 の累乗でなければいけません"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, fuzzy, gcc-internal-format
 #| msgid "case label is not an integer constant expression"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "case ラベルは整数定数式に出来ません"
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma simd%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "base of array section must be pointer or array type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<:%> or numeral"
 msgstr "%<:%> または %<::%> が予期されます"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "array notations cannot be used with function type"
 msgstr "関数型に対して new を適用できません"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 #| msgid "expected boolean expression"
 msgid "expected array notation expression"
@@ -32040,7 +32074,7 @@
 msgid "%qD has an incomplete type"
 msgstr "%qD は不完全型を持っています"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void 式の無効な使用法です"
@@ -32150,7 +32184,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "添字が付けられた値が、配列、ポインタまたはベクトルではありません"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "配列の添字が整数型ではありません"
@@ -32276,7 +32310,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "プロトタイプによると渡している %d 番目の %qE の引数は符号付きとしてです"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
@@ -32306,7 +32340,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "不完全型へのポインタに関する計算です"
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -32392,7 +32426,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
@@ -32428,7 +32462,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "条件式内でポインタ型と整数型が適合しません"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr ""
@@ -32512,7 +32546,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "型 %qT の関数呼び出しから一致しない型 %qT へのキャストです"
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "異なるサイズの整数からポインタへのキャストです"
@@ -32666,7 +32700,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "左辺の初期化は format 属性の候補のようです"
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "戻り型は format 属性の候補のようです"
@@ -32803,7 +32837,7 @@
 msgid "initialization of a flexible array member"
 msgstr "可変配列メンバを初期化しています"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "ワイド文字列から char 配列が初期化されています"
@@ -32849,7 +32883,7 @@
 msgid "invalid initializer"
 msgstr "無効な初期化子です"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
@@ -32994,7 +33028,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C は %<goto *expr;%> を禁止しています"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> と宣言されている関数が %<return%> 文を持っています"
@@ -33004,7 +33038,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -33112,19 +33146,19 @@
 msgid "expression statement has incomplete type"
 msgstr "式の中の文に不完全型があります"
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "comparing vectors with different element types"
 msgstr "異なる列挙型の比較に関して警告する"
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, fuzzy, gcc-internal-format
 #| msgid "different number of results"
 msgid "comparing vectors with different number of elements"
 msgstr "結果の数が異なります"
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "浮動小数点の比較で == や != を使うのは安全ではありません"
@@ -33175,12 +33209,12 @@
 msgstr "NULL ポインタがあるポインタの順序比較です"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
@@ -33206,89 +33240,89 @@
 msgid "used vector type where scalar is required"
 msgstr "スカラーが必要な場所で構造体型の値が使用されています"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE does not have pointer or array type"
@@ -33299,17 +33333,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE は %<reduction(%s)%> 用の無効な型を持っています"
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE は %<threadprivate%> (%<copyin%> 用として) でなければいけません"
@@ -33319,7 +33353,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
@@ -33329,17 +33363,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE は %<firstprivate%> 句内では変数ではありません"
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE は %<lastprivate%> 句内では変数ではありません"
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -33357,51 +33391,51 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
@@ -33412,17 +33446,17 @@
 msgstr ""
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr "  %qT から %qT へ %<this%> パラメータを暗黙的に変換する方法が不明です"
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  no known conversion for argument %d from %qT to %qT"
 msgid "  conversion of argument %d would be ill-formed:"
@@ -33429,100 +33463,100 @@
 msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "  no known conversion for argument %d from %qT to %qT"
 msgid "  no known conversion from %qT to %qT"
 msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, gcc-internal-format
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] "  候補では %d 個の引数が予期されますが、%d 個の引数が与えられています"
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, gcc-internal-format
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr "%s%D(%T, %T, %T) <組み込み>"
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, gcc-internal-format
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "%s%D(%T, %T) <組み込み>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, gcc-internal-format
 msgid "%s%D(%T) <built-in>"
 msgstr "%s%D(%T) <組み込み>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, gcc-internal-format
 msgid "%s%T <conversion>"
 msgstr "%s%T <変換>"
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr ""
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr "%s%#D <削除済み>"
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, fuzzy, gcc-internal-format
 msgid "%s%#D"
 msgstr "%s: %s"
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "%qT から %qT への変換が曖昧です"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, gcc-internal-format
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr ""
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "オーバーロードされている %<%D(%A)%> の呼び出しが曖昧です"
@@ -33529,476 +33563,476 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr ""
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "%<(%T) (%A)%> への呼び出しが適合しません"
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "%<(%T) (%A)%> の呼び出しが曖昧です"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous overload for %qs in %<%s %E%>"
 msgid "ambiguous overload for "
 msgstr "%qs 用の %<%s %E%> 内にあるオーバーロードが曖昧です"
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %qs in %<%s %E%>"
 msgid "no match for "
 msgstr "%qs で %<%s %E%> 内にあるものが適合しません"
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "二項演算子 %s への無効な被演算子です (%qT と %qT)"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT and %qT)"
 msgstr "二項演算子 %s への無効な被演算子です (%qT と %qT)"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "ternary %<operator?:%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, fuzzy, gcc-internal-format
 #| msgid "no match for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%E ? %E : %E%> 内にある三項演算子 %<operator?:%> が適合しません "
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "%<operator%s%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> で %<%E%s%> 内にあるものが適合しません"
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "%<operator[]%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%E[%E]%> 内の %<operator[]%> が適合しません"
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "%qs で %<%s %E%> 内にあるものが適合しません"
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> で %<%E %s %E%> 内にあるものが適合しません"
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> で %<%s%E%> 内にあるものが適合しません"
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ は中間項が省略された ?: 式を禁止しています"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "%d 番目の引数が `%s' の型と互換性がありません"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T と %q#T の間での比較です"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, gcc-internal-format
 msgid "non-placement deallocation function %q+D"
 msgstr ""
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr ""
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%<operator %s%> は %qT 用としては適切ではありません"
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr "%q+#D は非公開です"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr "%q+#D は保護されています"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr "%q+#D はアクセス出来ません"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr ""
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULL から非ポインタ型 %qT へ変換しています"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULL から非ポインタ型へ変換しています"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "%qT 用の初期化子の周りに中括弧が多すぎます"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT from %qT may alter its value"
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr "%qT への %qT からの変換はその値が変更になるかもしれません"
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "%qT から %qT への無効な変換です"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "%qT から %qT への無効な変換です"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, gcc-internal-format
 msgid "  initializing argument %P of %q+D"
 msgstr ""
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, gcc-internal-format
 msgid "cannot bind %qT lvalue to %qT"
 msgstr ""
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr ""
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, gcc-internal-format
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr ""
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "関数呼び出しの引数が format 属性の候補であるようです"
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, gcc-internal-format
 msgid "  in call to %q+D"
 msgstr ""
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (-fno-deduce-init-list でこれを無効に出来ます)"
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr ""
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, fuzzy, gcc-internal-format
 #| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "定数が自身を参照しています"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "コンストラクタ %<%T::%D%> を直接呼び出すことは出来ません"
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "オーバーロードされた %<%s(%A)%> の呼び出しは曖昧です"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "オブジェクト以外がメンバ関数 %qD を呼び出すことは出来ません"
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr " 候補 1: %q+#F"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr " 候補 2: %q+#F"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "%qE から %qT へ変換できません"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr ""
@@ -34157,7 +34191,7 @@
 msgid "  by %q+D"
 msgstr ""
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D は無効です。無名共用体は非静的データメンバのみ持つことが出来ます"
@@ -34167,7 +34201,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D は無効です。無名構造体は非静的データメンバのみ持つことが出来ます"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr "無名共用体内に非公開メンバ %q+#D があります"
@@ -34177,7 +34211,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "無名構造体内に非公開メンバ %q+#D があります"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
@@ -34310,70 +34344,81 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4538
+#: cp/class.c:4300
 #, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, fuzzy, gcc-internal-format
+#| msgid "alignment of %qD is bigger than original declaration"
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr "%qD の整列は元の宣言より大きいです"
+
+#: cp/class.c:4557
+#, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "非仮想関数 %q+D 用の初期化子が指定されています"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "関数を inline にできません"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has volatile type"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr "コンストラクタが無いクラス内に非静的参照 %q+#D があります"
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr "コンストラクタが無いクラス内に非静的定数メンバ %q+#D があります"
@@ -34380,103 +34425,103 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D は定数参照を取るように宣言されていますが、暗黙的な宣言では非定数参照を取ります"
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "直接の基底 %qT は曖昧なため %qT 内でアクセスできません"
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "仮想基底 %qT は曖昧なため %qT 内ではアクセスできません"
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D のオフセットは ABI に適合していないため将来のバージョンの GCC では変更になるかもしれません"
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T が再定義されています"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T は仮想関数を持っており非仮想デストラクタからアクセス可能です"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "type transparent %q#T does not have any fields"
 msgstr "%q#D 用のプロトタイプがクラス %qT 内のどれとも一致しません"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "メンバ関数の名前を欠いています"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "言語文字列 %<\"%E\"%> は認識できません"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "関数 %qD から型 %q#T への変換が適合しません"
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "オーバーロードされた関数 %qD から型 %q#T への変換は曖昧です"
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "メンバ %qD へのポインタと見なしています"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "型情報が不十分です"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE を型 %qT から型 %qT へ変換できません"
@@ -34486,12 +34531,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "%q#D が宣言されています"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr "%qD の意味の %q+#D からの変更です"
@@ -34531,43 +34576,43 @@
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 msgid "call to internal function"
 msgstr "内部エラー"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr ""
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-constexpr function %qD"
@@ -34574,216 +34619,216 @@
 msgstr "非関数 %qD の呼び出しです"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr ""
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "右シフト回数が負です"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "array subscript out of bound"
 msgstr ""
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 msgid "negative array subscript"
 msgstr "配列の添字が `char' 型です"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not initialized with a constant expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "初期化子を欠いています"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qE は初期化されていません"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D は const ではありません"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D は volatile です"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant-expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant-expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, gcc-internal-format
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant-expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "初期化子内に非定数の配列インデックスがあります"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "ファイル \"%s\" に戻るはずでした"
@@ -34855,7 +34900,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr ""
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr ""
@@ -34895,7 +34940,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -34905,293 +34950,293 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "型 %qT から型 %qT へ変換できません"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "%q#T から %q#T への変換です"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "%qE が型 %qT の範囲外にあるので変換結果は不定です"
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T が %qT が予期される場所で使用されました"
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "%qE から %qT へ変換できません"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "%q#T が浮動小数点値が予期される場所で使用されました"
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "%qT から非スカラ型 %qT への変換が要求されました"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "疑似デストラクタが呼び出されません"
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "文は効果がありません"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "NULL から非ポインタ型へ変換しています"
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "%qT からのデフォルトの型変換が曖昧です"
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -35616,241 +35661,241 @@
 msgid "template parameters do not match template %qD"
 msgstr "仮引数 `%s' の型が宣言されていません"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, fuzzy, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr "無名構造体が名前つき型の中にありません"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, fuzzy, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr "無名共用体にメンバがありません"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一つの宣言に複数の型があります"
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "`enum %s' の再宣言"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, fuzzy, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typdef 宣言で型名を欠いています"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ は無名構造体を禁止しています"
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, fuzzy, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, fuzzy, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "`%s' の宣言で型がデフォルトの `int' とされました"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef `%s' が初期化されました"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "`%s' の宣言に `extern' がついており、初期化もされています"
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "初期化された変数 `%s' は dllimport マークされています"
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D のテンプレート宣言です"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "ポインタ宣言子に不適切な型修飾子"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "重複した初期化子"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr ""
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "変数 `%s' には初期化子がありますが、不完全型です"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "配列 `%s' の要素に不完全型があります"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "`%s' の宣言に `extern' がついており、初期化もされています"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "仮引数 `%s' は不完全型です"
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "自明でないラベルのついた初期化子です"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "`%s' での配列サイズを欠いています"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
@@ -35858,836 +35903,836 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "未初期化定数を ROM に置かない"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "無効なビット列初期化子です"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, fuzzy, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "無名基底クラスの初期設定子が曖昧です"
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "無効な初期化子です"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "入力ファイルが多すぎます"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "スカラー初期化子がブレースで囲まれています"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "初期化子のまわりのブレースを欠いています"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "配列 `%s' の要素に不完全型があります"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ISO C89 は複合リテラルを禁じます"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "`%s' は不完全型です"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "共用体初期化子内の要素が多すぎます"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "_Pramga が括弧で囲まれた文字列リテラルを受け取りました"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "コンストラクタの静的メンバ初期化子は無効です"
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(クラス外での初期化を必要とします)"
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "仮引数 %qD が初期化されます"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr ""
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr ""
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, fuzzy, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "関数 `%s' が変数であるかのように初期化されました"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "`%s' での配列サイズを欠いています"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, fuzzy, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, fuzzy, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> variable"
 msgstr ""
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, gcc-internal-format
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "`::main' を template としては宣言できません"
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "`::main' を inline としては宣言できません"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "`::main' を inline としては宣言できません"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD cannot be a bit-field"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "静的メンバ %qD はビットフィールドに出来ません"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "%qD has invalid argument list"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, fuzzy, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "`main' は `int' を返さなければなりません"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "typedef %q+D が再定義されました"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, fuzzy, gcc-internal-format
 msgid "%q+#D explicitly defaulted here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "メンバ関数へのポインタが呼ばれましたが、クラススコープ内ではありません"
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "配列 `%s' の大きさが負です"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, fuzzy, gcc-internal-format
 msgid "size of array is negative"
 msgstr "配列 `%s' の大きさが負です"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, fuzzy, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "定数式が欠けているか無効です"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C89 は可変長サイズの配列 `%s' を禁じます"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C89 は可変長サイズの配列 `%s' を禁じます"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "可変長配列が使用されています"
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "配列の次元がオーバーフローしました"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "`%s' の宣言は void の配列"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "`%s' の宣言は void の配列"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "配列参照での添字を欠いています"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, fuzzy, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, fuzzy, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "無名変数やフィールドが void と宣言されました"
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "変数またはフィールドが void と宣言されました"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr ""
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "関数の定義が `register' と宣言されました"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C は単なる %<complex%> を %<double complex%> を意味するものとしてはサポートしません"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ では型の無い %qs の宣言を禁止しています"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "このターゲットでは %<__int128%> はサポートされていません"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ は %<__int128%> を %qs に対してはサポートしていません"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> または %<unsigned%> は %qs に対しては無効です"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> と %<unsigned%> が %qs に対して両方指定されています"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> は %qs に対しては無効です"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> は %qs に対しては無効です"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> は %qs に対しては無効です"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> または %<short%> は %qs に対しては無効です"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>、%<int%>、%<short%>、または %<char%> は %qs に対しては無効です"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> または %<short%> が char と共に %qs に対して指定されています"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> および %<short%> が %qs に対して両方指定されています"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> または %<long%> は %qs に対しては無効です"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed または unsigned の使用は %qs に対しては無効です"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex は %qs に対しては無効です"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "仮引数宣言の中の typedef 宣言は無効です"
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "仮引数宣言の中の記憶域クラス指定は無効です"
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs の宣言内に複数の記憶域クラスがあります"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "%qs に対して記憶域クラスが指定されています"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "仮引数 %qs に対して記憶域クラスタ指定されています"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, fuzzy, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "ネストした関数 `%s' は `extern' に宣言されました"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "`%s' のトップレベルの宣言が `auto' を指定します"
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "friend 関数宣言内の記憶クラス指定子は無効です"
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "`%s' は配列を返す関数として宣言されています"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
@@ -36694,476 +36739,476 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "constructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr "コンストラクタは virtual 宣言できません"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, fuzzy, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "デストラクタは仮引数を取りません"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "メンバ関数は暗黙的にそのクラスの friend です"
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr ""
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, fuzzy, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "配列 `%s' の大きさが大きすぎます"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "`explicit' にできるのは、コンストラクタだけです"
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "static `%s' を mutable として宣言できません"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, fuzzy, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const `%s' を `mutable' として宣言できません"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, fuzzy, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "クラス宣言の外側で virtual 指定しています"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "複雑なパラメタをもつ関数は inline にできません"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, fuzzy, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "クラス `%s' を大域スコープの friend にしようとしています"
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "無効な用法の of %%d, %%x, 又は %%X"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%s: 関数 `%s' の宣言が変換されていません\n"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD redeclared as function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "変数 %qD が関数として再宣言されました"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 #| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "元の型はここで宣言されました"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "領域 `%s' は不完全な型です"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "仮引数が不完全型です"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr "関数を inline にできません"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `register' は無効です"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "初期化子リストは非メンバ関数では使えません"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, fuzzy, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual な非クラス関数 `%s'"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "`::main' を static としては宣言できません"
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "他の関数内で static 関数を宣言できません"
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, gcc-internal-format
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, fuzzy, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "`%s' が初期化されるところで、`extern' 宣言されました"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, fuzzy, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "仮引数 `%s' は不完全型です"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "パラメタはメソッドの型を不正に宣言しました"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -37183,174 +37228,174 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, fuzzy, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, fuzzy, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ は無名構造体を禁止しています"
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, fuzzy, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr ""
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr ""
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, fuzzy, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "using alias template specialization %qT after %qs"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, fuzzy, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -37362,88 +37407,88 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "事前の宣言なしの大域関数に関して警告する"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr ""
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr ""
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "型修飾子 `%s' は struct や class の後には使えません"
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複した case の値"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "`%s' は前にここで定義されました"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr ""
@@ -37452,90 +37497,90 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "`%s' の列挙値が整数定数ではありません"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, fuzzy, gcc-internal-format
 #| msgid "integer constant is too large for %<unsigned long%> type"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "整数定数が %<unsigned long%> 型に対して大きすぎます"
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "列挙値がオーバーフロー"
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr ""
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, fuzzy, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "`%s' の前方宣言がありません"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, fuzzy, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "無効な宣言です"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "関数の戻り型は %<volatile%> と互換性がありません"
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, gcc-internal-format
 msgid "parameter %q+D set but not used"
 msgstr ""
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "無効な宣言です"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD defaults to %<int%>"
 msgid "use of %qD before deduction of %<auto%>"
@@ -37577,7 +37622,7 @@
 msgid "deleting %qT is undefined"
 msgstr "%qT の削除は定義されていません"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D のテンプレート宣言です"
@@ -37600,7 +37645,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "デストラクタ %qD がメンバテンプレートとして宣言されています"
@@ -37692,27 +37737,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "ビットフィールドの幅が %qD 非整数型 %qT です"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "無名構造体が名前つき型の中にありません"
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "anonumous 名前空間の集合体は static でなければなりません"
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "メンバがない無名共用体です"
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> の戻り型は %qT でなければいけません"
@@ -37721,47 +37766,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "%<operator new%> の第一引数はデフォルト引数を持っていてはいけません"
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> は第一引数として型 %<size_t%> (%qT) をとります"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, fuzzy, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "`operator delete' の戻り型は `void' でなければなりません"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, fuzzy, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "`operator delete' は第一引数として `void *' 型をとります"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using anonymous type, is used but never defined"
 msgstr "`%s' が `static' と宣言されましたが未定義です"
@@ -37770,47 +37815,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "`%s' が `static' と宣言されましたが未定義です"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "`%s' が使われましたが未定義です"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "仮引数リストからの仮引数名を欠いています"
@@ -37817,12 +37862,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
@@ -38421,42 +38466,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初期設定子の末尾が本来より早く出現しました"
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr "多次元配列は初期化子で初期化することができません"
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete での配列サイズが不明です"
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
@@ -38588,17 +38633,17 @@
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, gcc-internal-format
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, gcc-internal-format
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
@@ -39014,7 +39059,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr "識別子 %qE は C++ 予約語と競合しています"
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -39039,7 +39084,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -39104,7 +39149,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "%s 宣言の後ろのセミコロンを欠いています"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
@@ -39129,7 +39174,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -39404,7 +39449,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
@@ -39584,7 +39629,7 @@
 msgid "capture of non-variable %qD "
 msgstr "読み取り専用変数 %qD の増分です"
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, fuzzy, gcc-internal-format
 msgid "%q+#D declared here"
 msgstr "`%s' は前にここで宣言されました"
@@ -39647,7 +39692,7 @@
 msgid "compound-statement in constexpr function"
 msgstr "純粋および定数関数を見つける"
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
@@ -39678,7 +39723,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
@@ -39712,12 +39757,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ は計算型 goto を禁じます"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
@@ -39765,7 +39810,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
@@ -39860,12 +39905,12 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
@@ -39880,7 +39925,7 @@
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> が予期されます"
@@ -39957,212 +40002,212 @@
 msgid "expected type specifier"
 msgstr "型指定が予期されます"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C は前方仮引数宣言を禁じます"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "型名が予期されます"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "宣言 %qD が何も宣言していません"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "インスタンス化されない型に対する無効な操作です"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, gcc-internal-format
 msgid "%qD is not an enumerator-name"
 msgstr ""
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> または %<{%> が予期されます"
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T が複数定義されています"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD は名前空間名ではありません"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "名前空間名が予期されます"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "ここでは関数定義は許可されていません"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, fuzzy, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "初期化子リストは非メンバ関数では使えません"
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "friend 関数 `%s' を初期化できません"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "non-function %qD declared as implicit template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "配列の添字が整数型ではありません"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr ""
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "トップレベルでの `this' の使用は無効です"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -40171,7 +40216,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "無効な宣言子です"
@@ -40178,296 +40223,296 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "無効な宣言です"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "宣言子が予期されます"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD は名前空間です"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "ポインタ演算子が予期されます"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "重複する `virtual' 指定子"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-specifier"
 msgid "duplicate virt-specifier"
 msgstr "型指定子が予期されます"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, gcc-internal-format
 msgid "invalid use of %<auto%>"
 msgstr "無効な %<auto%> の使用です"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "型指定子が予期されます"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> または %<...%> が予期されます"
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr ""
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "メソッドは関数ポインタに変換できません"
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "クラス定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "構造体定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "共用体定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> または %<:%> が予期されます"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "クラス %s 用のファイルを見つけられません。"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD の宣言内に無効なクラス名です"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr "%q+#T の前の定義"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "メンバ宣言の最後には %<;%> が予期されます"
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "メンバ宣言の最後には %<;%> が予期されます"
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr ""
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "識別子または %<(%> が予期されます"
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無効な宣言です"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -40476,550 +40521,550 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver は最早サポートされません"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "`>>' はテンプレートクラス名は `> >' とすべきです"
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "テンプレート型統一中 `%s' が使用されました"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> が %qD の前にあります"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ は `long long' を受け入れません"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE が重複しています"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "`%s' が重複しています"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> が予期されます"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> が予期されます"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> が予期されます"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> が予期されます"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> が予期されます"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> が予期されます"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> が予期されます"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> が予期されます"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> が予期されます"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> が予期されます"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> が予期されます"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> が予期されます"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> が予期されます"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> が予期されます"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> が予期されます"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> が予期されます"
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> が予期されます"
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<static_assert%>"
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<static_assert%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> が予期されます"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> が予期されます"
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> が予期されます"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> が予期されます"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> または %<::%> が予期されます"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "前はここで宣言されました"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "デフォルト引数内でファイルが終了しています"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c method declaration is expected"
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c メソッド定義が予期されます"
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "識別子が必要です"
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected positive integer expression"
 msgstr "整数式が予期されます"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<wait%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "無効な初期化子です"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 #| msgid "a function-definition is not allowed here"
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "ここでは関数定義は許可されていません"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, fuzzy, gcc-internal-format
 msgid "not enough collapsed for loops"
 msgstr "不十分な型情報"
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, fuzzy, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "無効な初期化子です"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "式が予期されます"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "#pragma GCC java_exceptions の末尾にゴミ"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "演算子に対する無効な制約です"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "ret 命令は実装されていません"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "expected variable-name"
 msgstr "名前空間名が予期されます"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "%<,%> または %<)%> が予期されます"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "ポインタ宣言子に不適切な型修飾子"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, fuzzy, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr "`%s' が再定義されました"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -41026,71 +41071,71 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid "candidate is: %#D"
 msgstr "候補: %+#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
 msgstr "%s %+#D"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD は変数ではありません"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, gcc-internal-format
 msgid "too many template headers for %D (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -41097,57 +41142,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "`operator delete' の宣言内に多すぎる引数"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, fuzzy, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "#define 中の仮引数リストが終端されていません"
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD の宣言内でテンプレート仮引数リストが多すぎます"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD の宣言内でテンプレート仮引数リストが少なすぎます"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD はテンプレート関数ではありません"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "%qD は %qD 内では宣言されていません"
@@ -41160,93 +41205,93 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "メンバ関数 %qD は %qT 内では宣言されていません"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <無名>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "%q+#D の宣言です"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr ""
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "#define 中の仮引数リストが終端されていません"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr ""
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template here"
 msgstr "前はここで宣言されました"
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -41253,12 +41298,12 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD 用のデフォルト引数がありません"
@@ -41266,42 +41311,42 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "仮引数リスト中の `void' はリスト全体を占めなければなりません"
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr ""
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "名前無しテンプレートクラスです"
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -41311,57 +41356,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "非テンプレート %q#D のテンプレート定義です"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -41368,7 +41413,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q+D used %d template parameter"
 msgid_plural "previous declaration %q+D used %d template parameters"
@@ -41375,12 +41420,12 @@
 msgstr[0] "`%s' の宣言は仮引数を覆い隠します"
 msgstr[1] "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "テンプレート仮引数 %q+#D です"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "ここで %q#D として再宣言されています"
@@ -41389,106 +41434,106 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "元の定義はここに出現しています"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %q+#D"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "テンプレート仮引数 %q+#D です"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "  mismatched types %qT and %qT"
 msgstr "型 %qT と %qT の間での比較です"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -41496,175 +41541,175 @@
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  候補では %d 個の引数が予期されますが、%d 個の引数が与えられています"
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "型 %qT から型 %qT へ変換できません"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qD"
 msgstr "型 %qT の引数が %qT と一致しません"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "  could not resolve address from overloaded function %qE"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT "
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr ""
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr ""
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, fuzzy, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "#if 式の中では文字列定数が使えません"
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "`restrict' の用法が不適切です"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
@@ -41671,79 +41716,79 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "型が前方の外部宣言と一致しません"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr ""
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of arguments to function %<va_start%>"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "関数 %<va_start%> への引数の数が間違っています"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr ""
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "空の宣言です"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %D"
@@ -41762,269 +41807,269 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "sizeof が関数型に適用されました"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "仮引数 `%s' は無効です"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "無効な宣言です"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "関数が集合体を返しています"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "メンバ関数へのポインタが呼ばれましたが、クラススコープ内ではありません"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "大きさゼロの配列を作ろうとしています"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "static フィールド `%s' を欠いています"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void 式の不適切な使用"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%q+D declared here, later in the translation unit"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr ""
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "不正な文字列定数です"
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%s: `%s' の初期化:\n"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ は減算にメソッドへのポインタを使うことを禁じます"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
@@ -42036,62 +42081,62 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'#' にマクロ仮引数名が続いていません"
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無効なメソッド宣言です。メソッド名が必要です"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
@@ -42329,69 +42374,69 @@
 msgid "invalid base-class specification"
 msgstr "無効な宣言です"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "要求されたメンバ `%s' は多重継承グラフの中で曖昧です"
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "レジスタ '%c' が不明です"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
@@ -42398,202 +42443,202 @@
 msgstr "%qT はテンプレート型ではありません"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "仮引数宣言の中の記憶域クラス指定は無効です"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "%qE は %<reduction%> 用の無効な型を持っています"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "linear step expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "インスタンス変数 `%s' は private と宣言されています"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "インスタンス変数 `%s' は private と宣言されています"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%qs length expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, fuzzy, gcc-internal-format
 #| msgid "expression in static assertion is not an integer constant expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<num_teams%> expression must be integral"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<async%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<device%> id must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, fuzzy, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr "無効な参照型です"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed: %s"
 msgstr "静的アサーションに失敗しました: %E"
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "decltype cannot resolve address of overloaded function"
@@ -42609,126 +42654,126 @@
 msgid "lambda-expression in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "`java_interface' 属性は Java クラス定義に対してのみ用いる事ができます"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr ""
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "要求された init_priority は整数型の定数ではありません"
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, fuzzy, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "init_priority 属性はクラス型オブジェクトのファイルスコープ定義でのみ使えます"
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "要求された init_priority が範囲外です"
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "要求された init_priority は内部で使用するために予約されています"
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "init_priority 属性はこのプラットフォームではサポートされていません"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "`%s' 属性は関数に対してのみ適用されます"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "配列の添字が整数型ではありません"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "Tree 検査: %s があるべき所に %s があります(%s 内, %s:%d)"
@@ -42921,566 +42966,561 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr "配列要素の整列が要素のサイズより大きいです"
 
-#: cp/typeck.c:3141
-#, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr "ISO C++ は左辺値ではない配列の添字を禁じます"
-
-#: cp/typeck.c:3157
+#: cp/typeck.c:3148
 #, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "`register' と宣言された配列に添字をつけようとしています"
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "添字をつけられた値が配列でもポインタでもありません"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "メンバへのポインタ構築の使用でオブジェクトを欠いています"
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ はプログラムの中から `::main' を呼び出すことを禁じます"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "関数に対する引数が多すぎます"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "関数への引数が少なすぎます"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "仮引数が不完全型です"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "仮引数が不完全型です"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, fuzzy, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "関数ポインタが計算で使われました"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, fuzzy, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "%s ローテート回数が負の値です"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, fuzzy, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "%s ローテート回数が負の値です"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, fuzzy, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "%s ローテート回数 >= 型の幅です"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, fuzzy, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "%s ローテート回数 >= 型の幅です"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr ""
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ はポインタと整数との比較を禁じます"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between %qT and %qT"
 msgid "operand types are %qT and %qT"
 msgstr "%qT と %qT の比較です"
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "非浮動小数点引数での順序付けられない比較です"
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "二項演算子 %s が不適切です"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ は減算にメソッドへのポインタを使うことを禁じます"
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ポインタ演算で不完全型へのポインタを使うことは無効です"
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qE"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qE"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ は非左辺値式へのキャストのアドレスを取ることを禁じます"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ は `::main' 関数のアドレスを取ることを禁じます"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr "ISO C++ は非左辺値式へのキャストのアドレスを取ることを禁じます"
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "不完全型へのポインタに対する演算"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "オペランドとして無効な式"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, fuzzy, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "`this' は右辺値式であり、そのアドレスを取ることはできません"
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "register 変数 `%s' のアドレスが要求されました"
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "無名基底クラスの初期設定子が曖昧です"
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "初期化子リストは複合式として取り扱われました"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %qT"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, fuzzy, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "NaN から整数への変換です"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr "%s: 全体的な精度の低下"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "キャストによってポインタが示す型の要求アラインメントが増加します"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ は関数ポインタとオブジェクトポインタの間でのキャストを禁じます"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C は共用体型へのキャストを禁じます"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "%d 番目の引数が `%s' の型と互換性がありません"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "配列の不正な初期化"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "代入として無効な左辺値です"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   ポインタからメンバ関数への変換で"
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "無効なバージョン番号形式"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr ""
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr ""
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr ""
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr ""
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr ""
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr ""
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "format 属性をの候補となりそうな関数について警告する"
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "引数 %d 個の `%s' を渡します"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "非左辺値への参照が返されました"
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr "非左辺値への参照が返されました"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, fuzzy, gcc-internal-format
 msgid "address of label %q+D returned"
 msgstr "要求された大域レジスタ変数 `%s' のアドレス"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr "要求された大域レジスタ変数 `%s' のアドレス"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "デストラクタから値を返そうとしています"
@@ -43487,46 +43527,46 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "コンストラクタの関数 try ブロックのハンドラからは return できません"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "コンストラクタから値を返そうとしています"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "戻り型が関数で、`return' に値がありません"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "初期化子がありません"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "戻り型が void の関数で、`return' に値があります"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -43755,124 +43795,124 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr "%qE の %qT から %qT への変換は曖昧です"
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr ""
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "非ワイド文字列から int の配列が初期化されました"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, fuzzy, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "非ワイド文字列から int の配列が初期化されました"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "char の配列にとって初期化子文字列が長すぎます"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "初期化子を欠いています"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "レコードや共用体にフィールド名がない初期化子です"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "union 初期化子がフィールド名ではなくインデックス値になっています"
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "循環ポインタの代表を検出しました"
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, fuzzy, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "`operator->()'の結果が非ポインタの結果をもたらします"
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
@@ -44050,8 +44090,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -44187,7 +44227,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -44303,7 +44343,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
@@ -44893,12 +44933,12 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
@@ -45169,6 +45209,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -45176,7 +45221,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -45397,399 +45442,399 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 msgid "Function name %qs not allowed at %C"
 msgstr "セクション属性は `%s' には使えません"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "重複した初期化子"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "長さ 0 の初期化は推奨されません"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "-traditional は C++ では受け付けられません"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "正式な仮引数項を欠いています"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "長さ 0 の初期化は推奨されません"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "長さ 0 の初期化は推奨されません"
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "VAX 浮動小数では丸めモードを利用できません"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "VAX 浮動小数では丸めモードを利用できません"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "FPU レジスタ内の機能の値を返す"
@@ -45796,804 +45841,810 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "数値がありません"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "不明なレジスタ名です: %s"
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "ファイル \"%s\" に戻るはずでした"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "section 属性はローカル変数に対しては指定できません"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in statement"
 msgid "ENTRY statement at %C"
 msgstr "式内"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:5597
-#, gcc-internal-format
-msgid "gfc_match_entry(): Bad state"
-msgstr ""
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "expected statement"
+msgid "Unexpected ENTRY statement at %C"
+msgstr "文が予期されます"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "無効なビット列初期化子です"
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "'%s' トークンの所で文法エラー"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "式文が無効です"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr ""
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%>"
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> が予期されます"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "述語は識別子でなければなりません"
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "配列を仮引数リストによって初期化しようとしています"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in statement"
 msgid "VALUE statement at %C"
 msgstr "式内"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%qD は既に定義されています"
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "反復子 `%s' は非整数型です"
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "`*' の前に型の名前があるべきです"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "重複するアクセス指定子"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "重複するアクセス指定子"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, fuzzy, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "識別子が必要です"
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "')' が必要です"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<::%>"
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> が予期されます"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, gcc-internal-format, gfc-internal-format
+msgid "Malformed GENERIC statement at %C"
+msgstr ""
+
+#: fortran/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>"
 msgid "Expected %<=>%> at %C"
 msgstr "%<=%> が予期されます"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>"
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> が予期されます"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "不明なレジスタ名です: %s"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
@@ -46873,343 +46924,343 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "呼び出されたオブジェクトは関数ではありません"
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "NaN から整数への変換です"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "%qT から %qT への無効な変換です"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 msgid "Conversion from %qs to %qs at %L"
 msgstr "NaN から整数への変換です"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "キャストは関数型を指定しています"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, fuzzy, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "`asm' の引数が定数文字列ではありません "
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "入力ファイル %s を close できません"
@@ -47231,28 +47282,28 @@
 msgid "Removing call to function %qs at %L"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "illegal OP in optimize_comparison"
 msgstr "gimple 比較内で無効な被演算子です"
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr ""
@@ -47307,594 +47358,599 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr ""
+
+#: fortran/interface.c:353
+#, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr ""
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr ""
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr ""
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr ""
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr ""
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr ""
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr ""
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr ""
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr ""
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous overload for %qs in %<%s %E%>"
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr "%qs 用の %<%s %E%> 内にあるオーバーロードが曖昧です"
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, fuzzy, gcc-internal-format
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "参照 `%s' は曖昧です: interface `%s' と interface `%s' に現れました"
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "`%s' オプションに対する引数がありません"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qE"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D が未定義シンボル %qE の別名となっています"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, fuzzy, gcc-internal-format
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr "値をベクトルには変換できません"
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
@@ -48307,12 +48363,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
@@ -48322,7 +48378,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
@@ -48347,778 +48403,778 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr ""
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr ""
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "-I- が二回指定されました"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ラベル `%s' が使われましたが定義されていません"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "ラベル `%s' が使われましたが定義されていません"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "ラベル `%s' が使われましたが定義されていません"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "ラベル `%s' が使われましたが定義されていません"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr ""
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr ""
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "式文が無効です"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr ""
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
 msgstr ""
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "`*' の前に型の名前があるべきです"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "`*' の前に型の名前があるべきです"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr ""
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr ""
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 msgid "Label name %qs at %C is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, fuzzy, gcc-internal-format
 msgid "Duplicate construct label %qs at %C"
 msgstr "ラベルの宣言 `%s' が重複しています"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr "無効な文字定数が #if にあります"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr ""
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr ""
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr ""
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr ""
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr ""
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr ""
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, gcc-internal-format, gfc-internal-format
 msgid "gfc_match(): Bad match code %c"
 msgstr ""
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr "式の整数がオーバーフローしました"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr ""
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
 msgstr ""
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr ""
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr ""
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr ""
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in association at %C"
 msgstr "キャストは関数型を指定しています"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "%<,%> または %<)%> が予期されます"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr ""
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, gcc-internal-format
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "無効な型引数です"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr ""
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr ""
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr ""
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr ""
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "  try ブロックに入ります"
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr ""
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in statement"
 msgid "LOCK statement at %C"
 msgstr "式内"
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr ""
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr ""
@@ -49126,147 +49182,147 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr ""
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "関数の引数が構造体だったら警告する"
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "関数の引数が構造体だったら警告する"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr ""
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, fuzzy, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -49412,168 +49468,168 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "ラベル %s があらゆる関数の外側で参照されました"
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "%s: 読み込み用にファイル `%s' を開くことができません: %s\n"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: ファイル `%s' に書き込み中にエラー: %s\n"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: ファイル `%s' を削除できません: %s\n"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: 警告: ファイル `%s' を `%s' 名前変更できません: %s\n"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: 副 info ファイル `%s' を削除できません: %s\n"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "シンボルの頭にアンダースコアをつける"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: 読み込み用にファイル `%s' を開くことができません: %s\n"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr ""
@@ -49868,7 +49924,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -50564,369 +50620,364 @@
 msgid "Unexpected %s statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2428
-#, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr "`%s' の extern 宣言がネストしています"
-
-#: fortran/parse.c:2439
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr "ファイル \"%s\" に戻るはずでした"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "不明なレジスタ名です: %s"
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "前方での `%s' の宣言"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, fuzzy, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, fuzzy, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In constructor %qs"
 msgid "BLOCK construct at %C"
 msgstr "コンストラクタ %qs 内"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In constructor %qs"
 msgid "ASSOCIATE construct at %C"
 msgstr "コンストラクタ %qs 内"
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr "配列の添字が `char' 型です"
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr ""
@@ -50934,7 +50985,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -51631,7 +51682,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "ラベル %s があらゆる関数の外側で参照されました"
@@ -51686,367 +51737,367 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr ""
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, fuzzy, gcc-internal-format
 #| msgid "error in args to spec function %qs"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "spec 関数 %qs の引数内でエラーが発生しました"
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "呼び出されたオブジェクトは関数ではありません"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_function(): bad function type"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_subroutine(): bad function type"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "shared と mdll とは共存できません"
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "要求されたアラインメントが大きすぎます"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -52055,12 +52106,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -52069,249 +52120,249 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index must be integer"
 msgid "%s at %L must be integer"
 msgstr "添え字は整数でなければいけません"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -52320,189 +52371,189 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 #| msgid "expected numeric type"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "数値型が予期されます"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無効なオプション %s"
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -52509,12 +52560,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -52522,158 +52573,158 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr ""
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr ""
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr ""
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -52680,7 +52731,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -52688,57 +52739,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr ""
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "配列 `%s' の大きさが大きすぎます"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
@@ -52745,426 +52796,426 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -53171,398 +53222,398 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%s に互換性のない型"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -53594,47 +53645,47 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr ""
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr ""
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr ""
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "文字定数の中でファイルの終端を検出しました"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr ""
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
 msgstr ""
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr ""
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr "ファイル \"%s\" から出ましたが入っていません"
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr "プリプロセス命令中に %s があります"
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 msgid "Can't open file %qs"
 msgstr "出力ファイル `%s' を open できません"
@@ -53901,52 +53952,52 @@
 msgid "Reshaped array too large at %C"
 msgstr "配列のサイズが大きすぎます"
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, fuzzy, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr "定数式がオーバーフローしました"
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "関数呼び出しが集合体の値を持っています"
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -54024,313 +54075,318 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
+#, gcc-internal-format, gfc-internal-format
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr ""
+
+#: fortran/symbol.c:489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "`%s' 属性は関数に対してのみ適用されます"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, fuzzy, gcc-internal-format
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute with %s attribute at %L"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, fuzzy, gcc-internal-format
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "フィールド '%s' の ConstantValue 属性が重複しています"
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "section 属性はローカル変数に対しては指定できません"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "フィールド '%s' の ConstantValue 属性が重複しています"
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr ""
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -54591,7 +54647,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -56939,6 +56995,9 @@
 #~ msgid "%qD has no member named %qE"
 #~ msgstr "%s に `%s' という名前のメンバはありません"
 
+#~ msgid "ISO C++ forbids subscripting non-lvalue array"
+#~ msgstr "ISO C++ は左辺値ではない配列の添字を禁じます"
+
 #, fuzzy
 #~ msgid "  since type %qT has pure virtual functions"
 #~ msgstr "使われない仮想関数を切り捨てる"
Index: gcc/po/zh_TW.po
===================================================================
--- gcc/po/zh_TW.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/zh_TW.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.8.0\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2013-06-07 23:29+0800\n"
 "Last-Translator: Wei-Lun Chao <bluebat@member.fsf.org>\n"
 "Language-Team: Chinese (traditional) <zh-l10n@linux.org.tw>\n"
@@ -193,13 +193,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "錯誤地使用了浮點常數"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1418,7 +1418,7 @@
 msgid "options enabled: "
 msgstr "啟用的選項："
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2736,97 +2736,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "無效的運算元程式碼「%c」"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, fuzzy, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "『%%&』使用的而無需任何本地動態 TLS 參考"
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "無效 %%H 值"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "無效 %%J 值"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "無效 %%r 值"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "無效 %%R 值"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "無效 %%N 值"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "無效 %%P 值"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "無效 %%h 值"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "無效 %%L 值"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "無效 %%m 值"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "無效 %%M 值"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "無效 %%U 值"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "無效 %%s 值"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "無效 %%C 值"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "無效 %%E 值"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "不明的不可預期重定位"
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "無效的 %%xn 程式碼"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 msgid "invalid operand address"
 msgstr "無效的 %%d 運算元"
@@ -2878,7 +2878,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "無效的運算元輸出程式碼"
@@ -3038,8 +3038,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3260,62 +3260,62 @@
 msgid "bad output_condmove_single operand"
 msgstr "錯誤的 output_condmove_single 運算元"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "無效的 UNSPEC 做為運算元"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "無效的運算元類型使用的與運算元編碼『%c』"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『D』"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『D』"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "運算元不是 offsettable 記憶體參考，無效的運算元編碼『H』"
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "無效的運算元程式碼「%c」"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "運算元的約束無效"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "不明的指令模式"
 
@@ -3356,7 +3356,7 @@
 msgid "invalid %%P operand"
 msgstr "無效的 %%P 運算元"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "無效的 %%p 值"
@@ -3423,7 +3423,7 @@
 msgstr "後自增位址不是一個暫存器"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "錯誤位址"
 
@@ -3595,103 +3595,103 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "產生低位位元組在前的程式碼"
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 #, fuzzy
 msgid "bad move"
 msgstr "不當的移動"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "無效 %%f 值"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "無效 %%F 值"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "無效 %%G 值"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "無效 %%j 程式碼"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "無效 %%J 程式碼"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "無效 %%k 值"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "無效 %%K 值"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "無效 %%O 值"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "無效 %%q 值"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "無效 %%S 值"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "無效 %%T 值"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "無效 %%u 值"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "無效 %%v 值"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "無效的 %%x 值"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無效的 %%y 值，嘗試使用『Z』條件約束"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "不為每個函式產生單一的離開點"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load offset for fusion"
@@ -3787,60 +3787,60 @@
 msgid "invalid operand to %%S"
 msgstr "%%S 的運算元無效"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr "建立和使用時使用了不同的架構/ABI"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr "建立和使用時使用了不同的 ABI"
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr "建立和使用時使用了不同的高/低位位元組在前設定"
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "無效的 %%Y 運算元"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "無效的 %%A 運算元"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "無效的 %%B 運算元"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, c-format
 msgid "invalid %%C operand"
 msgstr "無效的 %%C 運算元"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, c-format
 msgid "invalid %%D operand"
 msgstr "無效的 %%D 運算元"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "無效的 %%f 運算元"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "無效的 %%s 運算元"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "long long 常數不是一個有效的立即數值運算元"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "浮點常數不是一個有效的立即數值運算元"
@@ -4050,7 +4050,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要 %<;%>"
@@ -4066,15 +4066,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "預期 %<(%>"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "預期 %<,%>"
@@ -4096,8 +4096,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "預期 %<)%>"
@@ -4104,8 +4104,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "預期 %<]%>"
@@ -4115,13 +4115,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "預期 %<}%>"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要 %<{%>"
@@ -4128,8 +4128,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "預期 %<:%>"
@@ -4152,7 +4152,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "預期 %<while%>"
@@ -4170,34 +4170,34 @@
 msgid "expected %<.%>"
 msgstr "預期 %<.%>"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "預期 %<@end%>"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "預期 %<>%>"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "預期 %<,%>或 %<)%>"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要 %<=%>"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "預期 %<[%>"
@@ -4207,11 +4207,11 @@
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "備選 1："
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "備選 2："
 
@@ -4459,11 +4459,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%s:%d：  在中 constexpr 擴展的 %qs"
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "備選為："
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -4519,52 +4519,52 @@
 msgid "source type is not polymorphic"
 msgstr "來源型態不是 polymorphic"
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "單位元減的運算元類型錯誤"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "單位元加的運算元類型錯誤"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "按位取反的引數類型錯誤"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "不能對該類型的引數求絕對值"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "不能對該類型的引數求共軛"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "在中引數到一元！"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "沒有 pre-increment 運算子用於型態"
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 #, fuzzy
 msgid "no post-increment operator for type"
 msgstr "沒有 post-increment 運算子用於型態"
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "沒有 pre-decrement 運算子用於型態"
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 #, fuzzy
 msgid "no post-decrement operator for type"
 msgstr "沒有 post-decrement 運算子用於型態"
@@ -4664,7 +4664,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "%C 處運算式中整數值太大"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 #, fuzzy
 msgid "array assignment"
 msgstr "陣列指派"
@@ -4688,7 +4688,7 @@
 msgid "Driving:"
 msgstr "驅動："
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 #, fuzzy
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "實際引數到含義=出/INOUT"
@@ -4763,7 +4763,7 @@
 msgid "%s tag"
 msgstr "%s 標籤"
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 #, fuzzy
 msgid "internal unit in WRITE"
 msgstr "內部單位在中寫入"
@@ -4770,7 +4770,7 @@
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, fuzzy, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s 標籤與查詢"
@@ -4848,7 +4848,7 @@
 msgid "Bad type in constant expression"
 msgstr "常數運算式中類型錯誤"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 msgid "Unexpected end of module"
 msgstr "非預期的模組結束"
 
@@ -4876,11 +4876,11 @@
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr "賦值"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 msgid "pointer assignment"
 msgstr "指標賦值"
 
@@ -4898,219 +4898,219 @@
 msgid "internal function"
 msgstr "內部函式"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 #, fuzzy
 msgid "elemental procedure"
 msgstr "elemental 程序"
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 #| msgid "no arguments"
 msgid "allocatable argument"
 msgstr "沒有參數"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "不足引數"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 msgid "optional argument"
 msgstr "無效的 PHI 引數"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "指標賦值"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 msgid "target argument"
 msgstr "太多引數"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 msgid "value argument"
 msgstr "無效的 PHI 引數"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "沒有參數"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "不匹配的引數"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 msgid "assumed-rank argument"
 msgstr "不匹配的引數"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 msgid "coarray argument"
 msgstr "陣列指派"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "沒有參數"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "不匹配的引數"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 #, fuzzy
 msgid "pointer or allocatable result"
 msgstr "Coindexed allocatable 物件於 %L"
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 #, fuzzy
 msgid "result with non-constant character length"
 msgstr "共同變數『%s』於 %L 必須有常數字元長度"
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 #, fuzzy
 msgid "bind(c) procedure"
 msgstr "模組程序"
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, fuzzy, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "無效的語境用於空值() 指標於 %%L"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr "單位元數值運算子「%s」(位於 %%L)的運算元為 %s"
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr "二元數值運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "字串粘貼運算子(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr "邏輯運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, fuzzy, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "運算元的.not。運算子於 %%L 是 %s"
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L 處複數不能比較大小"
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L 處邏輯值必須與 %s 比較，而不是 %s"
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr "比較運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, fuzzy, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr "不明運算子『%s』於 %%L"
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr "使用者運算子「%s」(位於 %%L)的運算元為 %s"
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr "使用者運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, fuzzy, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "不一致分級用於運算子於 %%L 和 %%L"
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 #, fuzzy
 msgid "Loop variable"
 msgstr "迴圈變數"
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 #, fuzzy
 msgid "iterator variable"
 msgstr "迭代器變數"
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 #, fuzzy
 msgid "Start expression in DO loop"
 msgstr "開始運算式在中做迴圈"
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "結束運算式在中做迴圈"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "步驟運算式在中做迴圈"
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "取消配置物件"
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "配置物件"
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 #, fuzzy
 msgid "STAT variable"
 msgstr "STAT 變數"
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "ERRMSG 變數"
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 #, fuzzy
 msgid "item in READ"
 msgstr "項目在中讀取"
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK 變數"
@@ -5544,18 +5544,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr "rx200 cpu 沒有 FPU 硬體"
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-#, fuzzy
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr "認為使用『-pg』以代替『-p』與 gprof (1)"
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-#, fuzzy
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr "認為使用『-pg』以代替『-p』與 gprof (1)"
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr "不支援 multilib"
@@ -5568,6 +5556,11 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "-Xbind-now 與 -Xbind-lazy 不相容"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+#, fuzzy
+msgid "profiling not supported with -mg"
+msgstr "側寫檔不支援與 -mg"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "不支援 -mhard-float"
@@ -5576,10 +5569,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "不能同時指定 -msingle-float 和 -msoft-float"
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr "m210 不支援低位位元組在前"
-
 #: config/cris/cris.h:184
 #, fuzzy
 msgid "do not specify both -march=... and -mcpu=..."
@@ -5613,6 +5602,13 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+#, fuzzy
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr "認為使用『-pg』以代替『-p』與 gprof (1)"
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5619,6 +5615,11 @@
 msgid "may not use both -m32 and -m64"
 msgstr "不能同時使用 -m32 和 -m64"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+#, fuzzy
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr "認為使用『-pg』以代替『-p』與 gprof (1)"
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr "TPF-OS 不支援 static"
@@ -5632,6 +5633,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian 和 -mlittle-endian 不能一起使用"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr "m210 不支援低位位元組在前"
+
 #: config/avr/specs.h:68
 #, fuzzy
 msgid "shared is not supported"
@@ -5662,18 +5667,20 @@
 msgid "no processor type specified for linking"
 msgstr "沒有處理器型態指定的用於鏈結"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 #, fuzzy
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr "警告：認為鏈結與『-static』做為系統函式庫與"
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 #, fuzzy
 msgid "  profiling support are only provided in archive format"
 msgstr "  側寫檔支援是只有提供的在中封存格式"
@@ -5710,11 +5717,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "-shared 選項目前在 VAX ELF 下不受支援"
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-#, fuzzy
-msgid "profiling not supported with -mg"
-msgstr "側寫檔不支援與 -mg"
-
 #: fortran/lang.opt:146
 #, fuzzy
 msgid "-J<directory>\tPut MODULE files in 'directory'"
@@ -5924,9 +5926,9 @@
 msgstr "允許在實體名中使用美元符號"
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 #, fuzzy
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "沒做任何事。保留的用於回溯相容性。"
@@ -6170,10 +6172,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 #, fuzzy
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "沒做任何事。 保留的用於回溯相容性。"
@@ -6224,7 +6226,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr "%qs 後缺少檔案名稱"
@@ -8272,48 +8274,52 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr "假定目的 CPU 被配置為低位位元組在前"
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 #, fuzzy
 msgid "Specify the code model"
 msgstr "選取編碼式樣"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr "為葉函式(不呼叫其它函式的函式)忽略框架指標"
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 #, fuzzy
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr "-mcpu=CPU\t使用特徵的和排程編碼用於給定的 CPU"
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 #, fuzzy
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr "-mcpu=CPU\t使用特徵的和排程編碼用於給定的 CPU"
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 #, fuzzy
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr "-mabi=ABI\t產生編碼該符合到給定的 ABI"
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 #, fuzzy
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr "已知手臂 ABIs (用於使用與 -mabi=選項)："
@@ -9542,10 +9548,16 @@
 
 #: config/i386/i386.opt:864
 #, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "支援 MMX 和 SSE 內建函式及程式碼產生"
+
+#: config/i386/i386.opt:868
+#, fuzzy
 msgid "Use given stack-protector guard"
 msgstr "使用 propolice 做為堆疊保護方法"
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 #, fuzzy
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr "已知手臂架構 (用於使用與 -march=選項)："
@@ -9929,7 +9941,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -10084,7 +10096,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr "設定分支成本用於條件分支指令。 Reasonable"
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
@@ -10228,7 +10240,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr "允許調度函式前言序列"
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr "不在函式前言中載入 PIC 暫存器"
 
@@ -10586,353 +10598,352 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "使用向量/純量 (VSX) 指令"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 #, fuzzy
 msgid "Do not generate load/store with update instructions"
 msgstr "不產生載入/儲存與更新指令"
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 #, fuzzy
 msgid "Generate load/store with update instructions"
 msgstr "產生載入/儲存與更新指令"
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 #, fuzzy
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr "避免產生的索引的載入/儲存指令時可能的"
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 #, fuzzy
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "標記 __tls_get_addr 呼叫與引數資訊"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr "調度程序的起始與終止"
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr "所有結構在記憶體中回傳 (AIX 預設)"
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr "小結構在暫存器中回傳 (SVR4 預設)"
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr "盡量接近 IBM XLC 語義"
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 #, fuzzy
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr "產生軟體倒數除和平方根用於較好流量。"
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 #, fuzzy
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr "假設該倒數估計指令提供更多準確度。"
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr "不在 TOC 中存放浮點常數"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr "在 TOC 中存放浮點常數"
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "不在 TOC 中存放符號+偏移量常數"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr "在 TOC 中存放符號+偏移量常數"
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr "為每個程序只使用一個 TOC 條目"
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 #, fuzzy
 msgid "Put everything in the regular TOC"
 msgstr "置放所有東西在中標準光碟內容表"
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr "產生 AltiVec 程式碼時產生 VRSAVE 指令"
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 #, fuzzy
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr "不宜用選項。 使用 -mno-vrsave 做為替代"
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 #, fuzzy
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr "不宜用選項。 使用 -mvrsave 做為替代"
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 #, fuzzy
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr "指定有多少位元組應該被移動內聯之前呼叫出到 memcpy/memmove"
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 msgid "Generate isel instructions"
 msgstr "產生 isel 指令"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 #, fuzzy
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr "不宜用選項。 使用 -mno-isel 做為替代"
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 #, fuzzy
 msgid "Deprecated option.  Use -misel instead"
 msgstr "不宜用選項。 使用 -misel 做為替代"
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr "在 E500 上產生 SPE SIMD 指令"
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 #, fuzzy
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "產生 PPC750 CL paired-single 指令"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 #, fuzzy
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr "不宜用選項。 使用 -mno-spe 做為替代"
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 #, fuzzy
 msgid "Deprecated option.  Use -mspe instead"
 msgstr "不宜用選項。 使用 -mspe 做為替代"
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 #, fuzzy
 msgid "-mdebug=\tEnable debug output"
 msgstr "-mdebug=\t啟用除錯輸出"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 #, fuzzy
 msgid "Use the AltiVec ABI extensions"
 msgstr "使用 AltiVec ABI 延伸"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 #, fuzzy
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "不使用 AltiVec ABI 延伸"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 #, fuzzy
 msgid "Use the SPE ABI extensions"
 msgstr "使用 SPE ABI 延伸"
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 #, fuzzy
 msgid "Do not use the SPE ABI extensions"
 msgstr "不使用 SPE ABI 延伸"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv1 ABI"
 msgstr "使用 EABI"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv2 ABI"
 msgstr "使用 EABI"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 #, fuzzy
 msgid "using darwin64 ABI"
 msgstr "使用 darwin64 ABI"
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 #, fuzzy
 msgid "using old darwin ABI"
 msgstr "使用舊的 darwin ABI"
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 #, fuzzy
 msgid "using IEEE extended precision long double"
 msgstr "使用我進階精確度長雙倍"
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 #, fuzzy
 msgid "using IBM extended precision long double"
 msgstr "使用 IBM 進階精確度長雙倍"
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 #, fuzzy
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr "-mcpu=\t使用特徵的和排程編碼用於給定的 CPU"
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 #, fuzzy
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "-mtune=\t排程編碼用於給定的 CPU"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 #, fuzzy
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr "-mtraceback=\t選取全部、部分，或沒有追溯表格"
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 #, fuzzy
 msgid "Avoid all range limits on call instructions"
 msgstr "避免所有範圍限度於呼叫指令"
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 #, fuzzy
 msgid "Generate Cell microcode"
 msgstr "產生儲存格 microcode"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 #, fuzzy
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "警告時儲存格 microcoded 指令被發出"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr "使用過時的「vector long ...」AltiVec 類型時給出警告"
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 #, fuzzy
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr "-mfloat-gprs=\t選取 GPR 浮點數方法"
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 #, fuzzy
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "有效引數到 -mfloat-gprs=："
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 #, fuzzy
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr "-mlong-double-<n>\t指定大小的長雙倍 (64 或 128 位元)"
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 #, fuzzy
 msgid "Determine which dependences between insns are considered costly"
 msgstr "決定該項 dependences 介於 insns 被認為成本"
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 #, fuzzy
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr "指定該項貼文排程 nop 插入 scheme 到套用"
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 #, fuzzy
 msgid "Specify alignment of structure fields default/natural"
 msgstr "指定對齊的結構欄位預設/自然"
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 #, fuzzy
 msgid "Valid arguments to -malign-:"
 msgstr "有效引數到 -malign-："
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 #, fuzzy
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr "指定排程優先權用於派送插槽限制的 insns"
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 #, fuzzy
 msgid "Single-precision floating point unit"
 msgstr "單精度浮點數單位"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 #, fuzzy
 msgid "Double-precision floating point unit"
 msgstr "倍精度浮點數單位"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 #, fuzzy
 msgid "Floating point unit does not support divide & sqrt"
 msgstr "浮點數單位不支援除 & sqrt"
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 #, fuzzy
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr "-mfpu=\t指定 FP (sp、dp，sp-lite，dp-lite) (意味著 -mxilinx-fpu)"
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 #, fuzzy
 msgid "Specify Xilinx FPU."
 msgstr "指定 Xilinx FPU。"
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 #, fuzzy
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr "使用/不使用 r11 以存放靜態連結在中呼叫到函式透過指標。"
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 #, fuzzy
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr "控制是否我們儲存光碟內容表在中 prologue 用於間接呼叫或產生儲存內聯"
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 #, fuzzy
 #| msgid "Align destination of the string operations"
 msgid "Allow sign extension in fusion operations"
 msgstr "對齊字串作業的目的"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
-#, fuzzy
-msgid "Use ISA 2.07 crypto instructions"
-msgstr "使用 SmartMIPS 指令"
+#: config/rs6000/rs6000.opt:566
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr ""
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 #, fuzzy
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr "使用向量/純量 (VSX) 指令"
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "產生載入/儲存多重指令"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -14162,1750 +14173,1750 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr "-dumpdir <dir>\t設定目錄名稱為用於傾印"
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "對齊函式入口"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr "對齊只能為跳轉所到達的標籤"
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr "對齊所有的標籤"
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "對齊循環入口"
 
-#: common.opt:894
+#: common.opt:897
 #, fuzzy
 msgid "Select what to sanitize"
 msgstr "選取執行階段"
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr "此開關已過時；請改用 -Wextra"
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr "產生精確到每條指令邊界的堆疊展開表"
 
-#: common.opt:918
+#: common.opt:921
 #, fuzzy
 msgid "Generate auto-inc/dec instructions"
 msgstr "產生 auto-inc/十二月指令"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr "為分支概率使用取樣資訊"
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "產生檢查陣列存取是否越界的程式碼"
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr "將加/減法、比較、跳轉指令序列替換為根據計數暫存器跳轉指令"
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr "為分支概率使用取樣資訊"
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr "在開始/結末執行緒前進行分支目的載入最佳化"
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr "在開始/結末執行緒後進行分支目的載入最佳化"
 
-#: common.opt:956
+#: common.opt:959
 #, fuzzy
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr "限制目標載入遷移無法到重新使用暫存器在中任何基本區塊"
 
-#: common.opt:960
+#: common.opt:963
 #, fuzzy
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr "-fcall-saved-<register>\t標記<暫存器>做為被保留跨越函式"
 
-#: common.opt:964
+#: common.opt:967
 #, fuzzy
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr "-fcall-used-<register>\t標記<暫存器>做為被已損壞由函式呼叫"
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr "函式呼叫前後儲存/恢復暫存器值"
 
-#: common.opt:975
+#: common.opt:978
 #, fuzzy
 msgid "Compare the results of several data dependence analyzers."
 msgstr "比較結果的多個資料 dependence 分析器。"
 
-#: common.opt:979
+#: common.opt:982
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++"
 msgstr "檢查 new 的回傳值"
 
-#: common.opt:983
+#: common.opt:986
 #, fuzzy
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "找尋機會到縮小堆疊調整和堆疊參考。"
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr "不將未初始化的全域資料放在公共區段中"
 
-#: common.opt:995
+#: common.opt:998
 #, fuzzy
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr "-fcompare-debug [=<opts>]\t編譯與和而無需例如： -gtoggle，而比較 final-insns 傾印"
 
-#: common.opt:999
+#: common.opt:1002
 #, fuzzy
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr "運行只有第二編譯的 -fcompare-debug"
 
-#: common.opt:1003
+#: common.opt:1006
 #, fuzzy
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr "施行比較 elimination 之後暫存器配額已完成"
 
-#: common.opt:1007
+#: common.opt:1010
 #, fuzzy
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr "不施行最佳化增加 noticeably 堆疊用法"
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr "進行一趟暫存器副本傳遞最佳化"
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr "進行跨跳轉最佳化"
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr "進行 CSE 時，跟隨跳轉至目的"
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr "當進行複數除法時省略縮減範圍的步驟"
 
-#: common.opt:1031
+#: common.opt:1034
 #, fuzzy
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr "複雜乘法和除法追隨 Fortran 規則"
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr "將每個資料項分別放在它們各自的區段中"
 
-#: common.opt:1039
+#: common.opt:1042
 #, fuzzy
 msgid "List all available debugging counters with their limits and counts."
 msgstr "列出所有可用偵錯計數器與它們的限度和計數。"
 
-#: common.opt:1043
+#: common.opt:1046
 #, fuzzy
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr "-fdbg-cnt=<counter>:<限制>[,<計數器>:<限制>,...]\t設定除錯計數器限制。  "
 
-#: common.opt:1047
+#: common.opt:1050
 #, fuzzy
 msgid "Map one directory name to another in debug information"
 msgstr "映射一個目錄名稱到另外的在中除錯資訊"
 
-#: common.opt:1051
+#: common.opt:1054
 #, fuzzy
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "輸出.debugtypes 區段時使用 DWARF v4 debuginfo(_T)。"
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr "延遲將函式引數彈堆疊"
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr "試圖利用延遲轉移指令後"
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr "刪除無用的空指標檢查"
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 #, fuzzy
 msgid "Perform speculative devirtualization"
 msgstr "施行超區塊格式透過尾端複印法"
 
-#: common.opt:1081
+#: common.opt:1084
 #, fuzzy
 msgid "Try to convert virtual calls to direct ones."
 msgstr "試著轉換虛擬呼叫到直接的一個。"
 
-#: common.opt:1085
+#: common.opt:1088
 #, fuzzy
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr "-fdiagnostics-show-location=[一旦|every-line]\t多久會到 emit 來源位置於起始部分的 line-wrapped 診斷"
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 #, fuzzy
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr "修正適當診斷訊息與命令列選項該控制項它們"
 
-#: common.opt:1134
+#: common.opt:1137
 #, fuzzy
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr "-fdisable-[ 樹|rtl|ipa ]-<pass>=range1+range2 停用最佳化回合"
 
-#: common.opt:1138
+#: common.opt:1141
 #, fuzzy
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr "-fenable-[ 樹|rtl|ipa ]-<pass>=range1+range2 啟用最佳化回合"
 
-#: common.opt:1142
+#: common.opt:1145
 #, fuzzy
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr "-fdump-<type>\t傾印各種編譯器內部到檔案"
 
-#: common.opt:1149
+#: common.opt:1152
 #, fuzzy
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr "-fdump-final-insns=檔名\t傾印到檔名 insns 於結束的翻譯"
 
-#: common.opt:1153
+#: common.opt:1156
 #, fuzzy
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr "-fdump-go-spec=檔名\t寫入所有宣告到檔案做為前往編碼"
 
-#: common.opt:1157
+#: common.opt:1160
 #, fuzzy
 msgid "Suppress output of addresses in debugging dumps"
 msgstr "不列印輸出的位址在中偵錯傾印"
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 #, fuzzy
 msgid "Dump optimization passes"
 msgstr "傾印最佳化次數"
 
-#: common.opt:1170
+#: common.opt:1173
 #, fuzzy
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr "不列印輸出的指令數量，列號記事和位址在中偵錯傾印"
 
-#: common.opt:1174
+#: common.opt:1177
 #, fuzzy
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr "不列印輸出的前一個和下一個 insn 數量在中偵錯傾印"
 
-#: common.opt:1178
+#: common.opt:1181
 #, fuzzy
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "啟用 CFI 表格透過氣體組譯器指令。"
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr "進行早內聯"
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr "進行 DWARF2 冗餘消除"
 
-#: common.opt:1190
+#: common.opt:1193
 #, fuzzy
 msgid "Perform interprocedural reduction of aggregates"
 msgstr "施行 interprocedural 消除的彙總"
 
-#: common.opt:1194
+#: common.opt:1197
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info"
 msgstr "在除錯資訊中進行無用類型消除"
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr "在除錯資訊中進行無用類型消除"
 
-#: common.opt:1202
+#: common.opt:1205
 #, fuzzy
 msgid "Do not suppress C++ class debug information."
 msgstr "不抑制 C++類別除錯資訊。"
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "啟用異常處理"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr "進行一些細微的、代價高昂的最佳化"
 
-#: common.opt:1214
+#: common.opt:1217
 #, fuzzy
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr "-fexcess-precision=[快速|標準]\t指定處理的過剩浮點精確度"
 
-#: common.opt:1217
+#: common.opt:1220
 #, fuzzy, c-format
 msgid "unknown excess precision style %qs"
 msgstr "不明過剩精確度樣式 %qs"
 
-#: common.opt:1230
+#: common.opt:1233
 #, fuzzy
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "輸出 lto 物件包含兩者中介語言和二進位輸出。"
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr "假定結果不會是 NaN 或無限大浮點數"
 
-#: common.opt:1238
+#: common.opt:1241
 #, fuzzy
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr "-ffixed-<register>\t標記<暫存器>做為是不得使用到編譯器"
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr "不將單精度和雙精度浮點數指派到擴充精度的暫存器中"
 
-#: common.opt:1250
+#: common.opt:1253
 #, fuzzy
 msgid "Perform a forward propagation pass on RTL"
 msgstr "施行轉寄傳播傳送 RTL"
 
-#: common.opt:1254
+#: common.opt:1257
 #, fuzzy
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr "-ffp-contract=[關閉|於|快速] 施行浮點運算式合約。"
 
-#: common.opt:1257
+#: common.opt:1260
 #, fuzzy, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "不明浮點數合約樣式 %qs"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr "允許將函式位址儲存在暫存器中"
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr "將每個函式分別放在它們各自的區段中"
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr "進行全域公因式消去"
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr "在全域公因式消去中進行增強的讀轉移最佳化"
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr "在全域公因式消去後進行存儲轉移"
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr "在全域公因式消去中進行冗餘的寫後讀消除"
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr "在指派暫存器後進行全域公因式消去"
 
-#: common.opt:1305
+#: common.opt:1308
 #, fuzzy
 msgid "Enable in and out of Graphite representation"
 msgstr "啟用在中和超出石墨表示"
 
-#: common.opt:1309
+#: common.opt:1312
 #, fuzzy
 msgid "Enable Graphite Identity transformation"
 msgstr "啟用石墨身分變換"
 
-#: common.opt:1313
+#: common.opt:1316
 #, fuzzy
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr "啟用 hoisting 載入從條件指標。"
 
-#: common.opt:1318
+#: common.opt:1321
 #, fuzzy
 msgid "Mark all loops as parallel"
 msgstr "標記所有迴圈做為平行"
 
-#: common.opt:1322
+#: common.opt:1325
 #, fuzzy
 msgid "Enable Loop Strip Mining transformation"
 msgstr "啟用迴圈截除最小變換"
 
-#: common.opt:1326
+#: common.opt:1329
 #, fuzzy
 msgid "Enable Loop Interchange transformation"
 msgstr "啟用迴圈交換變換"
 
-#: common.opt:1330
+#: common.opt:1333
 #, fuzzy
 msgid "Enable Loop Blocking transformation"
 msgstr "啟用迴圈阻塞變換"
 
-#: common.opt:1334
+#: common.opt:1337
 #, fuzzy
 msgid "Enable Loop Unroll Jam transformation"
 msgstr "啟用迴圈交換變換"
 
-#: common.opt:1338
+#: common.opt:1341
 #, fuzzy
 msgid "Enable support for GNU transactional memory"
 msgstr "啟用支援用於 GNU transactional 記憶體"
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 #, fuzzy
 msgid "Force bitfield accesses to match their type width"
 msgstr "強制 bitfield 存取到匹配它們的型態寬度"
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr "啟用分支概率猜測"
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr "處理 #ident 指令"
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr "將條件跳轉替換為沒有跳轉的等值表示"
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr "將條件跳轉替換為條件執行"
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, fuzzy, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:1394
+#: common.opt:1397
 #, fuzzy
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr "轉換條件式跳位在中 innermost 迴圈到 branchless equivalents"
 
-#: common.opt:1398
+#: common.opt:1401
 #, fuzzy
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr "也 if-convert 條件式跳位包含記憶體寫入"
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr "不產生 .size 指令"
 
-#: common.opt:1410
+#: common.opt:1413
 #, fuzzy
 msgid "Perform indirect inlining"
 msgstr "施行間接內聯"
 
-#: common.opt:1416
+#: common.opt:1419
 #, fuzzy
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr "啟用內聯的函式宣告「內聯」，停用全部停用內聯"
 
-#: common.opt:1420
+#: common.opt:1423
 #, fuzzy
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "整合函式進入它們的呼叫者時編碼大小是已知無法到 grow"
 
-#: common.opt:1424
+#: common.opt:1427
 #, fuzzy
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "整合函式無法宣告「內聯」進入它們的呼叫者時 profitable"
 
-#: common.opt:1428
+#: common.opt:1431
 #, fuzzy
 msgid "Integrate functions only required by their single caller"
 msgstr "整合函式只有必要項由它們的單一呼叫者"
 
-#: common.opt:1435
+#: common.opt:1438
 #, fuzzy
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr "-finline-limit=<number>\t限制大小的內聯的函式到<數字>"
 
-#: common.opt:1439
+#: common.opt:1442
 #, fuzzy
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "內聯 __atomic 計算時鎖定自由指令序列是可用。"
 
-#: common.opt:1443
+#: common.opt:1446
 #, fuzzy
 msgid "Instrument function entry and exit with profiling calls"
 msgstr "器具函式條目然後離開與側寫檔呼叫"
 
-#: common.opt:1447
+#: common.opt:1450
 #, fuzzy
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr "-finstrument-functions-exclude-function-list=名稱 ,... 不器具清單的函式"
 
-#: common.opt:1451
+#: common.opt:1454
 #, fuzzy
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr "-finstrument-functions-exclude-file-list=檔名 ,... 不器具函式清單的在中檔案"
 
-#: common.opt:1455
+#: common.opt:1458
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation"
 msgstr "進行處理序間的複寫傳遞"
 
-#: common.opt:1459
+#: common.opt:1462
 #, fuzzy
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr "施行仿本要讓 Interprocedural 常數傳用 stronger"
 
-#: common.opt:1463
+#: common.opt:1466
 #, fuzzy
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr "施行仿本要讓 Interprocedural 常數傳用 stronger"
 
-#: common.opt:1467
+#: common.opt:1470
 #, fuzzy
 msgid "Perform interprocedural profile propagation"
 msgstr "施行 interprocedural 側寫檔傳播"
 
-#: common.opt:1471
+#: common.opt:1474
 #, fuzzy
 msgid "Perform interprocedural points-to analysis"
 msgstr "施行 interprocedural points-to 分析"
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr "發現純函式和常函式"
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables"
 msgstr "展開所有循環"
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr "發現唯讀和不可定址靜態變數"
 
-#: common.opt:1503
+#: common.opt:1506
 #, fuzzy
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr "-fira-algorithm=[CB|優先權] 設定使用的 IRA 演算法"
 
-#: common.opt:1506
+#: common.opt:1509
 #, fuzzy, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "不明 IRA 演算法 %qs"
 
-#: common.opt:1516
+#: common.opt:1519
 #, fuzzy
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr "-fira-region=[一個|所有|混合] 設定區域用於 IRA"
 
-#: common.opt:1519
+#: common.opt:1522
 #, fuzzy, c-format
 msgid "unknown IRA region %qs"
 msgstr "不明 IRA 區域 %qs"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 #, fuzzy
 msgid "Use IRA based register pressure calculation"
 msgstr "使用 IRA 基底的暫存器壓力 calculation"
 
-#: common.opt:1542
+#: common.opt:1545
 #, fuzzy
 msgid "Share slots for saving different hard registers."
 msgstr "共享插槽用於儲存不同的硬暫存器。"
 
-#: common.opt:1546
+#: common.opt:1549
 #, fuzzy
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "共享堆疊插槽用於 spilled pseudo-registers。"
 
-#: common.opt:1550
+#: common.opt:1553
 #, fuzzy
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<number>\t控制 IRA's 等級的診斷訊息。"
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr "在樹上最佳化歸納變數"
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "為足夠大的 switch 敘述使用跳轉表"
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr "為完全內聯的函式產生程式碼"
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr "保留未用到的靜態常數"
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr "給外部符號加入起始的底線"
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 #, fuzzy
 msgid "Enable link-time optimization."
 msgstr "啟用 link-time 最佳化。"
 
-#: common.opt:1586
+#: common.opt:1589
 #, fuzzy
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Link-time 最佳化與平行工作編號的或 jobserver。"
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 #, fuzzy
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr "-flto-compression-level=<number>\t使用 zlib 壓縮等級<數字>用於 IL"
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 #, fuzzy
 msgid "Report various link-time optimization statistics"
 msgstr "報告各種 link-time 最佳化統計"
 
-#: common.opt:1625
+#: common.opt:1628
 #, fuzzy
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr "報告各種 link-time 最佳化統計"
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr "執行內建數學函式後設定 errno"
 
-#: common.opt:1633
+#: common.opt:1636
 #, fuzzy
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr "-fmax-errors=<number>\t最大值錯誤代號的到報告"
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr "報告永久性記憶體指派"
 
-#: common.opt:1641
+#: common.opt:1644
 #, fuzzy
 msgid "Report on permanent memory allocation in WPA only"
 msgstr "報告永久性記憶體指派"
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr "試圖合併相同的常數和常變數"
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr "試圖合併不同編譯單元中的相同常數"
 
-#: common.opt:1656
+#: common.opt:1659
 #, fuzzy
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr "試圖到合併相等的除錯字串跨越編譯單元"
 
-#: common.opt:1660
+#: common.opt:1663
 #, fuzzy
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr "-fmessage-length=<number>\t限制診斷到<數字>字元各列。 0 抑制換列"
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr "在首趟調度前進行基於 SMS 的模調度"
 
-#: common.opt:1668
+#: common.opt:1671
 #, fuzzy
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr "施行 SMS 基底的 modulo 排程與暫存器移動允許"
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr "將每次循環中不變的計算外提"
 
-#: common.opt:1676
+#: common.opt:1679
 #, fuzzy
 msgid "Use the RTL dead code elimination pass"
 msgstr "使用 RTL 無作用程式碼 elimination 回合"
 
-#: common.opt:1680
+#: common.opt:1683
 #, fuzzy
 msgid "Use the RTL dead store elimination pass"
 msgstr "使用 RTL 無作用儲存體 elimination 回合"
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr "啟用/停用已經透過模調度的循環中的傳統調度"
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr "支援同步非呼叫異常"
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "%qs 後判定語"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 msgid "unknown offload ABI %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr "盡可能不產生堆疊框架"
 
-#: common.opt:1713
+#: common.opt:1716
 #, fuzzy
 msgid "Enable all optimization info dumps on stderr"
 msgstr "在樹層級進行循環最佳化"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr "最佳化同級遞迴和尾遞迴"
 
-#: common.opt:1729
+#: common.opt:1732
 #, fuzzy
 msgid "Perform partial inlining"
 msgstr "施行部分內聯"
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 #, fuzzy
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr "報告於記憶體配置之前 interprocedural 最佳化"
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr "將結構成員不帶間隔地緊實存放"
 
-#: common.opt:1745
+#: common.opt:1748
 #, fuzzy
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr "-fpack-struct=<number>\t設定初始最大值結構成員對齊"
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr "在記憶體而不是暫存器中回傳小聚合"
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr "進行循環剝離"
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr "啟用機器相關的窺孔最佳化"
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr "在 sched2 前進行一趟 RTL 窺孔最佳化"
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr "盡可能產生與位置無關的程式碼(大模式)"
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr "為可執行檔案盡可能產生與位置無關的程式碼(大模式)"
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr "盡可能產生與位置無關的程式碼(小模式)"
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr "為可執行檔案盡可能產生與位置無關的程式碼(小模式)"
 
-#: common.opt:1781
+#: common.opt:1784
 #, fuzzy
 msgid "Specify a plugin to load"
 msgstr "指定外掛程式到載入"
 
-#: common.opt:1785
+#: common.opt:1788
 #, fuzzy
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr "-fplugin-arg-<name>-< 鍵>[=<值>]\t指定引數<鍵>=<值>用於外掛程式<名稱>"
 
-#: common.opt:1789
+#: common.opt:1792
 #, fuzzy
 msgid "Run predictive commoning optimization."
 msgstr "運行 predictive 共同最佳化。"
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr "如果可用，為循環中的陣列產生預取指令"
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr "啟用基本程式取樣程式碼"
 
-#: common.opt:1801
+#: common.opt:1804
 #, fuzzy
 msgid "Insert arc-based program profiling code"
 msgstr "插入 arc-based 程式側寫檔編碼"
 
-#: common.opt:1805
+#: common.opt:1808
 #, fuzzy
 msgid "Set the top-level directory for storing the profile data."
 msgstr "設定最上層目錄用於存入側寫檔資料。"
 
-#: common.opt:1810
+#: common.opt:1813
 #, fuzzy
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr "啟用校正的流程不一致側寫檔資料輸入"
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr "啟用一些公共選項來產生樣本檔案，以便進行基於取樣的最佳化"
 
-#: common.opt:1818
+#: common.opt:1821
 #, fuzzy
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "啟用共同選項用於產生側寫檔資訊用於側寫檔反饋導最佳化，而設定 -fprofile-dir="
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr "啟用一些公共選項以進行基於取樣的最佳化"
 
-#: common.opt:1826
+#: common.opt:1829
 #, fuzzy
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "啟用共同選項用於履行側寫檔反饋導最佳化，而設定 -fprofile-dir="
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr "為取樣運算式的值插入相關程式碼"
 
-#: common.opt:1834
+#: common.opt:1837
 #, fuzzy
 msgid "Report on consistency of profile"
 msgstr "內部一致性錯誤"
 
-#: common.opt:1838
+#: common.opt:1841
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement"
 msgstr "函式重新排序以改善程式碼版面設置"
 
-#: common.opt:1845
+#: common.opt:1848
 #, fuzzy
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr "-frandom-seed=<string>\t製作編譯可再生使用<字串>"
 
-#: common.opt:1855
+#: common.opt:1858
 #, fuzzy
 msgid "Record gcc command line switches in the object file."
 msgstr "記錄 gcc 命令列切換在中目的檔案。"
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr "在暫存器中回傳小聚合"
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 #, fuzzy
 msgid "Relief of register pressure through live range shrinkage"
 msgstr "啟用暫存器壓力敏感的 insn 排程"
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr "進行暫存器重新命名最佳化"
 
-#: common.opt:1880
+#: common.opt:1883
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr "進行暫存器重新命名最佳化"
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr "基本區塊重新排序以改善程式碼版面設置"
 
-#: common.opt:1888
+#: common.opt:1891
 #, fuzzy
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr "重新排序基本區塊和分割進入熱門和 cold 區段"
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr "函式重新排序以改善程式碼版面設置"
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr "在循環最佳化結束後增加一趟公因式消去"
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr "停用假定預設浮點捨入行為的最佳化"
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr "啟用基本區塊間的調度"
 
-#: common.opt:1912
+#: common.opt:1915
 #, fuzzy
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr "啟用暫存器壓力敏感的 insn 排程"
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr "允許非載入的預測移動"
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr "允許一些載入的預測移動"
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr "允許更多載入的預測移動"
 
-#: common.opt:1928
+#: common.opt:1931
 #, fuzzy
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr "-fsched-verbose=<number>\t設定詳細度等級的排程程式"
 
-#: common.opt:1932
+#: common.opt:1935
 #, fuzzy
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr "如果排程貼文重新載入，做超區塊排程"
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr "指派暫存器前重新調度指令"
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr "指派暫存器後重新調度指令"
 
-#: common.opt:1951
+#: common.opt:1954
 #, fuzzy
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr "排程指令使用選擇性排程演算法"
 
-#: common.opt:1955
+#: common.opt:1958
 #, fuzzy
 msgid "Run selective scheduling after reload"
 msgstr "運行選擇性排程之後重新載入"
 
-#: common.opt:1959
+#: common.opt:1962
 #, fuzzy
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr "施行軟體管線操作的內迴圈在的期間選擇性排程"
 
-#: common.opt:1963
+#: common.opt:1966
 #, fuzzy
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr "施行軟體管線操作的外迴圈在的期間選擇性排程"
 
-#: common.opt:1967
+#: common.opt:1970
 #, fuzzy
 msgid "Reschedule pipelined regions without pipelining"
 msgstr "重新排程管線的區域而無需管線操作"
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 #, fuzzy
 msgid "Allow premature scheduling of queued insns"
 msgstr "允許過早排程的已佇列 insns"
 
-#: common.opt:1981
+#: common.opt:1984
 #, fuzzy
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr "-fsched-stalled-insns=<number>\t設定已佇列 insns 數量該可以是過早已排程"
 
-#: common.opt:1989
+#: common.opt:1992
 #, fuzzy
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr "設定 dependence 距離簽入過早排程的已佇列 insns"
 
-#: common.opt:1993
+#: common.opt:1996
 #, fuzzy
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr "-fsched-stalled-insns-dep=<number>\t設定 dependence 距離簽入過早排程的已佇列 insns"
 
-#: common.opt:1997
+#: common.opt:2000
 #, fuzzy
 msgid "Enable the group heuristic in the scheduler"
 msgstr "啟用群組試探在中排程程式"
 
-#: common.opt:2001
+#: common.opt:2004
 #, fuzzy
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr "啟用關鍵路徑試探在中排程程式"
 
-#: common.opt:2005
+#: common.opt:2008
 #, fuzzy
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr "啟用 speculative 指令試探在中排程程式"
 
-#: common.opt:2009
+#: common.opt:2012
 #, fuzzy
 msgid "Enable the rank heuristic in the scheduler"
 msgstr "啟用分級試探在中排程程式"
 
-#: common.opt:2013
+#: common.opt:2016
 #, fuzzy
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr "啟用最後一筆指令試探在中排程程式"
 
-#: common.opt:2017
+#: common.opt:2020
 #, fuzzy
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr "啟用附屬計數試探在中排程程式"
 
-#: common.opt:2021
+#: common.opt:2024
 #, fuzzy
 msgid "Access data in the same section from shared anchor points"
 msgstr "存取資料在中相同區段從共享的錨點"
 
-#: common.opt:2033
+#: common.opt:2036
 #, fuzzy
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "打開冗餘延伸 Elimination 回合。"
 
-#: common.opt:2037
+#: common.opt:2040
 #, fuzzy
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr "顯示欄數量在中診斷，若是可用。 預設開"
 
-#: common.opt:2041
+#: common.opt:2044
 #, fuzzy
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr "Emit 函式 prologues 只有之前零件的函式該需要它，"
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr "停用為 IEEE 訊息 NaN 可見的最佳化"
 
-#: common.opt:2050
+#: common.opt:2053
 #, fuzzy
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr "停用浮點數最佳化該忽略我 signedness 的零"
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr "將浮點常數轉換為單精度常數"
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr "展開循環時分離歸納變數的生存期"
 
-#: common.opt:2062
+#: common.opt:2065
 #, fuzzy
 msgid "Generate discontiguous stack frames"
 msgstr "產生 discontiguous 堆疊框架"
 
-#: common.opt:2066
+#: common.opt:2069
 #, fuzzy
 msgid "Split wide types into independent registers"
 msgstr "分割 wide 類型進入獨立暫存器"
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 #, fuzzy
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr "固定的暫存器 %s 用來回合參數到函式"
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr "展開循環時也展開變數"
 
-#: common.opt:2082
+#: common.opt:2085
 #, fuzzy
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "-fstack-check=[沒有|通用|特定的]\t插入堆疊檢查編碼進入程式"
 
-#: common.opt:2086
+#: common.opt:2089
 #, fuzzy
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "插入堆疊檢查編碼進入程式。 如同 -fstack-check=特定的"
 
-#: common.opt:2093
+#: common.opt:2096
 #, fuzzy
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr "-fstack-limit-register=<register>\t陷阱如果堆疊前往過去<暫存器>"
 
-#: common.opt:2097
+#: common.opt:2100
 #, fuzzy
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr "-fstack-limit-symbol=<name>\t陷阱如果堆疊前往過去符號<名稱>"
 
-#: common.opt:2101
+#: common.opt:2104
 #, fuzzy
 msgid "Use propolice as a stack protection method"
 msgstr "使用 propolice 做為堆疊保護方法"
 
-#: common.opt:2105
+#: common.opt:2108
 #, fuzzy
 msgid "Use a stack protection method for every function"
 msgstr "使用堆疊保護方法用於每函式"
 
-#: common.opt:2109
+#: common.opt:2112
 #, fuzzy
 msgid "Use a smart stack protection method for certain functions"
 msgstr "使用堆疊保護方法用於每函式"
 
-#: common.opt:2113
+#: common.opt:2116
 #, fuzzy
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr "使用堆疊保護方法用於每函式"
 
-#: common.opt:2117
+#: common.opt:2120
 #, fuzzy
 msgid "Output stack usage information on a per-function basis"
 msgstr "輸出堆疊用法資訊於 per-function 基礎"
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr "假定套用強重疊規則"
 
-#: common.opt:2133
+#: common.opt:2136
 #, fuzzy
 msgid "Treat signed overflow as undefined"
 msgstr "對待帶正負號溢位做為未定義"
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr "檢查語法錯誤，然後停止"
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr "產生「gcov」需要的資料檔案"
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr "進行跳轉執行緒最佳化"
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr "報告每趟組譯的耗時"
 
-#: common.opt:2157
+#: common.opt:2160
 #, fuzzy
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\t設定預設 thread-local 貯藏體編碼產生式樣"
 
-#: common.opt:2160
+#: common.opt:2163
 #, fuzzy, c-format
 msgid "unknown TLS model %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:2176
+#: common.opt:2179
 #, fuzzy
 msgid "Reorder top level functions, variables, and asms"
 msgstr "重新排序頂層函式、變數，而asms"
 
-#: common.opt:2180
+#: common.opt:2183
 #, fuzzy
 msgid "Perform superblock formation via tail duplication"
 msgstr "施行超區塊格式透過尾端複印法"
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr "假定浮點運算可能引發陷阱"
 
-#: common.opt:2191
+#: common.opt:2194
 #, fuzzy
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr "陷阱用於帶正負號溢位另外、減去和乘法"
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr "啟用樹上的 SSA-CCP 最佳化"
 
-#: common.opt:2199
+#: common.opt:2202
 #, fuzzy
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr "啟用 SSA-BIT-CCP 最佳化於樹"
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr "啟用樹上的循環不變量轉移"
 
-#: common.opt:2211
+#: common.opt:2214
 #, fuzzy
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr "施行變數追蹤並且標籤變數所 uninitialized"
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 #, fuzzy
 msgid "Replace SSA temporaries with better names in copies"
 msgstr "置換 SSA 暫時的與較好名稱在中份數"
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr "在樹層級進行複寫傳遞"
 
-#: common.opt:2231
+#: common.opt:2234
 #, fuzzy
 msgid "Transform condition stores into unconditional ones"
 msgstr "變換條件儲存進入 unconditional 一個"
 
-#: common.opt:2235
+#: common.opt:2238
 #, fuzzy
 msgid "Perform conversions of switch initializations."
 msgstr "施行轉換的切換初始化。"
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr "啟用樹上的 SSA 死程式碼消除最佳化"
 
-#: common.opt:2243
+#: common.opt:2246
 msgid "Enable dominator optimizations"
 msgstr "啟用主導最佳化"
 
-#: common.opt:2247
+#: common.opt:2250
 #, fuzzy
 msgid "Enable tail merging on trees"
 msgstr "啟用尾端合併於樹"
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr "刪除死存儲"
 
-#: common.opt:2255
+#: common.opt:2258
 #, fuzzy
 msgid "Enable forward propagation on trees"
 msgstr "啟用轉寄傳播於樹"
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr "啟用樹上的完全冗餘消除(FRE)"
 
-#: common.opt:2263
+#: common.opt:2266
 #, fuzzy
 msgid "Enable string length optimizations on trees"
 msgstr "啟用字串長度最佳化於樹"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 #, fuzzy
 msgid "Enable loop distribution on trees"
 msgstr "啟用迴圈發布於樹"
 
-#: common.opt:2284
+#: common.opt:2287
 #, fuzzy
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr "啟用迴圈發布用於胚騰變換的進入函式庫呼叫"
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr "啟用樹上的循環不變量轉移"
 
-#: common.opt:2292
+#: common.opt:2295
 #, fuzzy
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr "啟用迴圈交換變換。 如同 -floop-interchange"
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr "在循環中產生正規的歸納變數"
 
-#: common.opt:2300
+#: common.opt:2303
 msgid "Enable loop optimizations on tree level"
 msgstr "在樹層級進行循環最佳化"
 
-#: common.opt:2304
+#: common.opt:2307
 #, fuzzy
 msgid "Enable automatic parallelization of loops"
 msgstr "啟用自動 parallelization 的迴圈"
 
-#: common.opt:2308
+#: common.opt:2311
 #, fuzzy
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "啟用 hoisting 載入從條件指標。"
 
-#: common.opt:2312
+#: common.opt:2315
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "啟用樹上的 SSA-PRE 最佳化"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 #, fuzzy
 msgid "Perform function-local points-to analysis on trees."
 msgstr "施行 function-local points-to 分析於樹。"
 
-#: common.opt:2324
+#: common.opt:2327
 #, fuzzy
 msgid "Enable reassociation on tree level"
 msgstr "啟用 reassociation 於樹等級"
 
-#: common.opt:2332
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
 msgstr "啟用樹上的 SSA 程式碼下沉最佳化"
 
-#: common.opt:2336
+#: common.opt:2339
 #, fuzzy
 msgid "Perform straight-line strength reduction"
 msgstr "進行強度削減最佳化"
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr "為聚合類型進行標量替換"
 
-#: common.opt:2344
+#: common.opt:2347
 #, fuzzy
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr "置換暫時的運算式在中 SSA-> 一般回合"
 
-#: common.opt:2348
+#: common.opt:2351
 #, fuzzy
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr "施行即時範圍分裂在的期間 SSA-> 一般回合"
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr "進行樹上的值欄位傳遞"
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr "一次編譯一整個編譯單元"
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr "展開所有迭代次數已知的循環"
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr "展開所有循環"
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr "允許假定循環以「正常」方式動作的循環最佳化"
 
-#: common.opt:2375
+#: common.opt:2378
 #, fuzzy
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr "允許最佳化用於浮點算術該項也許會變更"
 
-#: common.opt:2380
+#: common.opt:2383
 #, fuzzy
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "如同 -fassociative-math 用於運算式該項包含除法。"
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr "允許可能違反 IEEE 或 ISO 標準的最佳化"
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr "外提循環內的測試敘述"
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr "僅為異常處理產生堆疊展開表"
 
-#: common.opt:2400
+#: common.opt:2403
 #, fuzzy
 msgid "Use the bfd linker instead of the default linker"
 msgstr "使用硬體大桶 shifter 以代替模擬"
 
-#: common.opt:2404
+#: common.opt:2407
 #, fuzzy
 msgid "Use the gold linker instead of the default linker"
 msgstr "使用硬體大桶 shifter 以代替模擬"
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr "進行變數追蹤"
 
-#: common.opt:2424
+#: common.opt:2427
 #, fuzzy
 msgid "Perform variable tracking by annotating assignments"
 msgstr "施行變數追蹤由 notating 指派"
 
-#: common.opt:2430
+#: common.opt:2433
 #, fuzzy
 msgid "Toggle -fvar-tracking-assignments"
 msgstr "切換 -fvar-tracking-assignments"
 
-#: common.opt:2438
+#: common.opt:2441
 #, fuzzy
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr "施行變數追蹤並且標籤變數所 uninitialized"
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees"
 msgstr "在樹上進行循環向量化"
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr "在樹上進行循環向量化"
 
-#: common.opt:2454
+#: common.opt:2457
 #, fuzzy
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr "啟用基本區塊 vectorization (SLP) 於樹"
 
-#: common.opt:2458
+#: common.opt:2461
 #, fuzzy
 msgid "Specifies the cost model for vectorization"
 msgstr "產生編碼用於內建基元的計算"
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:2478
+#: common.opt:2481
 #, fuzzy
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "沒做任何事。 保留的用於回溯相容性。"
 
-#: common.opt:2482
+#: common.opt:2485
 #, fuzzy
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr "沒做任何事。 保留的用於回溯相容性。"
 
-#: common.opt:2490
+#: common.opt:2493
 #, fuzzy
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "啟用複製傳用的 scalar-evolution 資訊。"
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr "為組譯輸出加入額外註釋"
 
-#: common.opt:2504
+#: common.opt:2507
 #, fuzzy
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr "-fvisibility=[預設|內部|隱藏|保護的]\t設定預設符號可視性"
 
-#: common.opt:2507
+#: common.opt:2510
 #, fuzzy, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "無法辨識的可視性值 %qs"
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(在 %qs 的初始化附近)"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr "在最佳化中使用運算式值樣本提供的資訊"
 
-#: common.opt:2551
+#: common.opt:2554
 #, fuzzy
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr "建構網頁和分割 unrelated 使用的單一變數"
 
-#: common.opt:2555
+#: common.opt:2558
 #, fuzzy
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr "啟用條件無作用程式碼 elimination 用於內建呼叫"
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr "進行全程式最佳化"
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr "假定有號運算溢出時回繞"
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr "將初始化為零的資料存放在 bss 區段中"
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr "產生 COFF 格式的除錯資訊"
 
-#: common.opt:2579
+#: common.opt:2582
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format"
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:2583
+#: common.opt:2586
 #, fuzzy
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr "產生除錯資訊在中 DWARF v2 (或稍後) 格式"
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr "產生預設擴充格式的除錯資訊"
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 #, fuzzy
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr "不記錄 gcc 命令列切換在中 DWARF DW_AT_producer。"
 
-#: common.opt:2607
+#: common.opt:2610
 #, fuzzy
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "記錄 gcc 命令列切換在中 DWARF DW_AT_producer。"
 
-#: common.opt:2611
+#: common.opt:2614
 #, fuzzy
 msgid "Don't generate debug information in separate .dwo files"
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:2615
+#: common.opt:2618
 #, fuzzy
 msgid "Generate debug information in separate .dwo files"
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr "產生 STABS 格式的除錯資訊"
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr "產生擴充 STABS 格式的除錯資訊"
 
-#: common.opt:2627
+#: common.opt:2630
 #, fuzzy
 msgid "Emit DWARF additions beyond selected version"
 msgstr "Emit DWARF 增加位於之後已選版本"
 
-#: common.opt:2631
+#: common.opt:2634
 #, fuzzy
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr "不 emit DWARF 增加位於之後已選版本"
 
-#: common.opt:2635
+#: common.opt:2638
 #, fuzzy
 msgid "Toggle debug information generation"
 msgstr "切換除錯資訊產生"
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr "產生 VMS 格式的除錯資訊"
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr "產生 XCOFF 格式的除錯資訊"
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr "產生 XCOFF 擴充格式的除錯資訊"
 
-#: common.opt:2665
+#: common.opt:2668
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections"
 msgstr "產生 isel 指令"
 
-#: common.opt:2669
+#: common.opt:2672
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:2676
+#: common.opt:2679
 #, fuzzy
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr "-iplugindir=<dir>\t設定<dir>為預設外掛程式目錄"
 
-#: common.opt:2680
+#: common.opt:2683
 #, fuzzy
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr "-imultilib <dir>\t設定<dir>為 multilib 包含子目錄"
 
-#: common.opt:2702
+#: common.opt:2705
 #, fuzzy
 msgid "-o <file>\tPlace output into <file>"
 msgstr "-o <file>\t置放輸出進入<檔案>"
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr "啟用函式取樣"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr "與 -pedantic 類似，但將它們視作錯誤"
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr "不顯示編譯的函式或逝去的時間"
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr "啟用詳細輸出"
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr "顯示編譯器版本"
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "不顯示警告"
 
-#: common.opt:2806
+#: common.opt:2809
 #, fuzzy
 msgid "Create a shared library"
 msgstr "建立共用函式庫"
 
-#: common.opt:2851
+#: common.opt:2854
 #, fuzzy
 msgid "Create a position independent executable"
 msgstr "建立位置獨立可執行檔案"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "計算出的值未被使用"
@@ -15941,272 +15952,272 @@
 msgid "expected integer or boolean type"
 msgstr "預期的整數或布林值型態"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 #, fuzzy
 msgid "invalid comparison of nil with nil"
 msgstr "無效的比較編碼在中 gimple cond"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 #, fuzzy
 msgid "incompatible types in binary expression"
 msgstr "不相容的類型在中二進位運算式"
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 #| msgid "division by zero"
 msgid "integer division by zero"
 msgstr "被零除"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 #, fuzzy
 msgid "shift of non-integer operand"
 msgstr "Shift 的 non-integer 運算元"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 #, fuzzy
 msgid "shift count not unsigned integer"
 msgstr "Shift 計數無法無正負號整數"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 #, fuzzy
 msgid "negative shift count"
 msgstr "負 Shift 計數"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 #, fuzzy
 msgid "object is not a method"
 msgstr "物件並非方法"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 #, fuzzy
 msgid "method type does not match object type"
 msgstr "方法型態不匹配物件類型"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 #, fuzzy
 msgid "invalid use of %<...%> with builtin function"
 msgstr "無效的使用的 %<...%>與內建函式"
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 #, fuzzy
 #| msgid "invalid use of template-name %qE without an argument list"
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "使用範本名 %qE 時不帶引數表無效"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 #, fuzzy
 msgid "not enough arguments"
 msgstr "不足引數"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 #, fuzzy
 msgid "too many arguments"
 msgstr "太多引數"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 #, fuzzy
 msgid "argument 1 must be a map"
 msgstr "引數 1 必須是映射"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 #, fuzzy
 msgid "invalid type for make function"
 msgstr "無效的型態用於製作函式"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 #, fuzzy
 msgid "length required when allocating a slice"
 msgstr "長度必要項時配置切片"
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 #, fuzzy
 msgid "too many arguments to make"
 msgstr "太多引數要讓"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 #, fuzzy
 msgid "argument must be array or slice or channel"
 msgstr "引數必須是陣列或切片或頻道"
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 #, fuzzy
 msgid "argument must be string or array or slice or map or channel"
 msgstr "引數必須正在字串或陣列或切片或映射或頻道"
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 #, fuzzy
 msgid "unsupported argument type to builtin function"
 msgstr "不受支援的引數類型到內建函式"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 #, fuzzy
 msgid "argument must be channel"
 msgstr "引數必須是頻道"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 #, fuzzy
 msgid "cannot close receive-only channel"
 msgstr "無法關閉 receive-only 頻道"
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 #, fuzzy
 msgid "argument must be a field reference"
 msgstr "引數必須是欄位參考"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 #, fuzzy
 msgid "left argument must be a slice"
 msgstr "左引數必須是切片"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 #, fuzzy
 msgid "element types must be the same"
 msgstr "元件類型必須相同"
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 #, fuzzy
 msgid "first argument must be []byte"
 msgstr "第一個引數必須是 [] 位元組"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 #, fuzzy
 msgid "second argument must be slice or string"
 msgstr "秒引數必須是切片或字串"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 #, fuzzy
 msgid "argument 2 has invalid type"
 msgstr "引數 2 有無效的型態"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 #, fuzzy
 msgid "argument must have complex type"
 msgstr "引數必須有複雜型態"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 #, fuzzy
 msgid "complex arguments must have identical types"
 msgstr "複雜引數必須有相等的類型"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 #, fuzzy
 msgid "complex arguments must have floating-point type"
 msgstr "複雜引數必須有浮點型態"
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 #, fuzzy
 msgid "expected function"
 msgstr "預期的函式"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 #, fuzzy
 msgid "multiple-value argument in single-value context"
 msgstr "多重值函式呼叫在中單一值語境"
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 #, fuzzy
 msgid "invalid use of %<...%> with non-slice"
 msgstr "無效的使用的 %<...%>與 non-slice"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 #, fuzzy
 #| msgid "Function return value not set"
 msgid "function result count mismatch"
 msgstr "未設定函式回傳值"
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 #, fuzzy
 msgid "incompatible type for receiver"
 msgstr "不相容的型態用於收件者"
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 #, fuzzy
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "無效的使用的 %<...%>呼叫 non-variadic 函式"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 #, fuzzy
 msgid "number of results does not match number of values"
 msgstr "結果數量不匹配值數量"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 #, fuzzy
 msgid "index must be integer"
 msgstr "索引必須是整數"
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 #, fuzzy
 msgid "slice end must be integer"
 msgstr "切片結束必須是整數"
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 msgid "slice capacity must be integer"
 msgstr "切片結束必須是整數"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 #, fuzzy
 msgid "slice of unaddressable value"
 msgstr "切片的 unaddressable 值"
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 #, fuzzy
 msgid "incompatible type for map index"
 msgstr "不相容的型態用於映射索引"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 #, fuzzy
 msgid "expected interface or pointer to interface"
 msgstr "預期的介面或指標到介面"
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 #, fuzzy
 msgid "too many expressions for struct"
 msgstr "太多運算式用於結構"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 #, fuzzy
 msgid "too few expressions for struct"
 msgstr "太少運算式用於結構"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 #, fuzzy
 msgid "type assertion only valid for interface types"
 msgstr "型態假設只有有效用於介面類型"
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 #, fuzzy
 msgid "impossible type assertion: type does not implement interface"
 msgstr "不可能的型態假設：型態不實作介面"
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 #, fuzzy
 msgid "expected channel"
 msgstr "預期的頻道"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 #, fuzzy
 msgid "invalid receive on send-only channel"
 msgstr "無效的接收於 send-only 頻道"
@@ -16339,79 +16350,79 @@
 msgid "cannot use type %s as type %s"
 msgstr "無法使用型態 %s 做為型態 %s"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 #, fuzzy
 msgid "different receiver types"
 msgstr "不同的收件者類型"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 #, fuzzy
 msgid "different number of parameters"
 msgstr "不同的參數數量"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 #, fuzzy
 msgid "different parameter types"
 msgstr "不同的參數類型"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 #, fuzzy
 msgid "different varargs"
 msgstr "不同的 varargs"
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 #, fuzzy
 msgid "different number of results"
 msgstr "不同的結果數量"
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 #, fuzzy
 msgid "different result types"
 msgstr "不同的結果類型"
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, fuzzy, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "需要明確的轉換；缺少的方法 %s%s%s"
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "不相容的型態用於方法 %s%s%s"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "不相容的型態用於方法 %s%s%s (%s)"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 #, fuzzy
 msgid "pointer to interface type has no methods"
 msgstr "指標到介面類型沒有任何方法"
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 #, fuzzy
 msgid "type has no methods"
 msgstr "型態沒有任何方法"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, fuzzy, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "模稜兩可的方法 %s%s%s"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, fuzzy, c-format
 msgid "missing method %s%s%s"
 msgstr "缺少方法 %s%s%s"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, fuzzy, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "方法 %s%s%s 需要指標"
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, fuzzy, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr "方法 %s%s%s 需要指標"
@@ -16531,7 +16542,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "%<__builtin_prefetch%> 的第三個引數無效；使用 0"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "給函式 %<va_start%> 的參數太少"
@@ -16713,12 +16724,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kattempt 以釋放 non-heap 物件"
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "函式呼叫有聚合類型"
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT for argument %P to %qD"
 msgid "passing too large argument on stack"
@@ -17280,244 +17291,249 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "bb 記事數量在中 insn 鏈接 (%d) !=n_basic_blocks (%d)"
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr "呼叫邊計數為負"
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, fuzzy, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr "呼叫者邊緣頻率是負"
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, fuzzy, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr "呼叫者邊緣頻率太大"
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "為邊 %s->%s 設定 AUX 欄位"
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, fuzzy, gcc-internal-format
 msgid "execution count is negative"
 msgstr "執行計數是負"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, fuzzy, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "節點是單獨在中 comdat 群組"
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "假定符號可能無效"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, fuzzy, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "外部可見的內聯仿本"
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, fuzzy, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "內聯仿本與位址佔用"
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, fuzzy, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "內聯仿本被所需的"
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "aux 欄位設定用於間接邊緣從 %s"
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "間接邊緣從 %s 未被標記為間接或已關聯的 indirectinfo(_I)，相應敘述是："
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to pointer 錯誤"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "多個內聯呼叫者"
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "為非內聯的呼叫者設定了 inlined_to pointer"
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr "呼叫者邊緣頻率 %i 不匹配 BB 頻率 %i"
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr "呼叫者邊緣頻率 %i 不匹配 BB 頻率 %i"
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "inlinedto 指標是設定並不是找到任何 predecessors(_T)"
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "inlined_to pointer 參照自身"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "節點有錯誤的 cloneof(_O)"
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "節點有錯誤的仿本清單"
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "節點有錯誤的 prevclone 指標(_C)"
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, fuzzy, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "雙倍鏈結的仿本清單的已損壞"
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, fuzzy, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "別名有呼叫邊緣"
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, fuzzy, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "別名有 non-alias 參考"
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, fuzzy, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "別名有超過一個別名參考"
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, fuzzy, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "分析的別名沒有任何參考"
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, fuzzy, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "對齊的 %qD 是大於原來的宣告"
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, fuzzy, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr "對齊的 %qD 是大於原來的宣告"
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, fuzzy, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr "別名有超過一個別名參考"
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, fuzzy, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr "表單參考到參考類型 %qT"
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, fuzzy, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr "分析的別名沒有任何參考"
 
-#: cgraph.c:3026
+#: cgraph.c:3046
+#, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
 #, fuzzy, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "沒有邊緣超出 thunk 節點"
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, fuzzy, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "超過一個邊緣超出 thunk 節點"
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, fuzzy, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Thunk 未被猜想到有內文"
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "共享的 call_stmt："
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "邊緣指到不對的宣告："
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, fuzzy, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "間接邊緣與不明被呼叫端相應到 callstmt 與已知宣告(_S)："
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, fuzzy, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "缺少callgraph 邊緣用於呼叫 stmt："
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "需要敘述"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "邊緣 %s->%s 沒有任何相應 callstmt(_S)"
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "間接邊緣從 %s 沒有任何相應 callstmt(_S)"
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node 失敗"
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "%s：區段 %s 缺少"
@@ -17648,7 +17664,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER 必須是設定"
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, fuzzy, gcc-internal-format
 msgid "atexit failed"
@@ -17889,17 +17905,17 @@
 msgid "          %s"
 msgstr "          %s"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, fuzzy, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr "共同符號除錯資訊未被結構做為符號+偏移"
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "全域解構函式在此目標平臺上不受支援"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "全域建構式在此目標平臺上不受支援"
@@ -17944,12 +17960,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "多重 EH 身分被支援只有與組譯器支援.cfipersonality 指令(_P)"
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "non-delegitimized UNSPEC %s (%d) 找到在中變數位置"
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -18144,7 +18160,7 @@
 msgid "total size of local objects too large"
 msgstr "總計大小的區域物件太大"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%> 中不可能的約束"
@@ -18595,9 +18611,9 @@
 msgstr "can%'t 寫入 PCH 檔案"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "宣告的在此"
@@ -18612,152 +18628,147 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr "gimple 檢查：預期 %s(%s)，有 %s(%s) 在中 %s，於 %s:%d"
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, fuzzy, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "使用結果的函式回傳 %<void%>"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "組譯輸出 %d 中左值無效"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "non-memory 輸入 %d 必須保持在中記憶體"
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "記憶體輸入 %d 不可直接定址"
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "threadprivate 變數 %qE 已用於 untied 任務"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, fuzzy, gcc-internal-format
 msgid "enclosing target region"
 msgstr "封閉任務"
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "threadprivate 變數 %qE 已用於 untied 任務"
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, fuzzy, gcc-internal-format
 msgid "enclosing task"
 msgstr "封閉任務"
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr "%qE 尚未指定在中封閉平行"
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, fuzzy, gcc-internal-format
 msgid "enclosing parallel"
 msgstr "封閉平行"
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr "%qE 尚未指定在中封閉平行"
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr "%qE 尚未指定在中封閉平行"
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, fuzzy, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr "封閉任務"
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "迭代變數 %qE 不應為消除"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "迭代變數 %qE 應該是私人的"
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "迭代變數 %qE 不應為 firstprivate"
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "迭代變數 %qE 不應為消除"
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "迭代變數 %qE 不應為 firstprivate"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "迭代變數 %qE 應該是私人的"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s 變數 %qE 是私人的在中外語境"
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s 變數 %qE 是私人的在中外語境"
 
-#: gimplify.c:7001
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, fuzzy, gcc-internal-format
-msgid "lastprivate variable %qE is private in outer context"
-msgstr "%s 變數 %qE 是私人的在中外語境"
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
-#, fuzzy, gcc-internal-format
 msgid "directive not yet implemented"
 msgstr "Finalization 於 %L 不是未實作"
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, fuzzy, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "預期 %<}%>之前 %<else%>expected %<}%> before %<else%>預期 %<}%>之前 %<else%>"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification 失敗"
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "給 %<va_arg%> 的第一個參數的類型不是 %<va_list%>"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "透過 %<...%> 傳遞時 %qT 被提升為 %qT"
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(因此您應該向 %<va_arg%> 傳遞 %qT 而不是 %qT)"
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "如果執行到這段程式碼，程式將中止"
@@ -19171,47 +19182,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "位元碼串流：找到多重實體的 cgraph 節點 %d"
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "位元碼串流：找不到任何呼叫者當讀取邊緣"
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "位元碼串流：找不到任何被呼叫端當讀取邊緣"
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "位元碼串流：找到清空 cgraph 節點"
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "最多 %i 側寫檔運行被支援。也許已損壞側寫檔？"
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "側寫檔資訊在中 %s 已損壞"
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "找不到 LTO cgraph 在中 %s"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "找不到 LTO 區段 refs 在中 %s"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -19295,48 +19306,48 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "異常的 COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "沒有輸入檔案"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 msgid "writing output file"
 msgstr "寫入輸出檔案『%s 時發生錯誤』\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, fuzzy, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "環境變數 COLLECT_GCC 必須是設定"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, fuzzy, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "環境變數 COLLECT_GCC_OPTIONS 必須是設定"
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen %s：%m"
@@ -19473,29 +19484,29 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "無效的離開從 OpenMP 結構化訊息塊"
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "無效的條目到 OpenMP 結構化訊息塊"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr "無效的分支到/從 OpenMP 結構化訊息塊"
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "ignoring large linear step"
 msgstr "忽略重複的目錄「%s」\n"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -20022,8 +20033,8 @@
 msgstr "can%'t 使用 %qs 做為固定的暫存器"
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "不明的暫存器名：%s"
@@ -20463,7 +20474,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld 回傳 %d"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F 使用過但從未定義"
@@ -21442,42 +21453,42 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr ""
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -21858,47 +21869,47 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, fuzzy, gcc-internal-format
 msgid "array subscript is outside array bounds"
 msgstr "陣列下標超出陣列邊界"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, fuzzy, gcc-internal-format
 msgid "array subscript is above array bounds"
 msgstr "陣列下標是以上的陣列邊界"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, fuzzy, gcc-internal-format
 msgid "array subscript is below array bounds"
 msgstr "陣列下標是下列的陣列邊界"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr "假設帶正負號溢位不發生時簡化條件到常數"
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr "假設帶正負號溢位不發生時簡化條件"
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, fuzzy, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr "比較一律假由於限制的範圍的資料類型"
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, fuzzy, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr "比較一律真由於限制的範圍的資料類型"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr "假設帶正負號溢位不發生時簡化 %</%>或 %<%%%>到 %<>>%>或 %<&%>"
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr "假設帶正負號溢位不發生時簡化 %<abs (X)%> 到 %<X%>或 %<-X%>"
@@ -21942,9 +21953,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -22177,7 +22188,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "%q+D 需要的對齊邊界大於實作的對齊邊界 %wu"
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D 的存儲大小不明"
@@ -22326,27 +22337,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "字串長 %qd 比 %qd (ISO C%d 被要求支援的最大長度) 還要長"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左移次數為負"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右移次數為負"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左移次數大於或等於類型寬度"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右移次數大於或等於類型寬度"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "常數運算式溢出"
@@ -22677,12 +22688,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "位址的 %qD 將一律評估做為 %<true%>"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "建議在做為真值的賦值敘述前後加上括號"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "錯誤地使用了 %<restrict%>"
@@ -23134,12 +23145,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "屬性 %qE 的向量類型無效"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, fuzzy, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "向量大小不是積分多重的成分大小"
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, fuzzy, gcc-internal-format
 msgid "zero vector size"
 msgstr "零向量大小"
@@ -23149,22 +23160,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr "向量中分量數不是 2 的某次方"
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "非空的屬性在非原型中沒有引數"
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "非空的引數 %lu 運算元號不正確"
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "非空的引數運算元號越界(引數 %lu，運算元 %lu)"
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "非空的引數 %lu 參照了非指標運算元 %lu"
@@ -23204,12 +23215,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "%qE 屬性只能用於帶可變參數函式"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "要求的位置不是一個整數常數"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "要求的位置小於 0"
@@ -23289,7 +23300,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "無法套用 %<offsetof%> 到非常數位址"
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "試圖取位元段結構成員 %qD 的位址"
@@ -23707,7 +23718,7 @@
 msgstr "索引值是超出約束"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "轉換的純量到向量牽連出截斷"
@@ -24163,7 +24174,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用兩不同的變數用於記憶體"
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "無效的型態用於迭代變數 %qE"
@@ -24173,22 +24184,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE 未被初始化的"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制述詞"
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "無效的控制述詞"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少遞增運算式"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無效的遞增運算式"
@@ -24727,6 +24738,12 @@
 msgid "too many input files"
 msgstr "輸入檔案太多"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+#| msgid "stack frame too large"
+msgid "-mcpu string too large"
+msgstr "堆疊框架太大"
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -24753,47 +24770,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s 有無效的 silicon 修訂"
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops 已經過時，請使用 -falign-loops"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d 不在 0 和 %d 之間"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps 已經過時，請使用 -falign-jumps"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d 未被介於 0 和 %d"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions 已過時，請使用 -falign-functions"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d 未被介於 0 和 %d"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d 不在 0 和 5 之間"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> 目前只有支援的於 GNU/Linux"
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> 需求組譯器支援用於 CFI 指令"
@@ -25177,63 +25194,63 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr "運算元號超出範圍"
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "-mtrap-precision 開關的值 %qs 不正確"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "-mfp-rounding-mode 開關的值 %qs 不正確"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "-mfp-trap-mode 開關的值 %qs 不正確"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr "-mcpu 開關的值 %qs 錯誤"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mtune switch"
 msgstr "不當的值 %qs 用於 -mtune 切換"
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, fuzzy, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr "fp 軟體完成需求 -mtrap-precision=i"
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "捨入模式不為 VAX 浮點數所支援"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "陷阱模式不為 VAX 浮點數所支援"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr "128 位 long double 在 VAX 上不受支援"
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr "L%d 快取延遲不明，對 %s 來說"
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr "-mmemory-latency 開關的值 %qs 錯誤"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -25711,14 +25728,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to functions"
@@ -26364,378 +26381,394 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "can%'t 設定位置在中 PCH 檔案：%m"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong arg %s to option %s"
 msgstr "-Werror=%s：沒有選項 -%s"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "%q+D 的暫存器名無效"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
+
+#: config/i386/i386.c:3012
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown alignment %s specified for option %s"
 msgstr "對齊指定的用於函式 %qE"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too many size ranges specified in option %s"
 msgstr "無效的範圍 %s 在中選項 %s"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "不明引數清單函式於 %L"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr "%stune =x86-64%s 被不宜用；使用 %stune=k8%s 或 %stune=generic%s 做為替代做為適當"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, fuzzy, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "編碼式樣 %s 不支援 PIC 模式"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel 不支援在中這個組態"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "未編譯入對 %i 位模式的支援"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "您選擇的 CPU 不支援 x86-64 指令集"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s 不支援 %s"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "不當的值 (%s) 用於 %sarch=%s %s"
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "不當的值 (%s) 用於 %stune=%s %s"
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, fuzzy, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm 被忽略在中 64-bit 模式"
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d 不在 0 和 %d 之間"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary 未被支援用於這個目標"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 未被介於 %d 和 %d"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 未被介於 %d 和 12"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mno-fentry isn%'t 相容與 SEH"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr "%ssseregparm%s 使用的而無需 SSE 已啟用"
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已停用，使用 387 指令"
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已停用，使用 SSE 指令"
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, fuzzy, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry isn%'t 支援的用於 32-bit 在中組合與 -fpic"
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, fuzzy, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry isn%'t 相容與 SEH"
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "不明選項用於 -mrecip=%s"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "屬性 %qE 引數不是字串"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "選項 (「%s」) 已經指定的"
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 屬性互不相容"
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 屬性需求整數常數引數"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "引數到 %qE 屬性大於 %d"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 屬性互不相容"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 屬性互不相容"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 屬性被用於無 class-method"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "呼叫 %qD 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, fuzzy, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "呼叫 %qT 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.c:5923
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr "呼叫 %qD 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
-
-#: config/i386/i386.c:6210
-#, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "不支援 multilib"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, fuzzy, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue 不是相容與巢狀的函式"
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, fuzzy, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, fuzzy, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "沒有啟用 SSE，卻出現了 SSE 向量引數，這變更了 ABI"
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "沒有啟用 SSE，卻有 SSE 向量回傳值，這變更了 ABI"
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "沒有啟用 MMX，卻出現了 MMX 向量引數，這變更了 ABI"
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "沒有啟用 MMX卻回傳 MMX 向量，這變更了 ABI"
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI 的傳遞結構與 flexible 陣列成員已變更在中 GCC 4.4"
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI 的傳遞聯合與長雙倍已變更在中 GCC 4.4"
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "已停用 SSE 卻在 SSE 暫存器中回傳"
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "已停用 SSE 卻在 SSE 暫存器中傳遞參數"
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, fuzzy, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 暫存器回傳與 x87 已停用"
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, fuzzy, gcc-internal-format
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr "呼叫 %qD 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
 #, fuzzy, gcc-internal-format
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr "呼叫 %qD 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
+
+#: config/i386/i386.c:11378
+#, fuzzy, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "ms_hook_prologue 屬性 isn%'t 相容與 -mfentry 用於 32-bit"
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack 不支援 fastcall 與巢狀的函式"
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack 不支援 2 暫存器  參數用於巢狀的函式"
@@ -26742,256 +26775,256 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack 不支援 3 暫存器參數"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "擴充的暫存器沒有高半部分"
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "擴充的暫存器不支援的運算元大小"
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "non-integer 運算元使用的與運算元編碼『%c』"
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "不支援堆疊限制運算式"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "%q+D 的前一個宣告"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "ifunc 未被支援在中這個組態"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs 的引數必須是一個 2 位無號原文"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "-ffpe-trap 的參數無效：%s"
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最後一筆引數必須是 2-bit 即時"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "fifth 引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "第三引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最後一筆引數必須是 1-bit 即時"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最後一筆引數必須是 32-bit 即時"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最後一筆引數必須是 4-bit 即時"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最後一筆引數必須是 1-bit 即時"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最後一筆引數必須是 5-bit 即時"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "下一個到最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "引數必須是常數"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "錯誤指令："
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "對樹結區段的共享不正確"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最後一筆引數必須是 4-bit 即時"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最後一筆引數必須是 5-bit 即時"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最後一筆引數必須是 32-bit 即時"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "選擇子必須是 0 到 %wi 間的整常數"
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, fuzzy, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE 需要不明 isa 選項"
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE 需要 isa 選項 %s"
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最後一筆引數必須是即時"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最後一筆引數必須是尺度 1,- 2,- 4, 8"
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "最後一筆引數必須是尺度 1,- 2,- 4, 8"
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "錯誤指令："
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 屬性只有可見於 32-bit"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, fuzzy, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 屬性不是相容"
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE 不相容的屬性忽略"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "不支援的組合：%s"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "不受支援的引數類型到內建函式"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -27085,13 +27118,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 屬性需要字串常數引數"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr "-mfixed-range 值必須有「暫存器1-暫存器2」的形式"
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -27163,7 +27196,7 @@
 msgstr "%qE 屬性未被支援用於 R8C 目標"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument not an integer constant"
 msgstr "%qE 屬性引數不是整數常數"
@@ -27223,7 +27256,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interruptthread 是可用只有於 fido(_T)"
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "不支援堆疊限制運算式"
@@ -28082,16 +28115,11 @@
 msgid "-g option disabled"
 msgstr "-g 選項已被停用"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "對齊 (%u) 用於 %s 超出最大值對齊用於全域共同資料。 使用 %u"
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr "使用 C89 修訂版 1 的特性必須指定 -munix=98 選項。\n"
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, fuzzy, gcc-internal-format
@@ -28353,312 +28381,317 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "目標屬性或 pragma 變更雙倍精度浮點數"
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 回傳向量參照：非標準的 ABI 擴充，不保證相容性"
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量暫存器中回傳值，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量暫存器中傳遞參數，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 傳遞向量參照：非標準的 ABI 擴充，不保證相容性"
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "內部錯誤：內建函式 %s 已經處理"
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "引數 1 必須是一個 5 位有號字面值"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "引數 1 必須是一個 5 位有號字面值"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "__builtin_altivec_predicate 的第一個引數必須是常數"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "__builtin_altivec_predicate 的第 1 個引數越界"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr "%srtd%s 被忽略在中 64 位元模式"
+
+#: config/rs6000/rs6000.c:12763
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate 的第 1 個引數越界"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "引數 3 必須是一個 4 位無號字面值"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "引數 3 必須是 2-bit 無正負號實字"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "引數 3 必須是 1-bit 無正負號實字"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "引數 1 必須是映射"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "引數 3 必須是 1-bit 無正負號實字"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "數字必須是 0 或 1"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "引數 %d 的 %qE 必須是在中範圍 %d...%d"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs 的引數必須是一個 2 位無號原文"
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, fuzzy, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "無法解析的過載用於 Altivec 內建 %qF"
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "dss 的引數必須是一個 2 位無號原文"
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "引數 1 的 __builtin_paired_predicate 必須是常數"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "引數 1 的 __builtin_paired_predicate 是超出範圍"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "__builtin_spe_predicate 的第一個引數必須是常數"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "__builtin_spe_predicate 的第 1 個引數越界"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "內建函式 %s 是只有有效用於儲存格處理器"
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "內建函式 %s 需求 -maltivec 選項"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "內建函式 %s 需求 -mpaired 選項"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "內建函式 %s 需求 -mspe 選項"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "內建函式 %s 需求 -mpaired 選項"
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "內建函式 %s 需求 -mpaired 選項"
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "內建函式 %s 需求 -mspe 選項"
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "內建函式 %s 需求 -maltivec 選項"
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "內建函式 %s 需求 -mpaired 選項"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "內建函式 %s 未被支援與目前的選項"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had no type"
 msgstr "內部錯誤：內建函式 %s 沒有任何型態"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "內部錯誤：內建函式 %s 有未預期的傳回類型 %s"
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "內部錯誤：內建函式 %s，引數 %d 已未預期的引數類型 %s"
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "堆疊框架太大"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支援取樣 64 位元程式碼"
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, fuzzy, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "您無法需位址的巢狀的函式如果您使用 -mno-pointers-to-nested-functions 選項。"
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<long double%> 無效"
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用布林類型無效"
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<complex%> 無效"
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, fuzzy, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "使用的十進位浮點數類型在中 AltiVec 類型無效"
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "使用的 %<long%> 在中 AltiVec 類型無效用於 64-bit 編碼而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "在 AltiVec 類型中使用 %<long%> 已過時；請改用 %<int%>"
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "使用的 %<long long%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "使用的 %<double%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "emitting microcode insn %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "emitting 條件 microcode insn %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "無效的 cpu「%s」用於 %s「%s」%s"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s「%s」%s 未被允許"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s「%s」%s 無效"
@@ -28909,88 +28942,88 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局部變數大小總和超過架構極值。"
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "影格大小的函式 %qs 是 %wd 位元組超出使用者提供的堆疊限制的 %d 位元組。 unconditional 陷阱被已加入。"
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "影格大小的函式 %qs 是 %wd 位元組該項是超過半堆疊大小。動態檢查會無法是 reliable。沒有檢查發出用於這個函式。"
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "影格大小的 %qs 是 %wd 位元組"
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs 使用動態堆疊指派"
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "引數到 %qs 應該是 non-negative 整數"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "引數到 %qE 屬性大於 %d"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/Architecture 模式在 %s 上不受支援"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支援"
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "硬體十進位浮點數指令無法使用於 %s"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "硬體十進位浮點數指令無法使用在中 ESA/390 模式"
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, fuzzy, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp can%'t 被已用於接合與 -msoft-float"
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float 一起使用不受支援"
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "堆疊大小必須大於堆疊防護值"
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "堆疊大小不能大於 64K"
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard 意味著使用 -mstack-size"
@@ -29005,53 +29038,53 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr "解捲表目前需要框架指標或 -maccumulate-outgoing-args 來保證正確性"
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "__builtin_saveregs 在此子目的上不受支援"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "%qE 屬性只有套用到插斷函式"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is supported only for SH2A"
 msgstr "%qE 屬性被支援只有用於 SH2A"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr "屬性 interrupt_handler 與 -m5-compact 不相容"
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to SH2A"
 msgstr "%qE 屬性只有套用到 SH2A"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument should be between 0 to 255"
 msgstr "%qE 屬性引數應該被介於 0 到 255"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument not a string constant"
 msgstr "%qE 屬性引數不是字串常數"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr "r0 需要做為呼叫篡改的暫存器"
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, fuzzy, gcc-internal-format
 msgid "need a second call-clobbered general purpose register"
 msgstr "需要秒 call-clobbered 通用暫存器"
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, fuzzy, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr "需要 call-clobbered 目標暫存器"
@@ -29430,44 +29463,44 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, fuzzy, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "無效的元件類型用於屬性 %qs"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "向量中分量數不是 2 的某次方"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "忽略 %qs 屬性"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "%qs 屬性需求原型與具名引數"
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "%qs 屬性只有套用到 variadic 函式"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "%qE 屬性沒有任何效果"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "屬性 %qs 套用到陣列類型只有"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -29529,7 +29562,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void 值未如預期地被忽略"
@@ -29559,62 +29592,62 @@
 msgid "GCC supports only %u nested scopes"
 msgstr "GCC 只支援 %u 個巢狀的作用欄位"
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "標籤 %q+D 使用前未定義"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "巢狀函式 %q+D 宣告過但從未定義"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr "內聯函式 %q+D 宣告的但是永不定義"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "未使用的變數 %q+D"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, fuzzy, gcc-internal-format
 msgid "variable %qD set but not used"
 msgstr "變數 %qD 設定並不是使用"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "陣列 %q+D 類型與隱含初始化不相容"
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "原本地定義的在此"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr "帶有省略號的參數清單無法與空參數名清單宣告匹配"
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr "具有預設提升的引數類型不能匹配空參數名清單宣告"
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "%q+D 的原型宣告的參數多於先前舊式的定義"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "%q+D 的原型宣告的參數少於先前舊式的定義"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr "%q+D 的原型對引數 %d 宣告類型不相容"
@@ -29621,42 +29654,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "%q+D 的原型出現在非原型定義之後"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "%q+D 的上一個定義在此"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "%q+D 的上一個隱含宣告在此"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "%q+D 的上一個宣告在此"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "%q+D 被重新宣告為不同意義的符號"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "內建函式 %q+D 未被宣告為函式"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "%q+D 的宣告隱藏了一個內建函式"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "列舉 %q+D 重宣告"
@@ -29664,341 +29697,341 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "與內建函式 %q+D 類型衝突"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "與 %q+D 類型衝突"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, fuzzy, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr "衝突具名的位址空間 (通用 vs %s) 用於 %q+D"
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, fuzzy, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr "衝突具名的位址空間 (%s vs 通用) 用於 %q+D"
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, fuzzy, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr "衝突具名的位址空間 (%s vs %s) 用於 %q+D"
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "%q+D 的類型限定衝突"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
 msgstr "重複定義的 typedef %q+D 與不同的型態"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "重複定義的 typedef %q+D 與 variably 已修改型態"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "%q+D 重定義"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "%q+D 重定義"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "對 %qD 的靜態宣告出現在非靜態宣告之後"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "對 %q+D 的靜態宣告出現在非靜態宣告之後"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, fuzzy, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr "%<gnu_inline%> 屬性呈現於 %q+D"
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, fuzzy, gcc-internal-format
 msgid "but not here"
 msgstr "並不是在此"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "%q+D 的執行緒局部宣告跟在其非執行緒局部宣告之後"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "%q+D 的執行緒局部宣告跟在其非執行緒局部宣告之後"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "%q+D 宣告為沒有外部連結的，之前卻有外部宣告"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "%q+D 宣告為沒有外部連結的，之前卻有外部宣告"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "%q+D 重宣告為沒有外部連結"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr "對 %q+D 的再次宣告中指定了不同的可見性 (保留原有的可見性)"
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "%q+D 帶有 noinline 屬性的宣告出現在其內聯宣告之後"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "%q+D 帶有 noinline 屬性的宣告出現在其內聯宣告之後"
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "%q+D 帶有 noinline 屬性的宣告出現在其內聯宣告之後"
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "參數 %q+D 重定義"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "對 %q+D 冗餘的重宣告"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "%q+D 的宣告隱藏了先前的一個非變數宣告"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD 的宣告隱藏了一個全域宣告"
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "%q+D 的宣告隱藏了先前的一個局部變數"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "帶陰影宣告是在此"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "對 %qD 的巢狀的外部宣告"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "隱含宣告函式 %qE"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "隱含宣告與內建函式 %qD 不相容"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "對 %q+#D 無效的重宣告"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "隱含宣告與函式 %qD 不相容"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE undeclared 在此 (無法在中函式)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE undeclared (先使用在中這個函式)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, fuzzy, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "每個 undeclared 識別碼被報告只一次用於每個函式看來在中"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "標籤 %qE 在所有函式外被參照"
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "跳至具有可變類型的識別碼的作用欄位中"
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, fuzzy, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "跳躍跳過變數初始化"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, fuzzy, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "標貼 %qD 定義的在此"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD 宣告的在此"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "跳轉至敘述運算式中"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "重複的標籤定義 %qE"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重複的標籤 %qD"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, fuzzy, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "傳統 C lacks 分隔命名空間用於標貼，識別碼 %qE 衝突"
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, fuzzy, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "切換跳躍之上變數初始化"
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, fuzzy, gcc-internal-format
 msgid "switch starts here"
 msgstr "切換開始在此"
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, fuzzy, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "切換跳躍進入敘述運算式"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, fuzzy, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE 定義為錯誤的 kind 的標籤"
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "未定義任何實體的無名結構/聯合"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "帶有存儲類別的空宣告沒有重宣告標記"
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "帶有類型限定的空宣告沒有重宣告標記"
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, fuzzy, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "清空宣告與 %<Alignas%(_A)>不 redeclare 標籤"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "空宣告中類型名無用"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> 用於空宣告中"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, fuzzy, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<Noreturn%(_N)>在中清空宣告"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "檔案作用欄位中出現 %<auto%> 空宣告"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "檔案作用欄位中出現 %<register%> 空宣告"
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "空宣告中指定存儲類別無用"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "無用的 %<Alignas%(_A)>在中清空宣告"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "空宣告中類型限定無用"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "無用的 %<Alignas%(_A)>在中清空宣告"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "空宣告"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 不支援在參數陣列宣告中使用 %<static%> 或類型限定符"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 不支援 %<[*]%> 陣列宣告"
@@ -30006,38 +30039,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%>不允許在中不同於函式原型範圍"
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D 一般是一個函式"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "typedef %qD 被初始化(改用 __typeof__)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "函式 %qD 像變數一樣被初始化"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "參數 %qD 已初始化"
@@ -30046,259 +30079,259 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "可變大小的物件不能被初始化"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "變數 %qD 有初始值設定但類型不完全"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "為內聯函式 %q+D 給定了 noinline 屬性"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "uninitialized 常數成員在中 %qT 無效在中 C++"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD 應該被初始化的"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "初始值設定無法決定 %q+D 的大小"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "在 %q+D 中缺少陣列大小"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "陣列 %q+D 大小為 0 或負"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "%q+D 的存儲大小不是常數"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "為非靜態局部變數 %q+D 忽略了 asm 限定符"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "不能將帶有 volatile 欄位的物件放入暫存器"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "uninitialized 常數 %qD 無效在中 C++"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C 不允許前向參數宣告"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, fuzzy, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "定義輸入複合實字無效在中 C++"
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "位元段 %qs 的寬度不是一個整數常數"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "bit-field %qs 寬度不是整數常數運算式"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "位元段 %qs 寬度為負"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "位元段 %qs 寬度為 0"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "位元段 %qs 類型無效"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "位元段類型 %qs 是一個 GCC 擴充"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "%qs 的寬度超過它自身的類型"
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs 比其類型的值要窄"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 禁止陣列 %qE 其大小 can%'t 被評估"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 禁止陣列其大小 can%'t 被評估"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 禁止變數長度陣列 %qE"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 禁止變數長度陣列"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "variably 已修改 %qE 於檔案範圍"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, fuzzy, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "variably 已修改欄位於檔案範圍"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "型態預設值到 %<int%> 在中宣告的 %qE"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "型態預設值到 %<int%> 在中型態名稱"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "重複的 %<const%>"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "重複的 %<restrict%>"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "重複的 %<volatile%>"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "重複的 %<restrict%>"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "衝突具名的位址空間 (%s vs %s)"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "函式宣告定義為 %<auto%>"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "函式宣告定義為 %<register%>"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "函式宣告定義為 %<typedef%>"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "函式宣告定義為 %<auto%>"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "貯藏類別指定的用於結構欄位 %qE"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "貯藏類別指定的用於結構欄位"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "貯藏類別指定的用於參數 %qE"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "貯藏類別指定的用於未命名參數"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "為類型名指定了存儲類別"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, fuzzy, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE 初始化的和宣告 %<extern%>"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, fuzzy, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE 同時有 %<extern%> 和初始設定式"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "file-scope 宣告的 %qE 指定 %<auto%>"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "file-scope 宣告的 %qE 指定 %<register%>"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, fuzzy, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "巢狀的函式 %qE 宣告 %<extern%>"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "function-scope %qE 隱含地自動和宣告 %<__thread%>"
@@ -30306,687 +30339,687 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static 或類型限定符出現在非參數陣列宣告中"
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "宣告的 %qE 做為陣列的虛值"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "宣告的型態名稱做為陣列的虛值"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "宣告的 %qE 做為陣列的函式"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "宣告的型態名稱做為陣列的函式"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "對包含彈性陣列成員的結構的無效使用"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "大小的陣列 %qE 有 non-integer 型態"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "大小的未命名陣列有 non-integer 型態"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C 禁止 zero-size 陣列 %qE"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C 禁止 zero-size 陣列"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "大小的陣列 %qE 是負"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "大小的未命名陣列是負"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "大小的陣列 %qE 太大"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "大小的未命名陣列太大"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 不允許彈性陣列成員"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%>無法在中宣告"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "陣列元素的類型不完全"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE 宣告的做為函式回傳函式"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "型態名稱宣告的做為函式回傳函式"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE 宣告的做為函式回傳陣列"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "型態名稱宣告的做為函式回傳陣列"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "函式定義有限定的 void 回傳類型"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函式回傳類型的類型限定"
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C 不允許使用 const 或 volatile 限定函式類型"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C 不允許使用 const 或 volatile 限定函式類型"
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs 合併的與 %<auto%> 限定元用於 %qE"
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs 合併的與 %<register%> 限定元用於 %qE"
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs 指定的用於自動變數 %qE"
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs 指定的用於參數 %qE"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs 指定的用於未命名參數"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs 指定的用於結構欄位 %qE"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs 指定的用於結構欄位"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "位元段 %qs 類型無效"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "位元段 %qs 類型無效"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "對齊指定的用於 typedef %qE"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "對齊指定的用於 %<register%> 物件 %qE"
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "對齊指定的用於參數 %qE"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "對齊指定的用於未命名參數"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "對齊指定的用於 bit-field %qE"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "對齊指定的用於未命名 bit-field"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "對齊指定的用於函式 %qE"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, fuzzy, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "%<Alignas%(_A)>說明符無法縮小對齊的 %qE"
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, fuzzy, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "%<Alignas%(_A)>說明符無法縮小對齊的未命名欄位"
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D 宣告為 %<inline%>"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D 宣告 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C 不允許使用 const 或 volatile 限定函式類型"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, fuzzy, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "成員的結構或聯合無法有 variably 已修改型態"
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "變數或欄位 %qE 宣告為 void"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "出現在參數陣列宣告中的屬性被忽略"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "參數 %q+D 宣告為 %<inline%>"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "參數 %q+D 宣告 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, fuzzy, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "欄位 %qE 宣告的做為函式"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "欄位 %qE 有不完整型態"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, fuzzy, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "未命名欄位有不完整型態"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, fuzzy, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "無效的貯藏類別用於函式 %qE"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "不能內聯 %<main%> 函式"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> 宣告 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 不支援 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 不支援 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "先前被宣告為 %<static%> 的變數重宣告為 %<extern%>"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "變數 %q+D 宣告為 %<inline%>"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "變數 %q+D 宣告 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, fuzzy, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "non-nested 函式與 variably 已修改型態"
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, fuzzy, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "物件與 variably 已修改型態必須沒有任何鏈結"
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "函式宣告不是一個原型"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "函式宣告中出現參數名卻未指定類型"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "參數 %u (%q+D) 的類型不完全"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "參數 %u 有不完整型態"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "參數 %u (%q+D)類型為 void"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "參數 %u 有虛值型態"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> 做為僅有的參數時不能被限定"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> 必須是僅有的參數"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "參數 %q+D 有一個前向宣告"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "%<%s %E%> 在參數表內部宣告"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "在參數清單中宣告了匿名 %s"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "它的作用欄位僅限於此定義或宣告，這可能並不是您想要的"
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, fuzzy, gcc-internal-format
 msgid "enum type defined here"
 msgstr "enum 型態定義的在此"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, fuzzy, gcc-internal-format
 msgid "struct defined here"
 msgstr "結構定義的在此"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, fuzzy, gcc-internal-format
 msgid "union defined here"
 msgstr "聯合定義的在此"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%> 重定義"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%> 重定義"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "巢狀的 %<union %E%> 重定義"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "巢狀的 %<struct %E%> 重定義"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, fuzzy, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "定義輸入 %qs 運算式無效在中 C++"
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "沒有宣告任何東西"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 doesn%'t 支援未命名結構/聯合"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 doesn%'t 支援未命名結構/聯合"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "重複的成員 %q+D"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "聯合包含無名成員"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "聯合體沒有成員"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "結構不包含任何具名成員"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "結構體沒有成員"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexible 陣列成員在中聯合"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr "flexible 陣列成員在中否則清空結構"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "值傳遞在中 %qs 太大"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "聯合不能成為透明的"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "巢狀的 %<enum %E%> 重定義"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> 重宣告"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "列舉值超過了最大整數類型可表示的範圍"
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "指定的模式對列舉值來說太小"
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE 的列舉值不是一個整數常數"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "列舉值值用於 %qE 不是整數常數運算式"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "列舉值溢出"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C 將列舉值限制在 %<int%> 範圍內"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "內聯函式 %qD 給定的屬性 noinline"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "回傳不完全的類型"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "回傳類型預設為 %<int%>"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "沒有前一個原型用於 %qD"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD 被使用不具任何原型之前它的定義"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "沒有前一個宣告用於 %qD"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD 被使用不具任何宣告之前它的定義"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "傳回類型的 %qD 不是 %<int%>"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD 是正常非靜態函式"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, fuzzy, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "舊式參數宣告在中原型的函式定義"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, fuzzy, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "傳統 C 拒絕 ISO C 樣式函式定義"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, fuzzy, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "參數名稱省略"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, fuzzy, gcc-internal-format
 msgid "old-style function definition"
 msgstr "舊式函式定義"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "參數名稱缺少的從參數清單"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD 宣告的做為 non-parameter"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "多重參數具名的 %qD"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "參數 %qD 宣告的與虛值型態"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "型態的 %qD 預設值到 %<int%>"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "參數 %qD 有不完整型態"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "宣告用於參數 %qD 但是沒有此類參數"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "引數個數與內建原型不符"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "引數數目與原型不符"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "原型宣告"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "提升後的引數 %qD 與內建原型不符"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "提升後的引數 %qD 與原型不符"
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "引數 %qD 與內建原型不符"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引數 %qD 與原型不符"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "參數 %qD 設定並不是使用"
@@ -30994,201 +31027,201 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> 迴圈初始宣告是只有允許的在中 C99 模式"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "使用選項 -std=c99 或 -std=gnu99 到編譯您的編碼"
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的靜態變數 %qD 在中 %<for%> 迴圈初始宣告"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的 %<extern%> 變數 %qD 在中 %<for%>迴圈初始宣告"
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的 non-variable %qD 在中 %<for%> 迴圈初始宣告"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, fuzzy, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "不相容的位址空間限定元 %qs 和 %qs"
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "重複的 %qE"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "宣告指定了兩個以上的資料類型"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> 對 GCC 來說太長了"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 不支援 %<long long%>"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 不支援複數類型"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C 不支援飽和類型"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C 不支援 %<__int128%>型態"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int128%>未被支援用於這個目標"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 不支援複數類型"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C 不支援十進位浮點數"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "定點類型不支援用於這個目標"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C 不支援定點類型"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, fuzzy, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "C++查找的 %qD 會回傳欄位，不是型態"
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE 不是一個 typedef 類型，也不是一個內建類型"
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE 沒有出現在宣告的開頭"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> 與 %<auto%> 一起使用"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> 與 %<register%> 一起使用"
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> 與 %<typedef%> 一起使用"
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 不支援 %qE"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 不支援 %qE"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> 出現在 %<extern%> 之前"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> 出現在 %<static%> 之前"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "宣告指定了多個存儲類別"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs 必須被使用與 %qs"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%>被使用而無需 %<_Fract%>或 %<_Accum%>"
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支援單獨用 %<complex%> 表示 %<double complex%>"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支援複整數"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -31198,7 +31231,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr "識別碼 %qE 衝突與 C++關鍵字"
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "預期的列尾"
@@ -31218,8 +31251,8 @@
 msgid "unknown type name %qE"
 msgstr "不明型態名稱 %qE"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定宣告"
@@ -31234,7 +31267,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "預期 %<;%>，識別碼或 %<(%>"
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "前綴屬性被忽略用於方法"
@@ -31313,7 +31346,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 不支援 %<_Static_assert%>"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "需要字面字串"
@@ -31371,14 +31404,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要識別碼"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "列舉表以逗號結尾"
@@ -31832,32 +31865,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr "沒有型態或貯藏類別也許會被指定的在此，"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明內容屬性"
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "缺少%<=%>(之後 %<setter%>屬性)missing %<=%> (after %<setter%> attribute)缺少%<=%>(之後 %<setter%>屬性)"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%<setter%> 屬性也許會只有被指定的一旦"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, fuzzy, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 名稱必須終止與 %<:%>"
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%<getter%> 屬性也許會只有被指定的一旦"
@@ -31867,47 +31900,47 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr "%<# pragma omp barrier%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr "%<# pragma omp barrier%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr "%<# pragma omp flush%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr "%<# pragma omp taskwait%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr "%<# pragma omp taskyield%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr "%<# pragma omp taskyield%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr "%<# pragma omp taskwait%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp sections%>建構"
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
@@ -31922,12 +31955,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "預期的整數運算式"
@@ -31937,27 +31970,27 @@
 msgid "expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a constant"
 msgstr "%q#D 不是常數"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "預期 %<none%> 或 %<shared%>"
@@ -31989,17 +32022,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, fuzzy, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<runtime%> 不需 %<chunksize%(_S)>參數"
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, fuzzy, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<auto%> 不需 %<chunksize%(_S)>參數"
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "無效的排程 kind"
@@ -32019,12 +32052,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "using parameters for %<linear%> step is not supported yet"
@@ -32045,18 +32078,18 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "無效的排程 kind"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "無效遮罩"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "無效的排程 kind"
@@ -32066,58 +32099,58 @@
 msgid "invalid proc_bind kind"
 msgstr "無效的排程 kind"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs 必須被使用與 %qs"
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr "預期的字串之後 %<# pragma message%>"
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid pragma"
 msgstr "無效的 #pragma %s"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "無效的表單的 %<# pragma omp atomic%>"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "無效的運算子用於 %<# pragma omp atomic%>"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用兩不同的變數用於記憶體"
@@ -32127,17 +32160,17 @@
 msgid "expected %<(%> or end of line"
 msgstr "預期 %<(%>或列尾"
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "預期的迭代宣告或初始化"
@@ -32147,243 +32180,243 @@
 msgid "not enough perfectly nested loops"
 msgstr "不足 perfectly 巢狀的迴圈"
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, fuzzy, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "崩潰的迴圈無法 perfectly 巢狀"
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代變數 %qD 不應為 firstprivate"
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "預期 %<operator%>"
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "預期 %<using%>"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr "%<# pragma omp taskwait%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "預期 %<try%>"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "預期 %<decltype%>"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<# pragma GCC pop_options%>而無需相應 %<# pragma GCC push_options%>"
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "模板宣告無法出現於區塊範圍"
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, fuzzy, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "前一個宣告"
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, fuzzy, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "預期 %<(%>或列尾"
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "預期的函式"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE 宣告 %<threadprivate%> 之後先使用"
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動變數 %qE 無法 %<threadprivate%>"
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE 有不完整型態"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, fuzzy, gcc-internal-format
 msgid "pragma simd must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "vectorlength must be an integer constant"
 msgstr "選擇子必須是 0 到 %wi 間的整常數"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "堆疊大小必須剛好是 2 的某次方"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "選擇子必須是 0 到 %wi 間的整常數"
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "在這裡不允許使用 %<#pragma%>"
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%>而無需 transactional 記憶體支援已啟用"
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%>在之內 %<__transaction_relaxed%>"
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "外 %<__transaction_cancel%>無法在之內外 %<__transaction_atomic%>"
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  或 %<transaction_may_cancel_outer%> 函式"
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%>無法在之內 %<__transaction_atomic%>"
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "base of array section must be pointer or array type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "預期 %<:%>或 %<::%>"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "array notations cannot be used with function type"
 msgstr "new 不能用於函式類型"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 msgid "expected array notation expression"
 msgstr "預期的布林表示式"
@@ -32393,7 +32426,7 @@
 msgid "%qD has an incomplete type"
 msgstr "%qD 類型不完全"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "對 void 運算式的無效使用"
@@ -32501,7 +32534,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "註標的值是 neither 陣列 nor 指標 nor 向量"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "陣列下標不是一個整數"
@@ -32624,7 +32657,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "根據原型，引數 %d (%qE) 將做為有號數傳遞"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "隱含轉換從 %qT 到 %qT 時傳遞引數到函式"
@@ -32654,7 +32687,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "在參照不完全類型的指標上執行算術運算"
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -32740,7 +32773,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "非左值陣列出現在條件運算式中"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他結果的條件"
@@ -32776,7 +32809,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "條件運算式中指標/整數類型不匹配"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, fuzzy, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr "函式呼叫無法出現在中 constant-expression"
@@ -32862,7 +32895,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "從類型為 %qT 的函式呼叫轉換到不匹配的類型 %qT"
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "當將一個指標轉換為大小不同的整數時給出警告"
@@ -33024,7 +33057,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手邊可能是 format 屬性的備選時"
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "回傳類型可能是 format 屬性的備選"
@@ -33161,7 +33194,7 @@
 msgid "initialization of a flexible array member"
 msgstr "對彈性陣列成員的初始化"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "用寬字串初始化 char 陣列"
@@ -33207,7 +33240,7 @@
 msgid "invalid initializer"
 msgstr "無效的初始值設定"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量類型不能被初始化"
@@ -33352,7 +33385,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C++ 不允許 %<goto *expr;%>"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被宣告為 %<noreturn%> 的函式卻有 %<return%> 敘述"
@@ -33362,7 +33395,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "%qE 不能做為函式"
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, fuzzy, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr "邏輯的範圍在中條件敘述於 %L 未被允許"
@@ -33470,17 +33503,17 @@
 msgid "expression statement has incomplete type"
 msgstr "運算式敘述類型不完全"
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "比較向量與不同的元件類型"
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "比較向量與不同的元件號碼的"
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "使用 == 或 != 比較浮點數是不安全的"
@@ -33531,12 +33564,12 @@
 msgstr "已排序的比較的指標與空指標"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "指標與整數 0 比較大小"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他運算元的二進位運算式"
@@ -33561,87 +33594,87 @@
 msgid "used vector type where scalar is required"
 msgstr "使用的向量型態位置純量被必要項"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "變數長度陣列被使用"
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "用於遞增運算式沒有任何效果"
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "複製陣列區段進入 contiguous 區塊於程序條目"
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qD 沒有積分或列舉類型型態"
@@ -33651,17 +33684,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE 有無效的型態用於 %<reduction(%s)%>"
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, fuzzy, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE 必須是 %<threadprivate%> 用於 %<copyin%>"
@@ -33671,7 +33704,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -33681,17 +33714,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE 並非變數在中子句 %<firstprivate%>"
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE 並非變數在中子句 %<lastprivate%>"
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -33707,47 +33740,47 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "陣列區段無法允許的在中『%s』呼叫於 %L"
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE 被 predetermined %qs 用於 %qs"
@@ -33758,117 +33791,117 @@
 msgstr "C++需求升級的型態，無法 enum 型態，在中 %<va_arg%>"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "將 %qT 做為 %q#D 的 %<this%> 引數時丟棄了類型限定"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, fuzzy, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr "  沒有已知轉換用於隱含的 %<this%> 參數從 %qT 到 %qT"
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "  沒有已知轉換用於引數 %d 從 %qT 到 %qT"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion from %qT to %qT"
 msgstr "  當從 %qT 轉換為 %qT 時"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, fuzzy, gcc-internal-format
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "  沒有已知轉換用於引數 %d 從 %qT 到 %qT"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] "  candidate 預期 %d 引數，%d 提供"
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, fuzzy, gcc-internal-format
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr "%s%D(%T, %T, %T) <built-in>"
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, fuzzy, gcc-internal-format
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "%s%D(%T, %T) <built-in>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, fuzzy, gcc-internal-format
 msgid "%s%D(%T) <built-in>"
 msgstr "%s%D(%T) <built-in>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, fuzzy, gcc-internal-format
 msgid "%s%T <conversion>"
 msgstr "%s%T <conversion>"
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, fuzzy, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr "%s%#D <near match>"
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, fuzzy, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr "%s%#D <deleted>"
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, fuzzy, gcc-internal-format
 msgid "%s%#D"
 msgstr "%s%#D"
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, fuzzy, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr "  傳回類型 %qT 的明確的轉換函式無法轉換到 %qT 與合格轉換"
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, fuzzy, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr "  轉換從傳回類型 %qT 的模板轉換函式特殊化到 %qT 不是精確的匹配"
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, fuzzy, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr "  替代的 deduced 模板引數結果的在中錯誤看見以上的"
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "  模板引數推導/替代失敗："
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, fuzzy, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr "  建構子需單一引數的它的本身類別型態無效"
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "從 %qT 到 %qT 的轉換有歧義"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr "轉換從 %qT 到 %qT 無法認為的用於 non-type 模板引數"
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "對 %<%D(%A)%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "呼叫多載的 %<%D(%A)%> 有歧義"
@@ -33875,461 +33908,461 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr "沒有物件不能呼叫成員函式指標 %E，考慮使用 .* 或 ->*"
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "對 %<(%T) (%A)%> 的呼叫沒有匹配"
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "對 %<(%T) (%A)%> 的呼叫有歧義"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "模稜兩可的過載用於 %qs 在中 %<%s %E%>"
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, fuzzy, gcc-internal-format
 msgid "no match for "
 msgstr "沒有匹配用於 %qs 在中 %<%s %E%>"
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "無效的運算元到二進位 %s (有 %qT 和 %qT)"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "無效的運算元到二進位 %s (有 %qT 和 %qT)"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "沒有匹配用於三進 %<operator?:%> 在中 %<%E？%E：%E%>"
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%E%s%>"
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "沒有匹配用於 %<operator[]%> 在中 %<%E[%E]%>"
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "沒有匹配用於 %qs 在中 %<%s %E%>"
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%E %s %E%>"
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%s%E%>"
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C 不允許省略 ?: 運算式中的第二項"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "條件運算式中列舉不匹配：%qT 對 %qT"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, fuzzy, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "秒運算元到條件式運算子是的型態 %<void%>，但是第三運算元是 neither throw-expression nor 的型態 %<void%>"
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, fuzzy, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "第三運算元到條件式運算子是的型態 %<void%>，但是第二運算元是 neither throw-expression nor 的型態 %<void%>"
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, fuzzy, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "運算元到 ?:有不同的類型 %qT 和 %qT"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "條件運算式中列舉不匹配：%qT 對 %qT"
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "列舉和非列舉類型一起出現在條件運算式中"
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%> 沒有出現在字尾 %qs 中，嘗試使用字首運算子"
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "沒有 %<%D(整數)%>宣告的用於後綴 %qs"
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "在 %q#T 和 %q#T 間比較"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, fuzzy, gcc-internal-format
 msgid "non-placement deallocation function %q+D"
 msgstr "non-placement deallocation 函式 %q+D"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, fuzzy, gcc-internal-format
 msgid "selected for placement delete"
 msgstr "已選用於放置位址刪除"
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, fuzzy, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "沒有相應 deallocation 函式用於 %qD"
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "沒有合適的 %<operator %s%> 給 %qT"
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr "%q+#D 是私有的"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr "%q+#D 是保護的"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr "%q+#D 無法存取"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "將 NULL 做為非指標引數 %P 傳遞給 %qD"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "將 NULL 轉換到非指標類型 %qT"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "轉換 %<false%> 到指標類型用於引數 %P 的 %qD"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "轉換 %<false%> 到指標類型 %qT"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "太多大括號周圍初始設定式用於 %qT"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, fuzzy, gcc-internal-format
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, fuzzy, gcc-internal-format
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "無效的使用者定義的轉換從 %qT 到 %qT"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  初始化引數 %P，屬於 %qD"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "從類型 %qT 到類型 %qT 的轉換無效"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, fuzzy, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "轉換到 %qT 從初始設定式清單會使用明確的建構子 %qD"
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %q+D"
 msgstr "  初始化引數 %P 的 %q+D"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, fuzzy, gcc-internal-format
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "無法繫結 %qT lvalue 到 %qT"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, fuzzy, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "將 %qT 做為 %q#D 的 %<this%> 引數時丟棄了類型限定"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "無法將位元段 %qE 繫結到 %qT"
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "不能將緊實的欄位 %qE 繫結到 %qT"
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "無法將右值 %qE 繫結到 %qT"
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, fuzzy, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "無法回合物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>"
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "無法接收物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>；"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, fuzzy, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "無法接收物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>；"
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "遞迴求值的預設引數用於 %q#D"
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "呼叫到 %qD 使用預設引數用於參數 %P, 該項不是未定義"
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "函式的引數可能是 format 屬性的備選"
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "缺席函式 %q+D 與預設引數"
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "將 %qT 做為 %q#D 的 %<this%> 引數時丟棄了類型限定"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  在呼叫 %qD 時"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT 是 %qT 的一個不可存取的基礎類別"
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "deducing %qT 做為 %qT"
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, fuzzy, gcc-internal-format
 msgid "  in call to %q+D"
 msgstr "  在中呼叫到 %q+D"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, fuzzy, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (您可以停用這個與 -fno-deduce-init-list)"
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr "在 java 介面類型 %qT 中找不到 class$ 欄位"
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "常數參考它自己"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "呼叫非函式的 %qD"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, fuzzy, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "無法呼叫建構子 %<%T::%D%>直接"
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, fuzzy, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  用於 function-style 演員陣容，移除冗餘 %<::%D%>"
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "沒有匹配函式用於呼叫到 %<%T::運算子 %T(%A)%#V%>"
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr "對 %<%T::%s(%A)%#V%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "對 %<%D(%A)%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "對多載的 %<%s(%A)%> 的呼叫有歧義"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT 沒具名為 %qD 的非靜態資料成員"
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "沒有物件無法呼叫成員函式 %qD"
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "傳遞 %qT 時選擇 %qT 而不是 %qT"
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "選擇 %qD 而不是 %qD"
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  當從 %qT 轉換為 %qT 時"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  因為前者的引數類型轉換序列更好"
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "預設引數不匹配在中過載解析度"
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr " candidate 1:%q+#F"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr " candidate 2:%q+#F"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ 認為有歧義，盡管第一個備選的最差類型轉換要好於第二個備選的最差類型轉換"
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "無法轉換 %qE 從 %qT 到 %qT"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, fuzzy, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "暫時的約束到 %qD 只有持續直到建構子離開"
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "將類型為 %qT 的參照初始化為類型為 %qT 的運算式無效"
@@ -34490,7 +34523,7 @@
 msgid "  by %q+D"
 msgstr "  為 %q+D"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D 無效；匿名聯合只能有非靜態的資料成員"
@@ -34500,7 +34533,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D 無效的；匿名結構只能有非靜態資料成員"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr "匿名聯合中出現私有成員 %q+#D"
@@ -34510,7 +34543,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "私人的成員 %q+#D 在中匿名結構"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr "匿名聯合中出現保護成員 %q+#D"
@@ -34644,68 +34677,78 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  也沒有多載 %<operator=(const %T&)%>"
 
-#: cp/class.c:4538
+#: cp/class.c:4300
 #, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, fuzzy, gcc-internal-format
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr "對齊的 %qD 是大於原來的宣告"
+
+#: cp/class.c:4557
+#, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "為非虛方法 %q+D 指定了初始值設定項"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, fuzzy, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "方法強制變更兩者 %<transaction_pure%> 和 %qE 方法"
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, fuzzy, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "方法宣告 %qE 強迫 %qE 方法"
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "封入類別的 constexpr 非靜態成員函式 %q+#D 並非實字型態"
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T 不是實字因為："
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解構式"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, fuzzy, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr "  %q+T 不是彙總，沒有 trivial 預設建構函式，而沒有任何 constexpr 建構子該並非複製或移動建構子"
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  基礎類別 %qT 的 %q+T 是 non-literal"
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has volatile type"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "基礎類別 %q#T 有一個非虛解構函式"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr "類別中有非靜態參照 %q+#D，卻沒有提供建構式"
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr "類別中有非靜態常數成員 %q+#D 卻沒有建構式"
@@ -34712,102 +34755,102 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D 宣告到需常數參考，但是蘊含宣告會需 non-const"
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "由於存在歧義，直接基礎類別 %qT 在 %qT 中無法存取"
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "由於存在歧義，虛基礎類別 %qT 在 %qT 中無法存取"
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D 的偏移量與 ABI 不相容，並且在 GCC 的未來版本中可能會有變化"
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T 重定義"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T 有虛擬函式和可存取 non-virtual 解構式"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "型態透明類別 %qT 沒有任何欄位"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "型態透明類別 %qT 有基礎類別"
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "型態透明類別 %qT 有虛擬函式"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, fuzzy, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "deducing 從 brace-enclosed 初始設定式清單需求 # 包含 <initializer_list>"
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "試圖完成結構，但為先前的解析錯誤所插斷"
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "語言字串 %<\"%E\"%> 不可識別"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "無法解析多載函式 %qD，基於向類型 %qT 的轉換"
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "沒有可將函式 %qD 轉換到類型 %q#T 的匹配項"
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "將多載函式 %qD 轉換為類型 %q#T 有歧義"
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "假定是成員指標 %qD"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(成員指標只能用 %<&%E%> 構成)"
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "類型資訊不充分"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "無法將 %qE 從類型 %qT 轉換到類型 %qT"
@@ -34817,12 +34860,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "%q#D 的宣告"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr "變更了 %qD 的原意 %q+#D"
@@ -34862,258 +34905,258 @@
 msgid "constexpr constructor does not have empty body"
 msgstr "constexpr 建構子沒有清空內文"
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "%<constexpr%> 建構子用於聯合 %qT 必須初始化精確的一個非靜態資料成員"
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, fuzzy, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, fuzzy, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "內文的 constexpr 函式 %qD 不是 return-statement"
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, fuzzy, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr "%q+D 不是可用做為 constexpr 函式因為："
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 msgid "call to internal function"
 msgstr "內部函式"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "運算式 %qE 不指定 constexpr 函式"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, fuzzy, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "呼叫到 non-constexpr 函式 %qD"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD called 在中常數運算式"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD 使用的之前它的定義"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, fuzzy, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "呼叫有環狀依存性"
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "constexpr 求值深度超出最大值的 %d (使用 -fconstexpr-depth=到增加最大值)"
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E並非常數運算式"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "右移次數為負"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "逗號運算式的左運算元不起作用"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "整型運算式 %qE 不是常數"
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 msgid "array subscript out of bound"
 msgstr "陣列下標超出約束"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "negative array subscript"
 msgstr "%C 處需要陣列下標"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "可變的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "存取 %qD 成員以代替初始化的 %qD 成員在中常數運算式"
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "存取值的 %qE 透過 %qT glvalue 在中常數運算式"
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "值的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD 已用於它的本身初始設定式"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D 不是常數"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D 是易變的"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD 未被初始化的與常數運算式"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD 未被宣告 %<constexpr%>"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant-expression"
 msgstr "除法由零並非 constant-expression"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpretcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant-expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "未預期的運算式 %qE 的 kind %s"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr "轉換從指標類型 %qT 到算術型式 %qT 在中 constant-expression"
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, fuzzy, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "運算式 %qE 有 side-effects"
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of 物件 %qE 與執行緒本地或自動貯藏體並非常數運算式"
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, fuzzy, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, fuzzy, gcc-internal-format
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "差異的兩指標運算式並非常數運算式"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, fuzzy, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr "指標比較運算式並非常數運算式"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant-expression"
 msgstr "除法由零並非 constant-expression"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "non-constant 陣列初始化"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "未預期的 AST 的 kind %s"
@@ -35185,7 +35228,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr "%s 敘述未被允許內部的區塊於 %C"
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, fuzzy, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr "%qE 隱含地決定的做為 %<firstprivate%> 有參考類型"
@@ -35225,7 +35268,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "從 %qT 到 %qT 的轉換丟失了限定資訊"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "從 %qT 轉換到 %qT 並未提領指標"
@@ -35235,292 +35278,292 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "不能將類型 %qT 轉換為類型 %qT"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "從 %q#T 到 %q#T 的轉換"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, fuzzy, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "結果的轉換被未指定的因為 %qE 超出範圍的型態 %qT"
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "不應使用 %q#T 而應使用 %qT"
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "無法轉換 %qE 從 %qT 到 %qT"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "需要浮點數值時使用了 %q#T"
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "請求從 %qT 轉換到非標量類型 %qT"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "偽解構函式未被呼叫"
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "轉換到虛值將無法存取物件的不完整型態 %qT"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中秒運算元的條件運算式"
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中第三運算元的條件運算式"
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中權限運算元的逗號運算子"
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中向左運算元的逗號運算子"
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中敘述"
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中用於遞增運算式"
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "轉換到虛值將無法存取物件的型態 %qT"
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中秒運算元的條件運算式"
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中第三運算元的條件運算式"
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中權限運算元的逗號運算子"
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中向左運算元的逗號運算子"
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中敘述"
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中用於遞增運算式"
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "轉換到虛值將無法存取物件的 non-trivially-copyable 型態 %qT"
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中秒運算元的條件運算式"
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中第三運算元的條件運算式"
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中權限運算元的逗號運算子"
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中向左運算元的逗號運算子"
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中敘述"
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中用於遞增運算式"
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "轉換到虛值將無法存取物件 %qE 的不完整型態 %qT"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中秒運算元的條件運算式"
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中第三運算元的條件運算式"
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中權限運算元的逗號運算子"
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中向左運算元的逗號運算子"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中敘述"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中用於遞增運算式"
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, fuzzy, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "轉換到虛值無法解析位址的多載化函式"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "秒運算元的條件運算式無法解析位址的多載化函式"
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "第三運算元的條件運算式無法解析位址的多載化函式"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "右運算元的逗號運算子無法解析位址的多載化函式"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "左運算元的逗號運算子無法解析位址的多載化函式"
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, fuzzy, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "敘述無法解析位址的多載化函式"
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, fuzzy, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "用於遞增運算式無法解析位址的多載化函式"
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "秒運算元的條件運算式是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "第三運算元的條件運算式是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "右運算元的逗號運算子是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "左運算元的逗號運算子是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "敘述是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "用於遞增運算式是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "秒運算元的條件運算式沒有任何效果"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "第三運算元的條件運算式沒有任何效果"
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "右運算元的逗號運算子沒有任何效果"
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "左運算元的逗號運算子沒有任何效果"
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, fuzzy, gcc-internal-format
 msgid "statement has no effect"
 msgstr "敘述沒有任何效果"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, fuzzy, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "用於遞增運算式沒有任何效果"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "將 NULL 轉換為非指標類型"
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "  無法 deduce 模板參數 %qD"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "%qT 的預設類型轉換有歧義"
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  備選轉換包括 %qD 和 %qD"
@@ -35950,243 +35993,243 @@
 msgid "template parameters do not match template %qD"
 msgstr "範本參數與範本不符"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, fuzzy, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr "匿名結構無法有函式成員"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, fuzzy, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr "匿名等位無法有函式成員"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "有建構式的成員 %q+#D 不允許在匿名聚合中出現"
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "有構構函式的成員 %q+#D 不允許在匿名聚合中出現"
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "有複製賦值運算子的成員 %q+#D 不能用在聯合中"
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "屬性用於 %q#T 必須追隨 %qs 關鍵字"
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一個宣告指定了多個類型"
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "對 C++ 內建類型 %qT 的重宣告"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> 只能被指定的用於變數或函式宣告"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef 宣告中缺少類型名"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ 不允許匿名結構"
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr "只能為函式指定 %qs"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> 只能在類別中指定"
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "只能為建構式指定 %<explicit%>"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "只能為物件和函式指定存儲類別"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> 被忽略在中這個宣告"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%> 無法用於類型宣告"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "屬性忽略的於模板具現化"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "忽略屬性套用到類別型態 %qT 外側的定義"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "忽略屬性套用到附屬型態 %qT 而無需關聯的宣告"
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD 被初始化的 (使用 decltype 做為替代)"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D 宣告有 %<extern%> 並被初始化"
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "定義的 %q#D 被標記 %<dllimport%>"
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D 不是 %qT 的非靜態資料成員"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D 宣告為範本"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "無效的成員範本宣告 %qD"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ 不允許將 %<%T::%D%> 定義為 %<%T::%D%>"
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "ISO C++ 不允許成員 %qD 的初始化"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr "%qD 宣告 %<constexpr%> 外側它的類別"
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "出現在類別外的 %q#D 的宣告不是定義"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F 宣告為 %<static%> 卻從未定義過"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "變數 %q#D 有初始值設定，但是類型不完全"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "陣列 %q#D 的元素類型不完全"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "宣告的 %q#D 沒有任何初始設定式"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "聚合 %q#D 類型不完全，無法被定義"
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD 宣告為參照卻未被初始化"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, fuzzy, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "名稱已用於 GNU-style 指定的初始設定式用於陣列"
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "名稱 %qD 用在 GNU 風格的陣列指定元素初始值設定中"
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "不平凡的代理初始值設定不受支援"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初始值設定無法決定 %qD 的大小"
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD 缺少陣列大小"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "大小為 0 的陣列 %qD"
@@ -36194,829 +36237,829 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "貯藏大小的 %qD isn%'t 已知"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "貯藏大小的 %qD isn%'t 常數"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "抱歉：語意的內聯函式靜態資料 %q+#D 是錯誤的 (you%'ll 旋緊向上與多重份數)"
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  您可以解決方法這個由移除初始設定式"
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "未初始化的常數 %qD"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T 沒有任何 user-provided 預設建構函式"
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, fuzzy, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "建構子未被 user-provided 因為它是明確的缺席在中類別本體"
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr "和 implicitly-defined 建構子不初始化 %q+#D"
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "無效類型 %qT 做為類型為 %qT 的向量的初始化設定"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT 的初始化設定必須在大括號內"
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E]=%>已用於 GNU-style 指定的初始設定式用於類別 %qT"
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT 沒具名為 %qD 的非靜態資料成員"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 指示項 %qE 外側彙總初始設定式"
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT 的初始值設定項太多"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "類型 %qT 的標量初始化帶大括號"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT 的初始值設定周圍缺少大括號"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "元件的陣列 %q#T 有不完整型態"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "variable-sized 複合實字"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D 有不完整型態"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "純量物件 %qD 需求一個元件在中初始設定式"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "在中 C++98 %qD 必須被初始化的由建構子，無法由 %<{...}%>"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "陣列 %qD 被有括號的字面字串 %qE 所初始化"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "建構式中對靜態成員的初始化無效"
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "non-constant in-class 初始化無效的用於靜態成員 %qD"
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(需要一個類別外的初始化)"
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD 被初始化的以其本身"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "隱藏了早先的類型宣告 %q#D"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, fuzzy, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr "Java 物件 %qD 無法配置的與 %<new%>"
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr "非靜態資料成員 %qD 有 Java 類別型態"
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "函式 %q#D 像變數一樣被初始化"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解構式"
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始設定式失敗到決定大小的 %qT"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "陣列大小缺少的在中 %qT"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "zero-size 陣列 %qT"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的解構函式不能做為成員"
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的建構式不能做為成員"
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD 宣告的做為 %<virtual%> 變數"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> variable"
 msgstr "%qD 宣告的做為 %<inline%> 變數"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中變數宣告"
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD 宣告的做為 %<virtual%> 參數"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD 宣告的做為 %<inline%> 參數"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中參數宣告"
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD 宣告的做為 %<virtual%> 型態"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD 宣告的做為 %<inline%> 型態"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中類型宣告"
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD 宣告的做為 %<virtual%> 欄位"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD 宣告的做為 %<inline%> 欄位"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中欄位宣告"
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D 宣告時有異常指定"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD 的定義不在包含 %qT 的命名空間中"
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "靜態成員函式 %q#D 的宣告帶有類型限定符"
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "在夥伴宣告中定義明確特例化 %qD"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "在基本範本的宣告中對範本識別碼 %qD 的使用無效"
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "夥伴範本特例化 %qD 中不允許出現預設參數"
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> 不允許用於夥伴範本特例化 %qD 的宣告"
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> 不允許用於夥伴範本特例化 %qD 的宣告"
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "不能將 %<::main%> 宣告為一個範本"
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "不能將 %<::main%> 宣告為 inline"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "不能將 %<::main%> 宣告為 inline"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "不能將 %<::main%> 宣告為 static"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "實字運算子與 C 鏈結"
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD 有無效的引數清單"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr "整數字尾 %<%s%>帶陰影由實作"
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, fuzzy, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr "浮點數字尾 %<%s%>帶陰影由實作"
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD 必須是 non-member 函式"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> 必須回傳 %<int%>"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "隱含宣告的 %qD 的定義"
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "定義的 explicitly-defaulted %q+D"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, fuzzy, gcc-internal-format
 msgid "%q+#D explicitly defaulted here"
 msgstr "%q+#D 明確的缺席在此"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "成員函式 %q#D 未在類別 %qT 中宣告"
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "in-class 初始化的靜態資料成員 %q#D 的不完整型態"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> 所需自 in-class 初始化的靜態資料成員 %q#D 的 non-integral 型態"
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "in-class 初始化的靜態資料成員 %q#D 的 non-literal 型態"
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "類別中對具有非整數類型 %qT 的靜態資料成員的初始化無效"
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ 不允許在類別內初始化非常數靜態成員 %qD"
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ 不允許初始化成員常數 %qD，因為它有非整數的類型 %qT"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "陣列 %qD 的大小具有非整數類型 %qT"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "陣列 %qT 的大小的類型不是整數"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "陣列 %qD 的大小為負"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "陣列大小為負數"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C 不允許大小為 0 的陣列 %qD"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ 不允許大小為 0 的陣列"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++禁止變數長度陣列 %qD"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++禁止變數長度陣列"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, fuzzy, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "變數長度陣列 %qD 被使用"
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, fuzzy, gcc-internal-format
 msgid "variable length array is used"
 msgstr "變數長度陣列被使用"
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "陣列維數溢出"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "宣告的 %qD 做為陣列的虛值"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "建立陣列的虛值"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "宣告的 %qD 做為陣列的函式"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "建立陣列的函式"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "宣告的 %qD 做為陣列的參考"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "建立陣列的參考"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "宣告的 %qD 做為陣列的函式成員"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "建立陣列的函式成員"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多維陣列 %qD 的宣告必須至少指定除第一維以外所有維的大小"
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "宣告多維陣列必須至少指定除第一維以外所有維的大小"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "為建構式指定回傳值無效"
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "指定解構函式的回傳類型無效"
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "為 %<operator %T%> 指定了回傳值"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "無名變數或欄位宣告為 void"
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "變數或欄位宣告為 void"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "無效的使用的限定名稱 %<::%D%>"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "無效的使用的限定名稱 %<%T::%D%>"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "無效的使用的限定名稱 %<%D::%D%>"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T 並非類別或命名空間"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "%qD 未宣告為成員"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "缺少宣告識別碼：使用了保留字 %qD"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "函式定義不宣告參數"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "宣告的 %qD 做為 %<typedef%>"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "宣告的 %qD 做為參數"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> 無法出現在中 typedef 宣告"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs 的宣告指定了兩個以上的資料類型"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "衝突說明符在中宣告的 %qs"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支援單獨用 %<complex%> 表示 %<double complex%>"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ 不允許宣告無類型的 %qs"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int128%>未被支援由這個目標"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++不支援 %<__int128%>用於 %qs"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> 或 %<unsigned%>無效的用於 %qs"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> 和 %<unsigned%>指定的一起用於 %qs"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, fuzzy, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> 無效的用於 %qs"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, fuzzy, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> 無效的用於 %qs"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, fuzzy, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> 無效的用於 %qs"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> 或 %<short%>無效的用於 %qs"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, fuzzy, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>，%<int%>，%<short%>，或 %<char%>無效的用於 %qs"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> 或 %<short%>指定的與字元用於 %qs"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> 和 %<short%>指定的一起用於 %qs"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, fuzzy, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> 或 %<long%>無效的用於 %qs"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "為 %qs 使用 long、short、signed 或 unsigned 無效"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "對 %qs 而言無效的複數"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr "成員 %qD 不能既被宣告為虛函式，又被宣告為靜態函式"
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "參數宣告中出現的 typedef 宣告無效"
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "貯藏類別指定的用於模板參數 %qs"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "為參數宣告指定了無效的存儲類別"
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "參數無法宣告 %<constexpr%>"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> 外側類別宣告"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs 的宣告指定了多個存儲類別"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "為 %qs 指定了存儲類別"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "為參數 %qs 指定了存儲類別"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "巢狀函式 %qs 被宣告為 %<extern%>"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "在頂層將 %qs 宣告為 %<auto%>"
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "函式作用欄位的 %qs 隱含為 auto，卻被宣告為 %<__thread%>"
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "為夥伴函式宣告指定了無效的存儲類別"
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs 宣告為回傳一個函式的函式"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs 宣告為回傳一個陣列的函式"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs 函式使用 %<auto%> 型態說明符而無需尾隨傳回類型"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs 函式與尾隨傳回類型有 %qT 做為它的型態而非普通 %<auto%>"
@@ -37023,477 +37066,477 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs 函式與尾隨傳回類型無法宣告的與 %<auto%> 型態說明符"
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "解構函式不能是靜態成員函式"
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "建構式不能帶 cv 限定"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr "建構式不能被宣告為虛函式"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "夥伴宣告不在類別定義內"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, fuzzy, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "can%'t 定義朋友函式 %qs 在中區域類別定義"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "解構函式不能有參數"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "無法宣告參照 %q#T 的指標"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "無法宣告對 %q#T 的參照"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "無法宣告參照 %q#T 成員的指標"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "無法宣告參考到 %q#T, 該項並非 typedef 或模板型態引數"
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "範本識別碼 %qD 做為宣告"
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成員函式隱含地成為所屬類別的夥伴"
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多餘的限定 %<%T::%> 於成員 %qs 上"
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "無法定義成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "無法宣告成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "無法宣告成員 %<%T::%s%> 於 %qT 之內"
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "non-parameter %qs 無法參數包裝"
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "陣列 %qs 太大"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "資料成員不能具有可變類型 %qT"
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "參數不能具有可變類型 %qT"
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> 外側類別宣告"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> 用於空宣告中"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有建構式才能被宣告為 %<explicit%>"
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非物件成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函式 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "靜態 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "常數 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "參考 %qs 無法宣告 %<mutable%>"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef 宣告 %<auto%>"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, fuzzy, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名稱可能無法是 nested-name-specifier"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允許嵌類別的類型 %qD 與其所屬的類別同名"
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr "為夥伴類別宣告指定了類型限定"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "夥伴函式宣告中出現了 %<inline%>"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "範本參數不能是夥伴"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "夥伴宣告需要 class，即 %<friend class %T::%D%>"
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "夥伴宣告需要 class，即 %<friend %#T%>"
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "試圖讓 %qT 成為全域欄位的夥伴"
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成員函式類型上的限定符無效"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象宣告 %qT 做為宣告"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在參數宣告中使用 %<::%>"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> 不能用在此上下文中"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "參數宣告 %<auto%>"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared %<auto%>"
 msgstr "非靜態資料成員宣告 %<auto%>"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "錯誤地使用了 %<::%>"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "宣告的函式 %qD 在中無效的語境"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "聯合成員函式 %qD 被宣告為虛函式"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr "%qD 不能宣告為虛函式，因為它總是靜態的"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在解構函式 %qD 中的夥伴宣告需要限定名"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "預期的限定名稱在中朋友宣告用於建構子 %qD"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "原來的型態宣告的在此"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "欄位 %qD 類型不完全"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名稱 %qT 類型不完全"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE 既不是函式也不是成員函式；不能宣告為夥伴"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr "constexpr 靜態資料成員 %qD 必須有初始設定式"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<auto%> 無效"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<register%> 無效"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specifiers 在中 %qs 不允許外側類別定義"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<static%> 無效"
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<inline%> 無效"
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虛函式 %qs 不是類別成員"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs 定義的在中 non-class 範圍"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs 宣告的在中 non-class 範圍"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能將成員函式 %qD 宣告為有靜態連結"
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一個函式中宣告一個靜態函式"
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "與宣告不同，定義靜態資料成員時不能使用 %<static%>"
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "靜態成員 %qD 宣告為 %<register%>"
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能明確地將成員 %q#D 宣告為有外部連結"
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, fuzzy, gcc-internal-format
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "宣告的 constexpr 變數 %qD 並非定義"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs 已初始化，卻又被宣告為 %<extern%>"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs 既有 %<extern%> 又有初始值設定"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "預設引數 %qE 使用 %qD"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "預設引數 %qE 使用了局部變數 %qD"
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "參數 %qD 有 Java 類別型態"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "參數 %qD 被無效地被宣告為具有方法類型"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "參數 %qD 包含指標到陣列的不明約束 %qT"
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "參數 %qD 包含參考到陣列的不明約束 %qT"
@@ -37513,173 +37556,173 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "無效的建構式：您要的可能是 %<%T (const %T&)%>"
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD 不能在命名空間宣告"
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD 不能被宣告為靜態的"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD 必須是一個非靜態的成員函式"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD 必須是一個非靜態成員函式或非成員函式"
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD 的引數必須有類別或列舉類型"
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "轉換到參考到虛值將永不使用類型轉換運算子"
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "轉換到虛值將永不使用類型轉換運算子"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "轉換到參考到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, fuzzy, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "轉換到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "轉換到參考到基礎類別將永不使用類型轉換運算子"
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, fuzzy, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "轉換到基礎類別將永不使用類型轉換運算子"
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ 不允許多載 ?: 運算子"
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD 必須不有可變個數引數數量"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的參數"
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的第二個參數"
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr "%qD 必須帶 0 或 1 個引數"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr "%qD 必須帶 1 或 2 個引數"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "字首 %qD 應當回傳 %qT"
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "字尾 %qD 應當回傳 %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr "%qD 必須有 %<void%> 類型"
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr "%qD 帶且僅帶 1 個引數"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "%qD 帶且僅帶 2 個引數"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "使用者定義的 %qD 總是計算所有兩個參數"
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD 應當回傳值而非參照"
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD 不能有預設參數"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用範本類型參數 %qT，在 %qs 後"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "使用別名模板特殊化 %qT 之後 %qs"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名 %qD，在 %qs 後"
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD 有前一個宣告在此"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT 做為 %qs 被參照"
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "%q+T 先前在此處有過宣告"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT 做為列舉被參照"
@@ -37691,88 +37734,88 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> 需要範本參數"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD 與其宣告所在的類別同名"
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用列舉 %q#D 前沒有給出宣告"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT 重宣告為非範本"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "先前的宣告 %q+D"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "衍生聯合 %qT 無效"
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr "Java 類別 %qT 不能有多個基礎類別"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr "Java 類別 %qT 不能有虛基礎類別"
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基礎類別型 %qT 不是結構或類別"
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "遞迴的類型 %qT 未定義"
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複的基礎類別型 %qT 無效"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "範圍/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "前一個定義在此"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "下層的型態不匹配在中 enum %q#T"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "不同的下層的輸入 enum %q#T"
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, fuzzy, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr "下層的型態 %<%T%>的 %<%T%>必須是整數類資料類型"
@@ -37781,87 +37824,87 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "沒有一個整數類型可以表示 %qT 的所有列舉值"
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "列舉值值用於 %qD 不是整數常數"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "遞增的列舉值值太大用於 %<unsigned long%>"
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD 處列舉值溢出"
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr "列舉值值 %E 太大用於下層的型態 %<%T%>"
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, fuzzy, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr "傳回類型有 Java 類別型態 %q#T"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> 應當回傳一個對 %<*this%> 的參照"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "%q+D 先前沒有宣告過"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "無效的函式宣告"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "參數 %qD 被宣告為 void"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由於 %<volatile%>，函式回傳類型不相容"
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D set but not used"
 msgstr "參數 %q+D 設定並不是使用"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "無效的成員函式宣告"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD 已在類別 %qT 中定義過"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "型態的 %qD 預設值到 %<int%>"
@@ -37901,7 +37944,7 @@
 msgid "deleting %qT is undefined"
 msgstr "刪除 %qT 未定義"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D 宣告為範本"
@@ -37924,7 +37967,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "解構函式 %qD 被宣告為一個成員範本"
@@ -38015,27 +38058,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "寬度的 bit-field %qD 有 non-integral 型態 %qT"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, fuzzy, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD 並非靜態資料成員的類別模板"
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "匿名結構不在具名類型內"
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "命名空間欄位的匿名聚合必須是靜態的"
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "匿名聯合沒有成員"
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> 必須回傳 %qT"
@@ -38044,47 +38087,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, fuzzy, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "第一個參數的 %<operator new%> 無法有預設引數"
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> 的第一個參數類型為 %<size_t%> (%qT)"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> 必須回傳 %qT"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> 的第一個參數類型為 %qT"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT 宣告的與更大可視性比型態的它的欄位 %qD"
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT 宣告的與更大可視性比它的基底 %qT"
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using anonymous type, is used but never defined"
 msgstr "%q+#D, 宣告的使用匿名型態，被使用但是永不定義"
@@ -38093,48 +38136,48 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, fuzzy, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr "匿名型態不具任何鏈結用來宣告變數 %q#D 與鏈結"
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, fuzzy, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr "匿名型態不具任何鏈結用來宣告函式 %q#D 與鏈結"
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D 未指明非限定類型，所以它不做為外部連結"
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D, 宣告的使用本地型態 %qT，被使用但是永不定義"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "型態 %qT 不具任何鏈結用來宣告變數 %q#D 與鏈結"
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "型態 %qT 不具任何鏈結用來宣告函式 %q#D 與鏈結"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "使用了內聯函式 %q+D 但從未定義過"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "參數 %P (屬於 %q+#D)缺少預設引數"
@@ -38141,12 +38184,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, fuzzy, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr "轉換 lambda 該項使用 %<...%>到函式指標"
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用的刪除的函式 %qD"
@@ -38726,42 +38769,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "neither 解構式 nor class-specific 運算子刪除將被 called，即使它們被宣告時類別被定義"
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初始值設定在完成之前結束"
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr "不能用初始值設定項來初始化多維陣列"
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete 時陣列大小不明"
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "偵測到呼叫 delete 運算子時可能出現的問題："
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "neither 解構式 nor class-specific 運算子刪除將被 called，即使它們被宣告時類別被定義"
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, fuzzy, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr "刪除物件的抽象類別型態 %qT 該項有 non-virtual 解構式將造成未定義的行為"
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, fuzzy, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr "刪除物件的 polymorphic 類別型態 %qT 該項有 non-virtual 解構式也許造成未定義的行為"
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
@@ -38892,18 +38935,18 @@
 msgid "string literal in function template signature"
 msgstr "字串實字在中函式模板簽名"
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, fuzzy, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=6 (或=0) 避免這個錯誤與變更在中 mangling"
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "%qD 修飾後的名稱將在 GCC 的未來版本中有變化"
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
@@ -39319,7 +39362,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr "識別碼 %qE 是關鍵字在中 C++11"
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -39344,7 +39387,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "要求用於成員 %qE 在中 non-class 型態 %qT"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%>未被宣告"
@@ -39409,7 +39452,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(%qT 的定義末尾可能缺少一個分號)"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT 不是一個範本"
@@ -39434,7 +39477,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "浮點實字無法出現在中 constant-expression"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, fuzzy, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "演員陣容到型態不同於積分或列舉類型型態無法出現在中 constant-expression"
@@ -39703,7 +39746,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "實字運算子字尾無法前繼的由 %<_%>被保留的用於未來標準化"
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "預期 unqualified-id"
@@ -39880,7 +39923,7 @@
 msgid "capture of non-variable %qD "
 msgstr "擷取的 non-variable %qD "
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, fuzzy, gcc-internal-format
 msgid "%q+#D declared here"
 msgstr "%q+#D 宣告的在此"
@@ -39940,7 +39983,7 @@
 msgid "compound-statement in constexpr function"
 msgstr "複合陳述在中 constexpr 函式"
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "預期 selection-statement"
@@ -39970,7 +40013,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "不一致開始/結束類型在中 range-based %<for%> 敘述：%qT 和 %qT"
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "預期 iteration-statement"
@@ -40001,12 +40044,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允許執行時可知的 goto 目的"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "預期 jump-statement"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "多餘的 %<;%>"
@@ -40053,7 +40096,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "類別定義不能被宣告為夥伴"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, fuzzy, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
@@ -40144,12 +40187,12 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "關鍵字 %<export%> 未實作，將被忽略"
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "模板參數包裝 %qD 無法有預設引數"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "模板參數包裝無法有預設引數"
@@ -40164,7 +40207,7 @@
 msgid "expected template-id"
 msgstr "預期 template-id"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "預期 %<<%>"
@@ -40241,210 +40284,210 @@
 msgid "expected type specifier"
 msgstr "預期的型態說明符"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C 不允許前向參數宣告"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "預期 template-id 用於型態"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "預期 type-name"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, fuzzy, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr "elaborated-type-specifier 用於範圍的 enum 必須不使用 %<%D%>關鍵字"
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "宣告 %qD 不宣告任何事"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "屬性忽略的於 uninstantiated 型態"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "屬性忽略的於模板具現化"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "屬性忽略的於 elaborated-type-specifier 該並非前置宣告"
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD 是列舉類型模板"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an enumerator-name"
 msgstr "%qD 不是 enumerator-name"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "預期 %<;%>或 %<{%>"
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "無法加入列舉值清單到模板具現化"
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "宣告的 %qD 在中命名空間 %qD 該項不封閉 %qD"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qD 宣告出現在 %qD 中，而後者並不包含 %qD"
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T 多次定義"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C++禁止遞增 enum"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier 而無需名稱"
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier 必須使用簡單的識別碼"
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD 不是一個命名空間"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "預期 namespace-name"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> 定義未被允許在此"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "範本識別碼不允許出現在 using 宣告中"
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, fuzzy, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "存取宣告被不宜用在中 favour 的 using-declarations；建議：加入 %<using%> 關鍵字"
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "類型可能無法被定義在中別名模板宣告"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "function-definition 未被允許在此"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "函式定義中不允許出現 asm 指定"
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "函式定義中不允許有屬性"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, fuzzy, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "預期的建構子、解構式，或類型轉換"
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "預期的初始設定式"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "初始設定式提供的用於函式"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "括起的初始值設定後出現的屬性被忽略"
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "函式 %q+D 重宣告為內聯的"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "陣列邊界不是一個整數常數"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "無法定義成員的附屬 typedef %qT"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%>並非型態"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "將建構式做為範本用法無效"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "使用 %<%T::%D%> 而不是 %<%T::%D%> 來以限定名指定建構式"
@@ -40453,7 +40496,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "無效的宣告子"
@@ -40460,293 +40503,293 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "%q+D 在宣告前使用"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "預期的宣告子"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD 是一個命名空間"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "無法表單成員指標的 non-class %q#T"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "預期 ptr-operator"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "重製 virt-specifier"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%>"
 msgstr "無效的使用的 %<auto%>"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "類型可能無法被定義在中模板引數"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "無效的 non-type 模板引數"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "預期 type-specifier"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "預期 %<,%>或 %<...%>"
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "類型可能無法被定義在中參數類型"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr "為非函式指定預設參數的用法已過時"
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "預設參數只允許出現在函式參數中"
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "參數包裝 %qD 無法有預設引數"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "參數包裝無法有預設引數"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++不允許 C99 指定的初始設定式"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "預期 class-name"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "預期 %<;%>之後類別定義"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "預期 %<;%>之後結構定義"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "預期 %<;%>之後聯合定義"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "預期 %<{%>或 %<:%>"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "無法指定 %<override%> 用於類別"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "全域合格的類別名稱無效"
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "限定名稱不名稱類別"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD 的宣告中類別名無效"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "額外合格不允許"
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "明確特例化前必須有 %<template <>%>"
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "函式模板 %qD redeclared 做為類別模板"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "無法解析 typename 型態"
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr "%q+#T 的上一個定義"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "預期 class-key"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, fuzzy, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "在中 C++03 class-key 必須被使用時宣告朋友"
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "夥伴宣告沒有指定類別或函式名"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "函式定義上有 pure 指定"
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "預期 %<;%>於結束的成員宣告"
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "預期 %<;%>於結束的成員宣告"
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "無效的 pure 說明符 (只有 %<=0%>被允許)"
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "brace-enclosed 初始設定式未被允許在此"
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr "%<virtual%> 指定的一次以上在中 base-specified"
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, fuzzy, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr "超過一個存取說明符在中 base-specified"
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "關鍵字 %<typename%> 不允許用在此上下文中(基礎類別隱含地是一個類型)"
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "類型可能無法被定義在中 exception-specification"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, fuzzy, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr "動態異常規格被不宜用在中 C++0x; 使用 %<noexcept%> 做為替代"
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "類型可能無法被定義在中 exception-declarations"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "需要識別碼或 %<(%>"
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, fuzzy, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "專用化成員 %<%T::%E%>需求 %<模板<>%>語法specializing member %<%T::%E%> requires %<template<>%> syntax專用化成員 %<%T::%E%>需求 %<模板<>%>語法"
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無效的宣告的 %<%T::%E%>"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "範本參數表太少"
@@ -40755,538 +40798,538 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "範本參數表太多"
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "具名回傳值不再被支援"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "無效的宣告的成員模板在中區域類別"
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C 連結的範本"
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "無效的明確的特殊化"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "模板宣告的 %<typedef%>"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "明確的模板特殊化無法有貯藏類別"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%>應該是 %<>>%>在之內巢狀的模板引數清單"
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的 %<>>%>，使用 %<>%> 來結束範本引數清單"
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "無效的使用的 %qD 在中連繫規格"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>之前 %qD"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++1998 不支援 %<long long%>"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "宣告中同時使用了 %<short%> 和 %<char%>"
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重複的 %qE"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重複的 %qs"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "預期 %<new%>"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "預期 %<delete%>"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "預期 %<return%>"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "預期 %<extern%>"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "預期 %<static_assert%>"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "預期 %<decltype%>"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "預期 %<operator%>"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "預期 %<class%>"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "預期 %<template%>"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "預期 %<namespace%>"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "預期 %<using%>"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "預期 %<asm%>"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "預期 %<try%>"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "預期 %<catch%>"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "預期 %<throw%>"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "預期 %<__label__%>"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "預期 %<@try%>"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "預期 %<@synchronized%>"
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "預期 %<@throw%>"
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "預期 %<__transaction_atomic%>"
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "預期 %<__transaction_relaxed%>"
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "預期 %<::%>"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "預期 %<...%>"
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "預期 %<*%>"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "預期 %<~%>"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "預期 %<:%>或 %<::%>"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了 %qs 標記，在命名 %q#T 時"
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T 是在之前宣告的在此"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD 重宣告時有不同的可存取性"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "做為消歧義的 %<template%> 只能用於範本內"
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "檔案在預設參數處結束"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置錯誤的 %<@%D%> Objective-C++ 建構"
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> 必須指定一個類型做為引數"
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "無效的 Objective-C++ 選擇子名"
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "objective-c++ 方法宣告被預期"
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "方法屬性必須被指定的於結束"
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, fuzzy, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "零星的 %qs 介於 Objective-C++ 方法"
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "無效的型態舉例來說變數"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> 需要識別碼"
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, fuzzy, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "屬性可能無法被指定的之前 %<@%D%>Objective-C++ 關鍵字"
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "前綴屬性被忽略之前 %<@%D%>"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "無效的型態用於內容"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 msgid "expected positive integer expression"
 msgstr "預期的整數運算式"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "無效的初始值設定"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "parenthesized 初始化未被允許在中 OpenMP %<for%> 迴圈"
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "parenthesized 初始化未被允許在中 OpenMP %<for%> 迴圈"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代變數 %qD 不應為消除"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, fuzzy, gcc-internal-format
 msgid "not enough collapsed for loops"
 msgstr "不足崩潰的用於迴圈"
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "函式定義中不允許有屬性"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "無效的初始值設定"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "預期 id-expression"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在回傳類型中定義新類型"
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "垃圾於結束的 %<# pragma GCC pchpreprocess%(_P)>"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "運算元的約束無效"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "在 %C 處需要變數名"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "預期 %<,%>或 %<)%>"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "資料成員 %qD 不能是成員範本"
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "無效的成員範本宣告 %qD"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "明確特例化出現在非命名空間作用欄位 %qD 中"
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "所包含的類別範本並未被明確特例化"
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "在不同命名空間內對 %qD 的特例化"
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr "  從 %q+#D 的定義"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%qD 的明確實體化出現在命名空間 %qD 中，而後者並不包含命名空間 %qD"
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "名稱的類別陰影模板模板參數 %qD"
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "明確特例化非範本 %qT"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "%qT 的實體化在特例化之後"
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "在不同命名空間中特例化 %q#T"
@@ -41293,67 +41336,67 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "%qT 的實體化在 %qT 的特例化之後"
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "模板特殊化的 %qD 不允許由 ISO C++"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "%qD 的特例化在實體化之後"
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, fuzzy, gcc-internal-format
 msgid "candidate is: %#D"
 msgstr "備選為：%+#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, fuzzy, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %+#D"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD 不是一個函式範本"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD 並非變數"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "範本識別碼 %qD(屬於 %q+D)不匹配任何範本宣告"
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, fuzzy, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "發現 %d %<template<>%>，需要 %d 用於專用化成員函式模板"
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "有歧義的範本特例化 %qD (為 %q+D)"
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %D (should be %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -41360,59 +41403,59 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "範本識別碼 %qD 出現在基本範本的宣告中"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "明確初始化中出現了範本參數清單"
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "為明確實體化提供的定義"
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD 宣告時範本參數表太多"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD 宣告時範本參數表太少"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "%qD 的明確特例化必須由 %<template <>%> 引入"
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "函式範本部分特例化 %qD 是不允許的"
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "函式範本部分特例化 %qD 是不允許的"
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "明確特例化時指定了預設參數"
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD 不是一個範本函式"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, fuzzy, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "%qD 未被宣告在中 %qD"
@@ -41425,105 +41468,105 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "特例化了隱含宣告的特殊成員函式"
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "成員函式 %qD 未在 %qT 中宣告"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, fuzzy, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr "基底初始設定式擴展 %<%T%>不含任何參數包裝"
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr "擴展胚騰 %<%T%>不含任何引數包裝"
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr "擴展胚騰 %<%E%>不含任何引數包裝"
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, fuzzy, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "參數包裝無法展開的與 %<...%>："
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, fuzzy, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonymous>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "%q+#D 的宣告"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr " 隱藏了模版參數 %q+#D"
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "部分特例化中未用到範本參數："
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr "部分特例化 %qT 並未特例化任何範本參數"
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "參數包裝引數 %qE 必須是於結束的模板引數清單"
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "參數包裝引數 %qT 必須是於結束的模板引數清單"
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "範本引數 %qE 混雜了範本參數"
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "型態 %qT 的模板引數 %qE 依存於模板參數"
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "局部特化的 %qT 之後實體化的 %qT"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD 沒有預設參數"
@@ -41531,42 +41574,42 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "參數包裝 %qE 必須是於結束的模板參數清單"
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "預設模板引數可能無法被已用於函式模板朋友重新宣告"
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr "預設模板引數可能無法被已用於函式模板朋友宣告"
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "預設模板引數可能無法被已用於函式模板而無需 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "預設模板引數可能無法被已用於局部特化"
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "範本類別沒具名字"
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
@@ -41576,74 +41619,74 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD 範本宣告無效"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "對非範本 %q#D 的範本定義"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "需要 %d 級的 %q#D 範本參數，卻給出了 %d 級"
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "得到 %d 個範本參數，為 %q#D"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "得到 %d 個範本參數，為 %q#T"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  但實際需要 %d 個"
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "模板引數到 %qD 不匹配原來的模板 %qD"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, fuzzy, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr "使用模板<>用於明確的特殊化"
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT 不是一個範本類型"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD 的宣告中沒有 template 限定"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "redeclared 與 %d 模板參數"
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q+D used %d template parameter"
 msgid_plural "previous declaration %q+D used %d template parameters"
 msgstr[0] "前一個宣告 %q+D 使用 %d 模板參數"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "範本參數 %q+#D"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "在這裡又被宣告為 %q#D"
@@ -41652,273 +41695,273 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "重定義 %q#D 的預設參數"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "原來的定義出現的在此"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE 並非有效模板引數用於型態 %qT"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, fuzzy, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "它必須是位址的函式與外部連結"
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "它必須是位址的函式與外部連結"
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, fuzzy, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "它必須是成員指標的形式 %<&X::Y%>"
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "  無法 deduce 模板參數 %qD"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  類型 %qT 和 %qT 有不相容的 cv-qualifiers"
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  不匹配的類型 %qT 和 %qT"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  模板參數 %qD 並非參數包裝，但是引數 %qD 是"
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  模板引數 %qE 不匹配成員指標常數 %qE"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE 不是 equivalent 到 %qE"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  不一致參數包裝推導與 %qT 和 %qT"
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  deduced 衝突類型用於參數 %qT (%qT 和 %qT)"
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  deduced 衝突值用於 non-type 參數 %qE (%qE 和 %qE)"
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  成員函數型式 %qT 並非有效模板引數"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  candidate 預期 %d 引數，%d 提供"
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  無法轉換 %qE (型態 %qT) 輸入 %qT"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT 是模稜兩可的基礎類別的 %qT"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT 未被衍生自 %qT"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, fuzzy, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  模板參數的模板模板引數是不一致與其他 deduced 模板引數"
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "  無法 deduce 模板用於 %qT 從 non-template 型態 %qT"
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qD"
 msgstr "  模板引數 %qE 不匹配 %qD"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, fuzzy, gcc-internal-format
 msgid "  could not resolve address from overloaded function %qE"
 msgstr "  無法解析位址從多載化函式 %qE"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為字面字串不能用在此上下文中"
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT "
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD 並非有效模板引數因為 %qD 是變數，不是位址的變數"
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD 並非有效模板引數因為 %qD 是變數，不是位址的變數"
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qE 並非變數"
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為 cv 限定衝突"
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為它不是 lvalue"
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D 並非有效模板引數用於型態 %qT 因為參考變數沒有常數位址"
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為它不是物件與外部連結"
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為物件 %qD 沒有外部連結"
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它是一個指標"
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "嘗試使用 %qE 代替"
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它的類型是 %qT"
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "此上下文中不允許標準轉換"
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "injected-class-name %qD 使用的做為模板模板引數"
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "無效的使用的解構式 %qE 做為型態"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某個範本參數的類型成員時，請使用 %<typename %E%>"
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "引數 %d 的類型/值不匹配，在 %qD 的範本參數清單中"
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  需要一個 %qT 類型的常數，卻給出了 %qT"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  需要一個類別範本，卻給出了 %qE"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  需要一個類型，卻給出了 %qE"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  需要一個類型，卻給出了 %qT"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  需要一個類別範本，卻給出了 %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  預期的模板的型態 %qD，得到 %qT"
@@ -41925,78 +41968,78 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "型態不匹配在中 nontype 參數包裝"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr "不能將範本參數從 %qE 轉換到 %qT"
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "範本參數 %d 無效"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "提供給 %q+D"
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D 並非函式模板"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非範本類型 %qT 做為範本"
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "對於範本宣告 %q+D"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d (使用 -ftemplate-depth=到增加最大值) 替代 %qS"
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "不匹配的引數包裝長度當展開 %<%T%>"
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "不匹配的引數包裝長度當展開 %<%E%>"
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "重定義 %q#D 的預設參數"
@@ -42014,269 +42057,269 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "變數 %qD 有函數型式"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "無效的參數類型 %qT"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在宣告 %q+D 中"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函式回傳了一個陣列"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函式回傳了一個函式"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員函式指標"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成對 void 的參照"
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "表單指標到參考類型 %qT"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "表單參考到參考類型 %qT"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "產生參照類型 %qT 的成員指標"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "建立參照 void 類型的成員指標"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "產生 %qT 的陣列"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT 不是類別、結構或聯合類型"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT 被解析到非列舉類型 %qT"
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT 被解析到非類別類型 %qT"
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定型態 %qT 不匹配解構式名稱 ~%qT"
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依賴名 %qE 被解析為非類型，但實體化卻產生了一個類型"
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定類型，請使用 %<typename %E%>"
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用無效欄位 %qD"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "無效的使用的包裝擴展運算式"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用 %<...%>到展開引數包裝"
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被宣告在中這個範圍，而找不到任何宣告是由 argument-dependent 查找於點的實體化"
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "宣告在中附屬基底 %qT 找不到由資格不符的查找"
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用 %<this->%D%>做為替代"
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用 %<%T::%D%>做為替代"
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared here, later in the translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT 既不是類別也不是命名空間"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD 既不是類別也不是命名空間"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr "%qT 是/使用了匿名類型"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "模板引數用於 %qD 使用本地型態 %qT"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT 是一個可變類型"
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型運算式 %qE 不是常數"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  試圖實體化 %qD"
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD 並非靜態資料成員的類別模板"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "型態 %qT 用於明確的實體化 %qD 不匹配宣告的型態 %qT"
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "對 %q#D 的明確實體化"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "對 %q#D 重複的明確實體化"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++1998 禁止使用的 %<extern%> 於明確的實體化"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "為範本實體化化套用了存儲類型 %qD"
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "明確的實體化的 non-class 模板 %qD"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "明確實體化非範本類型 %qT"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T 的明確實體化出現在範本定義之前"
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允許在明確實體化時使用 %qE"
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "對 %q#T 重複的明確實體化"
@@ -42288,62 +42331,62 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "明確實體化 %qD 時沒有可用的定義"
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d 舉例說明 %q+D, 可能會從虛擬表格產生 (使用 -ftemplate-depth=到增加最大值)"
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T 並非有效型態用於模板 non-type 參數"
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, fuzzy, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "deducing 從 brace-enclosed 初始設定式清單需求 # 包含 <initializer_list>"
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "不一致類型 %qT 和 %qT deduced 用於 lambda 傳回類型"
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "不一致推導用於 %qT：%qT 然後 %qT"
@@ -42582,262 +42625,262 @@
 msgid "invalid base-class specification"
 msgstr "無效的基礎類別"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名聯合中出現保護成員 %q+#D"
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD 未被擷取"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, fuzzy, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "在包含函式中使用 %<auto%> 變數"
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "在包含函式中使用參數"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "範本參數 %qD(類型為 %qT)不允許出現在整數運算式中，因為它的類型不是整數或列舉"
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "命名空間 %qD 做為運算式"
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "將類別範本 %qT 做為運算式"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "在多繼承網格中對 %qD 的存取有歧義"
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD 不能出現在常數運算式中"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE 的類型不明"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT 不是列舉類型型態"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "參數包裝 __bases 只有有效在中模板宣告"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "無法套用 %<offsetof%> 到解構式 %<~%T%>"
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, fuzzy, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD 並非變數在中子句 %<firstprivate%>"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD 並非變數在中子句 %<lastprivate%>"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, fuzzy, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, fuzzy, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, fuzzy, gcc-internal-format
 msgid "%<num_teams%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "切片結束必須是整數"
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, fuzzy, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr "%qE 有參考類型用於 %qs"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD 不是檔案，命名空間或區塊範圍變數"
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE 指令無法在中 %qT 定義"
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, fuzzy, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "差異介於 %qE 和 %qD 沒有整數類型"
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "靜態假設失敗：%s"
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "non-constant 條件用於靜態假設"
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, fuzzy, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "引數到 decltype 必須是運算式"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype 無法解析位址的多載化函式"
@@ -42852,119 +42895,119 @@
 msgid "lambda-expression in a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "只能為 Java 類別定義套用 %qE 屬性"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr "%qE 已過時：g++ 的虛函式表現在預設與 COM 相容"
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "請求的 init_priority 不是一個整數常數"
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "只能將 %qE 屬性用於某個類別的物件的檔案作用欄位定義"
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "請求的 init_priority 越界"
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "請求的 init_priority 保留為內部使用"
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "%qE 屬性在此平臺上不受支援"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "與此處早先的宣告 %q+#D 衝突"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qD 屬性需要單一 NTBS 引數"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> 不是一個有效的宣告"
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> 不是一個有效的宣告"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE 屬性在不是類別的類型上被忽略"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE 屬性套用只有到函式"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%qE 屬性套用只有到函式"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "零做為空指標常數"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check：在 %s 中失敗，於 %s:%d"
@@ -43156,567 +43199,562 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr "陣列元素的對齊邊界比元素大小還要大"
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr "ISO C++ 不允許按下標存取非左值的陣列"
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "按下標存取宣告為 %<register%> 的陣列"
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "下標運算的左運算元既非陣列也非指標"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "使用 %qE 時缺少物件"
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ 不允許在程式裡呼叫 %<::main%>"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, fuzzy, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "必須使用 %<.*%>或 %<->*%> 到呼叫成員指標函式在中 %<%E (...)%>，例如： %<(...->* %E) (...)%>"
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "太多引數到建構子 %q#D"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "太少引數到建構子 %q#D"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "太多引數到成員函式 %q#D"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "太少引數到成員函式 %q#D"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "太多引數到函式 %q#D"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "太少引數到函式 %q#D"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "太多引數到方法 %q#D"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "太少引數到方法 %q#D"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "給予函式的引數太多"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "給予函式的引數太少"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "參數 %P (屬於 %qD)的類型 %qT 不完全"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "參數 %P 的類型 %qT 不完全"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "假定從多載函式轉換到類型 %qT"
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "算術運算式中使用了 NULL"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, fuzzy, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "左旋轉計數是負"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, fuzzy, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "右旋轉計數是負"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, fuzzy, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "左旋轉計數>=寬度的型態"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, fuzzy, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "右旋轉計數>=寬度的型態"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, fuzzy, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr "比較與字串實字結果於未指定的行為"
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "位址的 %qD 將永不是空值"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ 不允許比較指標和整數的值"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "沒具名為 %q#T 的類型，在%q#T 中 "
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "找不到介面用於類別 %qE"
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "非浮點引數間的無效比較"
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "運算元類型 %qT 和 %qT 對二進位 %qO 而言無效"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ 不允許在減法中使用類型為 %<void *%> 的指標"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ 不允許在減法中使用函式指標"
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ 不允許在減法中使用參照方法的指標"
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "在指標算術中使用參照不完全類型的指標無效"
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qE"
 msgstr "需位址的建構子 %qE"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qE"
 msgstr "需位址的解構式 %qE"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "用 %qE 形成成員函式指標的用法無效。"
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  需要一個限定的識別碼"
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parentheses 周圍 %qE 無法用來表單成員函式指標"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允許透過提取一個未限定的或帶括號的非靜態成員函式的位址來形成一個成員函式指標。請使用 %<&%T::%D%>"
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允許透過取已繫結的成員函式的位址來建構成員函式指標。請改用 %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "取臨時變數的位址"
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, fuzzy, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "需位址的 xvalue (rvalue 參考)"
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ 不允許取函式 %<::main%> 的位址"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr "ISO C++ 不允許取轉換到非左值運算式的位址"
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "不能建立參照參照成員 %qD 的指標"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++禁止遞增 enum"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++禁止遞減 enum"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "無法遞增指標到不完整型態 %qT"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "無法遞減指標到不完整型態 %qT"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++禁止遞增指標的型態 %qT"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++禁止遞減指標的型態 %qT"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "無效的使用的布林表示式做為運算元到 %<operator--%>"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "無法取右值運算式 %<this%> 的位址"
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "要求明確暫存器變數 %qD 的位址。"
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "請求宣告為 %<register%> 的 %qD 的位址"
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "list-initializer 用於 non-class 型態必須不被 parenthesized"
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "運算式清單視為複合式表示式在中初始設定式"
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "運算式清單視為複合式表示式在中 mem-initializer"
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "運算式清單視為複合式表示式在中 functional 演員陣容"
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s 運算式清單被看作複合運算式"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, fuzzy, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "沒有語境到解析型態的 %qE"
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "演員陣容從型態 %qT 輸入 %qT 演員陣容暫離限定元"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, fuzzy, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "staticcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpretcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %qT"
 msgstr "%qT 使用了局部類型 %qT"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 static_cast 無效"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "從 %qT 轉換到 %qT"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "從具有類型 %qT 的右值運算式到類型 %qT 中的轉換無效"
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr "從 %qT 到 %qT 的轉換損失精度"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "從 %qT 到 %qT 的轉換增大了目的類型的對齊需求"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ 不允許在函式指標和物件指標間進行轉換"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 的轉換無效"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "在類型 %qT 上使用 const_cast 無效，因為它既不是指標，也不是參照，也不是資料成員指標"
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "在類型 %qT 上使用 const_cast 無效，因為它是一個指標函式類型的指標或參照"
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 const_cast 無效"
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 const_cast 無效"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ 不允許轉換為陣列類型 %qT"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "向函式類型 %qT 的轉換無效"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  在求 %<%Q(%#T, %#T)%> 值時"
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "指派到陣列從初始設定式清單"
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "將 %qT 賦值給 %qT 時類型不相容"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "陣列使用的做為初始設定式"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "無效的陣列指派"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "  在成員函式指標轉換中"
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "成員指標轉換經由虛基礎類別 %qT"
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "  在成員指標轉換中"
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "到類型 %qT 的轉換無效，從類型 %qT"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "不能從 %qT 轉換到 %qT，為引數 %qP(屬於 %qD)"
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "無法轉換 %qT 到 %qT 在中預設引數"
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "無法轉換 %qT 到 %qT 在中引數傳遞"
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "無法轉換 %qT 到 %qT"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "無法轉換 %qT 到 %qT 在中回傳"
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "無法轉換 %qT 到 %qT 在中指派"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "參數 %qP 的 %qD 也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "參數也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "目標的轉換也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "目標的初始化也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "left-hand 側邊的指派也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "在傳遞引數 %P (屬於 %q+D)"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "回傳臨時變數的參照"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "回傳了一個非左值的參照"
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr "回傳了對局部變數的 %q+D 的參照"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %q+D returned"
 msgstr "回傳了局部變數的 %q+D 的位址"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr "回傳了局部變數的 %q+D 的位址"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "解構函式回傳值"
@@ -43723,45 +43761,45 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "不能從建構式的異常處理中回傳"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "建構式回傳值"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "在回傳 %qT 的函式中，回傳敘述不帶回傳值"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "<brace-enclosed initializer list>"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "在回傳「void」的函式中，回傳敘述帶回傳值"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> 不能回傳 NULL，除非它被宣告為 %<throw()%> (或 -fcheck-new 起作用)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, fuzzy, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "使用暫時的做為 lvalue"
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, fuzzy, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "使用 xvalue (rvalue 參考) 做為 lvalue"
@@ -43994,125 +44032,125 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr "narrowing 轉換的 %qE 從 %qT 到 %qT 內部 {} 被不當形式的在中 C++11"
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, fuzzy, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "narrowing 轉換的 %qE 從 %qT 到 %qT 內部 {}"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int 型陣列由非寬字串初始化"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, fuzzy, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-array 初始化的從不相容的 wide 字串"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "用以初始化字元陣列的字串太長"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "不可使用複合原文初始化類型為 %qT 的聚集"
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, fuzzy, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "陣列必須被初始化的與 brace-enclosed 初始設定式"
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的聯合中找不到欄位 %qD"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在聯合初始值設定中出現了索引值而不是欄位名"
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "偵測到循環指標代理"
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> 的基運算元具有非指標類型 %qT"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> 的結果給出了非指標的結果"
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> 的左運算元不是一個指標"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE 不能做為成員指標，因為它的類型為 %qT"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "無法套用成員指標 %qE 到 %qE，該項是的 non-class 型態 %qT"
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成員指標類型 %qT 與物件類型 %qT 不相容"
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "functional 演員陣容到陣列類型 %qT"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "無效的 value-initialization 的參考類型"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "呼叫的函式 %qD 會拋出不完全的類型 %q#T"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "呼叫的函式會拋出不完全的類型 %q#T"
@@ -44294,8 +44332,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, fuzzy, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr "Coarrays 已停用於 %C, 使用 -fcoarray=以啟用"
@@ -44432,7 +44470,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr "Fortran 2003:陣列建構子包含型態規格於 %C"
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Type-spec 於 %L 無法包含已推遲型態參數"
@@ -44554,7 +44592,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須為 INTEGER 或 PROCEDURE"
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -45171,12 +45209,12 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "「shape」內建函式的「source」引數在 %L 處不能是假定大小的陣列"
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 可能無法是程序"
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
@@ -45451,6 +45489,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須為 INTEGER 或 LOGICAL"
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -45458,7 +45501,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, fuzzy, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "最大值延伸等級達到的與型態『%s』於 %L"
@@ -45680,403 +45723,403 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "變數『%s』於 %C 與初始設定式已經出現在中資料敘述"
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "無法初始化 implied-shape 陣列於 %L 與純量"
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Non-constant 下限在中 implied-shape 宣告於 %L"
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "%C 處的元件必須有 POINTER 屬性"
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "陣列成分的結構於 %C 必須有明確的或已推遲形狀"
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "指標陣列成分的結構於 %C 必須有已推遲形狀"
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Allocatable 成分的結構於 %C 必須有已推遲形狀"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "陣列成分的結構於 %C 必須有明確的形狀"
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "%C 處的 NULL() 初始化有歧義"
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "%C 處的 NULL() 初始化有歧義"
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "%C 處對指標的初始化不允許出現在 PURE 程序中"
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "在中指標初始化於 %C 時發生錯誤"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Fortran 2008:non-NULL 指標初始化於 %C"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "Function name %qs not allowed at %C"
 msgstr "函式名「%s」不允許出現在 %C 處"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, fuzzy, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr "Non-PARAMETER 符號『%s』於 %L 無法 implied-shape"
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Fortran 2008:Implied-shape 陣列於 %L"
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "重製陣列 spec 用於 Cray 點於 %C"
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "擴充：%C 處舊式的初始化"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "無效的 value-initialization 的參考類型"
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%C 的初始化不是為指標變數準備的"
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "在 %C 處的指標初始化需要「=>」，而不是「=」"
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "%C 處需要一個初始化運算式"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "%C 處對變數的初始化不允許出現在 PURE 程序中"
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "初始化的 allocatable 成分於 %C 未被允許"
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "舊式的型態宣告 %s*%d 在 %C 處不被支援"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Nonstandard 類型宣告 %s*%d 於 %C"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "缺少右括號於 %C"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "%C 處需要初始化運算式"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "%C 處需要標量初始化運算式"
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Kind %d 不支援用於型態 %s 於 %C"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "C kind 型態參數是用於型態 %s 但是型態於 %L 是 %s"
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "缺少右括號或逗號於 %C"
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Kind %d 未被支援用於字元於 %C"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "%C 的 CHARACTER 宣告語法錯誤"
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "擴充：%C 處的 BYTE 類型"
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "%C 使用到的 BYTE 類型在目標平臺上不可"
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "By-value 引數於 %L 未被允許在中這個語境"
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "Fortran 2008:型態與 intrinsic-type-spec 於 %C"
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "延伸：雙倍複雜於 %C"
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "Fortran 2003:類別敘述於 %C"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "類型名「%s」(於 %C 處)有歧義"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "型態名稱『%s』於 %C 衝突與在之前宣告的實體於 %L, 該項有同名"
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "%C 處 IMPLICIT NONE 敘述重複"
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "缺少字元範圍在中隱含的於 %C"
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "%C 處 IMPLICIT 敘述中的字母必須按序排列"
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "%C 處 SAVE 敘述跟隨空白 SAVE 敘述"
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "匯入敘述於 %C 只有允許的在中介面內文"
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "預期具名的實體清單的於 %C"
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, fuzzy, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "無法匯入『%s』從主機範圍單位於 %C - 不存在。"
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, fuzzy, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "『%s』已經匯入的從主機範圍單位於 %C。"
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "語法時發生錯誤匯入敘述於 %C"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "缺少codimension 規格於 %C"
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "%C 處沒有指定維數"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "重複的 %s 屬性，位於 %L"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003:ALLOCATABLE 屬性於 %C 在中類型定義"
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "屬性於 %L 未被允許在中類型定義"
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003:屬性 %s 於 %L 在中類型定義"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s 屬性於 %L 未被允許外側的規格部分的模組"
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Fortran 2003:非同步屬性於 %C"
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Fortran 2008:CONTIGUOUS 屬性於 %C"
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "保護的於 %C 只有允許的在中規格部分的模組"
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003:保護的屬性於 %C"
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003:值屬性於 %C"
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003:易變的屬性於 %C"
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "多重識別碼提供的與單一名稱=說明符於 %C"
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, fuzzy, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "隱含地宣告的繫結©函式『%s』於 %L 可能無法是 C 可交流的"
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "變數『%s』在中共同區塊『%s』於 %L 可能無法是 C 可交流的 kind 雖然共同區塊『%s』是繫結©"
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, fuzzy, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "類型宣告『%s』於 %L 不是 C 可交流的但是它是繫結©"
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "變數『%s』於 %L 可能無法是 C 可交流的 kind 但是它是繫結©"
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "變數『%s』在中共同區塊『%s』於 %L 無法宣告的與繫結©自從它並非全域"
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "傳回類型的繫結©函式『%s』於 %L 無法陣列"
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "傳回類型的繫結©函式『%s』於 %L 無法字元串"
@@ -46083,807 +46126,812 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "符號『%s』於 %L 被標記私人的但是已被給定的繫結標貼『%s』"
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "需要還是實體或共同區塊名稱用於屬性規格敘述於 %C"
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "缺少實體或共同區塊名稱用於屬性規格敘述於 %C"
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "缺少數字"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "Fortran 2008:同步敘述於 %C"
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "衍生類型於 %C 未被在之前定義的和因而無法出現在中衍生類型定義"
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "%C 處資料宣告語法錯誤"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "Fortran 2008:IMPURE 程序於 %C"
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE 和 IMPURE 必須不出現兩者於 %C"
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "%C 處需要替代的回傳標籤"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "名稱「%s」(位於 %C)是一個程序的名稱"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "%C 處參數清單中有非預期的無用字元"
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "符號「%s」在 %C 處的參數清單中重複出現"
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "%C 處 RESULT 變數不能與函式同名"
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "%C 處的函式宣告後有非預期的無用字元"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008:繫結©屬性於 %L 可能無法被指定的用於內部程序"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "繫結©屬性於 %C 需求介面與繫結©"
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "繫結©程序與名稱可能無法有指標屬性於 %C"
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "虛設程序於 %C 可能無法有繫結©屬性與名稱"
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "程序『%s』於 %L 已經有基本型式的 %s"
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "語法時發生錯誤程序敘述於 %C"
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "預期『::』之後 binding-attributes 於 %C"
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS 或明確的介面必要項於 %C"
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Fortran 2003:程序指標成分於 %C"
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "語法時發生錯誤程序指標成分於 %C"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "程序於 %C 必須是在中通用介面"
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Fortran 2008:雙倍科郎在中模組程序敘述於 %L"
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003:程序敘述於 %C"
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "預期的形式引數清單在中函式定義於 %C"
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "繫結©屬性於 %L 只能使用用於變數或共同區塊"
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "%C 處的 ENTRY 敘述不能出現在 PROGRAM 中"
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 MODULE 中"
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "%C 處的 ENTRY 敘述不能出現在 BLOCK DATA 中"
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 INTERFACE 中"
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 DERIVED TYPE 區塊中"
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 IF-THEN 區塊中"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 DO 中"
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 SELECT 區塊中"
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 FORALL 區塊中"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 WHERE 區塊中"
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "%C 處的 ENTRY 敘述不能出現在巢狀的子程式中"
 
-#: fortran/decl.c:5597
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
-msgid "gfc_match_entry(): Bad state"
-msgstr "gfc_trans_code()：錯誤的敘述程式碼"
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Unexpected END statement at %C"
+msgid "Unexpected ENTRY statement at %C"
+msgstr "%C 處非預期的 END 敘述"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%C 處 ENTRY 敘述不能出現在被包含的程序中"
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "缺少必要項 parentheses 之前繫結©於 %C"
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "無效的 C 名稱在中名稱=說明符於 %C"
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "語法時發生錯誤名稱=說明符用於繫結標貼於 %C"
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "非同步=說明符於 %L 必須是初始化運算式"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "缺少關閉同位用於繫結標貼於 %C"
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "沒有繫結名稱被允許在中繫結©於 %C"
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "用於虛設程序 %s，沒有繫結名稱被允許在中繫結©於 %C"
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "名稱不允許於繫結©用於摘要介面於 %C"
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "%C 處非預期的 END 敘述"
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "Fortran 2008:結束敘述以代替 %s 敘述於 %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "需要 %s 敘述在 %L 處"
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "需要 %s 敘述，於 %C"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "需要塊名「%s」在「%s」運算式中，於 %C"
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "%C 處需要結束名"
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "需要標籤「%s」，為 %s 敘述，於 %C"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "缺少陣列規格於 %L 在中尺寸敘述"
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr "維度指定的用於 %s 於 %L 之後它的 initialisation"
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "缺少陣列規格於 %L 在中 CODIMENSION 敘述"
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "%L 處陣列指定必須延遲"
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "%C 處變數清單中有非預期的無用字元"
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "在 %C 處需要「(」"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "在 %C 處需要變數名"
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray 指標於 %C 必須是整數"
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray 指標於 %C 有 %d 位元組的精確度；記憶體位址需求 %d 位元組"
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "在 %C 處需要「,」"
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "在 %C 處需要「)」"
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "在 %C 處需要「,」或敘述尾"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "含義未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "可選的未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Cray 指標宣告於 %C 需求 -fcray-pointer 旗標"
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "Fortran 2008:CONTIGUOUS 敘述於 %C"
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "存取規格的 %s 運算子於 %C 已指定的"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "存取規格的.%s。運算子於 %C 已指定的"
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003:保護的敘述於 %C"
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "語法時發生錯誤保護的敘述於 %C"
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "私人的敘述於 %C 是只有允許的在中規格部分的模組"
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "公用的敘述於 %C 是只有允許的在中規格部分的模組"
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "預期的變數名稱於 %C 在中參數敘述"
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "%C 在 PARAMETER 敘述中需要 = 符號"
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "%C 在 PARAMETER 敘述中需要運算式"
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "初始化已經初始化的變數於 %C"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "%C 處 PARAMETER 敘述中有非預期的字元"
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Blanket 儲存敘述於 %C 追隨前一個儲存敘述"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "%C 處 SAVE 敘述跟隨空白 SAVE 敘述"
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "%C SAVE 敘述語法錯誤"
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "值未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003:值敘述於 %C"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "語法時發生錯誤值敘述於 %C"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003:易變的敘述於 %C"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, fuzzy, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "指定易變的用於 coarray 變數『%s』於 %C, 該項是 use-/ host-associated"
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "語法時發生錯誤易變的敘述於 %C"
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Fortran 2003:非同步敘述於 %C"
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "語法時發生錯誤非同步敘述於 %C"
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "模組程序於 %C 必須是在中通用模組介面"
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Intrinsic 程序於 %L 無法模組程序"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "模稜兩可的符號在中類型定義於 %C"
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "符號『%s』於 %C 已主機關聯的"
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, fuzzy, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "『%s』在中延伸運算式於 %C 並非衍生類型"
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "『%s』無法進階於 %C 因為它是繫結©"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "『%s』無法進階於 %C 因為它是序列型態"
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "衍生類型於 %C 只能是私人的在中規格部分的模組"
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "衍生類型於 %C 只能是公用的在中規格部分的模組"
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "摘要型態『%s』使用的於 %L"
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "%C 在 TYPE 定義中需要 ::"
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "類型「%s」(位於 %C)不能與內建類型同名"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "衍生類型名稱『%s』於 %C 已經有基本型式的 %s"
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "衍生類型定義的『%s』於 %C 已定義"
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray 點於 %C 無法假設的形狀陣列"
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003:ENUM 和列舉值於 %C"
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "%C 處：列舉量超過 C 整數類型"
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "列舉值 %L 無法初始化的與整數運算式"
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM 定義敘述預期的之前 %C"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "%C 處 ENUMERATOR 定義中語法錯誤"
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "重製 access-specifier 於 %C"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "繫結屬性已經指定傳遞，不合法的 NOPASS 於 %C"
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "繫結屬性已經指定傳遞，不合法的回合於 %C"
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "重製指標屬性於 %C"
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "重製 NON_OVERRIDABLE 於 %C"
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "重製已推遲於 %C"
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "預期 access-specifier 於 %C"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "預期的繫結屬性於 %C"
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE 和已推遲無法兩者出現於 %C"
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "指標屬性被必要項用於程序指標成分於 %C"
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, fuzzy, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Interface-name 預期的之後『(』於 %C"
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "『)』預期的於 %C"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "介面必須被指定的用於已推遲繫結於 %C"
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "程序 (介面) 於 %C 應該被宣告已推遲"
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "預期的繫結名稱於 %C"
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "Fortran 2008:程序清單於 %C"
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "『=>目標』無效用於已推遲繫結於 %C"
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, fuzzy, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "『::』所需的在中程序繫結與明確的目標於 %C"
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "預期的繫結目標之後『=>』於 %C"
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, fuzzy, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "型態『%s』包含已推遲繫結於 %C 不是摘要"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, fuzzy, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "已經有程序與繫結名稱『%s』用於衍生類型『%s』於 %C"
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "通用於 %C 必須是內部衍生類型含有"
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "預期『::』於 %C"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "預期的通用名稱或運算子描述元於 %C"
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Malformed GENERIC statement at %C"
+msgstr "%C IMPLICIT 敘述為空"
+
+#: fortran/decl.c:8526
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "預期『=>』於 %C"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, fuzzy, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "那裡『s 已經 non-generic 程序與繫結名稱 』%s『 用於衍生類型 』%s' 於 %C"
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, fuzzy, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "繫結於 %C 必須有相同存取做為已經定義的繫結『%s』"
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "預期的特定的繫結名稱於 %C"
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, fuzzy, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "『%s』已經定義為特定的繫結用於通用『%s』於 %C"
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "垃圾之後通用繫結於 %C"
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "最後的宣告於 %C 必須是內部衍生類型含有區段"
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "衍生類型宣告與最後的於 %C 必須是在中規格部分的模組"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "清空最後的於 %C"
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "預期的模組程序名稱於 %C"
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "在 %C 處需要「,」"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "不明程序名稱「%s」於 %C"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "『%s』於 %C 已經定義為最後的程序！"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "不明屬性在中！GCC $ 屬性敘述於 %C"
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "語法時發生錯誤！GCC $ 屬性敘述於 %C"
@@ -47175,343 +47223,343 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "不同的形狀用於 %s 於 %L 於尺寸 %d (%d 和 %d)"
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "『%s』於 %L 並非值"
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "賦值中有不相容的秩 %d 和 %d，位於 %L"
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "%L 處賦值中的變數類型是 UNKNOWN"
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "%L 處賦值右手邊出現 NULL"
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "%L 處賦值右手邊出現值為 POINTER 的函式"
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, fuzzy, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "延伸：BOZ 實字於 %L 用來初始化 non-integer 變數『%s』"
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "延伸：BOZ 實字於 %L 外側資料敘述和外側整數/真實/DBLE/CMPLX"
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, fuzzy, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "BOZ 實字於 %L 是逐位元已轉送 non-integer 符號『%s』"
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "算術欠位的逐位元已轉送 BOZ 於 %L.這個檢查可以已停用與選項 -fno-range-check"
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "算術溢位的逐位元已轉送 BOZ 於 %L.這個檢查可以已停用與選項 -fno-range-check"
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "算術 NaN 的逐位元已轉送 BOZ 於 %L.這個檢查可以已停用與選項 -fno-range-check"
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "變更的值在中轉換從  %s 到 %s 於 %L"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "可能的變更的值在中轉換從 %s 到 %s 於 %L"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Conversion from %qs to %qs at %L"
 msgstr "從 %s 轉換到 %s，位於 %L"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "不相容的類型在中資料敘述於 %L; 試圖的轉換的 %s 到 %s"
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "指標指派目標並非指標於 %L"
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, fuzzy, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "『%s』在中指標指派於 %L 無法 l-value 自從它是程序"
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "預期的邊界規格用於『%s』於 %L"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Fortran 2003:邊界規格用於『%s』在中指標指派於 %L"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr "下限必須都到位於 %L"
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Stride 必須不都到位於 %L"
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr "還是所有或沒有任何上限必須被指定的於 %L"
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "指標物件於 %L 不應該有 coindex"
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "無效的程序指標指派於 %L"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "敘述函式『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, fuzzy, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "摘要介面『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "敘述函式『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Nonintrinsic elemental 程序『%s』無效在中程序指標 assigment 於 %L"
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "不匹配在中程序指標指派於 %L:不匹配在中呼叫慣例"
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "NOPASS 或明確的介面必要項於 %C"
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "介面不匹配在中程序指標指派於 %L:%s"
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "不同的類型在中指標指派於 %L; 試圖的指派的 %s 到 %s"
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "不同的 kind 型態參數在中指標指派於 %L"
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "%L 處指標賦值時秩不同"
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "分級重新映射目標是小於大小的指標 (%ld<%ld) 於 %L"
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "分級重新映射目標必須是分級 1 或僅需 contiguous 於 %L"
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Fortran 2008:分級重新映射目標不是分級 1 於 %L"
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "指標指派目標是 neither 目標 nor 指標於 %L"
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "不當的目標在中指標指派在中 PURE 程序於 %L"
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "指標指派與向量註標於 rhs 於 %L"
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "指標指派目標有保護的屬性於 %L"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "資料目標於 %L 不應該有 coindex"
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "指標初始化目標於 %L 必須不是 ALLOCATABLE "
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "指標初始化目標於 %C 必須有目標屬性"
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "指標初始化目標於 %L 必須有儲存屬性"
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "程序指標初始化目標於 %L 可能無法是程序指標"
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008:指標函式在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Non-variable 運算式在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "具名的常數『%s』在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "『%s』在中變數定義語境 (%s) 於 %L 並非變數"
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non-POINTER 在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "虛引數『%s』與含義 (在中) 在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "虛引數『%s』與含義 (在中) 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "變數『%s』是保護的和無法出現在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "變數『%s』是保護的和無法出現在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "變數『%s』無法出現在中變數定義語境 (%s) 於 %L 在中 PURE 程序"
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到 vector-indexed 目標無法已用於變數定義語境 (%s)"
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到運算式無法已用於變數定義語境 (%s)"
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Associate-name『%s』無法出現在中變數定義語境 (%s) 於 %L 因為它的目標於 %L 無法，還是"
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到運算式無法已用於變數定義語境 (%s)"
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "無法開啟輸入檔案：%s"
@@ -47533,27 +47581,27 @@
 msgid "Removing call to function %qs at %L"
 msgstr "移除呼叫到函式『%s』於 %L"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, fuzzy, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "無效的運算元在中 gimple 比較"
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
@@ -47609,599 +47657,605 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr "%C 處需要「END INTERFACE ASSIGNMENT (=)」或敘述尾"
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, fuzzy, gcc-internal-format
+#| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr "需要「END INTERFACE ASSIGNMENT (.%s.)」在 %C 處"
+
+#: fortran/interface.c:353
+#, fuzzy, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr "預期『結束介面運算子 (%s)』於 %C, 但是得到 %s"
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr "需要「END INTERFACE ASSIGNMENT (.%s.)」在 %C 處"
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE %s' at %C"
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr "需要「END INTERFACE %s」於 %C 處"
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr "交替回傳無法出現在中運算子介面於 %L"
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr "指派運算子介面於 %L 必須有兩引數"
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr "運算子介面於 %L 有錯誤的引數數量"
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr "指派運算子介面於 %L 必須是副常式"
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr "指派運算子介面於 %L 必須不重新定義 INTRINSIC 型態指派"
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr "Intrinsic 運算子介面於 %L 必須是函式"
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr "第一個引數的定義的指派於 %L 必須是含義 (出) 或含義 (INOUT)"
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L 處定義賦值的第二個參數必須是 INTENT(IN)"
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第一個參數必須是 INTENT(IN)"
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第二個參數必須是 INTENT(IN)"
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr "運算子介面於 %L 衝突與 intrinsic 介面"
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr "程序『%s』在中 %s 於 %L 沒有任何明確的介面"
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr "程序「%s」(在 %s 中，位於 %L) 既不是函式也不是子處理序"
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr "在中 %s 於 %L 程序必須是還是所有副常式或所有函式"
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr "在中 %s 於 %L 程序必須是所有函式做為通用名稱也是名稱的衍生類型"
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
 msgstr "Fortran 2008:內部程序『%s』在中 %s 於 %L"
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, fuzzy, gcc-internal-format
 #| msgid "Ambiguous interfaces '%s' and '%s' in %s at %L"
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr "有歧義的介面「%s」和「%s」在 %s 中，位於 %L"
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, fuzzy, gcc-internal-format
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "雖然無法引用，『%s』有模稜兩可的介面於 %L"
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "『%s』於 %L 並非模組程序"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, fuzzy, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "分級不匹配在中引數『%s』於 %L (純量和 rank-%d)"
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "分級不匹配在中引數『%s』於 %L (rank-%d 和純量)"
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "分級不匹配在中引數『%s』於 %L (rank-%d 和 rank-%d)"
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "無效的程序引數於 %L"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "介面不匹配在中虛設程序『%s』於 %L:%s"
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "實際引數到 contiguous 指標虛設『%s』於 %L 必須是僅需 contigous"
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "型態不匹配在中引數『%s』於 %L; 傳遞 %s 到 %s"
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "實際引數到『%s』於 %L 必須有相同宣告的型態"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Corank 不匹配在中引數『%s』於 %L (%d 和 %d)"
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "實際引數到『%s』於 %L 必須是僅需 contiguous"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "實際引數到 non-INTENT (INOUT) 虛設『%s』於 %L, 該項是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "虛引數『%s』必須是指標或 assumed-shape 陣列而無需 CONTIGUOUS 屬性 - 做為實際引數於 %L 不是僅需 contiguous 和兩者是非同步或易變的"
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "傳遞 coarray 於 %L 到 allocatable、noncoarray，含義 (出) 虛引數『%s』"
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "傳遞 coarray 於 %L 到 allocatable，noncoarray 虛引數『%s』，該項無效如果配額狀態被已修改"
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Polymorphic 純量傳遞到陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr "元件的 assumed-shaped 或指標陣列傳遞到陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "延伸：純量 non-default-kind，non-C_CHAR-kind 字元實際引數與陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003:純量字元實際引數與陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "關鍵字引數『%s』於 %L 不是在中程序"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "關鍵字引數『%s』於 %L 已經關聯的與另外的實際引數"
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "更多實際的比形式引數在中程序呼叫於 %L"
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "缺少交替回傳 spec 在中副常式呼叫於 %L"
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr "未預期的交替回傳 spec 在中副常式呼叫於 %L"
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "未預期的空值() intrinsic 於 %L 到虛設『%s』"
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008:空指標於 %L 到 non-pointer 虛設『%s』"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "字元長度不匹配 (%ld/%ld) 介於實際引數和指標或 allocatable 虛引數『%s』於 %L"
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "字元長度不匹配 (%ld/%ld) 介於實際引數和 assumed-shape 虛引數『%s』於 %L"
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "實際引數於 %L 到 allocatable 或指標虛引數『%s』必須有已推遲長度型態參數如果和只有如果虛設有一個"
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "字元長度的實際引數短於的虛引數『%s』(%lu/%lu) 於 %L"
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "實際引數含有太少元件用於虛引數『%s』(%lu/%lu) 於 %L"
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "預期的程序指標用於引數『%s』於 %L"
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "預期的程序用於引數『%s』於 %L"
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "實際引數用於『%s』無法 assumed-size 陣列於 %L"
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "「%s」的引數在 %L 處必須是一個指標"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008:Non-pointer 實際引數於 %L 到指標虛設『%s』"
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Coindexed 實際引數於 %L 到指標虛設『%s』"
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Coindexed 實際引數於 %L 到 allocatable 虛設『%s』需求含義 (在中)"
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, fuzzy, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Coindexed 非同步或易變的實際引數於 %L 需求該虛設『%s』有 neither 非同步 nor 易變的"
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Coindexed 實際引數於 %L 與 allocatable ultimate 成分到虛設『%s』需求還是值或含義 (在中)"
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "實際的類別陣列引數用於『%s』必須是全部陣列於 %L"
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "實際引數用於『%s』必須是 ALLOCATABLE 於 %L"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Array-section 實際引數與向量註標於 %L 是不相容的與含義 (出)，含義 (INOUT)，易變的或非同步屬性的虛引數『%s』"
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Assumed-shape 實際引數於 %L 是不相容的與 non-assumed-shape 虛引數『%s』由於易變的屬性"
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Array-section 實際引數於 %L 是不相容的與 non-assumed-shape 虛引數『%s』由於易變的屬性"
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, fuzzy, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Pointer-array 實際引數於 %L 需求 assumed-shape 或 pointer-array 虛引數『%s』由於易變的屬性"
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "參數「%s」在 %L 處缺少引數"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, fuzzy, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "相同實際引數關聯的與含義 (%s) 引數『%s』和含義 (%s) 引數『%s』於 %L"
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "程序引數於 %L 是本地到 PURE 程序和有指標屬性"
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Coindexed 實際引數於 %L 在中 PURE 程序被傳遞到含義 (%s) 引數"
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Coindexed 實際引數於 %L 在中 PURE 程序被傳遞到指標虛引數"
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Coindexed polymorphic 實際引數於 %L 被傳遞 polymorphic 虛引數『%s』"
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "程序『%s』called 於 %L 不是明確的宣告"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "呼叫程序「%s」帶隱含介面，位於 %L"
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "指標物件『%s』於 %L 必須有明確的函式介面或被宣告做為陣列"
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "allocatable 物件『%s』於 %L 必須有明確的函式介面或被宣告做為陣列"
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Allocatable 函式『%s』於 %L 必須有明確的函式介面"
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "關鍵字引數需求明確的介面用於程序『%s』於 %L"
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "符號「%s」在 %L 處已經有了明確介面"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "實際引數的 LOCK_TYPE 或與 LOCK_TYPE 成分於 %L 需求明確的介面用於程序『%s』"
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "鑄型引數到空值必要項於 %L"
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "關鍵字引數需求明確的介面用於程序『%s』於 %L"
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "程序指標成分『%s』called 與隱含的介面於 %L"
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "關鍵字引數需求明確的介面用於程序指標成分『%s』於 %L"
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "鑄型=必要項在中空值() 引數於 %L:模稜兩可介於特定的函式 %s 和 %s"
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "%q+D 別名到未定義的符號 %qE"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "實體『%s』於 %C 已經呈現在中介面"
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, fuzzy, gcc-internal-format
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr "無法覆寫通用『%s』於 %L"
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "『%s』於 %L 強制變更程序繫結宣告 NON_OVERRIDABLE"
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "『%s』於 %L 必須不是已推遲做為它強制變更 non-DEFERRED 繫結"
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "『%s』於 %L 強制變更 PURE 程序且須也是 PURE"
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "『%s』於 %L 強制變更 ELEMENTAL 程序且須也是 ELEMENTAL"
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "『%s』於 %L 強制變更 non-ELEMENTAL 程序且須無法是 ELEMENTAL，還是"
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "『%s』於 %L 強制變更副常式且須也是副常式"
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "『%s』於 %L 強制變更函式且須也是函式"
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "引數不匹配用於強迫程序『%s』於 %L:%s"
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "『%s』於 %L 強制變更公用的程序且須無法是私人的"
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "虛引數『%s』的『%s』於 %L 應該被具名的『%s』做為到匹配相應引數的 overridden 程序"
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "引數不匹配用於強迫程序『%s』於 %L:%s"
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "『%s』於 %L 必須有相同形式引數數量做為 overridden 程序"
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "『%s』於 %L 強制變更 NOPASS 繫結且須也是 NOPASS"
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "『%s』於 %L 強制變更繫結與回合且須也是回合"
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須是於相同位置做為 passed-object 虛引數的 overridden 程序"
@@ -48620,12 +48674,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:非同步=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:空白=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:十進位=於 %C 不允許在中 Fortran 95"
@@ -48635,7 +48689,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:編碼=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:四捨五入=於 %C 不允許在中 Fortran 95"
@@ -48660,781 +48714,781 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "單元號碼在中關閉敘述於 %L 必須是 non-negative"
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s 敘述不允許在中 PURE 程序於 %C"
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "單元號碼在中敘述於 %L 必須是 non-negative"
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "Fortran 2003：%C 處的 FLUSH 敘述"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "%C 處重複的 UNIT 指定"
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "%C 處重複的格式指定"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "符號「%s」在名稱清單「%s」是 INTENT(IN)，位於 %C"
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "%C 處重複的 NML 指定"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "符號『%s』於 %C 必須是名稱表列群組名稱"
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "%C 處的 END 標記不允許出現在輸出敘述中"
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "單位尚未指定於 %L"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "%L 處指定的 UNIT 必須是 INTEGER 運算式或一個 CHARACTER 變數"
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "無效的表單的寫入敘述於 %L, 單位必要項"
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "內部單位與向量註標於 %L"
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "%L 處外部 IO UNIT 不能是陣列"
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr "名稱表列『%s』在中讀取敘述於 %L 含有符號『%s』該項可能無法出現在中變數定義語境"
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "延伸：逗號之前 i/o 項目清單於 %L"
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR 標記標籤 %d 在 %L 處未定義"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END 標記標籤 %d 在 %L 處未定義"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR 標記標籤 %d 在 %L 處未定義"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT 標籤 %d 在 %L 處未定義"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "%C 處 I/O 迭代語法錯誤"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "%C READ 敘述需要變數"
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "需要 %s 敘述，於 %C 處"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s 敘述在 %C 處語法錯誤"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr "Fortran 2003:內部檔案於 %L 與名稱表列"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "非同步=說明符於 %L 必須是初始化運算式"
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:填充=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:DELIM=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "%C 處的 PRINT 名稱清單是一個擴充"
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "%C 處 I/O 清單中需要逗號"
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "%C 處的 PRINT 敘述不允許出現在 PURE 程序中"
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE 敘述不允許出現在 %C 處的 PURE 程序中"
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENGTH 標籤無效的在中查詢敘述於 %C"
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "查詢敘述於 %L 無法包含兩者檔案和單位說明符"
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "%L 處的 INQUIRE 敘述需要 FILE 或 UNIT 限定符"
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr "單元號碼在中敘述於 %L 必須是 non-negative"
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "查詢敘述於 %L 需要擱置=說明符與識別號=說明符"
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:等待於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "等待敘述不允許在中 PURE 程序於 %C"
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_op2string(): Bad code"
 msgstr "gfc_trans_code()：錯誤的敘述程式碼"
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "缺少『)』在中敘述於或之前 %L"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "缺少『(』在中敘述於或之前 %L"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr "%C 處整數太大"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "%C 處的敘述標籤太多位數"
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr "%C 處敘述標籤為零"
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 #| msgid "Label name '%s' at %C is ambiguous"
 msgid "Label name %qs at %C is ambiguous"
 msgstr "標籤名「%s」在 %C 處有歧義"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Duplicate construct label %qs at %C"
 msgstr "重複的建構標籤「%s」出現在 %C 處"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr "無效字元在中名稱於 %C"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr "%C 的名稱太長"
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, fuzzy, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr "無效字元『$』於 %C.使用 -fdollar-ok 到允許它做為延伸"
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr "迴圈變數於 %C 無法 coarray"
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr "迴圈變數於 %C 無法 sub-component"
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr "預期的步驟值在中迭代器於 %C"
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr "%C 處迭代語法錯誤"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_match(): Bad match code %c"
 msgstr "gfc_trans_code()：錯誤的敘述程式碼"
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr "%C 處 PROGRAM 敘述格式無效"
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %C"
 msgstr "Obsolescent 特徵：算術如果敘述於 %C"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr "%C 處 IF 運算式語法錯誤"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr "區塊標貼無法適當用於算術如果敘述於 %C"
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr "區塊標貼不是適當用於如果敘述於 %C"
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr "無法指派到具名的常數於 %C"
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr "%C 處 IF 子句中有無法歸類別的敘述"
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr "%C 處 IF 敘述語法錯誤"
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr "%C 處 ELSE 敘述後有非預期的無用字元"
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "標貼『%s』於 %C 不匹配如果標貼『%s』"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr "未預期的垃圾之後不然就如果敘述於 %C"
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr "影像控制敘述重要於 %C 在中 PURE 程序"
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr "影像控制敘述重要於 %C 在中做共時區塊"
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
 msgstr "Fortran 2008:重要敘述於 %C"
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr "巢狀的重要區塊於 %C"
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr "預期的關聯清單於 %C"
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr "預期的關聯於 %C"
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in association at %C"
 msgstr "重製名稱『%s』在中關聯於 %C"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, fuzzy, gcc-internal-format
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "預期『)』或『，』於 %C"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr "垃圾之後關聯敘述於 %C"
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "衍生類型『%s』於 %L 可能無法是摘要"
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "無效的 type-spec 於 %C"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "%C 處 FORALL 迭代語法錯誤"
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr "Fortran 2008:做共時建構於 %C"
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "名稱『%s』在中 %s 敘述於 %C 為未知"
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "名稱『%s』在中 %s 敘述於 %C 並非建構名稱"
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "%s 敘述於 %C 樹葉重要建構"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "%s 敘述於 %C 樹葉做共時建構"
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "%s 敘述於 %C 不是在之內建構"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "%s 敘述於 %C 不是在之內建構『%s』"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, fuzzy, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "週期敘述於 %C 不是適用的到 non-loop 建構『%s』"
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "Fortran 2008:離開敘述不具任何 do-construct-name 於 %C"
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "%s 敘述於 %C 不是適用的到建構『%s』"
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "%s 敘述於 %C 離開 OpenMP 結構化訊息塊"
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "離開敘述於 %C 終止 !$OMP 做迴圈"
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "週期敘述於 %C 到 non-innermost 崩潰 !$OMP 做迴圈"
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "離開敘述於 %C 終止 !$OMP 做迴圈"
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "週期敘述於 %C 到 non-innermost 崩潰 !$OMP 做迴圈"
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr "影像控制敘述 %s 於 %C 在中 PURE 程序"
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr "影像控制敘述停止於 %C 在中重要區塊"
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "影像控制敘述停止於 %C 在中做共時區塊"
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "停止編碼於 %L 必須是還是整數或字元型式"
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "停止編碼於 %L 必須是純量"
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr "停止編碼於 %L 必須是預設字元 KIND=%d"
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "停止編碼於 %L 必須是預設整數 KIND=%d"
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "%C 處非預期的 CASE 敘述"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "Fortran 2008:錯誤停止敘述於 %C"
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "影像控制敘述 %s 於 %C 在中 PURE 程序"
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "影像控制敘述 %s 於 %C 在中重要區塊"
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "影像控制敘述 %s 於 %C 在中做共時區塊"
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr "冗餘 STAT 標籤找到於 %L "
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr "冗餘 ERRMSG 標籤找到於 %L "
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr "冗餘 ACQUIRED_LOCK 標籤找到於 %L "
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "Fortran 2008:鎖定敘述於 %C"
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "Fortran 2008:解除鎖定敘述於 %C"
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "影像控制敘述同步於 %C 在中 PURE 程序"
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "Fortran 2008:同步敘述於 %C"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr "影像控制敘述同步於 %C 在中重要區塊"
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "影像控制敘述同步於 %C 在中做共時區塊"
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "刪除的特徵：指派敘述於 %C"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "刪除的特徵：指派的前往敘述於 %C"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "敘述標貼清單在中前往於 %C 不可為空"
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "Obsolescent 特徵：計算的前往於 %C"
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "在中 type-spec 於 %L 時發生錯誤"
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr "Fortran 2003:typespec 在中配置於 %L"
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "不當的 allocate-object 於 %C 用於 PURE 程序"
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "配置的 coarray 於 %C 在中做共時區塊"
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr "配置的 coarray 於 %C 在中重要區塊"
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "Allocate-object 於 %L 並非 nonprocedure 指標或 allocatable 變數"
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "型態的實體於 %L 是型態不相容的與 typespec"
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr "Kind 型態參數用於實體於 %L 不同從 kind 型態參數的 typespec"
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "形狀規格用於 allocatable 純量於 %C"
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "Fortran 2003:ERRMSG 標籤於 %L"
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "Fortran 2003:來源標籤於 %L"
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr "冗餘來源標籤找到於 %L "
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr "來源標籤於 %L 衝突與 typespec 於 %L"
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr "Fortran 2008:來源標籤於 %L 與超過單一配置物件"
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "Fortran 2008:鑄型標籤於 %L"
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr "冗餘鑄型標籤找到於 %L "
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr "鑄型標籤於 %L 衝突與 typespec 於 %L"
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "鑄型標籤於 %L 衝突與來源標籤於 %L"
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Allocate-object 於 %L 與已推遲型態參數需求還是 type-spec 或來源標籤或鑄型標籤"
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Allocate-object 於 %L 與已推遲型態參數需求還是 type-spec 或來源標籤或鑄型標籤"
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "指標物件於 %C 不應該被 coindexed"
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "不合法的 allocate-object 於 %C 用於 PURE 程序"
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "取消配置的 coarray 於 %C 在中做共時區塊"
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr "取消配置的 coarray 於 %C 在中重要區塊"
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "Allocate-object 於 %C 並非 nonprocedure 指標或 allocatable 變數"
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "Fortran 2003:ERRMSG 於 %L"
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr "影像控制敘述回傳於 %C 在中重要區塊"
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "影像控制敘述回傳於 %C 在中做共時區塊"
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "%C 處的替代 RETURN 敘述只允許出現在 SUBROUTINE 中"
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr "延伸：回傳敘述在中主要程式於 %C"
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "預期的成分參考於 %C"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "垃圾之後呼叫於 %C"
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "預期 type-bound 程序或程序指標成分於 %C"
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "%C 處公共塊名語法錯誤"
@@ -49442,147 +49496,147 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr "變數『%s』於 %L 在中共同區塊『%s』於 %C 必須被宣告與 C 可交流的 kind 自從共同區塊『%s』是繫結©"
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr "變數『%s』在中共同區塊『%s』於 %C 無法繫結©自從它不是全域"
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "符號『%s』於 %C 已經在中共同區塊"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, fuzzy, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "初始化的符號『%s』於 %C 只能是共同在中區塊資料"
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, fuzzy, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "陣列規格用於符號『%s』在中共同於 %C 必須是明確的"
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "符號『%s』在中共同於 %C 無法指標陣列"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "符號『%s』，在中共同區塊『%s』於 %C 正在是間接等價到另外的共同區塊『%s』"
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, fuzzy, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "名稱表列群組名稱『%s』於 %C 已經有基本型式的 %s"
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, fuzzy, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "名稱表列群組名稱『%s』於 %C 已經是使用關聯的和無法 respecified。"
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "假設的大小陣列『%s』在中名稱表列『%s』於 %C 未被允許"
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "衍生類型成分 %C 並非允許的等價成員"
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "陣列參照在中等價於 %C 無法陣列區段"
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "等價於 %C 需求兩個以上物件"
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "試圖到間接重疊共同區塊 %s 和 %s 由等價於 %C"
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "預期逗號在中等價於 %C"
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "%L 處的敘述函式是遞迴的"
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "%L 處的敘述函式是遞迴的"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "%C 處 CASE 中需要初始化運算式"
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, fuzzy, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "預期的區塊名稱『%s』的選取建構於 %C"
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "語法時發生錯誤保護的敘述於 %C"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "選擇器在中選取型態於 %C 並非具名的變數；使用 associate-name=>"
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "%C 處非預期的 CASE 敘述"
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "語法時發生錯誤大小寫規格於 %C"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "未預期的型態是敘述於 %C"
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "語法時發生錯誤型態是規格於 %C"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "語法時發生錯誤類別是規格於 %C"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "其他情況下敘述於 %C 無法夾於位置區塊"
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "標貼『%s』於 %C 不匹配位置標貼『%s』"
@@ -49733,171 +49787,171 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "名稱表列 %s 無法重新命名的由使用關聯到 %s"
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, fuzzy, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "『%s』的模組『%s』，匯入的於 %C, 也是名稱的目前的程式單元"
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "符號『%s』引用於 %L 找不到在中模組『%s』"
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, fuzzy, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "使用者運算子『%s』引用於 %L 找不到在中模組『%s』"
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Intrinsic 運算子『%s』引用於 %L 找不到在中模組『%s』"
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "無法開啟模組檔案「%s」寫入，在 %C 處：%s"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "寫入模組檔案「%s」時發生錯誤：%s"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "無法刪除模組檔案『%s』：%s"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "無法重新命名模組檔案『%s』到『%s』：%s"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "無法刪除暫時的模組檔案『%s』：%s"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "符號『%s』已經宣告"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, fuzzy, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "符號『%s』，引用於 %L, 不是在中已選標準"
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "符號『%s』引用於 %L 找不到在中 intrinsic 模組 ISO_C_BINDING"
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, fuzzy, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "使用的 intrinsic 模組『%s』於 %C 衝突與非內建模組名稱使用的在之前"
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, fuzzy, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "使用的 NUMERIC_STORAGE_SIZE 具名的常數從 intrinsic 模組 ISO_FORTRAN_ENV 於 %L 是不相容的與選項 %s"
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "使用的 NUMERIC_STORAGE_SIZE 具名的常數從 intrinsic 模組 ISO_FORTRAN_ENV 於 %C 是不相容的與選項 %s"
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "符號『%s』引用於 %L 找不到在中 intrinsic 模組 ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "%C 處非預期的 CASE 敘述"
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003:ISO_FORTRAN_ENV intrinsic 模組於 %C"
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003:ISO_C_BINDING 模組於 %C"
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, fuzzy, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "找不到 intrinsic 模組具名的『%s』於 %C"
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "Fortran 2003:「使用::模組」於 %C"
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "Fortran 2003:ISO_C_BINDING 模組於 %C"
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "Fortran 2003:ISO_C_BINDING 模組於 %C"
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "無法開啟模組檔案「%s」讀取，在 %C 處：%s"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, fuzzy, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "使用的非內建模組『%s』於 %C 衝突與 intrinsic 模組名稱使用的在之前"
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, fuzzy, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "檔案『%s』開啟的於 %C 並非 GFORTRAN 模組檔案"
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, fuzzy, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr "無法使用相同模組我們正在建立！"
@@ -50194,7 +50248,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "如果子句於 %L 需要純量邏輯的運算式"
@@ -50896,371 +50950,365 @@
 msgid "Unexpected %s statement at %C"
 msgstr "非預期的 %s 敘述於 %C 處"
 
-#: fortran/parse.c:2428
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected %s statement in MODULE at %C"
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr "非預期的 %s 敘述出現在 %C 處的 MODULE 中"
-
-#: fortran/parse.c:2439
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "%s 敘述在 %C 處不能跟隨 %s 敘述在 %L 處"
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "「%s」中非預期的檔案結尾"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "衍生類型『%s』與序列必須不有含有區段於 %C"
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "衍生類型『%s』與繫結©必須不有含有區段於 %C"
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "成分在中型態於 %C 必須前繼含有"
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "Fortran 2003: Type-bound 程序於 %C"
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "垃圾之後通用繫結於 %C"
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "Fortran 2003: 最後的程序宣告於 %C"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Fortran 2008:衍生類型定義於 %C 與清空含有區段"
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "私人的敘述在中型態於 %C 必須是內部模組"
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "私人的敘述於 %C 必須前繼程序繫結"
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "%C 處重複的 PRIVATE 敘述"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "序列敘述於 %C 必須前繼含有"
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "已經內部含有區塊於 %C"
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "最後的宣告於 %C 必須是內部含有"
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr "Fortran 2003:衍生類型定義於 %C 而無需成分"
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "私人的敘述於 %C 必須前繼結構成分"
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "序列敘述於 %C 必須前繼結構成分"
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "序列屬性於 %C 已經指定的在中型態敘述"
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "%C 處重複的 SEQUENCE 敘述"
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr "Fortran 2003: 含有區塊在中衍生類型定義於 %C"
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "成分 %s 於 %L 的型態 LOCK_TYPE 必須有 codimension 或是 subcomponent 的 coarray，該項不是可能的做為成分有指標屬性"
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "指標成分 %s 於 %L 有 noncoarray subcomponent 的型態 LOCK_TYPE，該項必須有 codimension 或是 subcomponent 的 coarray"
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "Allocatable 成分 %s 於 %L 的型態 LOCK_TYPE 必須有 codimension"
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr "Allocatable 成分 %s 於 %L 必須有 codimension 做為它有 noncoarray subcomponent 的型態 LOCK_TYPE"
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "Noncoarray 成分 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須有 codimension 或是 subcomponent 的 coarray。(變數的型態 %s 可能無法有 codimension 做為已經 coarray subcomponent 存在)"
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "Noncoarray 成分 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須有 codimension 或是 subcomponent 的 coarray。(變數的型態 %s 可能無法有 codimension 做為 %s 於 %L 有 codimension 或 coarray subcomponent)"
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "ENUM 宣告於 %C 沒有任何列舉值"
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "非預期的 %s 敘述出現在 %C 處的 INTERFACE 區塊中"
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, fuzzy, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "名稱『%s』的摘要介面於 %C 無法如同 intrinsic 型態"
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "非預期的 %s 敘述出現在 %C 處的 INTERFACE 體中"
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, fuzzy, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "介面程序『%s』於 %L 有同名做為封閉程序"
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "%s 敘述未被允許內部的區塊於 %C"
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "%s 敘述未被允許內部的區塊於 %C"
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "%s 敘述必須出現在 MODULE 中"
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "%s 敘述於 %C 追隨另外的輔助工具規格"
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "不當的 kind 運算式用於函式『%s』於 %L"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, fuzzy, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "型態用於函式『%s』於 %L 不是可存取"
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "其他情況下敘述於 %C 追隨前一個取消遮罩的其他情況下"
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "非預期的 %s 敘述出現在 %C 處的 WHERE 區塊中"
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "非預期的 %s 敘述出現在 %C 處的 FORALL 區塊中"
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "%C 處的 ELSE IF 敘述不能出現在 %L 處的 ELSE 敘述之後"
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "%L 和 %C 處重複的 ELSE 敘述"
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "預期的大小寫或結束選取敘述下列選取大小寫於 %C"
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "預期的型態是，類別是或結束選取敘述下列選取型態於 %C"
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "結束的 nonblock 做敘述於 %C 是在之內另外的區塊"
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "結束的 nonblock 做敘述於 %C 被 interwoven 與另外的做迴圈"
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr "Fortran 2003: 含有區塊在中衍生類型定義於 %C"
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "敘述標貼在中結束重要於 %C 不匹配 CRITIAL 標貼"
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "Fortran 2008:區塊建構於 %C"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "Fortran 2003:關聯建構於 %C"
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "敘述標貼在中 ENDDO 於 %C 不匹配做標貼"
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "具名的區塊做於 %L 需求匹配 ENDDO 名稱"
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr "缺少!$OMP 結束基元的之後 !$OMP 基元的擷取於 %C"
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr "巢狀的重要區塊於 %C"
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s at %C"
 msgstr "需要 %s 敘述，於 %C"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "在 %C 處需要「(」"
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr "冗餘 ACQUIRED_LOCK 標籤找到於 %L "
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "名稱之後 !$omp 重要和 !$omp 結束重要不匹配於 %C"
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "%s 敘述於 %C 無法終止 non-block 做迴圈"
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr "%L 處 FORMAT 敘述沒有敘述標籤"
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "包含的程序『%s』於 %C 已經模稜兩可的"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "非預期的 %s 敘述出現在 %C 處的 CONTAINS 段中"
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr "Fortran 2008:含有敘述而無需函式或副常式敘述於 %C"
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "含有敘述於 %C 已經在中包含的程式單元"
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr "總體名稱『%s』於 %L 已經被做為 %s 於 %L"
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr "總體名稱『%s』於 %L 已經被做為 %s 於 %L"
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "空白區塊資料於 %C 衝突與事前區塊資料於 %L"
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "非預期的 %s 敘述出現在 %C 處的 DATA 區塊中"
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "非預期的 %s 敘述出現在 %C 處的 MODULE 中"
@@ -51268,7 +51316,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "%L 和 %C 處有兩個主 PROGRAM"
@@ -51969,7 +52017,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "非遞迴程序『%s』於 %L 是可能會呼叫它自己遞迴。 宣告它遞迴或使用 -frecursive"
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "標籤 %d(參照自 %L)從未被定義"
@@ -52027,367 +52075,367 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "傳遞內部程序於 %L 依位置不允許"
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL non-INTRINSIC 程序「%s」在 %L 處不允許做為實際引數"
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Coindexed 實際引數於 %L 與 ultimate 指標成分"
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "『%s』於 %L 是陣列和可選的；如果它缺少，它無法實際引數的 ELEMENTAL 程序除非有 non-optional 引數與同級 (12.4.1.5)"
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "實際引數於 %L 用於含義 (%s) 虛設『%s』的 ELEMENTAL 副常式『%s』是純量，但是另外的實際引數是陣列"
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "傳回類型不匹配的函式『%s』於 %L (%s/%s)"
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr "介面不匹配在中虛設程序『%s』於 %L:%s"
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, fuzzy, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "沒有任何特定的函式用於通用『%s』於 %L"
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, fuzzy, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "通用函式『%s』於 %L 不是一致的與特定的 intrinsic 介面"
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "函式『%s』於 %L 是 INTRINSIC 但是不是相容與 intrinsic"
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "無法解析特定的函式『%s』於 %L"
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "函式「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "參考到 non-PURE 函式『%s』於 %L 內部 FORALL %s"
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "參考到 non-PURE 函式『%s』於 %L 內部做共時 %s"
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "參考到 non-PURE 函式『%s』於 %L 內部 FORALL %s"
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "『%s』於 %L 並非函式"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, fuzzy, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "摘要介面『%s』必須不被引用於 %L"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, fuzzy, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "函式『%s』被宣告字元 (*) 和無法使用的於 %L 自從它並非虛引數"
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, fuzzy, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "<unresolved overloaded function type>"
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, fuzzy, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "使用者自訂 non-ELEMENTAL 函式『%s』於 %L 不允許在中 WORKSHARE 建構"
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "條目『%s』於 %L 無法 called 遞迴，因為函式『%s』不是遞迴"
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "函式『%s』於 %L 無法 called 遞迴，因為它不是遞迴"
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "副常式呼叫到『%s』在中 FORALL 區塊於 %L 不是 PURE"
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "副常式呼叫到『%s』在中做共時區塊於 %L 不是 PURE"
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "副常式呼叫到『%s』於 %L 不是 PURE"
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, fuzzy, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "沒有任何特定的副常式用於通用『%s』於 %L"
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, fuzzy, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "通用副常式『%s』於 %L 不是一致的與 intrinsic 副常式介面"
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, fuzzy, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "副常式『%s』於 %L 是 INTRINSIC 但是不是相容與 intrinsic"
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "無法解析特定的副常式『%s』於 %L"
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr "『%s』於 %L 有型態，該項不是一致的與呼叫於 %L"
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "條目『%s』於 %L 無法 called 遞迴，因為副常式『%s』不是遞迴"
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, fuzzy, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "副常式『%s』於 %L 無法 called 遞迴，因為它不是遞迴"
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, fuzzy, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "<unresolved overloaded function type>"
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "%L 和 %L 處的運算元外形不相容"
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld<%ld) 在中 codimension %d"
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld>%ld) 在中 codimension %d"
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L 零間隔無效"
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "降低陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "降低陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "大寫陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "大寫陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "陣列參照缺少下標"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Rightmost 上限的假設的大小陣列區段尚未指定於 %L"
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L 處陣列參照中秩不匹配(%d/%d)"
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Coindex 分級不匹配在中陣列參照於 %L (%d/%d)"
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Coindex 的 codimension %d 必須是純量於 %L"
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L 處陣列索引必須是標量"
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "陣列索引於 %L 必須是的整數類型，找到 %s"
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "擴充：%L 處的 REAL 陣列索引"
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L 引數維數必須是標量"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L 處引數維數必須具有 INTEGER 類型"
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L 處陣列索引是一個秩為 %d 的陣列"
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L 處的子字串起始索引類型必須為 INTEGER"
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L 處的子字串起始索引必須是標量"
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L 處的子字串起始索引小於 1"
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L 處的子字串終止索引類型必須為 INTEGER"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L 處的子字串終止索引必須是標量"
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "子字串結束索引於 %L 超出字串長度"
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "子字串結束索引於 %L 太大"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L 處陣列參照錯誤"
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "成分到權限的部分參考與非零值分級必須不有指標屬性於 %L"
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "成分到權限的部分參考與非零值分級必須不有 ALLOCATABLE 屬性於 %L"
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "兩個以上部分參考與非零值分級必須不被指定的於 %L"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
@@ -52396,12 +52444,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
@@ -52410,249 +52458,249 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "變數『%s』，已用於規格運算式，被引用於 %L 之前條目敘述在中該項它是參數"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "變數『%s』被使用於 %L 之前條目敘述在中該項它是參數"
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorphic 子物件的 coindexed 物件於 %L"
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Coindexed 物件與 polymorphic allocatable subcomponent 於 %L"
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Passed-object 於 %L 必須是純量"
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 procedure-pointer 成分呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 type-bound 程序呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "基底物件用於 NOPASS type-bound 程序呼叫於 %L 必須是純量"
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "找到沒有匹配特定的繫結用於呼叫到通用『%s』於 %L"
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "『%s』於 %L 應該是副常式"
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "『%s』於 %L 應該是函式"
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要運算式類型"
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L 處)必須是一個標量"
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L 處)必須是 INTEGER"
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "步進敘述於 %L 處的 DO 迴圈中不可為零"
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "做迴圈於 %L 將被執行零次"
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L 處 FORALL 索引名稱必須是 INTEGER 標量"
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 啟始敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 結束敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L 處的 FORALL 步幅敘述必須是 %s 標量"
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L 處的 FORALL 步幅敘述不能為零"
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引『%s』可能無法出現在中 triplet 規格於 %L"
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allocate-object 於 %L 必須是 ALLOCATABLE 或指標"
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Coindexed allocatable 物件於 %L"
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Source-expr 於 %L 必須是純量或有同級做為 allocate-object 於 %L"
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Source-expr 於 %L 和 allocate-object 於 %L 必須有相同形狀"
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "型態的實體於 %L 是型態不相容的與 source-expr 於 %L"
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "allocate-object 於 %L 和 source-expr 於 %L 應該有相同 kind 型態參數"
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 於 %L 應該 neither 是的型態 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 於 %L 是 coarray"
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "配置 %s 的摘要基底類型於 %L 需要 type-spec 或 source-expr"
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "配置 %s 於 %L 與 type-spec 需求相同 character-length 參數做為在中宣告"
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "陣列規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Coarray 規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "不當的陣列規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, fuzzy, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "『%s』必須不出現在中陣列規格於 %L 在中相同配置敘述位置它是它自己配置"
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "預期『*』在中 coindex 規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "不當的 coarray 規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-variable 於 %L 必須是純量整數變數"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG 於 %L 是無用的而無需 STAT 標籤"
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "Errmsg-variable 於 %L 必須是純量字元變數"
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allocate-object 於 %L 也出現於 %L"
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allocate-object 於 %L 是子物件的物件於 %L"
@@ -52661,188 +52709,188 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "大小寫標貼於 %L 重疊與大小寫標貼於 %L"
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L 處 CASE 敘述中的運算式必須具有 %s 類型"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "運算式在中條件敘述於 %L 必須是的 kind %d"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L 處 CASE 敘述中的運算式必須為標量"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "選擇運算式在中計算的前往敘述於 %L 必須是純量整數運算式"
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "運算式在中條件敘述於 %L 不是在中範圍的 %s"
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "預設大小寫於 %L 無法在之後秒預設大小寫於 %L"
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "邏輯的範圍在中條件敘述於 %L 未被允許"
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "常數邏輯的值在中條件敘述被重複於 %L"
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "範圍規格於 %L 可以永不被匹配"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "邏輯的選取大小寫區塊於 %L 有更多該兩大小寫"
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associate-name『%s』於 %L 被做為陣列"
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "選擇器應該是 polymorphic 在中選取型態敘述於 %L"
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "衍生類型『%s』於 %L 必須是 extensible"
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "衍生類型『%s』於 %L 必須是延伸的『%s』"
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "未預期的空值() intrinsic 於 %L 到虛設『%s』"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Type-spec 於 %L 無法包含已推遲型態參數"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "雙倍類別是區塊在中選取型態敘述於 %L"
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無效的語境用於空值() 指標於 %%L"
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法 polymorphic 除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有指標成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "資料轉移元件於 %L 無法有程序指標成分"
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有 ALLOCATABLE 成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "資料轉移元件於 %L 無法有私人的成分"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "資料轉移元件於 %L 無法全部參考到 assumed-size 陣列"
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "鎖定變數於 %L 必須是純量的型態 LOCK_TYPE"
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=引數於 %L 必須是純量整數變數"
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=引數於 %L 必須是純量字元變數"
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=引數於 %L 必須是純量邏輯的變數"
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Imageset 引數於 %L 必須介於 1 和 numimages()(_I)"
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "敘述於 %L 並非有效分支目標敘述用於分支敘述於 %L"
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "分支於 %L 也許會導致無窮迴圈"
@@ -52849,12 +52897,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "前往敘述於 %L 樹葉重要建構用於標貼於 %L"
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "前往敘述於 %L 樹葉做共時建構用於標貼於 %L"
@@ -52862,161 +52910,161 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "標貼於 %L 不是在中相同區塊做為前往敘述於 %L"
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "位置遮罩於 %L 有不一致形狀"
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "位置指派目標於 %L 有不一致形狀"
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Non-ELEMENTAL 使用者定義的指派在中位置於 %L"
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L 處在 WHERE 內不支援的敘述"
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, fuzzy, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL 與索引『%s』未被使用左側的側邊的指派於 %L 和因而也許造成多重指派到這個物件"
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "外 FORALL 建構已經有索引與這個名稱 %L"
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L 處的 WHERE/ELSEWHERE 子句需要一個 LOGICAL 陣列"
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr "字元運算式將被截斷在中指派 (%d/%d) 於 %L"
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Coindexed 運算式於 %L 被指派到衍生類型變數與指標成分在中 PURE 程序"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "impure 變數於 %L 被指派到衍生類型變數與指標成分在中 PURE 程序 (12.6)"
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "指派到 coindexed 變數於 %L 在中 PURE 程序"
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr "無限制的多型於 %C 尚未支援"
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "變數必須不是 polymorphic 在中 intrinsic 指派於 %L - 檢查該有匹配特定的副常式用於『=』運算子"
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Coindexed 變數必須不是有 allocatable ultimate 成分在中指派於 %L"
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "指派的前往敘述於 %L 需求整數變數"
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "變數「%s」在 %L 尚未指派到目標標籤"
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "交替回傳敘述於 %L 需要 SCALAR-INTEGER 回傳說明符"
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "指派敘述於 %L 需要純量預設整數變數"
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr "算術如果敘述於 %L 需要數值運算式"
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "離開條件的做當迴圈於 %L 必須是純量邏輯的運算式"
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL 遮罩子句於 %L 需要純量邏輯的運算式"
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：錯誤的敘述程式碼"
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
@@ -53023,7 +53071,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -53031,58 +53079,58 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr "字元變數於 %L 有負長度 %d，長度已被設定為零"
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "字串長度於 %L 太大"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可指派的陣列「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "純量物件『%s』於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "陣列指標「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "陣列「%s」在 %L 處不能有延遲的外形"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "型態『%s』的類別變數『%s』於 %L 不是 extensible"
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "類別變數『%s』於 %L 必須是虛設，allocatable 或指標"
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "型態『%s』無法主機關聯的於 %L 因為它被阻斷由不相容的物件的同名宣告的於 %L"
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008:意味著的儲存用於模組變數『%s』於 %L, 所需的由於預設初始化"
@@ -53089,432 +53137,432 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr "模組或主程式陣列「%s」在 %L 處必須有常態的外形"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr "實體『%s』於 %L 有已推遲型態參數和需求還是指標或 allocatable 屬性"
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "實體與假設的字元長度於 %L 必須是虛引數或參數"
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr "『%s』於 %L 必須有常數字元長度在中這個語境"
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "共同變數『%s』於 %L 必須有常數字元長度"
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可指派的「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "啞元「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "內建函式「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函式結果「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自動陣列「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Character-valued 敘述函式『%s』於 %L 必須有常數長度"
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:『%s』是的私人的型態和無法虛引數的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003:程序『%s』在中公用的介面『%s』於 %L 需虛引數的『%s』該項是私人的"
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函式『%s』於 %L 無法有初始設定式"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部物件「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL 函式『%s』於 %L 必須有純量結果"
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "敘述函式『%s』於 %L 可能無法有指標或 allocatable 屬性"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以陣列賦值"
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以指標賦值"
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "字元 (*) 函式『%s』於 %L 無法遞迴"
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "程序『%s』在中 %s 於 %L 沒有任何明確的介面"
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "虛設程序『%s』於 %C 無法有通用介面"
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "程序屬性衝突與儲存屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "程序屬性衝突與含義屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "程序屬性衝突與結果屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "外部屬性衝突與函式屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "程序指標結果『%s』於 %L 缺少指標屬性"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "最後的程序『%s』於 %L 並非副常式"
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "最後的程序於 %L 必須有精確的一個引數"
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "引數的最後的程序於 %L 必須是的型態『%s』"
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "引數的最後的程序於 %L 必須不是指標"
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "引數的最後的程序於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "引數的最後的程序於 %L 必須不是可選的"
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "引數的最後的程序於 %L 必須不是含義 (出)"
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Non-scalar 最後的程序於 %L 應該已假設形狀引數"
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "最後的程序『%s』宣告的於 %L 有同級 (%d) 做為『%s』"
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, fuzzy, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "只有陣列最後的程序宣告的用於衍生類型『%s』定義的於 %L, 建議也純量一個"
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "『%s』和『%s』無法混合的函式/副常式用於通用『%s』於 %L"
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "『%s』和『%s』用於通用『%s』於 %L 是模稜兩可的"
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定義的特定的繫結『%s』做為目標的通用『%s』於 %L"
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "通用『%s』於 %L 必須目標特定的繫結，『%s』是通用，太"
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "通用『%s』於 %L 無法覆寫特定的繫結與同名"
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "Type-bound 運算子於 %L 無法 NOPASS"
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "『%s』必須是模組程序或外部程序與明確的介面於 %L"
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "程序『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Non-polymorphic passed-object 虛引數的『%s』於 %L"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須是純量"
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是指標"
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "程序『%s』於 %L 有同名做為成分的『%s』"
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "程序『%s』於 %L 有同名做為繼承的成分的『%s』"
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "衍生類型『%s』宣告的於 %L 必須是摘要因為『%s』是已推遲和無法 overridden"
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, fuzzy, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "做為延伸型態『%s』於 %L 有 coarray 成分，親代型態『%s』應該也有一個"
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Non-extensible 衍生類型『%s』於 %L 必須不是摘要"
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Coarray 成分『%s』於 %L 必須是 allocatable 與已推遲形狀"
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "成分『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "成分『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "成分『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標"
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序指標成分『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "程序指標成分『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是純量"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法有指標屬性"
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "成分『%s』的『%s』於 %L 有同名做為繼承 type-bound 程序"
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, fuzzy, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "字元長度的成分『%s』需要是常數規格運算式於 %L"
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, fuzzy, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "字元成分『%s』的『%s』於 %L 與已推遲長度必須是指標或 ALLOCATABLE"
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:成分『%s』是私人的型態和無法成分的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphic 成分 %s 於 %L 在中序列或繫結©型態 %s"
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "成分 %s 的序列型態宣告的於 %L 沒有序列屬性"
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, fuzzy, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "指標成分『%s』的『%s』於 %L 是型態該未被宣告"
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, fuzzy, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr "成分『%s』與類別於 %L 必須是 allocatable 或指標"
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr "Fortran 2003:通用名稱『%s』的函式『%s』於 %L 相同名稱做為衍生類型於 %L"
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "假設的大小陣列『%s』在中名稱表列『%s』於 %L 未被允許"
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與假設的形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與 nonconstant 形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列物件『%s』與 nonconstant 字元長度在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "名稱表列物件『%s』在中名稱表列『%s』於 %L 是 polymorphic 和需要定義的輸入/輸出程序"
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Fortran 2003:名稱表列物件『%s』在中名稱表列『%s』於 %L 與 ALLOCATABLE 或指標成分"
@@ -53521,398 +53569,398 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr "名稱表列物件『%s』在中名稱表列『%s』於 %L 有 ALLOCATABLE 或指標成分和因而需要定義的輸入/輸出程序"
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』被宣告私人的和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "名稱表列物件『%s』已 use-associated 私人的成分和無法成員的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』有私人的成分和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "程序屬性衝突與名稱表列屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "參數陣列『%s』於 %L 無法自動或的已推遲形狀"
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "隱含地型態的參數『%s』於 %L 不匹配稍後隱含的型態"
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "不相容的衍生類型在中參數於 %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "保護的屬性衝突與外部屬性於 %L"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "程序屬性衝突與保護的屬性於 %L"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標或 assumed-shape 陣列"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "假定大小的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L 處的符號不是一個 DUMMY 變數"
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "『%s』於 %L 無法有值屬性因為它並非虛引數"
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "字元虛設變數『%s』於 %L 與值屬性必須有常數長度"
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C 可交流的字元虛設變數『%s』於 %L 與值屬性必須有長度一個"
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "衍生類型『%s』於 %L 是的型態『%s』，該項未被定義"
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "假設的形狀陣列『%s』於 %L 未被允許在中初始化運算式"
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "迴圈變數於 %C 無法 coarray"
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "變數『%s』於 %L 無法繫結©因為它是 neither 共同區塊 nor 宣告的於模組等級範圍"
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003:公用的 %s『%s』於 %L 的私人的衍生類型『%s』"
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "含義 (出) 虛引數『%s』於 %L 是假設的大小和因而無法有預設初始設定式"
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函數計算結果『%s』於 %L 不應該是 coarray 或有 coarray 成分"
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "變數『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "變數『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "變數『%s』於 %L 是 coarray 和不是 ALLOCATABLE，儲存 nor 虛引數"
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allocatable coarray 變數『%s』於 %L 必須已已推遲形狀"
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "變數『%s』於 %L 是含義 (出) 和可以因而無法是 allocatable coarray 或有 coarray 成分"
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate 於 %L 不是儲存"
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "區塊資料元素『%s』於 %L 必須是在中共同"
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "資料陣列『%s』於 %L 必須被指定的在中前一個宣告"
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "資料元素『%s』於 %L 無法有 coindex"
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "資料元素『%s』於 %L 是指標和因而必須是全部陣列"
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Nonconstant 陣列區段於 %L 在中資料敘述"
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "資料敘述於 %L 有更多變數比值"
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "開始的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "結束的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步驟的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "資料敘述於 %L 有更多值比變數"
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "標籤 %d 於 %L 經定義但未被使用"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "標籤 %d 於 %L 經定義但無法被使用"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 必須有序列屬性為等價物件"
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 無法有 ALLOCATABLE 成分為等價物件"
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "衍生類型變數『%s』於 %L 與預設初始化無法在中等價與變數在中共同"
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 與指標成分無法等價物件"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L 處 EQUIVALENCE 敘述語法錯誤"
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "還是所有或沒有任何物件在中等價設定於 %L 應該有保護的屬性"
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, fuzzy, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "共同區塊成員『%s』於 %L 無法等價物件在中 pure 程序『%s』"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "具名的常數『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "陣列『%s』於 %L 與 non-constant 邊界無法等價物件"
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "結構成分『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字串長度為零"
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003:公用的函式『%s』於 %L 的私人的型態『%s』"
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "使用者運算子程序『%s』於 %L 必須是函式"
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "使用者運算子程序『%s』於 %L 無法假設的字元長度"
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "使用者運算子程序『%s』於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "第一個引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "秒引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "運算子介面於 %L 必須有，最多，兩引數"
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "包含的程序『%s』於 %L 的 PURE 程序必須也是 PURE"
@@ -53942,47 +53990,47 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr "!$OMP 於 %C 開始評論的列做為它 neither 被在之後空格 nor 是延續列"
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr "列截斷的於 %L"
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr "限制的 %d 延續超出的在中敘述於 %C"
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "缺少『&』在中繼續的字元常數於 %C"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr "Nonconforming 定位字元於 %C"
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, fuzzy, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
 msgstr "『&』不允許由它自己於第 %d 列"
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr "Nonconforming 定位字元在中欄 %d 的列 %d"
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr "%s:%d: 檔案 %s 被留下但未進入"
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr "%s:%d：無效的預包含指示"
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open file '%s'"
 msgid "Can't open file %qs"
@@ -54251,55 +54299,55 @@
 msgid "Reshaped array too large at %C"
 msgstr "%C 處整數太大"
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "%L 處 SCALE 的結果向上溢位其種別"
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "Bad type in gfc_simplify_sign"
 msgstr "常數運算式中類型錯誤"
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "%L 處 SQRT 的參數為負"
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid second argument of IBSET at %L"
 msgid "invalid argument of SQRT at %L"
 msgstr "%L 處 IBSET 的第二個參數無效"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr "發信匣的邊界在中 IMAGE_INDEX 於 %L 用於尺寸 %d，子有 %ld 和 COARRAY 下限是 %ld)"
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr "發信匣的邊界在中 IMAGE_INDEX 於 %L 用於尺寸 %d，子有 %ld 和 COARRAY 上限是 %ld)"
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_conv_constant_to_tree(): invalid type: %s"
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree()：無效類型；%s"
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, fuzzy, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr "字元『%s』在中字串於 %L 無法轉換的進入字元 kind %d"
@@ -54380,320 +54428,325 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "名稱表列群組名稱於 %L 無法有儲存屬性"
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "Fortran 2008:內部程序『%s』被做為實際引數於 %L"
+
+#: fortran/symbol.c:489
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "Fortran 2003:程序指標於 %C"
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "%s 屬性套用到 %s %s 於 %L"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "繫結©套用到 %s %s 於 %L"
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr "%s 屬性與 %s 屬性衝突，在「%s」中，位於 %L"
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute with %s attribute at %L"
 msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, fuzzy, gcc-internal-format
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr "%s 屬性與 %s 屬性衝突，在「%s」中，位於 %L"
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "無法變更屬性的 USE-associated 符號於 %L"
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "無法變更屬性的 USE-associated 符號 %s 於 %L"
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "重複的 %s 屬性在 %L 處被指定"
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "ALLOCATABLE 指定的外側的介面內文於 %L"
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, fuzzy, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "CODIMENSION 指定的用於『%s』外側它的介面內文於 %L"
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, fuzzy, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "尺寸指定的用於『%s』外側它的介面內文於 %L"
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "Cray 點於 %L 出現在中多重指標() 敘述"
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "重製保護的屬性指定的於 %L"
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "%L 處 PURE 程序不能指定 SAVE 屬性"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "%L 指定了重複的 SAVE 屬性"
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "重製值屬性指定的於 %L"
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "重製易變的屬性指定的於 %L"
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "重製非同步屬性指定的於 %L"
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s 屬性的『%s』衝突與 %s 屬性於 %L"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "%s 程序於 %L 已經宣告的做為 %s 程序"
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) 與 INTENT(%s) 在 %L 衝突"
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "存取規格於 %L 已經指定的"
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "重製繫結屬性指定的於 %L"
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "Fortran 2003:繫結©於 %L"
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "重製延伸屬性指定的於 %L"
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "Fortran 2003:延伸於 %L"
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "符號「%s」在 %L 處已經有了明確介面"
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "『%s』於 %L 有屬性指定的外側它的介面內文"
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr "符號『%s』於 %L 衝突與符號從模組『%s』，use-associated 於 %L"
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "符號「%s」在 %L 處已經有了基本類型 %s"
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "程序『%s』於 %L 可能無法有基本型式的 %s"
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "符號「%s」於 %L 處不能有類型"
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr "元件「%s」在 %C 處已經於 %L 處被宣告"
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr "成分『%s』於 %C 已經在中親代型態於 %L"
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "符號「%s」在 %C 處有歧義"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "衍生類型『%s』於 %C 正在被使用之前它被定義"
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "元件「%s」在 %C 處是「%s」的 PRIVATE 元件"
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "「%s」在 %C 處不是「%s」結構的成員"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "重複的敘述標籤 %d 出現在 %L 和 %L 處"
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "標貼 %d 於 %C 已經引用做為分支目標"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "標貼 %d 於 %C 已經引用做為格式標貼"
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "標貼 %d 於 %C 在之前使用的做為格式標貼"
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "標貼 %d 於 %C 在之前使用的做為分支目標"
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "%C 處需要結束名"
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "名稱『%s』於 %C 是模稜兩可的參考到『%s』從模組『%s』"
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "名稱『%s』於 %C 是模稜兩可的參考到『%s』從目前的程式單元"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "符號『%s』於 %C 已主機關聯的"
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "衍生類型『%s』宣告的於 %L 必須有繫結屬性為 C 可交流的"
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "衍生類型『%s』與繫結©屬性於 %L 是空的，而也許會是不可存取由 C companion 處理器"
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr "成分『%s』於 %L 無法有指標屬性因為它是成員的繫結©衍生類型『%s』於 %L"
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr "程序指標成分『%s』於 %L 無法成員的繫結©衍生類型『%s』於 %L"
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr "成分『%s』於 %L 無法有 ALLOCATABLE 屬性因為它是成員的繫結©衍生類型『%s』於 %L"
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "成分『%s』在中衍生類型『%s』於 %L 可能無法是 C 可交流的，甚至雖然衍生類型『%s』是繫結©"
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "成分『%s』在中衍生類型『%s』於 %L 可能無法是 C 可交流的"
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "衍生類型『%s』於 %L 無法宣告的與兩者私人的和繫結©屬性"
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "衍生類型『%s』於 %L 無法有序列屬性因為它是繫結©"
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "符號『%s』被使用之前它被型態於 %L"
@@ -54955,7 +55008,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr "錯誤的 IO 基礎類別型(%d)"
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, fuzzy, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr "gfc_trans_omp_workshare()：不當的敘述編碼"
@@ -56964,6 +57017,9 @@
 #~ msgid "%q+D causes a section type conflict"
 #~ msgstr "%q+D 導致一個區段類型衝突"
 
+#~ msgid "-munix=98 option required for C89 Amendment 1 features.\n"
+#~ msgstr "使用 C89 修訂版 1 的特性必須指定 -munix=98 選項。\n"
+
 #, fuzzy
 #~ msgid "invalid AE type specified (%s)"
 #~ msgstr "無效的型態指定的 (%s)"
@@ -57282,6 +57338,9 @@
 #~ msgid "%qD has no member named %qE"
 #~ msgstr "%qD 沒具名為 %qE 的成員"
 
+#~ msgid "ISO C++ forbids subscripting non-lvalue array"
+#~ msgstr "ISO C++ 不允許按下標存取非左值的陣列"
+
 #, fuzzy
 #~ msgid "  since type %qT has pure virtual functions"
 #~ msgstr "  自從型態 %qT 有純虛擬函式"
Index: gcc/po/id.po
===================================================================
--- gcc/po/id.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/id.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.4.1\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2009-11-10 09:00+0700\n"
 "Last-Translator: Arif E. Nugroho <arif_endro@yahoo.com>\n"
 "Language-Team: Indonesian <translation-team-id@lists.sourceforge.net>\n"
@@ -207,13 +207,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "konstanta pecahan disalah gunakan"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1450,7 +1450,7 @@
 msgid "options enabled: "
 msgstr "pilihan aktif: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2707,97 +2707,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "kode operan '%c' tidak valid"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "nilai %%H tidak valid"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "nilai %%J tidak valid"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "nilai %%r tidak valid"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "nilai %%R tidak valid"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "nilai %%N tidak valid"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "nilai %%P tidak valid"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "nilai %%h tidak valid"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "nilai %%L tidak valid"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "nilai %%m tidak valid"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "nilai %%M tidak valid"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "nilai %%U tidak valid"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "nilai %%s tidak valid"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "nilai %%C tidak valid"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "nilai %%E tidak valid"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "relokasi unspek tidak diketahui"
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "kode %%xn tidak valid"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid operand address"
@@ -2850,7 +2850,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "operan kode keluaran tidak valid"
@@ -3017,8 +3017,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3240,69 +3240,69 @@
 msgid "bad output_condmove_single operand"
 msgstr "operan output_condmove_single buruk"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC tidak valid sebagai operan"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "kode operan '%c' tidak valid"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "batasan untuk operan tidak valid"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "mode insn tidak diketahui"
 
@@ -3345,7 +3345,7 @@
 msgid "invalid %%P operand"
 msgstr "operan %%P tidak valid"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "nilai %%p tidak valid"
@@ -3413,7 +3413,7 @@
 msgstr "alamat post-increment bukan sebuah register"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "alamat buruk"
 
@@ -3596,104 +3596,104 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "Hasilkan kode dalam mode little endian"
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "tes buruk"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "nilai %%f tidak valid"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "nilai %%F tidak valid"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "nilai %%G tidak valid"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "kode %%j tidak valid"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "kode %%J tidak valid"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "nilai %%k tidak valid"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "nilai %%K tidak valid"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "nilai %%O tidak valid"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "nilai %%q tidak valid"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "nilai %%S tidak valid"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "nilai %%T tidak valid"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "nilai %%u tidak valid"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "nilai %%v tidak valid"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "nilai %%x tidak valid"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "nilai %%ytidak valid, coba menggunakan batasan 'Z'"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Jangan hasilkan sebuah titik keluar tunggal untuk setiap fungsi"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load offset for fusion"
@@ -3798,34 +3798,34 @@
 msgid "invalid operand to %%S"
 msgstr "operan tidak valid ke %%S"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr "dibuat dan digunakan dengan arsitektur berbeda / ABI"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr "dibuat dan digunakan dengan ABI berbeda"
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr "dibuat dan digunakan dengan endianness berbeda"
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "operan %%Y tidak valid"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "operan %%A tidak valid"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "operan %%B tidak valid"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
@@ -3832,28 +3832,28 @@
 msgid "invalid %%C operand"
 msgstr "operan %%P tidak valid"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
 msgid "invalid %%D operand"
 msgstr "operan %%P tidak valid"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "operan %%f tidak valid"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "operan %%s tidak valid"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "konstanta long long bukan sebuah operan langsung yang valid"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "konstanta titik pecahan bukan sebuah operan langsung yang valid"
@@ -4077,7 +4077,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "diduga %<,%>"
@@ -4093,15 +4093,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "diduga %<(%>"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -4124,8 +4124,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -4133,8 +4133,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -4146,14 +4146,14 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "diduga %<{%>"
@@ -4160,8 +4160,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
@@ -4185,7 +4185,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -4205,20 +4205,20 @@
 msgid "expected %<.%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -4225,17 +4225,17 @@
 msgstr "diduga %<,%> atau %<,%>"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "diduga %<=%>"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "diduga %<#pragma omp section%> atau %<}%>"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -4247,11 +4247,11 @@
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
@@ -4507,11 +4507,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "kandidat adalah:"
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -4575,54 +4575,54 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "tipe argumen salah ke unary minus"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "tipe argume salah ke unary plus"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "tipe argumen salah ke bit-complement"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "tipe argumen salah ke abs"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "tipe argumen salah ke konjugasi"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "tipe argume salah ke unary plus"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 #, fuzzy
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "no pre-increment operator for type"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 #, fuzzy
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "no pre-decrement operator for type"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4720,7 +4720,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "Nilai integer terlalu besar dalam ekspresi di %C"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 msgid "array assignment"
 msgstr "penempatan array"
 
@@ -4744,7 +4744,7 @@
 msgid "Driving:"
 msgstr "Driving:"
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4818,13 +4818,13 @@
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4902,7 +4902,7 @@
 msgid "Bad type in constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 msgid "Unexpected end of module"
 msgstr "Tidak terduga akhir dari modul"
 
@@ -4930,11 +4930,11 @@
 msgid "implied END DO"
 msgstr "Diimplikasikan END DO"
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr "assignment"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 msgid "pointer assignment"
 msgstr "assignmen penunjuk"
 
@@ -4954,231 +4954,231 @@
 msgid "internal function"
 msgstr "fungsi mengembalikan sebuah fungsi"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 msgid "elemental procedure"
 msgstr "prosedur elemental"
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "assignmen penunjuk"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-shape argument"
 msgstr "argumen tidak cocok"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-rank argument"
 msgstr "argumen tidak cocok"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 #| msgid "array assignment"
 msgid "coarray argument"
 msgstr "penempatan array"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "parametrized derived type argument"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 #, fuzzy
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "result with non-constant character length"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 #, fuzzy
 #| msgid "elemental procedure"
 msgid "bind(c) procedure"
 msgstr "prosedur elemental"
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Konteks tidak valid untuk penunjuk NULL() di %%L"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr "Operan dari operator numerik unary '%s' di %%L adalah %s"
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr "Operan dari operan binari numerik '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operan dari string operator konkatenasi di %%L adalah %s/%s"
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr "Operan dari operator logikal '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operan dari operator .not. di %%L adalah %s"
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "kuantitas KOMPLEKS tidak dapat dibandingkan di %L"
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logikal di %%L harus dibandingkan dengan %s daripada %s"
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr "Operan dari operator perbandingan '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr "Operan dari operator pengguna '%s' di %%L adalah %s"
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr "Operan dari operator pengguna '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Tingkat tidak konsisten untuk operator di %%L dan %%L"
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 #, fuzzy
 #| msgid "%qD is not a variable"
 msgid "iterator variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ekspresi sebagai operan tidak valid"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALOKASIKAN "
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALOKASIKAN "
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5618,16 +5618,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr ""
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr ""
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr ""
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr "tidak mendukung multilib"
@@ -5640,6 +5630,12 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "-Xbind-now dan -Xbind-lazy tidak kompatibel"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+#, fuzzy
+#| msgid "profiling not supported with -mg\n"
+msgid "profiling not supported with -mg"
+msgstr "profiling tidak didukung dengan -mg\n"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "-mhard-float tidak didukung"
@@ -5648,10 +5644,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "-msingle-float dan -msoft-float tidak dapat keduanya dispesifikasikan"
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr "m210 tidak memiliki dukungan little endian"
-
 #: config/cris/cris.h:184
 #, fuzzy
 #| msgid "Do not specify both -march=... and -mcpu=..."
@@ -5686,6 +5678,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr ""
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5692,6 +5690,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr "tidak boleh digunakan bersamaan -m32 dan -m64"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr ""
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr "static tidak didukung dalam TPF-OS"
@@ -5706,6 +5708,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian dan -mlittle-endian tidak boleh digunakan bersamaan"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr "m210 tidak memiliki dukungan little endian"
+
 #: config/avr/specs.h:68
 #, fuzzy
 #| msgid "-mhard-float not supported"
@@ -5733,17 +5739,19 @@
 msgid "no processor type specified for linking"
 msgstr "tipe prosesor tidak dispesifikasikan untuk penyambungan"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr ""
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr ""
 
@@ -5779,12 +5787,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "pilihan -shared saat ini tidak didukung untuk VAX ELF"
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-#, fuzzy
-#| msgid "profiling not supported with -mg\n"
-msgid "profiling not supported with -mg"
-msgstr "profiling tidak didukung dengan -mg\n"
-
 #: fortran/lang.opt:146
 #, fuzzy
 #| msgid "Put MODULE files in 'directory'"
@@ -5984,9 +5986,9 @@
 msgstr "Ijinkan tanda dollar dalam nama entity"
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Does nothing. Preserved for backward compatibility."
@@ -6224,10 +6226,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Tidak melakukan apa-apa. Dijaga untuk kompabilitas versi sebelumnya."
 
@@ -6275,7 +6277,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr "hilang nama berkas setelah %qs"
@@ -8326,50 +8328,54 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr "Asumsikan target CPU dikonfigurasikan sebagai little endian"
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 #, fuzzy
 #| msgid "Specify the target CPU"
 msgid "Specify the code model"
 msgstr "Spesifikasikan target CPU"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr "Abaikan frame pointer dalam fungsi daun"
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr "Gunakan feature dari dan jadwalkan kode untuk CPU yang diberikan"
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 #, fuzzy
 #| msgid "Generate code that conforms to the given ABI"
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr "Hasilkan kode yang konform ke ABI yang diberikan"
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -9552,11 +9558,17 @@
 
 #: config/i386/i386.opt:864
 #, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "Dukung fungsi dalam dan pembuatan kode MMX dan SSE"
+
+#: config/i386/i386.opt:868
+#, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use given stack-protector guard"
 msgstr "Gunakan propolice sebagai sebuah metode proteksi stack"
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr ""
 
@@ -9950,7 +9962,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -10099,7 +10111,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
@@ -10236,7 +10248,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr "Ijinkan penjadwalan dari sebuah urutan prolog fungsi"
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr "Jangan load register PIC dalam fungsi prolog"
 
@@ -10583,359 +10595,357 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "Gunakan instruksi media"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr "Jangan hasilkan load/store dengan instruksi update"
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr "Hasilkan load/store dengan update instruksi"
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr "Abaikan pembuatan dari indeks instruksi muat/simpan jika memungkinkan"
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 #, fuzzy
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "%<__builtin_next_arg%> dipanggil tanpa sebuah argumen"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr "Jadwalkan awal dan akhir dari prosedur"
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr "Kembali seluruh struktur dalam memori (baku AIX)"
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr "Kembali struktur kecil dalam register (baku SVR4)"
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr "Konform lebih dekan ke IBM XLC semantik"
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 #, fuzzy
 #| msgid "Generate software reciprocal sqrt for better throughput"
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr "Hasilkan piranti lunak reciprocal sqrt untuk throughput lebih baik"
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr "Jangan tempatkan konstanta titik pecahan dalam TOC"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr "Tempatkan konstanta titik pecahan dalam TOC"
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "Jangan tempatkan simbol+ofset konstanta dalam TOC"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr "Tempatkan simbol+ofset konstan dalam TOC"
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr "Gunakan hanya satu TOC masukan setiap prosedur"
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr "Tempatkan seluruhnya dalam TOC umum"
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr "Hasilkan instruksi VRSAVE ketika menghasilkan kode AltiVec"
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 #, fuzzy
 #| msgid "Deprecated option.  Use -mvrsave/-mno-vrsave instead"
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr "Pilihan ditinggalkan. Gunakan -mvrsave/-mno-vrsave lebih baik"
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 #, fuzzy
 #| msgid "Deprecated option.  Use -mvrsave/-mno-vrsave instead"
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr "Pilihan ditinggalkan. Gunakan -mvrsave/-mno-vrsave lebih baik"
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 msgid "Generate isel instructions"
 msgstr "Hasilkan instruksi isel"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 #, fuzzy
 #| msgid "Deprecated option.  Use -misel/-mno-isel instead"
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr "Pilihan ditinggalkan. Gunakan -misel/-mno-isel lebih baik"
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 #, fuzzy
 #| msgid "Deprecated option.  Use -misel/-mno-isel instead"
 msgid "Deprecated option.  Use -misel instead"
 msgstr "Pilihan ditinggalkan. Gunakan -misel/-mno-isel lebih baik"
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr "Hasilkan instruksi SPE SIMD dalam E500"
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "Hasilkan instruksi PPC750CL paired-single"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 #, fuzzy
 #| msgid "Deprecated option.  Use -mspe/-mno-spe instead"
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr "Pilihan ditinggalkan. Gunakan -mspe/-mno-spe lebih baik"
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 #, fuzzy
 #| msgid "Deprecated option.  Use -mspe/-mno-spe instead"
 msgid "Deprecated option.  Use -mspe instead"
 msgstr "Pilihan ditinggalkan. Gunakan -mspe/-mno-spe lebih baik"
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "-mdebug=\tEnable debug output"
 msgstr "Aktifkan keluaran debug"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 #, fuzzy
 #| msgid "Use the Cray Pointer extension"
 msgid "Use the AltiVec ABI extensions"
 msgstr "Gunakan ekstensi Cray Pointer"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 #, fuzzy
 #| msgid "Do not use the bit-field instructions"
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "Jangan gunakan instruksi bit-field"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 #, fuzzy
 #| msgid "Use the Cray Pointer extension"
 msgid "Use the SPE ABI extensions"
 msgstr "Gunakan ekstensi Cray Pointer"
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 #, fuzzy
 #| msgid "Do not use the bit-field instructions"
 msgid "Do not use the SPE ABI extensions"
 msgstr "Jangan gunakan instruksi bit-field"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv1 ABI"
 msgstr "Gunakan EABI"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv2 ABI"
 msgstr "Gunakan EABI"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 #, fuzzy
 #| msgid "Using darwin64 ABI"
 msgid "using darwin64 ABI"
 msgstr "Menggunakan ABI darwin64"
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 #, fuzzy
 #| msgid "Using old darwin ABI"
 msgid "using old darwin ABI"
 msgstr "Menggunakan ABI lama darwin"
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 #, fuzzy
 #| msgid "Using IEEE extended precision long double"
 msgid "using IEEE extended precision long double"
 msgstr "Menggunakan IEEE ekstended presisi long double"
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 #, fuzzy
 #| msgid "Using IBM extended precision long double"
 msgid "using IBM extended precision long double"
 msgstr "Menggunakan IBM ekstended presisi long double"
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr "Gunakan feature dari dan jadwalkan kode untuk CPU yang diberikan"
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 #, fuzzy
 #| msgid "Schedule code for given CPU"
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "Jadwalkan kode untuk CPU yang diberikan"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 #, fuzzy
 #| msgid "Select full, part, or no traceback table"
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr "Pilih penuh, bagian, atau tidak ada traceback tabel"
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr "Hindari batasan seluruh jangkauan dalam instruksi pemanggilan"
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 msgid "Generate Cell microcode"
 msgstr "Hasilkan mikrokode Cell"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "Peringatkan ketika sebuah instruksi mikrokode Cell dihasilkan"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr "Peringatkan mengenai penggunaan AltiVec 'vector long ...' yang sudah ditinggalkan"
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 #, fuzzy
 #| msgid "Select GPR floating point method"
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr "Pilih metode titik pecahan GPR"
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 #, fuzzy
 #| msgid "invalid option for -mfloat-gprs: '%s'"
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "pilihan untuk -mfloat-gprs tidak valid: '%s'"
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 #, fuzzy
 #| msgid "Specify size of long double (64 or 128 bits)"
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr "Spesifikasikan ukuran dari long double (64 atau 128 bits)"
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr "tentaukan which dependence diantara insns yang dipertimbangkan mahal"
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr "Spesifikasikan penjadwalan post nop insertion scheme untuk diaplikasikan"
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr "Spesifikasikan alignmen dari daerah struktur baku/alami"
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 #, fuzzy
 #| msgid "alias argument not a string"
 msgid "Valid arguments to -malign-:"
 msgstr "alias argumen bukan sebuah string"
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr "Spesifikasikan prioritas penjadwalan untuk dispatch slot instruksi yang restricted"
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 msgid "Single-precision floating point unit"
 msgstr "Presisi-tunggal satuan titik pecahan"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 msgid "Double-precision floating point unit"
 msgstr "Presisi-ganda satuan titik pecahan"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 msgid "Floating point unit does not support divide & sqrt"
 msgstr "Satuan titik pecahan tidak mendukung divide & sqrt"
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 #, fuzzy
 #| msgid "Specify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr "Spesifikasikan FP (sp, dp, sp-lite, dp-lite) (mengimplikasikan -mxilinx-fpu)"
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 msgid "Specify Xilinx FPU."
 msgstr "Spesifikasikan Xilinx FPU."
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 #, fuzzy
 #| msgid "Align destination of the string operations"
 msgid "Allow sign extension in fusion operations"
 msgstr "Tujuan align dari operasi string"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
-#, fuzzy
-#| msgid "Use SmartMIPS instructions"
-msgid "Use ISA 2.07 crypto instructions"
-msgstr "Gunakan instruksi SmartMIPS"
+#: config/rs6000/rs6000.opt:566
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr ""
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Hasilkan load/store multiple instruksi"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -14150,1712 +14160,1712 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr "Set berkas nama dasar yang akan digunakan untuk dumps"
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "Align awal dari fungsi"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr "Align labels yang hanya dicapai dengan melompat"
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr "Align seluruh labels"
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "Align awal dari loops"
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr ""
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr "Pilihan ini sudah ditinggalkan; lebih baik gunakan -Wextra"
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr "Hasilkan tabel unwind yang tepat di setiap batasan instruksi"
 
-#: common.opt:918
+#: common.opt:921
 msgid "Generate auto-inc/dec instructions"
 msgstr "Hasilkan instruksi auto-inc/dec"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr "Gunakan informasi profiling untuk setiap kemungkinan percabangan"
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "Hasilkan kode untuk memeriksa batasan sebelum array pengindeksan"
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr "Gantikan tambah, banding, cabang dengan cabang di jumlah register"
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr "Gunakan informasi profiling untuk setiap kemungkinan percabangan"
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr "Lakukan target percabangan load optimisasi sebelum prologue / epilog threading"
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr "Lakukan target percabangan optimisasi setelah prolog / epilog threading"
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr "Batasi target load migrasi bukan untuk re-use register dalam blok dasar apapun"
 
-#: common.opt:960
+#: common.opt:963
 #, fuzzy
 #| msgid "Mark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr "Tandai <register> sebagai telah disimpan dalam fungsi"
 
-#: common.opt:964
+#: common.opt:967
 #, fuzzy
 #| msgid "Mark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr "Tandai <register> sebagai telah terkorupsi oleh pemanggilan fungsi"
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr "Simpan register dalam pemanggilan fungsi"
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr "Bandingkan hasil dari beberapa data dependence penganalisa."
 
-#: common.opt:979
+#: common.opt:982
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++"
 msgstr "Periksa nilai kembali dari new"
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr "Jangan letakan tidak terinisialisasi global dalam daerah umum"
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr ""
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr ""
 
-#: common.opt:1003
+#: common.opt:1006
 #, fuzzy
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr "Lakukan penghapusan global common subexpression setelah alokasi register"
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr "Jangan lakukan optimisasi semakin meningkat dapat dinotifikasi penggunaan stack"
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr "Lakukan sebuah register tahap optimisasi copy-propagation"
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr "Lakukan optimisasi cross-jumping"
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr "Ketika menjalankan CSE, ikuti jump ke targetnya"
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr "Abaikan tahap reduksi jangkauan ketika menjalankan pembagian kompleks"
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr "Perkalian dan pembagian kompleks mengikuti aturan Fortran"
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr "Tempatkan data item kedalam daerah mereka"
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Daftar seluruh debugging counter yang tersedia dengan batasan dan jumlah mereka"
 
-#: common.opt:1043
+#: common.opt:1046
 #, fuzzy
 #| msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]    Set the debug counter limit.   "
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]    Set the debug counter batas.   "
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr "Petakan satu nama direktori ke yang lainnya dalam informasi debug"
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr "Defer popping fungsi args dari stack sampai kemudian"
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr "Coba untuk mengisi delay slot dalam instruksi percabangan"
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr "Hapus ketidak bergunaan pemeriksaan penunjuk kosong"
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization"
 msgstr "Lakukan formasi superblok melalaui duplikasi tail"
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1085
+#: common.opt:1088
 #, fuzzy
 #| msgid "How often to emit source location at the beginning of line-wrapped diagnostics"
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr "Seberapa sering mengeluarkan sumber lokasi di awal dari baris-wrapped diagnosa"
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr "Tambahkan pesan diagnosa yang sesuai dengan pilihan baris perintah yang mengontrolnya"
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1145
 #, fuzzy
 #| msgid "Dump various compiler internals to a file"
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr "Dump beberapa kompiler internal ke sebuah berkas"
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr ""
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr ""
 
-#: common.opt:1157
+#: common.opt:1160
 msgid "Suppress output of addresses in debugging dumps"
 msgstr "Tekan keluaran dari alamat dalam dump debugging"
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 #, fuzzy
 #| msgid "Do the full register move optimization pass"
 msgid "Dump optimization passes"
 msgstr "Lakukan tahap optimisasi register penuh"
 
-#: common.opt:1170
+#: common.opt:1173
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr "Tekan keluaran dari jumlah instruksi, catatan nomor baris dan alamat dalam debugging dumps"
 
-#: common.opt:1174
+#: common.opt:1177
 #, fuzzy
 #| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr "Tekan keluaran dari alamat dalam dump debugging"
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Aktfikan tabel CFI melalui direktif perakit GAS."
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr "Lakukan inlining awal"
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr "Lakukan penghapusan duplikasi DWARF2"
 
-#: common.opt:1190
+#: common.opt:1193
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural reduction of aggregates"
 msgstr "Lakukan propagasi konstanta interprosedural"
 
-#: common.opt:1194
+#: common.opt:1197
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info"
 msgstr "Lakukan penghapusan tidak tidak digunakan dalam informasi debug"
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr "Lakukan penghapusan tidak tidak digunakan dalam informasi debug"
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr "Jangan tekan informasi debug C++ class."
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "Aktifkan penanganan eksepsi"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr "Lakukan beberapa dari minor, ekspensi optimisasi"
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr ""
 
-#: common.opt:1217
+#: common.opt:1220
 #, fuzzy, c-format
 #| msgid "unknown demangling style '%s'"
 msgid "unknown excess precision style %qs"
 msgstr "gaya demangling '%s' tidak diketahui"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr "Asumsikan tidak ada NaN atau tidak terhingga dihasilkan"
 
-#: common.opt:1238
+#: common.opt:1241
 #, fuzzy
 #| msgid "Mark <register> as being unavailable to the compiler"
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr "Tandai <register> sebagai tidak tersedia ke kompiler"
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr "Jangan alokasikan float dan double dalam register presisi ekstended"
 
-#: common.opt:1250
+#: common.opt:1253
 msgid "Perform a forward propagation pass on RTL"
 msgstr "Lakukan sebuah tahap propagasi ke depan dalam RTL"
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, fuzzy, c-format
 #| msgid "Place floating point constants in TOC"
 msgid "unknown floating point contraction style %qs"
 msgstr "Tempatkan konstanta titik pecahan dalam TOC"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr "Ijinkan alamat fungsi untuk disimpan dalam register"
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr "Tempatkan setiap fungsi kedalam daerahnya masing-masing"
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr "Lakukan penghapusan global comman subexpression"
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr "Lakukan penghapusan enhanced load motion selama global common subexpression"
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr "Lakukan store motion setelah penghapusan global common subexpression"
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr "Lakukan redundansi load setelah penghapusan store dalam global common subexpressionn"
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr "Lakukan penghapusan global common subexpression setelah alokasi register"
 
-#: common.opt:1305
+#: common.opt:1308
 msgid "Enable in and out of Graphite representation"
 msgstr "Aktifkan in dan keluar dari representasi Graphite"
 
-#: common.opt:1309
+#: common.opt:1312
 msgid "Enable Graphite Identity transformation"
 msgstr "Aktifkan transformasi Graphite Identify"
 
-#: common.opt:1313
+#: common.opt:1316
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr ""
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr ""
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr "Aktifkan transformasi Loop Strip Mining"
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr "Aktifkan transformasi Loop Interchange"
 
-#: common.opt:1330
+#: common.opt:1333
 msgid "Enable Loop Blocking transformation"
 msgstr "Aktifkan transformasi Loop Blocking"
 
-#: common.opt:1334
+#: common.opt:1337
 #, fuzzy
 #| msgid "Enable Loop Interchange transformation"
 msgid "Enable Loop Unroll Jam transformation"
 msgstr "Aktifkan transformasi Loop Interchange"
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr "Aktifkan penerkaan kemungkinan dari percabangan"
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr "Proses #ident direktif"
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr "Lakukan konversi dari kondisional jump ke branchless ekuivalen"
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr "Lakukan konversi dari kondisional lompat ke kondisional eksekusi"
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Stack Reuse Level %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:1394
+#: common.opt:1397
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr "Lakukan konversi dari kondisional jump ke branchless ekuivalen"
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr ""
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr "Jangan hasilkan direktif .size"
 
-#: common.opt:1410
+#: common.opt:1413
 msgid "Perform indirect inlining"
 msgstr "Lakukan inlining tidak langsung"
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 #, fuzzy
 #| msgid "Integrate simple functions into their callers when code size is known to not growth"
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "Integrasikan fungsi sederhana kedalam pemanggilnya ketika ukuran kode diketahui tidak berkembang"
 
-#: common.opt:1424
+#: common.opt:1427
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "Integrasikan fungsi dipanggil sekali dalam pemanggilnya"
 
-#: common.opt:1428
+#: common.opt:1431
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions only required by their single caller"
 msgstr "Integrasikan fungsi dipanggil sekali dalam pemanggilnya"
 
-#: common.opt:1435
+#: common.opt:1438
 #, fuzzy
 #| msgid "Limit the size of inlined functions to <number>"
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr "Batasi ukuran dari fungsi diinline ke <angka>"
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr "Instrumen fungsi masukan dan keluaran dengan profiling panggilan"
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr "-finstrumen-functions-exclude-function-list=name,... jangan instrumen fungsi yang terdaftar"
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr "-finstrument-functions-exclude-file-list=filename,... Jangan instrumen fungsi yang terdaftar dalam berkas"
 
-#: common.opt:1455
+#: common.opt:1458
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation"
 msgstr "Lakukan propagasi konstanta interprosedural"
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr "Lakukan cloning untuk membuat propagasi konstanta lebih kuat antar prosedur"
 
-#: common.opt:1463
+#: common.opt:1466
 #, fuzzy
 #| msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr "Lakukan cloning untuk membuat propagasi konstanta lebih kuat antar prosedur"
 
-#: common.opt:1467
+#: common.opt:1470
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural profile propagation"
 msgstr "Lakukan propagasi konstanta interprosedural"
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr "Lakukan analisa interprosedural titik-ke"
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr "Temukan fungsi pure dan const"
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables"
 msgstr "Lakukan penguraian loop untuk semua loops"
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr "Temukan baca-saja dan variabel statis tidak beralamat"
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr "-fire-algorithm=[CB|prioritas] Set penggunaan algoritma IRA"
 
-#: common.opt:1506
+#: common.opt:1509
 #, fuzzy, c-format
 #| msgid "unknown ira algorithm \"%s\""
 msgid "unknown IRA algorithm %qs"
 msgstr "algoritma ira \"%s\" tidak diketahui"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr "-fira-region=[one|all|mixed] Set daerah untuk IRA"
 
-#: common.opt:1519
+#: common.opt:1522
 #, fuzzy, c-format
 #| msgid "unknown ira region \"%s\""
 msgid "unknown IRA region %qs"
 msgstr "daerah ira \"%s\" tidak diketahui"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr "Share slots untuk menyimpan register keras berbeda."
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Share stack slots untuk spilled pseudo-register."
 
-#: common.opt:1550
+#: common.opt:1553
 #, fuzzy
 #| msgid "-fira-verbose=<number> Control IRA's level of diagnostic messages."
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<angka>  Kontrol tingkat dari pesan diagnosa IRA."
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr "Optimasi variabel induksi dalam pohon"
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "Gunakan tabel jump untuk pernyataan secara mencukupi besar switch"
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr "Hasilkan kode untuk fungsi walaupun jika mereka secara penuh inlined"
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr "Keluarkan variabel statis const walapu mereka tidak digunakan"
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr "Berikan eksternal simbol sebuah awalan garis bawah"
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable link-time optimization."
 msgstr "Aktifkan optimasi penghubung"
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr ""
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Report various link-time optimization statistics"
 msgstr "Lakukan sebuah tahap optimisasi pengubahan nama register"
 
-#: common.opt:1625
+#: common.opt:1628
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr "Set errno setelah fungsi matematik bawaan"
 
-#: common.opt:1633
+#: common.opt:1636
 #, fuzzy
 #| msgid "Maximum number of errors to report"
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr "Jumlah maksimum dari error untuk dilaporkan"
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr "Laporkan pada alokasi memori permanen"
 
-#: common.opt:1641
+#: common.opt:1644
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only"
 msgstr "Laporkan pada alokasi memori permanen"
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr "Mencoba menggabungkan konstanta identik dan konstanta variabel"
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr "Mencoba menggabungkan konstanta identik melewati satuan kompilasi"
 
-#: common.opt:1656
+#: common.opt:1659
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr "Mencoba untuk menggabungkan debug string identik across satuan kompilasi"
 
-#: common.opt:1660
+#: common.opt:1663
 #, fuzzy
 #| msgid "Limit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr "Batasi diagnosa sampai <number> karakter per baris. 0 tekan line-wrapping"
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr "Lakukan penjadwalan berdasarkan SMS modulo sebelum tahap penjadwalan pertama"
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr "Lakukan penjadwalan berdasarkan module SMS dengan perpindahan register diperbolehkan"
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr "Move loop invarian komputasi diluar dari loops"
 
-#: common.opt:1676
+#: common.opt:1679
 msgid "Use the RTL dead code elimination pass"
 msgstr "Gunaka tahap penghapusan RTL kode mati"
 
-#: common.opt:1680
+#: common.opt:1683
 msgid "Use the RTL dead store elimination pass"
 msgstr "Gunakan tahap penghapusan RTL dead store"
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr "Aktifkan/Non-aktifkan penjadwalan tradisional dalam loop yang telah dilewatkan penjadwalan modulo"
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr "Dukung eksepsi sinkronous bukan panggilan"
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "assertion hilang setelah %qs"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 #| msgid "unknown tls-model \"%s\""
 msgid "unknown offload ABI %qs"
 msgstr "tls-model \"%s\" tidak dikenal"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr "Jika memungkinkan jangan hasilkan stack frames"
 
-#: common.opt:1713
+#: common.opt:1716
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable all optimization info dumps on stderr"
 msgstr "Aktifkan optimasi loop pada tingkat pohon"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr "Optimisasi sibling dan tail rekursi calls"
 
-#: common.opt:1729
+#: common.opt:1732
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform partial inlining"
 msgstr "Lakukan inlining awal"
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr "Laporkan dalam alokasi memori sebelum optimisasi interprosedural"
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr "Pack anggota struktur bersama tanpa lubang"
 
-#: common.opt:1745
+#: common.opt:1748
 #, fuzzy
 #| msgid "Set initial maximum structure member alignment"
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr "Set inisial maksimal alignmen anggota struktur"
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr "Kembali agregate kecil dalam memori, bukan register"
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr "Lakukan loop peeling"
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr "Aktifkan mesin spesifik peephole optimisasi"
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr "Aktifkan sebuah tahap RTL peephole sebelum sched2"
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr "Hasilkan kode bebas posisi jika memungkinkan (mode besar)"
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr "Hasilkan kode bebas posisi untuk executables jika memungkinkan (mode besar)"
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr "Hasilkan kode bebas posisi jika memungkinkan (mode kecil)"
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr "Hasilkan kode bebas posisi untuk executables jika memungkinkan (mode kecil)"
 
-#: common.opt:1781
+#: common.opt:1784
 #, fuzzy
 #| msgid "Specify options to GNAT"
 msgid "Specify a plugin to load"
 msgstr "Spesifikasikan pilihan ke GNAT"
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr ""
 
-#: common.opt:1789
+#: common.opt:1792
 msgid "Run predictive commoning optimization."
 msgstr "Jalankan optimisasi prediktif commoning."
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr "Hasilkan instruksi prefetch, jika tersedia, untuk array dalam loops"
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr "Aktifkan aplikasi dasar profiling kode"
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr "Masukan aplikasi berbasis arc profiling kode"
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr "Set direktori tingkat atas untuk menyimpan data profile."
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr "Aktifkan koreksi dari alur profile tidak konsisten masukan data"
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr "Aktifkan pilihan umum untuk menghasilkan informasi profile untuk feedback profile direkted optimisasi"
 
-#: common.opt:1818
+#: common.opt:1821
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Aktifkan pilihan umum untuk menghasilkan informasi profile untuk feedback profile direkted optimisasi, dan set -fprofile-dir="
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr "Aktifkan pilihan umum untuk melakukan profile feedback directed optimisasi"
 
-#: common.opt:1826
+#: common.opt:1829
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "Aktifkan pilihan umum untuk melakukan profile feedback directed optimisasi, dan set -fprofile-dir="
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr "Masukan kode untuk profile nilai dari ekspresi"
 
-#: common.opt:1834
+#: common.opt:1837
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Report on consistency of profile"
 msgstr "kegagalan konsistensi internal"
 
-#: common.opt:1838
+#: common.opt:1841
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement"
 msgstr "Urutkan kembali fungsi untuk meningkatkan penempatan kode"
 
-#: common.opt:1845
+#: common.opt:1848
 #, fuzzy
 #| msgid "Make compile reproducible using <string>"
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr "Buat kompile reproducible menggunakan <string>"
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr "Rekam pilihan baris perintah gcc dalam berkas objek."
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr "Kembali kumpulan kecil dalam registers"
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr ""
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr "Lakukan sebuah tahap optimisasi pengubahan nama register"
 
-#: common.opt:1880
+#: common.opt:1883
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr "Lakukan sebuah tahap optimisasi pengubahan nama register"
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr "Urutkan kembali blok dasar untuk meningkatkan penempatan kode"
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr "Urutkan kembali blok dasar dan partisi kedalam daerah panas dan dingin"
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr "Urutkan kembali fungsi untuk meningkatkan penempatan kode"
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr "Tambahkan sebuah tahap penghapusan umum subexpression setelah optimisasi loop"
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr "Non-aktifkan optimisasi yang mengasumsikan perilaku baku pembulatan titik pecahan"
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr "Aktifkan penjadwalan melewati blok dasar"
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr "Ijinkan perpindahan spekulasi dari bukan loads"
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr "Ijinkan perpindahan spekulasi dari beberapa loads"
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr "Ijinkan spekulasi motion dari beberapa loads"
 
-#: common.opt:1928
+#: common.opt:1931
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr "Set tingkat verbositas dari penjadwal"
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr "Jika penjadwalan post reload, lakukan penjadwalan superblok"
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr "Atur penjadwalan instruksi sebelum alokasi register"
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr "Atur penjadwalan instruksi setelah alokasi register"
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr "Instruksi penjadwalan menggunakan algoritma penjadwalan selektif"
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr "Jalankan penjadwalan selektif setelah reload"
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr "Lakukan software pipelining dari loops dalam selama penjadwalan selektif"
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr "Lakukan software pipelining dari loops luar selama penjadwalan selektif"
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr "Reschedule daerah pipelined tanpa pipelining"
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr "Ijinkan premature penjadwalan dari antrian instruksi"
 
-#: common.opt:1981
+#: common.opt:1984
 #, fuzzy
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr "Set jumlah dari antrian instruksi yang dapat secara permature dijadwalkan"
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr "Set dependence pemeriksaan jarak dalam premature penjadwalan dari antrian instruksi"
 
-#: common.opt:1993
+#: common.opt:1996
 #, fuzzy
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr "Set dependence pemeriksaan jarak dalam premature penjadwalan dari antrian instruksi"
 
-#: common.opt:1997
+#: common.opt:2000
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the group heuristic in the scheduler"
 msgstr "Set tingkat verbositas dari penjadwal"
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2009
+#: common.opt:2012
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the rank heuristic in the scheduler"
 msgstr "Set tingkat verbositas dari penjadwal"
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr "Akses data dalam daerah sama dari titik achor terbagi"
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 #, fuzzy
 #| msgid "Show column numbers in diagnostics, when available.  Default off"
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr "Tampilkan jumlah kolom dalam diagnosa, jika tersedia. Baku tidak aktif"
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr "Non-aktifkan optimisasi dilihat oleh IEEE pensinyalan NaN"
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr "Non-aktifkan optimisasi titik pecahan yang mengabaikan IEEE signedness dari nol"
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr "Ubah konstanta titik pecahan ke konstanta presisi tunggal"
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr "Bagi waktu-hidup dari variabel induksi ketika loops diunroll"
 
-#: common.opt:2062
+#: common.opt:2065
 #, fuzzy
 #| msgid "Generate APCS conformant stack frames"
 msgid "Generate discontiguous stack frames"
 msgstr "Hasilkan APCS konforman stack frames"
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr "Bagi tipe lebar kedalam register independent"
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr ""
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr "Aplikasikan ekspansi variabel ketika loops diuraikan"
 
-#: common.opt:2082
+#: common.opt:2085
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "Masukan pemeriksaan kode stack kedalam aplikasi"
 
-#: common.opt:2086
+#: common.opt:2089
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "Masukan pemeriksaan kode stack kedalam aplikasi. Sama seperti -fstack-check=specific"
 
-#: common.opt:2093
+#: common.opt:2096
 #, fuzzy
 #| msgid "Trap if the stack goes past <register>"
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr "Trap jika stact pergi melampaui <register>"
 
-#: common.opt:2097
+#: common.opt:2100
 #, fuzzy
 #| msgid "Trap if the stack goes past symbol <name>"
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr "Trap jika stack pergi melampaui simbol <nama>"
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr "Gunakan propolice sebagai sebuah metode proteksi stack"
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr "Gunakan sebuah metode proteksi stact untuk setiap fungsi"
 
-#: common.opt:2109
+#: common.opt:2112
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions"
 msgstr "Gunakan sebuah metode proteksi stact untuk setiap fungsi"
 
-#: common.opt:2113
+#: common.opt:2116
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr "Gunakan sebuah metode proteksi stact untuk setiap fungsi"
 
-#: common.opt:2117
+#: common.opt:2120
 #, fuzzy
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output stack usage information on a per-function basis"
 msgstr "Reuse r30 di sebuah per fungsi dasar"
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr "Asumsikan aturan strict aliasing berjalan"
 
-#: common.opt:2133
+#: common.opt:2136
 msgid "Treat signed overflow as undefined"
 msgstr "Perlakukan signed overflow sebagai tidak terdefinisi"
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr "Periksa untuk sintaks errors kemudian berhenti"
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr "Buat sebuah berkas data dibutuhkan oleh \"gcov\""
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr "Lakukan optimasi jump threading"
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr "Laporkan waktu yang diambil oleh setiap tahap kompiler"
 
-#: common.opt:2157
+#: common.opt:2160
 #, fuzzy
 #| msgid "Set the default thread-local storage code generation model"
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr "Set mode baku pembuatan kode TLS"
 
-#: common.opt:2160
+#: common.opt:2163
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown TLS model %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr "Urutkan kembali fungsi tingkat atas, variabel, dan asm"
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr "Lakukan formasi superblok melalaui duplikasi tail"
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr "Asumsikan operasi titik pecahan dapat trap"
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr "Trap untuk signed overflow dalam penambahan, pengurangan dan perkalian"
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr "Aktifkan optimasi SSA-CCP pada pohon"
 
-#: common.opt:2199
+#: common.opt:2202
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr "Aktifkan optimasi SSA-CCP pada pohon"
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr "Aktifkan penyalinan loop header pada pohon"
 
-#: common.opt:2211
+#: common.opt:2214
 #, fuzzy
 #| msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr "Lakukan pelacakan variabel dan juga variabel tag yang tidak terinisialisasi"
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr "Gantikan SSA temporaries dengan nama yang lebih baik dalam salinan"
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr "Aktifkan salin propagasi pada pohon"
 
-#: common.opt:2231
+#: common.opt:2234
 msgid "Transform condition stores into unconditional ones"
 msgstr "Transformasi kondisi stores kedalam tidak terkondisi satu"
 
-#: common.opt:2235
+#: common.opt:2238
 msgid "Perform conversions of switch initializations."
 msgstr "Lakukan konversi dari kondisional switch."
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr "Aktifkan optimasi penghapusan kode mati SSA pada pohon"
 
-#: common.opt:2243
+#: common.opt:2246
 msgid "Enable dominator optimizations"
 msgstr "Aktifkan optimasi dominator"
 
-#: common.opt:2247
+#: common.opt:2250
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable tail merging on trees"
 msgstr "Aktifkan penyalinan loop header pada pohon"
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr "Aktifkan penghapusan dead store"
 
-#: common.opt:2255
+#: common.opt:2258
 #, fuzzy
 #| msgid "Enable copy propagation on trees"
 msgid "Enable forward propagation on trees"
 msgstr "Aktifkan salin propagasi pada pohon"
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr "Aktifkan Penghapusan Redundasi Penuh (FRE) pada pohon"
 
-#: common.opt:2263
+#: common.opt:2266
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable string length optimizations on trees"
 msgstr "Aktifkan optimasi SSA-CCP pada pohon"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 msgid "Enable loop distribution on trees"
 msgstr "Aktifkan loop distribusi pada pohon"
 
-#: common.opt:2284
+#: common.opt:2287
 #, fuzzy
 #| msgid "Enable loop distribution on trees"
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr "Aktifkan loop distribusi pada pohon"
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr "Aktifkan loop tidak variant pergerakan pada pohon"
 
-#: common.opt:2292
+#: common.opt:2295
 #, fuzzy
 #| msgid "Enable Loop Interchange transformation"
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr "Aktifkan transformasi Loop Interchange"
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr "Buat variabel induksi kanonikal dalam loops"
 
-#: common.opt:2300
+#: common.opt:2303
 msgid "Enable loop optimizations on tree level"
 msgstr "Aktifkan optimasi loop pada tingkat pohon"
 
-#: common.opt:2304
+#: common.opt:2307
 msgid "Enable automatic parallelization of loops"
 msgstr "Aktifkan paralelisasi otomatis dari loops"
 
-#: common.opt:2308
+#: common.opt:2311
 #, fuzzy
 #| msgid "Enable conditional moves"
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Aktifkan perpindahan kondisional"
 
-#: common.opt:2312
+#: common.opt:2315
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "Aktifkan SSA-PRE optimisasi pada pohon"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 #, fuzzy
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Lakukan analisa interprosedural titik-ke"
 
-#: common.opt:2324
+#: common.opt:2327
 msgid "Enable reassociation on tree level"
 msgstr "Aktifkan reasosiasi pada tingkat pohon"
 
-#: common.opt:2332
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
 msgstr "Aktifkan penenggelaman kode SSA pada pohon"
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr ""
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr "Lakukan penggantian skalar dari kumpulan"
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr "Gantikan ekspresi sementara dalam tahap SSA->normal"
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr "Lakukan jangkauan hidup pemisahaan selama tahap SSA->normal"
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr "Lakukan Propagasi Jangkauan Nilai pada pohon"
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr "Kompile seluruh satuan kompilasi di satu waktu"
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr "Lakukan penguraian loop ketika jumlah iterasi diketahui"
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr "Lakukan penguraian loop untuk semua loops"
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr "Ijinkan optimasi loop untuk mengasumsikan bahwa loop berperilaku secara normal"
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr "Ijinkan optimisasi untuk aritmetik titik pecahan dimana mungkin mengubah"
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Sama seperti -fassociative-math untuk ekspresi yang memasukan pembagian."
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr "Ijinkan optimisasi matematik yang mungkin melanggar standar  IEEE atau ISO"
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr "Lakukan loop unswitching"
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr "Buat tabel unwind untuk penanganan eksepsi"
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr "Lakukan pelacakan variabel"
 
-#: common.opt:2424
+#: common.opt:2427
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments"
 msgstr "Lakukan pelacakan variabel"
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr ""
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr "Lakukan pelacakan variabel dan juga variabel tag yang tidak terinisialisasi"
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees"
 msgstr "Aktifkan vektorisasi loop pada pohon"
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr "Aktifkan vektorisasi loop pada pohon"
 
-#: common.opt:2454
+#: common.opt:2457
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr "Aktifkan vektorisasi loop pada pohon"
 
-#: common.opt:2458
+#: common.opt:2461
 #, fuzzy
 #| msgid "Enable use of cost model in vectorization"
 msgid "Specifies the cost model for vectorization"
 msgstr "Aktifkan penggunaan dari model biaya dalam vektorisasi"
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:2478
+#: common.opt:2481
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Tidak melakukan apa-apa. Dijaga untuk kompabilitas versi sebelumnya."
 
-#: common.opt:2482
+#: common.opt:2485
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Tidak melakukan apa-apa. Dijaga untuk kompabilitas versi sebelumnya."
 
-#: common.opt:2490
+#: common.opt:2493
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Aktifkan propagasi penyalinan dari informasi skalar-evolusi."
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr "Tambahkan ekstra komentar ke keluaran perakit"
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr ""
 
-#: common.opt:2507
+#: common.opt:2510
 #, fuzzy, c-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "nilai visibility \"%s\" tidak dikenal"
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(dekat inisialisasi untuk %qs)"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr "Gunakan nilai ekspresi profiles dalam optimisasi"
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr "Konstruksi webs dan pisahkan penggunaan tidak berelasi dari variabel tunggal"
 
-#: common.opt:2555
+#: common.opt:2558
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr "Aktifkan kondisional penghapusan kode mati untuk panggilan bawaan"
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr "Lakukan optimisasi seluruh aplikasi"
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr "Asumsikan perbaikan signed aritmetik overflow"
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr "Tempatkan nol data terinisialisasi dalam daerah bss"
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr "Hasilkan informasi debug dalam format COFF"
 
-#: common.opt:2579
+#: common.opt:2582
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format"
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:2583
+#: common.opt:2586
 #, fuzzy
 #| msgid "Generate debug information in DWARF v2 format"
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr "Hasilkan informasi debug dalam formas DWARF v2"
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr "Hasilkan informasi debug dalam format baku extended"
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 #, fuzzy
 #| msgid "Record gcc command line switches in the object file."
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Rekam pilihan baris perintah gcc dalam berkas objek."
 
-#: common.opt:2607
+#: common.opt:2610
 #, fuzzy
 #| msgid "Record gcc command line switches in the object file."
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Rekam pilihan baris perintah gcc dalam berkas objek."
 
-#: common.opt:2611
+#: common.opt:2614
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Don't generate debug information in separate .dwo files"
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:2615
+#: common.opt:2618
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files"
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr "Hasilkan informasi debug dalam format STABS"
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr "Hasilkan informasi debug dalam formas STABS extended"
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2638
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation"
 msgstr "Hasilkan informasi debug dalam format VMS"
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr "Hasilkan informasi debug dalam format VMS"
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr "Hasilkan informasi debug dalam format XCOFF"
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr "Hasilkan informasi debug dalam format XCOFF extended"
 
-#: common.opt:2665
+#: common.opt:2668
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections"
 msgstr "Hasilkan instruksi isel"
 
-#: common.opt:2669
+#: common.opt:2672
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:2676
+#: common.opt:2679
 #, fuzzy
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr "-multilib <dir> Set <dir> untuk menjadi multilib inlude subdirektori"
 
-#: common.opt:2680
+#: common.opt:2683
 #, fuzzy
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr "-multilib <dir> Set <dir> untuk menjadi multilib inlude subdirektori"
 
-#: common.opt:2702
+#: common.opt:2705
 #, fuzzy
 #| msgid "Place output into <file>"
 msgid "-o <file>\tPlace output into <file>"
 msgstr "Tempatkan keluaran kedalam <berkas>"
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr "Aktifkan profiling fungsi"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr "Seperti -pedantic tetapi menisukannya sebagai errors"
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr "Jangan tampilkan fungsi yang dikompile atau waktu yang sudah lewat"
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr "Aktifkan keluaran verbose"
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr "Tampilkan versi dari kompiler"
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "Tekan peringatan"
 
-#: common.opt:2806
+#: common.opt:2809
 msgid "Create a shared library"
 msgstr "Buat sebuah perpustakaan terbagi"
 
-#: common.opt:2851
+#: common.opt:2854
 msgid "Create a position independent executable"
 msgstr "Buat sebuah aplikasi bebas posisi"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "nilai dihitung tidak digunakan"
@@ -15897,299 +15907,299 @@
 msgid "expected integer or boolean type"
 msgstr "diduga ekspresi integer"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 #, fuzzy
 #| msgid "invalid operand to switch statement"
 msgid "invalid comparison of nil with nil"
 msgstr "operan tidak valid ke pernyataan switch"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 #, fuzzy
 #| msgid "incompatible types in return"
 msgid "incompatible types in binary expression"
 msgstr "tipe tidak kompatibel dalam kembali"
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 #| msgid "division by zero"
 msgid "integer division by zero"
 msgstr "pembagian dengan nol"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 #, fuzzy
 #| msgid "size of array %qs has non-integer type"
 msgid "shift of non-integer operand"
 msgstr "ukuran dari array %qs memiliki tipe bukan integer"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 #, fuzzy
 #| msgid "switch quantity not an integer"
 msgid "shift count not unsigned integer"
 msgstr "switch kuantiti bukan sebuah integer"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 #, fuzzy
 #| msgid "negative insn length"
 msgid "negative shift count"
 msgstr "panjang insn negatif"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 #, fuzzy
 #| msgid "called object %qE is not a function"
 msgid "object is not a method"
 msgstr "dipanggil objek %qE bukan sebuah fungsi"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 #, fuzzy
 #| msgid "argument of type %qT does not match %qT"
 msgid "method type does not match object type"
 msgstr "argumen dari tipe %qT tidak cocok dengan %qT"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 #, fuzzy
 #| msgid "invalid argument to built-in function"
 msgid "invalid use of %<...%> with builtin function"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 #, fuzzy
 #| msgid "%Hinvalid use of template-name %qE without an argument list"
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "%Hpenggunaan tidak vlaid dari nama template %qE tanpa sebuah daftar argumen"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 #, fuzzy
 #| msgid "no arguments"
 msgid "not enough arguments"
 msgstr "tidak ada argumen"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 #, fuzzy
 #| msgid "too many arguments for format"
 msgid "too many arguments"
 msgstr "terlalu banyak argumen untuk format"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 #, fuzzy
 #| msgid "argument must be a constant"
 msgid "argument 1 must be a map"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 #, fuzzy
 #| msgid "invalid pure const state for function"
 msgid "invalid type for make function"
 msgstr "pure const state tidak valid untuk fungsi"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 #, fuzzy
 #| msgid "too many arguments for format"
 msgid "too many arguments to make"
 msgstr "terlalu banyak argumen untuk format"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 #, fuzzy
 #| msgid "argument must be a constant"
 msgid "argument must be array or slice or channel"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 #, fuzzy
 #| msgid "invalid argument to built-in function"
 msgid "unsupported argument type to builtin function"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 #, fuzzy
 #| msgid "argument must be a constant"
 msgid "argument must be channel"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 #, fuzzy
 #| msgid "last argument must be an immediate"
 msgid "argument must be a field reference"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 #, fuzzy
 #| msgid "last argument must be an immediate"
 msgid "left argument must be a slice"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 #, fuzzy
 #| msgid "last argument must be an immediate"
 msgid "first argument must be []byte"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 #, fuzzy
 #| msgid "argument must be a constant"
 msgid "second argument must be slice or string"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 #, fuzzy
 #| msgid "%Jparameter %u has void type"
 msgid "argument 2 has invalid type"
 msgstr "%J parameter %u memiliki tipe void"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 #, fuzzy
 #| msgid "%Jparameter %u has incomplete type"
 msgid "argument must have complex type"
 msgstr "%J parameter %u memiliki tipe tidak lengkap"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 #, fuzzy
 #| msgid "cleanup argument not an identifier"
 msgid "complex arguments must have identical types"
 msgstr "membersihkan argumen bukan sebuah identifikasi"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 #, fuzzy
 #| msgid "Do not use hardware floating point"
 msgid "complex arguments must have floating-point type"
 msgstr "Jangan gunakan piranti keras titik pecahan"
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 #, fuzzy
 #| msgid "deleted function %q+D"
 msgid "expected function"
 msgstr "fungsi %q+D terhapus"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 msgid "multiple-value argument in single-value context"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 #, fuzzy
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<...%> with non-slice"
 msgstr "penggunaan tidak valid ari %<this%> di tingkat paling atas"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 #, fuzzy
 #| msgid "Function return value not set"
 msgid "function result count mismatch"
 msgstr "Fungsi mengembalikan nilai tidak diset"
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 #, fuzzy
 #| msgid "incompatible types in return"
 msgid "incompatible type for receiver"
 msgstr "tipe tidak kompatibel dalam kembali"
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 #, fuzzy
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "penggunaan tidak valid dari %<this%> dalam fungsi bukan anggota"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 #, fuzzy
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "number of results does not match number of values"
 msgstr "jumlah ujung masukan tidak cocok dengan jumlah dari argumen PHI"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 #, fuzzy
 #| msgid "Cray pointer at %C must be an integer"
 msgid "index must be integer"
 msgstr "Penunjuk Cray di %C harus berupa sebuah integer"
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 #, fuzzy
 #| msgid "Cray pointer at %C must be an integer"
 msgid "slice end must be integer"
 msgstr "Penunjuk Cray di %C harus berupa sebuah integer"
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 #| msgid "switch quantity not an integer"
 msgid "slice capacity must be integer"
 msgstr "switch kuantiti bukan sebuah integer"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 #, fuzzy
 #| msgid "incompatible types in return"
 msgid "incompatible type for map index"
 msgstr "tipe tidak kompatibel dalam kembali"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 #, fuzzy
 #| msgid "too many arguments for format"
 msgid "too many expressions for struct"
 msgstr "terlalu banyak argumen untuk format"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 #, fuzzy
 #| msgid "too few arguments for format"
 msgid "too few expressions for struct"
 msgstr "terlalu sedikit argumen untuk format"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 msgid "type assertion only valid for interface types"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 #, fuzzy
 #| msgid "expected class name"
 msgid "expected channel"
 msgstr "diduga nama class"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -16331,83 +16341,83 @@
 msgid "cannot use type %s as type %s"
 msgstr "tidak dapat mengubah tipe %qT ke tipe %qT"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 #, fuzzy
 #| msgid "invalid receiver type %qs"
 msgid "different receiver types"
 msgstr "tipe penerima %qs tidak valid"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "different number of parameters"
 msgstr "redefinisi dari parameter %q+D"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 #, fuzzy
 #| msgid "invalid parameter type %qT"
 msgid "different parameter types"
 msgstr "tipe parameter %qT tidak valid"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "incompatible type for method %s%s%s"
 msgstr "tipe tidak kompatibel untuk argumen %d dari %qE"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "tipe tidak kompatibel untuk argumen %d dari %qE"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 #, fuzzy
 #| msgid "error while parsing methods"
 msgid "type has no methods"
 msgstr "error ketika parsing metoda"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, fuzzy, c-format
 #| msgid "ambiguous abbreviation %s"
 msgid "ambiguous method %s%s%s"
 msgstr "kependekan %s ambigu"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, fuzzy, c-format
 #| msgid "missing argument to \"%s\""
 msgid "missing method %s%s%s"
 msgstr "hilang argumen ke \"%s\""
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -16537,7 +16547,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "argumen ketiga ke %<__builtin_prefetch%> tidak valid; menggunakan nol"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "terlalu sedikit argumen ke fungsi %<va_start%>"
@@ -16727,12 +16737,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kmencoba membebaskan sebuah objek bukan heap"
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "pemanggilan fungsi memiliki nilai bersama"
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "passing too large argument on stack"
@@ -17325,248 +17335,253 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "jumlah dari catatan bb dalam rantai instruksi (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr "jumlah ujung pemanggil negatif"
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr "frekuensi ujung pemanggil negatif"
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr "frekuensi ujung pemanggil terlalu besar"
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "field tambahan diset untuk ujung  %s->%s"
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, fuzzy, gcc-internal-format
 #| msgid "Execution count is negative"
 msgid "execution count is negative"
 msgstr "Jumlah eksekusi negatif"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Asumsikan simbol mungkin tidak valid"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "aux field set for edge %s->%s"
 msgid "aux field set for indirect edge from %s"
 msgstr "field tambahan diset untuk ujung  %s->%s"
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "penunjuk inlined_to salah"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "multiple pemanggil inline"
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "penunjuk inlined_to diset untuk pemanggil bukan inline"
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "caller edge frequency is too large"
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr "frekuensi ujung pemanggil terlalu besar"
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "penunjuk inlined_to diset tetapi tidak ada predecessor ditemukan"
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "penunjuk inlined_to mereferensikan ke dirinya sendiri"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "shared call_stmt:"
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "titik ujung ke deklarasi salah:"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "hilang ujung callgraph untuk pemanggilan stmt:"
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "diduga pernyataan"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "ujung %s->%s tidak memiliki korespondensi call_stmt"
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "edge %s->%s has no corresponding call_stmt"
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "ujung %s->%s tidak memiliki korespondensi call_stmt"
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node gagal"
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to '-%s' is missing"
 msgid "%s: section %s is missing"
@@ -17710,7 +17725,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
@@ -17964,17 +17979,17 @@
 msgid "          %s"
 msgstr "          %s"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr "informasi debug simbol umum tidak terstruktur seperti simbol+ofset"
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "global desktruktor tidak didukung di target ini"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "global konstruktor tidak didukung di target ini"
@@ -18021,12 +18036,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -18231,7 +18246,7 @@
 msgid "total size of local objects too large"
 msgstr "%J ukuran total dari objek lokal terlalu besar"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "batasan tidak memungkinkan dalam %<asm%>"
@@ -18728,9 +18743,9 @@
 msgstr "tidak dapat menulis berkas PCH"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
@@ -18746,172 +18761,166 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr "pemeriksaan gimple: diduga %s(%s), memiliki %s(%s) dalam %s, di %s:%d"
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "using result of function returning %<void%>"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "lvalue tidak valid dalam keluaran asm %d"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "masukan %d bukan memori harus tetap berada dalam memori"
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "masukan memori %d tidak secara langsung dapat dialamatkan"
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing target region"
 msgstr "%Hparallel yang melingkupi"
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing task"
 msgstr "%Hparallel yang melingkupi"
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing parallel"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing parallel"
 msgstr "%Hparallel yang melingkupi"
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing task"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing teams construct"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 #| msgid "%Hiteration variable %qE is unsigned"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%H variabel iterasi %qE unsigned"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should be private"
 msgstr "iterasi variabel %qs seharusnya private"
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qD should not be firstprivate"
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be reduction"
 msgstr "iterasi variabel %qs seharusnya bukan reduksi"
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qD should not be firstprivate"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should not be private"
 msgstr "iterasi variabel %qs seharusnya private"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s variabel %qs private dalam konteks luar"
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%s variable %qE is private in outer context"
 msgstr "%s variabel %qs private dalam konteks luar"
 
-#: gimplify.c:7001
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, fuzzy, gcc-internal-format
-#| msgid "%s variable %qs is private in outer context"
-msgid "lastprivate variable %qE is private in outer context"
-msgstr "%s variabel %qs private dalam konteks luar"
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
-#, fuzzy, gcc-internal-format
 #| msgid "Finalization at %L is not yet implemented"
 msgid "directive not yet implemented"
 msgstr "Finalisasi di %L belum diimplementasikan"
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "diduga %<}%> sebelum %<else%>"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification gagal"
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "argumen pertama ke %<va_arg%> bukan dari tipe %<va_list%>"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT dipromosikan ke %qT ketika dilewatkan melalui %<...%>"
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(jadi anda harus melewatkan %qT bukan %qT ke %<va_arg%>)"
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "jika kode ini dicapai, aplikasi akan digagalkan"
@@ -19340,49 +19349,49 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot find LTO cgraph in %s"
 msgstr "tidak dapat menemukan class %qs"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find protocol declaration for %qs"
 msgid "cannot find LTO section refs in %s"
 msgstr "tidak dapat menemukan deklarasi protokol untuk %qs"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -19469,51 +19478,51 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "tidak ada berkas masukan"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 #| msgid "%s:error writing output file '%s'\n"
 msgid "writing output file"
 msgstr "%s:error menulis berkas keluaran '%s'\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "variabel lingkungan DJGPP tidak didefinisikan"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "variabel lingkungan DJGPP tidak didefinisikan"
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen: %s: %m"
@@ -19654,13 +19663,13 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid exit from OpenMP structured block"
 msgid "invalid exit from %s structured block"
 msgstr "exit tidak valid dari blok struktur OpenMP"
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid entry to OpenMP structured block"
 msgid "invalid entry to %s structured block"
@@ -19667,19 +19676,19 @@
 msgstr "masukan tidak valid ke blok struktur OpenMP"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid branch to/from an OpenMP structured block"
 msgid "invalid branch to/from %s structured block"
 msgstr "cabang tidak valid ke/dari sebuah blok struktur OpenMP"
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "ignoring large linear step"
 msgstr "mengabaikan duplikasi direktori \"%s\"\n"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -20242,8 +20251,8 @@
 msgstr "tidak dapat menggunakan '%s' sebagai sebuah register %s"
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "nama register: %s tidak dikenal"
@@ -20703,7 +20712,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld menghasilkan status keluaran %d"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F digunakan tetapi tidak pernah didefinisikan"
@@ -21746,42 +21755,42 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr ""
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -22180,51 +22189,51 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "array subscript is outside array bounds"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is above array bounds"
 msgid "array subscript is above array bounds"
 msgstr "%H array subscript diatas dari array bounds"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is below array bounds"
 msgid "array subscript is below array bounds"
 msgstr "%Harray subscrip dibawah dari array bounds"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr "diasumsikan signed overflow tidak terjadi ketika menyederhakan kondisi ke konstanta"
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr "diasumsikan signed overflow tidak terjadi ketika menyederhanakan kondisional"
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr "perbandingan selalu salah karena jangkauan terbatas dari tipe data"
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr "perbandingan selalu benar karena jangkauan terbatas dari tipe data"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when simplifying && or || to & or |"
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr "diasumsikan signed overflow tidak terjadi ketika menyederhanakan && atau || ke & atau |"
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when simplifying && or || to & or |"
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
@@ -22269,9 +22278,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -22518,7 +22527,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "alignmen yang diminta untuk %q+D lebih besar dari alignmen yang diimplementasikan dari %wu"
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "ukuran penyimpanan dari %q+D tidak diketahui"
@@ -22678,27 +22687,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "panjang string %qd lebih besar daripada panjang %qd ISO C%d kompiler dibutuhkan untuk mendukung"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "jumlah geser kiri negatif"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "jumlah geser kanan negatif"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "jumlah geser kiri >= lebar dari tipe"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "jumlah geser kanan >= lebar dari tipe"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overflow dalam konstanta ekspresi"
@@ -23034,12 +23043,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "alamat dari %qD akan selalu dievaluasi sebagai %<true%>"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "disarankan parentheses disekitar assignmen digunakan sebagai nilai kebenaran"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "penggunaan tidak valid dari %<restrict%>"
@@ -23529,12 +23538,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "tipe vektori tidak valid untuk atribut %qE"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "ukuran vektor bukan sebuah kelipatan integral dari ukuran komponen"
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "ukuran vektor nol"
@@ -23544,22 +23553,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr "jumlah dari komponen dari vektor bukan kelipatan dari dua"
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "atribut bukan null tanpa argumen di sebuah bukan prototipe"
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "argumen bukan null memiliki jumlah operan tidak valid (argumen %lu)"
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "argumen bukan null dengan diluar-dari-jangkauan jumlah operan (argumen %lu, operan %lu)"
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "referensi argumen nonnull operan bukan penunjuk (argumen %lu, operan %lu)"
@@ -23599,12 +23608,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "%qE atribut hanya berlaku untuk fungsi variadic"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "posisi yang diminta bukan sebuah konstanta integer"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "posisi yang diminta lebih kecil dari nol"
@@ -23691,7 +23700,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "mencoba untuk mengambil alamat dari bit-field anggota struktur %qD"
@@ -24141,7 +24150,7 @@
 msgstr "indeks dalam dimensi %d diluar dari jangkauan di %L"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -24609,7 +24618,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
@@ -24619,22 +24628,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE tidak terinisialisasi"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "hilang predikat pengontrol"
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predikat pengontrol tidak valid"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "hilang ekspresi peningkatan"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ekspresi peningkatan tidak valid"
@@ -25192,6 +25201,12 @@
 msgid "too many input files"
 msgstr "terlalu banyak berkas masukan"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+#| msgid "stack frame too large"
+msgid "-mcpu string too large"
+msgstr "stack frame terlalu besar"
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -25218,54 +25233,54 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s memiliki revisi silikon tidak valid"
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-loops%s is obsolete, use -falign-loops%s"
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "%salign-loops%s sudah ditinggalkan, gunakan -falign-loops%s"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s tidak berada diantara 0 dan %d"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-jumps%s is obsolete, use -falign-jumps%s"
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "%salign-jumps%s sudah ditinggalkan, gunakan -falign-jumps%s"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s tidak berada diantara 0 dan %d"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-functions%s is obsolete, use -falign-functions%s"
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "%salign-functions%s sudah ditinggalkan, gunakan -falign-functions%s"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s tidak berada diantara 0 dan %d"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%sbranch-cost=%d%s is not between 0 and 5"
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "%sbranch-cost=%d%s tidak berada diantara 0 dan 5"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -25677,64 +25692,64 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr ""
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "nilai buruk %qs untuk pilihan -mtrap-precision"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "nilai buruk %qs untuk pilihan -mfp-rounding-mode"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "nilai buruk %qs untuk pilihan -mfp-trap-mode"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr "nilai buruk %qs untuk pilihan -mcpu"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "bad value %qs for -mtune switch"
 msgstr "nilai buruk %qs untuk pilihan -mcpu"
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr "fp software completion membutuhkan -mtrap-precision=i"
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "mode pembulatan tidak didukung untuk VAX floats"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "mode trap tidak didukung untuk VAX floats"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr "128-bit long double tidak didukung untuk VAX floats"
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr "L%d cache latensi tidak diketahui untuk %s"
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr "nilai buruk %qs untuk -mmemory-latency"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -26225,14 +26240,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
@@ -26927,47 +26942,53 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "tidak dapat menset posisi dalam berkas PCH: %m"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-Werror=%s: No option -%s"
 msgid "wrong arg %s to option %s"
 msgstr "-Werror=%s: Tidak ada pilihan -%s"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "nama register tidak dispesifikasikan untuk %q+D"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
+#, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386.c:3012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %s specified for option %s"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %s"
 msgstr "tidak ada nama class dispesifikasikan dengan %qs"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown argument list function at %L"
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "Daftar fungsi argumen tidak diketahui di %L"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%stune=x86-64%s is deprecated.  Use %stune=k8%s or %stune=generic%s instead as appropriate."
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
@@ -26974,365 +26995,376 @@
 msgstr "%smtune=x86-64%s sudah ditinggalkan. Lebih baik gunakan %stune=k8%s atau %stune=generic%s yang lebih sesuai."
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "model kode %s tidak mendukung kode PIC"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s tidak didukung dalam konfigurasi ini"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-bit mode tidak terkompile"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU yang anda pilih tidak mendukung set instruksi x86-64"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s tidak mendukung %s"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "nilai (%s) buruk untuk pilihan %sarch=%s %s"
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "nilai (%s) buruk untuk %stune=%s %s"
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, fuzzy, gcc-internal-format
 #| msgid "%sregparm%s is ignored in 64-bit mode"
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "%sregparm%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%sregparm=%d%s is not between 0 and %d"
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "%sregparm=%d%s tidak berada diantara 0 dan %d"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-array tidak didukung untuk target ini"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s tidak berada diantara %d dan 12"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d tidak berada diantara %d dan 12"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr "%ssseregparam%s digunakan tanpa SSE aktif"
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "set instruksi SSE non-aktif, menggunakan 387 aritmetik"
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "set instruksi 387 non-aktif, menggunakan aritmetik SSE"
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for -mrecip=%s"
 msgstr "pilihan -m%s= tidak diketahui dispesifikasikan: '%s'"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "alias argumen bukan sebuah string"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "pilihan(\"%s\") telah dispesifikasikan"
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "atribut fastcall dan regparm tidak kompatibel"
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "atribut fastcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "atribut stdcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Memanggil %qD dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Memanggil %qT dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.c:5923
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
-#| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr "Memanggil %qD dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
-
-#: config/i386/i386.c:6210
-#, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "tidak mendukung multilib"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "argumen vektor SSE tanpa SSE aktif mengubah ABI"
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE vektor kembali tanpa SSE aktif mengubah ABI"
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "argumen vektor MMX tanpa MMX aktif mengubah ABI"
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX vektor kembali tanpa MMX aktif mengubah ABI"
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI dari melewatkan struct dengan sebuah anggota array flexible telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI dari melewatkan union dengan long double telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "register SSE kembali dengan SSE tidak aktif"
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argumen register SSE dengan SSE tidak aktif"
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 register kembali dengan x87 tidak aktif"
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, fuzzy, gcc-internal-format
+#| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr "Memanggil %qD dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI dari melewatkan union dengan long double telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
+#, fuzzy, gcc-internal-format
+#| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr "Memanggil %qD dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
+
+#: config/i386/i386.c:11378
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "%s tidak didukung untuk fungsi nested"
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -27340,280 +27372,280 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 tidak mendukung keanggotaan array fleksibel"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "register extended tidak memiliki setengah tinggi"
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ukuran operan tidak didukung untuk register ekstended"
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, fuzzy, gcc-internal-format
 #| msgid "non-integral used in condition"
 msgid "non-integer operand used with operand code 'z'"
 msgstr "bukan integral digunakan dalam kondisi"
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "ekspresi batas stack tidak didukung"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %D"
 msgstr "deklarasi sebelumnya dari %q+D"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "Argumen ke -ffpe-trap tidak valid: %s"
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 2 bit immediate"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, fuzzy, gcc-internal-format
 #| msgid "the fifth argument must be a 8-bit immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "argumen kelima harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, fuzzy, gcc-internal-format
 #| msgid "the third argument must be a 8-bit immediate"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "argumen ketiga harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 1-bit immediate"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 1 bit immediate"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 1 bit immediate"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 5 bit immediate"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "argumen selanjutnya ke terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "insn tidak benar:"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "pembagian tidak benar dari titik pohon"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 5 bit immediate"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 2-bit immediate"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 2 bit immediate"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "pemilih harus berupa sebuah konstanta integer dalam jangkauan 0..%wi"
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE membutuhkan pilihan isa tidak diketahui"
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE membutuhkan pilihan isa %s"
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, fuzzy, gcc-internal-format
 #| msgid "the fifth argument must be a 8-bit immediate"
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "argumen kelima harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "insn tidak benar:"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only available for 64-bit"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs atribut hanya tersedia untuk 64 bit"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "atribut ms_abi dan sysv_abi tidak kompatibel"
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "atribut %qs tidak kompatibel diabaikan"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown architecture '%s'"
 msgid "Unknown architecture specific memory model"
 msgstr "Arsitektur '%s' tidak dikenal"
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "kombinasi tidak didukung: %s"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "argumen yang tidak digunakan dalam $-gaya format"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -27714,13 +27746,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr "nilai dari -mfixed-range harus memiliki bentuk REG1-REG2"
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -27795,7 +27827,7 @@
 msgstr "atribut `%s' tidak didukung untuk target R8C"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%qE attribute argument not an integer constant"
@@ -27859,7 +27891,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread hanya tersedia di fido"
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "ekspresi batas stack tidak didukung"
@@ -28776,16 +28808,11 @@
 msgid "-g option disabled"
 msgstr "-g pilihan tidak aktif"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "alignmen (%u) untuk %s melebihi maksimal alignmen untuk global common data. Menggunakan %u"
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr "-munix=98 pilihan dibutuhkan untuk feature C89 Amendment 1.\n"
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, fuzzy, gcc-internal-format
@@ -29056,334 +29083,340 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektor dikembalikan dengan referensi: ekstensi bukan standar ABI dengan tidak ada garansi kompabilitas"
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "tidak dapat memberikan nilai kembali dalam register vektor karena instruksi altivec tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI dari melewatkan union dengan long double telah berubah dalam GCC 4.4"
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "tidak dapat melewatkan argumen dalam vektor register karena instruksi altivek tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektor dilewatkan dengan referensi: bukan ekstensi standar ABI dengan tidak ada garansi kompabilitas"
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %s already processed"
 msgstr "Perlakukan berkas masukan seperti sudah terproses"
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argumen 1 harus berupa sebuah 5 bit signed literal"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argumen 1 harus berupa sebuah 5 bit signed literal"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "argumen 1 dari __builtin_altivec_predicate harus berupa sebuah konstanta"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "argumen 1 dari __builtin_altivec_predicate diluar dari jangkauan"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "%srtd%s is ignored in 64bit mode"
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr "%srtd%s diabaikan dalam mode 64 bit"
+
+#: config/rs6000/rs6000.c:12763
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argumen 1 dari __builtin_spe_predicate diluar dari jangkauan"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "angka harus berupa 0 atau 1"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "angka harus berupa 0 atau 1"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range 0..15"
 msgstr "Argumen dari ATANH di %L harus berada didalam jangkauan -1 ke 1"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "tidak teresolf overload untuk Altivec bawaan %qF"
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "argumen ke dss harus berupa sebuah 2 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "argumen 1 dari __builtin_paired_predicate harus berupa sebuah konstanta"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "argumen 1 dari __builtin_paired_predicate diluar dari jangkauan"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "argumen 1 dari __builtin_spe_predicate harus berupa sebuah konstanta"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "argumen 1 dari __builtin_spe_predicate diluar dari jangkauan"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "fungsi bawaan ini hanya tersedia di fr450"
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mspe option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qs not supported for MIPS16"
 msgid "Builtin function %s is not supported with the current options"
 msgstr "fungsi bawaan %qs tidak didukung untuk MIPS16"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "internal error: sideeffect-insn affecting main effect"
 msgid "internal error: builtin function %s had no type"
 msgstr "internal error: sideeffect-insn mempengaruhi efek utama"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "stack frame terlalu besar"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "tidak ada profiling dari kode 64 bit untuk ABI ini"
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<long double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe boolean dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<complex%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe titik pecahan desimal dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec tidak valid untuk kode 64 bit"
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec sudah ditinggalkan; gunakan %<int%>"
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "penggunaan dari %<long long%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "penggunaan dari %<double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "mengeluarkan instruksi microcode %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "mengeluarkan kondisional instruksi microcode %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid use of '%%%c'"
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "penggunaan dari '%%%c' tidak valid"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%H%<#pragma%> is not allowed here"
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%H%<#pragma%> tidak diijinkan disini"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s\"%s\"%s is invalid"
@@ -29642,94 +29675,94 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "ukuran total dari variabel lokal melebihi batas arsitektur"
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "ukuran frame dari %qs adalah "
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs menggunakan alokasi dinamis stack"
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argumen ke \"%s\" seharusnya sebuah integer tidak negatif"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "mode z/Arsitektur tidak didukung di %s"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64 bit ABI tidak didukung di mode ESA/390"
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Hardware decimal floating point instructions not available on %s"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia di %s"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, fuzzy, gcc-internal-format
 #| msgid "Hardware decimal floating point instructions not available in ESA/390 mode"
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia dalam mode ESA/390"
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can't be used in conjunction with -msoft-float"
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp tidak dapat digunakan dalam konjungsi dengan -msoft-float"
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float tidak didukung dalam kombinasi"
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "ukuran stack harus lebih besar dari nilai penjaga stack"
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "ukuran stack harus lebih besar  dari 64k"
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard mengimplikasikan penggunaan dari -mstack-size"
@@ -29745,35 +29778,35 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr "unwind tabel saat ini membutuhkan baik sebuah frame pointer atau %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "__builtin_saveregs tidak didukung oleh subtarget ini"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to interrupt functions"
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "atribut %qs hanya berlaku ke fungsi interupsi"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute is supported only for SH2A"
 msgid "%qE attribute is supported only for SH2A"
 msgstr "atribut %qs tidak didukung hanya untuk SH2A"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr "atribut interrupt_handler tidak kompatibeldengan -m5-compact"
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to SH2A"
 msgid "%qE attribute only applies to SH2A"
 msgstr "atribut %qs hanya berlaku ke SH2A"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument should be between 0 to 255"
 msgid "%qE attribute argument should be between 0 to 255"
@@ -29780,24 +29813,24 @@
 msgstr "argumen atribut `%s' seharusnya berada diantara 0 sampai 255"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "%qE attribute argument not a string constant"
 msgstr "argumen atribut %qs bukan sebuah konstanta string"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr "r0 harus tersedia sebaga sebuah call-clobbered register"
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, fuzzy, gcc-internal-format
 #| msgid "Need a second call-clobbered general purpose register"
 msgid "need a second call-clobbered general purpose register"
 msgstr "Butuh sebuah call-clobbered general purpose register kedua"
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, fuzzy, gcc-internal-format
 #| msgid "Need a call-clobbered target register"
 msgid "need a call-clobbered target register"
@@ -30202,49 +30235,49 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid element type for attribute %qs"
 msgstr "tipe vektori tidak valid untuk atribut %qE"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "jumlah dari komponen dari vektor bukan kelipatan dari dua"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "%qs atribut diabaikan"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "%qE atribut membutuhkan prototipe dengan argumen bernama"
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variadic functions"
 msgid "%qs attribute only applies to variadic functions"
 msgstr "%qE atribut hanya berlaku untuk fungsi variadic"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "%qE attribute has no effect"
 msgstr "%qE atribut diabaikan"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "attribute %qs applies to array types only"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
@@ -30308,7 +30341,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "nilai void tidak diabaikan karena ini seharusnya"
@@ -30338,64 +30371,64 @@
 msgid "GCC supports only %u nested scopes"
 msgstr "GCC hanya mendukung %u nested scopes"
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "label %q+D digunakan tetapi tidak didefinisikan"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "fungsi nested %q+D dideklarasikan tetapi tidak pernah didefinisikan"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr "fungsi inline %q+D dideklarasikan tetapi tidak pernah didefinisikan"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "variabel %q+D tidak digunakan"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "variable %qD set but not used"
 msgstr "label %q+D didefinisikan tetapi tidak digunakan"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "tipe dari array %q+D dilengkapi secara tidak kompatibel dengan inisialisasi implisit"
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "originally defined here"
 msgstr "%J definisi asli muncul disini"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr "sebuah daftar parameter dengan sebuah ellipsis tidak dapat cocok dengan sebuah parameter kosong deklarasi daftar nama"
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr "sebuah tipe argumen yang memiliki sebuah promosi baku tidak dapat cocok sebuah nama parameter kosong deklarasi daftar nama"
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "prototipe untuk %q+D mendeklarasikan lebih argumen dari definisi gaya lama sebelumnya"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "prototipe untuk %q+D mendeklarasikan lebih sedikit argumen dari definisi gaya lama sebelumnya"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr "prototipe untuk %q+D mendeklarasikan argumen %d dengan tipe tidak kompatibel"
@@ -30402,42 +30435,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "prototipe untuk %q+D mengikuti definisi bukan-prototipe"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "definisi sebelumnya dari %q+D ada disini"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "deklarasi implisit sebelumnya dari %q+D ada disini"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "deklarasi sebelumnya dari %q+D ada disini"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "%q+D diredeklarasi sebagai jenis yang berbeda dari simbol"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "deklarasi dari %q+D shadows sebuah fungsi bawaan"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "redeklarasi dari enumerator %q+D"
@@ -30445,159 +30478,159 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "tipe konfliks untuk fungsi bawaan %q+D"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "tipe konfliks untuk %q+D"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting type attributes specified for %q+#D"
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr "konflik atribut tipe dispesifikasikan untuk %q+#D"
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting type attributes specified for %q+#D"
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr "konflik atribut tipe dispesifikasikan untuk %q+#D"
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting type attributes specified for %q+#D"
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr "konflik atribut tipe dispesifikasikan untuk %q+#D"
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "tipe konfliks kualifier untuk %q+D"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D"
 msgid "redefinition of typedef %q+D with different type"
 msgstr "redefinisi dari tipedef %q+D"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, fuzzy, gcc-internal-format
 #| msgid "jump into scope of identifier with variably modified type"
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "melompat kedalam lingkup dari pengidentifikasi dengan tipe variabel dapat dimodifikasi"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "redefinisi dari tipedef %q+D"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "redefinisi dari %q+D"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "deklarasi statis dari %q+D mengikuti deklarasi bukan statis"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "deklarasi bukan statis dari %q+D mengikuti deklarasi statis"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr "%<gnu_inline%> atribut hadir di %q+D"
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbut not here"
 msgid "but not here"
 msgstr "%J tetapi tidak disini"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "thread-local deklarasi dari %q+D mengikuti deklarasi bukan-thread-lokal"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "non-thread-local deklarasi dari %q+D mengikuti deklarasi thread-local"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "extern deklarasi dari %q+D mengikuti deklarasi dengan tidak ada hubungan"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "deklarasi dari %q+D dengan tidak ada sambungan mengikuti deklarasi extern"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "redeklarasi dari %q+D dengan tidak ada sambungan"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr "redeklarasi dari %q+D dengan visibility berbeda (visibility lama dijaga)"
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "deklarasi inline dari %qD mengikuti deklarasi dengan atribut noinline"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "deklarasi dari %q+D dengan atribut noinline mengikuti deklarasi inline"
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "deklarasi dari %q+D dengan atribut noinline mengikuti deklarasi inline"
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "redefinisi dari parameter %q+D"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "redundan redeklarasi dari %q+D"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "deklarasi dari %q+D membayangi bukan-variabel sebelumnya"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "deklarasi dari %qD membayangi sebuah deklarasi global"
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "deklarasi dari %q+D membayangi lokal sebelumnya"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
@@ -30604,73 +30637,73 @@
 msgid "shadowed declaration is here"
 msgstr "%J membayangi deklarasi ada disini"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "deklarasi extern nested dari %qD"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "implisit deklarasi dari fungsi %qE"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "deklarasi implisit tidak kompatibel dari fungsi bawaan %qD"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "redeklarasi tidak valid dari %q+D"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "deklarasi implisit dari fungsi %qD tidak kompatibel"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function)"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function)"
 msgstr "%H%qE tidak dideklarasikan (pertama digunakan dalam fungsi ini)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, fuzzy, gcc-internal-format
 #| msgid "%H(Each undeclared identifier is reported only once"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H (Setiap identifier yang tidak dideklarasikan hanya dilaporkan sekali)"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "label %qE direferensikan diluar dari fungsi apapun"
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "melompat kedalam lingkup dari pengidentifikasi dengan tipe variabel dapat dimodifikasi"
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "jump skips variable initialization"
 msgstr "  melewati inisialisasi dari %q+#D"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "label %qD defined here"
 msgstr "label %q+D didefinisikan tetapi tidak digunakan"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
@@ -30677,129 +30710,129 @@
 msgid "%qD declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "melompat kedalam pernyataan ekspresi"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "duplikasi deklarasi label %qE"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "duplikasi label %qD"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, fuzzy, gcc-internal-format
 #| msgid "%Htraditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "%H tradisional C kuran pemisahan ruang nama untuk labels, identifier %qE konflik"
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr ""
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, fuzzy, gcc-internal-format
 #| msgid "jump into statement expression"
 msgid "switch jumps into statement expression"
 msgstr "melompat kedalam pernyataan ekspresi"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE defined as wrong kind of tag"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%H%qE didefinisikan sebagai jenis salah dari tag"
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "struct/union tidak bernama yang mendefinisikan no instances"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "deklarasi kosong dengan storage class penspesifikasi tidak redeklarasi tag"
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "deklarasi kosong dengan tipe kualifier tidak redeklarasi tag"
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration with type qualifier does not redeclare tag"
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "deklarasi kosong dengan tipe kualifier tidak redeklarasi tag"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "nama tipe tidak berguna dalam deklarasi kosong"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> dalam deklarasi kosong"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<inline%> dalam deklarasi kosong"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> dalam file-scope deklarasi kosong"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> dalam file-scope deklarasi kosong"
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "penspesifikasi storage class tidak berguna dalam deklarasi kosong"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "useless type name in empty declaration"
 msgid "useless %qs in empty declaration"
 msgstr "nama tipe tidak berguna dalam deklarasi kosong"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "tipe kualifier tidak berguna dalam deklarasi kosong"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 #| msgid "useless %<__thread%> in empty declaration"
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "tidak berguna %<__thread%> dalam deklarasi kosong"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "deklarasi kosong"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 tidak mendukung %<static%> atau tipe kualifier dalam parameter array pendeklarasi"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 tidak mendukung %<[*]%> array pendeklarasi"
@@ -30807,38 +30840,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> tidak diijinkan dalam hal lain selain lingkup prototipe fungsi"
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D biasanya sebuah fungsi"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "typedef %qD diinisialisasi (lebih baik gunakan __typeof__)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "fungsi %qD diinisialisasi seperti sebuah variabel"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "parameter %qD dinisialisasi"
@@ -30847,279 +30880,279 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "objek berukuran-variabel tidak boleh diinisialisasi"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "variabel %qD memiliki penginisialisasi tetapi tipe tidak lengkap"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "fungsi inline %q+D memberikan atribut noinline"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "anggota const tidak terinisialisasi %qD"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD should be initialized"
 msgstr "%qD akan diinisialisasi setelah"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "ukuran array hilang dalam %q+D"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "ukuran array nol atau negatif %q+D"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "ukuran penyimpanan dari %q+D bukan konstant"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "mengabaikan asm-penspesifikasi untuk bukan-statis variabel lokal %q+D"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "tidak dapat meletakan objek dengan bagian volatile kedalam register"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "tidak terinisialisasi const %qD"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C melarang deklarasi parameter kedepan"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "lebar bit-field %qs bukan sebuah konstanta integer"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs width not an integer constant"
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "lebar bit-field %qs bukan sebuah konstanta integer"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "lebar negatif dalam bit-field %qs"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "lebar nol untuk bit-field %qs"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "bit-field %qs memiliki tipe tidak valid"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "tipe dari bit-field  %qs adalah sebuah ekstensi GCC"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "lebar dari %qs melebihi tipenya"
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs lebih kecil dari nilai dari tipenya"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 melarang array %qs yang ukurannya tidak dapat dievaluasi"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 melarang array yang ukurannya tidak dapat dievaluasi"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qs"
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 melarang array dengan panjang bervariabel %qs"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 melarang array dengan panjang bervariabel"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified %qs at file scope"
 msgid "variably modified %qE at file scope"
 msgstr "variabel dimodifikasi %qs di lingkup berkas"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified %qs at file scope"
 msgid "variably modified field at file scope"
 msgstr "variabel dimodifikasi %qs di lingkup berkas"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "tipe baku ke %<int%> dalam deklarasi dari %qs"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in type name"
 msgstr "tipe baku ke %<int%> dalam deklarasi dari %qs"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "duplikasi %<const%>"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "duplikasi %<restrict%>"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "duplikasi %<volatile%>"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "duplikasi %<restrict%>"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting super class name %qs"
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "konflik nama super class %qs"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "definisi fungsi dideklarasikan %<auto%>"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "definisi fungsi dideklarasikan %<register%>"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "definisi fungsi dideklarasikan %<typedef%>"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "definisi fungsi dideklarasikan %<auto%>"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field %qE"
 msgstr "class penyimpanan dispesifikasikan untuk daerah struktur %qs"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field"
 msgstr "class penyimpanan dispesifikasikan untuk daerah struktur %qs"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for parameter %qE"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for unnamed parameter"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "class penyimpanan dispesifikasikan untuk nama tipe"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs diinisialisasi dan dideklarasi %<extern%>"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, fuzzy, gcc-internal-format
 #| msgid "%qs has both %<extern%> and initializer"
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs keduanya memiliki %<extern> dan penginisialisasi"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<auto%>"
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "deklarasi lingkup-berkas dari %qs menspesifikasikan %<auto%>"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<register%>"
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "deklarasi lingkup-berkas dari %qs menspesifikasikan %<register%>"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested function %qE declared %<extern%>"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -31128,757 +31161,757 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "statis atau tipe kualifier dalam array pendeklarasi bukan parameter"
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qE as array of voids"
 msgstr "deklarasi dari %qs sebagai dari voids"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of type name as array of voids"
 msgstr "deklarasi dari %qs sebagai dari voids"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qE as array of functions"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of type name as array of functions"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "penggunaan tidak valid dari struktur dengan anggota array fleksibel"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of array %qE has non-integer type"
 msgstr "ukuran dari array %qs memiliki tipe bukan integer"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of unnamed array has non-integer type"
 msgstr "ukuran dari array %qs memiliki tipe bukan integer"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids zero-size array %qs"
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C melarang array berukuran-nol %qs"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array"
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++ melarang array berukuran-nol"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE is negative"
 msgstr "ukuran dari array %qs adalah negatif"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "ukuran dari array negatif"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array %qE is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is too large"
 msgid "size of unnamed array is too large"
 msgstr "ukuran dari array terlalu besar"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 tidak mendukung keanggotaan array fleksibel"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "tipe array memiliki tipe elemen tidak lengkap"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "%qE declared as function returning a function"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah fungsi"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "type name declared as function returning a function"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah fungsi"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "%qE declared as function returning an array"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "type name declared as function returning an array"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "definisi fungsi memiliki pengkualifikasi tipe kembali void"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C melarang pengkualifikasi tipe fungsi"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C melarang pengkualifikasi tipe fungsi"
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting type qualifiers for %q+D"
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "tipe konfliks kualifier untuk %q+D"
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%qs specified for auto variable %qE"
 msgstr "%Htipe tidak valid untuk iterasi variabel %qE"
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for parameter %qE"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for unnamed parameter"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field %qE"
 msgstr "class penyimpanan dispesifikasikan untuk daerah struktur %qs"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field"
 msgstr "class penyimpanan dispesifikasikan untuk daerah struktur %qs"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "bit-field %qs memiliki tipe tidak valid"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "bit-field %qs memiliki tipe tidak valid"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for typedef %qE"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for %<register%> object %qE"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for parameter %qE"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for unnamed parameter"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for bit-field %qE"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 #| msgid "%<__alignof%> applied to a bit-field"
 msgid "alignment specified for unnamed bit-field"
 msgstr "%<__alignof%> diaplikasikan ke sebuah bit-field"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "alignment specified for function %qE"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C melarang tipe fungsi const atau volatile"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "sebuah anggota dari sebuah struktur atau union tidak dapat memiliki sebuah tipe variabel termodifikasi"
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabel atau field %qE dideklarasikan void"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "atribut dalam parameter pendeklarasi array diabaikan"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "parameter %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "parameter %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "field %qE declared as a function"
 msgstr "field %qs dideklarasikan sebagai sebuah fungsi"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "field %qE has incomplete type"
 msgstr "field %qs memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, fuzzy, gcc-internal-format
 #| msgid "name %qT has incomplete type"
 msgid "unnamed field has incomplete type"
 msgstr "nama %qT memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "invalid storage class for function %qE"
 msgstr "class penyimpanan tidak valid untuk fungsi %qs"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "tidak dapat inline fungsi %<main%>"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs diinisialisasi dan dideklarasi %<extern%>"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "variabel sebelumnya dideklarasikan %<static%> diredeklarasi %<extern%>"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "variabel %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "variabel %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, fuzzy, gcc-internal-format
 #| msgid "jump into scope of identifier with variably modified type"
 msgid "non-nested function with variably modified type"
 msgstr "melompat kedalam lingkup dari pengidentifikasi dengan tipe variabel dapat dimodifikasi"
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "objek dengan tipe variabel termodifikasi harus tidak memiliki hubungan"
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "deklarasi fungsi bukan sebuah prototipe"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "nama parameter (tanpa tipe) dalam deklarasi fungsi"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "parameter %u (%q+D) memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "parameter %u has incomplete type"
 msgstr "%J parameter %u memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "parameter %u (%q+D) memiliki tipe void"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has void type"
 msgid "parameter %u has void type"
 msgstr "%J parameter %u memiliki tipe void"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> hanya memiliki parameter tidak boleh dikualifikasikan"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> harus menjadi parameter satu satunya"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "parameter %q+D hanya memiliki sebuah deklarasi kedepan"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "%<%s %E%> dideklarasikan didalam daftar parameter"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "anonymous %s dideklarasikan didalam daftar parameter"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "lingkup ini hanya dalam definisi atau deklarasi ini, dimana ini mungkin bukan yang anda inginkan"
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "enum type defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "struct defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "union defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "redefinisi dari %<union %E%>"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "redefinisi dari %<struct %E%>"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "nested redefinisi dari %<union %E%>"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "nested redefinisi dari %<struct %E%>"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C tidak mendukung structs/unions tidak bernama"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C tidak mendukung structs/unions tidak bernama"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "duplikasi anggota %q+D"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union tidak memiliki anggota bernama"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union tidak memiliki anggota"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct tidak memiliki anggota bernama"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct tidak memiliki anggota"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
 msgstr "%J anggota array fleksibel dalam union"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member not at end of struct"
 msgstr "%J anggota array fleksibel tidak diakhir dari struct"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member in otherwise empty struct"
 msgstr "%J anggota array fleksibel dalam sebaliknya struct kosong"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "type %qT is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union tidak dapat dibuat transparan"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "nested redefinisi dari %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "redeklarasi dari %<enum %E%>"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "nilai enumerasi melebihi jangkauan dari integer terbesar"
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "mode yang dispesifikasikan terlalu kecil untuk nilai enumerasi"
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "nilai pengenumerasi untuk %qE bukan sebuah konstanta integer"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "nilai pengenumerasi untuk %qE bukan sebuah konstanta integer"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "overflow dalam nilai enumerasi"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C melarang nilai pengenumerasi ke jangkauan dari %<int%>"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute noinline"
 msgstr "fungsi inline %q+D memberikan atribut noinline"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "tipe kembali adalah sebuah tipe tidak lengkap"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "tipe baku kembali ke %<int%>"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for %q+D"
 msgid "no previous prototype for %qD"
 msgstr "tidak ada prototipe sebelumnya untuk %q+D"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D telah digunakan dengan tidak ada prototipe sebelum definisinya"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
 msgstr "tidak deklarasi sebelumnya untuk %q+D"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD was used with no declaration before its definition"
 msgstr "%q+D telah digunakan tanpa deklarasi sebelum definisinya"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %<int%>"
 msgstr "tipe kembali dari %q+D bukan %<int%>"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is normally a non-static function"
 msgstr "%q+D secara normal sebuah fungsi bukan-statis"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style parameter declarations in prototyped function definition"
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%J deklarasi parameter gaya lama dalam definisi fungsi prototipe"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtraditional C rejects ISO C style function definitions"
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%J tradisional C menolak gaya ISO C definisi fungsi"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name omitted"
 msgid "parameter name omitted"
 msgstr "%J nama parameter diabaikan"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "old-style function definition"
 msgstr "%J definisi fungsi gaya-lama"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name missing from parameter list"
 msgid "parameter name missing from parameter list"
 msgstr "%J nama parameter hilang dari daftar parameter"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "%qD declared as a non-parameter"
 msgstr "%q+D dideklarasikan sebagai sebuah bukan-parameter"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, fuzzy, gcc-internal-format
 #| msgid "multiple parameters named %q+D"
 msgid "multiple parameters named %qD"
 msgstr "multiple parameter bernama %q+D"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "parameter %qD declared with void type"
 msgstr "parameter %q+D dideklarasikan dengan tipe void"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, fuzzy, gcc-internal-format
 #| msgid "type of %q+D defaults to %<int%>"
 msgid "type of %qD defaults to %<int%>"
 msgstr "tipe dari %q+D baku ke %<int%>"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "parameter %q+D memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "declaration for parameter %q+D but no such parameter"
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "deklarasi untuk parameter %q+D tetapi tidak ada parameter seperti itu"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "jumlah dari argumen tidak cocok dengan prototipe bawaan"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "jumlah dari argumen tidak cocok prototipe"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "deklarasi prototipe"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "argumen dipromosikan %qD tidak cocok dengan prototipe bawaan"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "argumen dipromosikan %qD tidak cocok dengan prototipe"
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argumen %qD tidak cocok dengan prototipe bawaan"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumen %qD tidak cocok dengan prototipe"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -31887,211 +31920,211 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> deklarasi inisial loop hanya diijinkan dalam mode C99"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99 or -std=gnu99 to compile your code"
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "gunakan pilihan -std=c99 atau -std=gnu99 untuk mengkompile kode anda"
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari variabel statis %q+D dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari bukan-variabel %q+D dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "duplikasi %qE"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "dua atau lebih tipe data dalam penspesifikasi deklarasi"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> terlalu panjang untuk GCC"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 tidak mendukung tipe kompleks"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C tidak mendukung tipe yang bersaturasi"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support fixed-point types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C tidak mendukung tipe titik tetap"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 tidak mendukung tipe kompleks"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C tidak mendukung titik pecahan desimal"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "tipe titik tetap tidak didukung untuk target ini"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C tidak mendukung tipe titik tetap"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE gagal untuk menjadi sebuah typedef atau tipe bawaan"
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE tidak berada di awal dari deklarasi"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> digunakan dengan %<auto%>"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> digunakan dengan %<register%>"
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> digunakan dengan %<typedef%>"
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s tidak mendukung %s"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> sebelum %<extern%>"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> sebelum %<static%>"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "multiple class penyimpanan dalam deklarasi penspesifikasi"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs used with %qE"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> digunakan tanpa %<_Fract%> atau %<_Accum%>"
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C tidak mendukung plain %<complex%> yang berarti %<double complex%>"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C tidak mendukung tipe integer kompleks"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -32102,7 +32135,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr "pengidentifikasi %qs konflik dengan kata kunci C++"
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -32124,8 +32157,8 @@
 msgid "unknown type name %qE"
 msgstr "nama register: %s tidak dikenal"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "diduga penspesifikasi deklarasi"
@@ -32142,7 +32175,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -32226,7 +32259,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "diduga string literal"
@@ -32289,14 +32322,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "diduga pengidentifikasi"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "koma di akhir dari daftar pengenumerasi"
@@ -32772,35 +32805,35 @@
 msgid "no type or storage class may be specified here,"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "hilang %<(%> setelah %<#pragma pack%> - diabaikan"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "hilang %<(%> setelah %<#pragma pack%> - diabaikan"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%J atribut daerah tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
@@ -32812,51 +32845,51 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> hanya  boleh digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> hanya  boleh digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> hanya  boleh digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> harus menjadi pertama"
@@ -32872,12 +32905,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -32889,29 +32922,29 @@
 msgid "expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "%qD is not a constant"
 msgstr "argumen %qd bukan sebuah konstanta"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "diduga %<none%> atau %<shared%>"
@@ -32946,17 +32979,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "jadwal %<runtime%> tidak mengambil sebuah parameter %<chunk_size%>"
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "penjadwalan %<auto%> tidak mengambil sebuah parameter %<chunk_size%>"
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "jenis penjadwalan tidak valid"
@@ -32979,13 +33012,13 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -33008,19 +33041,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "jenis penjadwalan tidak valid"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "topeng tidak valid"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -33032,62 +33065,62 @@
 msgid "invalid proc_bind kind"
 msgstr "jenis penjadwalan tidak valid"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr "diduga sebuah string setelah %<#pragma message%>"
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid pragma"
 msgstr "#pragma %s tidak valid"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -33097,18 +33130,18 @@
 msgid "expected %<(%> or end of line"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "_Cilk_for statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "diduga iterasi deklarasi atau inisialisasi"
@@ -33118,257 +33151,257 @@
 msgid "not enough perfectly nested loops"
 msgstr "tidak cukup secara sempurna nested loops"
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "collapsed loops tidak secara sempurna nested"
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> hanya  boleh digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> harus muncul sebelum deklarasi dari %D, abaikan"
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma GCC pop_options%> tanpa sebuah %<#pragma GCC push_options%> yang berhubungan"
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "diduga %<#pragma omp section%> atau %<}%>"
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<omp_priv%> or function-name"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected function-name %<(%>"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "diduga %<#pragma omp section%> atau %<}%>"
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE dideklarasikan %<threadprivate%> setelah penggunaan pertama"
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "variabel otomatis %qE tidak dapat berupa %<threadprivate%>"
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE memiliki tipe tidak lengkap"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "vectorlength must be an integer constant"
 msgstr "pemilih harus berupa sebuah konstanta integer dalam jangkauan 0..%wi"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "ukuran stack harus berupa sebuah kelipatan tepat dari 2"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "pemilih harus berupa sebuah konstanta integer dalam jangkauan 0..%wi"
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma simd%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "base of array section must be pointer or array type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or numeral"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "array notations cannot be used with function type"
 msgstr "new tidak dapat diaplikasikan ke sebuah fungsi tipe"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 #| msgid "Expected an initialization expression at %C"
 msgid "expected array notation expression"
@@ -33379,7 +33412,7 @@
 msgid "%qD has an incomplete type"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "penggunaan tidak valid dari ekspresi void"
@@ -33489,7 +33522,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "nilai subscripted adalah bukan array ataupun penunjuk"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "array subscrip bukan sebuah integer"
@@ -33617,7 +33650,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "melewatkan argumen %d dari %qE sebagai signed karena ada prototipe"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT when passing argument to function"
@@ -33649,7 +33682,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmetik di penunjuk ke sebuah tipe tidak lengkap"
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -33738,7 +33771,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "array bukan lvalue dalam ekspresi kondisional"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
@@ -33776,7 +33809,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "tipe penunjuk/integer tidak cocok dalam ekspresi kondisional"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr ""
@@ -33864,7 +33897,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "cast dari panggilan fungsi dari tipe %qT ke tipe yang tidak cocok %qT"
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "cast ke penunjuk dari integer dari ukuran yang berbeda"
@@ -34040,7 +34073,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "inisialisasi sisi tangan kiri mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "tipe kembali mungkin berupa sebuah kandidat untuk sebuah atribut format"
@@ -34177,7 +34210,7 @@
 msgid "initialization of a flexible array member"
 msgstr "inisialisasi dari sebuah anggota array fleksibel"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-array terinisialisasi dari string lebar"
@@ -34224,7 +34257,7 @@
 msgid "invalid initializer"
 msgstr "penginisialisasi tidak valid"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "tipe vektor opaque tidak dapat diinisialisasi"
@@ -34371,7 +34404,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C melarang %<goto *expr;%>"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "fungsi dideklarasikan %<noreturn%> memiliki sebuah pernyataan %<return%>"
@@ -34381,7 +34414,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
@@ -34492,18 +34525,18 @@
 msgid "expression statement has incomplete type"
 msgstr "ekspresi pernyataan memiliki tipe tidak lengkap"
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "comparing vectors with different element types"
 msgstr "Peringatkan mengenai perbandingan dari tipe enum yang berbeda"
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "membandingkan titik pecahan dengan == atau != adalah tidak aman"
@@ -34556,12 +34589,12 @@
 msgstr "perbandingan terurut dari penunjuk dengan integer nol"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "perbandingan terurut dari penunjuk dengan integer nol"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
@@ -34588,92 +34621,92 @@
 msgid "used vector type where scalar is required"
 msgstr "menggunakan nilai tipe struct dimana skalar dibutuhkan"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array %qs is used"
 msgid "negative length in array section in %qs clause"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Salin bagian array kedalam sebuah blok kontinu dalam masukan prosedur"
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not have class type"
 msgid "%qE does not have pointer or array type"
@@ -34684,17 +34717,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction(%s)%>"
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE harus berupa %<threadprivate%> untuk %<copyin%>"
@@ -34704,7 +34737,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
@@ -34714,17 +34747,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE bukan sebuah variabel dalam clause %<firstprivate%>"
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE bukan sebuah variabel dalam clause %<lastprivate%>"
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -34742,53 +34775,53 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE adalah predetermined %qs untuk %qs"
@@ -34799,36 +34832,36 @@
 msgstr ""
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "melewatkan %qT sebagai %<this%> argumen dari %q#D mengabaikan kualifier"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion from %qT to %qT"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -34835,90 +34868,90 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T, %T) <built-in>"
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr "%s %D(%T, %T, %T) <built-in>"
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T) <built-in>"
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "%s %D(%T, %T) <built-in>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T) <built-in>"
 msgid "%s%D(%T) <built-in>"
 msgstr "%s %D(%T) <built-in>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "%s %T <conversion>"
 msgid "%s%T <conversion>"
 msgstr "%s %T <conversion>"
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D <near match>"
 msgid "%s%#D <near match>"
 msgstr "%s %+#D <near match>"
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr ""
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr ""
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument deduction/substitution failed:"
 msgstr "template argumen %d tidak valid"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "konversi dari %qT ke %qT adalah ambigu"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to non-scalar type %qT requested"
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr "konversi dari %qT ke tipe bukan-skalar %qT diminta"
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "tidak ada fungsi yang cocok untuk panggilan ke %<%D(%A)%>"
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "panggilan dari overloaded %<%D(%A)%> adalah ambigu"
@@ -34925,493 +34958,493 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr "pointer-ke-anggota fungsi %E tidak dapat dipanggil tanpa sebuah objek; pertimbangkan menggunakan .* atau ->*"
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "tidak ada yang cocok untuk panggilan ke %<(%T) (%A)%>"
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "panggilan dari %<(%T) (%A)%> adalah ambigu"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "konversi ambigu untuk array subscript"
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "operan ke binari %s tidak valid (memiliki %qT dan %qT)"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT and %qT)"
 msgstr "operan ke binari %s tidak valid (memiliki %qT dan %qT)"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, fuzzy, gcc-internal-format
 #| msgid "User operators:\n"
 msgid "ternary %<operator?:%>"
 msgstr "Operator pengguna:\n"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, fuzzy, gcc-internal-format
 #| msgid "%s for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%s untuk ternary %<operator?:%> dalam %<%E ? %E : %E%>"
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator%s%>"
 msgstr "Operator buruk"
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s untuk %<operator%s%> dalam %<%E%s%>"
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator[]%>"
 msgstr "Operator buruk"
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%s untuk %<operator[]%> dalam %<%E[%E]%>"
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "%s untuk %qs dalam %<%s %E%>"
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s untuk %<operator%s%> dalam %<%E %s %E%>"
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s untuk %<operator%s%> dalam %<%s%E%>"
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ melarang mengabaikan term tengah dari sebuah ekspresi ?:"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "enumeral tidak cocok dalam ekspresi kondisional: %qT vs %qT"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "operan kedua ke operator kondisional bertipe %<void%>, tetapi operan ketika bukan sebuah throw-expression ataupun bertipe %<void%>"
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "operan ketiga ke opertor kondisional bertipe %<void%>, tetapi operan kedua bukan sebuah throw-expression ataupun bertipe %<void%>"
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "operan ke ?: memiliki tipe berbeda %qT dan %qT"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "enumeral tidak cocok dalam ekspresi kondisional: %qT vs %qT"
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "tipe enumeral dan bukan enumeral dalam ekspresi kondisional"
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "tidak ada %<%D(int%> dideklarasikan untuk postfix %qs, mencoba operator prefix sebaliknya"
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, fuzzy, gcc-internal-format
 #| msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "tidak ada %<%D(int%> dideklarasikan untuk postfix %qs, mencoba operator prefix sebaliknya"
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "perbandingan antara %q#T dan %q#T"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, fuzzy, gcc-internal-format
 #| msgid "no corresponding deallocation function for %qD"
 msgid "non-placement deallocation function %q+D"
 msgstr "tidak ada dealokasi fungsi yang berhubungan untuk %qD"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr ""
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "tidak ada dealokasi fungsi yang berhubungan untuk %qD"
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "tidak cocok %<operator %s%> untuk %qT"
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr "%q+#D adalah private"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr "%q+#D terproteksi"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr "%q+#D tidak dapat diakses"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr "dalam konteks ini"
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "melewatkan koson ke argumen bukan penunjuk %P dari %qD"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "mengubah ke tipe bukan penunjuk %qT dari KOSONG"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "mengubah %<false%> ke tipe penunjuk untuk argumen %P dari %qD"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, fuzzy, gcc-internal-format
 #| msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "mengubah %<false%> ke tipe penunjuk untuk argumen %P dari %qD"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "terlalu banyak kurung diantara penginisialisasi untuk %qT"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT from %qT may alter its value"
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr "konversi ke %qT dari %qT mungkin mengubah nilainya"
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "konversi dari %qT ke %qT tidak valid"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  inisialisasi argumen %P dari %qD"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "konversi dari %qT ke %qT tidak valid"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "mengubah ke %qT untuk daftar penginisialisasi akan menggunakan konstruktor eksplist %qD"
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, fuzzy, gcc-internal-format
 #| msgid "  initializing argument %P of %qD"
 msgid "  initializing argument %P of %q+D"
 msgstr "  inisialisasi argumen %P dari %qD"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind rvalue %qE to %qT"
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "tidak dapat mengikat rvalue %qE ke %qT"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe sementara %qT tidak valid"
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "melewatkan %qT sebagai %<this%> argumen dari %q#D mengabaikan kualifier"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "tidak dapat mengikat bitfield %qE ke %qT"
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "tidak dapat mengikat packed field %qE ke %qT"
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "tidak dapat mengikat rvalue %qE ke %qT"
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "tidak dapat melewatkan objek dari tipe bukan POD %q#T melalui %<...%>; panggilan akan dibatalkan pada saat waktu-jalan"
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "tidak dapat menerima objek dari tipe bukan POD %q#T melalui %<...%>; panggilan akan dibatalkan pada saat waktu-jalan"
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "evaluasi rekursi dari argumen baku untuk %q#D"
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, fuzzy, gcc-internal-format
 #| msgid "the default argument for parameter %d of %qD has not yet been parsed"
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "argumen baku untuk parameter %d dari %qD belum diparse"
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "melewatkan %qT sebagai %<this%> argumen dari %q#D mengabaikan kualifier"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  dalam panggilan ke %qD"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT bukan sebuah dasar yang bisa diakses dari %qT"
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "deducing %qT as %qT"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, fuzzy, gcc-internal-format
 #| msgid "  in call to %qD"
 msgid "  in call to %q+D"
 msgstr "  dalam panggilan ke %qD"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr "tidak dapat menemukan class$ field dalam antar-muka java tipe %qT"
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, fuzzy, gcc-internal-format
 #| msgid "mangling function-style cast with more than one argument"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "mangling function-style cast dengan lebih dari satu argumen"
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "tidak pasangan fungsi untuk panggilan ke %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr "tidak pasangan fungsi untuk panggilan ke %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "tidak ada fungsi yang cocok untuk panggilan ke %<%D(%A)%>"
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "panggilan dari overloaded %<%s(%A)%> adalah ambigu"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT memiliki anggota data tidak statis bernama %qD"
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "tidak dapat memanggil anggota fungsi %qD tanpa objek"
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "melewatkan %qT memilih %qT diatas %qT"
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "memilih %qD diatas %qD"
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  karena urutan konversi untuk argumen lebih baik"
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "argumen baku tidak cocok dalam kelebihan beban resolusi"
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr " kandidat 1: %q+#F"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr " kandidat 2: %q+#F"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ mengatakan bahwa ini adalah ambigu, meskipun melalui konversi terburuk untuk yang pertama lebih baik daripada konversi terburuk untuk yang kedua:"
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %qT to %qT"
 msgstr "tidak dapat mengubah %qE ke %qT"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "inisialisasi dari referensi dari tipe %qT dari ekspresi dari tipe %qT tidak valid"
@@ -35576,7 +35609,7 @@
 msgid "  by %q+D"
 msgstr "  oleh %q+D"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D tidak valid; sebuah anonymous union hanya dapat mempunnya anggota data tidak statis"
@@ -35586,7 +35619,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D tidak valid; sebuah anonymous struct hanya dapat memiliki anggota data tidak statis"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr "anggota private %q+#D dalam union anonymous"
@@ -35596,7 +35629,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "anggota private %q+#D dalam struct anonymous"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr "anggota terproteksi %q+#D dalam union anonymous"
@@ -35731,74 +35764,84 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  tetapi tidak override %<operator=(const %T&)%>"
 
-#: cp/class.c:4538
+#: cp/class.c:4300
 #, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, gcc-internal-format
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr ""
+
+#: cp/class.c:4557
+#, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "penginisialisasi dispesifikasikan untuk metode %q+D bukan virtual"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q+T is not literal because:"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "  non-static data member %q+D has volatile type"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr "referensi bukan-statis %q+#D dalam kelas tanpa sebuah konstruktor"
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr "anggota const bukan-statis %q+#D dalam kelas tanpa sebuah konstruktor"
@@ -35805,105 +35848,105 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direct base %qT tidak dapat diakses dalam %qT karena adanya ambigu"
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtual base %qT tidak dapat diakses dalam %qT karena adanya ambigu"
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr "ofset dari %q+D adalah bukan ABI komplian dan mungkin berubah dalam versi GCC yang akan datang"
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinisi dari %q#T"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T memiliki fungsi maya dan dapat diakses bukan virtual desktruktor"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "kelas %qT tidak memiliki field apapun bernama %qD"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "tipe %qs memiliki anggota fungsi virtual"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, fuzzy, gcc-internal-format
 #| msgid "deducing auto from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "deduksi auto dari daftar penginisialisasi dikurung membutuhkan #include <daftar_penginisialisasi>"
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "mencoba menyelesaikan struct, tetapi ditendang keluar karena error parse sebelumnya"
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "bahasa string %<\"%E\"%> tidak dikenal"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "tidak dapat meresolf fungsi overloaded %qD berdasar dari konversi ke tipe %qT"
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "tidak cocok mengubah fungsi %qD ke tipe %q#T"
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "mengubah fungsi overloaded %qD ke tipe %q#T adalah ambigu"
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "mengasumsikan penunjuk ke anggota %qD"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(sebuah penunjuk ke anggota hanya dapat dibentuk dengan %<&%E%>)"
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "tidak cukup informasi mengenai tipe"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "tidak dapat mengubah %qE dari tipe %qT ke tipe %qT"
@@ -35913,12 +35956,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "deklarasi dari %q#D"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr "perubahan berarti dari %qD dari %q+#D"
@@ -35961,47 +36004,47 @@
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "%J kelas dasar %q#T seharusnya secara eksplisit diinisialisasikan dalam konstruktor salinan"
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion in return statement"
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "konversi tidak valid dalam pernyataan return"
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr "%q+D secara normal sebuah fungsi bukan-statis"
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "expression %qE does not designate a constexpr function"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-constexpr function %qD"
@@ -36008,246 +36051,246 @@
 msgstr "panggilan ke bukan-fungsi %qD"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD used before its definition"
 msgstr "%q+D telah digunakan dengan tidak ada prototipe sebelum definisinya"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qs has circular dependency"
 msgid "call has circular dependency"
 msgstr "protokol %qs memiliki ketergantungan circular"
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "kedalaman template instantiation melebihi maksimal dari %d (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal) instantiating %qD"
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, fuzzy, gcc-internal-format
 #| msgid "Warn on calls to these functions"
 msgid "constexpr call flows off the end of the function"
 msgstr "Peringatkan di panggilan ke fungsi ini"
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%q+E is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "jumlah geser kanan negatif"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "array subscript out of bound"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "negative array subscript"
 msgstr "Diduga array subscript di %C"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qE is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not initialized"
 msgid "%qD used in its own initializer"
 msgstr "%qE tidak terinisialisasi"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#D is not const"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D adalah private"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD belum pernah dideklarasikan dalam lingkup ini"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "%Hekspresi dalam pendeklarasi new harus memiliki integral atau tipe enumerasi"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of %qE is not a constant-expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "tipe enumeral dan bukan enumeral dalam ekspresi kondisional"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away constness"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant-expression"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "statement is not a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "diduga ekspresi"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, fuzzy, gcc-internal-format
 #| msgid "cast from type %qT to type %qT casts away constness"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr "cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "pointer comparison expression is not a constant expression"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant-expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -36320,7 +36363,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr ""
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr "%qE secara implisit ditentukan sebagai %<firstprivate%> memiliki referensi tipe"
@@ -36365,7 +36408,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "konversi dari %qT ke %qT mengabaikan kualifikasi"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "casting %qT ke %qT tidak medereferensi penunjuk"
@@ -36375,322 +36418,322 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "tidak dapat mengubah tipe %qT ke tipe %qT"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "konversi dari %q#T ke %q#T"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "hasil dari konversi tidak dispesifikasikan karena %qE diluar dari jangkauan tipe %qT"
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T digunakan dimana sebuah %qT telah diduga"
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "tidak dapat mengubah %qE ke %qT"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "%q#T digunakan dimana seubah nilai titik pecahan telah diduga"
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "konversi dari %qT ke tipe bukan-skalar %qT diminta"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "pseudo-destruktor tidak dipanggil"
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "konversi ke tipe yang tidak lengkap"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to incomplete type %qT "
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "apliasi tidak valid dari %qs ke tipe tidak lengkap %qT"
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of type %qT"
 msgstr "konversi ke tipe yang tidak lengkap"
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "second operand of conditional expression has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "third operand of conditional expression has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right operand of comma operator has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of comma operator has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, fuzzy, gcc-internal-format
 #| msgid "statement with no effect"
 msgid "statement has no effect"
 msgstr "pernyataan dengan tidak ada efek"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "for increment expression has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "mengubah NULL ke tipe bukan penunjuk"
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "tidak dapat mengubah argumen template %qE ke %qT"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "ambigu tipe konversi baku dari %qT"
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  kandidat konversi termasuk %qD dan %qD"
@@ -37145,253 +37188,253 @@
 msgid "template parameters do not match template %qD"
 msgstr "parameter template tidak cocok dengan template"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, fuzzy, gcc-internal-format
 #| msgid "%Jan anonymous struct cannot have function members"
 msgid "an anonymous struct cannot have function members"
 msgstr "%J sebuah anonymous struct tidak dapat memiliki anggota fungsi"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "%Jan anonymous union cannot have function members"
 msgid "an anonymous union cannot have function members"
 msgstr "%J sebuah anonymous union tidak dapat memiliki anggota fungsi"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan konstruktor tidak diijinkan dalam kumpulan anonymous"
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan desktruktor tidak diijinkan dalam kumpulan anoymous"
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan operator penempatan salin tidak diperbolehkan dalam kumpulan anonymous"
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "atribut untuk %q+#T harus mengikuti kata kunci %qs"
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "multiple tipe dalam satu deklarasi"
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redeklarasi dari C++ tipe bawaan %qT"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "hilang nama-tipe dalam typedef-deklarasi"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ menghambat struct anonymous"
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> hanya dapat dispesifikasikan didalam sebuah kelas"
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> hanya dapat dispesifikasikan untuk konstruktor"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "sebuah kelas penyimpanan hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> telah diabaikan dalam deklarasi ini"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "%<register%> in file-scope empty declaration"
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<register%> dalam file-scope deklarasi kosong"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "atribut diabaikan di template instantiation"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "mengabaikan atribut yang diaplikasikan ke tipe kelas %qT diluar dari definisi"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "mengabaikan atribut yang diaplikasikan ke tipe dependen %qT tanpa sebuah deklarasi yang berasosiasi"
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD diinisialisasi (lebih baik gunakan decltype)"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "deklarasi dari %q#D memiliki %<extern%> dan terinisialisasi"
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "definisi dari %q#D ditandai %<dllimport%>"
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D bukan sebuah anggota data bukan-statis dari %qT"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "deklarasi anggota template %qD tidak valid"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tidak mengijinkan %<%T::%D%> untuk didefinisikan sebagai %<%T::%D%>"
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "duplikasi inisialisasi dari %qD"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, fuzzy, gcc-internal-format
 #| msgid "%qE declared %<threadprivate%> after first use"
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr "%qE dideklarasikan %<threadprivate%> setelah penggunaan pertama"
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "deklarasi dari %q#D diluar dari kelas bukan sebuah definisi"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabel %q#D memiliki penginisialisasi tetapi tipe tidak lengkap"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elemen dari array %q#D memiliki tipe tidak lengkap"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarasi dari %q#D tidak memiliki penginisialisasi"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "kumpulan %q#D memiliki tipe tidak lengkap dan tidak dapat didefinisikan"
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD dideklarasikan sebagai referensi tetapi tidak terinisialisasi"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "nama digunakan dalam sebuah gaya GNU diperuntukan penginisialisasi untuk sebuah array"
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "nama %qD digunakan dalam sebuah gaya GNU didesign penginisialisasi untuk sebuah array"
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "bukan trivial designated penginisialisasi tidak didukung"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "ukuran array hilang dalam %qD"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "array berukuran-nol %qD"
@@ -37399,883 +37442,883 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "ukuran penyimpanan dari %q+D tidak diketahui"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "ukuran penyimpanan dari %q+D bukan konstant"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "maaf: semantik dari fungsi inline data statis %q+#D salah (anda akan berputar putar dengan beberap salinan)"
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  anda dapat memperbaiki ini dengan menghapus penginisialisasi"
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "tidak terinisialisasi const %qD"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "tipe %qs memiliki sebuah konstruktor yang didefinisikan pengguna"
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "tipe tidak valid %qT sebagai penginisialisasi untuk sebuah vektor dari tipe %qT"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "penginisialisasi untuk %qT harus berupa kurung dilingkupi"
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "nama %qD digunakan dalam sebuah gaya GNU didesign penginisialisasi untuk sebuah array"
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT memiliki anggota data tidak statis bernama %qD"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "terlalu banyak penginisialisasi untuk %qT"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "kurung disekitar penginisialisasi skalar untuk tipe %qT"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "hilang kurung diantara penginisialisasi untuk %qT"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elemen dari array %q#T memiliki tipe tidak lengkap"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ukuran-variabel compound literals"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "objek skalar %qD membutuhkan satu elemen dalam penginisialisasi"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "dalam C++98 %qD harus diinisialisasi dengan konstruktor, bukan dengan %<{...}%>"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "array %qD diinisialisasi dengan tanda kurung string literal %qE"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "penginisialisasi tidak valid untuk anggota statis  dengan konstruktor"
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(diluar dari kelas inisialisasi dibutuhkan)"
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "parameter %qD dinisialisasi"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "membayangi tipe deklarasi sebelumnya dari %q#D"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr "Java objek %qD tidak dialokasikan dengan %<new%>"
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "fungsi %q#D telah dinisialisasi seperti sebuah variabel"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "ukuran array hilang dalam %qD"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "array berukuran-nol %qD"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "desktruktor untuk alien kelas %qT tidak dapat berupa sebuah anggota"
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktor untuk alien kelas %qT tidak dapt berupa sebuah anggota"
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> variable"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D dideklarasikan dengan spesifikasi eksepsi"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definisi dari %qD tidak dalam namespace melingkupi %qT"
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "anggota fungsi statis %q#D dideklarasikan dengan tipe pengkualifikasi"
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "mendifinisikan eksplisit spesialisasi %qD dalam deklarasi friend"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "penggunaan tidak valid dari template-id %qD dalam deklarasi dari primary template"
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "argumen baku tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi sebuah template"
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi inline"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi inline"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi statis"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate with C linkage"
 msgid "literal operator with C linkage"
 msgstr "%Htemplate dengan C linkage"
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "pilihan argumen %qs tidak valid"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> harus kembali %<int%>"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "definisi dari secara implisit dideklarasikan %qD"
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definisi dari secara implisit dideklarasikan %qD"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q+#D explicitly defaulted here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "bukan %q#D anggota fungsi dideklarasikan dalam kelas %qT"
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ melarang inisialisasi dari anggota constant %qD dari bukan integral tipe %qT"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "ukuran dari array %qD memiliki tipe bukan integral %qT"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "ukuran dari array memiliki tipe %qT bukan integral"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "ukuran dari array %qD negatif"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "ukuran dari array negatif"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ melarang array berukuran-nol %qD"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ melarang array berukuran-nol"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ melarang array dengan variabel panjang %qD"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ melarang array dengan variabel panjang"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "array dengan panjang bervariabel  %qD digunakan"
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "overflow dalam dimensi array"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "deklarasi dari %qs sebagai dari voids"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklarasi dari %qD sebagai array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "spesifikasi tipe kembali untuk konstruktor tidak valid"
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "spesifikasi tipe kembali untuk desktruktor tidak valid"
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "tipe kembali yang dispesifikasikan untuk %<operator %T%>"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "variabel tidak bernama atau field dideklarasikan void"
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel atau field dideklarasikan void"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<::%D%>"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<%T::%D%>"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<%D::%D%>"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T bukan sebuah kelas atau ruang nama"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "deklarasi dari %qD sebagai bukan anggota"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "id pendeklarasi hilang; menggunaka kata reserved %qD"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "definisi fungsi tidak mendeklarasikan parameter"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha template-id may not appear in a using-declaration"
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%Hsebuah template-id mungkin tidak muncul dalam sebuah using deklarasi"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "dua atau lebih tipe data dalam deklarasi dari %qs"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "penspesifikasi konflik dalam deklarasi dari %qs"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C tidak mendukung plain %<complex%> yang berarti %<double complex%>"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ melarang deklarasi dari %qs dengan tidak ada tipe"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs tidak didukung oleh target ini"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ 1998 does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 1998 tidak mendukung %<long long%>"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> atau %<unsigned%> tidak valid untuk %qs"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> dan %<unsigned%> dispesifikasikan bersama untuk %qs"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> tidak valid untuk %qs"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> tidak valid untuk %qs"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> tidak valid untuk %qs"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> atau %<short%> tidak valid untuk %qs"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> or %<short%> invalid for %qs"
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%> atau %<short%> tidak valid untuk %qs"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> atau %<short%> dispesifikasikan dengan char untuk %qs"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> dan %<short%> dispesifikasikan bersama untuk %qs"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> atau %<long%> tidak valid untuk %qs"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed, atau unsigned digunakan secara tidak valid untuk %qs"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "kompleks tidak valid untuk %qs"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr "anggota %qD tidak dapat dideklarasikan baik virtual dan statis"
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "type deklarasi tidak valid dalam parameter deklarasi"
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, fuzzy, gcc-internal-format
 #| msgid "parameter declared %<auto%>"
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> diluar deklarasi kelas"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "multiple storage kelas dalam deklarasi dari %qs"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "top-level deklarasi dari %qs menspesifikasikan %<auto%>"
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "lingkup-fungsi %qs secara implisit auto dan dideklarasikan %<__thread%>"
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "spesifikasi kelas penyimpanan tidak valid dalam deklarasi fungsi friend"
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah fungsi"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function uses %<auto%> type specifier without late return type"
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs fungsi menggunakan penspesifikasi tipe %<auto%> tanpa tipe kembali late"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
@@ -38283,279 +38326,279 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type not declared with %<auto%> type specifier"
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs fungsi dengan tipe kembali late tidak dideklarasikan dengan penspesifikasi tipe %<auto%>"
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "constructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "deklarasi friend tidak dalam definisi kelas"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "tidak dapat mendefinisikan fungsi friend %qs dalam sebuah definisi lokal kelas"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktor mungkin tidak memiliki parameter"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T anggota"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T, yang bukan sebuah typedef atau sebuah argumen tipe template"
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD digunakan sebagai sebuah pendeklarasi"
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "anggota fungsi secara implisit friends dari kelasnya"
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra kualifikasi %<%T::%> di anggota %qs"
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "tidak dapat mendefinisikan anggota fungsi %<%T::%s%> dalam %<%T%>"
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "tidak dapat mendefinisikan anggota fungsi %<%T::%s%> dalam %<%T%>"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "tidak dapat mendeklarasikan anggota %<%T::%s%> dalam %qT"
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "bukan parameter %qs tidak dapat menjadi parameter pack"
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "anggota member tidak boleh memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter mungkin tidak memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> diluar deklarasi kelas"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> dalam deklarasi kosong"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "hanya deklarasi dari konstruktor yang dapan berupa %<explicit%>"
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "anggota bukan-objek %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "statis %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, fuzzy, gcc-internal-format
 #| msgid "parameter declared %<auto%>"
 msgid "typedef declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%J typedef nama mungkin berupa sebuah nested-name-specifier"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ melarang tipe nested %qD dengan nama sama seperti kelas yang melingkupi"
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr "tipe kualifier yang dispesifikan untuk deklarasi kelas friend"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> dispesifikan untuk deklarasi kelas friend"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "parameter template tidak dapat berupa friends"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "deklarasi friend membutuhkan kunci kelas, i.e. %<friend class %T::%D%>"
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "deklarasi friend membutuhkan class-key, i.e. %<friend %#T%>"
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "mencoba untuk membuat kelas %qT sebuah friend dari lingkup global"
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "kualifier tidak valid di tipe fungsi bukan anggota"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "deklarasi abstrak %qT digunakan sebagai deklarasi"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%H%<this%> mungkin tidak digunakan dalam konteks ini"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, fuzzy, gcc-internal-format
 #| msgid "parameter declared %<auto%>"
 msgid "non-static data member declared %<auto%>"
@@ -38562,223 +38605,223 @@
 msgstr "parameter dideklarasikan %<auto%>"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "penggunaan tidak valid dari %<::%>"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "deklarasi dari C fungsi %q#D konflik dengan"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "fungsi %qD dideklarasikan virtual didalam sebuah union"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr "%qD tidak dapat dideklarasikan virtual, karena itu selalu statis"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "diduga nama yang dikualifikasikan dalam deklarasi friend untuk destruktor %qD"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklarasi dari %qD sebagai anggota dari %qT"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "diduga kualifikasi nama dalam deklarasi friend untuk konstruktor %qD"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "spesialisasi dari anggota fungsi spesial secara implist dideklarasikan"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel atau field dideklarasikan void"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "field %qD memiliki tipe tidak lengkap"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nama %qT memiliki tipe tidak lengkap"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE bukan fungsi atau anggota fungsi; tidak dapat dideklarasikan sebagai friend"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "constexpr static data member %qD must have an initializer"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "kelas penyimpanan %<auto%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "kelas penyimpanan %<register%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 #| msgid "%Han asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Hsebuah spesifikasi asm tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr "%<static%> dispesifikasikan tidak valid untuk fungsi %qs dideklarasikan diluar lingkup global"
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> penspesifikasi tidak valid untuk fungsi %qs dideklarasikan diluar dari lingkup global"
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual bukan kelas fungsi %qs"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 #| msgid "%qs defined in a non-class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "tidak dapat mendeklarasikan anggota fungsi %qD untuk memiliki linkage statis"
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "tidak dapat mendeklarasikan fungsi statis didalam fungsi lainnya"
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> mungkin tidak digunakan ketika mendefinisikan (terbalik untuk deklarasi) sebuah anggota data statis"
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "tidak dapat secara eksplisit mendeklarasikan anggota %q#D untuk memiliki extern linkage"
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "deklarasi dari %q#D diluar dari kelas bukan sebuah definisi"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs diinisialisasi dan dideklarasi %<extern%>"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs keduanya memiliki %<extern> dan penginisialisasi"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "parameter %qD memiliki tipe kelas Java"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD secara tidak valid dideklarasikan tipe metode"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD includes %s ke array dari ikatan tidak dikenal %qT"
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
@@ -38799,72 +38842,72 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "konstruktor tidak valid; anda mungkin bermaksud %<%T (const %T&)%>"
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD tidak boleh dideklarasikan sebagai statis"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD harus baik sebuah anggota fungsi tidak statis atau bukan anggota fungsi"
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD harus memiliki sebuah argumen dari kelas atau tipe enumerasi"
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to void will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a base class will never use a type conversion operator"
@@ -38871,109 +38914,109 @@
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ melarang overloading operator ?:"
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD tidak boleh memiliki argumen dengan jumlah bervariabel"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumennya"
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumen keduanya"
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr "%qD harus mengambil baik nol atau satu argumen"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr "%qD harus mengambil baik satu atau dua argumen"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr "%qD harus mengambil %<void%>"
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr "%qD harus mengambil secara tepat satu argumen"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "%qD harus mengambil secara tepat dua argumen"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "definisi-pengguna %qD selalu mengevaluasikan kedua argumen"
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD seharusnya kembali dengan nilai"
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "spesialisasi template ambigu %qD untuk %q+D"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "menggunakan typedef-name %qD setelah %qs"
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT mereferensikan sebagai %qs"
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT direferensikan sebagai enum"
@@ -38985,89 +39028,89 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "argumen template dibutuhkan untuk %<%s %T%>"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD memiliki nama sama seperti kelas yang telah dideklarasikan"
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "penggunaan dari enum %q#D tanpa deklarasi sebelumnya"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeklarasi dari %qT sebagai bukan-template"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "deklarasi sebelumnya %q+D"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union turunan %qT tidak valid"
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr "Kelas Java %qT tidak dapat memiliki multiple bases"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr "Kelas Java %qT tidak dapat memiliki bases virtual"
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "tipe base %qT gagal untuk menjadi sebuah struct atau tipe kelas"
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipe rekursif %qT tidak terdefinisi"
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "duplikasi tipe dasar %qT tidak valid"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%J definisi sebelumnya disini"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr "tipe yang digaris bawahi %<%T%> dari %<%T%> harus berupa sebuah tipe integral"
@@ -39076,92 +39119,92 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "tidak ada tipe integral yang dapat merepresentasikan seluruh dari nilai enumerasi untuk %qT"
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "nilai enumerasi untuk %qD bukan sebuah konstanta integer"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow dalam nilai enumerasi di %qD"
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr "tipe kembali memiliki tipe kelas Java %q#T"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> seharusnya mengembalikan referensi ke %<*this%>"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "tidak deklarasi sebelumnya untuk %q+D"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "deklarasi fungsi tidak valid"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "parameter %qD dideklarasikan void"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "tipe kembali fungsi tidak kompatibel karena %<volatile%>"
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "parameter %q+D set but not used"
 msgstr "label %q+D didefinisikan tetapi tidak digunakan"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "deklarasi anggota fungsi tidak valid"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD telah didefinisikan dalam kelas %qT"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -39202,7 +39245,7 @@
 msgid "deleting %qT is undefined"
 msgstr "menghapus %qT tidak terdefinisi"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "template deklarasi dari %q#D"
@@ -39226,7 +39269,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "destruktor %qD dideklarasikan sebagai anggota template"
@@ -39321,28 +39364,28 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "bit-field %qD dengan tipe bukan integral"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a static data member of a class template"
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD bukan sebuah anggota data statis dari sebuah template class"
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonymous struct tidak didalam tipe bernama"
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "kumpulan namespace scope anonymous harus berupa statis"
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonymous union dengan tida ada anggota"
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> harus mengembalikan tipe %qT"
@@ -39351,47 +39394,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "parameter pertama dari %<operator new%> tidak dapat memiliki sebuah argumen baku"
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> mengambil tipe %<size_t%> (%qT) sebagai parameter pertama"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> harus mengembalikan tipe %qT"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> mengambil tipe %qT sebagai parameter pertama"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT dideklarasikan dengan visibility lebih besar dari tipe dari fieldnya %qD"
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT dideklarasikan dengan visibility lebih besar dari basenya %qT"
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using anonymous type, is used but never defined"
@@ -39401,50 +39444,50 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D tidak merefer ke tipe tidak terkualifikasi, jadi ini tidak digunakan untuk linkage"
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "deklarasi sebelumnya dari %q+#D dengan %qL linkage"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "fungsi inline %q+D digunakan tetapi tidak pernah didefinisikan"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "argumen baku hilang untuk parameter %P dari %q+#Ddd"
@@ -39451,12 +39494,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, fuzzy, gcc-internal-format
 #| msgid "deleted function %q+D"
 msgid "use of deleted function %qD"
@@ -40086,43 +40129,43 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "bukan destruktor ataupu class-specific operator delete yang akan dipanggil, meskipun mereka dideklarasikan ketika kelas didefinisikan."
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "penginisialisasi berakhir secara prematur"
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr "tidak dapat menginisialisasi array multidimensi dengan penginisialisasi"
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "ukuran array tidak diketahui dalam delete"
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "kemungkinan masalah terdeteksi dalam penggunaan dari operator delete:"
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "bukan destruktor ataupu class-specific operator delete yang akan dipanggil, meskipun mereka dideklarasikan ketika kelas didefinisikan."
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
@@ -40258,18 +40301,18 @@
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "nama mangled dari %qD tidak akan berubah dalam versi yang akan datang dari GCC"
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
@@ -40701,7 +40744,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr "pengidentifikasi %<%s%> akan menjadi sebuah kata kunci dalam C++0x"
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -40730,7 +40773,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "%Hpermintaan untuk anggota %qE dalam tipe bukan kelas %qT"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<%T::%E%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -40807,7 +40850,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(mungkin sebuah semikolom hilang setelah definisi dari %qT)"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT mungkin bukan sebuah template"
@@ -40836,7 +40879,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "sebuah cast ke sebuah tipe selain dari sebuah integral atau tipe enumerasi tidak dapat muncul dalam sebuah ekspresi konstan"
@@ -41148,7 +41191,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
@@ -41345,7 +41388,7 @@
 msgid "capture of non-variable %qD "
 msgstr "peningkatan dari variabel baca-saja %qD"
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q+#D declared here"
@@ -41413,7 +41456,7 @@
 msgid "compound-statement in constexpr function"
 msgstr "Temukan fungsi pure dan const"
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
@@ -41446,7 +41489,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
@@ -41481,13 +41524,13 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ melarang gotos yang sudah dihitung"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "kelebihan %<;%>"
@@ -41540,7 +41583,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "%Hdefinisi kelas mungkin tidka dideklarasikan sebagai friend"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplates may not be %<virtual%>"
 msgid "templates may not be %<virtual%>"
@@ -41644,13 +41687,13 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "kata kunci %<export%> tidak terimplementasi, dan akan diabaikan"
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack %qD cannot have a default argument"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%Htemplate parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack cannot have a default argument"
 msgid "template parameter pack cannot have a default argument"
@@ -41668,7 +41711,7 @@
 msgid "expected template-id"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -41757,234 +41800,234 @@
 msgid "expected type specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C melarang deklarasi parameter kedepan"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "Diduga tipe ekspresi"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Diduga nama"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "deklarasi %qD tidak mendeklarasikan apapun"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "atribut diabaikan di tipe uninstantiasi"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "atribut diabaikan di template instantiation"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "atribut diabaikan di elaborated type penspesifikasi yang tidak memforward sebuah deklarasi"
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a namespace-name"
 msgid "%qD is not an enumerator-name"
 msgstr "%H%qD bukan sebuah nama namespace"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aktifkan instantiation template otomatis"
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %qD in namespace %qD which does not enclose %qD"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%Hdeklarasi dari %qD dalam namespace %qD yang tidak dilingkupi %qD"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %qD in %qD which does not enclose %qD"
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%Hdeklarasi dari %qD dalam %qD yang tidak dilingkup %qD"
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "multiple definisi dari %q#T"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C++ melarang menaikkan sebuah enum"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a namespace-name"
 msgid "%qD is not a namespace-name"
 msgstr "%H%qD bukan sebuah nama namespace"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "diduga nama class"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha template-id may not appear in a using-declaration"
 msgid "a template-id may not appear in a using-declaration"
 msgstr "%Hsebuah template-id mungkin tidak muncul dalam sebuah using deklarasi"
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a function-definition is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, fuzzy, gcc-internal-format
 #| msgid "%Han asm-specification is not allowed on a function-definition"
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "%Hsebuah spesifikasi asm tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "attributes are not allowed on a function-definition"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinitializer provided for function"
 msgid "initializer provided for function"
 msgstr "%Hpenginisialisasi disediakan untuk fungsi"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "fungsi %q+D redeklarasi sebagai inline"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "array bound bukan sebuah konstanta integer"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<%T::%E%> is not a type"
 msgid "%<%T::%E%> is not a type"
 msgstr "%H%<%T::%E%> bukan sebuah tipe"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of constructor as a template"
 msgid "invalid use of constructor as a template"
 msgstr "%Hpenggunaan tidak valid dari konstruktor sebagai sebuah template"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "penggunaan %<%T::%D%> daripada %<%T::%D%> untuk menamai konstruktor dalam sebuah nama berkualifikasi"
@@ -41993,7 +42036,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid declarator"
@@ -42001,336 +42044,336 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "qualified-id in declaration"
 msgstr "deklarasi fungsi tidak valid"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is a namespace"
 msgid "%qD is a namespace"
 msgstr "%H%qD adalah sebuah namespace"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "operan tidak terduga"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate cv-qualifier"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 #| msgid "multiple inline callers"
 msgid "multiple ref-qualifiers"
 msgstr "multiple pemanggil inline"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, gcc-internal-format
 msgid "invalid use of %<auto%>"
 msgstr "penggunaan tidak valid dari %<auto%>"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr "penggunaan deprecated dari argumen baku untuk parameter bukan fungsi"
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdefault arguments are only permitted for function parameters"
 msgid "default arguments are only permitted for function parameters"
 msgstr "%Hargumen baku hanya diijinkan untuk parameter fungsi"
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, fuzzy, gcc-internal-format
 #| msgid "%H%sparameter pack %qD cannot have a default argument"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%H%s parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "%H%sparameter pack cannot have a default argument"
 msgid "parameter pack cannot have a default argument"
 msgstr "%H%s parameter pack tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "diduga nama class"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D dideklarasikan inline setelah definisinya"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D dideklarasikan inline setelah definisinya"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "Tidak terduga sampah setelah deklarasi fungsi di %C"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "tidak dapat menemukan berkas untuk class %s"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid class name in declaration of %qD"
 msgid "invalid class name in declaration of %qD"
 msgstr "%Hnama kelas tidak valid dalam deklarasi dari %qD"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, fuzzy, gcc-internal-format
 #| msgid "%Hextra qualification not allowed"
 msgid "extra qualification not allowed"
 msgstr "%Hekstra pengkualifikasi diabaikan"
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, fuzzy, gcc-internal-format
 #| msgid "%Han explicit specialization must be preceded by %<template <>%>"
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "%Hsebuah eksplisit spesialisasi harus diawali oleh %<template <>%>"
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfunction template %qD redeclared as a class template"
 msgid "function template %qD redeclared as a class template"
 msgstr "%Htemplate fungsi %qD redeklarasikan sebagai sebuah template kelas"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprevious definition of %q+#T"
 msgid "previous definition of %q+#T"
 msgstr "%Hdefinisi sebelumnya dari %q+#T"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "diduga nama class"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "%Hsebuah class-key harus digunakan ketikan mendeklarasikan sebuah friend"
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "friend declaration does not name a class or function"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, fuzzy, gcc-internal-format
 #| msgid "%Hpure-specifier on function-definition"
 msgid "pure-specifier on function-definition"
 msgstr "%Hpenspesifikasi pure di definisi fungsi"
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<;%> at end of member declaration"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, fuzzy, gcc-internal-format
 #| msgid "invalid AE type specified (%s)\n"
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "tipe AE yang dispesifikasikan (%s) tidak valid\n"
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr ""
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan dalam konteks ini (kelas dasar  adalah sebuah tipe implisit)"
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "redeklarasi tidak valid dari %q+D"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo few template-parameter-lists"
 msgid "too few template-parameter-lists"
@@ -42340,605 +42383,605 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many template-parameter-lists"
 msgid "too many template-parameter-lists"
 msgstr "%Hterlalu banyak template-parameter-lists"
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnamed return values are no longer supported"
 msgid "named return values are no longer supported"
 msgstr "%Hnilai kembali bernama tidak lagi didukung"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid declaration of member template in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "%Hdeklarasi tidak valid dari anggota template dalam kelas lokal"
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate with C linkage"
 msgid "template with C linkage"
 msgstr "%Htemplate dengan C linkage"
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template declaration of %<typedef%>"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexplicit template specialization cannot have a storage class"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Heksplisit template spesialisasi tidak dapat memiliki sebuah kelas penyimpanan"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> seharusnya %<> >%> didalam sebuah daftar argumen template nested"
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, fuzzy, gcc-internal-format
 #| msgid "%Hspurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%Hspurious %<>>%>, gunakan %<>%> untuk mengakhiri sebuah daftar argumen template"
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of %qD in linkage specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "%Hpenggunaan tidak valid dari %qD dalam spesifikasi linkage"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<__thread%> before %qD"
 msgid "%<__thread%> before %qD"
 msgstr "%H%<__thread%> sebelum %qD"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 tidak mendukung %<long long%>"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "baik %<_Sat%> dan %<char%> dalam penspesifikasi deklarasi"
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "duplikasi %qE"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate %qs"
 msgid "duplicate %qs"
 msgstr "%Hduplikasi %qs"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs tag digunakan dalam penamaan %q#T"
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%q#T was previously declared here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD redeclared with different access"
 msgid "%qD redeclared with different access"
 msgstr "%H%qD redeklarasi dengan akses berbeda"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%H%<template%> (sebagai sebuah disambiguator) hanya diijinkan dalam templates"
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfile ends in default argument"
 msgid "file ends in default argument"
 msgstr "%Hberkas berakhir dalam argumen baku"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmisplaced %<@%D%> Objective-C++ construct"
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "%Hsalah tempat %<@%D%> Objective-C++ konstruk"
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<@encode%> must specify a type as an argument"
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%H%<@encode%> harus menspesifikasikan sebuah tipe sebagai sebuah argumen"
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid Objective-C++ selector name"
 msgid "invalid Objective-C++ selector name"
 msgstr "%Hpemilih nama Objective-C++ tidak valid"
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%J atribut daerah tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, fuzzy, gcc-internal-format
 #| msgid "%Hidentifier expected after %<@protocol%>"
 msgid "identifier expected after %<@protocol%>"
 msgstr "%Hpengidentifikasi diduga setelah %<@protocol%>"
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE atribut diabaikan untuk %qE"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected positive integer expression"
 msgstr "diduga ekspresi integer"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "inisialisasi berkurung tidak diijinkan dalam loop OpenMP %<for%>"
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "inisialisasi berkurung tidak diijinkan dalam loop OpenMP %<for%>"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterasi variabel %qD seharusnya bukan reduksi"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnot enough collapsed for loops"
 msgid "not enough collapsed for loops"
 msgstr "%Htidak cukup kolaps untuk loops"
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "diduga ekspresi"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, fuzzy, gcc-internal-format
 #| msgid "%Hjunk at end of %<#pragma GCC pch_preprocess%>"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%Hsampah diakhir dari %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "batasan untuk operan tidak valid"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "Diduga nama variabel di %C"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "%Htemplate mungkin bukan %<virtual%>"
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "anggota data %qD tidak dapat berupa sebuah anggota template"
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "deklarasi anggota template %qD tidak valid"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "explisit spesialisasi dalam lingkup non-namespace %qD"
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "template kelas yang melingkupi tidak secara eksplisit terspesialisasi"
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "spesialisasi dari %qD dalam namespace berbeda"
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "spesialisasi dari %qD dalam namespace berbeda"
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr "  dari definisi dari %q+#D"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "eksplisit instantiation dari %qD dalam namespace %qD (yang tidak melingkupi namespace %qD)"
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "nama dari template kelas bayangan parameter template %qD"
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of alias template %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "spesialisasi dari %qT setelah instantiation"
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "spesialisasi %q#T dalam namespace berbeda"
@@ -42945,73 +42988,73 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "spesialisasi %qT setelah instantiation %qT"
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "fungsi template partial spesialisasi %qD tidak diijinkan"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "spesialisasi dari %qD setelah instansiasi"
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid "candidate is: %#D"
 msgstr "kandidat adalah: %+#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
 msgstr "%s %+#D"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD bukan sebuah variabel"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "template-id %qD untuk %q+D tidak cocok dengan deklarasi template apapun"
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "spesialisasi template ambigu %qD untuk %q+D"
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %D (should be %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -43018,59 +43061,59 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "template-id %qD dalam deklarasi dari template utama"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "daftar parameter template digunakan dalam instantiation eksplisit"
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "definisi disediakan untuk instantiation eksplisit"
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "terlalu banyak daftar parameter template dalam deklarasi dari %qD"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "terlalu sedikit daftar parameter template dalam deklarasi dari %qD"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "eksplisit spesialisasi dari %qD harus dikenalkan oleh %<template <>%>"
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "fungsi template partial spesialisasi %qD tidak diijinkan"
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "fungsi template partial spesialisasi %qD tidak diijinkan"
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "argumen baku dispesifikasikan dalam spesialisasi eksplisit"
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD bukan sebuah fungsi template"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "%qD tidak dideklarasikan dalam %qD"
@@ -43083,94 +43126,94 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "spesialisasi dari anggota fungsi spesial secara implist dideklarasikan"
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "tidak ada anggota fungsi %qD dideklarasikan dalam %qT"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr "ekspansi penginisialisasi dasar %<%T%> berisi parameter packs"
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr "pola ekspansi %<%T%> berisi tidak ada argumen packs"
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr "pola ekspansi %<%E%> berisi tidak ada argumen packs"
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parameter packs tidak diekspan dengan %<...%>:"
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonymous>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "deklarasi dari %q+#D"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr " bayangan template parameter %q+#D"
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameter pack argumen %qE harus berada di akhir dari daftar argumen template"
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameter pack argumen %qT harus berada di akhir dari daftar argumen template"
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "template argumen %qE melibatkan parameter template"
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT of template argument %qE depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -43178,13 +43221,13 @@
 msgstr[0] "tipe %qT dari template argumen %qE tergantung di parameter template"
 msgstr[1] "tipe %qT dari template argumen %qE tergantung di parameter template"
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "spesialisasi dari %qD setelah instansiasi"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "tidak ada argumen baku untuk %qD"
@@ -43192,47 +43235,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameter pack %qE harus berada di akhir dari daftar parameter template"
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "argumen baku tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr "argumen baku tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argumen baku untuk parameter dari tipe %qT memiliki tipe %qT"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "template kelas tanpa sebuah nama"
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -43243,57 +43286,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "deklarasi template dari %qD tidak valid"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "definisi template dari bukan template %q#D"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "diduga %d tingkat dari parm template untuk %q#D, diperoleh %d"
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "diperoleh %d parameter template untuk %q#D"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "diperoleh %d parameter template untuk %q#T"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  tetapi %d dibutuhkan"
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "template argumen ke %qD tidak cocok dengan template asli %qD"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr "gunakan template<> untuk spesialisasi eksplisit"
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT bukan sebuah tipe template"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "penspesifikasi template tidak dispesifikasikan dalam deklarasi dari %qD"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redeclared with %d template parameter(s)"
 msgid "redeclared with %d template parameter"
@@ -43301,7 +43344,7 @@
 msgstr[0] "redeklarasikan dengan %d parameter template"
 msgstr[1] "redeklarasikan dengan %d parameter template"
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter(s)"
 msgid "previous declaration %q+D used %d template parameter"
@@ -43309,12 +43352,12 @@
 msgstr[0] "deklarasi sebelumnya %q+D digunakan %d parameter template"
 msgstr[1] "deklarasi sebelumnya %q+D digunakan %d parameter template"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "parameter template %q+#D"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redeklarasikan disini sebagai %q#D"
@@ -43323,114 +43366,114 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redefinisi dari argumen baku untuk %q#D"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J definisi asli muncul disini"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "ini harus berupa alamat dari sebuah fungsi dengan hubungan eksternal"
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "ini harus berupa alamat dari sebuah fungsi dengan hubungan eksternal"
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena objek %qD bukan eksternal linkage"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(sebuah penunjuk ke anggota hanya dapat dibentuk dengan %<&%E%>)"
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "diperoleh %d parameter template untuk %q#D"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "  mismatched types %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack %qD cannot have a default argument"
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "%Htemplate parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, fuzzy, gcc-internal-format
 #| msgid "template arguments to %qD do not match original template %qD"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "template argumen ke %qD tidak cocok dengan template asli %qD"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs tidak valid untuk %qs"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -43437,186 +43480,186 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "tidak dapat mengubah tipe %qT ke tipe %qT"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT adalah sebuah dasar ambigu dari %qT"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "tipe %qT tidak diturunkan dari tipe %qT"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, fuzzy, gcc-internal-format
 #| msgid "template arguments to %qD do not match original template %qD"
 msgid "  template argument %qE does not match %qD"
 msgstr "template argumen ke %qD tidak cocok dengan template asli %qD"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "  could not resolve address from overloaded function %qE"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena string literal tidak dapat digunakan dalam konteks ini"
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "in template argument for type %qT "
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD bukan sebuah template argumen yang valid karena %qD bukan sebuah variabel, bukan alamat dari sebuah variabel"
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD bukan sebuah template argumen yang valid karena %qD bukan sebuah variabel, bukan alamat dari sebuah variabel"
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qE bukan sebuah variabel"
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qE bukan sebuah variabel"
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena konflik dalam cv kualifikasi"
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini bukan sebuah lvalue"
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena ini bukan sebuah ekspresi konstan"
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena objek %qD bukan eksternal linkage"
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena objek %qD bukan eksternal linkage"
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini adalah sebuah penunjuk"
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "lebih baik coba gunakan %qE"
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini dari tipe %qT"
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "konversi baku tidak diijinkan dalam konteks ini"
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, fuzzy, gcc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "ignoring attributes on template argument %qT"
 msgstr "Konflik dalam atribut dari argumen fungsi di %C"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "nama dari template kelas bayangan parameter template %qD"
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "%Hpenggunaan tidak valid dari desktruktor %qD memiliki sebuah tipe"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "merefer ke sebuah anggota tipe dari sebuah parameter template, gunakan %<typename %E%>"
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "tipe/nilai tidak cocok di argumen %d dalam daftar parameter template untuk %qD"
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  diduga sebuah konstanta dari tipe %qT, diperoleh %qT"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  diduga sebuah template kelas, diperoleh %qE"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  diduga sebuah tipe, diperoleh %qE"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  diduga sebuah tipe, diperoleh %qT"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  diduga sebuah template kelas, diperoleh %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
@@ -43624,80 +43667,80 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "tipe tidak cocok dalam paket parameter bukan tipe"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr "tidak dapat mengubah argumen template %qE ke %qT"
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "disediakan untuk %q+D"
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "tipe bukan template %qT digunakan sebuah sebuah template"
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "untuk deklarasi template %q+D"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "kedalaman template instantiation melebihi maksimal dari %d (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal) instantiating %qD"
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "panjang argumen pack tidak cocok akan diekspan %<%T%>"
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "panjang argumen pack tidak cocok ketika mengekspan %<%E%>"
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %D"
@@ -43716,277 +43759,277 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabel %qD memiliki tipe fungsi"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipe parameter %qT tidak valid"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "dalam deklarasi %q+D"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "fungsi mengembalikan sebuah array"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "fungsi mengembalikan sebuah fungsi"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "membuat penunjuk ke anggota fungsi dari tipe bukan kelas %qT"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "membentuk referensi ke void"
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "membuat penunjuk ke anggota dari tipe void"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "membuat array dari %qT"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT bukan sebuah tipe class, struct, atau union"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe enumerasi"
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe class"
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "dependent-name %qE diparse sebagai sebuah bukan-tipe, tetapi instantiation menghasilkan sebuah tipe"
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "katakan %<typename %E%> jika sebuah tipe adalah berarti"
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "menggunakan field tidak valid %qD"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "penggunaan tidak valid dari ekspresi ekspansi pack"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "gunakan %<...%> untuk mengekspan argumen pack"
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D declared here, later in the translation unit"
 msgstr "%q+D dideklarasikan inline setelah definisinya"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bukan sebuah class atau namespace"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD bukan sebuah class atau namespace"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr "%qT adalah/menggunakan tipe anonymous"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "argumen template untuk %qD menggunakan tipe lokal %qT"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT adalah sebuah tipe variabel termodifikasi"
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  mencoba untuk instantiate %qD"
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD bukan sebuah anggota data statis dari sebuah template class"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "tipe %qT untuk instantiation eksplisit %qD tidak cocok dengan tipe yang dideklarasikan %qT"
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eksplisit instantiation dari %q#D"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "duplikasi eksplisit instantiation dari %q#D"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 melarang penggunaan dari %<extern%> di instantiation eksplisit"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "class penyimpanan %qD diaplikasikan ke template instantiation"
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplisit instantiation dari %q#T sebelum definisi dari template"
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ melarang penggunaan dari %qE di instantiasi eksplisit"
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "duplikasi instansiasi eksplisit dari %q#T"
@@ -43998,67 +44041,67 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplisit instansiasi dari %qD tetapi tidak ada definisi yang tersedia"
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "kedalaman template instansiasi melebihi maksimal dari %d instantiating %q+D, kemungkinan dari pembuatan tabel virtual (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal)"
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bukan sebuah tipe valid untuk sebuah parameter template konstan"
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, fuzzy, gcc-internal-format
 #| msgid "deducing auto from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "deduksi auto dari daftar penginisialisasi dikurung membutuhkan #include <daftar_penginisialisasi>"
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
@@ -44301,72 +44344,72 @@
 msgid "invalid base-class specification"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anggota terproteksi %q+#D dalam union anonymous"
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
 msgstr "%qD bukan sebuah tipe"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "penggunaan dari variabel %<auto%> dari fungsi yang berisi"
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of parameter from containing function"
 msgstr "penggunaan dari variabel %<auto%> dari fungsi yang berisi"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "parameter template %qD dari tipe %qT tidak diijinkan dalam sebuah ekspresi konstanta integral karena ini bukan tipe integral atau enumerasi"
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "penggunaan dari namespace %qD  sebagai ekspresi"
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "penggunaan dari template class %qT sebagai ekspresi"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "permintaan untuk anggota %qD adalah ambigu dalam multiple inheritance lattice"
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "tipe dari %qE tidak dikenal"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
@@ -44373,210 +44416,210 @@
 msgstr "%qT bukan sebuah tipe template"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke destruktor %<~%T%>"
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction%>"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD bukan sebuah variabel dalam clause %<firstprivate%>"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD bukan sebuah variabel dalam clause %<lastprivate%>"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_teams%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<device%> id must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr "%qE memiliki tipe referensi untuk %qs"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD bukan berkas, namespace atau blok scope variabel"
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE direktif tidak dalam definisi %qT"
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdifference between %qE and %qD does not have integer type"
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%Hperbedaan antara %qE dan %qD tidak memiliki tipe integer"
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Htipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed: %s"
 msgstr "static assertion gagal: %E"
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "kondisi bukan konstan untuk assertion static"
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "argumen ke decltype harus berupa sebuah ekspresi"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
@@ -44593,131 +44636,131 @@
 msgid "lambda-expression in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class Java"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr "%qE sudah ditinggalkan; g++ vtables sekaran COM-compatibel secara baku"
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "permintaan init_priority bukan sebuah konstanta integer"
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "hanya dapat menggunakan atribut %qE di definisi lingkup-berkas dari objek dari tipe class"
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "permintaan init_priority diluar dari jangkauan"
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "permintaan init_priority disimpan untuk penggunaan internal"
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "atribut %qE tidak didukung di platform ini"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
 msgstr "deklarasi sebelumnya %q+#D disini"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "%qD atribut membutuhkan sebuah argumen NTBS tunggal"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> bukan sebuah deklarator yang valid"
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> bukan sebuah deklarator yang valid"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "atribut %J%qE berlaku hanya untuk fungsi"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute applied to %s %s at %L"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%s atribut diaplikasikan ke %s %s di %L"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "array bound bukan sebuah konstanta integer"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "pemeriksaan lang_*: gagal dalam %s, di %s:%d"
@@ -44925,601 +44968,596 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr "alignmen dari elemen array lebih besar dari ukuran elemen"
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr "ISO C++ melarang subscripting array bukan-lvalue"
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "subscripting array dideklarasikan %<register%>"
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "nilai subscripted adalah bukan array ataupun penunjuk"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objek hilang dalam penggunaan dari %qE"
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ melarang pemanggilan %<::main%> dari dalam aplikasi"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "harus menggunakan %<.*%> atau %<->*%> untuk memanggil penunjuk-ke-anggota fungsi dalam %<%E (...)%>, contoh %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "terlalu banyak argumen ke %s %q+#D"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "terlalu sedikit argumen ke %s %q+#D"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to member function %q#D"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to member function %q#D"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to function %q#D"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to function %q#D"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "terlalu banyak argumen ke %s %q+#D"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "terlalu sedikit argumen ke %s %q+#D"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "terlalu banyak argumen ke fungsi"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "terlalu sedikit argumen ke fungsi"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter %P dari %qD memiliki tipe tidak lengkap %qT"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameter %P memiliki tipe tidak lengkap %qT"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "mengasumsikan cast ke tipe %qT dari fungsi overloaded"
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL digunakan dalam aritmetik"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "jumlah rotasi kiri negatif"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "jumlah rotasi kanan negatif"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "jumlah rotasi kiri >= lebar dari tipe"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "jumlah rotasi kanan >= lebar dari tipe"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr "perbandingan dengan string literal menghasilkan perilaku yang tidak dispesifikasikan"
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "alamat dari %qD tidak akan pernah menjadi KOSONG"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ melarang perbandingan diantara penunjuk dan integer"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "operand types are %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "perbandingan tidak berurut di argumen bukan titik pecahan"
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "operang tidak valid untuk tipe %qT dan %qT ke binari %qO"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk dari tipe %<void *%> dalam pengurangan"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah fungsi  dalam pengurangan"
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah metoda  dalam pengurangan"
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "penggunaan tidak valid dari sebuah penunjuk ke sebuah tipe tidak lengkap dalam aritmetik penunjuk"
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qE"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qE"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "penggunaan tidak valid dari %qE untuk membentuk sebuah penunjuk ke anggota fungsi"
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  sebuah kualified-id dibutuhkan"
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "tanda kurung disekitar %qE tidak dapat digunakan untuk membentuk sebuah penunjuk-ke-anggota-fungsi"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ melarang mengambil alamat dari tidak terkualifikasi atau bertanda kurun anggota bukan statis fungsi untuk membentuk sebuah penunjuk ke anggota fungsi. Katakan %<&%T::%D%>"
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ melarang mengambil alamat dari sebuah anggota fungsi terikat ke sebuah bentuk penunjuk ke anggota fungsi. Katakan %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ melarang mengambil alamat dari fungsi %<::main%>"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr "ISO C++ melarang mengambil alamat dari sebuah cast ke sebuah ekspresi bukan lvalue"
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "tidak dapat membuat penunjuk ke anggota referensi %qD"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ melarang menaikkan sebuah enum"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ melarang mengurangi sebuah enum"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ melarang meningkatkan sebuah penunjuk dari tipe %qT"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ melarang mengurangi sebuah penunjuk dari tipe %qT"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "penggunaan tidak valid dari ekspresi Boolean sebagai operan ke %<operator--%>"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "tidak dapat mengambil alamat dari %<this%>, yang merupakan ekspresi rvalue"
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "alamat dari variabel eksplisit register %qD diminta"
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "alamat yang diminta untuk %qD, yang dideklarasikan %<register%>"
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "penginisialisasi untuk %qT harus berupa kurung dilingkupi"
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "cast from type %qT to type %qT casts away constness"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away constness"
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away constness"
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "useless cast to type %qT"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "tidak valid static_cast dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "mengubah dari %qT ke %qT"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "cast tidak valid dari sebuah ekspresi rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr "cast dari %qT ke %qT kehilangan presisi"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "cast dari %qT ke %qT menaikan alignmen yang dibutuhkan dari tipe target"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ melarang casting diantara penunjuk ke fungsi dan penunjuk ke objek"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "cast dari tipe %qT ke tipe %qT tidak valid"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "penggunaan tidak valid dari const_cast dengan tipe %qT, yang bukan sebuah penunjuk, referensi, ataupun sebuah tipe penunjuk-ke-anggota-data"
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "penggunaan tidak valid dari const_cast dengan tipe %qT, yang merupakan sebuah penunjuk atau referensi ke sebuah tipe fungsi"
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "const_cast tidak valid dari sebuah rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "const_cast dari tipe %qT ke tipe %qT tidak valid"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ melarang casting ke sebuah tipe array %qT"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  dalam evaluasi dari %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "tipe tidak kompatibel dalam assignmen dari %qT ke %qT"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "array digunakan sebagai penginisialisasi"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "assignmen array tidak valid"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   dalam penunjuk ke anggota fungsi konversi"
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "penunjuk ke anggota konversi melalui basis maya %qT"
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   dalam penunjuk ke anggota konversi"
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "konversi tidak valid ke tipe %qT dari tipe %qT"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "tidak dapat mengubah %qT ke %qT untuk argumen %qP ke %qD"
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "tidak dapat mengubah %qT ke %qT untuk argumen %qP ke %qD"
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in return"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "argumen %d dari %qE mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "tipe kembali mungkin berupa sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "penempatan sisi tangan-kiri mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "dalam melewatkan argumen %P dari %q+D"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "mengembalikan referensi ke sementara"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "referensi ke bukan-lvalue dikembalikan"
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr "referensi ke variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %q+D returned"
 msgstr "alamat dari variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr "alamat dari variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "mengembalikan sebuah nilai dari sebuah destruktor"
@@ -45526,46 +45564,46 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "tidam dapat kembali dari sebuah penanganan dari sebuah fungsi-coba-blok dari sebuah konstruktor"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "mengembalikan sebuah nilai dari sebuah konstruktor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "pernyataan-kembali dengan tidak ada nilai, dalam fungsi mengembalikan %qT"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "hilang penginisialisasi"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "pernyataan kembali dengan sebuah nilai, dalam fungsi mengembalikan 'void'"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> harus tidak mengembalikan KOSONG kecuali ini dideklarasikan %<throw()%> (atau ada dalam pengaruh -fcheck-new )"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -45819,127 +45857,127 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr "menyempitkan konversi %qE dari %qT ke %qT didalam { }"
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "menyempitkan konversi %qE dari %qT ke %qT didalam { }"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-array diinisialisasi dari string bukan-lebar"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-array diinisialisasi dari string lebar tidak kompatibel"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "inisialisasi-string untuk array dari karakter terlalu panjang"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "tidak dapat menginisialisasi kumpulan dari tipe %qT dengan sebuah kompound literal"
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "array harus diinisialisasi dengan sebuah kurung melingkupi penginisialisasi"
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "tidak ada field %qD ditemukan dalam union sedang diinisialisasi"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "nilai indeks daripada nama field dalam union penginisialisasi"
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "penunjuk circular delegasi terdeteksi"
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "operan dasar dari %<->%> memiliki tipe bukan penunjuk %qT"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "hasil dari %<operator->()%> menghasilkan hasil bukan penunjuk"
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "operan dasar dari %<->%> bukan sebuah penunjuk"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE tidak dapat digunakan sebagai sebuah anggota penunjuk, karena ini adalah tipe %qT"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "tidak dapat mengaplikasikan anggota penunjuk %qE ke %qE, yang dari tipe bukan class %qT"
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "penunjuk ke anggota tipe %qT tidak kompatibel dengan tipe objek %qT"
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, fuzzy, gcc-internal-format
 #| msgid "invalid value-initialization of reference types"
 msgid "invalid value-initialization of reference type"
 msgstr "nilai-inisialisasi dari referensi tidak valid"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi %qD yang melemparkan tipe tidak lengkap %q#T"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi yang melemparkan tipe tidak lengkap %q#T"
@@ -46127,8 +46165,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -46274,7 +46312,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr "Fortran 2003: Array konstruktor termasuk tipe spesifikasi di %C"
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Type-spec at %L cannot contain a deferred type parameter"
@@ -46398,7 +46436,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa INTEGER atau PROSEDUR"
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -47070,13 +47108,13 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "'source' argumen dari 'shape' intrinsik di %L tidak boleh sebuah ukuran arrayyang diasumsikan"
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa sebuah skalar"
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L cannot be INTENT(IN)"
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
@@ -47366,6 +47404,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa INTEGER atau LOGIKAL"
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -47373,7 +47416,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -47617,430 +47660,430 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Variabel '%s' di %C dengan sebuah penginisialisasi telah muncul dalam sebuah pernyataan DATA"
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "tidak dapat menginisialisasi array multidimensi dengan penginisialisasi"
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Sintaks error dalam deklarasi data di %C"
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Komponen array dari struktur di %C harus memiliki bentuk eksplisit atau deffered"
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Komponen penunjuk array dari struktur di %C harus memilki sebuah bentuk deffered"
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Komponen dapat dialokasikan dari struktur di %C harus memiliki sebuah bentuk deffered"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Struktur komponen array di %C harus memiliki sebuah bentuk eksplisit"
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "inisialisasi NULL() di %C adalah ambigu"
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NULL() initialization at %C is ambiguous"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "inisialisasi NULL() di %C adalah ambigu"
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Inisialisasi dari pointer di %C tidak diperbolehkan dalam prosedur PURE"
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Error in pointer initialization at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "non-NULL pointer initialization at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "Function name %qs not allowed at %C"
 msgstr "Nama fungsi '%s' tidak diperbolehkan di %C"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Duplikasi spesifikasi array untuk Cray pointee di %C"
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid value-initialization of reference types"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "nilai-inisialisasi dari referensi tidak valid"
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Inisialisasi di %C bukan sebuah variabel penunjuk"
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Inisialisasi dari penunjuk di %C membutuhkan '=>', bukan '='"
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Diduga sebuah ekspresi inisialisasi di %C"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Inisialisasi dari variabel di %C tidak diperbolehkan alam prosedur PURE"
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Inisialisasi dari komponen dapat dialokasikan di %C tidak diperbolehkan"
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Tipe deklarasi gaya-lama %s*%d tidak didukung di %C"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Tipe deklarasi tidak-baku %s*%d di %C"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Hilang paranthesis kanan di %C"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Diduga ekspresi inisialisasi di %C"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Didugak ekspresi inisialisasi skalar di %C"
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Jenis %d tidak didukung untuk tipe %s di %C"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Jenis tipe parameter C adalah untuk tipe %s tetapi tipe di %L adalah %s"
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Hilang paranthesis kanan atau koma di %C"
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Jenis %d tidak didukung untuk KARAKTER di %C"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Sintaks error dalam deklarasi KARAKTER di %C"
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Ekstensi: BYTE tipe di %C"
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "tipe BYTE digunakan di %C tidak tersedia dalam mesin target"
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Argumen dengan nilai di %L tidak diperbolehkan dalam konteks ini"
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "CLASS statement at %C"
 msgstr "Diduga pernyataan CASE di %C"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Tipe nama '%s' di %C adalah ambigu"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Duplikasi pernyataan IMPLISIT NONE di %C"
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Hilang jangkauan karakter dalam IMPLISIT di %C"
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Huruf harus dalam urutan alphabet dalam pernyataan IMPLISIT di %C"
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "pernyataan SAVE di %C mengikuti blanket pernyataan SAVE"
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "pernyataan IMPOR di %C hanya diijinkan di sebuah tubuh ANTAR-MUKA"
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Diduga daftar dari entiti bernama di %C"
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot IMPORT '%s' from host scoping unit at %C - does not exist."
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "Tidak dapat IMPOR '%s' dari satuan host scoping di %C - tidak ada."
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is already IMPORTed from host scoping unit at %C."
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "'%s' telah ter-IMPOR dari satuan host scoping di %C."
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Sintaks error dalam pernyataan IMPOR di %C"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "Missing codimension specification at %C"
 msgstr "Hilang spesifikasi dimensi di %C"
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Hilang spesifikasi dimensi di %C"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Duplikasi %s atribut di %L"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atribut DAPAT DIALOKASIKAN di %C dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Atribut di %L tidak diijinkan dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003: Atribut %s di %L dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s atribut di %L tidak diperbolehka diluar dari bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "TERPROTEKSI di %C hanya diperbolehkan dalam bagian spesifikasi dari modul"
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED attribute at %C"
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003: atribut TERPROTEKSI di %C"
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE attribute at %C"
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003: atribut NILAI di %C"
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE attribute at %C"
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003: atribut VOLATILE di %C"
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Multiple pengidentifikasi disediakan dengan penspesifikasi NAMA= tunggal di %C"
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly declared BIND(C) function '%s' at %L may not be C interoperable"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "secara implisit terdeklarasi fungsi BIND(C) '%s' di %L mungkin tidak C interoperable"
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L may not be a C interoperable kind though common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Variabel '%s' dalam blok umum '%s' di %L mungkin tidak berupa jenis C dapat berinteroperasi melalui blok umum '%s' adalah BIND(C)"
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, fuzzy, gcc-internal-format
 #| msgid "Type declaration '%s' at %L is not C interoperable but it is BIND(C)"
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Tipe deklarasi '%s' di %L bukan C interoperable tetapi ini adalah BIND(C)"
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L may not be a C interoperable kind but it is bind(c)"
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Variabel '%s' di %L mungkin bukan sebuah jenis C interoperable tetapi ini adalah bind(c)"
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L cannot be declared with BIND(C) since it is not a global"
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Variabel '%s' dalam blok umum '%s' di %L tidak dapat dideklarasikan dengan BIND(C)karena ini bukan sebuah global"
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Tipe kembali dari fungsi BIND(C) '%s' di %L tidak dapat berupa sebuah array"
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -48048,297 +48091,297 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is marked PRIVATE but has been given the binding label '%s'"
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Simbol '%s' di %L ditandai PRIVATE tetapi telah diberikan level binding '%s'"
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Dibutuhkan baik entiti atau nama blok umum untuk pernyataan spesifikasi atribut di %C"
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Hilang entiti atau nama blok umum untuk pernyataan spesifikasi atribut di %C"
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "hilang angka"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Tipe turunan di %C belum pernah didefinisikan sebelumnya jadi tidak dapat muncul dalam sebuah tipe definisi turunan"
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Sintaks error dalam deklarasi data di %C"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "IMPURE procedure at %C"
 msgstr "nama prosedur = %s"
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Diduga alternatif label kembali di %C"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Nama '%s' di %C adalah nama dari prosedur"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Tidak teduga sampah dalam daftar argumen formal di %C"
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Duplikasi simbol '%s dalam daftar argumen formal di %C"
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "variabel RESULT di %C harus berbeda dari nama fungsi"
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Tidak terduga sampah setelah deklarasi fungsi di %C"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BIND(C) attribute at %L may not be specified for an internal procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008: BIND(C) atribut di %L mungkin tidak dispesifikasikan untuk sebuah prosedur internal"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "atribut BIND(C) di %C membutuhkan sebuah antar-muka dengan BIND(C)"
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "prosedur BIND(C) dengan NAMA mungkin tidak memiliki atribut PENUNJUK di %C"
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Prosedur dummy di %C mungkin tidak memiliki atribut BIND(C) dengan NAMA"
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Nama tipe turunan '%s' di %C telah memiliki sebuah tipe dasar dari %s"
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Sintaks error dalam pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Diduga '::' setelah atribut binding di %C"
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Procedure pointer component at %C"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in structure constructor at %C"
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Sintaks error dalam struktur konstruktor di %C"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROSEDUR di %C harus berupa sebuah antar-muka umum"
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROCEDURE statement at %C"
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Sintaks error dalam pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROCEDURE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003: pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Diduga daftar argumen formal dalam definisi fungsi di %C"
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "atribut BIND(C) di %L hanya dapat digunakan untuk variabel atau blok umum"
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah APLIKASI"
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah MODUL"
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah DATA BLOK"
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah ANTAR-MUKA"
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok TIPE TURUNAN"
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok IF-THEN"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "pernnyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok DO"
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok SELECT"
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok FORALL"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok WHERE"
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah subprogram terkontain"
 
-#: fortran/decl.c:5597
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
-msgid "gfc_match_entry(): Bad state"
-msgstr "gfc_trans_code(): Pernyataan kode buruk"
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Unexpected END statement at %C"
+msgid "Unexpected ENTRY statement at %C"
+msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah prosedur terkontain"
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Hilang parantheses yang dibutuhkan sebelum BIND(C) di %C"
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid C name in NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Nama C tidak valid dalam penspesifikasi NAMA= di %C"
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Sintaks error dalam penspesifikasi NAMA= untuk binding label di %C"
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "ASYNCHRONOUS= penspesifikasi di %L harus berupa ekspresi inisialisasi"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Hilang penutup paren untuk binding label di %C"
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Tidak ada nama binding diijinkan dalam BIND(C) di %C"
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Untuk prosedur dummy %s, tidak ada nama binding diijinkan dalam BIND(C) di %C"
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAMA tidak diijinkan dalam BIND(C) untuk ANTAR-MUKA ABSTRAK di %C"
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot follow %s statement at %L"
 msgid "END statement instead of %s statement at %L"
@@ -48345,558 +48388,564 @@
 msgstr "pernyataan %s di %C tidak dapat mengikuti pernyataan %s di %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "pernyataan %s tidak terduga di %L"
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Diduga pernyataan %s di %C"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Diduga nama blok dari '%s' dalam pernyataan %s di %C"
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Diduga nama berakhir di %C"
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Diduga label '%s' untuk pernyataan %s di %C"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Hilang spesifikasi array di %L dalam pernyataan DIMENSI"
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr "Dimensi dipesifikasikan untuk %s di %L setelah inisialisasinya"
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing array specification at %L in DIMENSION statement"
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Hilang spesifikasi array di %L dalam pernyataan DIMENSI"
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Spesifikasi array harus deferred di %L"
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Karakter tidak terduda dalam daftar variabel di %C"
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Diduga nama variabel di %C"
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Penunjuk Cray di %C harus berupa sebuah integer"
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Penunjuk Cray di %C memiliki %d bytes ketelitian; alamat memori membutuhkan %d bytes"
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Diduga \",\" di %C"
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Diduga \")\" di %C"
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Diduga \",\" atau akhir dari pernyataan di %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Deklarasi penunjuk cray di %C membutuhkan pilihan -fcray-pointer"
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Spesifikasi akses dari operator %s di %C telah dispesifikasikan"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Spesifikasi akses dari operator .%s.  di %C telah dispesifikasikan"
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003: pernyataan TERPROTEKSI di %C"
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Sintaks error dalam pernyataan TERPROTEKSI di %C"
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "pernyataan PRIVATE di %C hanya diperbolehkan dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "pernyataan PUBLIK di %C hanya diperbolehkan dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Nama variabel diduga di %C dalam pernyataan PARAMETER"
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Diduga tanda = dalam pernyataan PARAMETER di %C"
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Diduga ekspresi di %C dalam pernyataan PARAMETER"
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Inisialisasi variabel  yang telah diinisialisasi di %C"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Karakter tidak terduga dalam pernyataan PARAMETER di %C"
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Blanket pernyataan SAVE di %C mengikuti pernyataan SAVE sebelumnya"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "pernyataan SAVE di %C mengikuti blanket pernyataan SAVE"
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Sintaks error dalam pernyataan SAVE di %C"
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003: pernyataan NILAI di %C"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Sintaks error dalam pernyataan NILAI di %C"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003: pernyataan VOLATILE di %C"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Sintaks error dalam pernyataan VOLATILE di %C"
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Duplikasi pernyataan SEQUENCE di %C"
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VALUE statement at %C"
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Sintaks error dalam pernyataan NILAI di %C"
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "PROSEDUR MODUL di %C harus dalam sebuah antar-muka modul umum"
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic procedure '%s' not allowed in PROCEDURE statement at %C"
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Prosedur intrinsik '%s' tidak diperbolehkan dalam pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Ambigu simbol dalam definisi TIPE di %C"
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Simbol '%s' di %C telah diassosiasikan host"
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in EXTENDS expression at %C is not a derived type"
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "'%s' dalam ekspresi EXTENDS di %C bukan sebuah tipe turunan"
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is BIND(C)"
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "'%s' tidak dapat diekstensikan di %C karena ini adalah BIND(C)"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is a SEQUENCE type"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "'%s' tidak dapat diekstensikan di %C karena ini adalah tipe SEQUENCE"
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Tipe turunan di %C hanya dapat berupa PRIVATE dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Tipe turunan di %C hanya dapat berupa PUBLIK dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ABSTRACT type '%s' used at %L"
 msgid "ABSTRACT type at %C"
 msgstr "tipe ABSTRAK '%s' digunakan di %L"
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Diduga :: dalam definisi TIPE di %C"
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Nama tipe '%s' di %C tidak dapat sama seperti sebuah tipe intrinsic"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Nama tipe turunan '%s' di %C telah memiliki sebuah tipe dasar dari %s"
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Definisi tipe turunan dari '%s' di %C telah terdefinisi"
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray Pointee di %C tidak dapat diasumsikan bentuk array"
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ENUM and ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003: ENUM dan ENUMERATOR di %C"
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Enumerator melebihi tipe integer C di %C"
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L tidak diinisialisasi dengan ekspresi integer"
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "pernyataan definisi ENUM diduga sebelum %C"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Sintaks error dalam definisi ENUMERATOR di %C"
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Duplikasi penspesifikasi akses di %C"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Binding atribut telah menspesifikasikan passing, tidak legal NOPASS di %C"
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Binding atribut telah menspesifikasikan passing, tidak legal PASS di %C"
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Duplikasi %s atribut di %L"
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Duplikasi NON_OVERRIDABLE di %C"
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate NON_OVERRIDABLE at %C"
 msgid "Duplicate DEFERRED at %C"
 msgstr "Duplikasi NON_OVERRIDABLE di %C"
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Diduga penspesifikasi akses di %C"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Diduga atribut binding di %C"
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "%<)%> expected at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in NAME= specifier for binding label at %C"
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Sintaks error dalam penspesifikasi NAMA= untuk binding label di %C"
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE(interface) at %C is not yet implemented"
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDUR(antar-muka) di %C belum diimplementasikan"
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Diduga nama binding di %C"
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "PROCEDURE list at %C"
 msgstr "Sampah setelah deklarasi PROCEDURE di %C"
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, fuzzy, gcc-internal-format
 #| msgid "'::' needed in PROCEDURE binding with explicit target at %C"
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "'::' diperlukan dalam binding PROCEDUR dengan target eksplisit di %C"
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Diduga binding target setelah '=>' di %C"
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Telah ada sebuah prosedur dengan nama binding '%s' untuk tipe turunan '%s' di %C"
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC di %C harus berada didalam sebuah tipe turunan CONTAINS"
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Diduga '::' di %C"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected generic name at %C"
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Diduga nama generik di %C"
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Invalid form of PROGRAM statement at %C"
+msgid "Malformed GENERIC statement at %C"
+msgstr "Form tidak valid dari pernyataan APLIKASI di %C"
+
+#: fortran/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a non-generic procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Telah ada sebuah prosedur bukan generik dengan nama binding '%s' untuk tipe turunan '%s' di %C"
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, fuzzy, gcc-internal-format
 #| msgid "Binding at %C must have the same access as already defined binding '%s'"
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Binding di %C harus memiliki akses sama seperti telah didefinisikan binding '%s'"
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Diduga nama binding spesifik di %C"
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' already defined as specific binding for the generic '%s' at %C"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "'%s' telah didefinisikan sebagai binding spesifik untuk generik '%s' di %C"
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Sampah setelah binding GENERIC di %C"
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "deklarasi FINAL di %C harus berada didalam sebuah tipe turunan daerah CONTAINS"
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Deklarasi tipe turunan dengan FINAL di %C harus berada dalam spesifikasi dari sebuah MODULE"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Kosong FINAL di %C"
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Diduga nama prosedur modul di %C"
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Diduga \",\" di %C"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "Nama prosedur tidak dikenal \"%s\" di %C"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is already defined as FINAL procedure!"
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "'%s' di %C telah didefinisikan sebagai prosedur FINAL!"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected characters in PARAMETER statement at %C"
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Karakter tidak terduga dalam pernyataan PARAMETER di %C"
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VALUE statement at %C"
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
@@ -49203,376 +49252,376 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "Bentuk berbeda untuk %s di %L dalam dimensi %d (%d dan %d)"
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a VALUE"
 msgid "%qs at %L is not a VALUE"
 msgstr "'%s' di %L bukan sebuah NILAI"
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Tingkat tidak kompatibel %d dan %d dalam penempatan di %L"
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "Tipe variabel adalah TIDAK DIKETAHUI dalam penempatan di %L"
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "NULL muncul di sisi kanan dalam penempatan di %L"
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "POINTER valued function appears on right-hand side of assignment at %L"
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "fungsi dinilai POINTER muncul di sisi kanan dari penempatan di %L"
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: BOZ literal at %L used to initialize non-integer variable '%s'"
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "Ekstensi: BOZ literal di %L digunakan untuk menginisialisasi variabel bukan-integer '%s'"
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "Ekstensi: BOZ literal di %L diluar sebuah pernyataan DATA dan diluar INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, fuzzy, gcc-internal-format
 #| msgid "BOZ literal at %L is bitwise transferred non-integer symbol '%s'"
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "BOZ literal di %L adalah bitwise dapat ditransfer bukan-integer simbol '%s'"
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetik underflow dari bit-wise dipindahkan BOZ di %L. Pemeriksaan ini dapat dinon-aktifkan dengan pilihan -fno-range-check"
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetik overflow dari bit-wise dipindahkan BOZ di %L. Pemeriksaan ini dapat dinonaktifkan dengan pilihan -fno-range-check"
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetik NaN dari bit-wise dipindahkan BOZ di %L. Pemeriksaan ini dapat dinon-aktifkan dengan pilihan -fno-range-check"
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "Konversi dari %s ke %s di %L"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: Conversion from %s to %s at %L"
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "Ekstensi: Konversi dari %s ke %s di %L"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Conversion from %qs to %qs at %L"
 msgstr "Konversi dari %s ke %s di %L"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Tipe tidak kompatibel dalam pernyataan DATA di %L; dicoba mengubah %s ke %s"
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Penempatan target penunjuk bukan sebuah PENUNJUK di %L"
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "'%s' dalam penempatan penunjuk di %L tidak dapat berupa sebuah nilai-kiri karena iniadalah sebuah prosedur"
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "Expected bounds specification for '%s' at %L"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Diduga spesifikasi terikat untuk '%s' di %L"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Bounds specification for '%s' in pointer assignment at %L"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Fortran 2003: Spesifikasi terikat untuk '%s' dalam penempatan penunjuk di %L"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack size must not be greater than 64k"
 msgid "Stride must not be present at %L"
 msgstr "ukuran stack harus lebih besar  dari 64k"
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Objek eksternal '%s' di %L tidak boleh memiliki sebuah penginisialisasi"
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "duplikasi deklarasi antar-muka untuk class %qs"
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Tipe berbeda dalam penempatan penunjuk di %L; mencoba penempatan dari %s ke %s"
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Jenis parameter berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Tingkat berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Penempatan target penunjuk bukan sebuah PENUNJUK di %L"
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Pemilihan ekspresi dalam pernyataan GOTO yang terhitung di %L harus berupa sebuah ekspresi integer skalar"
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Target penempatan penunjun baik bukan TARGET ataupun PENUNJUN di %L"
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Target buruk dalam penempatan penunjuk dalam prosedur PURE di %L"
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Penempatan penunjuk dengan subscrip vektori di rhs di %L"
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Target penempatan penunjuk memiliki atribut PROTECTED di %L"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data target at %L shall not have a coindex"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Noninteger exponent in an initialization expression at %L"
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2003: eksponen bukan integer dalam sebuah ekspresi inisialisasi di %L"
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, fuzzy, gcc-internal-format
 #| msgid "Argument to '%s' at %L is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "Argumen ke '%s' di %L bukan sebuah variabel"
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Variabel '%s' tidak dapat muncul dalam ekspresi di %L"
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variabel %s tidak dapat ditempatkan dalam prosedur PURE di %C"
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "tidak dapat membuka berkas masukan: %s"
@@ -49595,31 +49644,31 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Nilai kembali dari fungsi '%s' di %L tidak diset"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "illegal OP in optimize_comparison"
 msgstr "operan tidak valid dalam perbandingan gimple"
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
@@ -49679,663 +49728,669 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr "Diduga 'AKHIR ANTAR-MUKA PENEMPATAN (=)' di %C"
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (%s)' at %C"
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr "diduga 'AKHIR ANTAR-MUKA OPERATOR (%s)' di %C"
+
+#: fortran/interface.c:353
+#, fuzzy, gcc-internal-format
+#| msgid "Expecting 'END INTERFACE OPERATOR (%s)' at %C"
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr "diduga 'AKHIR ANTAR-MUKA OPERATOR (%s)' di %C"
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr "Diduga 'AKHIR ANTAR-MUKA OPERATOR (.%s.)' di %C"
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE %s' at %C"
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr "Diduga 'AKHIR ANTAR-MUKA %s' di %C"
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr "Kembali alternatif tidak dapat muncul dalam antar-muka operator di %L"
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr "Penempatan operator antar-muka di %L harus memiliki dua argumen"
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr "Operator antar-muka di %L memiliki jumlah argumen yang salah"
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr "Penempatan antar-muka operator di %L harus sebuah SUBROUTINE"
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr "Penempatan operator antar-muka di %L tidak boleh meredefinisi penempatan sebuah tipe INTRINSIK"
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr "Intrinsik operator antar-muka di %L harus sebuah FUNGSI"
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr "Argumen pertama dari penempatan yang didefinisikan di %L harus berupa INTENT(IN) atau INTENT(INOUT)"
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari penempatan didefinisikan di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen pertama dari antar-muka operator di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari antar-muka operator di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr "Antar-muka operator di %L konflik dengan antar-muka intrinsik"
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr "Prosedur '%s' dalam %s di %L tidak memiliki antar-muka eksplisit"
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr "Prosedur '%s' dalam %s di %L bukan sebuah fungsi atau subrutin"
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Internal procedure %qs in %s at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, fuzzy, gcc-internal-format
 #| msgid "Ambiguous interfaces '%s' and '%s' in %s at %L"
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr "Interface ambigu '%s' dan '%s' dalam %s di %L"
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, fuzzy, gcc-internal-format
 #| msgid "Although not referenced, '%s' at %L has ambiguous interfaces"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "Walaupun tidak direferensikan, '%s' di %L memiliki antar-muka ambigu"
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a module procedure"
 msgid "%qs at %L is not a module procedure"
 msgstr "'%s' di %L bukan sebuah prosedur module"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Invalid procedure argument at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, fuzzy, gcc-internal-format
 #| msgid "Type mismatch in argument '%s' at %L; passed %s to %s"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Tipe tidak cocok dalam argumen '%s' di %L; dilewatkan %s ke %s"
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Bentuk-diasumsikan aktual argumen di %L adalah tidak kompatibel dengan bentuk tidak diasumsikan dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Argumen dari %s di %L harus berupa panjang satu"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "'%s' dan '%s' argumen dari '%s' intrinsik di %L harus memiliki tipe yang sama"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "Argumen dari %s di %L harus berupa panjang satu"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped array passed to dummy argument '%s' at %L"
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Elemen dari array bentuk-diasumsikan dilewatkan ke argumen dummy '%s' di %L"
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped array passed to dummy argument '%s' at %L"
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr "Elemen dari array bentuk-diasumsikan dilewatkan ke argumen dummy '%s' di %L"
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Skalar KARAKTER aktual argumen dengan array dummy argumen '%s' di %L"
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Skalar KARAKTER aktual argumen dengan array dummy argumen '%s' di %L"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Kata kunci argumen '%s' di %L tidak dalam prosedur"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Argumen kata-kunci '%s' di %L telah berasosiasi dengan argumen aktual lain"
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Lebih aktual daripada formal argumen dalam pemanggilan prosedur di %L"
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Hilang alternatif spesifikasi kembali dalam pemanggilan subroutine di %L"
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr "Tidak terduga alternaatif spesifikasi kembali dalam pemanggilan subroutine di %L"
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Panjang karakter tidak cocok (%ld/%ld) diantara argumen aktual dan penunjuk atau dapat dialokasikan argumen dummy '%s' di %L"
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Panjang karakter tidak cocok (%ld/%ld) diantara argumen aktual dan diasumsikan-bentuk argumen dummy '%s' di %L"
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of actual argument shorter than of dummy argument '%s' (%lu/%lu) at %L"
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Panjang karakter dari argumen aktual lebih pendek dari argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Argumen aktual berisi terlalu sedikit elemen untuk argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure pointer for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Diduga sebuah prosedur penunjuk untuk argumen '%s' di %L"
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Diduga sebuah prosedur untuk argumen '%s' di %L"
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Aktual argumen untuk '%s' tidak dapat diasumsikan array berukuran di %L"
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Aktual argumen untuk '%s' harus DAPAT DIALOKASIKAN di %L"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT) or VOLATILE attribute of the dummy argument '%s'"
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Daerah array aktual argumen dengan vektor subscript di %L adalah tidak kompatibel dengan INTENT(OUT), INTENT(INOUT) atau VOLATILE atribut dari argumen dummy'%s'"
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Bentuk-diasumsikan aktual argumen di %L adalah tidak kompatibel dengan bentuk tidak diasumsikan dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Daerah array aktual argumen di %L adalah tidak kompatibel dengan tidak-diasumsikanbentuk dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument '%s' due to VOLATILE attribute"
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Penunjuk array aktual argumen di %L membutuhkan sebuah bentuk diasumsikan ataupenunjuk array dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Hilang aktual argumen untuk argumen '%s' di %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Aktual argumen sama berasosiasi dengan INTENT(%s) argumen '%s' dan INTENT(%s) argumen '%s' di %L"
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Prosedur argumen di %L adalah lokal ke sebuah prosedur PURE dan memiliki atribut PENUNJUK"
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Prosedur argumen di %L adalah lokal ke sebuah prosedur PURE dan adalah dilewatkan ke sebuah argumen INTENT(%s)"
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Prosedur argumen di %L adalah lokal ke sebuah prosedur PURE dan adalah dilewatkan ke sebuah argumen INTENT(%s)"
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Prosedur '%s' dalam %s di %L tidak memiliki antar-muka eksplisit"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Prosedur '%s' dipanggil dengan sebuah antar-muka implisit di %L"
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic character length function '%s' at %L must have an explicit interface"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Otomatis panjang fungsi karakter '%s' di %L harus memiliki sebuah antar-muka eksplisit"
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Simbol '%s' di %L telah memiliki sebuah antar-muka eksplisit"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "MOLD argument to NULL required at %L"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Prosedur '%s' dipanggil dengan sebuah antar-muka implisit di %L"
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qs"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D teraliasi ke simbol tidak terdefinisi %qs"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Entiti '%s' di %C telah ada dalam sebuah antar-muka"
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC '%s' at %L"
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr "Tidak dapat overwrite GENERIC '%s' di %L"
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "'%s' di %L overrides sebuah prosedur binding dideklarasikan NON_OVERRIDABLE"
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PURE procedure and must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "'%s' di %L overrides sebuah prosedur PURE dan juga harus berupa PURE"
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "'%s' di %L overrides sebuah prosedur ELEMENTAL dan juga harus berupa ELEMENTAL"
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "'%s' di %L overrides sebuah prosedur bukan ELEMENTAL dan tidak harus berupa ELEMENTAL juga"
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "'%s' di %L overrides sebuah SUBROUTINE dan juga harus berupa sebuah SUBROUTINE"
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a FUNCTION and must also be a FUNCTION"
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "'%s' di %L overrides sebuah FUNGSI dan juga harus berupa sebuah FUNGSI"
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "'%s' di %L overrides sebuah prosedur PUBLIK dah tidak harus berupa PRIVATE"
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' of '%s' at %L should be named '%s' as to match the corresponding argument of the overridden procedure"
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Argumen dummy '%s' dari '%s' di %L seharusnya bernama '%s' untuk mencocokan dengan argumen yang berhubungan dengan prosedur overridden"
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have the same number of formal arguments as the overridden procedure"
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "'%s' di %L harus memiliki jumlah sama dari argumen formal seperti prosedur overridden"
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a NOPASS binding and must also be NOPASS"
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "'%s' di %L overrides sebuah binding NOPASS dan juga harus berupa NOPASS"
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a binding with PASS and must also be PASS"
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "'%s' di %L overrides sebuah pengikatan dengan PASS dan juga harus berupa PASS"
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
@@ -50799,13 +50854,13 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: ASYNCHRONOUS= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: BLANK= at %C not allowed in Fortran 95"
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: BLANK= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DECIMAL= at %C not allowed in Fortran 95"
 msgid "DECIMAL= at %C not allowed in Fortran 95"
@@ -50817,7 +50872,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: ENCODING= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PAD= at %C not allowed in Fortran 95"
 msgid "ROUND= at %C not allowed in Fortran 95"
@@ -50846,455 +50901,455 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "pernyataan %s tidak diperbolehkan dalam prosedur PURE di %C"
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT tag in %s statement at %L must be a variable"
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "STAT tag dalam pernyataan %s di %L harus berupa sebuah variabel"
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: FLUSH statement at %C"
 msgid "FLUSH statement at %C"
 msgstr "Fortran 2003: pernyataan FLUSH di %C"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "Duplikasi SATUAN spesifikasi di %C"
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Duplikasi format spesifikasi di %C"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "Simbol '%s' dalam daftar nama '%s' adalah INTENT(IN) di %C"
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Duplikasi spesifikasi NML di %C"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C must be a NAMELIST group name"
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "Simbol '%s' di %C harus berupa sebuah nama grup DAFTAR-NAMA"
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "tag AKHIR di %C tidak diperbolehkan dalam pernyataan keluaran"
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-I- specified twice"
 msgid "UNIT not specified at %L"
 msgstr "-I- dispesifikasikan dua kali"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "spesifikasi SATUAN di %L harus berupa sebuah ekspresi INTEGER atau sebuah KARAKTER variabel"
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "Form tidak valid dari pernyataan WRITE di %L, dibutuhkan UNIT"
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "Satuan internal dengan vektor subscrip di %L"
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "Eksternal IO UNIT tidak dapat berupa sebuah array di %L"
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Comma before i/o item list at %L"
 msgid "Comma before i/o item list at %L"
 msgstr "Ekstensi: Koma sebalum i/o daftar item di %L"
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR tag label %d di %L tidak didefinisikan"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END tag label %d di %L tidak didefinisikan"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR tag label %d di %L tidak didefinisikan"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT label %d di %L tidak didefinisikan"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Sintaks error dalam iterasi I/O di %C"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Diduga variabel dalam pernyataan BACA di %C"
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Diduga ekspresi dalam pernyataan %s di %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Sintaks error dalam pernyataan %s di %C"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Internal file at %L with namelist"
 msgid "Internal file at %L with namelist"
 msgstr "Fortran 2003: Berkas internal di %L dengan daftar-nama"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "ASYNCHRONOUS= penspesifikasi di %L harus berupa ekspresi inisialisasi"
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PAD= at %C not allowed in Fortran 95"
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: PAD= di %C belum terimplementasi dalam Fortran 95"
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DELIM= at %C not allowed in Fortran 95"
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: DELIM= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "daftar-nama PRINT di %C adalah sebuah ekstensi"
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Diduga koma dalam daftar I/O di %C"
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "pernyataan PRINT di %C tidak diperbolehkan dalam prosedur PURE"
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "pernyataan INQUIRE tidak diperbolehkan dalam prosedur di %C"
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENTH tag tidak valid dalam pernyataan INQUIRE di %C"
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "pernyataan INQUIRE di %L tidak dapat berisi baik BERKAS dan penspesifikasi SATUAN"
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "pernyataan INQUIRE di %L membutuhkan baik BERKAS atau penspesifikasi SATUAN"
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L cannot be %s"
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr "Argumen dari pernyataan SELECT di %L tidak dapat berupa %s"
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "pernyataan INQUIRE di %L membutuhkan sebuah PENDING= penspesifikasi dengan ID= penspesifikasi"
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: WAIT at %C not allowed in Fortran 95"
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: WAIT di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "pernyataan WAIT tidak diperbolehkan dalam prosedur PURE di %C"
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_op2string(): Bad code"
 msgstr "gfc_trans_code(): Pernyataan kode buruk"
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 #| msgid "Missing ')' in statement at or before %L"
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "Hilang ')' dalam pernyataan di atau sebelum %L"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 #| msgid "Missing '(' in statement at or before %L"
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "Hilang '(' dalam pernyataan di atau sebelum %L"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr "Integer terlalu besar di %C"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "Terlalu banyak digit dalam pernyataan label di %C"
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr "Pernyataan label di %C adalah nol"
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 #| msgid "Label name '%s' at %C is ambiguous"
 msgid "Label name %qs at %C is ambiguous"
 msgstr "Nama label '%s' di %C adalah ambigu"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Duplicate construct label %qs at %C"
 msgstr "Duplikasi konstruksi label '%s' di %C"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr "Karakter tidak valid dalam nama di %C"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr "Nama di %C adalah terlalu panjang"
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid character '$' at %C. Use -fdollar-ok to allow it as an extension"
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr "Karakter '$' tidak valid di %C. Gunakan -fdollar-ok untuk mengijinkannya sebagai sebuah ekstensi"
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a sub-component"
 msgid "Loop variable at %C cannot be a coarray"
 msgstr "Variabel loop di %C tidak dapat berupa sebuah sub-komponen"
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr "Variabel loop di %C tidak dapat berupa sebuah sub-komponen"
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr "Diduga sebuah nilai step dalam iterator di %C"
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr "Sintaks error dalam iterator di %C"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_match(): Bad match code %c"
 msgstr "gfc_trans_code(): Pernyataan kode buruk"
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr "Form tidak valid dari pernyataan APLIKASI di %C"
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolescent: arithmetic IF statement at %C"
 msgid "Arithmetic IF statement at %C"
 msgstr "Obsolescent: aritmetik pernyataan IF di %C"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr "Sintaks error dalam pernyataan IF di %C"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr "Label blok tidak sesuai untuk pernyataan aritmetik IF di %C"
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr "Label blok tidak sesuai untuk pernyataan IF di %C"
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr "Tidak dapat assign ke sebuah konstanta bernama di %C"
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr "Pernyataan tidak terklasifikasi dalam clause IF di %C"
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr "Sintaks error dalam IF-clause di %C"
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match IF label '%s'"
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "Label '%s' di %C tidak cocok dengan label IF '%s'"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE IF di %C"
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr "pernyataan PRINT di %C tidak diperbolehkan dalam prosedur PURE"
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "CRITICAL statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr ""
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected comma in I/O list at %C"
 msgid "Expected association list at %C"
 msgstr "Diduga koma dalam daftar I/O di %C"
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "Expected association at %C"
 msgstr "Diduga array subscript di %C"
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate name %qs in association at %C"
 msgstr "Duplikasi %s spesifikasi di %C"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr "Duplikasi pernyataan PRIVATE di %C"
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "Bukan ekstensible tipe turunan '%s' di %L tidak boleh berupa ABSTRACT"
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Invalid type-spec at %C"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "Sintaks error dalam iterasi FORALL di %C"
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "Nama '%s' dalam pernyataan %s di %C bukan sebuah nama loop"
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "Nama '%s' dalam pernyataan %s di %C bukan sebuah nama loop"
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaves CRITICAL construct"
@@ -51301,383 +51356,383 @@
 msgstr "pernyataan %s di %C meninggalkan OpenMP blok terstruktur"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "pernyataan %s di %C meninggalkan OpenMP blok terstruktur"
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "%s statement at %C is not within a construct"
 msgstr "pernyataan %s di %C tidak dalam jangkauan sebuah loop"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "%s statement at %C is not within construct %qs"
 msgstr "pernyataan %s di %C tidak dlam jangkauan loop '%s'"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "pernyataan %s di %C tidak dlam jangkauan loop '%s'"
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "pernyataan %s di %C tidak dlam jangkauan loop '%s'"
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "pernyataan %s di %C meninggalkan OpenMP blok terstruktur"
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "pernyataan EXIT di %C mengakhiri loop !$OMP DO"
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "pernyataan EXIT di %C mengakhiri loop !$OMP DO"
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "pernyataan EXIT di %C mengakhiri loop !$OMP DO"
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "pernyataan EXIT di %C mengakhiri loop !$OMP DO"
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement at %C in PURE procedure"
 msgstr "pernyataan %s tidak diperbolehkan dalam prosedur PURE di %C"
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "spesifikasi SATUAN di %L harus berupa sebuah ekspresi INTEGER atau sebuah KARAKTER variabel"
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be scalar"
 msgid "STOP code at %L must be scalar"
 msgstr "Indeks array di %L harus berupa skalar"
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Penunjuk Cray di %C harus berupa sebuah integer"
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "PAUSE statement at %C"
 msgstr "Diduga pernyataan CASE di %C"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ERROR STOP statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "pernyataan PRINT di %C tidak diperbolehkan dalam prosedur PURE"
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "LOCK statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "UNLOCK statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "pernyataan PRINT di %C tidak diperbolehkan dalam prosedur PURE"
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "SYNC statement at %C"
 msgstr "Duplikasi pernyataan SEQUENCE di %C"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: ASSIGN statement at %C"
 msgid "ASSIGN statement at %C"
 msgstr "Featur terhapus: pernyataan ASSIGN di %C"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: Assigned GOTO statement at %C"
 msgid "Assigned GOTO statement at %C"
 msgstr "Featur terhapus: Terassign pernyataan GOTO di %C"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "Daftar pernyataan label dalam GOTO di %C tidak dapat kosong"
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad allocate-object in ALLOCATE statement at %C for a PURE procedure"
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "Alokasi-objek buruk dalam pernyataan ALOKASI di %C untuk sebuah prosedur PURE"
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "penunjuk ke anggota tipe %qT tidak kompatibel dengan tipe objek %qT"
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "Spesifikasi buruk untuk diasumsikan ukuran array di %C"
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "BLOK DATA kosong di %C konflik dengan BLOK DATA sebelumnya di %L"
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal deallocate-expression in DEALLOCATE at %C for a PURE procedure"
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "ekspresi deallokasi tidak legal dalam DEALLOCATE di %C untuk sebuah prosedur PURE"
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "Pernyataan alternatif RETURN di %C hanya diperbolehkan dalam sebuah SUBROUTINE"
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: RETURN statement in main program at %C"
 msgid "RETURN statement in main program at %C"
 msgstr "Ekstensi: pernyataan RETURN dalam aplikasi utama di %C"
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Diduga referensi komponen di %C"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "Sampah setelah CALL di %C"
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected type-bound procedure reference at %C"
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Diduga referensi type-bound prosedur di %C"
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "Sintaks error dalam nama blok umum di %C"
@@ -51685,164 +51740,164 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr "Variabel '%s' di %L dalam blok umum '%s' di %C harus terdeklarasi dengan sebuah C interoperable kind karena blok umum '%s' adalah bind(c)"
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %C can not be bind(c) since it is not global"
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr "Variabel '%s' dalam blok umum '%s' di %C tidak dapat bind(c) karena ini bukan global"
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Simbol '%s' di %C telah dalam sebuah blok COMMON"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, fuzzy, gcc-internal-format
 #| msgid "Initialized symbol '%s' at %C can only be COMMON in BLOCK DATA"
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "Simbol terinisialisasi '%s' di %C hanya dapat berupa COMMON dalam BLOK DATA"
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "Array specification for symbol '%s' in COMMON at %C must be explicit"
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "Spesifikasi array untuk simbol '%s' dalam COMMON di %C harus eksplisit"
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in COMMON at %C cannot be a POINTER array"
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "Simbol '%s' dalam COMMON di %C tidak dapat berupa sebuah array PENUNJUK"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s', in COMMON block '%s' at %C is being indirectly equivalenced to another COMMON block '%s'"
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "Simbol '%s', dalam blok COMMON '%s' di %C sedang secara tidak langsung sama dengan ke COMMON blok '%s' lain"
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already has a basic type of %s"
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "Daftar-nama nama grup '%s' di %C telah memiliki sebuah tipe dasar dari %s"
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already is USE associated and cannot be respecified."
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "Daftar-nama nama grup '%s' di %C telah USE diasosiasikan dan tidak dapat berupa respecified."
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Ukuran array yang diasumsikan '%s' dalam daftar nama '%s' di %C tidak diperbolehkan"
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "Tipe komponen turunan %C bukan sebuah anggota EQUIVALENCE yang diijinkan"
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "Referensi array dalam EQUIVALENCE di %C tidak dapat berupa daerah array"
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "EQUIVALENCE di %C membutuhkan dua atau lebih objek"
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Mencoba secara tidak langsung overlap blok COMMON %s dan %s dengan EQUIVALENCE di %C"
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected comma in I/O list at %C"
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Diduga koma dalam daftar I/O di %C"
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "Pernyataan fungsi di %L adalah rekursif"
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement function at %L is recursive"
 msgid "Statement function at %C"
 msgstr "Pernyataan fungsi di %L adalah rekursif"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Diduga ekspresi inisialisasi dalam CASE di %C"
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "Expected the name of the SELECT CASE construct at %C"
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Diduga nama dari SELECT CASE konstruk di %C"
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROTECTED statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Sintaks error dalam pernyataan TERPROTEKSI di %C"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Diduga pernyataan CASE di %C"
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CASE specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "pernyataan ELSEWHERE di %C tidak terenklose dalam blok WHERE"
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -51999,189 +52054,189 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Daftar-nama %s tidak dapat diubah namanya dengan assosiasi USE ke %s"
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul '%s'"
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, fuzzy, gcc-internal-format
 #| msgid "User operator '%s' referenced at %L not found in module '%s'"
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Operator pengguna '%s' direferensikan di %L tidak ditemukan dalam modul '%s'"
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Operator intrinsik '%s' direferensikan di %L tidak ditemukan dalam modul '%s'"
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Tidak dapat membuka berkas modul '%s' untuk menulis di %C: %s"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Error menulis berkas modul '%s' untuk menulis: %s"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file '%s': %s"
 msgid "Can't delete module file %qs: %s"
 msgstr "tidak dapat menghapus berkas modul '%s': %s"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "Can't rename module file '%s' to '%s': %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "tidak dapat mengubah nama berkas modul '%s' ke '%s': %s"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete temporary module file '%s': %s"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Tidak dapat menghapus berkas modul sementara '%s': %s"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs already declared"
 msgstr "Simbol '%s' telah terdeklarasi"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul '%s'"
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul intrinsik ISO_C_BINDING"
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, fuzzy, gcc-internal-format
 #| msgid "Use of intrinsic module '%s' at %C conflicts with non-intrinsic module name used previously"
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Penggunaan daro modul intrinsik '%s' di %C konflik dengan tidak-intrinsik nama modul digunakan sebelumnya"
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %s"
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Penggunaan dari NUMERIC_STORAGE_SIZE konstanta bernama dari modul intrinsik ISO_FORTRAN_ENV di %L adalah tidak kompatibel dengan pilihan %s"
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Penggunaan dari NUMERIC_STORAGE_SIZE konstanta bernama dari modul intrinsik ISO_FORTRAN_ENV di %C adalah tidak kompatibel dengan pilihan %s"
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul intrinsik ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "pernyataan %s di %C tidak dalam jangkauan sebuah loop"
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_FORTRAN_ENV intrinsic module at %C"
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003: ISO_FORTRAN_ENV modul intrinsik di %C"
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_C_BINDING module at %C"
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003: ISO_C_BINDING modul di %C"
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, fuzzy, gcc-internal-format
 #| msgid "Can't find an intrinsic module named '%s' at %C"
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "Tidak dapat menemukan modul intrinsik bernama '%s' di %C"
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Tidak dapat membuka berkas modul '%s' untuk pembacaan di %C: %s"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, fuzzy, gcc-internal-format
 #| msgid "Use of non-intrinsic module '%s' at %C conflicts with intrinsic module name used previously"
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Penggunaan dari modul tidak intrinsik '%s' di %C konflik dengan nama modul intrinsik yang digunakan sebelumnya"
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GFORTRAN module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Berkas '%s' dibuka di %C bukan sebuah berkas modul GFORTRAN"
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr "Tidak dapat MENGGUNAKAN module yang sama yang sedang kita buat!"
@@ -52517,7 +52572,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF clause di %L membutuhkan sebuah ekspresi skalara LOGIKAL"
@@ -53296,395 +53351,389 @@
 msgid "Unexpected %s statement at %C"
 msgstr "Tidak terduga pernyataan %s di %C"
 
-#: fortran/parse.c:2428
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected %s statement in MODULE at %C"
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr "Tidak terduga pernyataan %s dalam MODUL di %C"
-
-#: fortran/parse.c:2439
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "pernyataan %s di %C tidak dapat mengikuti pernyataan %s di %L"
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "Tidak terduga akhir dari berkas dalam '%s'"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with SEQUENCE must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "Tipe-turunan '%s' dengan SEQUENCE harus tidak memiliki sebuah bagian CONTAINS di %C"
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with BIND(C) must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "Tipe-turunan '%s' dengan BIND(C) harus tidak memiliki sebuah bagian CONTAINS di %C"
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "Komponen dalam TYPE di %C harus mengawali CONTAINS"
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  Type-bound procedure at %C"
 msgid "Type-bound procedure at %C"
 msgstr "Fortran 2003:  Prosedur Tipe-bound di %C"
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after GENERIC binding at %C"
 msgid "GENERIC binding at %C"
 msgstr "Sampah setelah binding GENERIC di %C"
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  FINAL procedure declaration at %C"
 msgid "FINAL procedure declaration at %C"
 msgstr "Fortran 2003:  Deklarasi prosedur FINAL di %C"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: Derived type definition at %C with empty CONTAINS section"
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Fortran 2008: Definisi tipe turunan di %C dengan daerah CONTAINS kosong"
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "pernyataan PRIVATE dalam TYPE di %C harus berada didalam sebuah MODUL"
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "pernyataan PRIVATE di %C harus mengawali prosedur bindings"
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Duplikasi pernyataan PRIVATE di %C"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "pernyataan SEQUENCE di %C harus mengawali CONTAINS"
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "Telah berada didalam sebuah blok CONTAINS di %C"
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "deklarasi FINAL di %C harus berada didalam CONTAINS"
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Derived type definition at %C without components"
 msgid "Derived type definition at %C without components"
 msgstr "Fortran 2003: Definisi tipe turunan di %C tanpa komponen"
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "pernyataan PRIVATE di %C harus mengawali struktur komponen"
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "pernyataan SEQUENCE di %C harus mengawali struktur komponen"
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "atribut SEQUENCE di %C telah dispesifikasikan dalam pernyataan TIPE"
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Duplikasi pernyataan SEQUENCE di %C"
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  CONTAINS block in derived type definition at %C"
 msgid "CONTAINS block in derived type definition at %C"
 msgstr "Fortran 2003: blok CONTAINS dalam definisi turunan di %C"
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocatable component of structure at %C must have a deferred shape"
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "Komponen dapat dialokasikan dari struktur di %C harus memiliki sebuah bentuk deffered"
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "deklarasi ENUM di %C tidak memiliki ENUMERASI"
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Tidak terduga pernyataan %s dalam ANTAR-MUKA blok di %C"
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "Nama '%s' dari ANTAR-MUKA ABSTRAK di %C tidak dapat sama dengan sebuah tipe intrinsik"
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Tidak terduga pernyataan %s di %C dalam tubuh ANTAR-MUKA"
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "prosedur ANTAR-MUKA '%s' di %L memiliki nama sama dengan prosedur yang melingkupinya"
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "pernyataan %s tidak diperbolehkan dalam prosedur PURE di %C"
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "pernyataan %s tidak diperbolehkan dalam prosedur PURE di %C"
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "pernyataan %s harus muncul dalam sebuah MODUL"
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "pernyataan %s di %C mengikuti spesifikasi aksesbiliti lain"
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "Bad kind expression for function '%s' at %L"
 msgid "Bad kind expression for function %qs at %L"
 msgstr "Jenis ekspresi buruk untuk fungsi '%s' di %L"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, fuzzy, gcc-internal-format
 #| msgid "The type for function '%s' at %L is not accessible"
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Tipe dari fungsi '%s' di %L tidak dapat diakses"
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "pernyataan ELSEWHERE di %C mengikuti tidak bertopen ELSEWHERE"
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Tidak terduga pernyataan %s dalam blok WHERE di %C"
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Tidak terduga pernyataan %s dalam blok FORALL di %C"
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "pernyataan ELSE IF di %C tidak dapat mengikuti pernyataan ELSE di %L"
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Duplikasi pernyataan ELSE di %L dan %C"
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "Diduga sebuah pernyataan CASE atau END SELECT mengikuti SELECT CASE di %C"
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "Diduga sebuah pernyataan CASE atau END SELECT mengikuti SELECT CASE di %C"
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "Akhir dari pernyataan bukan blok DO di %C adalah didalam blok lain"
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "Akhir dari pernyataan bukan blok DO di %C adalah interwoven dengan DO loop lainnya"
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "Pernyataan label dalam ENDDO di %C tidak cocok dengan label DO"
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "BLOCK construct at %C"
 msgstr "Baris terpotong di %C"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "Pernyataan label dalam ENDDO di %C tidak cocok dengan label DO"
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "named block DO at %L requires matching ENDDO name"
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "blok bernama DO di %L membutuhkan nama ENDDO yang sama"
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Already inside a CONTAINS block at %C"
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr "Telah berada didalam sebuah blok CONTAINS di %C"
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s at %C"
 msgstr "Diduga pernyataan %s di %C"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "Nama setelah !$omp kritis dan !$omp akhir kritis tidak cocok di %C"
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "pernyataan %s di %C tidak dapat mengakhiri sebuah bukan blok DO loop"
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORMAT statement at %L does not have a statement label"
 msgid "DATA statement at %C after the first executable statement"
 msgstr "pernyataan FORMAT di %L tidak memiliki sebuah label pernyataan"
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %C is already ambiguous"
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "Prosedur berisi '%s' di %C telah ambigu"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Tidak terduga pernyataan %s dalam daerah CONTAINS di %C"
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr "Fortran 2008: pernyataan CONTAINS tanpa pernyataan FUNCTION atau SUBROUTINE di %C"
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "pernyataan CONTAINS di %C telah berada dalam satuan aplikasi terisi"
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr "Nama global '%s' di %L telah digunakan sebuah sebuah %s di %L"
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr "Nama global '%s' di %L telah digunakan sebuah sebuah %s di %L"
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "BLOK DATA kosong di %C konflik dengan BLOK DATA sebelumnya di %L"
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Tidak terduga pernyataan %s dalam BLOK DATA di %C"
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Tidak terduga pernyataan %s dalam MODUL di %C"
@@ -53692,7 +53741,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "Dua APLIKASI utama di %L dan %C"
@@ -54475,7 +54524,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Bukan prosedur REKURSIF '%s' di %L mungkin memanggil dirinya sendiri secara rekursif. Deklarasikan itu secara RECURSIVE atau gunakan -frecursive"
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Label %d direferensikan di %L tidak pernah terdefinisi"
@@ -54536,96 +54585,96 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Melewati prosedur internal di %L dengan lokasi tidak diperbolehkan"
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL bukan INTRINSIK prosedur '%s' tidak diperbolehkan sebagai sebuah argumen aktual di %L"
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "'%s' di %L adalah sebuah array dan OPSIONAL; JIKA INI HILANG, ini tidak dapat berupa argumen aktual dari sebual prosedur ELEMENTAL kecuali disana ada sebuah tidak pilihanonal argumen dengan tingkat sama (12.4.1.5)"
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument at %L for INTENT(%s) dummy '%s' of ELEMENTAL subroutine '%s' is a scalar, but another actual argument is an array"
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "Argumen aktual di %L untuk INTENT(%s) dummy '%s' dari subroutine ELEMENTAL '%s' adalah sebuah skalar, tetapi argumen aktual lain adalah sebuah array"
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function '%s' at %L not set"
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Nilai kembali dari fungsi '%s' di %L tidak diset"
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, fuzzy, gcc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Disana tidak ada fungsi spesifik untuk umum '%s' di %L"
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Fungsi umum '%s' di %L tidak konsisten dengan sebuah antar-muka spesifik intrinsik."
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Fungsi '%s' di %L adalah INTRINSIK tetapi tidak kompatibel dengan sebuah intrinsik"
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Tidak dapat meresolf fungsi spesifik '%s'di %L"
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, fuzzy, gcc-internal-format
 #| msgid "reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "referensi ke fungsi bukan-PURE '%s' di %L didalam sebuah FORALL %s"
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, fuzzy, gcc-internal-format
 #| msgid "reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "referensi ke fungsi bukan-PURE '%s' di %L didalam sebuah FORALL %s"
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot write to internal file unit '%s' at %C inside a PURE procedure"
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Tidak dapat menulis ke internal berkas satuan '%s' di %C didalam prosedur PURE"
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a function"
 msgid "%qs at %L is not a function"
 msgstr "'%s' di %L bukan sebuah fungsi"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "ABSTRACT INTERFACE '%s' must not be referenced at %L"
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
@@ -54632,303 +54681,303 @@
 msgstr "ANTAR-MUKA ABSTRAK '%s' tidak boleh direferensikan di %L"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Fungsi '%s' adalah dideklarasikan KARAKTER(*) dan tidak dapat digunakan di %L karena ini bukan sebuah argumen dummy"
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "User defined non-ELEMENTAL function '%s' at %L not allowed in WORKSHARE construct"
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Fungsi bukan-ELEMENTAL definisi pengguna '%s' di %L tidak diperbolehkan dalam WORKSHAREkonstruksi"
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as function '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "MASUKAN '%s' di %L tidak dapat dipanggil secara rekursif, karena fungsi '%s' tidak REKURSIF"
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Fungsi '%s' di %L tidak dapat dipanggil secara rekursif, karena ini bukan REKURSIF"
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Panggilan subroutine ke '%s' dalam blok FORALL di %L tidak PURE"
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Panggilan subroutine ke '%s' dalam blok FORALL di %L tidak PURE"
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Panggilan subroutine ke '%s' di %L bukan PURE"
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific subroutine for the generic '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Disana tidak ada subroutine spesifik untuk umum '%s' di %L"
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Subroutine umum '%s' di %L tidak konsisten dengan sebuah anta-muka subroutine intrinsik"
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Subroutine '%s' di %L adalah INTRINSIK tetapi tidak kompatibel dengan sebuah intrinsik"
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Tidak dapat meresolf subroutine spesifik '%s' di %L"
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr "'%s' di %L memiliki sebuah tipe, yang tidak konsisten dengan CALL di %L"
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as subroutine '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "MASUKAN '%s' di %L tidak dapat dipanggil secara rekursif, karena subroutine '%s' tidak REKURSIF"
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE '%s' di %L tidak dapat dipanggil secara rekursif, karena ini bukan REKURSIF"
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Bentuk untuk operan di %L dan %L tidak konformant"
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Tidak legal stride dari nol di %L"
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array bawah di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array bawah di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array atas di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array atas di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "subscrip hilang dalam referensi array"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Jangkauan paling kanan ats dari daerah ukuran array yang diasumsikan tidak dispesifikasikan di %L"
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Tingkat tidak cocok dalam referensi array di %L (%d/%d)"
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Tingkat tidak cocok dalam referensi array di %L (%d/%d)"
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "indeks dalam dimensi %d diluar dari jangkauan di %L"
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Indeks array di %L harus berupa skalar"
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Indeks array di %L harus berupa tipe INTEGER, ditemukan %s"
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Ekstensi: indeks array RIL di %L"
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Argumen dim di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Indeks array di %L adalah sebuah array dari tingkat %d"
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Indeks awal substring di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Indeks awal substring di %L harus berupa skalar"
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Indeks awal substring di %L lebih kecil dari satu"
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Indeks akhir substring di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Indeks akhir substring di %L harus berupa skalar"
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Indeks akhir substring di %L melebihi panjang string"
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "Indeks akhir substring di %L harus berupa skalar"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Referensi array buruk di %L"
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponen ke bagian kanan dari referensi dengan tingkat bukan-nol harus tidak memiliki atribut PENUNJUK di %L"
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponen ke bagian kanan dari referensi dengan tingkat bukan-nol harus tidak memiliki atribut DAPAT DIALOKASIKAN di %L"
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Dua atau lebih referensi bagian dengan tingkat bukan-nol tidak boleh dispesifikasikan di %L"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -54938,12 +54987,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -54953,66 +55002,66 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifikasi tipe"
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifikasi tipe"
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel '%s', digunakan dalam sebuah ekspresi spesifikasi, direferensikan di %L sebelum pernyataan MASUKAN dimana ini adalah sebuah parameter"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel '%s' digunakan di %L sebelum pernyataan MASUKAN dimana ini adalah sebuah parameter"
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
@@ -55019,201 +55068,201 @@
 msgstr "Argumen '%s' dari prosedur elemental di %L harus berupa skalar"
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Tidak ditemukan pengikatan spesifik yang cocok untuk panggilan ke GENERIC '%s' di %L"
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' di %L seharusnya berupa sebuah SUBROUTINE"
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' di %L seharusnya berupa sebuah FUNGSI"
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Diduga tipe ekspresi"
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s di %L harus berupa sebuah skalar"
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "%s at %L must be integer"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s di %L harus berupa INTEGER"
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL awal ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL akhir ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL stride ekspresi di %L harus berupa sebuah skalar %s"
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL stride ekspresi di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL indeks '%s' mungkin tidak muncul dalam spesifikasi triplet di %L"
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Ekspresi dalam pernyataan ALOKASI di %L harus berupa DAPAT DIALOKASIKAN atau sebuah PENUNJUK"
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' tidak boleh muncul dalam spesifikasi array di %L dalam pernyataan ALOKASI yang sama dimana ini sendiri dialokasikan"
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "spesifikasi SATUAN di %L harus berupa sebuah ekspresi INTEGER atau sebuah KARAKTER variabel"
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -55222,124 +55271,124 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE label di %L overlaps dengan CASE label di %L"
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %d"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa skalar"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Pemilihan ekspresi dalam pernyataan GOTO yang terhitung di %L harus berupa sebuah ekspresi integer skalar"
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argumen dari pernyataan SELECT di %L tidak dapat berupa %s"
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "KASUS BAKU di %L tidak dapat diikuti oleh sebuah KASUS BAKU kedua di %L"
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Jangkauan logikal dalam pernyataan CASE di %L tidak diperbolehkan"
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "nilai logikan konstan dalam pernyataan CASE diulang di %L"
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Spesifikasi jangkauan di %L tidak pernah cocok"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logikal SELECT CASE blok di %L memiliki lebih dari dua kasus"
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "Selector at %L must not be coindexed"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Tidak terduga pernyataan %s di %C"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
@@ -55346,81 +55395,81 @@
 msgstr "Konteks tidak valid untuk penunjuk NULL() di %%L"
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN"
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PRIVATE"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Elemen pemindahan data di %L tidak dapat berupa sebuah referensi lengkap ke sebuah array yang ukurannya diasumsikan"
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argumen dari ACOS di %L harus berada diantara -1 dan 1"
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Pernyataan di %L bukan sebuah pernyataan pencabangan target yang valid untuk sebuah pernyataan percabangan di %L"
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Cabang di %L bisa menyebabkan sebuah loop tak terhingga"
@@ -55427,12 +55476,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -55440,165 +55489,165 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "DIMANA mask di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "penempatan target WHERE di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "penempatan bukan-ELEMEN didefinisikan-pengguna dalam WHERE di %L"
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Pernyataan didalam WHERE di %L tidak didukung"
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL dengan indeks '%s' tidak digunakan di sisi kiri dari penempatan di %L dan jadi mungkin menyebabkan penempatan berulang di objek ini"
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Sebuah konstruks FORALL luar telah memiliki sebuah indeks dengan nama ini %L"
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE clause di %L membutuhkan sebuah array LOGIKAL"
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr "Ekspresi KARAKTER akan dipotong dalam penempatan (%d/%d) di %L"
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Variabel impure di %L ditempatkan ke sebuah tipe variabel turunan dengan sebuah komponen PENUNJUK dalam sebuah prosedur PURE (12.6)"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Variabel impure di %L ditempatkan ke sebuah tipe variabel turunan dengan sebuah komponen PENUNJUK dalam sebuah prosedur PURE (12.6)"
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr ""
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "pernyataan GOTO ASSIGNED di %L membutuhkan sebuah variabel INTEGER"
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabel '%s' belum pernah ditempatkan sebuah label target di %L"
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Pernyataan RETURN alternatif di %L membutuhkan sebuah SKALAR-INTEGER return penspesifikasi"
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr "Pernyataan aritmetik IF di %L membutuhkan sebuah ekspresi numerik"
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Kondisi keluar dari loop DO WHILE di %L harus berupa sebuah ekspresi skalar LOGIKAL"
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL mask clause di %L membutuhkan sebuah ekspresi LOGIKAL"
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Pernyataan kode buruk"
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
@@ -55606,7 +55655,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -55614,63 +55663,63 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr "Binding label '%s' di %L collides dengan global entity '%s' di %L"
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr ""
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Objek skalar '%s' di %L mungkin tidak dapat DIALOKASIKAN"
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Tipe '%s' tidak dapat host assosiasi di %L karena ini diblok dengan sebuah objek tidak kompatibel dari nama sama yang dideklarasikan di %L"
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
@@ -55677,484 +55726,484 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr "Modul atau array aplikasi utama '%s' di %L harus memiliki bentuk konstan"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entity dengan panjang karakter diasumsikan di %L harus berupa sebuah argumen dummy atau sebuah PARAMETER"
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Dapat dialokasikan '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Eksternal '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsik '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Hasil fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Array otomatis '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Pernyataan fungsi nilai-karakter '%s' di %L harus memiliki panjang konstant"
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah argumen dummy dari '%s', yang mana ini adalah PUBLIK di %L"
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: Prosedur '%s' dalam antar-muka PUBLIK '%s' di %L memakai argumen dummy dari '%s' dimana ini adalah PRIVATE"
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Objek eksternal '%s' di %L tidak boleh memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Fungsi ELEMEN '%s' di %L harus memiliki sebuah hasil skalar"
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Pernyataan fungsi '%s' di %L tidak diperbolehkan sebagai argumen aktual"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-array"
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-penunjuk"
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat rekursif"
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prosedur '%s' dalam %s di %L tidak memiliki antar-muka eksplisit"
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Prosedur dummy '%s' di %C tidak dapat memiliki sebuah antar-muka umum"
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut SAVE dalam '%s' di %L"
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "Prosedur FINAL '%s' di %L bukan sebuah SUBROUTINE"
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Prosedur FINAL di %L harus memiliki tepat satu argumen"
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa tipe '%s'"
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "argumen dari prosedur FINAL di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argumen dari prosedur FINAL di %L tidak boleh berupa OPSIONAL"
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa INTENT(OUT)"
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Prosedur FINAL bukan skalar di %L seharusnya memiliki diasumsikan argumen bentuk"
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "prosedur FINAL '%s' dideklarasikan di %L memiliki tingkat yang sama (%d) seperti '%s'"
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Hanya array prosedur FINAL dideklarasikan untuk tipe turunan '%s' didefinisikan di %L, disarankan juga skalar satu"
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' dan '%s' tidak dapat dicampurkan FUNCTION/SUBROUTINE untuk GENERIC '%s' di %L"
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' dan '%s' untuk GENERIC '%s' di %L adalah ambigu"
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Tidak terdefinisi pengikatan spesifik '%s' sebagai target dari GENERIC '%s' di %L"
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC '%s' di %L harus target sebuah pengikatan spesifik, '%s' adalah GENERIC, juga"
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "GENERIC '%s' di %L tidak dapat overwrite pengikatan spesifik dengan nama sama"
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' harus berupa sebuah prosedur modul atau sebuah prosedur eksternal dengan sebuah antar-muka eksplisit di %L"
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 #| msgid "Polymorphic entities are not yet implemented, non-polymorphic passed-object dummy argument of '%s' at %L accepted"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "entiti polymorphic belum diimplementasikan, bukan polymorphic objek argumen dummy dilewatkan dari '%s' di %L diterima"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "'%s' argumen dari '%s' instrinsik di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama sebagai sebuah komponen dari '%s'"
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama seperti sebuah komponen turunan dari '%s'"
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Bukan ekstensible tipe turunan '%s' di %L tidak boleh berupa ABSTRACT"
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumen '%s' dari prosedur elemental di %L tidak dapat memiliki atribut POINTER"
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponen '%s' dari '%s' di %L memiliki nama sama dengan prosedur yang melingkupinya"
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Panjang karakter dari komponen '%s' butuh untuk menjadi sebuah ekspresi spesifikasi konstan di %L"
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: Komponen '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah komponen dari '%s', yang mana adalah PUBLIK di %L"
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponen %s dari tipe URUTAN dideklarasikan di %L tidak dapat memiliki atribut URUTAN"
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Komponen penunjuk '%s' dari '%s' di %L adalah sebuah tipe yang belum pernah dideklarasikan"
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr "Komponen '%s' dari '%s' di %L memiliki nama sama dengan prosedur yang melingkupinya"
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Ukuran array yang diasumsikan '%s' dalam daftar nama '%s' di %C tidak diperbolehkan"
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must not have assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' tidak boleh memiliki bentuk yang diasumsikan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' in namelist '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -56162,440 +56211,440 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' in namelist '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr "NAMELIST objek '%s' dalam daftar-nama '%s' di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN"
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' telah dideklarasikan PRIVATE dan tidak dapat berupa anggota dari PUBLIK namelist '%s' di %L"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST objek '%s' memiliki use-associated komponen PRIVATE dan tidak dapat berupa anggota dari daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' meemiliki komponen PRIVATE dan tidak dapat berupa anggota dari PUBLIK daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter array '%s' di %L tidak dapat berupa otomatis atau bentuk deferred"
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Tipe PARAMETER secara implisit '%s' di %L tidak cocok dengan tipe IMPLISIT kemudian"
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipe turunan tidak kompatibel dalam PARAMETER di %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Ukuran array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Simbol di %L bukan sebuah variabel DUMMY"
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' di %L tidak dapat memiliki VALUE atribut karena ini bukan sebuah argumen dummy"
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang konstant"
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C interoperable karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang satu"
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Tipe turunana '%s' di %L adalah tipe '%s',  yang mana belum didefinisikan"
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Diasumsikan bentuk array '%s' di %L tidak diijinkan dalam sebuah ekspresi inisialisasi"
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel '%s' di %L tidak dapat berupa BIND(C) karena ini bukan sebuah blok UMUM atau dideklarasikan dalam tingkat cakupan modul"
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: PUBLIK %s '%s' di %L dari tipe turunan '%s' PRIVATE"
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) dummy argumen '%s' di %L adalah UKURAN DIASUMSIKAN dan jadi tidak dapat memiliki sebuah penginisialisasi baku"
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Prosedur dummy di %L tidak diperbolehkan dalam prosedur ELEMENTAL"
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate di %L bukan SAVEd"
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "DATA BLOK elemen '%s' di %L harus berupa dalam COMMON"
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA array '%s' di %L harus dispesifikasikan dalam sebuah deklarasi sebelumnya"
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Daerah array tidak konstant di %L dalam pernyataan DATA"
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "pernyataan DATA di %L memiliki lebih variabel daripada nilai"
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "pernyataan DATA di %L memiliki lebih banyak nilai daripada variabel"
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Label %d di %L didefinisikan tetapi tidak digunakan"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Label %d di %L didefinisikan tetapi tidak dapat digunakan"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L harus memiliki atribut URUTAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Tipe variabel turunan '%s' di %L dengan inisialisasi baku tidak dapat berada dalam EKUIVALEN dengan sebuah variabel dalam COMMON"
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L dengan komponen penunjuk tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Baik semua atau kosong dari objek dalam EKUIVALEN set di %L yang memiliki atribut TERPROTEKSI"
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Anggota blok umum '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN dalam prosedur pure '%s'"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Konstanta bernama '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Array '%s' di %L dengan cakupan tidak-konstan tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Komponen struktur '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring di %L memiliki panjang nol"
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fungsi PUBLIK '%s' di %L tidak dapat berupa tipe PRIVATE '%s'"
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "MASUKAN '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prosedur operator pengguna '%s' di %L harus berupa sebuah FUNGSI"
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prosedur operator pengguna '%s' di %L tidak dapat berupa panjang karakter diasumsikan"
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prosedur operator pengguna '%s' di %L harus memiliki paling tida satu argumen"
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Argumen pertama dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Argumen kedua dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Antar-muka operator di %L harus memiliki, paling tidak, dua argumen"
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -56629,50 +56678,50 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr "!$OMP di %C berawal sebuah baris berkomentar yang tidak diikuti sebuah spasi atau sebuah baris kelanjutan"
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "Line truncated at %L"
 msgstr "Baris terpotong di %C"
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr "Batas dari %d kelanjutan dilampaui dalam pernyataan di %C"
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "Missing '&' in continued character constant at %C"
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "Hilang '&' dalam konstanta karakter kelanjutan di %C"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr "Karakter tab tidak konforman di %C"
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "'&' not allowed by itself in line %d"
 msgid "%<&%> not allowed by itself in line %d"
 msgstr "'&' tidak diperboleh dengan sendirinya dalam baris %d"
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr "Karakter tab tidak konforman dalam kolom %d dari baris %d"
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr "%s:%d: berkas %s tertinggal tetapi tidak dimasukan"
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr "%s:%d: Direktif preprosesor tidak legal"
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open file '%s'"
 msgid "Can't open file %qs"
@@ -56944,55 +56993,55 @@
 msgid "Reshaped array too large at %C"
 msgstr "Integer terlalu besar di %C"
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "Hasil dari overflow SKALA jenisnya di %L"
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "Argumen dari SQRT di %L memiliki sebuah nilai negatif"
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid second argument of IBSET at %L"
 msgid "invalid argument of SQRT at %L"
 msgstr "Argumen kedua dari IBSET di %L tidak valid"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_conv_constant_to_tree(): invalid type: %s"
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): tipe tidak valid: %s"
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, fuzzy, gcc-internal-format
 #| msgid "Character '%s' in string at %L cannot be converted into character kind %d"
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
@@ -57079,273 +57128,279 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "Argumen '%s' dari prosedur elemental di %L tidak dapat memiliki atribut POINTER"
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "Prosedur internal '%s' tidak diperbolehkan sebagai sebuah argumen aktual di %L"
+
+#: fortran/symbol.c:489
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "Procedure pointer at %C"
 msgstr "nama prosedur = %s"
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "%s atribut diaplikasikan ke %s %s di %L"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) diaplikasikan ke %s %s di %L"
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr "%s atribut konflik dengan %s atribut dalam '%s' di %L"
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute with %s attribute at %L"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr "%s atribut konflik dengan %s atribut dalam '%s' di %L"
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "Tidak dapat mengubah atribut dari USE-assosiasi simbol di %L"
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "Tidak dapat mengubah atribut dari USE-assosiasi simbol %s di %L"
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Duplikasi atribut %s dispesifikasikan di %L"
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "ALLOCATABLE dispesifikasikan diluar dari tubuh ANTAR-MUKA di %L"
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, fuzzy, gcc-internal-format
 #| msgid "DIMENSION specified for '%s' outside its INTERFACE body at %L"
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "DIMENSION dispesifikasikan untuk '%s' diluar dari badan ANTAR-MUKA di %L"
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, fuzzy, gcc-internal-format
 #| msgid "DIMENSION specified for '%s' outside its INTERFACE body at %L"
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "DIMENSION dispesifikasikan untuk '%s' diluar dari badan ANTAR-MUKA di %L"
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "Cray Pointee di %L muncul dalam beberapa pernyataan penunjuk()"
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Duplikasi atribut TERPROTEKSI dispesifikasikan di %L"
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "atribut SAVE di %L tidak dapat dispesifikasikan dalam sebuah prosedur PURE"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "Duplikasi SAVE atribut dispesifikasikan di %L"
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Duplikasi atribut NILAI dispesifikasikan di %L"
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Duplikasi atribut VOLATILE dispesifikasikan di %L"
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate VALUE attribute specified at %L"
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Duplikasi atribut NILAI dispesifikasikan di %L"
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s atribut dari '%s' konflik dengan %s atribut di %L"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "%s prosedur di %L telah dideklarasikan sebagai %s prosedur"
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) konfliks dengan INTENT(%s) di %L"
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "Spesifikasi AKSES di %L telah dispesifikasikan"
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Duplikasi atribut BIND dispesifikasikan di %L"
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid " BIND(C)"
 msgid "BIND(C) at %L"
 msgstr " BIND(C)"
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Duplikasi atribut EXTENDS dispesifikasikan di %L"
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: EXTENDS at %L"
 msgid "EXTENDS at %L"
 msgstr "Fortran 2003: EXTENDS di %L"
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Simbol '%s' di %L telah memiliki sebuah antar-muka eksplisit"
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has attributes specified outside its INTERFACE body"
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "'%s' di %L memiliki atribut dispesifikasikan diluar dari badan ANTAR-MUKA-nya"
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %C already has a type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Fungsi '%s' di %C telah memiliki sebuah tipe dari %s"
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Prosedur '%s' di %L memiliki nama sama sebagai sebuah komponen dari '%s'"
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Simbol '%s' di %L tidak dapat memiliki sebuah tipe"
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr "Komponen '%s' di %C telah dideklarasikan di %L"
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr "Komponen '%s' di %C telah berada dalam tipe induknya di %L"
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Simbol '%s' di %C adalah ambigu"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Tipe turunan '%s' di %C sedang digunakan sebelum itu didefinisikan"
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Komponen '%s' di %C adalah sebuah komponen PRIVATE dari '%s'"
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%s' di %C bukan sebuah anggota dari struktur '%s'"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Duplikasi pernyataan label %d di %L dan %L"
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Label %d di %C telah direferensikan sebagai target percabangan"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Label %d di %C telah direferensikan sebagai sebuah format label"
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Label %d di %C sebelumnya digunakan sebagai sebuah FORMAT label"
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Label %d di %C sebelumnya digunakan sebagai target percabangan"
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "Diduga nama berakhir di %C"
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Nama '%s' di C adalah sebuah referensi ambigu ke '%s' dari module '%s'"
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
@@ -57352,69 +57407,69 @@
 msgstr "Nama '%s' di %C adalah sebuah referensi ambigu ke '%s' dari satuan aplikasi sekarang"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Simbol '%s' di %C telah diassosiasikan host"
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' declared at %L must have the BIND attribute to be C interoperable"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Tipe turunan '%s' dideklarasikan di %L harus memiliki atribut BIND ke Cinteroperable"
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr "Komponen '%s' di %L tidak dapat memiliki atribut PENUNJUK karena ini sebuah anggota tari BIND(C) tipe turunan '%s' di %L"
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr "Komponen '%s' di %L tidak dapat memiliki atribut PENUNJUK karena ini sebuah anggota tari BIND(C) tipe turunan '%s' di %L"
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr "Komponen '%s' di %L tidak dapat memiliki atribut DAPAT DIALOKASIKAN karena ini sebuah anggota dari tipe turunan BIND(C) '%s' di %L"
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable, even though derived type '%s' is BIND(C)"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Komponen '%s' dalam tipe turunan '%s' di %L mungkin tidak C interoperabel, walaupun melalui tipe turunan '%s' adalah BIND(C)"
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Komponen '%s' dalam tipe turunan '%s' di %L mungkin tidak C interoperabel"
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "Tipe turunan '%s' di %L tidak dapat dideklarasikan dengan baik atribut PRIVATE dan BIND(C)"
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Tipe turunan '%s' di %L tidak dapat memiliki urutan atribut karena ini adalah BIND(C)"
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' is used before it is typed at %L"
 msgid "Symbol %qs is used before it is typed at %L"
@@ -57701,7 +57756,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr "IO basetype buruk (%d)"
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_omp_workshare(): Bad statement code"
@@ -61160,6 +61215,9 @@
 #~ msgid "CPU names must be lower case"
 #~ msgstr "nama CPU harus huruf kecil"
 
+#~ msgid "-munix=98 option required for C89 Amendment 1 features.\n"
+#~ msgstr "-munix=98 pilihan dibutuhkan untuk feature C89 Amendment 1.\n"
+
 #~ msgid "Invalid mul type specified (%s) - expected mac, mul or none"
 #~ msgstr "Tipe mul yang dispesifikasikan (%s) tidak valid - diduga mac, mul atau none"
 
@@ -61589,6 +61647,9 @@
 #~ msgid "%qD has no member named %qE"
 #~ msgstr "%qD tidak memiliki anggota bernama %qE"
 
+#~ msgid "ISO C++ forbids subscripting non-lvalue array"
+#~ msgstr "ISO C++ melarang subscripting array bukan-lvalue"
+
 #~ msgid "at this point in file"
 #~ msgstr "di titik ini dalam berkas"
 
Index: gcc/po/fi.po
===================================================================
--- gcc/po/fi.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/fi.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -32,7 +32,7 @@
 msgstr ""
 "Project-Id-Version: gcc 5.1-b20150208\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2015-04-12 18:13+0200\n"
 "Last-Translator: Lauri Nurmi <lanurmi@iki.fi>\n"
 "Language-Team: Finnish <translation-team-fi@lists.sourceforge.net>\n"
@@ -217,13 +217,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "liukulukuvakiota käytetty väärin"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1417,7 +1417,7 @@
 msgid "options enabled: "
 msgstr "käyttöön otetut valitsimet: "
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2624,97 +2624,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "virheellinen %%H-arvo"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "virheellinen %%r-arvo"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "virheellinen %%R-arvo"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "virheellinen %%N-arvo"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "virheellinen %%P-arvo"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "virheellinen %%h-arvo"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "virheellinen %%L-arvo"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "virheellinen %%m-arvo"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "virheellinen %%M-arvo"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "virheellinen %%U-arvo"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "virheellinen %%s-arvo"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "virheellinen %%C-arvo"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "virheellinen %%E-arvo"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr ""
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "virheellinen %%xn-koodi"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 msgid "invalid operand address"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
@@ -2762,7 +2762,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr ""
@@ -2919,8 +2919,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3142,62 +3142,62 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr ""
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr ""
 
@@ -3239,7 +3239,7 @@
 msgid "invalid %%P operand"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "virheellinen %%p-arvo"
@@ -3305,7 +3305,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr ""
 
@@ -3469,100 +3469,100 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "virheellinen %%H-arvo"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "virheellinen %%f-arvo"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "virheellinen %%F-arvo"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "virheellinen %%G-arvo"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "virheellinen %%j-koodi"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "virheellinen %%J-koodi"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "virheellinen %%k-arvo"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "virheellinen %%K-arvo"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "virheellinen %%O-arvo"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "virheellinen %%q-arvo"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "virheellinen %%S-arvo"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "virheellinen %%T-arvo"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "virheellinen %%u-arvo"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "virheellinen %%v-arvo"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "virheellinen %%x-arvo"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 msgid "Unable to generate load offset for fusion"
 msgstr ""
 
@@ -3656,60 +3656,60 @@
 msgid "invalid operand to %%S"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr ""
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr ""
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr ""
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr ""
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr ""
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, fuzzy, c-format
 msgid "invalid %%C operand"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, fuzzy, c-format
 msgid "invalid %%D operand"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr ""
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr ""
@@ -3913,7 +3913,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr ""
@@ -3929,15 +3929,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr ""
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
@@ -3959,8 +3959,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
@@ -3967,8 +3967,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
@@ -3978,13 +3978,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr ""
@@ -3991,8 +3991,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
@@ -4013,7 +4013,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
@@ -4031,34 +4031,34 @@
 msgid "expected %<.%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr ""
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%qs määrittää %<auto%>:n tiedostoalue-esittelyssä"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
@@ -4067,11 +4067,11 @@
 msgid "(anonymous)"
 msgstr "(nimetön)"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "ehdokas 1:"
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "ehdokas 2:"
 
@@ -4296,11 +4296,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "ehdokkaat ovat:"
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ehdokas on:"
@@ -4353,51 +4353,51 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "unaariselle miinus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "unaariselle plus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "bittikomplementille annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "konjugaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "unaariselle plus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4492,7 +4492,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "kokonaislukuylivuoto lausekkeessa"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 #, fuzzy
 msgid "array assignment"
 msgstr "epäkelpo lvalue sijoituksessa"
@@ -4512,7 +4512,7 @@
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4583,7 +4583,7 @@
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 #, fuzzy
 msgid "internal unit in WRITE"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -4590,7 +4590,7 @@
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4678,7 +4678,7 @@
 msgid "Bad type in constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 msgid "Unexpected end of module"
 msgstr ""
 
@@ -4709,11 +4709,11 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 #, fuzzy
 msgid "pointer assignment"
 msgstr "epäkelpo lvalue sijoituksessa"
@@ -4731,211 +4731,211 @@
 msgid "internal function"
 msgstr "sisäinen funktio"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 #| msgid "no arguments"
 msgid "allocatable argument"
 msgstr "ei argumentteja"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "ei argumentteja"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 msgid "optional argument"
 msgstr "virheellinen %%H-arvo"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 msgid "pointer argument"
 msgstr "epäkelpo lvalue sijoituksessa"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 msgid "target argument"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 msgid "value argument"
 msgstr "virheellinen %%H-arvo"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "ei argumentteja"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-shape argument"
 msgstr "täsmäämättömät argumentit"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-rank argument"
 msgstr "täsmäämättömät argumentit"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 msgid "coarray argument"
 msgstr "epäkelpo lvalue sijoituksessa"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "ei argumentteja"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-type argument"
 msgstr "täsmäämättömät argumentit"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 #, fuzzy
 msgid "bind(c) procedure"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr ""
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 #, fuzzy
 msgid "iterator variable"
 msgstr "%qD ei ole muuttuja"
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5344,16 +5344,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr ""
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr ""
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr ""
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr ""
@@ -5366,6 +5356,11 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr ""
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+#, fuzzy
+msgid "profiling not supported with -mg"
+msgstr "profilointia ei tueta valitsimen -mg kanssa\n"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr ""
@@ -5374,10 +5369,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr ""
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr ""
-
 #: config/cris/cris.h:184
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr ""
@@ -5407,6 +5398,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr ""
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5413,6 +5410,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr "ei voi käyttää sekä valitsinta -m32 että -m64"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr ""
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr ""
@@ -5426,6 +5427,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "valitsimia -mbig-endian ja -mlittle-endian ei voi käyttää yhdessä"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr ""
+
 #: config/avr/specs.h:68
 #, fuzzy
 msgid "shared is not supported"
@@ -5452,17 +5457,19 @@
 msgid "no processor type specified for linking"
 msgstr "linkitystä varten ei ole määritelty suoritinta"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr ""
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr ""
 
@@ -5498,11 +5505,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr ""
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-#, fuzzy
-msgid "profiling not supported with -mg"
-msgstr "profilointia ei tueta valitsimen -mg kanssa\n"
-
 #: fortran/lang.opt:146
 msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgstr ""
@@ -5693,9 +5695,9 @@
 msgstr ""
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -5901,10 +5903,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -5951,7 +5953,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
@@ -7879,45 +7881,49 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 #, fuzzy
 msgid "Specify the code model"
 msgstr "Määrittele käytettävä ABI"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 #, fuzzy
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr "epäkelpo osoitintila %qs"
@@ -9030,10 +9036,15 @@
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
 #: config/i386/i386.opt:864
+#, fuzzy
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
+
+#: config/i386/i386.opt:868
 msgid "Use given stack-protector guard"
 msgstr ""
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 #, fuzzy
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr "epäkelpo osoitintila %qs"
@@ -9391,7 +9402,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -9540,7 +9551,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 msgid "Use LRA instead of reload"
 msgstr ""
@@ -9667,7 +9678,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr ""
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr ""
 
@@ -9992,319 +10003,319 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "Käytä AltiVec-käskyjä"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 #, fuzzy
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 msgid "Generate isel instructions"
 msgstr "Tuota isel-käskyjä"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 msgid "Deprecated option.  Use -misel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 msgid "Generate PPC750CL paired-single instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 msgid "Deprecated option.  Use -mspe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 msgid "-mdebug=\tEnable debug output"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 #, fuzzy
 msgid "Use the AltiVec ABI extensions"
 msgstr "Käytä AltiVec-käskyjä"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 #, fuzzy
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "Älä varoita Microsoft-laajennosten käytöstä"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 msgid "Use the SPE ABI extensions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 msgid "Do not use the SPE ABI extensions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv1 ABI"
 msgstr "Käytä EABI:a"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 #, fuzzy
 #| msgid "Use EABI"
 msgid "Use the ELFv2 ABI"
 msgstr "Käytä EABI:a"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 #, fuzzy
 msgid "using darwin64 ABI"
 msgstr "Käytetään darwin64-ABIa"
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 #, fuzzy
 msgid "using old darwin ABI"
 msgstr "Käytetään vanhaa darwin-ABIa"
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 msgid "Generate Cell microcode"
 msgstr "Tuota Cell-mikrokoodia"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 #, fuzzy
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "Varoita kun Cell-mikrokoodattu käsky lähetetään"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 #, fuzzy
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_return_address%>"
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 #, fuzzy
 msgid "Valid arguments to -malign-:"
 msgstr "aliaksen argumentti ei ole merkkijono"
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 #, fuzzy
 msgid "Single-precision floating point unit"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 #, fuzzy
 msgid "Double-precision floating point unit"
 msgstr "tarkkuus printf-muotoilussa"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 #, fuzzy
 msgid "Floating point unit does not support divide & sqrt"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 msgid "Specify Xilinx FPU."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 #, fuzzy
 #| msgid "Enable sign extend instructions"
 msgid "Allow sign extension in fusion operations"
 msgstr "Ota käyttöön etumerkilliset laajennetut käskyt"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
+#: config/rs6000/rs6000.opt:566
 #, fuzzy
-msgid "Use ISA 2.07 crypto instructions"
-msgstr "Käytä SmartMIPS-käskyjä"
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr "Käytä AltiVec-käskyjä"
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 #, fuzzy
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr "Käytä AltiVec-käskyjä"
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -13248,1561 +13259,1561 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr ""
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "Tasaa funktioiden alut"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr ""
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr ""
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "Tasaa silmukoiden alut"
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr ""
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr ""
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr ""
 
-#: common.opt:918
+#: common.opt:921
 #, fuzzy
 msgid "Generate auto-inc/dec instructions"
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr ""
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr ""
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr ""
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr ""
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr ""
 
-#: common.opt:960
+#: common.opt:963
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr ""
 
-#: common.opt:964
+#: common.opt:967
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr ""
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr ""
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr ""
 
-#: common.opt:979
+#: common.opt:982
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++"
 msgstr "Tarkista new’n paluuarvo"
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr ""
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr ""
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr ""
 
-#: common.opt:1003
+#: common.opt:1006
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr ""
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr ""
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr ""
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr ""
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr ""
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr ""
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr ""
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr ""
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr ""
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr ""
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr ""
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr ""
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 msgid "Perform speculative devirtualization"
 msgstr ""
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1085
+#: common.opt:1088
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr ""
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1145
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr ""
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr ""
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr ""
 
-#: common.opt:1157
+#: common.opt:1160
 msgid "Suppress output of addresses in debugging dumps"
 msgstr ""
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 #, fuzzy
 msgid "Dump optimization passes"
 msgstr "annetut valitsimet: "
 
-#: common.opt:1170
+#: common.opt:1173
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1177
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Ota käyttöön CFI-taulut GAS-assembler-direktiivien kautta"
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr ""
 
-#: common.opt:1190
+#: common.opt:1193
 msgid "Perform interprocedural reduction of aggregates"
 msgstr ""
 
-#: common.opt:1194
+#: common.opt:1197
 msgid "Perform unused symbol elimination in debug info"
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "Käytä poikkeustenkäsittelyä"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr ""
 
-#: common.opt:1217
+#: common.opt:1220
 #, fuzzy, c-format
 msgid "unknown excess precision style %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr ""
 
-#: common.opt:1238
+#: common.opt:1241
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr ""
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr ""
 
-#: common.opt:1250
+#: common.opt:1253
 msgid "Perform a forward propagation pass on RTL"
 msgstr ""
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, fuzzy, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr ""
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr ""
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr ""
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr ""
 
-#: common.opt:1305
+#: common.opt:1308
 msgid "Enable in and out of Graphite representation"
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1312
 msgid "Enable Graphite Identity transformation"
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1316
 #, fuzzy
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr ""
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr ""
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr ""
 
-#: common.opt:1330
+#: common.opt:1333
 msgid "Enable Loop Blocking transformation"
 msgstr ""
 
-#: common.opt:1334
+#: common.opt:1337
 msgid "Enable Loop Unroll Jam transformation"
 msgstr ""
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr ""
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr ""
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr ""
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr ""
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, fuzzy, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1394
+#: common.opt:1397
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr ""
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr ""
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr ""
 
-#: common.opt:1410
+#: common.opt:1413
 msgid "Perform indirect inlining"
 msgstr ""
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 #, fuzzy
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: common.opt:1424
+#: common.opt:1427
 #, fuzzy
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: common.opt:1428
+#: common.opt:1431
 #, fuzzy
 msgid "Integrate functions only required by their single caller"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: common.opt:1435
+#: common.opt:1438
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr ""
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1458
 msgid "Perform interprocedural constant propagation"
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1466
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1470
 msgid "Perform interprocedural profile propagation"
 msgstr ""
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr ""
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 msgid "Perform Identical Code Folding for variables"
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr ""
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr ""
 
-#: common.opt:1506
+#: common.opt:1509
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr ""
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr ""
 
-#: common.opt:1519
+#: common.opt:1522
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr ""
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr ""
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr ""
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr ""
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr ""
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 msgid "Enable link-time optimization."
 msgstr ""
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr ""
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 msgid "Report various link-time optimization statistics"
 msgstr ""
 
-#: common.opt:1625
+#: common.opt:1628
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr ""
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr ""
 
-#: common.opt:1641
+#: common.opt:1644
 msgid "Report on permanent memory allocation in WPA only"
 msgstr ""
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr ""
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1659
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr ""
 
-#: common.opt:1660
+#: common.opt:1663
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr ""
 
-#: common.opt:1676
+#: common.opt:1679
 msgid "Use the RTL dead code elimination pass"
 msgstr ""
 
-#: common.opt:1680
+#: common.opt:1683
 msgid "Use the RTL dead store elimination pass"
 msgstr ""
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "väittämä puuttuu %qs:n jälkeen"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 msgid "unknown offload ABI %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr ""
 
-#: common.opt:1713
+#: common.opt:1716
 #, fuzzy
 msgid "Enable all optimization info dumps on stderr"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr ""
 
-#: common.opt:1729
+#: common.opt:1732
 msgid "Perform partial inlining"
 msgstr ""
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr ""
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr ""
 
-#: common.opt:1745
+#: common.opt:1748
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr ""
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr ""
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr ""
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr ""
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr ""
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr ""
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr ""
 
-#: common.opt:1781
+#: common.opt:1784
 msgid "Specify a plugin to load"
 msgstr ""
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr ""
 
-#: common.opt:1789
+#: common.opt:1792
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr ""
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr ""
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr ""
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1821
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1826
+#: common.opt:1829
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1837
 msgid "Report on consistency of profile"
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1841
 msgid "Enable function reordering that improves code placement"
 msgstr ""
 
-#: common.opt:1845
+#: common.opt:1848
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr ""
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr ""
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr ""
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr ""
 
-#: common.opt:1880
+#: common.opt:1883
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr ""
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr ""
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr ""
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr ""
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr ""
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr ""
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr ""
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr ""
 
-#: common.opt:1928
+#: common.opt:1931
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr ""
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr ""
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr ""
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr ""
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr ""
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr ""
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr ""
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1981
+#: common.opt:1984
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr ""
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1993
+#: common.opt:1996
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1997
+#: common.opt:2000
 msgid "Enable the group heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2009
+#: common.opt:2012
 msgid "Enable the rank heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr ""
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr ""
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr ""
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr ""
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr ""
 
-#: common.opt:2062
+#: common.opt:2065
 msgid "Generate discontiguous stack frames"
 msgstr ""
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr ""
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr ""
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr ""
 
-#: common.opt:2082
+#: common.opt:2085
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr ""
 
-#: common.opt:2086
+#: common.opt:2089
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr ""
 
-#: common.opt:2093
+#: common.opt:2096
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr ""
 
-#: common.opt:2097
+#: common.opt:2100
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr ""
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr ""
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr ""
 
-#: common.opt:2109
+#: common.opt:2112
 msgid "Use a smart stack protection method for certain functions"
 msgstr ""
 
-#: common.opt:2113
+#: common.opt:2116
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr ""
 
-#: common.opt:2117
+#: common.opt:2120
 msgid "Output stack usage information on a per-function basis"
 msgstr ""
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr ""
 
-#: common.opt:2133
+#: common.opt:2136
 msgid "Treat signed overflow as undefined"
 msgstr ""
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr ""
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr ""
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr ""
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr ""
 
-#: common.opt:2157
+#: common.opt:2160
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2163
 #, fuzzy, c-format
 msgid "unknown TLS model %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr ""
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr ""
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr ""
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr ""
 
-#: common.opt:2199
+#: common.opt:2202
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr ""
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr ""
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr ""
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr ""
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr ""
 
-#: common.opt:2231
+#: common.opt:2234
 msgid "Transform condition stores into unconditional ones"
 msgstr ""
 
-#: common.opt:2235
+#: common.opt:2238
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr ""
 
-#: common.opt:2243
+#: common.opt:2246
 msgid "Enable dominator optimizations"
 msgstr ""
 
-#: common.opt:2247
+#: common.opt:2250
 #, fuzzy
 msgid "Enable tail merging on trees"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr ""
 
-#: common.opt:2255
+#: common.opt:2258
 msgid "Enable forward propagation on trees"
 msgstr ""
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr ""
 
-#: common.opt:2263
+#: common.opt:2266
 #, fuzzy
 msgid "Enable string length optimizations on trees"
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 msgid "Enable loop distribution on trees"
 msgstr ""
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr ""
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr ""
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr ""
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr ""
 
-#: common.opt:2300
+#: common.opt:2303
 msgid "Enable loop optimizations on tree level"
 msgstr ""
 
-#: common.opt:2304
+#: common.opt:2307
 msgid "Enable automatic parallelization of loops"
 msgstr ""
 
-#: common.opt:2308
+#: common.opt:2311
 #, fuzzy
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2312
+#: common.opt:2315
 msgid "Enable SSA-PRE optimization on trees"
 msgstr ""
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2324
+#: common.opt:2327
 msgid "Enable reassociation on tree level"
 msgstr ""
 
-#: common.opt:2332
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
 msgstr ""
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr ""
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr ""
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr ""
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr ""
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr ""
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr ""
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr ""
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr ""
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr ""
 
-#: common.opt:2424
+#: common.opt:2427
 msgid "Perform variable tracking by annotating assignments"
 msgstr ""
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr ""
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr ""
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 msgid "Enable vectorization on trees"
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr ""
 
-#: common.opt:2454
+#: common.opt:2457
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr ""
 
-#: common.opt:2458
+#: common.opt:2461
 #, fuzzy
 msgid "Specifies the cost model for vectorization"
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:2478
+#: common.opt:2481
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2485
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2493
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr ""
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr ""
 
-#: common.opt:2507
+#: common.opt:2510
 #, fuzzy, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "tunnistamaton muotomäärite"
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr ""
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2558
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr ""
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr ""
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2582
 #, fuzzy
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in default version of DWARF format"
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:2583
+#: common.opt:2586
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2614
 msgid "Don't generate debug information in separate .dwo files"
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2618
 msgid "Generate debug information in separate .dwo files"
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr ""
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2638
 msgid "Toggle debug information generation"
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr "Tuota vianjäljitystietoja XCOFF-muodossa"
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr ""
 
-#: common.opt:2665
+#: common.opt:2668
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections"
 msgstr "Tuota isel-käskyjä"
 
-#: common.opt:2669
+#: common.opt:2672
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr ""
 
-#: common.opt:2676
+#: common.opt:2679
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr ""
 
-#: common.opt:2680
+#: common.opt:2683
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr ""
 
-#: common.opt:2702
+#: common.opt:2705
 #, fuzzy
 msgid "-o <file>\tPlace output into <file>"
 msgstr "  -o <tiedosto>            Ohjaa tuloste <tiedostoon>\n"
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr "Ota käyttöön funktioprofilointi"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr ""
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr ""
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr ""
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr "Näytä kääntäjän versio"
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "Vaimenna varoitukset"
 
-#: common.opt:2806
+#: common.opt:2809
 msgid "Create a shared library"
 msgstr "Luo jaettu kirjasto"
 
-#: common.opt:2851
+#: common.opt:2854
 msgid "Create a position independent executable"
 msgstr "Luo paikkariippumaton suoritettava tiedosto"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "laskettua arvoa ei käytetä"
@@ -14837,257 +14848,257 @@
 msgid "expected integer or boolean type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 #, fuzzy
 msgid "invalid comparison of nil with nil"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 #, fuzzy
 msgid "incompatible types in binary expression"
 msgstr "yhteensopimattomat tyypin palautuksessa"
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 #| msgid "division by zero"
 msgid "integer division by zero"
 msgstr "jako nollalla"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 #, fuzzy
 msgid "shift of non-integer operand"
 msgstr "taulukon %qE koko ei ole kokonaislukutyyppiä"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 msgid "shift count not unsigned integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 msgid "negative shift count"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 #, fuzzy
 msgid "object is not a method"
 msgstr "kutsuttu objekti %qE ei ole funktio"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 #, fuzzy
 msgid "method type does not match object type"
 msgstr "argumentti %qD ei sovi prototyyppiin"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 #, fuzzy
 msgid "invalid use of %<...%> with builtin function"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_return_address%>"
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 #, fuzzy
 #| msgid "invalid use of template-name %qE without an argument list"
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 #, fuzzy
 msgid "not enough arguments"
 msgstr "ei argumentteja"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 #, fuzzy
 msgid "too many arguments"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 #, fuzzy
 msgid "argument 1 must be a map"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 #, fuzzy
 msgid "invalid type for make function"
 msgstr "epäkelpo tallennusluokka funktiolle %qs"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 #, fuzzy
 msgid "too many arguments to make"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 #, fuzzy
 msgid "argument must be array or slice or channel"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 #, fuzzy
 msgid "unsupported argument type to builtin function"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_return_address%>"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 #, fuzzy
 msgid "argument must be channel"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 #, fuzzy
 msgid "argument must be a field reference"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 #, fuzzy
 msgid "left argument must be a slice"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 #, fuzzy
 msgid "first argument must be []byte"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 #, fuzzy
 msgid "second argument must be slice or string"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 #, fuzzy
 msgid "argument 2 has invalid type"
 msgstr "%Jparametrin %u tyyppi on void"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 #, fuzzy
 msgid "argument must have complex type"
 msgstr "%Jparametrilla %u in vaillinainen tyyppi"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 #, fuzzy
 msgid "complex arguments must have identical types"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 msgid "complex arguments must have floating-point type"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 #, fuzzy
 msgid "expected function"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 msgid "multiple-value argument in single-value context"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 #, fuzzy
 msgid "invalid use of %<...%> with non-slice"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 msgid "function result count mismatch"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 #, fuzzy
 msgid "incompatible type for receiver"
 msgstr "yhteensopimattomat tyypin palautuksessa"
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 #, fuzzy
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 #, fuzzy
 msgid "number of results does not match number of values"
 msgstr "argumenttien määrä ei vastaa prototyyppiä"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 msgid "index must be integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 msgid "slice end must be integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 #| msgid "Cray pointer at %C must be an integer"
 msgid "slice capacity must be integer"
 msgstr "Cray-osoittimen kohdassa %C on oltava kokonaisluku"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 #, fuzzy
 msgid "incompatible type for map index"
 msgstr "yhteensopimattomat tyypin palautuksessa"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 #, fuzzy
 msgid "too many expressions for struct"
 msgstr "liian monta argumenttia muotoilulle"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 #, fuzzy
 msgid "too few expressions for struct"
 msgstr "liian vähän argumentteja muotoilulle"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 msgid "type assertion only valid for interface types"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 #, fuzzy
 msgid "expected channel"
 msgstr "odotettiin luokan nimeä"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -15208,75 +15219,75 @@
 msgid "cannot use type %s as type %s"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 #, fuzzy
 msgid "different receiver types"
 msgstr "epäkelpo osoitintila %qs"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 #, fuzzy
 msgid "different number of parameters"
 msgstr "parametri %q+D määritelty uudelleen"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 #, fuzzy
 msgid "different parameter types"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 #, fuzzy
 msgid "type has no methods"
 msgstr "structilla ei ole jäseniä"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, fuzzy, c-format
 msgid "missing method %s%s%s"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -15396,7 +15407,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "%<__builtin_prefetch%>-funktion kolmas argumentti on epäkelpo; käytetään nollaa"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "liian vähän argumentteja funktiolle %<va_start%>"
@@ -15578,12 +15589,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr ""
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
@@ -16144,242 +16155,247 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr ""
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr ""
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr ""
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, fuzzy, gcc-internal-format
 msgid "execution count is negative"
 msgstr "taulukon %qs koko on negatiivinen"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr ""
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr ""
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, fuzzy, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, fuzzy, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "tyhjä esittely"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "tyhjä esittely"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr ""
@@ -16509,7 +16525,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, fuzzy, gcc-internal-format
 msgid "atexit failed"
@@ -16750,17 +16766,17 @@
 msgid "          %s"
 msgstr "          %s"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr ""
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr ""
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr ""
@@ -16805,12 +16821,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -17005,7 +17021,7 @@
 msgid "total size of local objects too large"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -17452,9 +17468,9 @@
 msgstr "PCH-tiedostoa ei voida kirjoittaa"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, gcc-internal-format
 msgid "declared here"
 msgstr "esitelty täällä"
@@ -17469,153 +17485,148 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr ""
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, fuzzy, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-tyhjän"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "paikallinen muuttuja %qD ei voi esiintyä tässä yhteydessä"
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:7001
-#, fuzzy, gcc-internal-format
-msgid "lastprivate variable %qE is private in outer context"
-msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, gcc-internal-format
 msgid "directive not yet implemented"
 msgstr ""
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, fuzzy, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "%<va_arg%>-funktion ensimmäinen argumentti ei ole tyyppiä %<va_list%>"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT muunnetaan tyypiksi %qT, kun se viedään %<...%>:n läpi"
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(eli kannattaisi antaa %qT eikä %qT funktiolle %<va_arg%>)"
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "jos tämä koodi saavutetaan, ohjelma keskeytyy"
@@ -18037,47 +18048,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr ""
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
@@ -18160,48 +18171,48 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "vääränmuotoinen COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "ei syötetiedostoja"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 msgid "writing output file"
 msgstr "%s:virhe kirjoitettaessa tulostetiedostoa ”%s”\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "COLLECT_GCC-ympäristömuuttujan on oltava asetettuna"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "COLLECT_GCC_OPTIONS-ympäristömuuttujan on oltava asetettuna"
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen: %s: %m"
@@ -18338,13 +18349,13 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid exit from %s structured block"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid entry to %s structured block"
@@ -18351,18 +18362,18 @@
 msgstr "%qs-attribuutin virheellinen argumentti"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "ignoring large linear step"
 msgstr "jätetään hakemiston ”%s” kaksoiskappale huomiotta,\n"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -18876,8 +18887,8 @@
 msgstr ""
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr ""
@@ -19318,7 +19329,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld:n paluuarvo oli %d"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F käytetty, mutta ei määritelty"
@@ -20297,42 +20308,42 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -20713,47 +20724,47 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, gcc-internal-format
 msgid "array subscript is outside array bounds"
 msgstr "taulukon indeksi on taulukkorajojen ulkopuolella"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, gcc-internal-format
 msgid "array subscript is above array bounds"
 msgstr "taulukon indeksi on taulukkorajojen yläpuolella"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, gcc-internal-format
 msgid "array subscript is below array bounds"
 msgstr "taulukon indeksi on taulukkorajojen alapuolella"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr ""
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr ""
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr "vertailu on aina epätosi johtuen tietotyypin rajallisesta arvoalueesta"
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr "vertailu on aina tosi johtuen tietotyypin rajallisesta arvoalueesta"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr ""
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr ""
@@ -20797,9 +20808,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21032,7 +21043,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "muuttujan %q+D koko muistissa ei ole tunnettu"
@@ -21182,27 +21193,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "merkkijonon pituudeksi annettu %1$qd merkkiä on suurempi kuin ISO C%3$d -kääntäjiltä vaadittu %2$qd merkkiä"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "vasemmalle siirron lukumäärä on negatiivinen"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "vasemmalle siirron lukumäärä >= tyypin leveys"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "oikealle siirron lukumäärä >= tyypin leveys"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
@@ -21534,12 +21545,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "%qD:n osoite tulee aina olemaan %<true%>"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "ehdotetaan sulkeita totuusarvona käytetyn sijoituksen ympärille"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
@@ -21992,12 +22003,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "epäkelpo vektorityyppi attribuutille %qE"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr ""
@@ -22007,23 +22018,23 @@
 msgid "number of components of the vector not a power of two"
 msgstr "vektorin komponenttien määrä ei ole kahden potenssi"
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "ei-tyhjä attribuutti ilman argumentteja ei-prototyypissä"
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "ei-tyhjällä argumentilla on epäkelpo operandinumero (argumentti %lu)"
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "ei-tyhjällä argumentilla arvoalueen ylittävä operandinumero (argumentti %lu,operandi %lu)"
 
 # XXX
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "ei-tyhjä argumentti viittaa ei-osoitinoperandiin (argumentti %lu, operandi %lu)"
@@ -22063,12 +22074,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "haluttu sijainti on pienempi kuin nolla"
@@ -22149,7 +22160,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr ""
@@ -22568,7 +22579,7 @@
 msgstr ""
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
@@ -23027,7 +23038,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
@@ -23037,22 +23048,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE:a ei ole alustettu"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "epäkelpo alustin"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "puuttuva kasvatuslauseke"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "virheellinen kasvatuslauseke"
@@ -23589,6 +23600,11 @@
 msgid "too many input files"
 msgstr "liikaa syötetiedostoja"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+msgid "-mcpu string too large"
+msgstr "pyydetty kohdistus on liian suuri"
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -23614,47 +23630,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr ""
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr ""
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr ""
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -24036,63 +24052,63 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr ""
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr ""
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr ""
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr ""
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr ""
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, gcc-internal-format
 msgid "bad value %qs for -mtune switch"
 msgstr ""
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr ""
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr ""
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr ""
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr ""
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr ""
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr ""
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -24569,14 +24585,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to functions"
@@ -25219,377 +25235,393 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong arg %s to option %s"
 msgstr "liian monta argumenttia funktiolle %qs"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
+
+#: config/i386/i386.c:3012
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown alignment %s specified for option %s"
 msgstr "Funktio %qs:"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too many size ranges specified in option %s"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown argument list function at %L"
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr ""
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "aliaksen argumentti ei ole merkkijono"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-attribuutti tarvitsee kokonaislukuvakioargumentin"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%Jei voi asettaa %qE-attribuuttia määrittelyn jälkeen"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attribuutit stdcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attribuutit stdcall ja fastcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5923
-#, gcc-internal-format
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr ""
-
-#: config/i386/i386.c:6210
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support saturating types"
 msgid "X32 does not support ms_abi attribute"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, gcc-internal-format
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
 #, gcc-internal-format
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:11378
+#, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
@@ -25596,252 +25628,252 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "dwarfin versio %d ei ole tuettu"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "muotomerkkijonolla on epäkelpo operandinumero"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, fuzzy, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr "Tuntematon arkkitehtuuri ”%s”"
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr ""
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_return_address%>"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -25934,13 +25966,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr ""
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -26012,7 +26044,7 @@
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument not an integer constant"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
@@ -26072,7 +26104,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -26926,16 +26958,11 @@
 msgid "-g option disabled"
 msgstr ""
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr ""
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, gcc-internal-format
@@ -27197,310 +27224,315 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argumentin 1 on oltava 5-bittinen etumerkillinen literaali"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argumentin 1 on oltava 5-bittinen etumerkillinen literaali"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
+#, gcc-internal-format, gfc-internal-format
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had no type"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr ""
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "väärinmuodostettu #pragma GCC pch_preprocess, jätetään huomiotta"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s: PCH-tiedosto oli epäkelpo"
@@ -27752,88 +27784,88 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "taulukon %qs koko on negatiivinen"
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "%q+D:n ensimmäisen argumentin pitäisi olla %<int%>"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%Jei voi asettaa %qE-attribuuttia määrittelyn jälkeen"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr ""
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
@@ -27848,53 +27880,53 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr ""
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr ""
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is supported only for SH2A"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr ""
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to SH2A"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument should be between 0 to 255"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument not a string constant"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr ""
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, gcc-internal-format
 msgid "need a second call-clobbered general purpose register"
 msgstr ""
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr ""
@@ -28273,44 +28305,44 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "epäkelpo alkiotyyppi attribuutille %qs"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "vektorin komponenttien määrä ei ole kahden potenssi"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "%qs attribuuttia ei huomioida"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "%qs-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "attribuutti %qs soveltuu vain taulukkotyyppeihin"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -28371,7 +28403,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
@@ -28401,62 +28433,62 @@
 msgid "GCC supports only %u nested scopes"
 msgstr "GCC tukee korkeintaan %u sisäkkäistä näkyvyysaluetta"
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "nimiötä %q+D käytetty mutta ei määritelty"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "sisäkkäinen funktio %q+D esitelty mutta ei koskaan määritelty"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, fuzzy, gcc-internal-format
 msgid "variable %qD set but not used"
 msgstr "nimike %q+D määritelty mutta käytettämättä"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, fuzzy, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "%Jtaulukon %qD tyyppi viimeistelty epäkelvosti implisiittisellä alustuksella"
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "alunperin määritelty täällä"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr "argumenttityyppi, jolla on tavallinen tyyppimuunnos, ei sovi tyhjään parametrinimiluetteloesittelyyn"
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "%q+D:n prototyyppi esittelee enemmän argumentteja kuin edellinen, vanhantyylinen määrittely"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "%q+D:n prototyyppi esittelee vähemmän argumentteja kuin edellinen, vanhantyylinen määrittely"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr "%q+D:n prototyypou esittelee yhteensopimatonta tyyppiä olevan argumentin %d"
@@ -28463,42 +28495,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, fuzzy, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "%Jfunktion %qD protyyppi seuraa ei-prototyypin määrittelyä"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "%q+D:n edellinen, implisiittinen esittely oli täällä"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "%q+D:n edellinen esittely oli täällä"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "%q+D esitelty uudelleen erityyppisenä symbolina"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "luetellun tyypin jäsenen %q+D uudelleenesittely"
@@ -28506,342 +28538,342 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "ristiriitaiset tyypit sisäiselle funktiolle %q+D"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "ristiriitaiset tyypit %q+D:lle"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, fuzzy, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr "%J ristiriitaiset tyyppimääreet %qD:lle"
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, fuzzy, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr "%J ristiriitaiset tyyppimääreet %qD:lle"
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, fuzzy, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr "%J ristiriitaiset tyyppimääreet %qD:lle"
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
 msgstr "typedef %q+D määritelty uudelleen"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "typedef %q+D määritelty uudelleen"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "typedef %q+D määritelty uudelleen"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "%q+D määritelty uudelleen"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "%q+D esitelty staattisena, edellinen esittely ei-staattinen"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "%q+D esitelty ei-staattisena, edellinen esittely staattinen"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr ""
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, gcc-internal-format
 msgid "but not here"
 msgstr "mutta ei täällä"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "%J%qD esitelty säiekohtaisena, edellinen esittely ei säiekohtainen"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "%j%qD esitelty ei-säiekohtaisena, edellinen esittely säiekohtainen"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, fuzzy, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "%J%qD esitelty extern-avainsanalla, edellinen esittely ei sisällä linkitystä"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "%J%qD esitelty ilman linkitystä, edellinen esittely sisältää extern-avainsanan"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr "%q+D esitelty uudelleen erilaisella näkyvyydellä (vanha näkyvyys säilytetty)"
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, fuzzy, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "%J%qD esitelty avoimeksi, edellinen esittely sisältää attribuutin noinline"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "%J%qD esitelty attribuutilla noinline, edellinen esittely on avoin "
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "%J%qD esitelty attribuutilla noinline, edellinen esittely on avoin "
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "parametri %q+D määritelty uudelleen"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "%J%qD esitelty turhaan uudestaan"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "%J%qD:n esittely varjostaa edellistä paikallista"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr "%J%qD:n esittely varjostaa parametria"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "%J%qD:n esittely varjostaa edellistä paikallista"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "varjostunut esittely on täällä"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "sisäisen funktion %qD yhteensopimaton implisiittinen esittely"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "funktion %qD yhteensopimaton implisiittinen esittely"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE esittelemättä täällä (ei funktiossa)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE esittelemättä (ensimmäinen käyttökerta tässä funktiossa)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, fuzzy, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Jokaisesta esittelemättömästä tunnisteesta ilmoitetaan vain"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "hyppy ohittaa muuttujan alustuksen"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "nimiö %qD määritelty täällä"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD esitelty täällä"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, fuzzy, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "%qE-nimiön kaksoisesittely"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr ""
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "perinteisestä C:stä puuttuu erillinen nimiavaruus nimikkeille, tunniste %qE on ristiriidassa"
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "switch hyppää muuttuja-alustuksen yli"
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "switch alkaa tästä"
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, fuzzy, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "nimeämätön tietue/unioni ei määrittele yhtään instanssia"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "tyhjä esittely tallennusluokkamääritteellä ei esittele tunnistetta uudelleen"
 
 # XXX
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "tyhjä esittely tyyppimääreellä ei esittele tunnistetta uudelleen"
 
 # XXX
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, fuzzy, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "tyhjä esittely tyyppimääreellä ei esittele tunnistetta uudelleen"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "tarpeeton tyyppinimi tyhjässä esittelyssä"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, fuzzy, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> tiedostoalueen tyhjässä esittelyssä"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> tiedostoalueen tyhjässä esittelyssä"
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "tarpeeton tallennusluokkamäärite tyhjässä esittelyssä"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "tarpeeton %<__thread%> tyhjässä esittelyssä"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "tarpeeton tyyppimääre tyhjässä esittelyssä"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "tarpeeton %<__thread%> tyhjässä esittelyssä"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "tyhjä esittely"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 ei tue parametritaulukkoesittelyissä avainsanaa %<static%> tai tyyppimääreitä"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 ei tue syntaksia %<[*]%> taulukkoesittelijöissä"
@@ -28849,38 +28881,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D on yleensä funktio"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "typedef %qD on alustettu (käytä __typeof__ sen sijaan)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "funktio %qD on alustettu kuten muuttuja"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "parametri %qD on alustettu"
@@ -28889,260 +28921,260 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "alustamaton const %qD"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%q+D alustetaan jäljempänä kuin"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "taulukon %q+D koko puuttuu"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "nollan tai negatiivisen kokoinen taulukko %q+D"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "muuttujan %q+D koko muistissa ei ole vakio"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "ei-staattisen paikallismuuttujan %q+D asm-määrittäjä jätetään huomiotta"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "ei voi laittaa volatile-kenttäistä objektia rekisteriin"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, gcc-internal-format
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "alustamaton vakio %qD on virheellinen C++-kielessä"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C kieltää parametrien ennakkoesittelyn"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "bittikentän %qs leveys ei ole kokonaislukuvakio"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "bittikentän %qs leveys ei ole kokonaislukuvakio"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "bittikentän %qs leveys on negatiivinen"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "bittikentällä %qs on epäkelpo tyyppi"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "bittikentän %qs tyyppi on GCC-laajennos"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "bittikentän %qs leveys ylittää tyyppinsä"
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs on kapeampi kuin tyyppisensä arvot"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 kieltää taulukon %qE, jonka kokoa ei voida määrittää"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 kieltää taulukot, joiden kokoa ei voida määrittää"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, fuzzy, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "%qE:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "tyypin nimessä tyyppi on oletuksena %<int%>"
 
 # XXX
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "ylimääräinen %<const%>"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "ylimääräinen %<restrict%>"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "ylimääräinen %<volatile%>"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "ylimääräinen %<restrict%>"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr ""
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "funktion määrittely esitelty %<register%>:ksi"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "funktion määrittely esitelty %<typedef%>:ksi"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "tallennusluokka annettu tietueen kentälle %qE"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "tallennusluokka annettu tietueen kentälle"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "tallennusluokka annettu parametrille %qE"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "tallennusluokka annettu nimettömälle parametrille"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, fuzzy, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, fuzzy, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs on sekä %<extern%> että alustin"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "%qs määrittää %<auto%>:n tiedostoalue-esittelyssä"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "%qs määrittää %<register%>:n tiedostoalue-esittelyssä"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, fuzzy, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "funktioalue %qs implisiittisesti auto ja esitelty %<__thread%>:ksi"
@@ -29150,687 +29182,687 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "staattinen tai tyyppimääreitä ei-parametrisessa taulukkoesittelijässä"
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "%qE:n esittely taulukollisena void-alkioita"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "tyyppinimen esittely taulukollisena void-alkioita"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "%qE:n esittely taulukollisena funktioita"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "tyyppinimen esittely taulukollisena funktioita"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "taulukon %qE koko ei ole kokonaislukutyyppiä"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "nimettömän taulukon koko ei ole kokonaislukutyyppiä"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C kieltää nollan kokoisen taulukon %qE"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C kieltää nollan kokoisen taulukon"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "taulukon %qE koko on negatiivinen"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "nimettömän taulukon koko on negatiivinen"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "taulukon %qE koko on liian suuri"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "nimettömän taulukon koko on liian suuri"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "tyyppinimi esitelty funktion palauttavana funktiona"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE esitelty taulukon palauttavan funktiona"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "tyyppinimi esitelty taulukon palauttavan funktiona"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, fuzzy, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "funktion määrittely oikeuttaa tyhjän paluutyypin"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, fuzzy, gcc-internal-format
 #| msgid "cast specifies function type"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "tyyppimuunnos määrittää funktiotyypin"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "epäkelpo vektorityyppi attribuutille %qs"
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs määritelty nimettömälle parametrille"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs määritelty tietueen kentälle %qE"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs määritelty tietueen kentälle"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "bittikentällä %qs on epäkelpo tyyppi"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "bittikentällä %qs on epäkelpo tyyppi"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "kohdistusta ei voi määrittää %q+D:lle"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "Funktio %qs:"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "%Jtypedef %qD esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "%Jtypedef %qD esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C kieltää const- ja volatile-funktiotyypit"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "muuttuja tai kenttä %qE esitelty voidiksi"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "kenttä %qE esitelty funktiona"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "kentällä %qs on vaillinainen tyyppi"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "epäkelpo tallennusluokka funktiolle %qE"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "%<static%>-määreellä esitelty muuttuja esitelty uudelleen %<extern%>-tyyppiseksi"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "funktion esittely ei ole prototyyppi"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "parametrien nimet (ilman tyyppejä) funktion esittelyssä"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "parametrilla %u (%q+D) on vaillinainen tyyppi"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "parametrilla %u in vaillinainen tyyppi"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "parametrin %u (%q+D) tyyppi on void"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "parametrin %u tyyppi on void"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, fuzzy, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%>:in on oltava ainoa parametri"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "parametrilla %q+D on vain etukäteisesittely"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "%<%s %E%> esitelty parametriluettelon sisällä"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "nimetön %s esitelty parametriluettelon sisällä"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "näkyvyysalue on vain tämä määrittely tai esittely, mikä ei todennäköisesti ole sitä, mitä halusit"
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "struct määritelty täällä"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "union määritelty täällä"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%> uudelleenmääritelty"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%> uudelleenmääritelty"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "sisäkkäinen %<union %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "sisäkkäinen %<struct %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "esittely ei esittele mitään"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ei tue nimettömiä structeja/unioneita"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ei tue nimettömiä structeja/unioneita"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "unionilla ei ole nimettyjä jäseniä"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "unionilla ei ole jäseniä"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "structilla ei ole nimettyjä jäseniä"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "structilla ei ole jäseniä"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr "joustava taulukkojäsen muuten tyhjässä structissa"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "pyydetty kohdistus on liian suuri"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "unionista ei voi tehdä läpinäkyvää"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "sisäkkäinen %<enum %E%>:n uudelleenmäärittely"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "luetellun tyypin arvot ylittävät suurimman kokonaisluvun arvoalueen"
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "annettu tila on liian pieni luetelluille arvoille"
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "ylivuoto luetellun tyypin arvoissa"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C rajoittaa luetellun tyypin arvot %<int%>-tyypin arvoalueelle"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "paluutyyppi on oletuksena %<int%>"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "%qD:lle ei ole edellistä prototyyppiä"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD käytössä ilman prototyyppiä ennen sen määrittelyä"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD:lle ei ole edellistä esittelyä"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD on tavallisesti ei-staattinen funktio"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "vanhanmallisia parametriesittelyitä prototyypitetyssä funktiomäärittelyssä"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "perinteinen C ei hyväksy ISO C -tyylisiä funktiomäärittelyitä"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "parametrin nimi jätetty pois"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "vanhanmallinen funktiomäärittely"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "parametrin nimi puuttuu parametriluettelosta"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD esitelty ei-parametrina"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "useita parametreja nimellä %qD"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%qD:n oletustyyppi on %<int%>"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "parametrin %qD tyyppi on vaillinainen"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "argumenttien määrä ei vastaa sisäistä prototyyppiä"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "argumenttien määrä ei vastaa prototyyppiä"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "prototyypin esittely"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "ylennetty argumentti %qD ei vastaa sisäistä prototyyppiä"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "ylennetty argumentti %qD ei vastaa prototyyppiä"
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argumentti %qD ei vastaa sisäistä prototyyppiä"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumentti %qD ei sovi prototyyppiin"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametri %qD on alustettu"
@@ -29838,204 +29870,204 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%>-silmukan alkuesittelyt ovat sallittuja vain C99-tilassa"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99 or -std=gnu99 to compile your code"
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "käytä valitsinta -std=c99 tai -std=gnu99 koodisi kääntämiseen"
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "staattisen muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<extern%>-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
 # XXX: alkuesittely
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE:n kaksoiskappale"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "yli yksi tietotyyppi esittelymääritteissä"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> on liian pitkä GCC:lle"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 ei tue kompleksityyppejä"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C ei tue kompleksikokonaiskulutyyppejä"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 ei tue kompleksityyppejä"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C90 ei tue tyyppiä %<long long%>"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C ei tue kompleksikokonaiskulutyyppejä"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE ei ole esittelyn alussa"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "käytetty sekä %<__thread%> että %<auto&>"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "käytetty sekä %<__thread%> että %<register%>"
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "käytetty sekä %<__thread%> että %<typedef%>"
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "käytetty %<__thread%> ennen %<static%>:a"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "käytetty sekä %<__thread%> että %qs"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "käytetty sekä %<__thread%> että %<auto&>"
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ei tue pelkkää %<complex%>-tyyppiä merkityksellä %<double complex%>"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ei tue kompleksikokonaislukutyyppejä"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -30045,7 +30077,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr "tunniste %qE on ristiriidassa C++:n varatun sanan kanssa"
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "päättämätön muotoilumerkkijono"
@@ -30065,8 +30097,8 @@
 msgid "unknown type name %qE"
 msgstr "tuntematon konetila %qs"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
@@ -30081,7 +30113,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
@@ -30159,7 +30191,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "odotettiin merkkijonoliteraalia"
@@ -30217,14 +30249,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "odotettu tunniste"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "luetellun tyypin luettelon lopussa on pilkku"
@@ -30679,32 +30711,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "<tuntematon operaattori>"
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "puuttuva %<(%> ilmaisun %<#pragma pack%> jälkeen - jätetään huomiotta"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "puuttuva %<(%> ilmaisun %<#pragma pack%> jälkeen - jätetään huomiotta"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
@@ -30714,47 +30746,47 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "väärinmuodostettu #pragma GCC pch_preprocess, jätetään huomiotta"
@@ -30770,12 +30802,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr ""
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -30786,28 +30818,28 @@
 msgid "expression must be integral"
 msgstr ""
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a constant"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
@@ -30841,17 +30873,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr "odotettiin %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> tai %<max%>"
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr ""
@@ -30874,12 +30906,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -30899,17 +30931,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid dist_schedule kind"
@@ -30920,60 +30952,60 @@
 msgid "invalid proc_bind kind"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<namespace%>"
 msgid "expected %<#pragma acc%> clause"
 msgstr "odotettiin %<namespace%>"
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "käytetty sekä %<__thread%> että %qs"
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid pragma"
 msgstr "virheellinen #pragma %s"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -30983,17 +31015,17 @@
 msgid "expected %<(%> or end of line"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
@@ -31003,17 +31035,17 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
@@ -31020,230 +31052,230 @@
 msgstr "odotettiin %<operator%>"
 
 # XXXXXXX
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "leveä merkkijonovakio %<asm%>-lauseessa"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "odotettiin %<decltype%>"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr "odotettiin %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> tai %<max%>"
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration"
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "edellinen esittely"
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<omp_priv%> or function-name"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%qs määrittää %<auto%>:n tiedostoalue-esittelyssä"
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%Jparametrin %qD tyyppi on vaillinainen"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, fuzzy, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "pyydetty kohdistus ei ole kahden potenssi"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, fuzzy, gcc-internal-format
 #| msgid "case label is not an integer constant expression"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "case-nimiö ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "odotettiin luokan nimeä"
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma%> ei ole sallittu täällä"
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, gcc-internal-format
 msgid "base of array section must be pointer or array type"
 msgstr ""
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 msgid "array notations cannot be used with function type"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 msgid "expected array notation expression"
 msgstr "vektoriylivuoto lausekkeessa"
@@ -31253,7 +31285,7 @@
 msgid "%qD has an incomplete type"
 msgstr "%qD on vaillinaista tyyppiä"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void-lausekkeen epäkelpo käyttö"
@@ -31360,7 +31392,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "taulukon indeksi ei ole kokonaisluku"
@@ -31483,7 +31515,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "funktion %2$qE argumentti %1$d annetaan etumerkillisenä prototyypin takia"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
@@ -31514,7 +31546,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -31601,7 +31633,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
@@ -31637,7 +31669,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "ehtolausekkeessa on osoitin/kokonaislukutyyppiristiriita"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, fuzzy, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
@@ -31723,7 +31755,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "tyyppimuunnos %qT-tyyppisestä funktiokutsusta yhteensopimattomaan tyyppiin %qT"
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "tyyppimuunnos erikokoisesta kokonaisluvusta osoittimeksi"
@@ -31883,7 +31915,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, fuzzy, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
@@ -32020,7 +32052,7 @@
 msgid "initialization of a flexible array member"
 msgstr "joustavan taulukkojäsenen alustus"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "merkkitaulukon alustus leveästä merkkijonosta"
@@ -32066,7 +32098,7 @@
 msgid "invalid initializer"
 msgstr "epäkelpo alustin"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "läpinäkymättömiä vektorityyppejä ei voida alustaa"
@@ -32211,7 +32243,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%>-esitellyllä funktiolla on %<return%>-lause"
@@ -32221,7 +32253,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -32329,17 +32361,17 @@
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "Varoita eri enum-tyyppien vertailusta"
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "liukulukujen vertailu operaattoreilla == ja != on epävarmaa"
@@ -32390,12 +32422,12 @@
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
@@ -32420,86 +32452,86 @@
 msgid "used vector type where scalar is required"
 msgstr "käytetty tietuetyypin arvoa, vaikka vaaditaan skalaari"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -32509,17 +32541,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -32529,7 +32561,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
@@ -32539,17 +32571,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
@@ -32564,48 +32596,48 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qs-attribuuttia ei huomioida %qs:lle"
@@ -32617,34 +32649,34 @@
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 msgid "  no known conversion from %qT to %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, fuzzy, gcc-internal-format
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -32651,83 +32683,83 @@
 msgstr[0] "  ehdokas odottaa %d argumenttia, %d annettu"
 msgstr[1] "  ehdokas odottaa %d argumenttia, %d annettu"
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, gcc-internal-format
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr ""
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, fuzzy, gcc-internal-format
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "<sisäinen>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, fuzzy, gcc-internal-format
 msgid "%s%D(%T) <built-in>"
 msgstr "<sisäinen>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, gcc-internal-format
 msgid "%s%T <conversion>"
 msgstr ""
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr ""
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr ""
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr ""
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, gcc-internal-format
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr ""
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
@@ -32734,217 +32766,217 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr ""
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr ""
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "<tuntematon operaattori>"
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "<tuntematon operaattori>"
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%J%s %<%c%s%>"
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ kieltää ?:-lausekkeen käytön ilman keskimmäistä termiä"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, fuzzy, gcc-internal-format
 msgid "non-placement deallocation function %q+D"
 msgstr "Funktio %qs:"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr ""
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr ""
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr ""
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr ""
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "annettu NULL funktion %2$qD ei-osoitinargumenttina %1$P"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "muunnetaan %<false%> osoitintyyppiksi %2$qD:n argumentissa %1$P"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "muunnetaan %<false%> osoitintyyppiksi %qT"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "liikaa aaltosulkeita %qT:n alustimen ympärillä"
@@ -32951,32 +32983,32 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, fuzzy, gcc-internal-format
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr "ei voi muuntaa tyypistä %qT tyyppiin %qT (%s)"
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, fuzzy, gcc-internal-format
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, gcc-internal-format
 msgid "  initializing argument %P of %q+D"
 msgstr "  alustettaessa funktion %2$q+D argumenttia %1$P"
@@ -32983,221 +33015,221 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, fuzzy, gcc-internal-format
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "ei voi muuntaa tyypistä %qT tyyppiin %qT (%s)"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, fuzzy, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-trivially-copyable type %q#T through %<...%>"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi välittää %<...%>:n kautta"
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
 # XXX
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "%Hswitch-lauseesta puuttuu default-nimike"
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, fuzzy, gcc-internal-format
 msgid "  in call to %q+D"
 msgstr "%J%qD esitelty turhaan uudestaan"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr ""
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "muodostimia ei voi esitellä virtuaalisiksi"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr " ehdokas 1: %q+#F"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr " ehdokas 2: %q+#F"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++:n mukaan nämä ovat moniselitteisiä siitä huolimatta, että ensimmäisen huonoin muunnos on parempi kuin toisen huonoin:"
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
@@ -33354,7 +33386,7 @@
 msgid "  by %q+D"
 msgstr ""
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
@@ -33365,7 +33397,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr ""
@@ -33375,7 +33407,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr ""
@@ -33508,68 +33540,78 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  mutta ei ylikuormitusta %<operator=(const %T&)%>"
 
-#: cp/class.c:4538
+#: cp/class.c:4300
 #, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, fuzzy, gcc-internal-format
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
+
+#: cp/class.c:4557
+#, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "%q+D-funktion paluuarvon tyyppi ei ole %<int%>"
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q#T ei ole luokka"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has volatile type"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "luokalla %q#T on virtuaalifunktioita ja käytettävissä oleva epävirtuaalinen hajotin"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr ""
@@ -33576,102 +33618,102 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T uudelleenmääritelty"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "luokalla %q#T on virtuaalifunktioita ja käytettävissä oleva epävirtuaalinen hajotin"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
@@ -33681,12 +33723,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr ""
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr ""
@@ -33726,260 +33768,260 @@
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, fuzzy, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "alustamaton const %qD"
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, fuzzy, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, fuzzy, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
 msgid "call to internal function"
 msgstr "sisäinen funktio"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "esittely ei esittele mitään"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, fuzzy, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "Funktio %qs:"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%J%qD käytössä ilman prototyyppiä ennen määrittelyänsä"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, fuzzy, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "protokollalla %qE on kehäriippuvuus"
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, fuzzy, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 msgid "array subscript out of bound"
 msgstr "taulukon indeksi ei ole kokonaisluku"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "negative array subscript"
 msgstr "Odotettiin taulukkoindeksiä kohdassa %C"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "parametri %qD on alustettu"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant-expression"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast-muunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant-expression"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, fuzzy, gcc-internal-format
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, fuzzy, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant-expression"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "ei-vakio taulukon indeksi alustimessa"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "vektoriylivuoto lausekkeessa"
@@ -34050,7 +34092,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr ""
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr ""
@@ -34091,7 +34133,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -34101,292 +34143,292 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr ""
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr ""
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr ""
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr ""
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr ""
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "epäkelpo %qs:n soveltaminen vaillinaiseen tyyppiin %qT "
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, fuzzy, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, fuzzy, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, fuzzy, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "ei-liukulukuargumentti funktiolle %qs"
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "ei-liukulukuargumentti funktiolle %qs"
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, fuzzy, gcc-internal-format
 msgid "statement has no effect"
 msgstr "lauseella ei ole vaikutusta"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, fuzzy, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "%Juseita parametreja nimellä %qD"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "ei-yksiselitteinen oletustyyppimuunnos tyypistä %qT"
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -34809,241 +34851,241 @@
 msgid "template parameters do not match template %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr "anonyymillä structilla ei voi olla funktiojäseniä"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr "anonyymillä unionilla ei voi olla funktiojäseniä"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T:n attribuutin on oltava %qs-avainsanan perässä"
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "useita tyyppejä yhdessä esittelyssä"
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "C++:n sisäinen tietotyyppi %qT määritelty uudelleen"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "tyypin nimi puuttuu typedef-esittelystä"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ kieltää nimettömät structit"
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD on alustettu (käytä __typeof__ sen sijaan)"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration %q+D"
 msgid "non-member-template declaration of %qD"
 msgstr "malliesittelylle %q+D"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration %q+D"
 msgid "does not match member template declaration here"
 msgstr "malliesittelylle %q+D"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr ""
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr ""
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "tallennusluokka %<thread_local%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%J%qF käytetty, mutta ei määritelty"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "muuttujalla %q#D on alustin, mutta vaillinaista tyyppiä"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "taulukon %q#D alkiot ovat vaillinaista tyyppiä"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D:n esittelyllä ei ole alustimia"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD esitelty viitteenä, mutta ei ole alustettu"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD-taulukon koko puuttuu"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "nollan kokoinen taulukko %qD"
@@ -35051,830 +35093,830 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "%qD:n koko muistissa ei ole tunnettu"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "%qD:n koko muistissa ei ole vakio"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, fuzzy, gcc-internal-format
 #| msgid "  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "  voit kiertää tämän poistamalla alustimen"
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "alustamaton const %qD"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "alustamaton const %qD"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "epäkelpo alustin"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "liikaa alustimia %qT:lle"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "alustimen ympäriltä puuttuu aaltosulkeet"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "taulukon %qD alkioilla on vaillinainen tyyppi"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "muuttuvakokoinen yhdysliteraali"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D on vaillinaista tyyppiä"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalaariobjekti %qD vaatii yhden alkion alustimeensa"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "C++98:ssa %qD on alustettava muodostimessa, ei käyttäen %<{...}%>"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "taulukko %qD alustettu sulkujen sisällä olevalla merkkijonoliteraalilla %qE"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%q+D on yleensä funktio"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr ""
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "funktio %q#D alustetaan kuin muuttuja"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "taulukon %q+D koko puuttuu"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "nollan kokoinen taulukko %qD"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "kenttä %qs esitelty funktiona"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> variable"
 msgstr "%q+D esitelty ei-parametrina"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%q+D esitelty ei-parametrina"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%q+D esitelty ei-parametrina"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "kenttä %qs esitelty funktiona"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%q+D esitelty ei-parametrina"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "kenttä %qs esitelty funktiona"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "kenttä %qs esitelty funktiona"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, gcc-internal-format
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %q#D declared with type qualifiers"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %q#D declared with type qualifiers"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "virheellinen IACC-argumentti"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "typedef %q+D määritelty uudelleen"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, fuzzy, gcc-internal-format
 msgid "%q+#D explicitly defaulted here"
 msgstr "%q+#D määritelty aiemmin täällä"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
 # semi-fuzzy
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "taulukon %qD koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "taulukon koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "taulukon %qD koko on negatiivinen"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "taulukon koko on negatiivinen"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ kieltää muuttuvakokoisen taulukon %qD"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ kieltää muuttuvakokoisen taulukon"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "taulukon koon ylivuoto"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qD:n esittely void-taulukkona"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "luodaan void-taulukko"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qD:n esittely funktioiden taulukkona"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "luodaan funktioiden taulukko"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qD:n esittely viitteiden taulukkona"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "luodaan viitteiden taulukko"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qD:n esittely funktiojäsenten taulukkona"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "luodaan funktiojäsenten taulukkoa"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "nimetön muuttuja tai kenttä esitelty voidiksi"
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "muuttuja tai kenttä esitelty voidiksi"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "määrittelemättömän tyypin %<%s %s%> epäkelpo käyttö"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "määrittelemättömän tyypin %<%s %s%> epäkelpo käyttö"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "määrittelemättömän tyypin %<%s %s%> epäkelpo käyttö"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T ei ole luokka eikä nimiavaruus"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "funktion määrittely ei esittele parametrejä"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "tyhjä esittely"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "%J%qD:n esittely varjostaa parametria"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ei tue pelkkää %<complex%>-tyyppiä merkityksellä %<double complex%>"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ kieltää muuttujan %qs esittelyn ilman tyyppiä"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> tai %<unsigned%> virheellinen %qs:lle"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "sekä %<signed%> että %<unsigned%> määritelty %qs:lle"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> virheellinen %qs:lle"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> virheellinen %qs:lle"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> tai %<short%> virheellinen %qs:lle"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, fuzzy, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "sekä %<long%> että %<short%> esittelymääritteissä"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr ""
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "sekä %<long%> että %<short%> määritelty %qs:lle"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> tai %<long%> virheellinen %qs:lle"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr ""
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "tallennusluokka annettu malliparametrille %qs"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> luokan esittelyn ulkopuolella"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "useita tallennusluokkia %qs:n esittelyssä"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "funktioalue %qs implisiittisesti auto ja esitelty %<__thread%>:ksi"
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs esitelty taulukon palauttavan funktiona"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
@@ -35881,476 +35923,476 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "muodostimia ei voi esitellä virtuaalisiksi"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr "muodostimia ei voi esitellä virtuaalisiksi"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hajottimilla ei voi olla parametreja"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr ""
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "taulukon %qs koko on liian suuri"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> luokan esittelyn ulkopuolella"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "vain muodostimen esittely voi olla %<explicit%>"
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "virheelliset määreet ei-jäsenfunktion tyypissä"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared %<auto%>"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr ""
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%J%qD:n esittely varjostaa parametria"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr ""
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "%qD esitelty staattisesti sisäkkäin"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "funktion määrittely esitelty %<__thread%>:ksi"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "kentällä %qD on vaillinainen tyyppi"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "tallennusluokka %<auto%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "tallennusluokka %<register%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "tallennusluokka %<__thread%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "tallennusluokka %<thread_local%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, fuzzy, gcc-internal-format
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs on sekä %<extern%> että alustin"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "vaillinaisen tyypin typedef %qD epäkelpo käyttö"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "parametrilla %qD on Java-luokkatyyppi"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -36370,173 +36412,173 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "virheellinen muodostin; tarkoitit todennäköisesti %<%T (const %T&)%>"
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ kieltää ?:-operaattorin ylikuormituksen"
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD:lla ei saa olla vaihtuvaa määrää argumentteja"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr "%qD:n on otettava joko nolla tai yksi argumenttia"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr "%qD:n on otettava joko yksi tai kaksi argumenttia"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr ""
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr "%qD:n on otettava tasan yksi argumentti"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "%qD:n on otettava tasan kaksi argumenttia"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, fuzzy, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -36548,88 +36590,88 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD:llä on sama nimi kuin luokalla, jossa se on esitelty"
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "edellinen esittely %q+D"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr ""
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr ""
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "edellinen määrittely täällä"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr ""
@@ -36638,87 +36680,87 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr "paluutyypillä on Java-luokkatyyppi %q#T"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "%q+D:lle ei ole edellistä esittelyä"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "virheellinen funktioesittely"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr ""
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-tyhjän"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "funktion paluuarvojen tyypit eivät ole yhteensopivia %<volatile%>:n takia"
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D set but not used"
 msgstr "nimike %q+D määritelty mutta käytettämättä"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "virheellinen jäsenfunktioesittely"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%q+D:n oletustyyppi on %<int%>"
@@ -36758,7 +36800,7 @@
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr ""
@@ -36781,7 +36823,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -36873,27 +36915,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "bittikentän %qs leveys ei ole kokonaislukuvakio"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%>:n on palautettava tyyppi %qT"
@@ -36902,47 +36944,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%>:n ensimmäisen parametrin tyypin on oltava %<size_t%> (%qT)"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%>:n ensimmäisen parametrin tyypin on oltava %qT"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using anonymous type, is used but never defined"
 msgstr "%J%qF käytetty, mutta ei määritelty"
@@ -36951,47 +36993,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%J%qF käytetty, mutta ei määritelty"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr ""
@@ -36998,12 +37040,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
@@ -37581,42 +37623,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr ""
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -37747,17 +37789,17 @@
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, gcc-internal-format
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, gcc-internal-format
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
@@ -38175,7 +38217,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr "tunniste %qE on ristiriidassa C++:n varatun sanan kanssa"
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -38200,7 +38242,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "pyyntö jäsenen %qs käsittelyyn jossain, joka ei ole tietue tai unioni"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> on esittelemättä"
@@ -38265,7 +38307,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ei ole malli"
@@ -38290,7 +38332,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "liukulukuylivuoto lausekkeessa"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -38559,7 +38601,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
@@ -38735,7 +38777,7 @@
 msgid "capture of non-variable %qD "
 msgstr "kirjoitussuojatun muuttujan %qD kasvatus"
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, fuzzy, gcc-internal-format
 msgid "%q+#D declared here"
 msgstr "%q+D esitelty täällä"
@@ -38795,7 +38837,7 @@
 msgid "compound-statement in constexpr function"
 msgstr ""
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "tyhjä esittely"
@@ -38825,7 +38867,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "tyhjä esittely"
@@ -38856,12 +38898,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ kieltää lasketut goto-käskyt"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "tyhjä esittely"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "ylimääräinen %<;%>"
@@ -38908,7 +38950,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "mallit eivät voi olla virtuaalisia"
@@ -38999,12 +39041,12 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
@@ -39019,7 +39061,7 @@
 msgid "expected template-id"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "odotettiin %<<%>"
@@ -39096,210 +39138,210 @@
 msgid "expected type specifier"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C kieltää parametrien ennakkoesittelyn"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "odotettiin luokan nimeä"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "esittely %qD ei esittele mitään"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an enumerator-name"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C++ kieltää enumin lisäyksen"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "odotettiin luokan nimeä"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "Funktio %qs:"
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, fuzzy, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "indeksoitu arvo on osoitin funktioon"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "%Jsisäänrakennettu funktio %qD esitelty ei-funktiona"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> ei ole tyyppi"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -39308,7 +39350,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
@@ -39315,293 +39357,293 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "%Hprototyypin esittely"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD on nimiavaruus"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "cv-määreen kaksoiskappale"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "cv-määreen kaksoiskappale"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "case-arvon kaksoiskappale"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "virheellinen IACC-argumentti"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "odotettiin %<,%> tai %<...%>"
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr ""
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr ""
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C90 ei tue joustavia taulukkojäseniä"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "odotettiin luokan nimeä"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "Käytä AltiVec-käskyjä"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "Käytä AltiVec-käskyjä"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "odotettiin %<{%> tai %<:%>"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr ""
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "esittely ei esittele mitään"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "virheellinen luokan nimi %qD:n esittelyssä"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "odotettiin luokan nimeä"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "pure-tarkenne funktiomäärittelyssä"
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "ylimääräinen %<,%> jäsenesittelyn lopussa"
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr ""
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "Funktio %qs:"
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "%qs attribuuttia ei huomioida"
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "virheellinen %<%T::%E%>:n esittely"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "%J%qD:n edellinen esittely oli täällä"
@@ -39610,544 +39652,544 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "nimetyt paluuarvot eivät ole enää tuettuja"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "tyhjä esittely"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sekä %<_Sat%> että %<char%> esittelymääritteissä"
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "ylimääräinen %qE"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "kaksois-%qs"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "odotettiin %<new%>"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "odotettiin %<delete%>"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "odotettiin %<return%>"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "odotettiin %<extern%>"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "odotettiin %<static_assert%>"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "odotettiin %<decltype%>"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "odotettiin %<operator%>"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "odotettiin %<namespace%>"
 
 # XXXXXXX
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "leveä merkkijonovakio %<asm%>-lauseessa"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "odotettiin luokan nimeä"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%Jviimeksi käytetty täällä"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%J%qD esitelty uudelleen erityyppisenä symbolina"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
 # XXX
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "%Hswitch-lauseesta puuttuu default-nimike"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "epäkelpo vektorityyppi attribuutille %qs"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qs-attribuuttia ei huomioida %qs:lle"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "void-lausekkeen epäkelpo käyttö"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected positive integer expression"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, gcc-internal-format
 msgid "not enough collapsed for loops"
 msgstr ""
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, fuzzy, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "odotettiin %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> tai %<max%>"
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "roskaa ilmaisun %<#pragma GCC pch_preprocess%> lopussa"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "Odotettiin muuttujanimeä kohdassa %C"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "mallit eivät voi olla virtuaalisia"
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr ""
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, fuzzy, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr "%J%qD määritelty uudelleen"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr ""
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -40154,68 +40196,68 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, fuzzy, gcc-internal-format
 msgid "candidate is: %#D"
 msgstr "ehdokas on: %+#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, fuzzy, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %+#T"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr ""
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, gcc-internal-format
 msgid "too many template headers for %D (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -40222,57 +40264,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, fuzzy, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -40285,92 +40327,92 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr ""
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <nimetön>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "%q+#D:n esittely"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr ""
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "%Jviimeksi käytetty täällä"
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -40377,12 +40419,12 @@
 msgstr[0] "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 msgstr[1] "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -40390,42 +40432,42 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%Jparametrin nimi puuttuu parametrilistasta"
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr ""
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -40435,57 +40477,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr ""
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -40492,7 +40534,7 @@
 msgstr[0] "%J%qD:n edellinen esittely oli täällä"
 msgstr[1] "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q+D used %d template parameter"
 msgid_plural "previous declaration %q+D used %d template parameters"
@@ -40499,12 +40541,12 @@
 msgstr[0] "%J%qD:n edellinen esittely oli täällä"
 msgstr[1] "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "%Juseita parametreja nimellä %qD"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
@@ -40513,102 +40555,102 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr ""
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "funktion määrittely esitelty %<__thread%>:ksi"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "%Juseita parametreja nimellä %qD"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -40617,173 +40659,173 @@
 msgstr[0] "  ehdokas odottaa %d argumenttia, %d annettu"
 msgstr[1] "  ehdokas odottaa %d argumenttia, %d annettu"
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "tyyppi %qT ei periydy %qT-tyypistä"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, fuzzy, gcc-internal-format
 msgid "  could not resolve address from overloaded function %qE"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT "
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr ""
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr ""
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  odotettiin %qT-tyyppistä vakiota, saatiin %qT"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  odotettiin luokkamallia, saatiin %qE"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  odotettiin tyyppiä, saatiin %qE"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "muotoilu %q.*s edellyttää %<%T%s%>-tyyppiä, mutta %d. argumentin tyyppi on %qT"
@@ -40790,77 +40832,77 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr ""
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "attribuutille %qs annettu väärä määrä argumentteja"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr ""
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr ""
@@ -40878,267 +40920,267 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "muuttujalla %qD on funktiotyyppi"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "esittelyssä %q+D"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "taulukon palauttava funktio"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion palauttava funktio"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%Jcase-arvo %qs ei ole luetellussa tyypissä"
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "käytetään virheellistä kenttää %qD"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void-lausekkeen epäkelpo käyttö"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared here, later in the translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr "%qT on/käyttää anonyymiä tyyppiä"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr ""
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 msgid "%s %#S"
 msgstr "%s %+#T"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
@@ -41150,62 +41192,62 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ei voi emuloida %qs"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "ei voi emuloida %qs"
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
@@ -41443,261 +41485,261 @@
 msgid "invalid base-class specification"
 msgstr ""
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%Jcase-arvo %qs ei ole luetellussa tyypissä"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "tarpeeton tyyppimääre tyhjässä esittelyssä"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, fuzzy, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<num_teams%> expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr ""
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparametrin %qD tyyppi on vaillinainen"
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "staattinen väite epäonnistui: %s"
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "ei-vakio ehto staattiselle väitteelle"
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -41712,117 +41754,117 @@
 msgid "lambda-expression in a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr ""
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr ""
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr "%qE on vanhentunut; g++:n vtable'it ovat nyt oletusarvoisesti COM-yhteensopivia"
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr ""
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qs-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -42015,476 +42057,471 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr ""
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr ""
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ kieltää %<::main%>-funktion kutsumisen ohjelmasta"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "kenttä %qs esitelty funktiona"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "liian vähän argumentteja funktiolle %qE"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "liian monta argumenttia funktiolle %qE"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "liian vähän argumentteja funktiolle %qE"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "liian monta argumenttia funktiolle %qE"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "liian vähän argumentteja funktiolle %qE"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "liian vähän argumentteja funktiolle %qE"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "liikaa argumentteja funktiolle"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "liian vähän argumentteja funktiolle"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL-arvon käyttö laskutoimituksessa"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "vasemmalle kierron laskuri on negatiivinen"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "oikealle kierron laskuri on negatiivinen"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr "vertailu merkkijonoliteraaliin johtaa määrittelemättömään toimintaan"
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "%qD:n osoite ei tule koskaan olemaan NULL"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ kieltää osoittimen ja kokonaisluvun vertailun"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr ""
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ kieltää %<void *%>-tyyppisen osoittimen käytön vähennyslaskussa"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ kieltää funktio-osoittimen käytön vähennyslaskussa"
 
 # semi-fuzzy; onko metodi tässä luokan jäsenfunktio ja yllä muu funktio?
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qE"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qE"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr ""
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ kieltää %<::main%>-funktion osoitteen ottamisen"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr ""
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ kieltää enumin lisäyksen"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ kieltää enumin vähentämisen"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ kieltää %qT-tyyppisen osoittimen kasvattamisen"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ kieltää %qT-tyyppisen osoittimen vähentämisen"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "virheellinen loogisen lausekkeen käyttö operandina %<operator--%>:lle"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "tyyppimuunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast-muunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast-muunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, gcc-internal-format
 msgid "useless cast to type %qT"
 msgstr "tarpeeton tyyppimuunnos tyyppiin %qT"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "virheellinen static_cast-muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr "muunnoksessa tyypistä %qT tyyppiin %qT menetetään tarkkuutta"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "muunnos tyypistä %qT tyyppiin %qT kasvattaa kohdetyypin vaadittua kohdistusta"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ kieltää tyyppimuunnoksen funktio-osoittimen ja olio-osoittimen välillä"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "virheellinen const_cast tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ kieltää tyyppimuunnoksen taulukkotyyppiin %qT"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "ei-vakio taulukon indeksi alustimessa"
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "vaillinaiset tyypit %qT:n sijoituksessa tyyppiin %qT"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "taulukkoa käytetty alustimena"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "virheellinen taulukkosijoitus"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
@@ -42491,7 +42528,7 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "ei voi muuntaa tyypistä %qT tyyppiin %qT (%s)"
@@ -42498,7 +42535,7 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "ei voi muuntaa tyypistä %qT tyyppiin %qT (%s)"
@@ -42505,7 +42542,7 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "ei voi muuntaa tyypistä %qT tyyppiin %qT (%s)"
@@ -42512,7 +42549,7 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "ei voi muuntaa tyypistä %qT tyyppiin %qT (%s)"
@@ -42519,74 +42556,74 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "ei voi muuntaa tyypistä %qT tyyppiin %qT (%s)"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr ""
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr "palautettu viittaus paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %q+D returned"
 msgstr "palautettu osoite paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr "palautettu osoite paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "arvon palautus hajottimesta"
@@ -42593,45 +42630,45 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "arvon palautus muodostimesta"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "arvo return-lauseelle funktiossa, jonka paluutyyppi on ”void”"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> ei saa palauttaa NULLia ellei esittely ole %<throw()%> (tai -fcheck-new ole voimassa)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -42860,125 +42897,125 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "%qE:n kaventava muunnos tyypistä %qT tyyppiin %qT { }:n sisällä"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-taulukko alustettu epäleveästä merkkijonosta"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-taulukko alustettu yhteensopimattomasta leveästä merkkijonosta"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "merkkitaulukon alustusmerkkijono on liian pitkä"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "puuttuva alustin jäsenelle %qD"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member %qD"
 msgid "member %qD with uninitialized reference fields"
 msgstr "alustamaton viitejäsen %qD"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "alustettavassa unionissa ei ole kenttää %qD"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -43159,8 +43196,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -43295,7 +43332,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -43418,7 +43455,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava INTEGER tai PROCEDURE"
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -44050,12 +44087,12 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "kääntäjänsisäisen ”shape”-funktion argumentti ”source” kohdassa %L ei saa olla oletetun kokoinen taulukko"
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
@@ -44335,6 +44372,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava INTEGER tai LOGICAL"
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -44342,7 +44384,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -44568,405 +44610,405 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL()-alustus kohdassa %C on moniselitteinen"
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "Function name %qs not allowed at %C"
 msgstr "Funktionimi ”%s” ei ole sallittu kohdassa %C"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Alustus kohdassa %C ei ole osoitinmuuttuja"
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, fuzzy, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Odotettiin alustuslauseketta kohdassa %C"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Vanhantyylinen esittely %s*%d ei ole tuettu kohdassa %C"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Ei-vakio tyyppiesittely %s*%d kohdassa %C"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Puuttuva oikea sulje kohdassa %C"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Odotettiin alustuslauseketta kohdassa %C"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Odotettiin skalaarialustuslauseketta kohdassa %C"
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Syntaksivirhe CHARACTER-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "Fortran 2003: CLASS-lause kohdassa %C"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Tyyppinimi ”%s” kohdassa %C ei ole yksiselitteinen"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Puuttuva ulottuvuusspesifikaatio kohdassa %C"
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Puuttuva ulottuvuusspesifikaatio kohdassa %C"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Kaksoiskappele %s attribuutti kohdassa %L"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s-attribuutti kohdassa %L ei ole sallittu moduulin spesifikaatio-osan ulkopuolella"
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "ylimääräinen %<restrict%>"
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED kohdassa %C on sallittu vain moduulin spesifikaatio-osassa"
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "ylimääräinen %<restrict%>"
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "ylimääräinen %<restrict%>"
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Useita tunnisteita tarjottu yhdellä NAME= tarkenteella kohdassa %C"
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -44974,818 +45016,824 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr ""
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Syntaksivirhe data-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Odotettiin vaihtoehtoista paluunimiötä kohdassa %C"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Nimi ”%s” kohdassa %C on proseduurin nimi"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Odottamatonta roskaa muodollisessa argumenttiluettelossa kohdassa %C"
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Kaksoiskappalesymboli ”%s” muodollisessa argumenttiluettelossa paikassa %C"
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT-muuttujan paikassa %C on oltava erilainen kuin funktionimen"
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Odottamatonta roskaa funktioesittelyn jälkeen kohdassa %C"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Odotettiin ”::” binding-attribuutin jälkeen kohdassa %C"
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Syntaksivirhe proseduuriosoitinkomponentissa kohdassa %C"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Odotetiin muodollista argumenttiluetteloa funktiomäärittelyssä kohdassa %C"
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:5597
-#, gcc-internal-format
-msgid "gfc_match_entry(): Bad state"
-msgstr ""
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Unexpected END statement at %C"
+msgid "Unexpected ENTRY statement at %C"
+msgstr "Odottamaton END-lause kohdassa %C"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Useita tunnisteita tarjottu yhdellä NAME= tarkenteella kohdassa %C"
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Sitomisnimeä ei ole sallittu BIND(C):ssä kohdassa %C"
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Odottamaton END-lause kohdassa %C"
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "Ei välitetä lausenimiöstä tyhjässä lauseessa kohdassa %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Odotettiin %s-lausetta kohdassa %C"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Odotettiin ”%s”-lohkonimeä %s-lauseessa kohdassa %C"
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Odotettiin päättävää nimeä kohdassa %C"
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Odotettiin nimiötä ”%s” %s-lauseelle kohdassa %C"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr ""
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Odottamaton merkki muuttujaluettelossa kohdassa %C"
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Odotettiin ”(” kohdassa %C"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Odotettiin muuttujanimeä kohdassa %C"
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray-osoittimen kohdassa %C on oltava kokonaisluku"
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray-osoittimella kohdassa %C on %d-tavun tarkkuus; muistiosoitteet vaativat %d tavua"
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Odotettiin ”)” kohdassa %C"
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Odotettiin ”,” tai lauseen loppua kohdassa %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Odotettiin muuttujanimeä kohdassa %C PARAMETER-lauseessa"
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Odotettiin =-merkkiä PARAMETER-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Odotettiin lauseketta kohdassa %C PARAMETER-lauseessa"
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Alustetaan jo alustettu muuttuja kohdassa %C"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Odottamattomia merkkejä PARAMETER-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Syntaksivirhe SAVE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003: VALUE-lause kohdassa %C"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003: VOLATILE-lause kohdassa %C"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Fortran 2003: CLASS-lause kohdassa %C"
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "kokonaislukuylivuoto lausekkeessa"
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Monimerkityksellinen symboli TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "ABSTRACT-tyyppiä ”%s” käytetty kohdassa %L"
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%qD on jo määritelty"
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Enumeraattori ylittää C-kokonaislukutyypin kohdassa %C"
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Syntaksivirhe ENUMERATOR-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Kaksoiskappale pääsy-tarkenne kohdassa %C"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Kaksoiskappale POINTER-attribuutti kohdassa %C"
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Odotettiin sitomisattribuuttia kohdassa %C"
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, fuzzy, gcc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Rajapintanimeä odotettiin merkin ”(” jälkeen kohdassa %C"
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected at %C"
 msgid "%<)%> expected at %C"
 msgstr "”)” odotettiin kohdassa %C"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Odotettiin sitomisnimeä kohteessa %C"
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "Roskaa PROCEDURE-esittelyn jälkeen kohdassa %C"
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Odotettiin sitomiskohteen jälkeen ”=>” kohdassa %C"
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Odotettiin ”::” kohdassa %C"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Odotettiin geneeristä nimeä tai operaattorimäärittelijää kohdassa %C"
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Malformed GENERIC statement at %C"
+msgstr "tyhjä esittely"
+
+#: fortran/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '=>' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Odotettiin ”=>” kohdassa %C"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Odotettiin erityistä sitomisnimeä kohdassa %C"
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "Tuntematon proseduurinimi ”%s” kohdassa %C"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Tuntematon attribuutti !GCC$ ATTRIBUTES-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Syntaksivirhe !GCC$ ATTRIBUTES-lauseessa kohdassa %C"
@@ -46074,350 +46122,350 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a VALUE"
 msgid "%qs at %L is not a VALUE"
 msgstr "”%s” kohdassa %L ei ole VALUE"
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic underflow converting %s to %s at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmeettien alivuoto muunnettaessa %s arvoksi %s kohdassa %L. Tämä tarkistus voidaan ottaa pois käytöstä valitsimella -fno-range-check"
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic overflow converting %s to %s at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmeettinen ylivuoto muunnettaessa %s arvoksi %s kohdassa %L. Tämä tarkistus voidaan ottaa pois käytöstä valitsimella -fno-range-check"
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic NaN converting %s to %s at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmeettinen NaN muunnettaessa %s arvoksi %s kohdassa %L. Tämä tarkistus voidaan ottaa pois käytöstä valitsimella -fno-range-check"
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Conversion from %qs to %qs at %L"
 msgstr "Muunnos tyypistä %s tyyppiin %s kohdassa %L"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Yhteensopimattomat tyypit DATA-lauseessa kohdassa %L; yritettiin muuntaa tyyppi %s tyypiksi %s"
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Käskyfunktio ”%s” on virheellinen proseduuriosoitinsijoituksessa kohdassa %L"
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Käskyfunktio ”%s” on virheellinen proseduuriosoitinsijoituksessa kohdassa %L"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Sisäinen proseduuri ”%s” on virheellinen proseduuriosoittimessa kohdassa %L"
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Eri tyypit osoitinsijoituksessa kohdassa %L; yritettiin tyypin %s sijoitusta tyyppiin %s"
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "ei voi avata syötetiedostoa: %s"
@@ -46439,27 +46487,27 @@
 msgid "Removing call to function %qs at %L"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, fuzzy, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "epäkelpo totuusarvolauseke"
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr ""
@@ -46516,608 +46564,614 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr "Odotettiin 'END INTERFACE ASSIGNMENT (=)' kohdassa %C"
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr "Odotettiin 'END INTERFACE OPERATOR (.%s.)' kohdassa %C"
+
+#: fortran/interface.c:353
+#, fuzzy, gcc-internal-format
+#| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr "Odotettiin 'END INTERFACE OPERATOR (.%s.)' kohdassa %C"
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr "Odotettiin 'END INTERFACE OPERATOR (.%s.)' kohdassa %C"
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE %s' at %C"
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr "Odotettiin 'END INTERFACE %s' kohdassa %C"
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr ""
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr ""
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr ""
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr "Sijoitusoperaattorirajapinta kohdassa %L ei saa määritellä uudelleen INTRINSIC-tyyppisijoitusta"
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr ""
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr ""
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr ""
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, gcc-internal-format
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr ""
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, gcc-internal-format
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr ""
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "%qs at %L is not a module procedure"
 msgstr "Nimi ”%s” kohdassa %C on proseduurin nimi"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Tämänhetkisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L on jo liitetty toiseen varsinaiseen argumenttiin"
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure pointer for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Odotettiin proseduuriosoitinta argumentille ”%s” kohdassa %L"
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Odotettiin proseduuria argumentille ”%s” kohdassa %L"
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Varsinainen argumentti kohteelle ”%s” ei voi olla oletetunkokoinen taulukko kohdassa %L"
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, fuzzy, gcc-internal-format
 #| msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Odotettiin tyyppiriippuvaista proseduuria tai proseduurin osoitinkomponenttia kohdassa %C"
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "ei voi emuloida %qs"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, fuzzy, gcc-internal-format
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr "ei voi kirjoittaa tiedostoon %s: %m"
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
@@ -47532,12 +47586,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
@@ -47547,7 +47601,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
@@ -47572,783 +47626,783 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr ""
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Kaksoiskappalemuotospesifikaatio kohdassa %C"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Kaksoiskappale-NML-spesifikaatio kohdassa %C"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "UNIT ei ole määritelty kohdassa %L"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR-tunnistenimiötä %d kohdassa %L ei ole määritelty"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END-tunnistenimiötä %d kohdassa %L ei ole määritelty"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR-tunnistenimiötä %d kohdassa %L ei ole määritelty"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT-nimiö %d kohdassa %L ei ole määritelty"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Syntaksivirhe siirräntäiteraattorissa kohdassa %C"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Odotettiin lauseketta %s-lauseessa kohdassa %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaksivirhe %s-lauseessa kohdassa %C"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT number in statement at %L must be non-negative"
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
 msgstr ""
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 #| msgid "Missing ')' in statement at or before %L"
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "Puuttuva ”)” lauseessa kohdassa tai ennen kohtaa %L"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 #| msgid "Missing '(' in statement at or before %L"
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "Puuttuva ”(” lauseessa kohdassa tai ennen kohtaa %L"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr "Kokonaisluku liian suuri kohdassa %C"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr ""
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Label name %qs at %C is ambiguous"
 msgstr "Tyyppinimi ”%s” kohdassa %C ei ole yksiselitteinen"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s label specification at %C"
 msgid "Duplicate construct label %qs at %C"
 msgstr "Kaksoiskappale %s-nimiöspesifikaatio kohdassa %C"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr "Virheellinen merkki nimessä kohdassa %C"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr "Nimi kohdassa %C on liian pitkä"
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr ""
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr ""
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr ""
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr "Odotettiin askelarvoa iteraattorissa kohdassa %C"
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, gcc-internal-format, gfc-internal-format
 msgid "gfc_match(): Bad match code %c"
 msgstr ""
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr "Syntaksivirhe IF-lausekkeessa kohdassa %C"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr "Lohkonimiö ei ole sopiva aritmeettiselle IF-lauseelle kohdassa %C"
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr "Lohkonimiö ei ole sopiva IF-lauseelle kohdassa %C"
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr "Ei voi sijoitaa nimettyyn vakioon kohdassa %C"
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr "Luokittelematon lause IF-lauseessa kohdassa %C"
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr "Syntaksivirhe IF-lauseessa kohdassa %C"
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match IF label '%s'"
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "Nimiö ”%s” kohdassa %C ei täsmää IF nimiön ”%s” kanssa"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr "Odottamatonta roskaa ELSE IF -lauseen jälkeen kohdassa %C"
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr ""
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in association at %C"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, fuzzy, gcc-internal-format
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, gcc-internal-format
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "epäkelpo osoitintila %qs"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr ""
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, fuzzy, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement at %C in PURE procedure"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "Fortran 2003: CLASS-lause kohdassa %C"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "epäkelpo osoitintila %qs"
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Odotettiin komponenttiviitettä kohdassa %C"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "Roskaa CALL-lauseen jälkeen kohdassa %C"
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Odotettiin tyyppiriippuvaista proseduuria tai proseduurin osoitinkomponenttia kohdassa %C"
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr ""
@@ -48356,151 +48410,151 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr ""
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "Empty array constructor at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr ""
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Odotettiin alustuslauseketta CASE-lauseessa kohdassa %C"
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, fuzzy, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROTECTED statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Odottamaton CASE-lause kohdassa %C"
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Syntaksivirhe CASE-spesifikaatiossa kohdassa %C"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Odottamaton TYPE IS -lause kohdassa %C"
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Syntaksivirhe TYPE IS -spesifikaatiossa kohdassa %C"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Syntaksvirhe CLASS IS -spesifikaatiossa kohdassa %C"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match IF label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -48652,174 +48706,174 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Ei voi avata moduulitiedostoa ”%s” kirjoittamista varten kohdassa %C: %s"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: virhe kirjoitettaessa tiedostoa ”%s”: %s\n"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file '%s': %s"
 msgid "Can't delete module file %qs: %s"
 msgstr "Ei voida poistaa moduulitiedostoa ”%s”: %s"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "Can't rename module file '%s' to '%s': %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Ei voida nimetä uudelleen moduulitiedostoa ”%s” nimellä ”%s”: %s"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete temporary module file '%s': %s"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Ei voida poistaa tilapäistä moduulitiedostoa ”%s”: %s"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs already declared"
 msgstr "Symboli ”%s” on jo esitelty"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "tyhjä esittely"
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Ei voi avata moduulitiedostoa ”%s” lukemista varten kohdassa %C: %s"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr ""
@@ -49121,7 +49175,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -49832,378 +49886,372 @@
 msgid "Unexpected %s statement at %C"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: fortran/parse.c:2428
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected %s statement in MODULE at %C"
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr "Odottamaton %s-lause MODULE-lohkossa kohdassa %C"
-
-#: fortran/parse.c:2439
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "Odottamaton tiedoston loppu tiedostossa ”%s”"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with SEQUENCE must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "Perityllä tyypillä ”%s” SEQUENCE:lla ei saa olla CONTAINS-lohkoa kohdassa %C"
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with BIND(C) must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "Perityllä tyypillä ”%s” BIND(C):llä ei saa olla CONTAINS-lohkoa kohdassa %C"
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Odottamaton %s-lause INTERFACE-lohkossa kohdassa %C"
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Odottamaton %s-lause kohdassa %C INTERFACE-rungossa"
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "Nimi ”%s” kohdassa %C on proseduurin nimi"
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function '%s' at %L not set"
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Odottamaton %s-lause WHERE-lohkossa kohdassa %C"
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Odottamaton %s-lause FORALL-lohkossa kohdassa %C"
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Kaksoiskappale-ELSE-lauseet kohdissa %L ja %C"
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "Odotettiin CASE- tai END SELECT-lausetta seuraavaa SELECT CASE-lausetta kohdassa %C"
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "Muodostin %qs"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "Muodostin %qs"
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s at %C"
 msgstr "Odotettiin %s-lausetta kohdassa %C"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "Odotettiin ”(” kohdassa %C"
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Odottamaton %s-lause CONTAINS-lohkossa kohdassa %C"
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Name '%s' at %C is already defined as a generic interface at %L"
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Odottamaton %s-lause BLOCK DATA -lohkossa kohdassa %C"
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Odottamaton %s-lause MODULE-lohkossa kohdassa %C"
@@ -50211,7 +50259,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -50930,7 +50978,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -50987,372 +51035,372 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function '%s' at %L not set"
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, fuzzy, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, fuzzy, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "Funktiota ”%s” kohdassa %L ei voida kutsua rekursiivisesti, koska se ei ole RECURSIVE"
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Funktiota ”%s” kohdassa %L ei voida kutsua rekursiivisesti, koska se ei ole RECURSIVE"
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "Funktiota ”%s” kohdassa %L ei voida kutsua rekursiivisesti, koska se ei ole RECURSIVE"
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Funktiota ”%s” kohdassa %L ei voida kutsua rekursiivisesti, koska se ei ole RECURSIVE"
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, fuzzy, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of references"
 msgid "check_dimension(): Bad array reference"
 msgstr "luodaan viitteiden taulukko"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of references"
 msgid "resolve_ref(): Bad array reference"
 msgstr "luodaan viitteiden taulukko"
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -51361,12 +51409,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -51375,249 +51423,249 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -51626,188 +51674,188 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-nimiö kohdassa %L menee CASE-nimiön päälle kohdassa %L"
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %d-kaltainen"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Haarautuminen kohdassa %L voi aiheuttaa ikisilmukan"
@@ -51814,12 +51862,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -51827,160 +51875,160 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr ""
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr ""
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -51987,7 +52035,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -51995,59 +52043,59 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr ""
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Merkkijonon pituus kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
@@ -52054,453 +52102,453 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Varattavalla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Ulkoisella objektilla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktiolla ”%s” kohdassa %L täytyy olla skalaaritulos"
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla taulukkoarvoinen"
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla osoitinarvoinen"
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla puhdas"
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla rekursiivinen"
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla puhdas"
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Valeproseduurilla ”%s” kohdassa %C ei voi olla geneeristä rajapintaa"
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa SAVE-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa RESULT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, fuzzy, gcc-internal-format
 #| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribuutti on ristiriidassa FUNCTION-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla skalaari"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, fuzzy, gcc-internal-format
 #| msgid "Empty array constructor at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -52507,402 +52555,402 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, fuzzy, gcc-internal-format
 #| msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta sitä ei voida käyttää"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla merkkijono"
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -52932,47 +52980,47 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr ""
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr ""
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr ""
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, gcc-internal-format
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr ""
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr ""
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
 msgstr ""
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr ""
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr ""
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr ""
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open file '%s'"
 msgid "Can't open file %qs"
@@ -53240,52 +53288,52 @@
 msgid "Reshaped array too large at %C"
 msgstr "Kokonaisluku liian suuri kohdassa %C"
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, fuzzy, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr ""
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -53364,320 +53412,325 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "Virheellinen proseduuriargumentti kohdassa %L"
+
+#: fortran/symbol.c:489
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, fuzzy, gcc-internal-format
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute with %s attribute at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, fuzzy, gcc-internal-format
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "Kaksoiskappale SAVE-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Kaksoiskappale VALUE-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Kaksoiskappale-BIND-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Kaksoiskappale-EXTENDS-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr ""
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Symboli ”%s” kohdassa %L ei ole yksiselitteinen"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qD"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' is used before it is typed at %L"
 msgid "Symbol %qs is used before it is typed at %L"
@@ -53944,7 +53997,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -55495,6 +55548,14 @@
 msgstr ""
 
 #, fuzzy
+#~ msgid "Use ISA 2.07 crypto instructions"
+#~ msgstr "Käytä SmartMIPS-käskyjä"
+
+#, fuzzy
+#~ msgid "lastprivate variable %qE is private in outer context"
+#~ msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
+
+#, fuzzy
 #~ msgid "hotpatching is not compatible with nested functions"
 #~ msgstr "ISO C kieltää sisäkkäiset funktiot"
 
@@ -55503,6 +55564,11 @@
 #~ msgstr "sekä %<_Sat%> että %<complex%> esittelymääritteissä"
 
 #, fuzzy
+#~| msgid "Unexpected %s statement in MODULE at %C"
+#~ msgid "Unexpected %s statement in verify_st_order() at %C"
+#~ msgstr "Odottamaton %s-lause MODULE-lohkossa kohdassa %C"
+
+#, fuzzy
 #~ msgid "%s:%d:%d: Invalid state file; %s"
 #~ msgstr "%s: virheellinen tiedoston nimi: %s\n"
 
Index: gcc/po/el.po
===================================================================
--- gcc/po/el.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/el.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.0-b20041128\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2004-12-15 18:53+0000\n"
 "Last-Translator: Simos Xenitellis <simos74@gmx.net>\n"
 "Language-Team: Greek <nls@tux.hellug.gr>\n"
@@ -189,13 +189,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, fuzzy, c-format
 msgid "invalid expression as operand"
@@ -1416,7 +1416,7 @@
 msgid "options enabled: "
 msgstr "επιλογή α\n"
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, fuzzy, gcc-internal-format
 msgid "<anonymous>"
@@ -2629,97 +2629,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, fuzzy, c-format
 msgid "invalid %%H value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, fuzzy, c-format
 msgid "invalid %%J value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, fuzzy, c-format
 msgid "invalid %%r value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, fuzzy, c-format
 msgid "invalid %%R value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, fuzzy, c-format
 msgid "invalid %%N value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, fuzzy, c-format
 msgid "invalid %%P value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, fuzzy, c-format
 msgid "invalid %%h value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, fuzzy, c-format
 msgid "invalid %%L value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, fuzzy, c-format
 msgid "invalid %%m value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, fuzzy, c-format
 msgid "invalid %%M value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, fuzzy, c-format
 msgid "invalid %%U value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, fuzzy, c-format
 msgid "invalid %%s value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, fuzzy, c-format
 msgid "invalid %%C value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, fuzzy, c-format
 msgid "invalid %%E value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, fuzzy, c-format
 msgid "unknown relocation unspec"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, fuzzy, c-format
 msgid "invalid %%xn code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 msgid "invalid operand address"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
@@ -2767,7 +2767,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, fuzzy, c-format
 msgid "invalid operand output code"
 msgstr "Μη έγκυρος κώδικας αίτησης"
@@ -2926,8 +2926,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3182,63 +3182,63 @@
 msgid "bad output_condmove_single operand"
 msgstr "αρχείο εξόδου"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "μη έγκυρη μετατόπιση UTC"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, fuzzy, c-format
 msgid "invalid constraints for operand"
 msgstr "μη έγκυρος χρήστης"
 
 # src/grep.c:1133
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "άγνωστη μέθοδος καταλόγων"
@@ -3282,7 +3282,7 @@
 msgid "invalid %%P operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, fuzzy, c-format
 msgid "invalid %%p value"
 msgstr "μη έγκυρος χρήστης"
@@ -3348,7 +3348,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 #, fuzzy
 msgid "bad address"
 msgstr "Εσφαλμένη διεύθυνση"
@@ -3516,102 +3516,102 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 #, fuzzy
 msgid "bad move"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 msgid "invalid %%e value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, fuzzy, c-format
 msgid "invalid %%f value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, fuzzy, c-format
 msgid "invalid %%F value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, fuzzy, c-format
 msgid "invalid %%G value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, fuzzy, c-format
 msgid "invalid %%j code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, fuzzy, c-format
 msgid "invalid %%J code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, fuzzy, c-format
 msgid "invalid %%k value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, fuzzy, c-format
 msgid "invalid %%K value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, fuzzy, c-format
 msgid "invalid %%O value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, fuzzy, c-format
 msgid "invalid %%q value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, fuzzy, c-format
 msgid "invalid %%S value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, fuzzy, c-format
 msgid "invalid %%T value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, fuzzy, c-format
 msgid "invalid %%u value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, fuzzy, c-format
 msgid "invalid %%v value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, fuzzy, c-format
 msgid "invalid %%x value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 #, fuzzy
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 #, fuzzy
 msgid "Unable to generate load offset for fusion"
 msgstr "Αδύνατη η δημιουργία διεργασίας στον εξυπηρετητή"
@@ -3706,60 +3706,60 @@
 msgid "invalid operand to %%S"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr ""
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr ""
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, fuzzy, c-format
 msgid "invalid %%Y operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, fuzzy, c-format
 msgid "invalid %%A operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, fuzzy, c-format
 msgid "invalid %%B operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, fuzzy, c-format
 msgid "invalid %%C operand"
 msgstr "μη έγκυρη μετατόπιση UTC"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, fuzzy, c-format
 msgid "invalid %%D operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, fuzzy, c-format
 msgid "invalid %%f operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, fuzzy, c-format
 msgid "invalid %%s operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr ""
@@ -3970,7 +3970,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3986,15 +3986,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "Μη ορισμένο όνομα %s"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4016,8 +4016,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4024,8 +4024,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4034,13 +4034,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr ""
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4047,8 +4047,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4069,7 +4069,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4087,34 +4087,34 @@
 msgid "expected %<.%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4124,11 +4124,11 @@
 msgid "(anonymous)"
 msgstr "((ανώνυμο))"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr ""
 
@@ -4357,11 +4357,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4414,49 +4414,49 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, fuzzy, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4557,7 +4557,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 #, fuzzy
 msgid "array assignment"
 msgstr "προσπέρασμα ορίσματος"
@@ -4577,7 +4577,7 @@
 msgid "Driving:"
 msgstr "προειδοποίηση: "
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4652,13 +4652,13 @@
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4748,7 +4748,7 @@
 msgid "Bad type in constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4780,12 +4780,12 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 #, fuzzy
 msgid "assignment"
 msgstr "προσπέρασμα ορίσματος"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 #, fuzzy
 msgid "pointer assignment"
 msgstr "προσπέρασμα ορίσματος"
@@ -4804,214 +4804,214 @@
 msgid "internal function"
 msgstr "Στη συνάρτηση"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 #, fuzzy
 msgid "elemental procedure"
 msgstr "πολύ λίγα ορίσματα"
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 msgid "allocatable argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 #| msgid "no arguments"
 msgid "pointer argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 msgid "value argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 #, fuzzy
 msgid "parametrized derived type argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 #, fuzzy
 msgid "pointer or allocatable result"
 msgstr "Δεν είναι δυνατό να δεσμευτεί μνήμη"
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 #, fuzzy
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr ""
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5427,16 +5427,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr ""
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr ""
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr ""
-
 #: config/sol2.h:222 config/sol2.h:227
 #, fuzzy
 msgid "does not support multilib"
@@ -5450,6 +5440,11 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr ""
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+#, fuzzy
+msgid "profiling not supported with -mg"
+msgstr "Η λειτουργία δεν υποστηρίζεται"
+
 #: config/mips/r3900.h:37
 #, fuzzy
 msgid "-mhard-float not supported"
@@ -5462,10 +5457,6 @@
 "Οι επιλογές για να εκτυπωθεί και να οριστεί η ώρα δεν μπορούν να\n"
 "χρησιμοποιηθούν παράλληλα."
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr ""
-
 #: config/cris/cris.h:184
 #, fuzzy
 msgid "do not specify both -march=... and -mcpu=..."
@@ -5495,6 +5486,12 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr ""
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5502,6 +5499,10 @@
 msgid "may not use both -m32 and -m64"
 msgstr "δεν είναι δυνατό να παραληφθεί ο χρήστης και η ομάδα"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr ""
+
 #: config/s390/tpf.h:106
 #, fuzzy
 msgid "static is not supported on TPF-OS"
@@ -5521,6 +5522,10 @@
 "Οι επιλογές για να εκτυπωθεί και να οριστεί η ώρα δεν μπορούν να\n"
 "χρησιμοποιηθούν παράλληλα."
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr ""
+
 #: config/avr/specs.h:68
 #, fuzzy
 msgid "shared is not supported"
@@ -5549,17 +5554,19 @@
 msgid "no processor type specified for linking"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr ""
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr ""
 
@@ -5597,11 +5604,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-#, fuzzy
-msgid "profiling not supported with -mg"
-msgstr "Η λειτουργία δεν υποστηρίζεται"
-
 #: fortran/lang.opt:146
 msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgstr ""
@@ -5789,9 +5791,9 @@
 msgstr ""
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -5998,10 +6000,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -6047,7 +6049,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, fuzzy, c-format
 msgid "missing filename after %qs"
 msgstr "παράληψη ορίσματος αρχείου"
@@ -7939,45 +7941,49 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 #, fuzzy
 msgid "Specify the code model"
 msgstr "Ορισμός ονόματος προγράμματος"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -9075,10 +9081,14 @@
 msgstr ""
 
 #: config/i386/i386.opt:864
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr ""
+
+#: config/i386/i386.opt:868
 msgid "Use given stack-protector guard"
 msgstr ""
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr ""
 
@@ -9444,7 +9454,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -9596,7 +9606,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 msgid "Use LRA instead of reload"
 msgstr ""
@@ -9722,7 +9732,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr ""
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr ""
 
@@ -10053,312 +10063,311 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 #, fuzzy
 msgid "Do not place floating point constants in TOC"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 #, fuzzy
 msgid "Generate isel instructions"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 msgid "Deprecated option.  Use -misel instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 #, fuzzy
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 msgid "Deprecated option.  Use -mspe instead"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 msgid "-mdebug=\tEnable debug output"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 #, fuzzy
 msgid "Use the AltiVec ABI extensions"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 #, fuzzy
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 msgid "Use the SPE ABI extensions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 #, fuzzy
 msgid "Do not use the SPE ABI extensions"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 msgid "Use the ELFv1 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 msgid "Use the ELFv2 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 msgid "using darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 msgid "using old darwin ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 #, fuzzy
 msgid "Avoid all range limits on call instructions"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 msgid "Generate Cell microcode"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 #, fuzzy
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 #, fuzzy
 msgid "Valid arguments to -malign-:"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 #, fuzzy
 msgid "Single-precision floating point unit"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 #, fuzzy
 msgid "Double-precision floating point unit"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 msgid "Floating point unit does not support divide & sqrt"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 msgid "Specify Xilinx FPU."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 msgid "Allow sign extension in fusion operations"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
-#, fuzzy
-msgid "Use ISA 2.07 crypto instructions"
-msgstr "Ακατάλληλη εντολή"
+#: config/rs6000/rs6000.opt:566
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr ""
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -13313,1561 +13322,1561 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr ""
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr ""
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr ""
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr ""
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr ""
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr ""
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr ""
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr ""
 
-#: common.opt:918
+#: common.opt:921
 #, fuzzy
 msgid "Generate auto-inc/dec instructions"
 msgstr "Ακατάλληλη εντολή"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr ""
 
-#: common.opt:936
+#: common.opt:939
 #, fuzzy
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr ""
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr ""
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr ""
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr ""
 
-#: common.opt:960
+#: common.opt:963
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr ""
 
-#: common.opt:964
+#: common.opt:967
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr ""
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr ""
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr ""
 
-#: common.opt:979
+#: common.opt:982
 msgid "Check the return value of new in C++"
 msgstr ""
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr ""
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr ""
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr ""
 
-#: common.opt:1003
+#: common.opt:1006
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr ""
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr ""
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr ""
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr ""
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr ""
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr ""
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr ""
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr ""
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr ""
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr ""
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr ""
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr ""
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 msgid "Perform speculative devirtualization"
 msgstr ""
 
-#: common.opt:1081
+#: common.opt:1084
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1085
+#: common.opt:1088
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr ""
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1145
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr ""
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr ""
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr ""
 
-#: common.opt:1157
+#: common.opt:1160
 msgid "Suppress output of addresses in debugging dumps"
 msgstr ""
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
 # src/getopt1.c:132
 # src/getopt1.c:132
-#: common.opt:1166
+#: common.opt:1169
 #, fuzzy
 msgid "Dump optimization passes"
 msgstr "επιλογή %s"
 
-#: common.opt:1170
+#: common.opt:1173
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1177
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr ""
 
-#: common.opt:1190
+#: common.opt:1193
 msgid "Perform interprocedural reduction of aggregates"
 msgstr ""
 
-#: common.opt:1194
+#: common.opt:1197
 msgid "Perform unused symbol elimination in debug info"
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr ""
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr ""
 
-#: common.opt:1217
+#: common.opt:1220
 #, fuzzy, c-format
 msgid "unknown excess precision style %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr ""
 
-#: common.opt:1238
+#: common.opt:1241
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr ""
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr ""
 
-#: common.opt:1250
+#: common.opt:1253
 msgid "Perform a forward propagation pass on RTL"
 msgstr ""
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, fuzzy, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr ""
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr ""
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr ""
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr ""
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr ""
 
-#: common.opt:1305
+#: common.opt:1308
 msgid "Enable in and out of Graphite representation"
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1312
 #, fuzzy
 msgid "Enable Graphite Identity transformation"
 msgstr "εμφάνιση πληροφοριών προόδου"
 
-#: common.opt:1313
+#: common.opt:1316
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr ""
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr ""
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr ""
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr ""
 
-#: common.opt:1330
+#: common.opt:1333
 msgid "Enable Loop Blocking transformation"
 msgstr ""
 
-#: common.opt:1334
+#: common.opt:1337
 msgid "Enable Loop Unroll Jam transformation"
 msgstr ""
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr ""
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr ""
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr ""
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr ""
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, fuzzy, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:1394
+#: common.opt:1397
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr ""
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr ""
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr ""
 
-#: common.opt:1410
+#: common.opt:1413
 msgid "Perform indirect inlining"
 msgstr ""
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr ""
 
-#: common.opt:1424
+#: common.opt:1427
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr ""
 
-#: common.opt:1428
+#: common.opt:1431
 msgid "Integrate functions only required by their single caller"
 msgstr ""
 
-#: common.opt:1435
+#: common.opt:1438
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr ""
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1458
 msgid "Perform interprocedural constant propagation"
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1466
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1470
 msgid "Perform interprocedural profile propagation"
 msgstr ""
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1478
 #, fuzzy
 msgid "Discover pure and const functions"
 msgstr "Ακατάλληλη εντολή"
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 msgid "Perform Identical Code Folding for variables"
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr ""
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr ""
 
-#: common.opt:1506
+#: common.opt:1509
 #, fuzzy, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr ""
 
-#: common.opt:1519
+#: common.opt:1522
 #, fuzzy, c-format
 msgid "unknown IRA region %qs"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1561
 #, fuzzy
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr ""
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr ""
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr ""
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 msgid "Enable link-time optimization."
 msgstr ""
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr ""
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 msgid "Report various link-time optimization statistics"
 msgstr ""
 
-#: common.opt:1625
+#: common.opt:1628
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr ""
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr ""
 
-#: common.opt:1641
+#: common.opt:1644
 msgid "Report on permanent memory allocation in WPA only"
 msgstr ""
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr ""
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1659
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr ""
 
-#: common.opt:1660
+#: common.opt:1663
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr ""
 
-#: common.opt:1676
+#: common.opt:1679
 msgid "Use the RTL dead code elimination pass"
 msgstr ""
 
-#: common.opt:1680
+#: common.opt:1683
 msgid "Use the RTL dead store elimination pass"
 msgstr ""
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 msgid "options or targets missing after %qs"
 msgstr "Αρχή αρχείου %s\n"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
 # src/grep.c:1133
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 msgid "unknown offload ABI %qs"
 msgstr "άγνωστη μέθοδος καταλόγων"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr ""
 
-#: common.opt:1713
+#: common.opt:1716
 msgid "Enable all optimization info dumps on stderr"
 msgstr ""
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr ""
 
-#: common.opt:1729
+#: common.opt:1732
 msgid "Perform partial inlining"
 msgstr ""
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr ""
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr ""
 
-#: common.opt:1745
+#: common.opt:1748
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr ""
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr ""
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr ""
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr ""
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr ""
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr ""
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr ""
 
-#: common.opt:1781
+#: common.opt:1784
 msgid "Specify a plugin to load"
 msgstr ""
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr ""
 
-#: common.opt:1789
+#: common.opt:1792
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr ""
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr ""
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr ""
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1821
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr ""
 
-#: common.opt:1826
+#: common.opt:1829
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1837
 #, fuzzy
 msgid "Report on consistency of profile"
 msgstr "εσωτερικό σφάλμα gcc"
 
-#: common.opt:1838
+#: common.opt:1841
 msgid "Enable function reordering that improves code placement"
 msgstr ""
 
-#: common.opt:1845
+#: common.opt:1848
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr ""
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr ""
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 msgid "Relief of register pressure through live range shrinkage"
 msgstr ""
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr ""
 
-#: common.opt:1880
+#: common.opt:1883
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr ""
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr ""
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr ""
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr ""
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr ""
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr ""
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr ""
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr ""
 
-#: common.opt:1928
+#: common.opt:1931
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr ""
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr ""
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr ""
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr ""
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr ""
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr ""
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr ""
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr ""
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1981
+#: common.opt:1984
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr ""
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1993
+#: common.opt:1996
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr ""
 
-#: common.opt:1997
+#: common.opt:2000
 msgid "Enable the group heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2009
+#: common.opt:2012
 msgid "Enable the rank heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr ""
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr ""
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr ""
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr ""
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr ""
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr ""
 
-#: common.opt:2062
+#: common.opt:2065
 msgid "Generate discontiguous stack frames"
 msgstr ""
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr ""
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr ""
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr ""
 
-#: common.opt:2082
+#: common.opt:2085
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr ""
 
-#: common.opt:2086
+#: common.opt:2089
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr ""
 
-#: common.opt:2093
+#: common.opt:2096
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr ""
 
-#: common.opt:2097
+#: common.opt:2100
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr ""
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr ""
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr ""
 
-#: common.opt:2109
+#: common.opt:2112
 msgid "Use a smart stack protection method for certain functions"
 msgstr ""
 
-#: common.opt:2113
+#: common.opt:2116
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr ""
 
-#: common.opt:2117
+#: common.opt:2120
 msgid "Output stack usage information on a per-function basis"
 msgstr ""
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr ""
 
-#: common.opt:2133
+#: common.opt:2136
 msgid "Treat signed overflow as undefined"
 msgstr ""
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr ""
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr ""
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr ""
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr ""
 
-#: common.opt:2157
+#: common.opt:2160
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2163
 #, fuzzy, c-format
 msgid "unknown TLS model %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr ""
 
-#: common.opt:2187
+#: common.opt:2190
 #, fuzzy
 msgid "Assume floating-point operations can trap"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr ""
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr ""
 
-#: common.opt:2199
+#: common.opt:2202
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr ""
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr ""
 
-#: common.opt:2211
+#: common.opt:2214
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr ""
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr ""
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr ""
 
-#: common.opt:2231
+#: common.opt:2234
 msgid "Transform condition stores into unconditional ones"
 msgstr ""
 
-#: common.opt:2235
+#: common.opt:2238
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr ""
 
-#: common.opt:2243
+#: common.opt:2246
 msgid "Enable dominator optimizations"
 msgstr ""
 
-#: common.opt:2247
+#: common.opt:2250
 msgid "Enable tail merging on trees"
 msgstr ""
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr ""
 
-#: common.opt:2255
+#: common.opt:2258
 msgid "Enable forward propagation on trees"
 msgstr ""
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr ""
 
-#: common.opt:2263
+#: common.opt:2266
 #, fuzzy
 msgid "Enable string length optimizations on trees"
 msgstr "ελάχιστο μέγεθος αλφαριθμητικού"
 
-#: common.opt:2267
+#: common.opt:2270
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2276
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr ""
 
-#: common.opt:2280
+#: common.opt:2283
 #, fuzzy
 msgid "Enable loop distribution on trees"
 msgstr "Ακατάλληλη εντολή"
 
-#: common.opt:2284
+#: common.opt:2287
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr ""
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr ""
 
-#: common.opt:2292
+#: common.opt:2295
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr ""
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr ""
 
-#: common.opt:2300
+#: common.opt:2303
 msgid "Enable loop optimizations on tree level"
 msgstr ""
 
-#: common.opt:2304
+#: common.opt:2307
 #, fuzzy
 msgid "Enable automatic parallelization of loops"
 msgstr "Ακατάλληλη εντολή"
 
-#: common.opt:2308
+#: common.opt:2311
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2312
+#: common.opt:2315
 msgid "Enable SSA-PRE optimization on trees"
 msgstr ""
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2324
+#: common.opt:2327
 msgid "Enable reassociation on tree level"
 msgstr ""
 
-#: common.opt:2332
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
 msgstr ""
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr ""
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr ""
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr ""
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr ""
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr ""
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr ""
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr ""
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr ""
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr ""
 
-#: common.opt:2400
+#: common.opt:2403
 msgid "Use the bfd linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2404
+#: common.opt:2407
 msgid "Use the gold linker instead of the default linker"
 msgstr ""
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr ""
 
-#: common.opt:2424
+#: common.opt:2427
 msgid "Perform variable tracking by annotating assignments"
 msgstr ""
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr ""
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr ""
 
-#: common.opt:2442
+#: common.opt:2445
 msgid "Enable vectorization on trees"
 msgstr ""
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr ""
 
-#: common.opt:2454
+#: common.opt:2457
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr ""
 
-#: common.opt:2458
+#: common.opt:2461
 msgid "Specifies the cost model for vectorization"
 msgstr ""
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:2478
+#: common.opt:2481
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2485
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2493
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr ""
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr ""
 
 # src/request.c:806 src/request.c:912
-#: common.opt:2507
+#: common.opt:2510
 #, fuzzy, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
 # src/request.c:263
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 #, fuzzy
 msgid "Use expression value profiles in optimizations"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2558
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr ""
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr ""
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2582
 msgid "Generate debug information in default version of DWARF format"
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2586
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2610
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2614
 msgid "Don't generate debug information in separate .dwo files"
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2618
 msgid "Generate debug information in separate .dwo files"
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr ""
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2638
 msgid "Toggle debug information generation"
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr ""
 
-#: common.opt:2665
+#: common.opt:2668
 msgid "Generate compressed debug sections"
 msgstr ""
 
-#: common.opt:2669
+#: common.opt:2672
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr ""
 
-#: common.opt:2676
+#: common.opt:2679
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr ""
 
-#: common.opt:2680
+#: common.opt:2683
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr ""
 
-#: common.opt:2702
+#: common.opt:2705
 #, fuzzy
 msgid "-o <file>\tPlace output into <file>"
 msgstr "  -o <αρχείο>              Τοποθέτηση της εξόδου στο <αρχείο>\n"
 
-#: common.opt:2706
+#: common.opt:2709
 #, fuzzy
 msgid "Enable function profiling"
 msgstr "αδύνατη η φόρτωση δεδομένων προφίλ"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr ""
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr ""
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr ""
 
-#: common.opt:2792
+#: common.opt:2795
 #, fuzzy
 msgid "Display the compiler's version"
 msgstr "  --help                   Εμφάνιση αυτών των πληροφοριών\n"
 
-#: common.opt:2796
+#: common.opt:2799
 #, fuzzy
 msgid "Suppress warnings"
 msgstr "%s: προειδοποίηση: "
 
-#: common.opt:2806
+#: common.opt:2809
 msgid "Create a shared library"
 msgstr ""
 
-#: common.opt:2851
+#: common.opt:2854
 msgid "Create a position independent executable"
 msgstr ""
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr ""
@@ -14902,46 +14911,46 @@
 msgid "expected integer or boolean type"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 msgid "invalid comparison of nil with nil"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 #, fuzzy
 msgid "incompatible types in binary expression"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 #| msgid "division by zero"
 msgid "integer division by zero"
 msgstr "διαίρεση με μηδέν"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 #, fuzzy
 msgid "shift of non-integer operand"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 msgid "shift count not unsigned integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 #, fuzzy
 msgid "negative shift count"
 msgstr "ελάχιστο μέγεθος αλφαριθμητικού"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 #, fuzzy
 msgid "object is not a method"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 #, fuzzy
 msgid "method type does not match object type"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 #, fuzzy
 msgid "invalid use of %<...%> with builtin function"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
@@ -14948,216 +14957,216 @@
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 #, fuzzy
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 #, fuzzy
 #| msgid "no arguments"
 msgid "not enough arguments"
 msgstr "χωρίς ορίσματα"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 #, fuzzy
 msgid "too many arguments"
 msgstr "πάρα πολλά ορίσματα"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 #, fuzzy
 msgid "argument 1 must be a map"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 #, fuzzy
 msgid "invalid type for make function"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 msgid "length required when allocating a slice"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 #, fuzzy
 msgid "too many arguments to make"
 msgstr "πάρα πολλά ορίσματα"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 #, fuzzy
 msgid "argument must be array or slice or channel"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 #, fuzzy
 msgid "unsupported argument type to builtin function"
 msgstr "πάρα πολλά ορίσματα"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 #, fuzzy
 msgid "argument must be channel"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 msgid "cannot close receive-only channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 #, fuzzy
 msgid "argument must be a field reference"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 #, fuzzy
 msgid "left argument must be a slice"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 #, fuzzy
 msgid "first argument must be []byte"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 #, fuzzy
 msgid "second argument must be slice or string"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 #, fuzzy
 msgid "argument 2 has invalid type"
 msgstr "μη πλήρης εγγραφή"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 #, fuzzy
 msgid "argument must have complex type"
 msgstr "μη πλήρης εγγραφή"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 #, fuzzy
 msgid "complex arguments must have identical types"
 msgstr "διπλός προσδιοριστής μηνύματος"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 #, fuzzy
 msgid "complex arguments must have floating-point type"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 #, fuzzy
 msgid "expected function"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 msgid "multiple-value argument in single-value context"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 #, fuzzy
 msgid "invalid use of %<...%> with non-slice"
 msgstr "μη έγκυρος χρήστης"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 msgid "function result count mismatch"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 #, fuzzy
 msgid "incompatible type for receiver"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 #, fuzzy
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 #, fuzzy
 msgid "number of results does not match number of values"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 #, fuzzy
 msgid "index must be integer"
 msgstr "διπλός προσδιοριστής μηνύματος"
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 #, fuzzy
 msgid "slice end must be integer"
 msgstr "διπλός προσδιοριστής μηνύματος"
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 msgid "slice capacity must be integer"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 #, fuzzy
 msgid "slice of unaddressable value"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 #, fuzzy
 msgid "incompatible type for map index"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 msgid "expected interface or pointer to interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 #, fuzzy
 msgid "too many expressions for struct"
 msgstr "υπερβολικά πολλά δευτερόλεπτα αναπήδησης"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 #, fuzzy
 msgid "too few expressions for struct"
 msgstr "πολύ λίγα ορίσματα"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 #, fuzzy
 msgid "type assertion only valid for interface types"
 msgstr "Μη έγκυρος εξακριβωτής(verifier) εξυπηρετούμενου"
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 #, fuzzy
 msgid "expected channel"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -15277,78 +15286,78 @@
 msgid "cannot use type %s as type %s"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 #, fuzzy
 msgid "different receiver types"
 msgstr "είδος μορφής"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 #, fuzzy
 msgid "different number of parameters"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 #, fuzzy
 msgid "different parameter types"
 msgstr "είδος μορφής"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 #, fuzzy
 msgid "different varargs"
 msgstr "είδος μορφής"
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 #, fuzzy
 msgid "different result types"
 msgstr "είδος μορφής"
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 #, fuzzy
 msgid "type has no methods"
 msgstr "σφάλμα κατά την ανάγνωση της εισόδου"
 
 # src/main.c:785
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, fuzzy, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "Ασαφής μορφή `%s'"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, fuzzy, c-format
 msgid "missing method %s%s%s"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -15469,7 +15478,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr ""
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "πάρα πολλά ορίσματα"
@@ -15650,12 +15659,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr ""
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "Λείπει παράμετρος για `%s'"
@@ -16216,217 +16225,222 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr ""
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr ""
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr ""
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, gcc-internal-format
 msgid "execution count is negative"
 msgstr ""
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, fuzzy, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "δεν δώθηκε συμβολικό όνομα"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr ""
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
@@ -16433,27 +16447,27 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -16585,7 +16599,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, gcc-internal-format
 msgid "atexit failed"
@@ -16830,17 +16844,17 @@
 msgid "          %s"
 msgstr "        `%D'"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr ""
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, fuzzy, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, fuzzy, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -16885,12 +16899,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -17085,7 +17099,7 @@
 msgid "total size of local objects too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -17539,9 +17553,9 @@
 msgstr "αδυναμία εγγραφής αρχείων εξόδου στο `%s'"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -17556,153 +17570,148 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr ""
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, fuzzy, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr ""
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr ""
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr ""
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, fuzzy, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
 # src/shred.c:1134
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr ""
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:7001
-#, gcc-internal-format
-msgid "lastprivate variable %qE is private in outer context"
-msgstr ""
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, fuzzy, gcc-internal-format
 msgid "directive not yet implemented"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr ""
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr ""
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -18116,47 +18125,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "αδυναμία εκτέλεσης ioctl στο `%s'"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "αδυναμία ανοίγματος υποδοχής: %s"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -18237,43 +18246,43 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "δεν υπάρχουν αρχεία εισόδου"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 msgid "writing output file"
 msgstr "%s: Σφάλμα κατά την εγγραφή του %s\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr ""
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr ""
@@ -18280,7 +18289,7 @@
 
 # src/getopt1.c:132
 # src/getopt1.c:132
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen: %s: %m"
@@ -18416,28 +18425,28 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 msgid "ignoring large linear step"
 msgstr "αγνοούνται όλα τα ορίσματα"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -18953,8 +18962,8 @@
 msgstr ""
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "άγνωστος χαρακτήρας `%s'"
@@ -19394,7 +19403,7 @@
 msgid "ld returned %d exit status"
 msgstr "η ld επέστρεψε κατάσταση εξόδου %d"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -20370,42 +20379,42 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr ""
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -20787,47 +20796,47 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, gcc-internal-format
 msgid "array subscript is outside array bounds"
 msgstr ""
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, gcc-internal-format
 msgid "array subscript is above array bounds"
 msgstr ""
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, gcc-internal-format
 msgid "array subscript is below array bounds"
 msgstr ""
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr ""
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr ""
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr ""
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr ""
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr ""
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr ""
@@ -20871,9 +20880,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21104,7 +21113,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
@@ -21252,27 +21261,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr ""
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -21610,12 +21619,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
@@ -22062,12 +22071,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr ""
@@ -22077,22 +22086,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr ""
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr ""
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr ""
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr ""
@@ -22132,12 +22141,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, fuzzy, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
@@ -22217,7 +22226,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
@@ -22633,7 +22642,7 @@
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
@@ -23090,7 +23099,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -23100,22 +23109,22 @@
 msgid "%qE is not initialized"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Η λειτουργία δεν επιτρέπεται"
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "μη έγκυρο όνομα μήνα"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "παράληψη ορίσματος αρχείου"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -23656,6 +23665,12 @@
 msgid "too many input files"
 msgstr "υπερβολικά πολλά αρχεία εισόδου"
 
+# src/shred.c:1134
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+msgid "-mcpu string too large"
+msgstr "%s: το αρχείο είναι πολύ μεγάλο"
+
 #: common/config/alpha/alpha-common.c:76
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -23681,47 +23696,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr ""
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr ""
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr ""
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -24108,63 +24123,63 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr "%s: αριθμός γραμμής έξω από τα όρια"
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr ""
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr ""
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mtune switch"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr ""
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, fuzzy, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, fuzzy, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, fuzzy, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr ""
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -24640,14 +24655,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to functions"
@@ -25292,374 +25307,390 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong arg %s to option %s"
 msgstr "πάρα πολλά ορίσματα"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
+#, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386.c:3012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown alignment %s specified for option %s"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, gcc-internal-format, gfc-internal-format
 msgid "too many size ranges specified in option %s"
 msgstr ""
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "πάρα πολλές δηλώσεις μετατροπής στην κατάληξη"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%s: η υποστήριξη εκσφαλμάτωσης δεν έχει συμπεριληφθεί στη μεταγλώττιση.\n"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr ""
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "άγνωστο σετ `%s'"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:5923
-#, gcc-internal-format
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr ""
-
-#: config/i386/i386.c:6210
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, gcc-internal-format
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
 #, gcc-internal-format
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.c:11378
+#, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -25666,252 +25697,252 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, fuzzy, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -26004,13 +26035,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr ""
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -26084,7 +26115,7 @@
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument not an integer constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -26144,7 +26175,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, fuzzy, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
@@ -26997,16 +27028,11 @@
 msgid "-g option disabled"
 msgstr "Η λειτουργία NIS+ απέτυχε"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr ""
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, gcc-internal-format
@@ -27264,308 +27290,313 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
+#, gcc-internal-format, gfc-internal-format
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000.c:12763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, fuzzy, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had no type"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
 # src/shred.c:1134
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr ""
@@ -27818,88 +27849,88 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "το πρώτο όρισμα της `%s' πρέπει να είναι `int'"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, fuzzy, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "%s: ο αριθμός γραμμής πρέπει να είναι μεγαλύτερος από το μηδέν"
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
@@ -27914,53 +27945,53 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr ""
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, fuzzy, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is supported only for SH2A"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr ""
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to SH2A"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument should be between 0 to 255"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument not a string constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr ""
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, gcc-internal-format
 msgid "need a second call-clobbered general purpose register"
 msgstr ""
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr ""
@@ -28340,44 +28371,44 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, fuzzy, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr ""
 
 # src/request.c:37
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "%s σε %s"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -28435,7 +28466,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -28465,62 +28496,62 @@
 msgid "GCC supports only %u nested scopes"
 msgstr ""
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, fuzzy, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, fuzzy, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "Στη συνάρτηση μέλος `%s':"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, fuzzy, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "αχρησιμοποίητη μεταβλητή `%s'"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, fuzzy, gcc-internal-format
 msgid "variable %qD set but not used"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr ""
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr ""
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr ""
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr ""
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, fuzzy, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
@@ -28527,42 +28558,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr ""
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, fuzzy, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr ""
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, fuzzy, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "αδυναμία εκτέλεσης ioctl στο `%s'"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -28570,340 +28601,340 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, fuzzy, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, fuzzy, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr ""
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, fuzzy, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, fuzzy, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, fuzzy, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr ""
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, gcc-internal-format
 msgid "but not here"
 msgstr ""
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, fuzzy, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr ""
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr ""
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr ""
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, fuzzy, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, fuzzy, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, fuzzy, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, fuzzy, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE δεν έχει διακυρηχθεί (πρώτη χρήση στη συνάρτηση αυτή)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr ""
 
 # src/request.c:263
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, fuzzy, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, fuzzy, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, fuzzy, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "Πρόωρο τέλος της κανονικής έκφρασης"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, fuzzy, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr ""
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, fuzzy, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, fuzzy, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr ""
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, fuzzy, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, fuzzy, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, fuzzy, gcc-internal-format
 msgid "empty declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr ""
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr ""
@@ -28911,38 +28942,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, fuzzy, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr ""
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr ""
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -28951,259 +28982,259 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr ""
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr ""
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr ""
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, fuzzy, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr ""
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr ""
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "μη αρχικοποιημένη σταθερά const %qD"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, fuzzy, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, fuzzy, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr ""
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, fuzzy, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr ""
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr ""
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "διπλό κλειδί"
 
 # src/request.c:806 src/request.c:912
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr ""
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, fuzzy, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "Στη συνάρτηση μέλος `%s':"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -29211,685 +29242,685 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, fuzzy, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr ""
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr ""
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "μη έγκυρη ώρα της μέρας"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, fuzzy, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, fuzzy, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, fuzzy, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, fuzzy, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, fuzzy, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr ""
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, fuzzy, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "συνεχίζεται στο τμήμα"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr ""
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, fuzzy, gcc-internal-format
 msgid "enum type defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, fuzzy, gcc-internal-format
 msgid "struct defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, fuzzy, gcc-internal-format
 msgid "union defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, fuzzy, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, fuzzy, gcc-internal-format
 msgid "union has no named members"
 msgstr "επώνυμα μέλη"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, fuzzy, gcc-internal-format
 msgid "union has no members"
 msgstr "επώνυμα μέλη"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, fuzzy, gcc-internal-format
 msgid "struct has no named members"
 msgstr "επώνυμα μέλη"
 
 # src/request.c:37
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, fuzzy, gcc-internal-format
 msgid "struct has no members"
 msgstr "%s σε %s"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr "μη έγκυρη ώρα της μέρας"
 
 # src/shred.c:1134
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, fuzzy, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "ο επιστρεφόμενος τύπος προκαθορίζεται σε `int'"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "διατήρηση ωρών στο %s"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, fuzzy, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "έχει παραληφθεί το όνομα της παραμέτρου"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, fuzzy, gcc-internal-format
 msgid "old-style function definition"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "ο επιστρεφόμενος τύπος προκαθορίζεται σε `int'"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, fuzzy, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, fuzzy, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -29897,197 +29928,197 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, fuzzy, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "σφάλμα εγγραφής %s"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -30097,7 +30128,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr ""
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "Μη ορισμένο όνομα %s"
@@ -30117,8 +30148,8 @@
 msgid "unknown type name %qE"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -30133,7 +30164,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -30209,7 +30240,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, fuzzy, gcc-internal-format
 msgid "expected string literal"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
@@ -30266,14 +30297,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, fuzzy, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "σκουπίδια στο τέλος του αριθμού"
@@ -30722,32 +30753,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -30757,47 +30788,47 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
@@ -30812,12 +30843,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -30827,27 +30858,27 @@
 msgid "expression must be integral"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a constant"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
@@ -30879,17 +30910,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr ""
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "μη έγκυρο δικαίωμα"
@@ -30909,12 +30940,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, fuzzy, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
@@ -30934,17 +30965,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -30954,57 +30985,57 @@
 msgid "invalid proc_bind kind"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr ""
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 msgid "invalid pragma"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -31014,17 +31045,17 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "αναμενόταν ')'\n"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "αναμενόταν ')'\n"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -31034,237 +31065,237 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:13854 cp/parser.c:31398
+#: c/c-parser.c:13851 cp/parser.c:31433
 #, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, fuzzy, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr ""
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, gcc-internal-format
 msgid "pragma simd must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, fuzzy, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr "%s: ο αριθμός γραμμής πρέπει να είναι μεγαλύτερος από το μηδέν"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, fuzzy, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, fuzzy, gcc-internal-format
 msgid "base of array section must be pointer or array type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 msgid "array notations cannot be used with function type"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 msgid "expected array notation expression"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
@@ -31274,7 +31305,7 @@
 msgid "%qD has an incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, fuzzy, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -31383,7 +31414,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "το πέρασμα του ορίσματος %d του δείκτη στη συνάρτηση"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -31506,7 +31537,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "το πέρασμα του ορίσματος %d του δείκτη στη συνάρτηση"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
@@ -31536,7 +31567,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -31621,7 +31652,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
@@ -31656,7 +31687,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr ""
@@ -31739,7 +31770,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -31899,7 +31930,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -32036,7 +32067,7 @@
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr ""
@@ -32082,7 +32113,7 @@
 msgid "invalid initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
@@ -32227,7 +32258,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
@@ -32237,7 +32268,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -32342,17 +32373,17 @@
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
@@ -32403,12 +32434,12 @@
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
@@ -32433,85 +32464,85 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -32521,17 +32552,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -32541,7 +32572,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -32551,17 +32582,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
@@ -32576,47 +32607,47 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -32627,33 +32658,33 @@
 msgstr ""
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, fuzzy, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 msgid "  no known conversion from %qT to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, fuzzy, gcc-internal-format
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -32660,78 +32691,78 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, gcc-internal-format
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr ""
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, gcc-internal-format
 msgid "%s%D(%T, %T) <built-in>"
 msgstr ""
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, gcc-internal-format
 msgid "%s%D(%T) <built-in>"
 msgstr ""
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, gcc-internal-format
 msgid "%s%T <conversion>"
 msgstr ""
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr ""
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr ""
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr ""
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
@@ -32738,7 +32769,7 @@
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "%s: η επιλογή `-W %s' είναι διφορούμενη\n"
@@ -32745,12 +32776,12 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr ""
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
@@ -32757,380 +32788,380 @@
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "%s: η επιλογή `-W %s' είναι διφορούμενη\n"
 
 # src/main.c:785
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "Ασαφής μορφή `%s'"
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "σφάλμα στην ανάγνωση εισόδου: %s"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr ""
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "Σφάλμα στο ταίριασμα στην κανονική έκφραση `%s'"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, fuzzy, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "Σφάλμα στο ταίριασμα στην κανονική έκφραση `%s'"
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, fuzzy, gcc-internal-format
 msgid "non-placement deallocation function %q+D"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr ""
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr ""
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr ""
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, fuzzy, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, gcc-internal-format
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, fuzzy, gcc-internal-format
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %q+D"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, fuzzy, gcc-internal-format
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, fuzzy, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, fuzzy, gcc-internal-format
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, fuzzy, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, fuzzy, gcc-internal-format
 msgid "  in call to %q+D"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr ""
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "δεν ταιριάζει συνάρτηση για την κλήση στο %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr "δεν ταιριάζει συνάρτηση για την κλήση στο %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%s(%A)%>"
@@ -33138,72 +33169,72 @@
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "η κλήση της υπερφορτωμένης %<%s(%A)%> είναι διφορούμενη"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, fuzzy, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr ""
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr ""
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr ""
@@ -33359,7 +33390,7 @@
 msgid "  by %q+D"
 msgstr "  κατά `%D'"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, fuzzy, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
@@ -33369,7 +33400,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, fuzzy, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
@@ -33379,7 +33410,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr ""
@@ -33509,67 +33540,77 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4538
+#: cp/class.c:4300
+#, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, gcc-internal-format
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr ""
+
+#: cp/class.c:4557
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has volatile type"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr ""
@@ -33576,102 +33617,102 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, fuzzy, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, fuzzy, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, fuzzy, gcc-internal-format
 msgid "not enough type information"
 msgstr "εμφάνιση πληροφοριών προόδου"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
@@ -33681,12 +33722,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr ""
@@ -33726,43 +33767,43 @@
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, fuzzy, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-constexpr function %qD"
@@ -33769,212 +33810,212 @@
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "array subscript out of bound"
 msgstr ""
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, gcc-internal-format
 msgid "negative array subscript"
 msgstr ""
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr ""
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, fuzzy, gcc-internal-format
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, fuzzy, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Μη ορισμένο όνομα %s"
@@ -34045,7 +34086,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr ""
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr ""
@@ -34085,7 +34126,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, fuzzy, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
@@ -34095,293 +34136,293 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, fuzzy, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr ""
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr ""
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, fuzzy, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
 # src/request.c:37
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, fuzzy, gcc-internal-format
 msgid "statement has no effect"
 msgstr "%s σε %s"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -34794,239 +34835,239 @@
 msgid "template parameters do not match template %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr ""
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr ""
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr ""
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr ""
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
@@ -35034,824 +35075,824 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "μη αρχικοποιημένη σταθερά const %qD"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "υπερβολικά πολλά αρχεία εισόδου"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr ""
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr ""
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> variable"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, gcc-internal-format
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> πρέπει να επιστρέψει %<int%>"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, fuzzy, gcc-internal-format
 msgid "%q+#D explicitly defaulted here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr ""
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, fuzzy, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, fuzzy, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, fuzzy, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, fuzzy, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, fuzzy, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, fuzzy, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr ""
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
@@ -35858,470 +35899,470 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr ""
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, fuzzy, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, fuzzy, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, fuzzy, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, fuzzy, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "Υπάρχει αντικείμενο με το ίδιο όνομα"
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared %<auto%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr ""
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr ""
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, fuzzy, gcc-internal-format
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -36341,173 +36382,173 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, fuzzy, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr ""
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr ""
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, fuzzy, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, fuzzy, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -36519,12 +36560,12 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
@@ -36531,78 +36572,78 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr ""
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr ""
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr ""
@@ -36611,87 +36652,87 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr ""
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr ""
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, fuzzy, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D set but not used"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -36731,7 +36772,7 @@
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -36754,7 +36795,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -36844,27 +36885,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -36873,47 +36914,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr ""
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, gcc-internal-format
 msgid "%q#D, declared using anonymous type, is used but never defined"
 msgstr ""
@@ -36922,47 +36963,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -36969,12 +37010,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
@@ -37557,42 +37598,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr ""
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -37722,17 +37763,17 @@
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, gcc-internal-format
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, gcc-internal-format
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
@@ -38148,7 +38189,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr ""
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -38173,7 +38214,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
@@ -38238,7 +38279,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr ""
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -38263,7 +38304,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -38533,7 +38574,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
@@ -38708,7 +38749,7 @@
 msgid "capture of non-variable %qD "
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, fuzzy, gcc-internal-format
 msgid "%q+#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -38768,7 +38809,7 @@
 msgid "compound-statement in constexpr function"
 msgstr ""
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
@@ -38798,7 +38839,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
@@ -38829,12 +38870,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
@@ -38881,7 +38922,7 @@
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
@@ -38972,12 +39013,12 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
@@ -38992,7 +39033,7 @@
 msgid "expected template-id"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -39071,208 +39112,208 @@
 msgid "expected type specifier"
 msgstr "Δεν ορίστηκε συντακτικό"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an enumerator-name"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, gcc-internal-format
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr ""
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -39281,7 +39322,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "μη έγκυρος χρήστης"
@@ -39288,292 +39329,292 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, fuzzy, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, fuzzy, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr ""
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr ""
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "δε βρέθηκε ο προεπεξεργαστής C: %s \n"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr ""
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -39582,247 +39623,247 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
@@ -39829,288 +39870,288 @@
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Προσδιοριστής αφαιρέθηκε"
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 msgid "expected positive integer expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
 # src/request.c:263
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, fuzzy, gcc-internal-format
 msgid "not enough collapsed for loops"
 msgstr "εμφάνιση πληροφοριών προόδου"
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 msgid "expected variable-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, fuzzy, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -40117,67 +40158,67 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, fuzzy, gcc-internal-format
 msgid "candidate is: %#D"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr ""
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %D (should be %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -40184,57 +40225,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, fuzzy, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -40247,92 +40288,92 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "Στη συνάρτηση μέλος `%s':"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, fuzzy, gcc-internal-format
 msgid "        %qD"
 msgstr "        `%D'"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, fuzzy, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "((ανώνυμο))"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, fuzzy, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr ""
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -40339,12 +40380,12 @@
 msgstr[0] "%s' δεν είναι ισχύων θετικός ακέραιος."
 msgstr[1] "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -40352,42 +40393,42 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr ""
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, fuzzy, gcc-internal-format
 msgid "template class without a name"
 msgstr "μη τερματιζόμενο όνομα βάρους"
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -40397,57 +40438,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  αλλά %d απαιτούνται"
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -40454,7 +40495,7 @@
 msgstr[0] "διπλό όνομα χαρακτήρα `%s'"
 msgstr[1] "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q+D used %d template parameter"
 msgid_plural "previous declaration %q+D used %d template parameters"
@@ -40461,12 +40502,12 @@
 msgstr[0] "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 msgstr[1] "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
@@ -40475,102 +40516,102 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -40577,172 +40618,172 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, gcc-internal-format
 msgid "  could not resolve address from overloaded function %qE"
 msgstr ""
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT "
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr ""
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr ""
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, fuzzy, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
@@ -40749,77 +40790,77 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr ""
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr ""
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -40837,266 +40878,266 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared here, later in the translation unit"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 msgid "%s %#S"
 msgstr ""
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "διπλός ορισμός συνόλου"
@@ -41108,62 +41149,62 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
@@ -41402,94 +41443,94 @@
 msgid "invalid base-class specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, fuzzy, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
@@ -41496,168 +41537,168 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, fuzzy, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, gcc-internal-format
 msgid "%<num_teams%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, fuzzy, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, fuzzy, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
@@ -41672,117 +41713,117 @@
 msgid "lambda-expression in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr ""
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr ""
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr ""
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -41973,564 +42014,559 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr ""
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr ""
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr ""
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, fuzzy, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr ""
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, fuzzy, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, fuzzy, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, gcc-internal-format
 msgid "taking address of constructor %qE"
 msgstr ""
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, gcc-internal-format
 msgid "taking address of destructor %qE"
 msgstr ""
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr ""
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr ""
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, fuzzy, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, fuzzy, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, fuzzy, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, fuzzy, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr ""
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, fuzzy, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, fuzzy, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr ""
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, fuzzy, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "xdr_reference: η μνήμη εξαντλήθηκε\n"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr ""
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, gcc-internal-format
 msgid "address of label %q+D returned"
 msgstr ""
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr ""
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -42537,45 +42573,45 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -42801,122 +42837,122 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, fuzzy, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr ""
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, fuzzy, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr ""
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
@@ -43093,8 +43129,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -43229,7 +43265,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -43345,7 +43381,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
@@ -43932,12 +43968,12 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
@@ -44207,6 +44243,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr ""
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -44214,7 +44255,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -44435,211 +44476,211 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
 # src/request.c:263
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
 # src/request.c:263
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 msgid "Function name %qs not allowed at %C"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
 # src/request.c:263
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
@@ -44646,193 +44687,193 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -44839,796 +44880,801 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Έχει παραληφθεί εντολή"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:5597
-#, gcc-internal-format
-msgid "gfc_match_entry(): Bad state"
+#: fortran/decl.c:5595
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Αγνωστος δυαδικός χειριστής."
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr ""
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων κατηγοριών"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected"
 msgid "%<)%> expected at %C"
 msgstr "αναμενόταν '('"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, gcc-internal-format, gfc-internal-format
+msgid "Malformed GENERIC statement at %C"
+msgstr ""
+
+#: fortran/decl.c:8526
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
@@ -45910,342 +45956,342 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr ""
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 msgid "Conversion from %qs to %qs at %L"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "%s: Μη έγκυρη ρύθμιση `%s'.\n"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "αδυναμία ανοίγματος αρχείου εισόδου `%s'"
@@ -46268,27 +46314,27 @@
 msgid "Removing call to function %qs at %L"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr ""
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr ""
@@ -46343,592 +46389,597 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr ""
+
+#: fortran/interface.c:353
+#, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr ""
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr ""
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, gcc-internal-format
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr ""
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr ""
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr ""
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr ""
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr ""
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr ""
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr ""
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr ""
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, gcc-internal-format
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr ""
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, gcc-internal-format
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr ""
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, gcc-internal-format
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr ""
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr ""
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "πολύ λίγα ορίσματα"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, fuzzy, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, gcc-internal-format
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
@@ -47340,12 +47391,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
@@ -47355,7 +47406,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
@@ -47380,234 +47431,234 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr ""
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "μη ορισμένο"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr ""
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error at %qs token"
 msgid "Syntax error in %s statement at %C"
 msgstr "συντακτικό σφάλμα στο σύμβολο %qs"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr ""
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
 msgstr ""
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "%s: Αναμενόταν δυαδικός χειριστής.\n"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "%s: Αναμενόταν δυαδικός χειριστής.\n"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr ""
@@ -47614,545 +47665,545 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 msgid "Label name %qs at %C is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, fuzzy, gcc-internal-format
 msgid "Duplicate construct label %qs at %C"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr "Μη έγκυρος χαρακτήρας ονόματος κλάσης"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr ""
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr ""
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr ""
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr ""
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr ""
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, gcc-internal-format, gfc-internal-format
 msgid "gfc_match(): Bad match code %c"
 msgstr ""
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr ""
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr ""
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr ""
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
 msgstr ""
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr ""
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr ""
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr ""
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in association at %C"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, gcc-internal-format
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr ""
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr ""
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, gcc-internal-format
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr ""
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr ""
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr ""
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr ""
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr ""
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr ""
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr ""
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr ""
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr ""
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr ""
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
@@ -48160,147 +48211,147 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr ""
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr ""
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "πάρα πολλά ορίσματα"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr ""
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr ""
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
@@ -48446,168 +48497,168 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "%s: Σφάλμα εγγραφής "
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: Σφάλμα κατά την εγγραφή του %s\n"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: Δεν είναι δυνατόν να δημιουργηθεί %s: %s\n"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: Προειδοποίηση: η uname απέτυχε: %s\n"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: Δε μπορεί να διαγραφεί το %s: %s\n"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr ""
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: Δεν είναι δυνατόν να ανοιχτεί το %s: %s\n"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr ""
@@ -48902,7 +48953,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -49595,367 +49646,362 @@
 msgid "Unexpected %s statement at %C"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/parse.c:2428
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr ""
-
-#: fortran/parse.c:2439
-#, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr ""
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr ""
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr ""
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr ""
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr ""
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr ""
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr ""
@@ -49963,7 +50009,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -50661,7 +50707,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -50718,363 +50764,363 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr ""
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -51083,12 +51129,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -51097,248 +51143,248 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -51347,188 +51393,188 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -51535,12 +51581,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -51548,158 +51594,158 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr ""
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr ""
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr ""
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -51706,7 +51752,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -51714,57 +51760,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr ""
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
@@ -51771,422 +51817,422 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -52193,397 +52239,397 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -52613,47 +52659,47 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr ""
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr ""
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr ""
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "κενό αλφαριθμητικό"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr ""
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
 msgstr ""
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr ""
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr ""
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr ""
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 msgid "Can't open file %qs"
 msgstr "αδυναμία ανοίγματος αρχείου εισόδου `%s'"
@@ -52919,52 +52965,52 @@
 msgid "Reshaped array too large at %C"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr ""
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr ""
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -53042,182 +53088,187 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
+#, gcc-internal-format, gfc-internal-format
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr ""
+
+#: fortran/symbol.c:489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, gcc-internal-format
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute with %s attribute at %L"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, gcc-internal-format
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr ""
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr ""
@@ -53224,133 +53275,133 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr ""
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -53612,7 +53663,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
Index: gcc/po/zh_CN.po
===================================================================
--- gcc/po/zh_CN.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/po/zh_CN.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.9-b20140202\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
-"POT-Creation-Date: 2015-04-13 20:12+0000\n"
+"POT-Creation-Date: 2015-07-02 12:31+0000\n"
 "PO-Revision-Date: 2014-05-14 14:25-0800\n"
 "Last-Translator: Meng Jie <zuxy.meng@gmail.com>\n"
 "Language-Team: Chinese (simplified) <i18n-zh@googlegroups.com>\n"
@@ -194,13 +194,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14656
+#: final.c:3973 config/arc/arc.c:4653 config/i386/i386.c:14715
 #: config/pdp11/pdp11.c:1727
 #, c-format
 msgid "floating constant misused"
 msgstr "错误地使用了浮点常量"
 
-#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14754
+#: final.c:4031 config/arc/arc.c:4725 config/i386/i386.c:14813
 #: config/pdp11/pdp11.c:1768
 #, c-format
 msgid "invalid expression as operand"
@@ -1389,7 +1389,7 @@
 msgid "options enabled: "
 msgstr "启用的选项："
 
-#: tree-diagnostic.c:306 c/c-decl.c:5183 c/c-typeck.c:6556 cp/error.c:700
+#: tree-diagnostic.c:306 c/c-decl.c:5184 c/c-typeck.c:6556 cp/error.c:700
 #: cp/error.c:1006 c-family/c-pretty-print.c:443
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2605,97 +2605,97 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/alpha/alpha.c:5167 config/i386/i386.c:15838
-#: config/rs6000/rs6000.c:19026 config/sparc/sparc.c:8821
+#: config/alpha/alpha.c:5173 config/i386/i386.c:15897
+#: config/rs6000/rs6000.c:19130 config/sparc/sparc.c:8825
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "使用‘%%&’ 时没有指定任何动态 TLS 引用"
 
-#: config/alpha/alpha.c:5207
+#: config/alpha/alpha.c:5213
 #, c-format
 msgid "invalid %%H value"
 msgstr "无效 %%H 值"
 
-#: config/alpha/alpha.c:5228 config/bfin/bfin.c:1462
+#: config/alpha/alpha.c:5234 config/bfin/bfin.c:1462
 #, c-format
 msgid "invalid %%J value"
 msgstr "无效 %%J 值"
 
-#: config/alpha/alpha.c:5258 config/ia64/ia64.c:5528
+#: config/alpha/alpha.c:5264 config/ia64/ia64.c:5528
 #, c-format
 msgid "invalid %%r value"
 msgstr "无效 %%r 值"
 
-#: config/alpha/alpha.c:5268 config/ia64/ia64.c:5482
-#: config/rs6000/rs6000.c:18675 config/xtensa/xtensa.c:2391
+#: config/alpha/alpha.c:5274 config/ia64/ia64.c:5482
+#: config/rs6000/rs6000.c:18779 config/xtensa/xtensa.c:2391
 #, c-format
 msgid "invalid %%R value"
 msgstr "无效 %%R 值"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:18595
+#: config/alpha/alpha.c:5280 config/rs6000/rs6000.c:18699
 #: config/xtensa/xtensa.c:2358
 #, c-format
 msgid "invalid %%N value"
 msgstr "无效 %%N 值"
 
-#: config/alpha/alpha.c:5282 config/rs6000/rs6000.c:18623
+#: config/alpha/alpha.c:5288 config/rs6000/rs6000.c:18727
 #, c-format
 msgid "invalid %%P value"
 msgstr "无效 %%P 值"
 
-#: config/alpha/alpha.c:5290
+#: config/alpha/alpha.c:5296
 #, c-format
 msgid "invalid %%h value"
 msgstr "无效 %%h 值"
 
-#: config/alpha/alpha.c:5298 config/xtensa/xtensa.c:2384
+#: config/alpha/alpha.c:5304 config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%L value"
 msgstr "无效 %%L 值"
 
-#: config/alpha/alpha.c:5337 config/rs6000/rs6000.c:18577
+#: config/alpha/alpha.c:5343 config/rs6000/rs6000.c:18681
 #, c-format
 msgid "invalid %%m value"
 msgstr "无效 %%m 值"
 
-#: config/alpha/alpha.c:5345 config/rs6000/rs6000.c:18585
+#: config/alpha/alpha.c:5351 config/rs6000/rs6000.c:18689
 #, c-format
 msgid "invalid %%M value"
 msgstr "无效 %%M 值"
 
-#: config/alpha/alpha.c:5389
+#: config/alpha/alpha.c:5395
 #, c-format
 msgid "invalid %%U value"
 msgstr "无效 %%U 值"
 
-#: config/alpha/alpha.c:5397 config/alpha/alpha.c:5408
-#: config/rs6000/rs6000.c:18683
+#: config/alpha/alpha.c:5403 config/alpha/alpha.c:5414
+#: config/rs6000/rs6000.c:18787
 #, c-format
 msgid "invalid %%s value"
 msgstr "无效 %%s 值"
 
-#: config/alpha/alpha.c:5419
+#: config/alpha/alpha.c:5425
 #, c-format
 msgid "invalid %%C value"
 msgstr "无效 %%C 值"
 
-#: config/alpha/alpha.c:5456 config/rs6000/rs6000.c:18442
+#: config/alpha/alpha.c:5462 config/rs6000/rs6000.c:18546
 #, c-format
 msgid "invalid %%E value"
 msgstr "无效 %%E 值"
 
-#: config/alpha/alpha.c:5481 config/alpha/alpha.c:5529
+#: config/alpha/alpha.c:5487 config/alpha/alpha.c:5535
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "未指定未知的重定位方式"
 
-#: config/alpha/alpha.c:5490 config/cr16/cr16.c:1570
-#: config/rs6000/rs6000.c:19031 config/spu/spu.c:1487
+#: config/alpha/alpha.c:5496 config/cr16/cr16.c:1570
+#: config/rs6000/rs6000.c:19135 config/spu/spu.c:1487
 #, c-format
 msgid "invalid %%xn code"
 msgstr "无效的 %%xn 代码"
 
-#: config/alpha/alpha.c:5594
+#: config/alpha/alpha.c:5600
 #, fuzzy, c-format
 msgid "invalid operand address"
 msgstr "无效的引用前缀"
@@ -2743,7 +2743,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3155 config/epiphany/epiphany.c:1318
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9006
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2329 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid operand output code"
 msgstr "无效的操作数输出代码"
@@ -2900,8 +2900,8 @@
 
 #: config/cris/cris.c:645 config/moxie/moxie.c:143 final.c:3440 final.c:3442
 #: fold-const.c:301 gcc.c:4972 gcc.c:4986 loop-iv.c:3100 loop-iv.c:3109
-#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7560
-#: cp/typeck.c:5911 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
+#: rtl-error.c:103 toplev.c:383 tree-ssa-loop-niter.c:2075 tree-vrp.c:7565
+#: cp/typeck.c:5902 java/expr.c:402 lto/lto-object.c:211 lto/lto-object.c:308
 #: lto/lto-object.c:365 lto/lto-object.c:389
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -3121,62 +3121,62 @@
 msgid "bad output_condmove_single operand"
 msgstr "错误的 output_condmove_single 操作数"
 
-#: config/i386/i386.c:14748
+#: config/i386/i386.c:14807
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "无效的 UNSPEC 用作操作数"
 
-#: config/i386/i386.c:15462
+#: config/i386/i386.c:15521
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "操作数代码‘%c’的操作数大小无效"
 
-#: config/i386/i386.c:15497
+#: config/i386/i386.c:15556
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "操作数代码‘%c’的操作数大小无效"
 
-#: config/i386/i386.c:15567
+#: config/i386/i386.c:15626
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "操作数代码‘%c’的操作数类型无效"
 
-#: config/i386/i386.c:15572
+#: config/i386/i386.c:15631
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "操作数代码‘%c’的操作数大小无效"
 
-#: config/i386/i386.c:15648
+#: config/i386/i386.c:15707
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:15721
+#: config/i386/i386.c:15780
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.c:15738
+#: config/i386/i386.c:15797
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.c:15751
+#: config/i386/i386.c:15810
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.c:15916
+#: config/i386/i386.c:15975
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/i386/i386.c:15972
+#: config/i386/i386.c:16031
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "操作数的约束无效"
 
-#: config/i386/i386.c:25988
+#: config/i386/i386.c:26087
 msgid "unknown insn mode"
 msgstr "未知的指令模式"
 
@@ -3217,7 +3217,7 @@
 msgid "invalid %%P operand"
 msgstr "无效的 %%P 操作数"
 
-#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18613
+#: config/iq2000/iq2000.c:3174 config/rs6000/rs6000.c:18717
 #, c-format
 msgid "invalid %%p value"
 msgstr "无效的 %%p 值"
@@ -3281,7 +3281,7 @@
 msgstr "后自增地址不是一个寄存器"
 
 #: config/m32r/m32r.c:2351 config/m32r/m32r.c:2366
-#: config/rs6000/rs6000.c:29215
+#: config/rs6000/rs6000.c:29313
 msgid "bad address"
 msgstr "错误地址"
 
@@ -3446,101 +3446,101 @@
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "生成小端在前的代码"
 
-#: config/rs6000/rs6000.c:8893
+#: config/rs6000/rs6000.c:8925
 msgid "bad move"
 msgstr "错误的移动"
 
-#: config/rs6000/rs6000.c:18430
+#: config/rs6000/rs6000.c:18534
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "无效 %%H 值"
 
-#: config/rs6000/rs6000.c:18451
+#: config/rs6000/rs6000.c:18555
 #, c-format
 msgid "invalid %%f value"
 msgstr "无效 %%f 值"
 
-#: config/rs6000/rs6000.c:18460
+#: config/rs6000/rs6000.c:18564
 #, c-format
 msgid "invalid %%F value"
 msgstr "无效 %%F 值"
 
-#: config/rs6000/rs6000.c:18469
+#: config/rs6000/rs6000.c:18573
 #, c-format
 msgid "invalid %%G value"
 msgstr "无效 %%G 值"
 
-#: config/rs6000/rs6000.c:18504
+#: config/rs6000/rs6000.c:18608
 #, c-format
 msgid "invalid %%j code"
 msgstr "无效 %%j 代码"
 
-#: config/rs6000/rs6000.c:18514
+#: config/rs6000/rs6000.c:18618
 #, c-format
 msgid "invalid %%J code"
 msgstr "无效 %%J 代码"
 
-#: config/rs6000/rs6000.c:18524
+#: config/rs6000/rs6000.c:18628
 #, c-format
 msgid "invalid %%k value"
 msgstr "无效 %%k 值"
 
-#: config/rs6000/rs6000.c:18539 config/xtensa/xtensa.c:2377
+#: config/rs6000/rs6000.c:18643 config/xtensa/xtensa.c:2377
 #, c-format
 msgid "invalid %%K value"
 msgstr "无效 %%K 值"
 
-#: config/rs6000/rs6000.c:18603
+#: config/rs6000/rs6000.c:18707
 #, c-format
 msgid "invalid %%O value"
 msgstr "无效 %%O 值"
 
-#: config/rs6000/rs6000.c:18650
+#: config/rs6000/rs6000.c:18754
 #, c-format
 msgid "invalid %%q value"
 msgstr "无效 %%q 值"
 
-#: config/rs6000/rs6000.c:18693
+#: config/rs6000/rs6000.c:18797
 #, c-format
 msgid "invalid %%S value"
 msgstr "无效 %%S 值"
 
-#: config/rs6000/rs6000.c:18733
+#: config/rs6000/rs6000.c:18837
 #, c-format
 msgid "invalid %%T value"
 msgstr "无效 %%T 值"
 
-#: config/rs6000/rs6000.c:18745
+#: config/rs6000/rs6000.c:18849
 #, c-format
 msgid "invalid %%u value"
 msgstr "无效 %%u 值"
 
-#: config/rs6000/rs6000.c:18759 config/xtensa/xtensa.c:2347
+#: config/rs6000/rs6000.c:18863 config/xtensa/xtensa.c:2347
 #, c-format
 msgid "invalid %%v value"
 msgstr "无效 %%v 值"
 
-#: config/rs6000/rs6000.c:18833 config/xtensa/xtensa.c:2398
+#: config/rs6000/rs6000.c:18937 config/xtensa/xtensa.c:2398
 #, c-format
 msgid "invalid %%x value"
 msgstr "无效的 %%x 值"
 
-#: config/rs6000/rs6000.c:18975
+#: config/rs6000/rs6000.c:19079
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "无效 %%y 值，请试用“Z”约束"
 
-#: config/rs6000/rs6000.c:32106
+#: config/rs6000/rs6000.c:32204
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/rs6000/rs6000.c:33798
+#: config/rs6000/rs6000.c:33940
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "不为每个函数生成单一的退出点"
 
-#: config/rs6000/rs6000.c:33857
+#: config/rs6000/rs6000.c:33999
 #, fuzzy
 msgid "Unable to generate load offset for fusion"
 msgstr "无法生成重新载入，为："
@@ -3635,60 +3635,60 @@
 msgid "invalid operand to %%S"
 msgstr "%%S 的操作数无效"
 
-#: config/sh/sh.c:9956
+#: config/sh/sh.c:9957
 msgid "created and used with different architectures / ABIs"
 msgstr "创建和使用时使用了不同的架构/ABI"
 
-#: config/sh/sh.c:9958
+#: config/sh/sh.c:9959
 msgid "created and used with different ABIs"
 msgstr "创建和使用时使用了不同的 ABI"
 
-#: config/sh/sh.c:9960
+#: config/sh/sh.c:9961
 msgid "created and used with different endianness"
 msgstr "创建和使用时使用了不同的大小端设定"
 
-#: config/sparc/sparc.c:8830 config/sparc/sparc.c:8836
+#: config/sparc/sparc.c:8834 config/sparc/sparc.c:8840
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "无效的 %%Y 操作数"
 
-#: config/sparc/sparc.c:8906
+#: config/sparc/sparc.c:8910
 #, c-format
 msgid "invalid %%A operand"
 msgstr "无效的 %%A 操作数"
 
-#: config/sparc/sparc.c:8916
+#: config/sparc/sparc.c:8920
 #, c-format
 msgid "invalid %%B operand"
 msgstr "无效的 %%B 操作数"
 
-#: config/sparc/sparc.c:8945 config/tilegx/tilegx.c:5134
+#: config/sparc/sparc.c:8949 config/tilegx/tilegx.c:5134
 #: config/tilepro/tilepro.c:4550
 #, fuzzy, c-format
 msgid "invalid %%C operand"
 msgstr "无效的 %%P 操作数"
 
-#: config/sparc/sparc.c:8962 config/tilegx/tilegx.c:5167
+#: config/sparc/sparc.c:8966 config/tilegx/tilegx.c:5167
 #, fuzzy, c-format
 msgid "invalid %%D operand"
 msgstr "无效的 %%P 操作数"
 
-#: config/sparc/sparc.c:8978
+#: config/sparc/sparc.c:8982
 #, c-format
 msgid "invalid %%f operand"
 msgstr "无效的 %%f 操作数"
 
-#: config/sparc/sparc.c:8992
+#: config/sparc/sparc.c:8996
 #, c-format
 msgid "invalid %%s operand"
 msgstr "无效的 %%s 操作数"
 
-#: config/sparc/sparc.c:9046
+#: config/sparc/sparc.c:9050
 #, c-format
 msgid "long long constant not a valid immediate operand"
 msgstr "long long 常量不是一个有效的立即数操作数"
 
-#: config/sparc/sparc.c:9049
+#: config/sparc/sparc.c:9053
 #, c-format
 msgid "floating point constant not a valid immediate operand"
 msgstr "浮点常量不是一个有效的立即数操作数"
@@ -3901,7 +3901,7 @@
 #: c/c-parser.c:8517 c/c-parser.c:8698 c/c-parser.c:9478 c/c-parser.c:9548
 #: c/c-parser.c:9591 c/c-parser.c:12688 c/c-parser.c:12707 c/c-parser.c:12725
 #: c/c-parser.c:12879 c/c-parser.c:12922 c/c-parser.c:2806 c/c-parser.c:8691
-#: cp/parser.c:24256 cp/parser.c:24828
+#: cp/parser.c:24294 cp/parser.c:24866
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要%<;%>"
@@ -3917,15 +3917,15 @@
 #: c/c-parser.c:11128 c/c-parser.c:11176 c/c-parser.c:11215 c/c-parser.c:11261
 #: c/c-parser.c:11297 c/c-parser.c:11337 c/c-parser.c:11389 c/c-parser.c:11431
 #: c/c-parser.c:11466 c/c-parser.c:11514 c/c-parser.c:11572 c/c-parser.c:12841
-#: c/c-parser.c:14258 c/c-parser.c:14468 c/c-parser.c:14818 c/c-parser.c:14876
-#: c/c-parser.c:15301 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22560
-#: cp/parser.c:24831
+#: c/c-parser.c:14255 c/c-parser.c:14465 c/c-parser.c:14815 c/c-parser.c:14873
+#: c/c-parser.c:15298 c/c-parser.c:10492 c/c-parser.c:10517 cp/parser.c:22591
+#: cp/parser.c:24869
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "需要%<(%>"
 
 #: c/c-parser.c:2068 c/c-parser.c:6878 c/c-parser.c:7265 c/c-parser.c:7303
-#: c/c-parser.c:7434 cp/parser.c:24254 cp/parser.c:24846
+#: c/c-parser.c:7434 cp/parser.c:24292 cp/parser.c:24884
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "需要 %<,%>"
@@ -3947,8 +3947,8 @@
 #: c/c-parser.c:11365 c/c-parser.c:11371 c/c-parser.c:11408 c/c-parser.c:11420
 #: c/c-parser.c:11437 c/c-parser.c:11473 c/c-parser.c:11485 c/c-parser.c:11533
 #: c/c-parser.c:11541 c/c-parser.c:11576 c/c-parser.c:12761 c/c-parser.c:12887
-#: c/c-parser.c:12933 c/c-parser.c:14447 c/c-parser.c:14520 c/c-parser.c:14854
-#: c/c-parser.c:14938 c/c-parser.c:15310 cp/parser.c:22583 cp/parser.c:24876
+#: c/c-parser.c:12933 c/c-parser.c:14444 c/c-parser.c:14517 c/c-parser.c:14851
+#: c/c-parser.c:14935 c/c-parser.c:15307 cp/parser.c:22623 cp/parser.c:24914
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "需要%<)%>"
@@ -3955,8 +3955,8 @@
 
 #: c/c-parser.c:3439 c/c-parser.c:4360 c/c-parser.c:4396 c/c-parser.c:5829
 #: c/c-parser.c:7370 c/c-parser.c:7705 c/c-parser.c:7849 c/c-parser.c:10172
-#: c/c-parser.c:15213 c/c-parser.c:15215 c/c-parser.c:15552 cp/parser.c:6487
-#: cp/parser.c:24840
+#: c/c-parser.c:15210 c/c-parser.c:15212 c/c-parser.c:15549 cp/parser.c:6487
+#: cp/parser.c:24878
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "需要%<]%>"
@@ -3965,13 +3965,13 @@
 msgid "expected %<;%>, %<,%> or %<)%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24834 cp/parser.c:26706
+#: c/c-parser.c:4220 c/c-parser.c:12708 cp/parser.c:24872 cp/parser.c:26744
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "需要 %<}%>"
 
-#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13292 c/c-parser.c:2624
-#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15853 cp/parser.c:24837
+#: c/c-parser.c:4529 c/c-parser.c:9032 c/c-parser.c:13288 c/c-parser.c:2624
+#: c/c-parser.c:2827 c/c-parser.c:8586 cp/parser.c:15877 cp/parser.c:24875
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要%<{%>"
@@ -3978,8 +3978,8 @@
 
 #: c/c-parser.c:4760 c/c-parser.c:4769 c/c-parser.c:5736 c/c-parser.c:6073
 #: c/c-parser.c:6926 c/c-parser.c:8797 c/c-parser.c:9180 c/c-parser.c:9241
-#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14315
-#: c/c-parser.c:14371 cp/parser.c:24870 cp/parser.c:25928
+#: c/c-parser.c:10159 c/c-parser.c:10853 c/c-parser.c:11356 c/c-parser.c:14312
+#: c/c-parser.c:14368 cp/parser.c:24908 cp/parser.c:25966
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "需要 %<:%>"
@@ -4004,7 +4004,7 @@
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr "new 不能用于函数类型"
 
-#: c/c-parser.c:5396 cp/parser.c:24764
+#: c/c-parser.c:5396 cp/parser.c:24802
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "需要 %<while%>"
@@ -4023,34 +4023,34 @@
 msgid "expected %<.%>"
 msgstr "需要%<.%>"
 
-#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26491
-#: cp/parser.c:26565
+#: c/c-parser.c:8257 c/c-parser.c:8289 c/c-parser.c:8529 cp/parser.c:26529
+#: cp/parser.c:26603
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "需要 %<@end%>"
 
-#: c/c-parser.c:8946 cp/parser.c:24855
+#: c/c-parser.c:8946 cp/parser.c:24893
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "需要 %<>%>"
 
-#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24879
+#: c/c-parser.c:10961 c/c-parser.c:11489 cp/parser.c:24917
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "需要 %<,%> 或 %<)%>"
 
 #: c/c-parser.c:12440 c/c-parser.c:12471 c/c-parser.c:12694 c/c-parser.c:12868
-#: c/c-parser.c:14505 c/c-parser.c:15040 c/c-parser.c:4419 cp/parser.c:24858
+#: c/c-parser.c:14502 c/c-parser.c:15037 c/c-parser.c:4419 cp/parser.c:24896
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要%<=%>"
 
-#: c/c-parser.c:13335 c/c-parser.c:13325 cp/parser.c:30862
+#: c/c-parser.c:13331 c/c-parser.c:13321 cp/parser.c:30896
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
 
-#: c/c-parser.c:15201 c/c-parser.c:10134 cp/parser.c:24843 cp/parser.c:27789
+#: c/c-parser.c:15198 c/c-parser.c:10134 cp/parser.c:24881 cp/parser.c:27827
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "需要%<[%>"
@@ -4059,11 +4059,11 @@
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: cp/call.c:9230
+#: cp/call.c:9242
 msgid "candidate 1:"
 msgstr "备选 1："
 
-#: cp/call.c:9231
+#: cp/call.c:9243
 msgid "candidate 2:"
 msgstr "备选 2："
 
@@ -4289,11 +4289,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%s:%d：在%qs的广义常表达式扩展中"
 
-#: cp/pt.c:1807 cp/semantics.c:4850
+#: cp/pt.c:1808 cp/semantics.c:4856
 msgid "candidates are:"
 msgstr "备选为："
 
-#: cp/pt.c:19440
+#: cp/pt.c:19576
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "备选是："
@@ -4338,48 +4338,48 @@
 msgid "source type is not polymorphic"
 msgstr "源类型不是多态的"
 
-#: cp/typeck.c:5663 c/c-typeck.c:3884
+#: cp/typeck.c:5654 c/c-typeck.c:3884
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "单目减的操作数类型错误"
 
-#: cp/typeck.c:5664 c/c-typeck.c:3871
+#: cp/typeck.c:5655 c/c-typeck.c:3871
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "单目加的操作数类型错误"
 
-#: cp/typeck.c:5691 c/c-typeck.c:3910
+#: cp/typeck.c:5682 c/c-typeck.c:3910
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "按位取反的参数类型错误"
 
-#: cp/typeck.c:5698 c/c-typeck.c:3918
+#: cp/typeck.c:5689 c/c-typeck.c:3918
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "不能对该类型的参数求绝对值"
 
-#: cp/typeck.c:5710 c/c-typeck.c:3930
+#: cp/typeck.c:5701 c/c-typeck.c:3930
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "不能对该类型的参数求共轭"
 
-#: cp/typeck.c:5728
+#: cp/typeck.c:5719
 msgid "in argument to unary !"
 msgstr "单目 ! 的参数中"
 
-#: cp/typeck.c:5777
+#: cp/typeck.c:5768
 msgid "no pre-increment operator for type"
 msgstr "类型没有前自增运算符"
 
-#: cp/typeck.c:5779
+#: cp/typeck.c:5770
 msgid "no post-increment operator for type"
 msgstr "类型没有后自增运算符"
 
-#: cp/typeck.c:5781
+#: cp/typeck.c:5772
 msgid "no pre-decrement operator for type"
 msgstr "类型没有前自减运算符"
 
-#: cp/typeck.c:5783
+#: cp/typeck.c:5774
 msgid "no post-decrement operator for type"
 msgstr "类型没有后自减运算符"
 
@@ -4477,7 +4477,7 @@
 msgid "Integer value too large in expression at %C"
 msgstr "%C处表达式中整数值太大"
 
-#: fortran/expr.c:3193
+#: fortran/expr.c:3196
 msgid "array assignment"
 msgstr "数组赋值"
 
@@ -4500,7 +4500,7 @@
 msgid "Driving:"
 msgstr "驱动："
 
-#: fortran/interface.c:2904 fortran/intrinsic.c:3941
+#: fortran/interface.c:2908 fortran/intrinsic.c:3941
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4570,7 +4570,7 @@
 msgid "%s tag"
 msgstr "%s 标记"
 
-#: fortran/io.c:2863
+#: fortran/io.c:2861
 #, fuzzy
 msgid "internal unit in WRITE"
 msgstr "gcc 内部放弃 %s，于 %s:%d"
@@ -4577,7 +4577,7 @@
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4055
+#: fortran/io.c:4053
 #, fuzzy, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s 与%<%%%c%>%s 格式并用"
@@ -4655,7 +4655,7 @@
 msgid "Bad type in constant expression"
 msgstr "常量表达式中类型错误"
 
-#: fortran/module.c:6745
+#: fortran/module.c:6741
 msgid "Unexpected end of module"
 msgstr "非预期的模块结束"
 
@@ -4683,11 +4683,11 @@
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.c:1811 fortran/resolve.c:10179
+#: fortran/parse.c:1811 fortran/resolve.c:10175
 msgid "assignment"
 msgstr "赋值"
 
-#: fortran/parse.c:1814 fortran/resolve.c:10224 fortran/resolve.c:10227
+#: fortran/parse.c:1814 fortran/resolve.c:10220 fortran/resolve.c:10223
 msgid "pointer assignment"
 msgstr "指针赋值"
 
@@ -4703,210 +4703,210 @@
 msgid "internal function"
 msgstr "内部函数"
 
-#: fortran/resolve.c:2147 fortran/resolve.c:2341
+#: fortran/resolve.c:2148 fortran/resolve.c:2342
 msgid "elemental procedure"
 msgstr "基本过程"
 
-#: fortran/resolve.c:2244
+#: fortran/resolve.c:2245
 #, fuzzy
 msgid "allocatable argument"
 msgstr "没有参数"
 
-#: fortran/resolve.c:2249
+#: fortran/resolve.c:2250
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "实参太少"
 
-#: fortran/resolve.c:2254
+#: fortran/resolve.c:2255
 #, fuzzy
 msgid "optional argument"
 msgstr "无效的 PHI 实参"
 
-#: fortran/resolve.c:2259
+#: fortran/resolve.c:2260
 #, fuzzy
 msgid "pointer argument"
 msgstr "指针赋值"
 
-#: fortran/resolve.c:2264
+#: fortran/resolve.c:2265
 #, fuzzy
 msgid "target argument"
 msgstr "没有参数"
 
-#: fortran/resolve.c:2269
+#: fortran/resolve.c:2270
 #, fuzzy
 msgid "value argument"
 msgstr "无效的 PHI 实参"
 
-#: fortran/resolve.c:2274
+#: fortran/resolve.c:2275
 #, fuzzy
 msgid "volatile argument"
 msgstr "没有参数"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2280
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "参数不匹配"
 
-#: fortran/resolve.c:2284
+#: fortran/resolve.c:2285
 #, fuzzy
 msgid "assumed-rank argument"
 msgstr "参数不匹配"
 
-#: fortran/resolve.c:2289
+#: fortran/resolve.c:2290
 #, fuzzy
 msgid "coarray argument"
 msgstr "数组赋值"
 
-#: fortran/resolve.c:2294
+#: fortran/resolve.c:2295
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2299
+#: fortran/resolve.c:2300
 #, fuzzy
 msgid "polymorphic argument"
 msgstr "没有参数"
 
-#: fortran/resolve.c:2304
+#: fortran/resolve.c:2305
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2311
+#: fortran/resolve.c:2312
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "参数不匹配"
 
-#: fortran/resolve.c:2322
+#: fortran/resolve.c:2323
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2327
+#: fortran/resolve.c:2328
 #, fuzzy
 msgid "pointer or allocatable result"
 msgstr "%3$L 处“%1$s”分句对象“%2$s”有 ALLOCATABLE 组件"
 
-#: fortran/resolve.c:2334
+#: fortran/resolve.c:2335
 #, fuzzy
 msgid "result with non-constant character length"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:2346
+#: fortran/resolve.c:2347
 #, fuzzy
 msgid "bind(c) procedure"
 msgstr "模块过程"
 
-#: fortran/resolve.c:3548
+#: fortran/resolve.c:3544
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "%%L处 NULL() 指针上下文无效"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3560
 #, c-format
 msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgstr "单目数值运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: fortran/resolve.c:3580
+#: fortran/resolve.c:3576
 #, c-format
 msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgstr "二元数值运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:3595
+#: fortran/resolve.c:3591
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "字符串毗连运算符(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:3614
+#: fortran/resolve.c:3610
 #, c-format
 msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgstr "逻辑运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:3628
+#: fortran/resolve.c:3624
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "%%L处的 .not. 运算符的操作数为 %s"
 
-#: fortran/resolve.c:3642
+#: fortran/resolve.c:3638
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L处复数不能比较大小"
 
-#: fortran/resolve.c:3693
+#: fortran/resolve.c:3689
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L处逻辑值必须与 %s 比较，而不是 %s"
 
-#: fortran/resolve.c:3699
+#: fortran/resolve.c:3695
 #, c-format
 msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgstr "比较运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:3707
+#: fortran/resolve.c:3703
 #, c-format
 msgid "Unknown operator '%s' at %%L"
 msgstr "未知的运算符‘%s’在 %%L处"
 
-#: fortran/resolve.c:3709
+#: fortran/resolve.c:3705
 #, c-format
 msgid "Operand of user operator '%s' at %%L is %s"
 msgstr "用户运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: fortran/resolve.c:3713
+#: fortran/resolve.c:3709
 #, c-format
 msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgstr "用户运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:3801
+#: fortran/resolve.c:3797
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "%%L和%%L处的操作数的秩不一致"
 
-#: fortran/resolve.c:6384
+#: fortran/resolve.c:6380
 msgid "Loop variable"
 msgstr "循环变量"
 
-#: fortran/resolve.c:6388
+#: fortran/resolve.c:6384
 #, fuzzy
 msgid "iterator variable"
 msgstr "未使用的变量%q+D"
 
-#: fortran/resolve.c:6392
+#: fortran/resolve.c:6388
 msgid "Start expression in DO loop"
 msgstr "DO 循环中的开始表达式"
 
-#: fortran/resolve.c:6396
+#: fortran/resolve.c:6392
 msgid "End expression in DO loop"
 msgstr "DO 循环中结束表达式"
 
-#: fortran/resolve.c:6400
+#: fortran/resolve.c:6396
 msgid "Step expression in DO loop"
 msgstr "DO 循环中的步进表达式"
 
-#: fortran/resolve.c:6657 fortran/resolve.c:6660
+#: fortran/resolve.c:6653 fortran/resolve.c:6656
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "减小目标文件"
 
-#: fortran/resolve.c:7012 fortran/resolve.c:7015
+#: fortran/resolve.c:7008 fortran/resolve.c:7011
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "减小目标文件"
 
-#: fortran/resolve.c:7217 fortran/resolve.c:8571
+#: fortran/resolve.c:7213 fortran/resolve.c:8567
 #, fuzzy
 msgid "STAT variable"
 msgstr "未使用的变量%q+D"
 
-#: fortran/resolve.c:7261 fortran/resolve.c:8583
+#: fortran/resolve.c:7257 fortran/resolve.c:8579
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "未使用的变量%q+D"
 
-#: fortran/resolve.c:8432
+#: fortran/resolve.c:8428
 #, fuzzy
 msgid "item in READ"
 msgstr "读取链接脚本"
 
-#: fortran/resolve.c:8595
+#: fortran/resolve.c:8591
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5329,18 +5329,6 @@
 msgid "rx200 cpu does not have FPU hardware"
 msgstr "RX200 CPU 没有 FPU 硬件"
 
-#: config/sparc/freebsd.h:45 config/dragonfly.h:76 config/rs6000/sysv4.h:731
-#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:95
-#: config/i386/freebsd64.h:35
-#, fuzzy
-msgid "consider using '-pg' instead of '-p' with gprof(1)"
-msgstr "与 gprof(1) 一起使用时请考虑使用‘-pg’以代替‘-p’"
-
-#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
-#, fuzzy
-msgid "consider using `-pg' instead of `-p' with gprof(1)"
-msgstr "与 gprof(1) 一起使用时请考虑使用‘-pg’以代替‘-p’"
-
 #: config/sol2.h:222 config/sol2.h:227
 msgid "does not support multilib"
 msgstr "不支持 multilib"
@@ -5353,6 +5341,10 @@
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
 msgstr "-Xbind-now 与 -Xbind-lazy 不兼容"
 
+#: config/vax/vax.h:46 config/vax/vax.h:47
+msgid "profiling not supported with -mg"
+msgstr "取样不支持 -mg"
+
 #: config/mips/r3900.h:37
 msgid "-mhard-float not supported"
 msgstr "不支持 -mhard-float"
@@ -5361,10 +5353,6 @@
 msgid "-msingle-float and -msoft-float cannot both be specified"
 msgstr "不能同时指定 -msingle-float 和 -msoft-float"
 
-#: config/mcore/mcore.h:53
-msgid "the m210 does not have little endian support"
-msgstr "m210 不支持小端在前"
-
 #: config/cris/cris.h:184
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "请勿同时指定 -march=... 和 -mcpu=..."
@@ -5395,6 +5383,13 @@
 msgid "You need a C startup file for -msys-crt0="
 msgstr ""
 
+#: config/dragonfly.h:76 config/sparc/freebsd.h:45 config/rs6000/sysv4.h:731
+#: config/alpha/freebsd.h:33 config/ia64/freebsd.h:26 config/i386/freebsd.h:82
+#: config/i386/freebsd64.h:35
+#, fuzzy
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr "与 gprof(1) 一起使用时请考虑使用‘-pg’以代替‘-p’"
+
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
 #: config/sparc/sol2.h:219 config/sparc/sol2.h:225
@@ -5401,6 +5396,11 @@
 msgid "may not use both -m32 and -m64"
 msgstr "不能同时使用 -m32 和 -m64"
 
+#: config/rs6000/freebsd64.h:161 config/rs6000/freebsd64.h:173
+#, fuzzy
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr "与 gprof(1) 一起使用时请考虑使用‘-pg’以代替‘-p’"
+
 #: config/s390/tpf.h:106
 msgid "static is not supported on TPF-OS"
 msgstr "TPF-OS 不支持 static"
@@ -5414,6 +5414,10 @@
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian 和 -mlittle-endian 不能一起使用"
 
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr "m210 不支持小端在前"
+
 #: config/avr/specs.h:68
 #, fuzzy
 msgid "shared is not supported"
@@ -5441,18 +5445,20 @@
 msgid "no processor type specified for linking"
 msgstr "没有指定链接用的处理器类型"
 
-#: config/pa/pa-hpux10.h:88 config/pa/pa-hpux10.h:91 config/pa/pa-hpux10.h:99
-#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux11.h:109
-#: config/pa/pa-hpux11.h:112 config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32
-#: config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+#: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
+#: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137
+#: config/pa/pa64-hpux.h:29 config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41
+#: config/pa/pa64-hpux.h:44
 #, fuzzy
 msgid "warning: consider linking with '-static' as system libraries with"
 msgstr "警告：考虑链接时使用‘-static’因为系统库"
 
-#: config/pa/pa-hpux10.h:89 config/pa/pa-hpux10.h:92 config/pa/pa-hpux10.h:100
-#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux11.h:110
-#: config/pa/pa-hpux11.h:113 config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33
-#: config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+#: config/pa/pa-hpux10.h:103 config/pa/pa-hpux10.h:106
+#: config/pa/pa-hpux10.h:114 config/pa/pa-hpux10.h:117
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138
+#: config/pa/pa64-hpux.h:30 config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42
+#: config/pa/pa64-hpux.h:45
 msgid "  profiling support are only provided in archive format"
 msgstr "取样支持只支持存档格式"
 
@@ -5488,10 +5494,6 @@
 msgid "the -shared option is not currently supported for VAX ELF"
 msgstr "-shared 选项目前在 VAX ELF 下不受支持"
 
-#: config/vax/vax.h:46 config/vax/vax.h:47
-msgid "profiling not supported with -mg"
-msgstr "取样不支持 -mg"
-
 #: fortran/lang.opt:146
 msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgstr "-J<目录>\t将 MODULE 文件放入目录"
@@ -5678,9 +5680,9 @@
 msgstr "允许在实体名中使用美元符号"
 
 #: fortran/lang.opt:433 config/alpha/alpha.opt:31 common.opt:696
-#: common.opt:878 common.opt:882 common.opt:886 common.opt:890 common.opt:1346
-#: common.opt:1495 common.opt:1499 common.opt:1721 common.opt:1863
-#: common.opt:2486
+#: common.opt:881 common.opt:885 common.opt:889 common.opt:893 common.opt:1349
+#: common.opt:1498 common.opt:1502 common.opt:1724 common.opt:1866
+#: common.opt:2489
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "不起作用。为向前兼容保留的选项。"
 
@@ -5893,10 +5895,10 @@
 
 #: fortran/lang.opt:679 c-family/c.opt:1064 c-family/c.opt:1088
 #: c-family/c.opt:1314 config/pa/pa.opt:42 config/pa/pa.opt:66
-#: config/sh/sh.opt:213 common.opt:1023 common.opt:1246 common.opt:1574
-#: common.opt:1900 common.opt:1936 common.opt:2025 common.opt:2029
-#: common.opt:2121 common.opt:2203 common.opt:2227 common.opt:2328
-#: common.opt:2446
+#: config/sh/sh.opt:213 common.opt:1026 common.opt:1249 common.opt:1577
+#: common.opt:1903 common.opt:1939 common.opt:2028 common.opt:2032
+#: common.opt:2124 common.opt:2206 common.opt:2230 common.opt:2331
+#: common.opt:2449
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "不起作用。为向前兼容保留的选项。"
 
@@ -5943,7 +5945,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:216 c-family/c.opt:220
 #: c-family/c.opt:232 c-family/c.opt:1497 c-family/c.opt:1505
-#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2701
+#: config/darwin.opt:53 common.opt:316 common.opt:319 common.opt:2704
 #, c-format
 msgid "missing filename after %qs"
 msgstr "%qs后缺少文件名"
@@ -7868,48 +7870,52 @@
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:76 config/arm/arm.opt:151
+#: config/aarch64/aarch64.opt:76
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:80 config/arm/arm.opt:151
 #: config/microblaze/microblaze.opt:64
 msgid "Assume target CPU is configured as little endian"
 msgstr "假定目标 CPU 被配置为小端在前"
 
-#: config/aarch64/aarch64.opt:80
+#: config/aarch64/aarch64.opt:84
 #, fuzzy
 msgid "Specify the code model"
 msgstr "选择代码模型"
 
-#: config/aarch64/aarch64.opt:84
+#: config/aarch64/aarch64.opt:88
 msgid "Don't assume that unaligned accesses are handled by the system"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/i386/i386.opt:390
+#: config/aarch64/aarch64.opt:92 config/i386/i386.opt:390
 msgid "Omit the frame pointer in leaf functions"
 msgstr "为叶函数(不调用其他函数的函数)忽略框架指针"
 
-#: config/aarch64/aarch64.opt:92
+#: config/aarch64/aarch64.opt:96
 msgid "Specify TLS dialect"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:96
+#: config/aarch64/aarch64.opt:100
 #, fuzzy
 msgid "-march=ARCH\tUse features of architecture ARCH"
 msgstr "-mcpu=\t使用指定 CPU 的特性和调度代码"
 
-#: config/aarch64/aarch64.opt:100
+#: config/aarch64/aarch64.opt:104
 #, fuzzy
 msgid "-mcpu=CPU\tUse features of and optimize for CPU"
 msgstr "-mcpu=\t使用指定 CPU 的特性和调度代码"
 
-#: config/aarch64/aarch64.opt:104
+#: config/aarch64/aarch64.opt:108
 msgid "-mtune=CPU\tOptimize for CPU"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:108
+#: config/aarch64/aarch64.opt:112
 #, fuzzy
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI"
 msgstr "-mabi=ABI\t生成遵循给定 ABI 的代码"
 
-#: config/aarch64/aarch64.opt:112
+#: config/aarch64/aarch64.opt:116
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -9027,10 +9033,16 @@
 
 #: config/i386/i386.opt:864
 #, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MWAITX and MONITORX built-in functions and code generation"
+msgstr "支持 MMX 和 SSE 内建函数及代码生成"
+
+#: config/i386/i386.opt:868
+#, fuzzy
 msgid "Use given stack-protector guard"
 msgstr "使用 propolice 来保护堆栈"
 
-#: config/i386/i386.opt:868
+#: config/i386/i386.opt:872
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
 msgstr ""
 
@@ -9398,7 +9410,7 @@
 msgstr ""
 
 #: config/avr/avr.opt:100
-msgid "Do not link against the device-specific library libdev.a"
+msgid "Do not link against the device-specific library lib<MCU>.a"
 msgstr ""
 
 #: config/m32r/m32r.opt:34
@@ -9546,7 +9558,7 @@
 msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 msgstr ""
 
-#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:470
+#: config/s390/s390.opt:169 config/rs6000/rs6000.opt:474
 #: config/mips/mips.opt:389
 #, fuzzy
 msgid "Use LRA instead of reload"
@@ -9677,7 +9689,7 @@
 msgid "Permit scheduling of a function's prologue sequence"
 msgstr "允许调度函数前言序列"
 
-#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:244
+#: config/arm/arm.opt:175 config/rs6000/rs6000.opt:248
 msgid "Do not load the PIC register in function prologues"
 msgstr "不在函数前言中加载 PIC 寄存器"
 
@@ -10008,318 +10020,318 @@
 msgid "Use vector/scalar (VSX) instructions"
 msgstr "使用向量/标量(VSX)指令"
 
-#: config/rs6000/rs6000.opt:236
+#: config/rs6000/rs6000.opt:240
 msgid "Do not generate load/store with update instructions"
 msgstr "不生成带更新的加载/存储指令"
 
-#: config/rs6000/rs6000.opt:240
+#: config/rs6000/rs6000.opt:244
 msgid "Generate load/store with update instructions"
 msgstr "生成带更新的加载/存储指令"
 
-#: config/rs6000/rs6000.opt:248
+#: config/rs6000/rs6000.opt:252
 msgid "Avoid generation of indexed load/store instructions when possible"
 msgstr "尽可能避免生成变址装载/存储指令"
 
-#: config/rs6000/rs6000.opt:252
+#: config/rs6000/rs6000.opt:256
 msgid "Mark __tls_get_addr calls with argument info"
 msgstr "用参数信息标注对 __tls_get_addr 的调用"
 
-#: config/rs6000/rs6000.opt:259
+#: config/rs6000/rs6000.opt:263
 msgid "Schedule the start and end of the procedure"
 msgstr "调度过程的起始与终止"
 
-#: config/rs6000/rs6000.opt:263
+#: config/rs6000/rs6000.opt:267
 msgid "Return all structures in memory (AIX default)"
 msgstr "所有结构在内存中返回 (AIX 默认)"
 
-#: config/rs6000/rs6000.opt:267
+#: config/rs6000/rs6000.opt:271
 msgid "Return small structures in registers (SVR4 default)"
 msgstr "小结构在寄存器中返回 (SVR4 默认)"
 
-#: config/rs6000/rs6000.opt:271
+#: config/rs6000/rs6000.opt:275
 msgid "Conform more closely to IBM XLC semantics"
 msgstr "尽量接近 IBM XLC 语义"
 
-#: config/rs6000/rs6000.opt:275 config/rs6000/rs6000.opt:279
+#: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
 #, fuzzy
 msgid "Generate software reciprocal divide and square root for better throughput."
 msgstr "为优化吞吐量生成软件平方根倒数"
 
-#: config/rs6000/rs6000.opt:283
+#: config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:287
+#: config/rs6000/rs6000.opt:291
 msgid "Do not place floating point constants in TOC"
 msgstr "不在 TOC 中存放浮点常量"
 
-#: config/rs6000/rs6000.opt:291
+#: config/rs6000/rs6000.opt:295
 msgid "Place floating point constants in TOC"
 msgstr "在 TOC 中存放浮点常量"
 
-#: config/rs6000/rs6000.opt:295
+#: config/rs6000/rs6000.opt:299
 msgid "Do not place symbol+offset constants in TOC"
 msgstr "不在 TOC 中存放符号+偏移量常量"
 
-#: config/rs6000/rs6000.opt:299
+#: config/rs6000/rs6000.opt:303
 msgid "Place symbol+offset constants in TOC"
 msgstr "在 TOC 中存放符号+偏移量常量"
 
-#: config/rs6000/rs6000.opt:310
+#: config/rs6000/rs6000.opt:314
 msgid "Use only one TOC entry per procedure"
 msgstr "为每个过程只使用一个 TOC 条目"
 
-#: config/rs6000/rs6000.opt:314
+#: config/rs6000/rs6000.opt:318
 msgid "Put everything in the regular TOC"
 msgstr "所有东西都放进常规 TOC 中"
 
-#: config/rs6000/rs6000.opt:318
+#: config/rs6000/rs6000.opt:322
 msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgstr "生成 AltiVec 代码时生成 VRSAVE 指令"
 
-#: config/rs6000/rs6000.opt:322
+#: config/rs6000/rs6000.opt:326
 #, fuzzy
 msgid "Deprecated option.  Use -mno-vrsave instead"
 msgstr "-mvrsave=yes/no\t不建议使用的选项。请改用 -mvrsave/-mno-vrsave"
 
-#: config/rs6000/rs6000.opt:326
+#: config/rs6000/rs6000.opt:330
 #, fuzzy
 msgid "Deprecated option.  Use -mvrsave instead"
 msgstr "不建议使用。请改用 -Os"
 
-#: config/rs6000/rs6000.opt:330
+#: config/rs6000/rs6000.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:334
+#: config/rs6000/rs6000.opt:338
 msgid "Generate isel instructions"
 msgstr "生成 isel 指令"
 
-#: config/rs6000/rs6000.opt:338
+#: config/rs6000/rs6000.opt:342
 #, fuzzy
 msgid "Deprecated option.  Use -mno-isel instead"
 msgstr "-misel=yes/no\t不建议使用的选项。请改用 -misel/-mno-isel"
 
-#: config/rs6000/rs6000.opt:342
+#: config/rs6000/rs6000.opt:346
 #, fuzzy
 msgid "Deprecated option.  Use -misel instead"
 msgstr "不建议使用。请改用 -Os"
 
-#: config/rs6000/rs6000.opt:346
+#: config/rs6000/rs6000.opt:350
 msgid "Generate SPE SIMD instructions on E500"
 msgstr "在 E500 上生成 SPE SIMD 指令"
 
-#: config/rs6000/rs6000.opt:350
+#: config/rs6000/rs6000.opt:354
 msgid "Generate PPC750CL paired-single instructions"
 msgstr "生成 PPC750CL 配对单精度指令"
 
-#: config/rs6000/rs6000.opt:354
+#: config/rs6000/rs6000.opt:358
 #, fuzzy
 msgid "Deprecated option.  Use -mno-spe instead"
 msgstr "-mspe=yes/no\t不建议使用的选项。请改用 -mspe/-mno-spe"
 
-#: config/rs6000/rs6000.opt:358
+#: config/rs6000/rs6000.opt:362
 #, fuzzy
 msgid "Deprecated option.  Use -mspe instead"
 msgstr "不建议使用。请改用 -Os"
 
-#: config/rs6000/rs6000.opt:362
+#: config/rs6000/rs6000.opt:366
 msgid "-mdebug=\tEnable debug output"
 msgstr "-mdebug=\t启用调试输出"
 
-#: config/rs6000/rs6000.opt:366
+#: config/rs6000/rs6000.opt:370
 #, fuzzy
 msgid "Use the AltiVec ABI extensions"
 msgstr "使用 Cray 指针扩展"
 
-#: config/rs6000/rs6000.opt:370
+#: config/rs6000/rs6000.opt:374
 #, fuzzy
 msgid "Do not use the AltiVec ABI extensions"
 msgstr "不使用位段指令"
 
-#: config/rs6000/rs6000.opt:374
+#: config/rs6000/rs6000.opt:378
 #, fuzzy
 msgid "Use the SPE ABI extensions"
 msgstr "使用 Cray 指针扩展"
 
-#: config/rs6000/rs6000.opt:378
+#: config/rs6000/rs6000.opt:382
 #, fuzzy
 msgid "Do not use the SPE ABI extensions"
 msgstr "不使用位段指令"
 
-#: config/rs6000/rs6000.opt:382
+#: config/rs6000/rs6000.opt:386
 #, fuzzy
 msgid "Use the ELFv1 ABI"
 msgstr "使用 EABI"
 
-#: config/rs6000/rs6000.opt:386
+#: config/rs6000/rs6000.opt:390
 #, fuzzy
 msgid "Use the ELFv2 ABI"
 msgstr "使用 EABI"
 
-#: config/rs6000/rs6000.opt:393
+#: config/rs6000/rs6000.opt:397
 msgid "using darwin64 ABI"
 msgstr "使用 darwin64 ABI"
 
-#: config/rs6000/rs6000.opt:396
+#: config/rs6000/rs6000.opt:400
 msgid "using old darwin ABI"
 msgstr "使用旧式的 Darwin ABI"
 
-#: config/rs6000/rs6000.opt:399
+#: config/rs6000/rs6000.opt:403
 msgid "using IEEE extended precision long double"
 msgstr "使用 IEEE 扩展精度 long double"
 
-#: config/rs6000/rs6000.opt:402
+#: config/rs6000/rs6000.opt:406
 msgid "using IBM extended precision long double"
 msgstr "使用 IBM 扩展精度 long double"
 
-#: config/rs6000/rs6000.opt:406
+#: config/rs6000/rs6000.opt:410
 msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgstr "-mcpu=\t使用指定 CPU 的特性和调度代码"
 
-#: config/rs6000/rs6000.opt:410
+#: config/rs6000/rs6000.opt:414
 msgid "-mtune=\tSchedule code for given CPU"
 msgstr "-mtune=\t为指定的 CPU 调度代码"
 
-#: config/rs6000/rs6000.opt:414
+#: config/rs6000/rs6000.opt:418
 msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgstr "-mtraceback=\t选择全部、部分或不需要回溯表"
 
-#: config/rs6000/rs6000.opt:430
+#: config/rs6000/rs6000.opt:434
 msgid "Avoid all range limits on call instructions"
 msgstr "为调用指令避免一切范围限制"
 
-#: config/rs6000/rs6000.opt:434
+#: config/rs6000/rs6000.opt:438
 msgid "Generate Cell microcode"
 msgstr "生成 Cell 微代码"
 
-#: config/rs6000/rs6000.opt:438
+#: config/rs6000/rs6000.opt:442
 msgid "Warn when a Cell microcoded instruction is emitted"
 msgstr "生成 Cell 微代码时给出警告"
 
-#: config/rs6000/rs6000.opt:442
+#: config/rs6000/rs6000.opt:446
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgstr "遇到不建议使用的‘vector long ...’AltiVec 类型时给出警告"
 
-#: config/rs6000/rs6000.opt:446
+#: config/rs6000/rs6000.opt:450
 msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgstr "-mfloat-gprs=\t选择通用寄存器浮点方法"
 
-#: config/rs6000/rs6000.opt:450
+#: config/rs6000/rs6000.opt:454
 #, fuzzy
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "析构函数不能有参数"
 
-#: config/rs6000/rs6000.opt:466
+#: config/rs6000/rs6000.opt:470
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgstr "-mlong-double-<n>\t指定 long double 的大小(64 或 128 位)"
 
-#: config/rs6000/rs6000.opt:474
+#: config/rs6000/rs6000.opt:478
 msgid "Determine which dependences between insns are considered costly"
 msgstr "指定指令间的哪些依赖关系将被认为是有开销的"
 
-#: config/rs6000/rs6000.opt:478
+#: config/rs6000/rs6000.opt:482
 msgid "Specify which post scheduling nop insertion scheme to apply"
 msgstr "指定要应用的调度后 NOP 插入机制"
 
-#: config/rs6000/rs6000.opt:482
+#: config/rs6000/rs6000.opt:486
 msgid "Specify alignment of structure fields default/natural"
 msgstr "指定结构字段默认或自然的对齐"
 
-#: config/rs6000/rs6000.opt:486
+#: config/rs6000/rs6000.opt:490
 #, fuzzy
 msgid "Valid arguments to -malign-:"
 msgstr "析构函数不能有参数"
 
-#: config/rs6000/rs6000.opt:496
+#: config/rs6000/rs6000.opt:500
 msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgstr "指定分配槽受限的指令的调度优先级"
 
-#: config/rs6000/rs6000.opt:500
+#: config/rs6000/rs6000.opt:504
 msgid "Single-precision floating point unit"
 msgstr "单精度浮点单元"
 
-#: config/rs6000/rs6000.opt:504
+#: config/rs6000/rs6000.opt:508
 msgid "Double-precision floating point unit"
 msgstr "双精度浮点单元"
 
-#: config/rs6000/rs6000.opt:508
+#: config/rs6000/rs6000.opt:512
 msgid "Floating point unit does not support divide & sqrt"
 msgstr "浮点单元不支持除法和开方"
 
-#: config/rs6000/rs6000.opt:512
+#: config/rs6000/rs6000.opt:516
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgstr "-mfpu=\t指定 FP (sp、dp、sp-lite、dp-lite)(同时指定了 -mxilinx-fpu)"
 
-#: config/rs6000/rs6000.opt:534
+#: config/rs6000/rs6000.opt:538
 msgid "Specify Xilinx FPU."
 msgstr "指定 Xilinx FPU。"
 
-#: config/rs6000/rs6000.opt:538
+#: config/rs6000/rs6000.opt:542
 msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:542
+#: config/rs6000/rs6000.opt:546
 msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:546
+#: config/rs6000/rs6000.opt:550
 msgid "Allow 128-bit integers in VSX registers"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:550
+#: config/rs6000/rs6000.opt:554
 msgid "Fuse certain integer operations together for better performance on power8"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:554
+#: config/rs6000/rs6000.opt:558
 #, fuzzy
 msgid "Allow sign extension in fusion operations"
 msgstr "对齐字符串操作的目标"
 
-#: config/rs6000/rs6000.opt:558
+#: config/rs6000/rs6000.opt:562
 msgid "Use/do not use vector and scalar instructions added in ISA 2.07."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:562
+#: config/rs6000/rs6000.opt:566
 #, fuzzy
-msgid "Use ISA 2.07 crypto instructions"
-msgstr "使用 SmartMIPS 指令"
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions"
+msgstr "使用向量/标量(VSX)指令"
 
-#: config/rs6000/rs6000.opt:566
+#: config/rs6000/rs6000.opt:570
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:570
+#: config/rs6000/rs6000.opt:574
 #, fuzzy
 msgid "Use ISA 2.07 transactional memory (HTM) instructions"
 msgstr "使用向量/标量(VSX)指令"
 
-#: config/rs6000/rs6000.opt:574
+#: config/rs6000/rs6000.opt:578
 #, fuzzy
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "生成加载/存储乘法指令"
 
-#: config/rs6000/rs6000.opt:578
+#: config/rs6000/rs6000.opt:582
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:582
+#: config/rs6000/rs6000.opt:586
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
-#: config/rs6000/rs6000.opt:586
+#: config/rs6000/rs6000.opt:590
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:590
+#: config/rs6000/rs6000.opt:594
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:594
+#: config/rs6000/rs6000.opt:598
 msgid "Allow float/double variables in upper registers if cpu allows it"
 msgstr ""
 
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:602
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
@@ -13265,1607 +13277,1607 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgstr "-dumpdir <目录>\t设定内存转储使用的目录名"
 
-#: common.opt:842
+#: common.opt:845
 msgid "The version of the C++ ABI in use"
 msgstr ""
 
-#: common.opt:846
+#: common.opt:849
 msgid "Aggressively optimize loops using language constraints"
 msgstr ""
 
-#: common.opt:850
+#: common.opt:853
 msgid "Align the start of functions"
 msgstr "对齐函数入口"
 
-#: common.opt:857
+#: common.opt:860
 msgid "Align labels which are only reached by jumping"
 msgstr "对齐只能为跳转所到达的标号"
 
-#: common.opt:864
+#: common.opt:867
 msgid "Align all labels"
 msgstr "对齐所有的标号"
 
-#: common.opt:871
+#: common.opt:874
 msgid "Align the start of loops"
 msgstr "对齐循环入口"
 
-#: common.opt:894
+#: common.opt:897
 msgid "Select what to sanitize"
 msgstr ""
 
-#: common.opt:898
+#: common.opt:901
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:902
+#: common.opt:905
 msgid "After diagnosing undefined behavior attempt to continue execution"
 msgstr ""
 
-#: common.opt:906
+#: common.opt:909
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead"
 msgstr "不建议使用此开关；请改用 -Wextra"
 
-#: common.opt:910
+#: common.opt:913
 msgid "Use trap instead of a library function for undefined behavior sanitization"
 msgstr ""
 
-#: common.opt:914
+#: common.opt:917
 msgid "Generate unwind tables that are exact at each instruction boundary"
 msgstr "生成精确到每条指令边界的堆栈展开表"
 
-#: common.opt:918
+#: common.opt:921
 msgid "Generate auto-inc/dec instructions"
 msgstr "生成 auto-inc/dec指令"
 
-#: common.opt:922
+#: common.opt:925
 msgid "Use sample profile information for call graph node weights. The default"
 msgstr ""
 
-#: common.opt:927
+#: common.opt:930
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile"
 msgstr "为分支概率使用取样信息"
 
-#: common.opt:936
+#: common.opt:939
 msgid "Generate code to check bounds before indexing arrays"
 msgstr "生成检查数组访问是否越界的代码"
 
-#: common.opt:940
+#: common.opt:943
 msgid "Replace add, compare, branch with branch on count register"
 msgstr "将加/减法、比较、跳转指令序列替换为根据计数寄存器跳转指令"
 
-#: common.opt:944
+#: common.opt:947
 msgid "Use profiling information for branch probabilities"
 msgstr "为分支概率使用取样信息"
 
-#: common.opt:948
+#: common.opt:951
 msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgstr "在开始/结末线程前进行分支目标载入优化"
 
-#: common.opt:952
+#: common.opt:955
 msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgstr "在开始/结末线程后进行分支目标载入优化"
 
-#: common.opt:956
+#: common.opt:959
 msgid "Restrict target load migration not to re-use registers in any basic block"
 msgstr "限制目标载入融合不重用任何基本块中的寄存器"
 
-#: common.opt:960
+#: common.opt:963
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgstr "-fcall-saved-<寄存器>\t认为寄存器在函数调用后值不变"
 
-#: common.opt:964
+#: common.opt:967
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgstr "-fcall-used-<寄存器>\t认为寄存器的值将被函数调用所改变"
 
-#: common.opt:971
+#: common.opt:974
 msgid "Save registers around function calls"
 msgstr "函数调用前后保存/恢复寄存器值"
 
-#: common.opt:975
+#: common.opt:978
 msgid "Compare the results of several data dependence analyzers."
 msgstr "比较几个数据依赖分析的结果。"
 
-#: common.opt:979
+#: common.opt:982
 #, fuzzy
 msgid "Check the return value of new in C++"
 msgstr "检查 new 的返回值"
 
-#: common.opt:983
+#: common.opt:986
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:987
+#: common.opt:990
 msgid "Do not put uninitialized globals in the common section"
 msgstr "不将未初始化的全局数据放在公共节中"
 
-#: common.opt:995
+#: common.opt:998
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgstr "-fcompare-debug[=<选项>]\t分别在带与不带“选项”，例如 -gtoggle，的情况下编译，然后比较最后的指令输出"
 
-#: common.opt:999
+#: common.opt:1002
 msgid "Run only the second compilation of -fcompare-debug"
 msgstr "只为 -fcompare-debug 运行第二遍编译"
 
-#: common.opt:1003
+#: common.opt:1006
 #, fuzzy
 msgid "Perform comparison elimination after register allocation has finished"
 msgstr "在分配寄存器后进行全局公共子表达式消除"
 
-#: common.opt:1007
+#: common.opt:1010
 msgid "Do not perform optimizations increasing noticeably stack usage"
 msgstr "不进行可能导致堆栈使用明显增长的优化"
 
-#: common.opt:1011
+#: common.opt:1014
 msgid "Perform a register copy-propagation optimization pass"
 msgstr "进行一趟寄存器副本传递优化"
 
-#: common.opt:1015
+#: common.opt:1018
 msgid "Perform cross-jumping optimization"
 msgstr "进行跨跳转优化"
 
-#: common.opt:1019
+#: common.opt:1022
 msgid "When running CSE, follow jumps to their targets"
 msgstr "进行 CSE 时，跟随跳转至目标"
 
-#: common.opt:1027
+#: common.opt:1030
 msgid "Omit range reduction step when performing complex division"
 msgstr "当进行复数除法时省略缩减范围的步骤"
 
-#: common.opt:1031
+#: common.opt:1034
 msgid "Complex multiplication and division follow Fortran rules"
 msgstr "复数乘除遵循 Fortran 规则"
 
-#: common.opt:1035
+#: common.opt:1038
 msgid "Place data items into their own section"
 msgstr "将每个数据项分别放在它们各自的节中"
 
-#: common.opt:1039
+#: common.opt:1042
 msgid "List all available debugging counters with their limits and counts."
 msgstr "列出所有可用的调试计数器及其极限和计数。"
 
-#: common.opt:1043
+#: common.opt:1046
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgstr "-fdbg-cnt=<计数器>:<极限>[,<计数器>:<极限>,...]\t设定调试计数器极限。"
 
-#: common.opt:1047
+#: common.opt:1050
 msgid "Map one directory name to another in debug information"
 msgstr "在调试信息中将一个目录名映射到另一个"
 
-#: common.opt:1051
+#: common.opt:1054
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1057
+#: common.opt:1060
 msgid "Defer popping functions args from stack until later"
 msgstr "延迟将函数实参弹栈"
 
-#: common.opt:1061
+#: common.opt:1064
 msgid "Attempt to fill delay slots of branch instructions"
 msgstr "尝试填充分支指令的延迟槽"
 
-#: common.opt:1065
+#: common.opt:1068
 msgid "Delete dead instructions that may throw exceptions"
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1072
 msgid "Delete useless null pointer checks"
 msgstr "删除无用的空指针检查"
 
-#: common.opt:1073
+#: common.opt:1076
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode"
 msgstr ""
 
-#: common.opt:1077
+#: common.opt:1080
 #, fuzzy
 msgid "Perform speculative devirtualization"
 msgstr "通过尾复制进行超块合成"
 
-#: common.opt:1081
+#: common.opt:1084
 #, fuzzy
 msgid "Try to convert virtual calls to direct ones."
 msgstr "允许链接器将 PIC 调用转化为直接调用"
 
-#: common.opt:1085
+#: common.opt:1088
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgstr "-fdiagnostics-show-location=[once|every-line]\t指定在自动换行的诊断信息开始给出源位置的频率"
 
-#: common.opt:1102
+#: common.opt:1105
 msgid "Show the source line with a caret indicating the column"
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1113
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics"
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1133
 msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgstr "在诊断信息后输出控制它们的命令行选项"
 
-#: common.opt:1134
+#: common.opt:1137
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1141
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1145
 msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgstr "-fdump-<类型>\t将一些编译器内部信息转储到一个文件里"
 
-#: common.opt:1149
+#: common.opt:1152
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgstr "-fdump-final-insns=文件名\t在翻译完毕后将指令输出到文件中"
 
-#: common.opt:1153
+#: common.opt:1156
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgstr ""
 
-#: common.opt:1157
+#: common.opt:1160
 msgid "Suppress output of addresses in debugging dumps"
 msgstr "在调试转储中不输出地址"
 
-#: common.opt:1161
+#: common.opt:1164
 msgid "Collect and dump debug information into temporary file if ICE in C/C++"
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1169
 #, fuzzy
 msgid "Dump optimization passes"
 msgstr "进行全寄存器传送优化"
 
-#: common.opt:1170
+#: common.opt:1173
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgstr "在调试转储中不输出指令数、行号标记和地址"
 
-#: common.opt:1174
+#: common.opt:1177
 msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgstr "在调试转储中不输出前一条和后一条指令号码"
 
-#: common.opt:1178
+#: common.opt:1181
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "用 GAS 汇编指示来启用 CFI 表"
 
-#: common.opt:1182
+#: common.opt:1185
 msgid "Perform early inlining"
 msgstr "进行早内联"
 
-#: common.opt:1186
+#: common.opt:1189
 msgid "Perform DWARF2 duplicate elimination"
 msgstr "进行 DWARF2 冗余消除"
 
-#: common.opt:1190
+#: common.opt:1193
 msgid "Perform interprocedural reduction of aggregates"
 msgstr "为聚合类型进行跨进程标量替换"
 
-#: common.opt:1194
+#: common.opt:1197
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info"
 msgstr "在调试信息中进行无用类型消除"
 
-#: common.opt:1198
+#: common.opt:1201
 msgid "Perform unused type elimination in debug info"
 msgstr "在调试信息中进行无用类型消除"
 
-#: common.opt:1202
+#: common.opt:1205
 msgid "Do not suppress C++ class debug information."
 msgstr "保留 C++ 类调试信息。"
 
-#: common.opt:1206
+#: common.opt:1209
 msgid "Enable exception handling"
 msgstr "启用异常处理"
 
-#: common.opt:1210
+#: common.opt:1213
 msgid "Perform a number of minor, expensive optimizations"
 msgstr "进行一些细微的、代价高昂的优化"
 
-#: common.opt:1214
+#: common.opt:1217
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgstr "-fexcess-precision=[fast|standard]\t指定如何处理有额外精度的浮点数"
 
-#: common.opt:1217
+#: common.opt:1220
 #, fuzzy, c-format
 msgid "unknown excess precision style %qs"
 msgstr "未知的额外精度风格“%s”"
 
-#: common.opt:1230
+#: common.opt:1233
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1234
+#: common.opt:1237
 msgid "Assume no NaNs or infinities are generated"
 msgstr "假定结果不会是 NaN 或无穷大浮点数"
 
-#: common.opt:1238
+#: common.opt:1241
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgstr "-ffixed-<寄存器>\t认为寄存器对编译器而言不可用"
 
-#: common.opt:1242
+#: common.opt:1245
 msgid "Don't allocate floats and doubles in extended-precision registers"
 msgstr "不将单精度和双精度浮点数分配到扩展精度的寄存器中"
 
-#: common.opt:1250
+#: common.opt:1253
 msgid "Perform a forward propagation pass on RTL"
 msgstr "进行 RTL 上的前向传递"
 
-#: common.opt:1254
+#: common.opt:1257
 msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1257
+#: common.opt:1260
 #, fuzzy, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "在 TOC 中存放浮点常量"
 
-#: common.opt:1274
+#: common.opt:1277
 msgid "Allow function addresses to be held in registers"
 msgstr "允许将函数地址保存在寄存器中"
 
-#: common.opt:1278
+#: common.opt:1281
 msgid "Place each function into its own section"
 msgstr "将每个函数分别放在它们各自的节中"
 
-#: common.opt:1282
+#: common.opt:1285
 msgid "Perform global common subexpression elimination"
 msgstr "进行全局公共子表达式消除"
 
-#: common.opt:1286
+#: common.opt:1289
 msgid "Perform enhanced load motion during global common subexpression elimination"
 msgstr "在全局公共子表达式消除中进行增强的读转移优化"
 
-#: common.opt:1290
+#: common.opt:1293
 msgid "Perform store motion after global common subexpression elimination"
 msgstr "在全局公共子表达式消除后进行存储转移"
 
-#: common.opt:1294
+#: common.opt:1297
 msgid "Perform redundant load after store elimination in global common subexpression"
 msgstr "在全局公共子表达式消除中进行冗余的写后读消除"
 
-#: common.opt:1299
+#: common.opt:1302
 msgid "Perform global common subexpression elimination after register allocation"
 msgstr "在分配寄存器后进行全局公共子表达式消除"
 
-#: common.opt:1305
+#: common.opt:1308
 msgid "Enable in and out of Graphite representation"
 msgstr "启用 Graphite 表示的输入输出"
 
-#: common.opt:1309
+#: common.opt:1312
 msgid "Enable Graphite Identity transformation"
 msgstr "启用 Graphite 身份转换"
 
-#: common.opt:1313
+#: common.opt:1316
 #, fuzzy
 msgid "Enable hoisting adjacent loads to encourage generating conditional move"
 msgstr "为条件指针外提内存读取操作。"
 
-#: common.opt:1318
+#: common.opt:1321
 msgid "Mark all loops as parallel"
 msgstr "将所有循环标记为并行"
 
-#: common.opt:1322
+#: common.opt:1325
 msgid "Enable Loop Strip Mining transformation"
 msgstr "启用循环条带开采转换"
 
-#: common.opt:1326
+#: common.opt:1329
 msgid "Enable Loop Interchange transformation"
 msgstr "启用循环交换转换"
 
-#: common.opt:1330
+#: common.opt:1333
 msgid "Enable Loop Blocking transformation"
 msgstr "启用循环分块转换"
 
-#: common.opt:1334
+#: common.opt:1337
 #, fuzzy
 #| msgid "Enable Loop Interchange transformation"
 msgid "Enable Loop Unroll Jam transformation"
 msgstr "启用循环交换转换"
 
-#: common.opt:1338
+#: common.opt:1341
 msgid "Enable support for GNU transactional memory"
 msgstr ""
 
-#: common.opt:1342
+#: common.opt:1345
 msgid "Use STB_GNU_UNIQUE if supported by the assembler"
 msgstr ""
 
-#: common.opt:1350
+#: common.opt:1353
 msgid "Enable the ISL based loop nest optimizer"
 msgstr ""
 
-#: common.opt:1354
+#: common.opt:1357
 msgid "Force bitfield accesses to match their type width"
 msgstr ""
 
-#: common.opt:1358
+#: common.opt:1361
 msgid "Enable guessing of branch probabilities"
 msgstr "启用分支概率猜测"
 
-#: common.opt:1366
+#: common.opt:1369
 msgid "Process #ident directives"
 msgstr "处理 #ident 指令"
 
-#: common.opt:1370
+#: common.opt:1373
 msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgstr "将条件跳转替换为没有跳转的等值表示"
 
-#: common.opt:1374
+#: common.opt:1377
 msgid "Perform conversion of conditional jumps to conditional execution"
 msgstr "将条件跳转替换为条件执行"
 
-#: common.opt:1378
+#: common.opt:1381
 msgid "-fstack-reuse=[all|named_vars|none] Set stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1381
+#: common.opt:1384
 #, fuzzy, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:1394
+#: common.opt:1397
 #, fuzzy
 msgid "Convert conditional jumps in innermost loops to branchless equivalents"
 msgstr "将条件跳转替换为没有跳转的等值表示"
 
-#: common.opt:1398
+#: common.opt:1401
 msgid "Also if-convert conditional jumps containing memory writes"
 msgstr "将包含内存写入的条件跳转转换为不带分支的等效形式"
 
-#: common.opt:1406
+#: common.opt:1409
 msgid "Do not generate .size directives"
 msgstr "不生成 .size 伪指令"
 
-#: common.opt:1410
+#: common.opt:1413
 msgid "Perform indirect inlining"
 msgstr "进行间接内联"
 
-#: common.opt:1416
+#: common.opt:1419
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
 msgstr ""
 
-#: common.opt:1420
+#: common.opt:1423
 #, fuzzy
 msgid "Integrate functions into their callers when code size is known not to grow"
 msgstr "在不导致代码膨胀的情况下将简单函数集成到它们的调用者中"
 
-#: common.opt:1424
+#: common.opt:1427
 #, fuzzy
 msgid "Integrate functions not declared \"inline\" into their callers when profitable"
 msgstr "将只被调用一次的函数集成到它们的调用者中"
 
-#: common.opt:1428
+#: common.opt:1431
 #, fuzzy
 msgid "Integrate functions only required by their single caller"
 msgstr "将只被调用一次的函数集成到它们的调用者中"
 
-#: common.opt:1435
+#: common.opt:1438
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgstr "-finline-limit=<N>\t将内联函数的大小限制在 N 以内"
 
-#: common.opt:1439
+#: common.opt:1442
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1443
+#: common.opt:1446
 msgid "Instrument function entry and exit with profiling calls"
 msgstr "在函数入口和出口加入取样调用"
 
-#: common.opt:1447
+#: common.opt:1450
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgstr "-finstrument-functions-exclude-function-list=函数名,...  取样时排除列出的函数"
 
-#: common.opt:1451
+#: common.opt:1454
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgstr "-finstrument-functions-exclude-file-list=文件名,...  取样时排除列出的文件中的函数"
 
-#: common.opt:1455
+#: common.opt:1458
 #, fuzzy
 msgid "Perform interprocedural constant propagation"
 msgstr "进行进程间的复写传递"
 
-#: common.opt:1459
+#: common.opt:1462
 msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgstr "进行复制以使跨进程常量传递更有效"
 
-#: common.opt:1463
+#: common.opt:1466
 #, fuzzy
 #| msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger"
 msgstr "进行复制以使跨进程常量传递更有效"
 
-#: common.opt:1467
+#: common.opt:1470
 #, fuzzy
 msgid "Perform interprocedural profile propagation"
 msgstr "进行进程间的复写传递"
 
-#: common.opt:1471
+#: common.opt:1474
 msgid "Perform interprocedural points-to analysis"
 msgstr "进行进程间的指向分析"
 
-#: common.opt:1475
+#: common.opt:1478
 msgid "Discover pure and const functions"
 msgstr "发现纯函数和常函数"
 
-#: common.opt:1479
+#: common.opt:1482
 msgid "Perform Identical Code Folding for functions and read-only variables"
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1486
 msgid "Perform Identical Code Folding for functions"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1490
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables"
 msgstr "展开所有循环"
 
-#: common.opt:1491
+#: common.opt:1494
 msgid "Discover readonly and non addressable static variables"
 msgstr "发现只读和不可寻址静态变量"
 
-#: common.opt:1503
+#: common.opt:1506
 msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgstr "-fira-algorithm=|CB|priority] 设置使用的 IRA 算法"
 
-#: common.opt:1506
+#: common.opt:1509
 #, fuzzy, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:1516
+#: common.opt:1519
 msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgstr "-fira-region=[one|all|mixed] 设置 IRA 的区域"
 
-#: common.opt:1519
+#: common.opt:1522
 #, fuzzy, c-format
 msgid "unknown IRA region %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:1532 common.opt:1537
+#: common.opt:1535 common.opt:1540
 msgid "Use IRA based register pressure calculation"
 msgstr "使用基于 IRA 的寄存器压力计算"
 
-#: common.opt:1542
+#: common.opt:1545
 msgid "Share slots for saving different hard registers."
 msgstr "为保存不同的硬寄存器的共享槽。"
 
-#: common.opt:1546
+#: common.opt:1549
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "为溢出的伪寄存器共享堆栈槽。"
 
-#: common.opt:1550
+#: common.opt:1553
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<N>\t控制 IRA 诊断信息的级别。"
 
-#: common.opt:1554
+#: common.opt:1557
 msgid "Optimize induction variables on trees"
 msgstr "在树上优化归纳变量"
 
-#: common.opt:1558
+#: common.opt:1561
 msgid "Use jump tables for sufficiently large switch statements"
 msgstr "为足够大的 switch 语句使用跳转表"
 
-#: common.opt:1562
+#: common.opt:1565
 msgid "Generate code for functions even if they are fully inlined"
 msgstr "为完全内联的函数生成代码"
 
-#: common.opt:1566
+#: common.opt:1569
 msgid "Emit static const variables even if they are not used"
 msgstr "保留未用到的静态常量"
 
-#: common.opt:1570
+#: common.opt:1573
 msgid "Give external symbols a leading underscore"
 msgstr "给外部符号添加起始的下划线"
 
-#: common.opt:1578
+#: common.opt:1581
 msgid "Do CFG-sensitive rematerialization in LRA"
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1585
 msgid "Enable link-time optimization."
 msgstr "启用链接时优化。"
 
-#: common.opt:1586
+#: common.opt:1589
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1589
+#: common.opt:1592
 #, fuzzy, c-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:1608
+#: common.opt:1611
 msgid "Specify the algorithm to partition symbols and vars at linktime"
 msgstr ""
 
-#: common.opt:1613
+#: common.opt:1616
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgstr "-flto-compression-level=<N>\t为 IL 使用 zlib 压缩级别 N"
 
-#: common.opt:1617
+#: common.opt:1620
 msgid "Merge C++ types using One Definition Rule"
 msgstr ""
 
-#: common.opt:1621
+#: common.opt:1624
 msgid "Report various link-time optimization statistics"
 msgstr "报告各种链接时优化统计"
 
-#: common.opt:1625
+#: common.opt:1628
 #, fuzzy
 msgid "Report various link-time optimization statistics for WPA only"
 msgstr "报告各种链接时优化统计"
 
-#: common.opt:1629
+#: common.opt:1632
 msgid "Set errno after built-in math functions"
 msgstr "执行内建数学函数后设置 errno"
 
-#: common.opt:1633
+#: common.opt:1636
 msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgstr "-fmax-errors=<n>\t报告错误数量的上限值"
 
-#: common.opt:1637
+#: common.opt:1640
 msgid "Report on permanent memory allocation"
 msgstr "报告永久性内存分配"
 
-#: common.opt:1641
+#: common.opt:1644
 #, fuzzy
 msgid "Report on permanent memory allocation in WPA only"
 msgstr "报告永久性内存分配"
 
-#: common.opt:1648
+#: common.opt:1651
 msgid "Attempt to merge identical constants and constant variables"
 msgstr "试图合并相同的常量和常变量"
 
-#: common.opt:1652
+#: common.opt:1655
 msgid "Attempt to merge identical constants across compilation units"
 msgstr "试图合并不同编译单元中的相同常量"
 
-#: common.opt:1656
+#: common.opt:1659
 msgid "Attempt to merge identical debug strings across compilation units"
 msgstr "试图合并不同编译单元中的相同调试字符串"
 
-#: common.opt:1660
+#: common.opt:1663
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgstr "-fmessage-length=<N>\t将诊断信息限制在每行 N 个字符。0 取消自动换行"
 
-#: common.opt:1664
+#: common.opt:1667
 msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgstr "在首趟调度前进行基于 SMS 的模调度"
 
-#: common.opt:1668
+#: common.opt:1671
 msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgstr "进行基于 SMS 且允许寄存器转移的模调度"
 
-#: common.opt:1672
+#: common.opt:1675
 msgid "Move loop invariant computations out of loops"
 msgstr "将每次循环中不变的计算外提"
 
-#: common.opt:1676
+#: common.opt:1679
 msgid "Use the RTL dead code elimination pass"
 msgstr "使用 RTL 死代码清除"
 
-#: common.opt:1680
+#: common.opt:1683
 msgid "Use the RTL dead store elimination pass"
 msgstr "使用 RTL 死存储清除"
 
-#: common.opt:1684
+#: common.opt:1687
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgstr "启用/禁用已经通过模调度的循环中的传统调度"
 
-#: common.opt:1688
+#: common.opt:1691
 msgid "Support synchronous non-call exceptions"
 msgstr "支持同步非调用异常"
 
-#: common.opt:1691
+#: common.opt:1694
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "%qs后断言"
 
-#: common.opt:1692
+#: common.opt:1695
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them"
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1699
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler"
 msgstr ""
 
-#: common.opt:1699
+#: common.opt:1702
 #, fuzzy, c-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown offload ABI %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:1709
+#: common.opt:1712
 msgid "When possible do not generate stack frames"
 msgstr "尽可能不生成栈帧"
 
-#: common.opt:1713
+#: common.opt:1716
 #, fuzzy
 msgid "Enable all optimization info dumps on stderr"
 msgstr "在树级别进行循环优化"
 
-#: common.opt:1717
+#: common.opt:1720
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details"
 msgstr ""
 
-#: common.opt:1725
+#: common.opt:1728
 msgid "Optimize sibling and tail recursive calls"
 msgstr "优化同级递归和尾递归"
 
-#: common.opt:1729
+#: common.opt:1732
 msgid "Perform partial inlining"
 msgstr "进行部分内联"
 
-#: common.opt:1733 common.opt:1737
+#: common.opt:1736 common.opt:1740
 msgid "Report on memory allocation before interprocedural optimization"
 msgstr "在跨进程优化前报告内存分配"
 
-#: common.opt:1741
+#: common.opt:1744
 msgid "Pack structure members together without holes"
 msgstr "将结构成员不带间隔地紧实存放"
 
-#: common.opt:1745
+#: common.opt:1748
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgstr "-fpack-struct=<N>\t设定结构成员最大对齐边界的初始值"
 
-#: common.opt:1749
+#: common.opt:1752
 msgid "Return small aggregates in memory, not registers"
 msgstr "在内存而不是寄存器中返回小聚合"
 
-#: common.opt:1753
+#: common.opt:1756
 msgid "Perform loop peeling"
 msgstr "进行循环剥离"
 
-#: common.opt:1757
+#: common.opt:1760
 msgid "Enable machine specific peephole optimizations"
 msgstr "启用机器相关的窥孔优化"
 
-#: common.opt:1761
+#: common.opt:1764
 msgid "Enable an RTL peephole pass before sched2"
 msgstr "在 sched2 前进行一趟 RTL 窥孔优化"
 
-#: common.opt:1765
+#: common.opt:1768
 msgid "Generate position-independent code if possible (large mode)"
 msgstr "尽可能生成与位置无关的代码(大模式)"
 
-#: common.opt:1769
+#: common.opt:1772
 msgid "Generate position-independent code for executables if possible (large mode)"
 msgstr "为可执行文件尽可能生成与位置无关的代码(大模式)"
 
-#: common.opt:1773
+#: common.opt:1776
 msgid "Generate position-independent code if possible (small mode)"
 msgstr "尽可能生成与位置无关的代码(小模式)"
 
-#: common.opt:1777
+#: common.opt:1780
 msgid "Generate position-independent code for executables if possible (small mode)"
 msgstr "为可执行文件尽可能生成与位置无关的代码(小模式)"
 
-#: common.opt:1781
+#: common.opt:1784
 msgid "Specify a plugin to load"
 msgstr "指定要加载的插件"
 
-#: common.opt:1785
+#: common.opt:1788
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgstr "-fplugin-arg-<插件>-<键>[=<值>]\t为插件指定参数键=值"
 
-#: common.opt:1789
+#: common.opt:1792
 msgid "Run predictive commoning optimization."
 msgstr "启用预测公因子优化。"
 
-#: common.opt:1793
+#: common.opt:1796
 msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgstr "如果可用，为循环中的数组生成预取指令"
 
-#: common.opt:1797
+#: common.opt:1800
 msgid "Enable basic program profiling code"
 msgstr "启用基本程序取样代码"
 
-#: common.opt:1801
+#: common.opt:1804
 msgid "Insert arc-based program profiling code"
 msgstr "插入基于弧的程序取样代码"
 
-#: common.opt:1805
+#: common.opt:1808
 msgid "Set the top-level directory for storing the profile data."
 msgstr "指定存储的取样数据的顶级目录"
 
-#: common.opt:1810
+#: common.opt:1813
 msgid "Enable correction of flow inconsistent profile data input"
 msgstr "启用对流不一致取样数据输入的修正"
 
-#: common.opt:1814
+#: common.opt:1817
 msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgstr "启用一些公共选项来生成样本文件，以便进行基于取样的优化"
 
-#: common.opt:1818
+#: common.opt:1821
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "启用生成取样信息的公共选项以支持基于取样反馈的优化，同时设置 -fprofile-dir="
 
-#: common.opt:1822
+#: common.opt:1825
 msgid "Enable common options for performing profile feedback directed optimizations"
 msgstr "启用一些公共选项以进行基于取样的优化"
 
-#: common.opt:1826
+#: common.opt:1829
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgstr "启用公共选项以进行基于取样反馈的优化，同时设置 -fprofile-dir="
 
-#: common.opt:1830
+#: common.opt:1833
 msgid "Insert code to profile values of expressions"
 msgstr "为取样表达式的值插入相关代码"
 
-#: common.opt:1834
+#: common.opt:1837
 #, fuzzy
 msgid "Report on consistency of profile"
 msgstr "内部一致性错误"
 
-#: common.opt:1838
+#: common.opt:1841
 #, fuzzy
 msgid "Enable function reordering that improves code placement"
 msgstr "函数重新排序以改善代码布局"
 
-#: common.opt:1845
+#: common.opt:1848
 #, fuzzy
 #| msgid "-frandom-seed=<string>\tMake compile reproducible using <string>"
 msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgstr "-frandom-seed=<字符串>\t使用字符串使编译可以复现"
 
-#: common.opt:1855
+#: common.opt:1858
 msgid "Record gcc command line switches in the object file."
 msgstr "在目标文件中记录 gcc 命令行开关。"
 
-#: common.opt:1859
+#: common.opt:1862
 msgid "Return small aggregates in registers"
 msgstr "在寄存器中返回小聚合"
 
-#: common.opt:1867
+#: common.opt:1870
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor"
 msgstr ""
 
-#: common.opt:1872
+#: common.opt:1875
 #, fuzzy
 msgid "Relief of register pressure through live range shrinkage"
 msgstr "启用对寄存器压力敏感的指令调度"
 
-#: common.opt:1876
+#: common.opt:1879
 msgid "Perform a register renaming optimization pass"
 msgstr "进行寄存器重命名优化"
 
-#: common.opt:1880
+#: common.opt:1883
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass"
 msgstr "进行寄存器重命名优化"
 
-#: common.opt:1884
+#: common.opt:1887
 msgid "Reorder basic blocks to improve code placement"
 msgstr "基本块重新排序以改善代码布局"
 
-#: common.opt:1888
+#: common.opt:1891
 msgid "Reorder basic blocks and partition into hot and cold sections"
 msgstr "对基本块重新排序并划分为热区和冷区"
 
-#: common.opt:1892
+#: common.opt:1895
 msgid "Reorder functions to improve code placement"
 msgstr "函数重新排序以改善代码布局"
 
-#: common.opt:1896
+#: common.opt:1899
 msgid "Add a common subexpression elimination pass after loop optimizations"
 msgstr "在循环优化结束后增加一趟公共子表达式消除"
 
-#: common.opt:1904
+#: common.opt:1907
 msgid "Disable optimizations that assume default FP rounding behavior"
 msgstr "禁用假定默认浮点舍入行为的优化"
 
-#: common.opt:1908
+#: common.opt:1911
 msgid "Enable scheduling across basic blocks"
 msgstr "启用基本块间的调度"
 
-#: common.opt:1912
+#: common.opt:1915
 msgid "Enable register pressure sensitive insn scheduling"
 msgstr "启用对寄存器压力敏感的指令调度"
 
-#: common.opt:1916
+#: common.opt:1919
 msgid "Allow speculative motion of non-loads"
 msgstr "允许非载入的投机移动"
 
-#: common.opt:1920
+#: common.opt:1923
 msgid "Allow speculative motion of some loads"
 msgstr "允许一些载入的投机移动"
 
-#: common.opt:1924
+#: common.opt:1927
 msgid "Allow speculative motion of more loads"
 msgstr "允许更多载入的投机移动"
 
-#: common.opt:1928
+#: common.opt:1931
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgstr "-fsched-verbose=<N>\t指定调度器的冗余级别"
 
-#: common.opt:1932
+#: common.opt:1935
 msgid "If scheduling post reload, do superblock scheduling"
 msgstr "在重载后调度中使用跨基本块调度"
 
-#: common.opt:1940
+#: common.opt:1943
 msgid "Reschedule instructions before register allocation"
 msgstr "分配寄存器前重新调度指令"
 
-#: common.opt:1944
+#: common.opt:1947
 msgid "Reschedule instructions after register allocation"
 msgstr "分配寄存器后重新调度指令"
 
-#: common.opt:1951
+#: common.opt:1954
 msgid "Schedule instructions using selective scheduling algorithm"
 msgstr "用选择性调度算法调度指令"
 
-#: common.opt:1955
+#: common.opt:1958
 msgid "Run selective scheduling after reload"
 msgstr "在重加载后使用选择性调度"
 
-#: common.opt:1959
+#: common.opt:1962
 msgid "Perform software pipelining of inner loops during selective scheduling"
 msgstr "在选择性调度中对内层循环进行软件流水化"
 
-#: common.opt:1963
+#: common.opt:1966
 msgid "Perform software pipelining of outer loops during selective scheduling"
 msgstr "在选择性调度中对外层循环进行软件流水化"
 
-#: common.opt:1967
+#: common.opt:1970
 msgid "Reschedule pipelined regions without pipelining"
 msgstr "重新调度没有被流水线化的流水线区域"
 
-#: common.opt:1971
+#: common.opt:1974
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker"
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1980
 msgid "Allow premature scheduling of queued insns"
 msgstr "允许对队列中的指令进行早调度"
 
-#: common.opt:1981
+#: common.opt:1984
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgstr "-fsched-stalled-insns=<N>\t指定能被早期调度的在排队中的指令的最大数量"
 
-#: common.opt:1989
+#: common.opt:1992
 msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgstr "设置排队中指令的进行早调度的依赖距离检查"
 
-#: common.opt:1993
+#: common.opt:1996
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgstr "-fsched-stalled-insns-dep=<N>\t设置排队中指令的进行早调度的依赖距离检查"
 
-#: common.opt:1997
+#: common.opt:2000
 msgid "Enable the group heuristic in the scheduler"
 msgstr "在调度器中启用组启发"
 
-#: common.opt:2001
+#: common.opt:2004
 msgid "Enable the critical path heuristic in the scheduler"
 msgstr "为调度器启用关键路径启发式发现"
 
-#: common.opt:2005
+#: common.opt:2008
 msgid "Enable the speculative instruction heuristic in the scheduler"
 msgstr "为调度器启用投机指令启发式发现"
 
-#: common.opt:2009
+#: common.opt:2012
 msgid "Enable the rank heuristic in the scheduler"
 msgstr "在调度器中启用秩启发"
 
-#: common.opt:2013
+#: common.opt:2016
 msgid "Enable the last instruction heuristic in the scheduler"
 msgstr "为调度器启用最近指令启发式发现"
 
-#: common.opt:2017
+#: common.opt:2020
 msgid "Enable the dependent count heuristic in the scheduler"
 msgstr "为调度器启用依赖计数启发式发现"
 
-#: common.opt:2021
+#: common.opt:2024
 msgid "Access data in the same section from shared anchor points"
 msgstr "从共享的锚点访问在同样的节中的数据"
 
-#: common.opt:2033
+#: common.opt:2036
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2037
+#: common.opt:2040
 msgid "Show column numbers in diagnostics, when available.  Default on"
 msgstr "诊断信息中给出行号。默认打开"
 
-#: common.opt:2041
+#: common.opt:2044
 msgid "Emit function prologues only before parts of the function that need it,"
 msgstr ""
 
-#: common.opt:2046
+#: common.opt:2049
 msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgstr "禁用为 IEEE NaN 可见的优化"
 
-#: common.opt:2050
+#: common.opt:2053
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgstr "禁用忽略 IEEE 中零的符号的浮点优化"
 
-#: common.opt:2054
+#: common.opt:2057
 msgid "Convert floating point constants to single precision constants"
 msgstr "将浮点常量转换为单精度常量"
 
-#: common.opt:2058
+#: common.opt:2061
 msgid "Split lifetimes of induction variables when loops are unrolled"
 msgstr "展开循环时分离归纳变量的生存期"
 
-#: common.opt:2062
+#: common.opt:2065
 #, fuzzy
 msgid "Generate discontiguous stack frames"
 msgstr "生成与 APCS 相容的堆栈框架"
 
-#: common.opt:2066
+#: common.opt:2069
 msgid "Split wide types into independent registers"
 msgstr "将宽类型分割到独立的寄存器中"
 
-#: common.opt:2070
+#: common.opt:2073
 msgid "Optimize conditional patterns using SSA PHI nodes"
 msgstr ""
 
-#: common.opt:2074
+#: common.opt:2077
 #, fuzzy
 msgid "Optimize amount of stdarg registers saved to stack at start of function"
 msgstr "用以传递整数参数的寄存器个数"
 
-#: common.opt:2078
+#: common.opt:2081
 msgid "Apply variable expansion when loops are unrolled"
 msgstr "展开循环时也展开变量"
 
-#: common.opt:2082
+#: common.opt:2085
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgstr "-fstack-check=[no|generic|specific]\t在程序中插入检查栈溢出的代码"
 
-#: common.opt:2086
+#: common.opt:2089
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgstr "在程序中插入检查栈溢出的代码。与 fstack-check=specific 相同"
 
-#: common.opt:2093
+#: common.opt:2096
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgstr "-fstack-limit-symbol=<寄存器>\t当堆栈越过寄存器时引发陷阱"
 
-#: common.opt:2097
+#: common.opt:2100
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgstr "-fstack-limit-symbol=<符号>\t当堆栈越过符号时引发陷阱"
 
-#: common.opt:2101
+#: common.opt:2104
 msgid "Use propolice as a stack protection method"
 msgstr "使用 propolice 来保护堆栈"
 
-#: common.opt:2105
+#: common.opt:2108
 msgid "Use a stack protection method for every function"
 msgstr "为每个函数使用堆栈保护机制"
 
-#: common.opt:2109
+#: common.opt:2112
 #, fuzzy
 msgid "Use a smart stack protection method for certain functions"
 msgstr "为每个函数使用堆栈保护机制"
 
-#: common.opt:2113
+#: common.opt:2116
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute"
 msgstr "为每个函数使用堆栈保护机制"
 
-#: common.opt:2117
+#: common.opt:2120
 #, fuzzy
 msgid "Output stack usage information on a per-function basis"
 msgstr "为每个函数重用 r30"
 
-#: common.opt:2129
+#: common.opt:2132
 msgid "Assume strict aliasing rules apply"
 msgstr "假定应用强重叠规则"
 
-#: common.opt:2133
+#: common.opt:2136
 msgid "Treat signed overflow as undefined"
 msgstr "将有符号数溢出的行为视为未定义的"
 
-#: common.opt:2137
+#: common.opt:2140
 msgid "Implement __atomic operations via libcalls to legacy __sync functions"
 msgstr ""
 
-#: common.opt:2141
+#: common.opt:2144
 msgid "Check for syntax errors, then stop"
 msgstr "检查语法错误，然后停止"
 
-#: common.opt:2145
+#: common.opt:2148
 msgid "Create data files needed by \"gcov\""
 msgstr "生成“gcov”需要的数据文件"
 
-#: common.opt:2149
+#: common.opt:2152
 msgid "Perform jump threading optimizations"
 msgstr "进行跳转线程优化"
 
-#: common.opt:2153
+#: common.opt:2156
 msgid "Report the time taken by each compiler pass"
 msgstr "报告每趟汇编的耗时"
 
-#: common.opt:2157
+#: common.opt:2160
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\t设定默认的线程局部存储代码生成模式"
 
-#: common.opt:2160
+#: common.opt:2163
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:2176
+#: common.opt:2179
 msgid "Reorder top level functions, variables, and asms"
 msgstr "重新排序文件作用域的函数、变量和汇编"
 
-#: common.opt:2180
+#: common.opt:2183
 msgid "Perform superblock formation via tail duplication"
 msgstr "通过尾复制进行超块合成"
 
-#: common.opt:2187
+#: common.opt:2190
 msgid "Assume floating-point operations can trap"
 msgstr "假定浮点运算可能引发陷阱"
 
-#: common.opt:2191
+#: common.opt:2194
 msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgstr "加法、减法或乘法溢出时激活陷阱"
 
-#: common.opt:2195
+#: common.opt:2198
 msgid "Enable SSA-CCP optimization on trees"
 msgstr "启用树上的 SSA-CCP 优化"
 
-#: common.opt:2199
+#: common.opt:2202
 #, fuzzy
 msgid "Enable SSA-BIT-CCP optimization on trees"
 msgstr "启用树上的 SSA 死代码消除优化"
 
-#: common.opt:2207
+#: common.opt:2210
 msgid "Enable loop header copying on trees"
 msgstr "启用树上的循环不变量转移"
 
-#: common.opt:2211
+#: common.opt:2214
 #, fuzzy
 msgid "Enable coalescing of copy-related user variables that are inlined"
 msgstr "进行变量追踪并且标记未被初始化的变量"
 
-#: common.opt:2215
+#: common.opt:2218
 msgid "Enable coalescing of all copy-related user variables"
 msgstr ""
 
-#: common.opt:2219
+#: common.opt:2222
 msgid "Replace SSA temporaries with better names in copies"
 msgstr "将 SSA 临时变量重命名为更易理解的名称"
 
-#: common.opt:2223
+#: common.opt:2226
 msgid "Enable copy propagation on trees"
 msgstr "在树级别进行复写传递"
 
-#: common.opt:2231
+#: common.opt:2234
 msgid "Transform condition stores into unconditional ones"
 msgstr "将条件存储转换为非条件存储"
 
-#: common.opt:2235
+#: common.opt:2238
 msgid "Perform conversions of switch initializations."
 msgstr "转换开关初始化"
 
-#: common.opt:2239
+#: common.opt:2242
 msgid "Enable SSA dead code elimination optimization on trees"
 msgstr "启用树上的 SSA 死代码消除优化"
 
-#: common.opt:2243
+#: common.opt:2246
 msgid "Enable dominator optimizations"
 msgstr "启用主导优化"
 
-#: common.opt:2247
+#: common.opt:2250
 #, fuzzy
 msgid "Enable tail merging on trees"
 msgstr "启用树上的循环不变量转移"
 
-#: common.opt:2251
+#: common.opt:2254
 msgid "Enable dead store elimination"
 msgstr "删除死存储"
 
-#: common.opt:2255
+#: common.opt:2258
 msgid "Enable forward propagation on trees"
 msgstr "在树级别进行前向复写传递"
 
-#: common.opt:2259
+#: common.opt:2262
 msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgstr "启用树上的完全冗余消除(FRE)"
 
-#: common.opt:2263
+#: common.opt:2266
 #, fuzzy
 msgid "Enable string length optimizations on trees"
 msgstr "启用树上的 SSA-CCP 优化"
 
-#: common.opt:2267
+#: common.opt:2270
 #, fuzzy
 msgid "Detect paths that trigger erroneous or undefined behavior due to"
 msgstr "与字面字符串比较的结构是不可预测的"
 
-#: common.opt:2273
+#: common.opt:2276
 #, fuzzy
 msgid "Detect paths that trigger erroneous or undefined behavior due a null value"
 msgstr "与字面字符串比较的结构是不可预测的"
 
-#: common.opt:2280
+#: common.opt:2283
 msgid "Enable loop distribution on trees"
 msgstr "在树上进行循环分配"
 
-#: common.opt:2284
+#: common.opt:2287
 #, fuzzy
 msgid "Enable loop distribution for patterns transformed into a library call"
 msgstr "在树上进行循环分配"
 
-#: common.opt:2288
+#: common.opt:2291
 msgid "Enable loop invariant motion on trees"
 msgstr "启用树上的循环不变量转移"
 
-#: common.opt:2292
+#: common.opt:2295
 #, fuzzy
 msgid "Enable loop interchange transforms.  Same as -floop-interchange"
 msgstr "启用循环交换转换"
 
-#: common.opt:2296
+#: common.opt:2299
 msgid "Create canonical induction variables in loops"
 msgstr "在循环中生成正规的归纳变量"
 
-#: common.opt:2300
+#: common.opt:2303
 msgid "Enable loop optimizations on tree level"
 msgstr "在树级别进行循环优化"
 
-#: common.opt:2304
+#: common.opt:2307
 msgid "Enable automatic parallelization of loops"
 msgstr "启用循环的自动并行化"
 
-#: common.opt:2308
+#: common.opt:2311
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "为条件指针外提内存读取操作。"
 
-#: common.opt:2312
+#: common.opt:2315
 msgid "Enable SSA-PRE optimization on trees"
 msgstr "启用树上的 SSA-PRE 优化"
 
-#: common.opt:2316
+#: common.opt:2319
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination"
 msgstr ""
 
-#: common.opt:2320
+#: common.opt:2323
 msgid "Perform function-local points-to analysis on trees."
 msgstr "在树上进行函数内的指向分析。"
 
-#: common.opt:2324
+#: common.opt:2327
 msgid "Enable reassociation on tree level"
 msgstr "在树级别进行重结合"
 
-#: common.opt:2332
+#: common.opt:2335
 msgid "Enable SSA code sinking on trees"
 msgstr "启用树上的 SSA 代码下沉优化"
 
-#: common.opt:2336
+#: common.opt:2339
 msgid "Perform straight-line strength reduction"
 msgstr ""
 
-#: common.opt:2340
+#: common.opt:2343
 msgid "Perform scalar replacement of aggregates"
 msgstr "为聚合类型进行标量替换"
 
-#: common.opt:2344
+#: common.opt:2347
 msgid "Replace temporary expressions in the SSA->normal pass"
 msgstr "在 SSA->normal 过程中替换临时表达式"
 
-#: common.opt:2348
+#: common.opt:2351
 msgid "Perform live range splitting during the SSA->normal pass"
 msgstr "在 SSA->normal 过程中分离活动范围"
 
-#: common.opt:2352
+#: common.opt:2355
 msgid "Perform Value Range Propagation on trees"
 msgstr "进行树上的值域传递"
 
-#: common.opt:2356
+#: common.opt:2359
 msgid "Compile whole compilation unit at a time"
 msgstr "一次编译一整个编译单元"
 
-#: common.opt:2360
+#: common.opt:2363
 msgid "Perform loop unrolling when iteration count is known"
 msgstr "展开所有迭代次数已知的循环"
 
-#: common.opt:2364
+#: common.opt:2367
 msgid "Perform loop unrolling for all loops"
 msgstr "展开所有循环"
 
-#: common.opt:2371
+#: common.opt:2374
 msgid "Allow loop optimizations to assume that the loops behave in normal way"
 msgstr "允许假定循环以“正常”方式动作的循环优化"
 
-#: common.opt:2375
+#: common.opt:2378
 msgid "Allow optimization for floating-point arithmetic which may change the"
 msgstr "允许可能因不同舍入模式而改变结果的浮点算术优化。"
 
-#: common.opt:2380
+#: common.opt:2383
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "与 -fassociative-math 相同，作用于包含除法的表达式。"
 
-#: common.opt:2388
+#: common.opt:2391
 msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgstr "允许可能违反 IEEE 或 ISO 标准的优化"
 
-#: common.opt:2392
+#: common.opt:2395
 msgid "Perform loop unswitching"
 msgstr "外提循环内的测试语句"
 
-#: common.opt:2396
+#: common.opt:2399
 msgid "Just generate unwind tables for exception handling"
 msgstr "仅为异常处理生成堆栈展开表"
 
-#: common.opt:2400
+#: common.opt:2403
 #, fuzzy
 msgid "Use the bfd linker instead of the default linker"
 msgstr "使用硬件桶型移位器代替仿真"
 
-#: common.opt:2404
+#: common.opt:2407
 #, fuzzy
 msgid "Use the gold linker instead of the default linker"
 msgstr "使用硬件桶型移位器代替仿真"
 
-#: common.opt:2416
+#: common.opt:2419
 msgid "Perform variable tracking"
 msgstr "进行变量跟踪"
 
-#: common.opt:2424
+#: common.opt:2427
 msgid "Perform variable tracking by annotating assignments"
 msgstr "评注赋值以进行变量跟踪"
 
-#: common.opt:2430
+#: common.opt:2433
 msgid "Toggle -fvar-tracking-assignments"
 msgstr "切换 -fvar-tracking-assignments"
 
-#: common.opt:2438
+#: common.opt:2441
 msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgstr "进行变量追踪并且标记未被初始化的变量"
 
-#: common.opt:2442
+#: common.opt:2445
 #, fuzzy
 msgid "Enable vectorization on trees"
 msgstr "在树上进行循环向量化"
 
-#: common.opt:2450
+#: common.opt:2453
 msgid "Enable loop vectorization on trees"
 msgstr "在树上进行循环向量化"
 
-#: common.opt:2454
+#: common.opt:2457
 msgid "Enable basic block vectorization (SLP) on trees"
 msgstr "在树上进行基本块向量化(SLP)"
 
-#: common.opt:2458
+#: common.opt:2461
 #, fuzzy
 msgid "Specifies the cost model for vectorization"
 msgstr "启用向量化开销模型"
 
-#: common.opt:2462
+#: common.opt:2465
 msgid "Specifies the vectorization cost model for code marked with a simd directive"
 msgstr ""
 
-#: common.opt:2465
+#: common.opt:2468
 #, fuzzy, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:2478
+#: common.opt:2481
 #, fuzzy
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "不起作用。为向前兼容保留的选项。"
 
-#: common.opt:2482
+#: common.opt:2485
 #, fuzzy
 msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 msgstr "不起作用。为向前兼容保留的选项。"
 
-#: common.opt:2490
+#: common.opt:2493
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "为标量演化信息进行复写传递。"
 
-#: common.opt:2500
+#: common.opt:2503
 msgid "Add extra commentary to assembler output"
 msgstr "为汇编输出添加额外注释"
 
-#: common.opt:2504
+#: common.opt:2507
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgstr "-fvisibility=[default|internal|hidden|protected]\t设置符号的默认可见性"
 
-#: common.opt:2507
+#: common.opt:2510
 #, fuzzy, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "无效的 --param 值%qs"
 
-#: common.opt:2523
+#: common.opt:2526
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2529
 #, fuzzy, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(在%qs的初始化附近)"
 
-#: common.opt:2539
+#: common.opt:2542
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2543
+#: common.opt:2546
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2547
+#: common.opt:2550
 msgid "Use expression value profiles in optimizations"
 msgstr "在优化中使用表达式值样本提供的信息"
 
-#: common.opt:2551
+#: common.opt:2554
 msgid "Construct webs and split unrelated uses of single variable"
 msgstr "建立关系网并且分离对同一变量的无关应用"
 
-#: common.opt:2555
+#: common.opt:2558
 msgid "Enable conditional dead code elimination for builtin calls"
 msgstr "为内建函数启用有条件的死代码消除优化"
 
-#: common.opt:2559
+#: common.opt:2562
 msgid "Perform whole program optimizations"
 msgstr "进行全程序优化"
 
-#: common.opt:2563
+#: common.opt:2566
 msgid "Assume signed arithmetic overflow wraps around"
 msgstr "假定有符号运算溢出时回绕"
 
-#: common.opt:2567
+#: common.opt:2570
 msgid "Put zero initialized data in the bss section"
 msgstr "将初始化为零的数据存放在 bss 节中"
 
-#: common.opt:2571
+#: common.opt:2574
 msgid "Generate debug information in default format"
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:2575
+#: common.opt:2578
 msgid "Generate debug information in COFF format"
 msgstr "生成 COFF 格式的调试信息"
 
-#: common.opt:2579
+#: common.opt:2582
 #, fuzzy
 msgid "Generate debug information in default version of DWARF format"
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:2583
+#: common.opt:2586
 msgid "Generate debug information in DWARF v2 (or later) format"
 msgstr "生成 DWARF v2(或更新)格式的调试信息"
 
-#: common.opt:2587
+#: common.opt:2590
 msgid "Generate debug information in default extended format"
 msgstr "生成默认扩展格式的调试信息"
 
-#: common.opt:2591
+#: common.opt:2594
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2598
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2602
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2606
 #, fuzzy
 msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 msgstr "在目标文件中记录 gcc 命令行开关。"
 
-#: common.opt:2607
+#: common.opt:2610
 #, fuzzy
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "在目标文件中记录 gcc 命令行开关。"
 
-#: common.opt:2611
+#: common.opt:2614
 #, fuzzy
 msgid "Don't generate debug information in separate .dwo files"
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:2615
+#: common.opt:2618
 #, fuzzy
 msgid "Generate debug information in separate .dwo files"
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:2619
+#: common.opt:2622
 msgid "Generate debug information in STABS format"
 msgstr "生成 STABS 格式的调试信息"
 
-#: common.opt:2623
+#: common.opt:2626
 msgid "Generate debug information in extended STABS format"
 msgstr "生成扩展 STABS 格式的调试信息"
 
-#: common.opt:2627
+#: common.opt:2630
 msgid "Emit DWARF additions beyond selected version"
 msgstr "生成较所选版本更先进的 DWARF 附加信息"
 
-#: common.opt:2631
+#: common.opt:2634
 msgid "Don't emit DWARF additions beyond selected version"
 msgstr "不生成较所选版本更先进的 DWARF 附加信息"
 
-#: common.opt:2635
+#: common.opt:2638
 msgid "Toggle debug information generation"
 msgstr "切换调试信息生成"
 
-#: common.opt:2639
+#: common.opt:2642
 msgid "Generate debug information in VMS format"
 msgstr "生成 VMS 格式的调试信息"
 
-#: common.opt:2643
+#: common.opt:2646
 msgid "Generate debug information in XCOFF format"
 msgstr "生成 XCOFF 格式的调试信息"
 
-#: common.opt:2647
+#: common.opt:2650
 msgid "Generate debug information in extended XCOFF format"
 msgstr "生成 XCOFF 扩展格式的调试信息"
 
-#: common.opt:2665
+#: common.opt:2668
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections"
 msgstr "生成 isel 指令"
 
-#: common.opt:2669
+#: common.opt:2672
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>"
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:2676
+#: common.opt:2679
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgstr "-iplugindir=<目录>\t将目录设定为默认的插件子目录"
 
-#: common.opt:2680
+#: common.opt:2683
 #, fuzzy
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
 msgstr "-imultilib <目录>\t将目录设定为 multilib 的包含子目录"
 
-#: common.opt:2702
+#: common.opt:2705
 msgid "-o <file>\tPlace output into <file>"
 msgstr "-o <文件>\t将输出写入文件"
 
-#: common.opt:2706
+#: common.opt:2709
 msgid "Enable function profiling"
 msgstr "启用函数取样"
 
-#: common.opt:2716
+#: common.opt:2719
 msgid "Like -pedantic but issue them as errors"
 msgstr "与 -pedantic 类似，但将它们视作错误"
 
-#: common.opt:2756
+#: common.opt:2759
 msgid "Do not display functions compiled or elapsed time"
 msgstr "不显示编译的函数或逝去的时间"
 
-#: common.opt:2788
+#: common.opt:2791
 msgid "Enable verbose output"
 msgstr "启用详细输出"
 
-#: common.opt:2792
+#: common.opt:2795
 msgid "Display the compiler's version"
 msgstr "显示编译器版本"
 
-#: common.opt:2796
+#: common.opt:2799
 msgid "Suppress warnings"
 msgstr "不显示警告"
 
-#: common.opt:2806
+#: common.opt:2809
 msgid "Create a shared library"
 msgstr "生成一个共享库"
 
-#: common.opt:2851
+#: common.opt:2854
 msgid "Create a position independent executable"
 msgstr "生成位置无关可执行文件"
 
-#: common.opt:2858
+#: common.opt:2861
 msgid "Use caller save register across calls if possible"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1170
-#: cp/cvt.c:1418
+#: go/gofrontend/expressions.cc:93 c-family/c-common.c:1910 cp/cvt.c:1182
+#: cp/cvt.c:1430
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "计算出的值未被使用"
@@ -14898,246 +14910,246 @@
 msgid "expected integer or boolean type"
 msgstr "需要整数或布尔类型"
 
-#: go/gofrontend/expressions.cc:5563
+#: go/gofrontend/expressions.cc:5565
 #, fuzzy
 msgid "invalid comparison of nil with nil"
 msgstr "gimple 条件中比较代码无效"
 
-#: go/gofrontend/expressions.cc:5569 go/gofrontend/expressions.cc:5587
+#: go/gofrontend/expressions.cc:5571 go/gofrontend/expressions.cc:5589
 #, fuzzy
 msgid "incompatible types in binary expression"
 msgstr "二元表达式中类型不匹配"
 
-#: go/gofrontend/expressions.cc:5607
+#: go/gofrontend/expressions.cc:5609
 #, fuzzy
 msgid "integer division by zero"
 msgstr "被零除"
 
-#: go/gofrontend/expressions.cc:5615
+#: go/gofrontend/expressions.cc:5617
 #, fuzzy
 msgid "shift of non-integer operand"
 msgstr "非整数操作数使用了操作数代码‘%c’"
 
-#: go/gofrontend/expressions.cc:5620 go/gofrontend/expressions.cc:5628
+#: go/gofrontend/expressions.cc:5622 go/gofrontend/expressions.cc:5630
 #, fuzzy
 msgid "shift count not unsigned integer"
 msgstr "switch 语句中的值不是一个整数"
 
-#: go/gofrontend/expressions.cc:5633
+#: go/gofrontend/expressions.cc:5635
 msgid "negative shift count"
 msgstr "移位次数为负"
 
-#: go/gofrontend/expressions.cc:6284
+#: go/gofrontend/expressions.cc:6286
 msgid "object is not a method"
 msgstr "对象不是一个方法"
 
-#: go/gofrontend/expressions.cc:6301
+#: go/gofrontend/expressions.cc:6303
 msgid "method type does not match object type"
 msgstr "方法类型不匹配对象类型"
 
-#: go/gofrontend/expressions.cc:6775
+#: go/gofrontend/expressions.cc:6777
 #, fuzzy
 msgid "invalid use of %<...%> with builtin function"
 msgstr "内建函数实参无效"
 
-#: go/gofrontend/expressions.cc:6786
+#: go/gofrontend/expressions.cc:6788
 #, fuzzy
 msgid "invalid use of method value as argument of Offsetof"
 msgstr "使用模板名%qE时不带实参表无效"
 
-#: go/gofrontend/expressions.cc:6800
+#: go/gofrontend/expressions.cc:6802
 msgid "argument of Offsetof implies indirection of an embedded field"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:6825 go/gofrontend/expressions.cc:6886
-#: go/gofrontend/expressions.cc:6988 go/gofrontend/expressions.cc:7802
-#: go/gofrontend/expressions.cc:7951 go/gofrontend/expressions.cc:7997
-#: go/gofrontend/expressions.cc:8056 go/gofrontend/expressions.cc:9208
-#: go/gofrontend/expressions.cc:9225 go/gofrontend/expressions.cc:9241
+#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
+#: go/gofrontend/expressions.cc:6990 go/gofrontend/expressions.cc:7804
+#: go/gofrontend/expressions.cc:7953 go/gofrontend/expressions.cc:7999
+#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:9210
+#: go/gofrontend/expressions.cc:9227 go/gofrontend/expressions.cc:9243
 msgid "not enough arguments"
 msgstr "实参太少"
 
-#: go/gofrontend/expressions.cc:6827 go/gofrontend/expressions.cc:6888
-#: go/gofrontend/expressions.cc:7807 go/gofrontend/expressions.cc:7934
-#: go/gofrontend/expressions.cc:7956 go/gofrontend/expressions.cc:8002
-#: go/gofrontend/expressions.cc:8058 go/gofrontend/expressions.cc:8806
-#: go/gofrontend/expressions.cc:9213 go/gofrontend/expressions.cc:9227
-#: go/gofrontend/expressions.cc:9248
+#: go/gofrontend/expressions.cc:6829 go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:7809 go/gofrontend/expressions.cc:7936
+#: go/gofrontend/expressions.cc:7958 go/gofrontend/expressions.cc:8004
+#: go/gofrontend/expressions.cc:8060 go/gofrontend/expressions.cc:8808
+#: go/gofrontend/expressions.cc:9215 go/gofrontend/expressions.cc:9229
+#: go/gofrontend/expressions.cc:9250
 msgid "too many arguments"
 msgstr "实参太多"
 
-#: go/gofrontend/expressions.cc:6890
+#: go/gofrontend/expressions.cc:6892
 #, fuzzy
 msgid "argument 1 must be a map"
 msgstr "实参必须是常数"
 
-#: go/gofrontend/expressions.cc:7014
+#: go/gofrontend/expressions.cc:7016
 #, fuzzy
 msgid "invalid type for make function"
 msgstr "函数%q+#D的抽象返回类型无效"
 
-#: go/gofrontend/expressions.cc:7030
+#: go/gofrontend/expressions.cc:7032
 #, fuzzy
 msgid "length required when allocating a slice"
 msgstr "生成切片时长度错误"
 
-#: go/gofrontend/expressions.cc:7065
+#: go/gofrontend/expressions.cc:7067
 msgid "len larger than cap"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7077
+#: go/gofrontend/expressions.cc:7079
 #, fuzzy
 msgid "too many arguments to make"
 msgstr "%qE实参太多"
 
-#: go/gofrontend/expressions.cc:7851
+#: go/gofrontend/expressions.cc:7853
 #, fuzzy
 msgid "argument must be array or slice or channel"
 msgstr "右实参必须是一个切片或字符串"
 
-#: go/gofrontend/expressions.cc:7861
+#: go/gofrontend/expressions.cc:7863
 msgid "argument must be string or array or slice or map or channel"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:7907
+#: go/gofrontend/expressions.cc:7909
 #, fuzzy
 msgid "unsupported argument type to builtin function"
 msgstr "%<__builtin_frame_address%>的实参不受支持"
 
-#: go/gofrontend/expressions.cc:7918
+#: go/gofrontend/expressions.cc:7920
 msgid "argument must be channel"
 msgstr "实参必须是通道"
 
-#: go/gofrontend/expressions.cc:7920
+#: go/gofrontend/expressions.cc:7922
 #, fuzzy
 msgid "cannot close receive-only channel"
 msgstr "间接引用操作数无效"
 
-#: go/gofrontend/expressions.cc:7942
+#: go/gofrontend/expressions.cc:7944
 #, fuzzy
 msgid "argument must be a field reference"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是 %4$s"
 
-#: go/gofrontend/expressions.cc:7972
+#: go/gofrontend/expressions.cc:7974
 msgid "left argument must be a slice"
 msgstr "左实参必须是一个切片"
 
-#: go/gofrontend/expressions.cc:7980
+#: go/gofrontend/expressions.cc:7982
 msgid "element types must be the same"
 msgstr "元素类型必须一样"
 
-#: go/gofrontend/expressions.cc:7985
+#: go/gofrontend/expressions.cc:7987
 #, fuzzy
 msgid "first argument must be []byte"
 msgstr "左实参必须是一个切片"
 
-#: go/gofrontend/expressions.cc:7988
+#: go/gofrontend/expressions.cc:7990
 #, fuzzy
 msgid "second argument must be slice or string"
 msgstr "右实参必须是一个切片或字符串"
 
-#: go/gofrontend/expressions.cc:8032
+#: go/gofrontend/expressions.cc:8034
 #, fuzzy
 msgid "argument 2 has invalid type"
 msgstr "第 %u 个参数类型为 void"
 
-#: go/gofrontend/expressions.cc:8048
+#: go/gofrontend/expressions.cc:8050
 msgid "argument must have complex type"
 msgstr "实参必须具有复数类型"
 
-#: go/gofrontend/expressions.cc:8066
+#: go/gofrontend/expressions.cc:8068
 msgid "complex arguments must have identical types"
 msgstr "复数实参必须具有相同的类型"
 
-#: go/gofrontend/expressions.cc:8068
+#: go/gofrontend/expressions.cc:8070
 msgid "complex arguments must have floating-point type"
 msgstr "复数实参必须具有浮点类型"
 
-#: go/gofrontend/expressions.cc:8618 go/gofrontend/expressions.cc:9154
-#: go/gofrontend/expressions.cc:9590
+#: go/gofrontend/expressions.cc:8620 go/gofrontend/expressions.cc:9156
+#: go/gofrontend/expressions.cc:9592
 msgid "expected function"
 msgstr "需要函数"
 
-#: go/gofrontend/expressions.cc:8645
+#: go/gofrontend/expressions.cc:8647
 #, fuzzy
 msgid "multiple-value argument in single-value context"
 msgstr "%qD的声明中类名无效"
 
-#: go/gofrontend/expressions.cc:8810
+#: go/gofrontend/expressions.cc:8812
 #, fuzzy
 msgid "invalid use of %<...%> with non-slice"
 msgstr "在文件作用域使用%<this%>无效"
 
-#: go/gofrontend/expressions.cc:9162
+#: go/gofrontend/expressions.cc:9164
 msgid "function result count mismatch"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:9180
+#: go/gofrontend/expressions.cc:9182
 msgid "incompatible type for receiver"
 msgstr "接收器类型不兼容"
 
-#: go/gofrontend/expressions.cc:9198
+#: go/gofrontend/expressions.cc:9200
 #, fuzzy
 msgid "invalid use of %<...%> calling non-variadic function"
 msgstr "在非成员函数中使用%<this%>无效"
 
-#: go/gofrontend/expressions.cc:9599 go/gofrontend/expressions.cc:9613
+#: go/gofrontend/expressions.cc:9601 go/gofrontend/expressions.cc:9615
 msgid "number of results does not match number of values"
 msgstr "返回值的数量不匹配值的数量"
 
-#: go/gofrontend/expressions.cc:9969 go/gofrontend/expressions.cc:10481
+#: go/gofrontend/expressions.cc:9971 go/gofrontend/expressions.cc:10483
 msgid "index must be integer"
 msgstr "索引必须是整数"
 
-#: go/gofrontend/expressions.cc:9977 go/gofrontend/expressions.cc:10489
+#: go/gofrontend/expressions.cc:9979 go/gofrontend/expressions.cc:10491
 msgid "slice end must be integer"
 msgstr "切片结尾必须是整数"
 
-#: go/gofrontend/expressions.cc:9985
+#: go/gofrontend/expressions.cc:9987
 #, fuzzy
 msgid "slice capacity must be integer"
 msgstr "切片结尾必须是整数"
 
-#: go/gofrontend/expressions.cc:10035 go/gofrontend/expressions.cc:10520
+#: go/gofrontend/expressions.cc:10037 go/gofrontend/expressions.cc:10522
 msgid "inverted slice range"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10078
+#: go/gofrontend/expressions.cc:10080
 msgid "slice of unaddressable value"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:10739
+#: go/gofrontend/expressions.cc:10741
 msgid "incompatible type for map index"
 msgstr "映射索引类型不兼容"
 
-#: go/gofrontend/expressions.cc:11118
+#: go/gofrontend/expressions.cc:11120
 #, fuzzy
 msgid "expected interface or pointer to interface"
 msgstr "%<delete%>的参数类型应为指针而非%q#T"
 
-#: go/gofrontend/expressions.cc:11857
+#: go/gofrontend/expressions.cc:11859
 #, fuzzy
 msgid "too many expressions for struct"
 msgstr "提供给格式字符串的实参太多"
 
-#: go/gofrontend/expressions.cc:11870
+#: go/gofrontend/expressions.cc:11872
 #, fuzzy
 msgid "too few expressions for struct"
 msgstr "格式字符串实参太少"
 
-#: go/gofrontend/expressions.cc:13618 go/gofrontend/statements.cc:1585
+#: go/gofrontend/expressions.cc:13620 go/gofrontend/statements.cc:1585
 msgid "type assertion only valid for interface types"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13630
+#: go/gofrontend/expressions.cc:13632
 msgid "impossible type assertion: type does not implement interface"
 msgstr ""
 
-#: go/gofrontend/expressions.cc:13809 go/gofrontend/statements.cc:1430
+#: go/gofrontend/expressions.cc:13811 go/gofrontend/statements.cc:1430
 msgid "expected channel"
 msgstr "需要通道"
 
-#: go/gofrontend/expressions.cc:13814 go/gofrontend/statements.cc:1435
+#: go/gofrontend/expressions.cc:13816 go/gofrontend/statements.cc:1435
 msgid "invalid receive on send-only channel"
 msgstr ""
 
@@ -15262,73 +15274,73 @@
 msgid "cannot use type %s as type %s"
 msgstr "不能将类型 %s 用作 %s"
 
-#: go/gofrontend/types.cc:3471
+#: go/gofrontend/types.cc:3479
 msgid "different receiver types"
 msgstr "不同的接收器类型"
 
-#: go/gofrontend/types.cc:3491 go/gofrontend/types.cc:3504
-#: go/gofrontend/types.cc:3519
+#: go/gofrontend/types.cc:3499 go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3527
 msgid "different number of parameters"
 msgstr "形参数量不同"
 
-#: go/gofrontend/types.cc:3512
+#: go/gofrontend/types.cc:3520
 msgid "different parameter types"
 msgstr "形参类型不同"
 
-#: go/gofrontend/types.cc:3527
+#: go/gofrontend/types.cc:3535
 msgid "different varargs"
 msgstr "不同的可变参数"
 
-#: go/gofrontend/types.cc:3536 go/gofrontend/types.cc:3549
-#: go/gofrontend/types.cc:3564
+#: go/gofrontend/types.cc:3544 go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3572
 #, fuzzy
 msgid "different number of results"
 msgstr "形参数量不同"
 
-#: go/gofrontend/types.cc:3557
+#: go/gofrontend/types.cc:3565
 #, fuzzy
 msgid "different result types"
 msgstr "不同的接收器类型"
 
-#: go/gofrontend/types.cc:7351
+#: go/gofrontend/types.cc:7359
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "需要显式转换；缺少方法%s%s%s"
 
-#: go/gofrontend/types.cc:7368 go/gofrontend/types.cc:7510
+#: go/gofrontend/types.cc:7376 go/gofrontend/types.cc:7518
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "方法%s%s%s类型不兼容"
 
-#: go/gofrontend/types.cc:7372 go/gofrontend/types.cc:7514
+#: go/gofrontend/types.cc:7380 go/gofrontend/types.cc:7522
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "方法%s%s%s类型不兼容"
 
-#: go/gofrontend/types.cc:7451 go/gofrontend/types.cc:7464
+#: go/gofrontend/types.cc:7459 go/gofrontend/types.cc:7472
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:7453 go/gofrontend/types.cc:7466
+#: go/gofrontend/types.cc:7461 go/gofrontend/types.cc:7474
 msgid "type has no methods"
 msgstr "类型没有方法"
 
-#: go/gofrontend/types.cc:7487
+#: go/gofrontend/types.cc:7495
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "有歧义的方法%s%s%s"
 
-#: go/gofrontend/types.cc:7490
+#: go/gofrontend/types.cc:7498
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "缺少方法%s%s%s"
 
-#: go/gofrontend/types.cc:7531
+#: go/gofrontend/types.cc:7539
 #, fuzzy, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "方法%s%s%s需要一个指针"
 
-#: go/gofrontend/types.cc:7549
+#: go/gofrontend/types.cc:7557
 #, fuzzy, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr "方法%s%s%s需要一个指针"
@@ -15449,7 +15461,7 @@
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "%<__builtin_prefetch%>的第三个实参无效；使用 0"
 
-#: builtins.c:4486 gimplify.c:2347
+#: builtins.c:4486 gimplify.c:2351
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "给函数%<va_start%>的参数太少"
@@ -15631,12 +15643,12 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%K试图 free 一个不在堆上的对象"
 
-#: calls.c:2487
+#: calls.c:2503
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "函数调用有聚合类型"
 
-#: calls.c:3179
+#: calls.c:3195
 #, fuzzy, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "%qs缺少参数"
@@ -16196,249 +16208,254 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "指令链中记录的基本块数 (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:2660
+#: cgraph.c:2675
 #, gcc-internal-format
 msgid "caller edge count is negative"
 msgstr "调用边计数为负"
 
-#: cgraph.c:2665
+#: cgraph.c:2680
 #, gcc-internal-format
 msgid "caller edge frequency is negative"
 msgstr "调用边频率为负"
 
-#: cgraph.c:2670
+#: cgraph.c:2685
 #, gcc-internal-format
 msgid "caller edge frequency is too large"
 msgstr "调用边频率太大"
 
-#: cgraph.c:2754
+#: cgraph.c:2769
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "为边 %s->%s 设定辅助域"
 
-#: cgraph.c:2761
+#: cgraph.c:2776
 #, gcc-internal-format
 msgid "execution count is negative"
 msgstr "执行次数为负"
 
-#: cgraph.c:2766
+#: cgraph.c:2781
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:2771
+#: cgraph.c:2786
 #, fuzzy, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "假定符号可能无效"
 
-#: cgraph.c:2776
+#: cgraph.c:2791
 #, fuzzy, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "外部可见的内联代码"
 
-#: cgraph.c:2781
+#: cgraph.c:2796
 #, fuzzy, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "内联已被取地址的克隆"
 
-#: cgraph.c:2786
+#: cgraph.c:2801
 #, fuzzy, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "需要内联克隆"
 
-#: cgraph.c:2793
+#: cgraph.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "为边 %s->%s 设定辅助域"
 
-#: cgraph.c:2800
+#: cgraph.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:2815
+#: cgraph.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:2825
+#: cgraph.c:2840
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to pointer 错误"
 
-#: cgraph.c:2830
+#: cgraph.c:2845
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "多个内联调用者"
 
-#: cgraph.c:2837
+#: cgraph.c:2852
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "为非内联的调用者设定了 inlined_to pointer"
 
-#: cgraph.c:2856
+#: cgraph.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "caller edge frequency %i does not match BB frequency %i"
 msgstr "调用边频率 %i 与基本块频率 %i 不匹配"
 
-#: cgraph.c:2874
+#: cgraph.c:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "indirect call frequency %i does not match BB frequency %i"
 msgstr "调用边频率 %i 与基本块频率 %i 不匹配"
 
-#: cgraph.c:2883
+#: cgraph.c:2898
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "设定了 inlined_to 指针却找不到前驱"
 
-#: cgraph.c:2888
+#: cgraph.c:2903
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "inlined_to pointer 指向自身"
 
-#: cgraph.c:2900
+#: cgraph.c:2915
 #, fuzzy, gcc-internal-format
 #| msgid "node has wrong clone_of"
 msgid "cgraph_node has wrong clone_of"
 msgstr "节点有错误的 clone_of"
 
-#: cgraph.c:2912
+#: cgraph.c:2927
 #, fuzzy, gcc-internal-format
 #| msgid "node has wrong clone list"
 msgid "cgraph_node has wrong clone list"
 msgstr "节点的克隆列表不正确"
 
-#: cgraph.c:2918
+#: cgraph.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "node is in clone list but it is not clone"
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "节点在克隆列表中，但并不是克隆"
 
-#: cgraph.c:2923
+#: cgraph.c:2938
 #, fuzzy, gcc-internal-format
 #| msgid "node has wrong prev_clone pointer"
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "节点的 prev_clone 指针错误"
 
-#: cgraph.c:2928
+#: cgraph.c:2943
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "双向克隆链接列表已损坏"
 
-#: cgraph.c:2940
+#: cgraph.c:2955
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:2948
+#: cgraph.c:2963
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:2953
+#: cgraph.c:2968
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:2960
+#: cgraph.c:2975
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:2969
+#: cgraph.c:2984
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:2976
+#: cgraph.c:2991
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "%qD的对齐"
 
-#: cgraph.c:2986
+#: cgraph.c:3001
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "Instrumented node has wrong original declaration"
 msgstr "%qD的对齐"
 
-#: cgraph.c:3004
+#: cgraph.c:3019
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3009
+#: cgraph.c:3024
 #, fuzzy, gcc-internal-format
 #| msgid "forming reference to reference type %qT"
 msgid "Wrong node is referenced with chkp reference"
 msgstr "生成指向引用类型%qT的引用"
 
-#: cgraph.c:3017
+#: cgraph.c:3032
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3026
+#: cgraph.c:3046
 #, gcc-internal-format
+msgid "Alias chain for instrumented node is broken"
+msgstr ""
+
+#: cgraph.c:3055
+#, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3031
+#: cgraph.c:3060
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3036
+#: cgraph.c:3065
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3042
+#: cgraph.c:3071
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3078
+#: cgraph.c:3107
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "共享的 call_stmt："
 
-#: cgraph.c:3086
+#: cgraph.c:3115
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "边指向错误的声明："
 
-#: cgraph.c:3095
+#: cgraph.c:3124
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3105
+#: cgraph.c:3134
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "调用语句缺少 callgraph 边："
 
-#: cgraph.c:3115
+#: cgraph.c:3144
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "需要语句"
 
-#: cgraph.c:3128
+#: cgraph.c:3157
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "边 %s->%s 没有对应的 call_stmt"
 
-#: cgraph.c:3140
+#: cgraph.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "边 %s->%s 没有对应的 call_stmt"
 
-#: cgraph.c:3151
+#: cgraph.c:3180
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node 失败"
 
-#: cgraph.c:3246 varpool.c:326
+#: cgraph.c:3275 varpool.c:326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "‘-l’缺少实参"
@@ -16569,7 +16586,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER 必须被设定。"
 
-#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1354
+#: collect2.c:966 gcc.c:6986 lto-wrapper.c:1356
 #: config/i386/intelmic-mkoffload.c:504
 #, gcc-internal-format
 msgid "atexit failed"
@@ -16810,17 +16827,17 @@
 msgid "          %s"
 msgstr "          %s"
 
-#: dbxout.c:3344
+#: dbxout.c:3346
 #, gcc-internal-format
 msgid "common symbol debug info is not structured as symbol+offset"
 msgstr "公共符号调试信息没有构造为符号+偏移的形式"
 
-#: dbxout.c:3816
+#: dbxout.c:3818
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "全局析构函数在此目标机上不受支持"
 
-#: dbxout.c:3833
+#: dbxout.c:3835
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "全局构造函数在此目标机上不受支持"
@@ -16865,12 +16882,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "多个 EH 个性需要汇编器支持 .cfi.personality 指示。"
 
-#: dwarf2out.c:11635
+#: dwarf2out.c:11638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "变量位置处发现未被非法化的 UNSPEC %d"
 
-#: dwarf2out.c:22628
+#: dwarf2out.c:22674
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -17065,7 +17082,7 @@
 msgid "total size of local objects too large"
 msgstr "局部对象的总大小太大"
 
-#: function.c:1774 gimplify.c:5188
+#: function.c:1774 gimplify.c:5192
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%>中不可能的约束"
@@ -17516,9 +17533,9 @@
 msgstr "无法写入 PCH 文件"
 
 #: gimple-ssa-isolate-paths.c:319 gimple-ssa-isolate-paths.c:448 tree.c:12136
-#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:748
-#: cp/decl2.c:4967 cp/pt.c:7035 cp/semantics.c:1742 cp/typeck.c:1643
-#: cp/typeck.c:3598
+#: tree.c:12173 c/c-typeck.c:2789 c/c-typeck.c:2872 cp/constexpr.c:757
+#: cp/decl2.c:4971 cp/pt.c:7091 cp/semantics.c:1742 cp/typeck.c:1643
+#: cp/typeck.c:3589
 #, gcc-internal-format
 msgid "declared here"
 msgstr "在此声明"
@@ -17533,154 +17550,148 @@
 msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr "gimple 检查：需要 %s(%s)，得到 %s(%s) 在 %s 中，于 %s:%d"
 
-#: gimplify.c:2499
+#: gimplify.c:2503
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "使用返回%<void%>的函数的结果"
 
-#: gimplify.c:5073
+#: gimplify.c:5077
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "汇编输出 %d 中左值无效"
 
-#: gimplify.c:5189
+#: gimplify.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "非内存输入 %d 必须在内存中"
 
-#: gimplify.c:5211
+#: gimplify.c:5215
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "内存输入 %d 不可直接寻址"
 
-#: gimplify.c:5732
+#: gimplify.c:5736
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "嵌套函数中使用了寄存器变量%qD"
 
-#: gimplify.c:5734
+#: gimplify.c:5738
 #, fuzzy, gcc-internal-format
 msgid "enclosing target region"
 msgstr "括入并行"
 
-#: gimplify.c:5746
+#: gimplify.c:5750
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "嵌套函数中使用了寄存器变量%qD"
 
-#: gimplify.c:5748 gimplify.c:5843
+#: gimplify.c:5752 gimplify.c:5847
 #, fuzzy, gcc-internal-format
 msgid "enclosing task"
 msgstr "括入并行"
 
-#: gimplify.c:5795
+#: gimplify.c:5799
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:5835
+#: gimplify.c:5839
 #, gcc-internal-format
 msgid "%qE not specified in enclosing parallel"
 msgstr "%qE未为在括入的并行中指定"
 
-#: gimplify.c:5837
+#: gimplify.c:5841
 #, gcc-internal-format
 msgid "enclosing parallel"
 msgstr "括入并行"
 
-#: gimplify.c:5841
+#: gimplify.c:5845
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing task"
 msgstr "%qE未为在括入的并行中指定"
 
-#: gimplify.c:5847
+#: gimplify.c:5851
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing teams construct"
 msgstr "%qE未为在括入的并行中指定"
 
-#: gimplify.c:5849
+#: gimplify.c:5853
 #, fuzzy, gcc-internal-format
 msgid "enclosing teams construct"
 msgstr "括入并行"
 
-#: gimplify.c:5960 gimplify.c:5989
+#: gimplify.c:5971 gimplify.c:6000
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "迭代变量%qE不应当是 reduction"
 
-#: gimplify.c:5963
+#: gimplify.c:5974
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "迭代变量%qE应当是私有的"
 
-#: gimplify.c:5977
+#: gimplify.c:5988
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "迭代变量%qE不应当是 firstprivate"
 
-#: gimplify.c:5980
+#: gimplify.c:5991
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "迭代变量%qE不应当是 reduction"
 
-#: gimplify.c:5983
+#: gimplify.c:5994
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "迭代变量%qE不应当是 firstprivate"
 
-#: gimplify.c:5986
+#: gimplify.c:5997
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "迭代变量%qE应当是私有的"
 
-#: gimplify.c:6285
+#: gimplify.c:6416
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s 变量%qE在外层上下文中是私有的"
 
-#: gimplify.c:6295
+#: gimplify.c:6426
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s 变量%qE在外层上下文中是私有的"
 
-#: gimplify.c:7001
+#: gimplify.c:8525 gimplify.c:8531 gimplify.c:8539
 #, fuzzy, gcc-internal-format
-#| msgid "%s variable %qE is private in outer context"
-msgid "lastprivate variable %qE is private in outer context"
-msgstr "%s 变量%qE在外层上下文中是私有的"
-
-#: gimplify.c:8369 gimplify.c:8375 gimplify.c:8383
-#, fuzzy, gcc-internal-format
 #| msgid "Finalization at %L is not yet implemented"
 msgid "directive not yet implemented"
 msgstr "%L处的终结化还未实现"
 
-#: gimplify.c:8535
+#: gimplify.c:8691
 #, fuzzy, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "%<else%>前需要%<}%>"
 
-#: gimplify.c:8831
+#: gimplify.c:8987
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification 失败"
 
-#: gimplify.c:9296
+#: gimplify.c:9452
 #, gcc-internal-format
 msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgstr "给%<va_arg%>的第一个参数的类型不是%<va_list%>"
 
-#: gimplify.c:9312
+#: gimplify.c:9468
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "通过%<...%>传递时%qT被提升为%qT"
 
-#: gimplify.c:9317
+#: gimplify.c:9473
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(因此您应该向%<va_arg%>传递%qT而不是%qT)"
 
-#: gimplify.c:9324
+#: gimplify.c:9480
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "如果执行到这段代码，程序将中止"
@@ -18096,42 +18107,42 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1307
+#: lto-cgraph.c:1332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "字节码流：找到 cgraph 节点 %d 的多个实例"
 
-#: lto-cgraph.c:1484
+#: lto-cgraph.c:1509
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "字节码流：读取边时找不到调用者"
 
-#: lto-cgraph.c:1490
+#: lto-cgraph.c:1515
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "字节码流：读取边时找不到被调用者"
 
-#: lto-cgraph.c:1565
+#: lto-cgraph.c:1590
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "字节码流：找到空的 cgraph 节点"
 
-#: lto-cgraph.c:1739
+#: lto-cgraph.c:1764
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1826
+#: lto-cgraph.c:1851
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "%s 的存储信息很诡异"
 
-#: lto-cgraph.c:1859
+#: lto-cgraph.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "找不到类%qE"
 
-#: lto-cgraph.c:1869
+#: lto-cgraph.c:1894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr ""
@@ -18138,7 +18149,7 @@
 "在插件 %2$s 中找不到 %1$s\n"
 "%3$s"
 
-#: lto-cgraph.c:1937
+#: lto-cgraph.c:1962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -18221,48 +18232,48 @@
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "COLLECT_GCC_OPTIONS 格式错误"
 
-#: lto-wrapper.c:298 lto-wrapper.c:310
+#: lto-wrapper.c:299 lto-wrapper.c:311
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:736
+#: lto-wrapper.c:738
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:755
+#: lto-wrapper.c:757
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "没有输入文件"
 
-#: lto-wrapper.c:760
+#: lto-wrapper.c:762
 #, fuzzy, gcc-internal-format
 msgid "writing output file"
 msgstr "%s：写入输出文件‘%s’时出错\n"
 
-#: lto-wrapper.c:786
+#: lto-wrapper.c:788
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadend.o"
 msgstr ""
 
-#: lto-wrapper.c:798
+#: lto-wrapper.c:800
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadbegin.o"
 msgstr ""
 
-#: lto-wrapper.c:902
+#: lto-wrapper.c:904
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "环境变量 COLLECT_GCC 必须被设置"
 
-#: lto-wrapper.c:906 config/nvptx/mkoffload.c:883
+#: lto-wrapper.c:908 config/nvptx/mkoffload.c:883
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "环境变量 COLLECT_GCC_OPTIONS 必须被设置"
 
-#: lto-wrapper.c:1172
+#: lto-wrapper.c:1174
 #, fuzzy, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen %s"
@@ -18399,13 +18410,13 @@
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:12029
+#: omp-low.c:12080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid exit from OpenMP structured block"
 msgid "invalid exit from %s structured block"
 msgstr "OpenMP 结构块出口无效"
 
-#: omp-low.c:12031 omp-low.c:12036
+#: omp-low.c:12082 omp-low.c:12087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid entry to OpenMP structured block"
 msgid "invalid entry to %s structured block"
@@ -18412,17 +18423,17 @@
 msgstr "OpenMP 结构块入口无效"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:12040
+#: omp-low.c:12091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr "进出 OpenMP 结构块的分支无效"
 
-#: omp-low.c:12531
+#: omp-low.c:12590
 #, fuzzy, gcc-internal-format
 msgid "ignoring large linear step"
 msgstr "忽略重复的目录“%s”\n"
 
-#: omp-low.c:12538
+#: omp-low.c:12597
 #, gcc-internal-format
 msgid "ignoring zero linear step"
 msgstr ""
@@ -18950,8 +18961,8 @@
 msgstr "无法将%qs用作调用者固定寄存器"
 
 #: reginfo.c:790 config/ia64/ia64.c:5983 config/ia64/ia64.c:5990
-#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9543
-#: config/sh/sh.c:9550 config/spu/spu.c:4956 config/spu/spu.c:4963
+#: config/pa/pa.c:466 config/pa/pa.c:473 config/sh/sh.c:9544
+#: config/sh/sh.c:9551 config/spu/spu.c:4956 config/spu/spu.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown register name: %s"
 msgstr "未知的寄存器名：%s"
@@ -19393,7 +19404,7 @@
 msgid "ld returned %d exit status"
 msgstr "ld 返回 %d"
 
-#: toplev.c:522 c/c-decl.c:10661
+#: toplev.c:522 c/c-decl.c:10662
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F使用过但从未定义"
@@ -20375,42 +20386,42 @@
 msgid "memory access check always fail"
 msgstr ""
 
-#: tree-chkp.c:1929
+#: tree-chkp.c:1994
 #, gcc-internal-format, gfc-internal-format
 msgid "-fcheck-pointer-bounds requires '%s' name for internal usage"
 msgstr ""
 
-#: tree-chkp.c:2636
+#: tree-chkp.c:2701
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
 msgstr ""
 
-#: tree-chkp.c:2711
+#: tree-chkp.c:2776
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
 msgstr ""
 
-#: tree-chkp.c:2754
+#: tree-chkp.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
 msgstr ""
 
-#: tree-chkp.c:3375
+#: tree-chkp.c:3440
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3527
+#: tree-chkp.c:3592
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
 msgstr ""
 
-#: tree-chkp.c:3538
+#: tree-chkp.c:3603
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
 msgstr ""
 
-#: tree-chkp.c:3654
+#: tree-chkp.c:3719
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
 msgstr ""
@@ -20791,47 +20802,47 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:6571
+#: tree-vrp.c:6576
 #, gcc-internal-format
 msgid "array subscript is outside array bounds"
 msgstr "数组下标越过了数组边界"
 
-#: tree-vrp.c:6589 tree-vrp.c:6689
+#: tree-vrp.c:6594 tree-vrp.c:6694
 #, gcc-internal-format
 msgid "array subscript is above array bounds"
 msgstr "数组下标大于数组边界"
 
-#: tree-vrp.c:6602 tree-vrp.c:6676
+#: tree-vrp.c:6607 tree-vrp.c:6681
 #, gcc-internal-format
 msgid "array subscript is below array bounds"
 msgstr "数组下标小于数组边界"
 
-#: tree-vrp.c:7542
+#: tree-vrp.c:7547
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
 msgstr "将条件简化为常量时假定有符号数从不溢出"
 
-#: tree-vrp.c:7548 tree-vrp.c:9455 tree-vrp.c:9499 tree-vrp.c:9560
+#: tree-vrp.c:7553 tree-vrp.c:9463 tree-vrp.c:9507 tree-vrp.c:9568
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
 msgstr "简化条件时假定有符号数从不溢出"
 
-#: tree-vrp.c:7592
+#: tree-vrp.c:7597
 #, gcc-internal-format
 msgid "comparison always false due to limited range of data type"
 msgstr "由于数据类型范围限制，比较结果永远为假"
 
-#: tree-vrp.c:7594
+#: tree-vrp.c:7599
 #, gcc-internal-format
 msgid "comparison always true due to limited range of data type"
 msgstr "由于数据类型范围限制，比较结果永远为真"
 
-#: tree-vrp.c:9090
+#: tree-vrp.c:9098
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
 msgstr "将%</%>或%<%%%>简化为%<>>%>或%<&%>时假定有符号数从不溢出"
 
-#: tree-vrp.c:9172
+#: tree-vrp.c:9180
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgstr "将%<abs (X)%>简化为%<X%>或%<-X%>时假定有符号数从不溢出"
@@ -20875,9 +20886,9 @@
 #: c-family/c-common.c:9217 c-family/c-common.c:9299 c-family/c-common.c:9446
 #: config/darwin.c:2069 config/arm/arm.c:6250 config/arm/arm.c:6278
 #: config/arm/arm.c:6295 config/avr/avr.c:8975 config/h8300/h8300.c:5496
-#: config/h8300/h8300.c:5520 config/i386/i386.c:5588 config/i386/i386.c:42817
-#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:28992 config/spu/spu.c:3790
-#: ada/gcc-interface/utils.c:5811 ada/gcc-interface/utils.c:5837
+#: config/h8300/h8300.c:5520 config/i386/i386.c:5608 config/i386/i386.c:42946
+#: config/ia64/ia64.c:797 config/rs6000/rs6000.c:29090 config/spu/spu.c:3790
+#: ada/gcc-interface/utils.c:5814 ada/gcc-interface/utils.c:5840
 #: lto/lto-lang.c:260
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21111,7 +21122,7 @@
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "%q+D需要的对齐边界大于实现的对齐边界 %wu"
 
-#: varasm.c:2137 c/c-decl.c:4804
+#: varasm.c:2137 c/c-decl.c:4805
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D的存储大小未知"
@@ -21260,27 +21271,27 @@
 msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
 msgstr "字符串长%qd比%qd(ISO C%d 被要求支持的最大长度) 还要长"
 
-#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4340
+#: c-family/c-common.c:1374 c/c-typeck.c:10711 cp/typeck.c:4331
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左移次数为负"
 
-#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4295
+#: c-family/c-common.c:1375 c/c-typeck.c:10661 cp/typeck.c:4286
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右移次数为负"
 
-#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4348
+#: c-family/c-common.c:1380 c/c-typeck.c:10719 cp/typeck.c:4339
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左移次数大于或等于类型宽度"
 
-#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4303
+#: c-family/c-common.c:1381 c/c-typeck.c:10673 cp/typeck.c:4294
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右移次数大于或等于类型宽度"
 
-#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1503
+#: c-family/c-common.c:1614 c-family/c-common.c:1626 cp/constexpr.c:1528
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "常量表达式溢出"
@@ -21611,12 +21622,12 @@
 msgid "the address of %qD will always evaluate as %<true%>"
 msgstr "%qD的地址总是等价为%<true%>"
 
-#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8257
+#: c-family/c-common.c:4809 cp/semantics.c:680 cp/typeck.c:8248
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "建议在用作真值的赋值语句前后加上括号"
 
-#: c-family/c-common.c:4888 c/c-decl.c:4101 c/c-typeck.c:12630
+#: c-family/c-common.c:4888 c/c-decl.c:4102 c/c-typeck.c:12630
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "错误地使用了%<restrict%>"
@@ -22071,12 +22082,12 @@
 msgid "invalid vector type for attribute %qE"
 msgstr "属性%qE的向量类型无效"
 
-#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3640
+#: c-family/c-common.c:8882 ada/gcc-interface/utils.c:3643
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "向量大小不是组件大小的整数倍"
 
-#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3647
+#: c-family/c-common.c:8888 ada/gcc-interface/utils.c:3650
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "向量大小为 0"
@@ -22086,22 +22097,22 @@
 msgid "number of components of the vector not a power of two"
 msgstr "向量中分量数不是 2 的某次方"
 
-#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5671
+#: c-family/c-common.c:8924 ada/gcc-interface/utils.c:5674
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "非空的属性在非原型中没有实参"
 
-#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5685
+#: c-family/c-common.c:8943 ada/gcc-interface/utils.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "非空的实参 %lu 操作数号不对"
 
-#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5707
+#: c-family/c-common.c:8965 ada/gcc-interface/utils.c:5710
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "非空的实参操作数号越界(实参 %lu，操作数 %lu)"
 
-#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5716
+#: c-family/c-common.c:8973 ada/gcc-interface/utils.c:5719
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "非空的实参 %lu 引用了非指针操作数 %lu"
@@ -22141,12 +22152,12 @@
 msgid "%qE attribute only applies to variadic functions"
 msgstr "%qE属性只能用于带可变参数函数"
 
-#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5758
+#: c-family/c-common.c:9257 ada/gcc-interface/utils.c:5761
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "要求的位置不是一个整数常量"
 
-#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5765
+#: c-family/c-common.c:9265 ada/gcc-interface/utils.c:5768
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "要求的位置小于 0"
@@ -22227,7 +22238,7 @@
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "不能为非常量地址应用%<offsetof%>"
 
-#: c-family/c-common.c:10096 cp/typeck.c:5576
+#: c-family/c-common.c:10096 cp/typeck.c:5567
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "试图取位段结构成员%qD的地址"
@@ -22645,7 +22656,7 @@
 msgstr "索引值越界"
 
 #: c-family/c-common.c:12214 c-family/c-common.c:12264
-#: c-family/c-common.c:12279 cp/call.c:4631 cp/call.c:4638
+#: c-family/c-common.c:12279 cp/call.c:4641 cp/call.c:4648
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "从%qT到%qT的转换有歧义"
@@ -23101,7 +23112,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:474 cp/semantics.c:6629
+#: c-family/c-omp.c:474 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "迭代变量%qE类型无效"
@@ -23111,22 +23122,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE未经初始化"
 
-#: c-family/c-omp.c:507 cp/semantics.c:6535
+#: c-family/c-omp.c:507 cp/semantics.c:6541
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制谓词"
 
-#: c-family/c-omp.c:592 cp/semantics.c:6279
+#: c-family/c-omp.c:592 cp/semantics.c:6285
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "无效的控制谓词"
 
-#: c-family/c-omp.c:599 cp/semantics.c:6541
+#: c-family/c-omp.c:599 cp/semantics.c:6547
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少自增语句"
 
-#: c-family/c-omp.c:663 cp/semantics.c:6389
+#: c-family/c-omp.c:663 cp/semantics.c:6395
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "无效的自增语句"
@@ -23663,6 +23674,12 @@
 msgid "too many input files"
 msgstr "输入文件太多"
 
+#: common/config/aarch64/aarch64-common.c:116
+#, fuzzy, gcc-internal-format
+#| msgid "stack frame too large"
+msgid "-mcpu string too large"
+msgstr "栈帧太大"
+
 #: common/config/alpha/alpha-common.c:76
 #, gcc-internal-format
 msgid "bad value %qs for -mtls-size switch"
@@ -23688,47 +23705,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s 芯片版本不正确"
 
-#: common/config/i386/i386-common.c:939
+#: common/config/i386/i386-common.c:954
 #, fuzzy, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "%salign-loops%s 已经过时，请使用 -falign-loops%s"
 
-#: common/config/i386/i386-common.c:941
+#: common/config/i386/i386-common.c:956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s 不在 0 和 %d 之间"
 
-#: common/config/i386/i386-common.c:948
+#: common/config/i386/i386-common.c:963
 #, fuzzy, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "%salign-jumps%s 已经过时，请使用 -falign-jumps%s"
 
-#: common/config/i386/i386-common.c:950
+#: common/config/i386/i386-common.c:965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s 不在 0 和 %d 之间"
 
-#: common/config/i386/i386-common.c:958
+#: common/config/i386/i386-common.c:973
 #, fuzzy, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "%salign-functions%s 已过时，请使用 -falign-functions%s"
 
-#: common/config/i386/i386-common.c:960
+#: common/config/i386/i386-common.c:975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s 不在 0 和 %d 之间"
 
-#: common/config/i386/i386-common.c:969
+#: common/config/i386/i386-common.c:984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "%sbranch-cost=%d%s不在 0 和 5 之间"
 
-#: common/config/i386/i386-common.c:1020
+#: common/config/i386/i386-common.c:1035
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%>只在 GNU/Linux 下被支持"
 
-#: common/config/i386/i386-common.c:1026
+#: common/config/i386/i386-common.c:1041
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%>需要汇编器支持 CFI 伪指令"
@@ -24112,63 +24129,63 @@
 msgid "lane %ld out of range %ld - %ld"
 msgstr "操作数号超出范围"
 
-#: config/alpha/alpha.c:464
+#: config/alpha/alpha.c:465
 #, gcc-internal-format
 msgid "bad value %qs for -mtrap-precision switch"
 msgstr "-mtrap-precision 开关的值%qs不正确"
 
-#: config/alpha/alpha.c:478
+#: config/alpha/alpha.c:479
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-rounding-mode switch"
 msgstr "-mfp-rounding-mode 开关的值%qs不正确"
 
-#: config/alpha/alpha.c:493
+#: config/alpha/alpha.c:494
 #, gcc-internal-format
 msgid "bad value %qs for -mfp-trap-mode switch"
 msgstr "-mfp-trap-mode 开关的值%qs不正确"
 
-#: config/alpha/alpha.c:510
+#: config/alpha/alpha.c:511
 #, gcc-internal-format
 msgid "bad value %qs for -mcpu switch"
 msgstr "-mcpu 开关的值%qs错误"
 
-#: config/alpha/alpha.c:525
+#: config/alpha/alpha.c:526
 #, gcc-internal-format
 msgid "bad value %qs for -mtune switch"
 msgstr "-mtune 开关的值%qs错误"
 
-#: config/alpha/alpha.c:546
+#: config/alpha/alpha.c:547
 #, gcc-internal-format
 msgid "fp software completion requires -mtrap-precision=i"
 msgstr "软件浮点需要 -mtrap-precision=i"
 
-#: config/alpha/alpha.c:562
+#: config/alpha/alpha.c:563
 #, gcc-internal-format
 msgid "rounding mode not supported for VAX floats"
 msgstr "舍入模式不为 VAX 浮点数所支持"
 
-#: config/alpha/alpha.c:567
+#: config/alpha/alpha.c:568
 #, gcc-internal-format
 msgid "trap mode not supported for VAX floats"
 msgstr "陷阱模式不为 VAX 浮点数所支持"
 
-#: config/alpha/alpha.c:571
+#: config/alpha/alpha.c:572
 #, gcc-internal-format
 msgid "128-bit long double not supported for VAX floats"
 msgstr "128 位 long double 在 VAX 上不受支持"
 
-#: config/alpha/alpha.c:599
+#: config/alpha/alpha.c:600
 #, gcc-internal-format, gfc-internal-format
 msgid "L%d cache latency unknown for %s"
 msgstr "L%d 缓存延迟未知，对 %s 来说"
 
-#: config/alpha/alpha.c:614
+#: config/alpha/alpha.c:615
 #, gcc-internal-format
 msgid "bad value %qs for -mmemory-latency"
 msgstr "-mmemory-latency 开关的值%qs错误"
 
-#: config/alpha/alpha.c:6726 config/alpha/alpha.c:6729
-#: config/s390/s390.c:10096 config/s390/s390.c:10099
+#: config/alpha/alpha.c:6732 config/alpha/alpha.c:6735
+#: config/s390/s390.c:10100 config/s390/s390.c:10103
 #: config/tilegx/tilegx.c:3579 config/tilepro/tilepro.c:3147
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -24642,14 +24659,14 @@
 #: config/arm/arm.c:6218 config/arm/arm.c:6236 config/avr/avr.c:8995
 #: config/avr/avr.c:9011 config/bfin/bfin.c:4699 config/bfin/bfin.c:4760
 #: config/bfin/bfin.c:4789 config/epiphany/epiphany.c:507
-#: config/h8300/h8300.c:5472 config/i386/i386.c:5543 config/i386/i386.c:42721
-#: config/i386/i386.c:42771 config/i386/i386.c:42841 config/m68k/m68k.c:764
+#: config/h8300/h8300.c:5472 config/i386/i386.c:5563 config/i386/i386.c:42850
+#: config/i386/i386.c:42900 config/i386/i386.c:42970 config/m68k/m68k.c:764
 #: config/mcore/mcore.c:3079 config/mep/mep.c:3929 config/mep/mep.c:3943
 #: config/mep/mep.c:4017 config/msp430/msp430.c:1312 config/nvptx/nvptx.c:2001
-#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:28918 config/rx/rx.c:2696
-#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9696
-#: config/sh/sh.c:9714 config/sh/sh.c:9743 config/sh/sh.c:9825
-#: config/sh/sh.c:9848 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
+#: config/rl78/rl78.c:734 config/rs6000/rs6000.c:29016 config/rx/rx.c:2696
+#: config/rx/rx.c:2722 config/s390/s390.c:480 config/sh/sh.c:9697
+#: config/sh/sh.c:9715 config/sh/sh.c:9744 config/sh/sh.c:9826
+#: config/sh/sh.c:9849 config/spu/spu.c:3732 config/stormy16/stormy16.c:2251
 #: config/v850/v850.c:2117 config/visium/visium.c:653
 #, gcc-internal-format
 msgid "%qE attribute only applies to functions"
@@ -25296,381 +25313,398 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "不能在 PCH 文件中设定位置：%m"
 
-#: config/i386/i386.c:2967
+#: config/i386/i386.c:2969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong arg %s to option %s"
 msgstr "-Werror=%s：没有选项 -%s"
 
-#: config/i386/i386.c:2974
+#: config/i386/i386.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "size ranges of option %s should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:2985
+#: config/i386/i386.c:2987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong stringop strategy name %s specified for option %s"
 msgstr "%q+D的寄存器名无效"
 
-#: config/i386/i386.c:2999
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386.c:2997
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "stringop strategy name %s specified for option %s not supported for 32-bit code"
+msgstr "%q+D的寄存器名无效"
+
+#: config/i386/i386.c:3012
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown alignment %s specified for option %s"
 msgstr "不能为%q+D指定对齐"
 
-#: config/i386/i386.c:3010
+#: config/i386/i386.c:3023
 #, gcc-internal-format, gfc-internal-format
 msgid "the max value for the last size range should be -1 for option %s"
 msgstr ""
 
-#: config/i386/i386.c:3018
+#: config/i386/i386.c:3031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too many size ranges specified in option %s"
 msgstr "%qs没有指定类名"
 
-#: config/i386/i386.c:3072
+#: config/i386/i386.c:3085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown parameter to option -mtune-ctrl: %s"
 msgstr "%L处参数列表函数未知"
 
-#: config/i386/i386.c:3453
+#: config/i386/i386.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgstr "不建议使用%stune=x86-64%s；请视情况改用%stune=k8%s或%stune=generic%s"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3480
+#: config/i386/i386.c:3494
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3497
+#: config/i386/i386.c:3511
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386.c:3523 config/i386/i386.c:3532 config/i386/i386.c:3544
-#: config/i386/i386.c:3555 config/i386/i386.c:3566
+#: config/i386/i386.c:3537 config/i386/i386.c:3546 config/i386/i386.c:3558
+#: config/i386/i386.c:3569 config/i386/i386.c:3580
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386.c:3535 config/i386/i386.c:3547
+#: config/i386/i386.c:3549 config/i386/i386.c:3561
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386.c:3553 config/i386/i386.c:3562 config/i386/i386.c:4600
+#: config/i386/i386.c:3567 config/i386/i386.c:3576 config/i386/i386.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "代码模式 %s 在 PIC 模式下不受支持"
 
-#: config/i386/i386.c:3590
+#: config/i386/i386.c:3604
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s 在此配置下不受支持"
 
-#: config/i386/i386.c:3595
+#: config/i386/i386.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "未编译入对 %i 位模式的支持"
 
-#: config/i386/i386.c:3608 config/i386/i386.c:3823
+#: config/i386/i386.c:3622 config/i386/i386.c:3840
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "您选择的 CPU 不支持 x86-64 指令集"
 
-#: config/i386/i386.c:3784 config/i386/i386.c:3787
+#: config/i386/i386.c:3801 config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s 不支持 %s"
 
-#: config/i386/i386.c:3790
+#: config/i386/i386.c:3807
 #, gcc-internal-format, gfc-internal-format
 msgid "generic CPU can be used only for %stune=%s %s"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386.c:3793
+#: config/i386/i386.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "intel CPU can be used only for %stune=%s %s"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386.c:3796
+#: config/i386/i386.c:3813
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %sarch=%s %s"
 msgstr "%2$sarch=%3$s %4$s所带参数(%1$s)不正确"
 
-#: config/i386/i386.c:3839
+#: config/i386/i386.c:3856
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for %stune=%s %s"
 msgstr "%2$stune=%3$s%4$s所带参数(%1$s)不正确"
 
-#: config/i386/i386.c:3894
+#: config/i386/i386.c:3911
 #, fuzzy, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "%sregparm%s 在 64 位模式下被忽略"
 
-#: config/i386/i386.c:3897
+#: config/i386/i386.c:3914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "%sregparm=%d%s 不在 0 和 %d 之间"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3957
 #, gcc-internal-format, gfc-internal-format
 msgid "%srtd%s is ignored in 64bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/i386/i386.c:4018
+#: config/i386/i386.c:4035
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "%spreferred-stack-boundary%s 在此目标机上不被支持"
 
-#: config/i386/i386.c:4021
+#: config/i386/i386.c:4038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s 不在 %d 和 %d 之间"
 
-#: config/i386/i386.c:4043
+#: config/i386/i386.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 不在 %d 和 12 之间"
 
-#: config/i386/i386.c:4057
+#: config/i386/i386.c:4074
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mno-fentry 与 SEH 不兼容"
 
-#: config/i386/i386.c:4060
+#: config/i386/i386.c:4077
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "模块间优化未为 C++ 实现"
 
-#: config/i386/i386.c:4065
+#: config/i386/i386.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "%ssseregparm%s used without SSE enabled"
 msgstr "使用了 %ssseregparm%s 却没有启用 SEE"
 
-#: config/i386/i386.c:4073
+#: config/i386/i386.c:4090
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已禁用，使用 387 指令"
 
-#: config/i386/i386.c:4079
+#: config/i386/i386.c:4096
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已禁用，使用 SSE 指令"
 
-#: config/i386/i386.c:4131
+#: config/i386/i386.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4251
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry 在 32 位下不能和 -fpic 同时使用"
 
-#: config/i386/i386.c:4239
+#: config/i386/i386.c:4258
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry 与 SEH 不兼容"
 
-#: config/i386/i386.c:4296 config/rs6000/rs6000.c:4240
+#: config/i386/i386.c:4315 config/rs6000/rs6000.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "L%d 缓存延迟未知，对 %s 来说"
 
-#: config/i386/i386.c:4801
+#: config/i386/i386.c:4821
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/i386/i386.c:4867 config/i386/i386.c:4914
+#: config/i386/i386.c:4887 config/i386/i386.c:4934
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/i386/i386.c:4895
+#: config/i386/i386.c:4915
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\")已经被指定"
 
-#: config/i386/i386.c:5556 config/i386/i386.c:5607
+#: config/i386/i386.c:5576 config/i386/i386.c:5627
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 属性互不兼容"
 
-#: config/i386/i386.c:5561
+#: config/i386/i386.c:5581
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:5568 config/i386/i386.c:42741
+#: config/i386/i386.c:5588 config/i386/i386.c:42870
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: config/i386/i386.c:5574
+#: config/i386/i386.c:5594
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE属性的实参大于 %d"
 
-#: config/i386/i386.c:5599 config/i386/i386.c:5642
+#: config/i386/i386.c:5619 config/i386/i386.c:5662
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386.c:5603
+#: config/i386/i386.c:5623
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 属性互不兼容"
 
-#: config/i386/i386.c:5611 config/i386/i386.c:5660
+#: config/i386/i386.c:5631 config/i386/i386.c:5680
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:5621 config/i386/i386.c:5638
+#: config/i386/i386.c:5641 config/i386/i386.c:5658
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386.c:5625
+#: config/i386/i386.c:5645
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 属性互不兼容"
 
-#: config/i386/i386.c:5629 config/i386/i386.c:5656
+#: config/i386/i386.c:5649 config/i386/i386.c:5676
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:5646 config/i386/i386.c:5664
+#: config/i386/i386.c:5666 config/i386/i386.c:5684
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:5652
+#: config/i386/i386.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE属性用于非类方法"
 
-#: config/i386/i386.c:5887
+#: config/i386/i386.c:5910
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qD却没有启用 SSE/SSE2"
 
-#: config/i386/i386.c:5890
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qT却没有启用 SSE/SSE2"
 
-#: config/i386/i386.c:5923
+#: config/i386/i386.c:6235
 #, fuzzy, gcc-internal-format
-#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
-msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
-msgstr "带属性 sseregparm 调用%qD却没有启用 SSE/SSE2"
-
-#: config/i386/i386.c:6210
-#, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "不支持 multilib"
 
-#: config/i386/i386.c:6239
+#: config/i386/i386.c:6264
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue 与嵌套函数不兼容"
 
-#: config/i386/i386.c:6573
+#: config/i386/i386.c:6599
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "没有启用 AVX，却出现了 AVX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:6579
+#: config/i386/i386.c:6605
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "没有启用 AVX，却出现了 AVX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:6593
+#: config/i386/i386.c:6619
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "没有启用 AVX，却出现了 AVX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:6599
+#: config/i386/i386.c:6625
 #, fuzzy, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "没有启用 AVX，却出现了 AVX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:6614
+#: config/i386/i386.c:6640
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "没有启用 SSE，却出现了 SSE 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:6620
+#: config/i386/i386.c:6646
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "没有启用 SSE，却有 SSE 向量返回值，这改变了 ABI"
 
-#: config/i386/i386.c:6632
+#: config/i386/i386.c:6658
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "没有启用 MMX，却出现了 MMX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:6638
+#: config/i386/i386.c:6664
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "没有启用 MMX却返回 MMX 向量，这改变了 ABI"
 
-#: config/i386/i386.c:6821
+#: config/i386/i386.c:6847
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递带有一个可变数组成员的结构的 ABI 有了改变"
 
-#: config/i386/i386.c:6938
+#: config/i386/i386.c:6964
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/i386/i386.c:7056
+#: config/i386/i386.c:7082
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/i386/i386.c:7219
+#: config/i386/i386.c:7245
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "已禁用 SSE 却在 SSE 寄存器中返回"
 
-#: config/i386/i386.c:7225
+#: config/i386/i386.c:7251
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "已禁用 SSE 却在 SSE 寄存器中传递参数"
 
-#: config/i386/i386.c:7241
+#: config/i386/i386.c:7267
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "已禁用 x87 却在 x87 寄存器中返回"
 
-#: config/i386/i386.c:8138
+#: config/i386/i386.c:7551 config/i386/i386.c:7801
+#, fuzzy, gcc-internal-format
+#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr "带属性 sseregparm 调用%qD却没有启用 SSE/SSE2"
+
+#: config/i386/i386.c:7553 config/i386/i386.c:7803 config/i386/i386.c:8289
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.c:8190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/i386/i386.c:11319
+#: config/i386/i386.c:8287
 #, fuzzy, gcc-internal-format
+#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
+msgstr "带属性 sseregparm 调用%qD却没有启用 SSE/SSE2"
+
+#: config/i386/i386.c:11378
+#, fuzzy, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "ms_hook_prologue 与嵌套函数不兼容"
 
-#: config/i386/i386.c:12357
+#: config/i386/i386.c:12416
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack 不支持在嵌套函数中使用两个寄存器参数"
 
-#: config/i386/i386.c:12377
+#: config/i386/i386.c:12436
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 2 register  parameters for a nested function"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -25678,252 +25712,252 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:12388
+#: config/i386/i386.c:12447
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 不允许可变数组成员"
 
-#: config/i386/i386.c:15244
+#: config/i386/i386.c:15303
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "扩展的寄存器没有高半部分"
 
-#: config/i386/i386.c:15259
+#: config/i386/i386.c:15318
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "扩展的寄存器不支持的操作数大小"
 
-#: config/i386/i386.c:15504
+#: config/i386/i386.c:15563
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "非整数操作数使用了操作数代码‘%c’"
 
-#: config/i386/i386.c:34585
+#: config/i386/i386.c:34694
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:34635
+#: config/i386/i386.c:34744
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:34645
+#: config/i386/i386.c:34754
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:34893
+#: config/i386/i386.c:35002
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:34898 config/i386/i386.c:35346
+#: config/i386/i386.c:35007 config/i386/i386.c:35455
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "不支持静态链接"
 
-#: config/i386/i386.c:34963
+#: config/i386/i386.c:35072
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:34966
+#: config/i386/i386.c:35075
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "%q+D的前一个声明"
 
-#: config/i386/i386.c:35185
+#: config/i386/i386.c:35294
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: config/i386/i386.c:35563
+#: config/i386/i386.c:35672
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs的实参必须是一个 2 位无符号字面常量"
 
-#: config/i386/i386.c:35588 config/i386/i386.c:35638
+#: config/i386/i386.c:35697 config/i386/i386.c:35747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "-ffpe-trap 的参数无效：%s"
 
-#: config/i386/i386.c:36049 config/i386/i386.c:37457
+#: config/i386/i386.c:36158 config/i386/i386.c:37566
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最后一个实参必须是一个 2 位立即数"
 
-#: config/i386/i386.c:36446
+#: config/i386/i386.c:36555
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "第五个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:36541
+#: config/i386/i386.c:36650
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "第三个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:37388
+#: config/i386/i386.c:37497
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最后一个实参必须是一个 1 位立即数"
 
-#: config/i386/i386.c:37403
+#: config/i386/i386.c:37512
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最后一个参数必须是一个 32 位立即数"
 
-#: config/i386/i386.c:37436
+#: config/i386/i386.c:37545
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386.c:37476
+#: config/i386/i386.c:37585
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最后一个实参必须是一个 1 位立即数"
 
-#: config/i386/i386.c:37489
+#: config/i386/i386.c:37598
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最后一个实参必须是一个 5 位立即数"
 
-#: config/i386/i386.c:37499
+#: config/i386/i386.c:37608
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "倒数第二个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:37503 config/i386/i386.c:38276
+#: config/i386/i386.c:37612 config/i386/i386.c:38385
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:37670
+#: config/i386/i386.c:37779
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "实参必须是常数"
 
-#: config/i386/i386.c:37675
+#: config/i386/i386.c:37784
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "对树结节的共享不正确"
 
-#: config/i386/i386.c:37681 config/i386/i386.c:37883
+#: config/i386/i386.c:37790 config/i386/i386.c:37992
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "对树结节的共享不正确"
 
-#: config/i386/i386.c:37865
+#: config/i386/i386.c:37974
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386.c:37871
+#: config/i386/i386.c:37980
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最后一个实参必须是一个 5 位立即数"
 
-#: config/i386/i386.c:37874
+#: config/i386/i386.c:37983
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:38274
+#: config/i386/i386.c:38383
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最后一个参数必须是一个 32 位立即数"
 
-#: config/i386/i386.c:38356 config/rs6000/rs6000.c:13196
+#: config/i386/i386.c:38465 config/rs6000/rs6000.c:13277
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/i386/i386.c:38551
+#: config/i386/i386.c:38660
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE需要未知的 ISA 选项"
 
-#: config/i386/i386.c:38555
+#: config/i386/i386.c:38664
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE需要 ISA 选项 %s"
 
-#: config/i386/i386.c:39289
+#: config/i386/i386.c:39418
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最后一个实参必须是一个立即数"
 
-#: config/i386/i386.c:39885 config/i386/i386.c:40037
+#: config/i386/i386.c:40014 config/i386/i386.c:40166
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386.c:40091
+#: config/i386/i386.c:40220
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "左实参必须是一个切片"
 
-#: config/i386/i386.c:40097
+#: config/i386/i386.c:40226
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "对树结节的共享不正确"
 
-#: config/i386/i386.c:40116
+#: config/i386/i386.c:40245
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:42728
+#: config/i386/i386.c:42857
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE属性只能在 32 位下使用"
 
-#: config/i386/i386.c:42749
+#: config/i386/i386.c:42878
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/i386/i386.c:42782 config/i386/i386.c:42791
+#: config/i386/i386.c:42911 config/i386/i386.c:42920
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 属性互不兼容"
 
-#: config/i386/i386.c:42827 config/rs6000/rs6000.c:29001
+#: config/i386/i386.c:42956 config/rs6000/rs6000.c:29099
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: config/i386/i386.c:51386
+#: config/i386/i386.c:51527
 #, fuzzy, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr "未知的架构‘%s’"
 
-#: config/i386/i386.c:51393
+#: config/i386/i386.c:51534
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51399
+#: config/i386/i386.c:51540
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:51423
+#: config/i386/i386.c:51564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "不支持的 ELF 文件类"
 
-#: config/i386/i386.c:51442
+#: config/i386/i386.c:51583
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51464
+#: config/i386/i386.c:51605
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "%<__builtin_frame_address%>的实参不受支持"
 
-#: config/i386/i386.c:51748
+#: config/i386/i386.c:51889
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -26017,13 +26051,13 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9532
+#: config/ia64/ia64.c:5971 config/pa/pa.c:454 config/sh/sh.c:9533
 #: config/spu/spu.c:4945
 #, gcc-internal-format
 msgid "value of -mfixed-range must have form REG1-REG2"
 msgstr "-mfixed-range 值必须有“寄存器1-寄存器2”的形式"
 
-#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9558
+#: config/ia64/ia64.c:5998 config/pa/pa.c:481 config/sh/sh.c:9559
 #: config/spu/spu.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "%s-%s is an empty range"
@@ -26095,7 +26129,7 @@
 msgstr "%qE属性在 R8C 目标机上不受支持"
 
 #. The argument must be a constant integer.
-#: config/m32c/m32c.c:2982 config/sh/sh.c:9751 config/sh/sh.c:9857
+#: config/m32c/m32c.c:2982 config/sh/sh.c:9752 config/sh/sh.c:9858
 #, gcc-internal-format
 msgid "%qE attribute argument not an integer constant"
 msgstr "%qE属性需要一个整常量作为实参"
@@ -26155,7 +26189,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread 只在 fido 中可用"
 
-#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22579
+#: config/m68k/m68k.c:1112 config/rs6000/rs6000.c:22683
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "不支持堆栈限制表达式"
@@ -27014,16 +27048,11 @@
 msgid "-g option disabled"
 msgstr "-g 选项已被禁用"
 
-#: config/pa/pa.c:8642
+#: config/pa/pa.c:8648
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "对齐边界(%u) 对 %s 来说超过了全局共同数据的最大对齐边界。使用 %u"
 
-#: config/pa/pa-hpux11.h:83
-#, gcc-internal-format
-msgid "-munix=98 option required for C89 Amendment 1 features.\n"
-msgstr "使用 C89 修订版 1 的特性必须指定 -munix=98 选项。\n"
-
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:379
 #, fuzzy, gcc-internal-format
@@ -27285,310 +27314,316 @@
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "目标属性或 pragma 改变了双精度浮点数"
 
-#: config/rs6000/rs6000.c:6162
+#: config/rs6000/rs6000.c:6189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/rs6000/rs6000.c:9232
+#: config/rs6000/rs6000.c:9264
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 返回向量引用：非标准的 ABI 扩展，不保证兼容性"
 
-#: config/rs6000/rs6000.c:9383
+#: config/rs6000/rs6000.c:9415
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量寄存器中返回值，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/rs6000/rs6000.c:9541
+#: config/rs6000/rs6000.c:9573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/rs6000/rs6000.c:9803
+#: config/rs6000/rs6000.c:9835
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量寄存器中传递参数，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/rs6000/rs6000.c:10662
+#: config/rs6000/rs6000.c:10694
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/rs6000/rs6000.c:10833
+#: config/rs6000/rs6000.c:10865
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 传递向量引用：非标准的 ABI 扩展，不保证兼容性"
 
-#: config/rs6000/rs6000.c:11625
+#: config/rs6000/rs6000.c:11657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "内部错误：对 %s 的内建函数已经处理过。"
 
-#: config/rs6000/rs6000.c:12067
+#: config/rs6000/rs6000.c:12099
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "实参 1 必须是一个 5 位有符号字面值"
 
-#: config/rs6000/rs6000.c:12114
+#: config/rs6000/rs6000.c:12146
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "实参 1 必须是一个 5 位有符号字面值"
 
-#: config/rs6000/rs6000.c:12217 config/rs6000/rs6000.c:13659
+#: config/rs6000/rs6000.c:12249 config/rs6000/rs6000.c:13740
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面值"
 
-#: config/rs6000/rs6000.c:12256
+#: config/rs6000/rs6000.c:12288
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "__builtin_altivec_predicate 的第 1 个实参必须是常量"
 
-#: config/rs6000/rs6000.c:12308
+#: config/rs6000/rs6000.c:12340
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "__builtin_altivec_predicate 的第 1 个实参越界"
 
-#: config/rs6000/rs6000.c:12718
+#: config/rs6000/rs6000.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "%srtd%s is ignored in 64bit mode"
+msgid "builtin %s is only valid in 64-bit mode"
+msgstr "%srtd%s 在 64 位模式下被忽略"
+
+#: config/rs6000/rs6000.c:12763
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面值"
 
-#: config/rs6000/rs6000.c:12720
+#: config/rs6000/rs6000.c:12765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate 的第 1 个实参越界"
 
-#: config/rs6000/rs6000.c:12847
+#: config/rs6000/rs6000.c:12928
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "实参 3 必须是一个 4 位无符号字面值"
 
-#: config/rs6000/rs6000.c:12865
+#: config/rs6000/rs6000.c:12946
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "实参 2 必须是一个 2 位无符号字面值"
 
-#: config/rs6000/rs6000.c:12885
+#: config/rs6000/rs6000.c:12966
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面值"
 
-#: config/rs6000/rs6000.c:12897
+#: config/rs6000/rs6000.c:12978
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "数字必须是 0 或 1"
 
-#: config/rs6000/rs6000.c:12909
+#: config/rs6000/rs6000.c:12990
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面值"
 
-#: config/rs6000/rs6000.c:12923
+#: config/rs6000/rs6000.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面值"
 
-#: config/rs6000/rs6000.c:12935
+#: config/rs6000/rs6000.c:13016
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "数字必须是 0 或 1"
 
-#: config/rs6000/rs6000.c:12942
+#: config/rs6000/rs6000.c:13023
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "%2$qE的第 %1$d 个参数必须是在 %3$d 和 %4$d 之间"
 
-#: config/rs6000/rs6000.c:13129
+#: config/rs6000/rs6000.c:13210
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs的实参必须是一个 2 位无符号字面常量"
 
-#: config/rs6000/rs6000.c:13282
+#: config/rs6000/rs6000.c:13363
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "无法解析的重载 Altivec 内建函数%qF"
 
-#: config/rs6000/rs6000.c:13412
+#: config/rs6000/rs6000.c:13493
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "dss 的实参必须是一个 2 位无符号字面常量"
 
-#: config/rs6000/rs6000.c:13779
+#: config/rs6000/rs6000.c:13860
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "__builtin_paired_predicate 的第一个实参必须是常量"
 
-#: config/rs6000/rs6000.c:13826
+#: config/rs6000/rs6000.c:13907
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "__builtin_paired_predicate 的第一个实参越界"
 
-#: config/rs6000/rs6000.c:13851
+#: config/rs6000/rs6000.c:13932
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "__builtin_spe_predicate 的第一个实参必须是常量"
 
-#: config/rs6000/rs6000.c:13923
+#: config/rs6000/rs6000.c:14004
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "__builtin_spe_predicate 的第 1 个实参越界"
 
-#: config/rs6000/rs6000.c:14005
+#: config/rs6000/rs6000.c:14086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "此内建函数只在 fr450 上可用"
 
-#: config/rs6000/rs6000.c:14007
+#: config/rs6000/rs6000.c:14088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:14009
+#: config/rs6000/rs6000.c:14090
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:14011
+#: config/rs6000/rs6000.c:14092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:14013
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:14015
+#: config/rs6000/rs6000.c:14096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:14018
+#: config/rs6000/rs6000.c:14099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:14021
+#: config/rs6000/rs6000.c:14102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:14023
+#: config/rs6000/rs6000.c:14104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:14026
+#: config/rs6000/rs6000.c:14107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:14029
+#: config/rs6000/rs6000.c:14110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:14031
+#: config/rs6000/rs6000.c:14112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "弱引用在此配置下不受支持"
 
-#: config/rs6000/rs6000.c:15524
+#: config/rs6000/rs6000.c:15628
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had no type"
 msgstr "内部错误：内建函数 %s 没有类型"
 
-#: config/rs6000/rs6000.c:15532
+#: config/rs6000/rs6000.c:15636
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "内部错误：内建函数 %s 有非预期的返回类型 %s"
 
-#: config/rs6000/rs6000.c:15549
+#: config/rs6000/rs6000.c:15653
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "内部错误：内建函数 %s 的第 %d 个参数有非预期的参数类型 %s"
 
-#: config/rs6000/rs6000.c:22549
+#: config/rs6000/rs6000.c:22653
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "栈帧太大"
 
-#: config/rs6000/rs6000.c:26625
+#: config/rs6000/rs6000.c:26723
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支持取样 64 位代码"
 
-#: config/rs6000/rs6000.c:28703
+#: config/rs6000/rs6000.c:28801
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:28785
+#: config/rs6000/rs6000.c:28883
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<long double%>无效"
 
-#: config/rs6000/rs6000.c:28787
+#: config/rs6000/rs6000.c:28885
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用布尔类型无效"
 
-#: config/rs6000/rs6000.c:28789
+#: config/rs6000/rs6000.c:28887
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<complex%>无效"
 
-#: config/rs6000/rs6000.c:28791
+#: config/rs6000/rs6000.c:28889
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用十进制浮点类型无效"
 
-#: config/rs6000/rs6000.c:28797
+#: config/rs6000/rs6000.c:28895
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long%>对 64 位代码无效"
 
-#: config/rs6000/rs6000.c:28800
+#: config/rs6000/rs6000.c:28898
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "不建议在 AltiVec 类型中使用%<long%>；请改用%<int%>"
 
-#: config/rs6000/rs6000.c:28805
+#: config/rs6000/rs6000.c:28903
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long long%>无效"
 
-#: config/rs6000/rs6000.c:28808
+#: config/rs6000/rs6000.c:28906
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<double%>无效"
 
-#: config/rs6000/rs6000.c:32141
+#: config/rs6000/rs6000.c:32239
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "生成微代码指令 %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:32145
+#: config/rs6000/rs6000.c:32243
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "生成条件微代码指令 %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:32391
+#: config/rs6000/rs6000.c:32533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/rs6000/rs6000.c:32394
+#: config/rs6000/rs6000.c:32536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "在这里不允许使用%<#pragma%>"
 
-#: config/rs6000/rs6000.c:32396
+#: config/rs6000/rs6000.c:32538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "spec‘%s’是无效的"
@@ -27839,88 +27874,88 @@
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/s390/s390.c:7790
+#: config/s390/s390.c:7794
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局部变量大小总和超过架构极限。"
 
-#: config/s390/s390.c:8790
+#: config/s390/s390.c:8794
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:8805
+#: config/s390/s390.c:8809
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:8833
+#: config/s390/s390.c:8837
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "%qs的框架大小是"
 
-#: config/s390/s390.c:8837
+#: config/s390/s390.c:8841
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs使用动态栈分配"
 
-#: config/s390/s390.c:10102
+#: config/s390/s390.c:10106
 #, gcc-internal-format
 msgid "Transactional execution builtins not enabled (-mhtm)\n"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:11935
+#: config/s390/s390.c:11945
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "“%s”的实参应该是一个非负整数"
 
-#: config/s390/s390.c:11942
+#: config/s390/s390.c:11952
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qE属性的实参大于 %d"
 
-#: config/s390/s390.c:11985
+#: config/s390/s390.c:11995
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/Architecture 模式在 %s 上不受支持"
 
-#: config/s390/s390.c:11987
+#: config/s390/s390.c:11997
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/s390/s390.c:12004
+#: config/s390/s390.c:12014
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "硬件十进制浮点指令在 %s 上不可用"
 
-#: config/s390/s390.c:12007
+#: config/s390/s390.c:12017
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "硬件十进制浮点指令在 ESA/390 模式下不可用"
 
-#: config/s390/s390.c:12017
+#: config/s390/s390.c:12027
 #, fuzzy, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp 不能与 -msoft-float 同时使用"
 
-#: config/s390/s390.c:12045
+#: config/s390/s390.c:12055
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float 一起使用不受支持"
 
-#: config/s390/s390.c:12051
+#: config/s390/s390.c:12061
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "栈大小必须大于栈防护值"
 
-#: config/s390/s390.c:12053
+#: config/s390/s390.c:12063
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "栈大小不能大于 64K"
 
-#: config/s390/s390.c:12056
+#: config/s390/s390.c:12066
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard 意味着使用 -mstack-size"
@@ -27935,53 +27970,53 @@
 msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgstr "解卷表目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/sh/sh.c:8417
+#: config/sh/sh.c:8418
 #, gcc-internal-format
 msgid "__builtin_saveregs not supported by this subtarget"
 msgstr "__builtin_saveregs 在此子目标上不受支持"
 
-#: config/sh/sh.c:9620
+#: config/sh/sh.c:9621
 #, gcc-internal-format
 msgid "%qE attribute only applies to interrupt functions"
 msgstr "%qE属性只能用于中断函数"
 
-#: config/sh/sh.c:9690
+#: config/sh/sh.c:9691
 #, gcc-internal-format
 msgid "%qE attribute is supported only for SH2A"
 msgstr "%qE属性只为 SH2A 所支持"
 
-#: config/sh/sh.c:9720
+#: config/sh/sh.c:9721
 #, gcc-internal-format
 msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgstr "属性 interrupt_handler 与 -m5-compact 不兼容"
 
-#: config/sh/sh.c:9737
+#: config/sh/sh.c:9738
 #, gcc-internal-format
 msgid "%qE attribute only applies to SH2A"
 msgstr "%qE属性只能用于 SH2A"
 
-#: config/sh/sh.c:9759
+#: config/sh/sh.c:9760
 #, gcc-internal-format
 msgid "%qE attribute argument should be between 0 to 255"
 msgstr "%qE属性的参数应当在 0 和 255 之间"
 
 #. The argument must be a constant string.
-#: config/sh/sh.c:9832
+#: config/sh/sh.c:9833
 #, gcc-internal-format
 msgid "%qE attribute argument not a string constant"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/sh/sh.c:12595
+#: config/sh/sh.c:12596
 #, gcc-internal-format
 msgid "r0 needs to be available as a call-clobbered register"
 msgstr "r0 需要用作调用篡改的寄存器"
 
-#: config/sh/sh.c:12616
+#: config/sh/sh.c:12617
 #, fuzzy, gcc-internal-format
 msgid "need a second call-clobbered general purpose register"
 msgstr "需要另一个调用篡改的通用寄存器"
 
-#: config/sh/sh.c:12624
+#: config/sh/sh.c:12625
 #, fuzzy, gcc-internal-format
 msgid "need a call-clobbered target register"
 msgstr "需要一个调用篡改的通用寄存器"
@@ -28360,44 +28395,44 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3631
+#: ada/gcc-interface/utils.c:3634
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "属性%qs的元素类型无效"
 
-#: ada/gcc-interface/utils.c:3655
+#: ada/gcc-interface/utils.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "向量中分量数不是 2 的某次方"
 
-#: ada/gcc-interface/utils.c:5620 ada/gcc-interface/utils.c:5794
-#: ada/gcc-interface/utils.c:5856
+#: ada/gcc-interface/utils.c:5623 ada/gcc-interface/utils.c:5797
+#: ada/gcc-interface/utils.c:5859
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "忽略%qs属性"
 
-#: ada/gcc-interface/utils.c:5737
+#: ada/gcc-interface/utils.c:5740
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "%qs属性需要带有名参数的原型"
 
-#: ada/gcc-interface/utils.c:5746
+#: ada/gcc-interface/utils.c:5749
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "%qs属性只能用于带可变参数函数"
 
-#: ada/gcc-interface/utils.c:5816
+#: ada/gcc-interface/utils.c:5819
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "不建议使用。此开关不起作用。"
 
-#: ada/gcc-interface/utils.c:5940
+#: ada/gcc-interface/utils.c:5943
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "%qs属性只能为数组类型使用"
 
-#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7569
+#: c/c-array-notation.c:229 c/c-array-notation.c:258 cp/call.c:7581
 #: cp/cp-array-notation.c:264
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
@@ -28456,7 +28491,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:110 c/c-typeck.c:2144 c/c-typeck.c:5879 c/c-typeck.c:11329
-#: cp/typeck.c:1952 cp/typeck.c:7383 cp/typeck.c:8094
+#: cp/typeck.c:1952 cp/typeck.c:7374 cp/typeck.c:8085
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void 值未如预期地被忽略"
@@ -28486,62 +28521,62 @@
 msgid "GCC supports only %u nested scopes"
 msgstr "GCC 只支持 %u 个嵌套的作用域"
 
-#: c/c-decl.c:1224 cp/decl.c:391
+#: c/c-decl.c:1225 cp/decl.c:391
 #, gcc-internal-format
 msgid "label %q+D used but not defined"
 msgstr "标号%q+D使用前未定义"
 
-#: c/c-decl.c:1269
+#: c/c-decl.c:1270
 #, gcc-internal-format
 msgid "nested function %q+D declared but never defined"
 msgstr "嵌套函数%q+D声明过但从未定义"
 
-#: c/c-decl.c:1283
+#: c/c-decl.c:1284
 #, gcc-internal-format
 msgid "inline function %q+D declared but never defined"
 msgstr "内联函数%q+D声明过但从未定义"
 
-#: c/c-decl.c:1300 cp/decl.c:658
+#: c/c-decl.c:1301 cp/decl.c:658
 #, gcc-internal-format
 msgid "unused variable %q+D"
 msgstr "未使用的变量%q+D"
 
-#: c/c-decl.c:1304
+#: c/c-decl.c:1305
 #, gcc-internal-format
 msgid "variable %qD set but not used"
 msgstr "变量%qD被设定但未被使用"
 
-#: c/c-decl.c:1309
+#: c/c-decl.c:1310
 #, gcc-internal-format
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "数组%q+D类型与隐式初始化不兼容"
 
-#: c/c-decl.c:1588 c/c-decl.c:6358 c/c-decl.c:7220 c/c-decl.c:7929
+#: c/c-decl.c:1589 c/c-decl.c:6359 c/c-decl.c:7221 c/c-decl.c:7930
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "原先在这里定义"
 
-#: c/c-decl.c:1706
+#: c/c-decl.c:1707
 #, gcc-internal-format
 msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgstr "带有省略号的形参列表无法与空形参名列表声明匹配"
 
-#: c/c-decl.c:1713
+#: c/c-decl.c:1714
 #, gcc-internal-format
 msgid "an argument type that has a default promotion can%'t match an empty parameter name list declaration"
 msgstr "具有默认提升的实参类型不能匹配空参数名列表声明"
 
-#: c/c-decl.c:1760
+#: c/c-decl.c:1761
 #, gcc-internal-format
 msgid "prototype for %q+D declares more arguments than previous old-style definition"
 msgstr "%q+D的原型声明的参数多于先前旧式的定义"
 
-#: c/c-decl.c:1766
+#: c/c-decl.c:1767
 #, gcc-internal-format
 msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
 msgstr "%q+D的原型声明的参数少于先前旧式的定义"
 
-#: c/c-decl.c:1775
+#: c/c-decl.c:1776
 #, gcc-internal-format
 msgid "prototype for %q+D declares argument %d with incompatible type"
 msgstr "%q+D的原型对实参 %d 声明类型不兼容"
@@ -28548,42 +28583,42 @@
 
 #. If we get here, no errors were found, but do issue a warning
 #. for this poor-style construct.
-#: c/c-decl.c:1788
+#: c/c-decl.c:1789
 #, gcc-internal-format
 msgid "prototype for %q+D follows non-prototype definition"
 msgstr "%q+D的原型出现在非原型定义之后"
 
-#: c/c-decl.c:1804
+#: c/c-decl.c:1805
 #, gcc-internal-format
 msgid "previous definition of %q+D was here"
 msgstr "%q+D的上一个定义在此"
 
-#: c/c-decl.c:1806
+#: c/c-decl.c:1807
 #, gcc-internal-format
 msgid "previous implicit declaration of %q+D was here"
 msgstr "%q+D的上一个隐式声明在此"
 
-#: c/c-decl.c:1808
+#: c/c-decl.c:1809
 #, gcc-internal-format
 msgid "previous declaration of %q+D was here"
 msgstr "%q+D的上一个声明在此"
 
-#: c/c-decl.c:1848
+#: c/c-decl.c:1849
 #, gcc-internal-format
 msgid "%q+D redeclared as different kind of symbol"
 msgstr "%q+D被重新声明为不同意义的符号"
 
-#: c/c-decl.c:1852
+#: c/c-decl.c:1853
 #, gcc-internal-format
 msgid "built-in function %q+D declared as non-function"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: c/c-decl.c:1855 c/c-decl.c:2025 c/c-decl.c:2801
+#: c/c-decl.c:1856 c/c-decl.c:2026 c/c-decl.c:2802
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a built-in function"
 msgstr "%q+D的声明隐藏了一个内建函数"
 
-#: c/c-decl.c:1864
+#: c/c-decl.c:1865
 #, gcc-internal-format
 msgid "redeclaration of enumerator %q+D"
 msgstr "枚举%q+D重声明"
@@ -28591,341 +28626,341 @@
 #. If types don't match for a built-in, throw away the
 #. built-in.  No point in calling locate_old_decl here, it
 #. won't print anything.
-#: c/c-decl.c:1885
+#: c/c-decl.c:1886
 #, gcc-internal-format
 msgid "conflicting types for built-in function %q+D"
 msgstr "与内建函数%q+D类型冲突"
 
-#: c/c-decl.c:1910 c/c-decl.c:1923 c/c-decl.c:1959
+#: c/c-decl.c:1911 c/c-decl.c:1924 c/c-decl.c:1960
 #, gcc-internal-format
 msgid "conflicting types for %q+D"
 msgstr "与%q+D类型冲突"
 
-#: c/c-decl.c:1939
+#: c/c-decl.c:1940
 #, gcc-internal-format
 msgid "conflicting named address spaces (generic vs %s) for %q+D"
 msgstr "为%2$q+D指定了冲突的有名寻址空间(泛型和 %1$s)"
 
-#: c/c-decl.c:1943
+#: c/c-decl.c:1944
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs generic) for %q+D"
 msgstr "为%2$q+D指定了冲突的有名寻址空间(%1$s 和泛型)"
 
-#: c/c-decl.c:1947
+#: c/c-decl.c:1948
 #, gcc-internal-format
 msgid "conflicting named address spaces (%s vs %s) for %q+D"
 msgstr "为%3$q+D指定了冲突的有名寻址空间(%1$s和 %2$s)"
 
-#: c/c-decl.c:1956
+#: c/c-decl.c:1957
 #, gcc-internal-format
 msgid "conflicting type qualifiers for %q+D"
 msgstr "%q+D的类型限定冲突"
 
-#: c/c-decl.c:1981
+#: c/c-decl.c:1982
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D with different type"
 msgstr "typedef%q+D重定义时具有不同类型"
 
-#: c/c-decl.c:1994
+#: c/c-decl.c:1995
 #, fuzzy, gcc-internal-format
 msgid "redefinition of typedef %q+D with variably modified type"
 msgstr "非嵌套函数有动态可变类型"
 
-#: c/c-decl.c:1999
+#: c/c-decl.c:2000
 #, gcc-internal-format
 msgid "redefinition of typedef %q+D"
 msgstr "typedef%q+D重定义"
 
-#: c/c-decl.c:2051 c/c-decl.c:2154
+#: c/c-decl.c:2052 c/c-decl.c:2155
 #, gcc-internal-format
 msgid "redefinition of %q+D"
 msgstr "%q+D重定义"
 
-#: c/c-decl.c:2086 c/c-decl.c:2192
+#: c/c-decl.c:2087 c/c-decl.c:2193
 #, gcc-internal-format
 msgid "static declaration of %q+D follows non-static declaration"
 msgstr "对%qD的静态声明出现在非静态声明之后"
 
-#: c/c-decl.c:2096 c/c-decl.c:2104 c/c-decl.c:2182 c/c-decl.c:2189
+#: c/c-decl.c:2097 c/c-decl.c:2105 c/c-decl.c:2183 c/c-decl.c:2190
 #, gcc-internal-format
 msgid "non-static declaration of %q+D follows static declaration"
 msgstr "对%q+D的静态声明出现在非静态声明之后"
 
-#: c/c-decl.c:2120
+#: c/c-decl.c:2121
 #, gcc-internal-format
 msgid "%<gnu_inline%> attribute present on %q+D"
 msgstr "%q+D上有%<gnu_inline%>属性"
 
-#: c/c-decl.c:2123
+#: c/c-decl.c:2124
 #, gcc-internal-format
 msgid "but not here"
 msgstr "但不是这里"
 
-#: c/c-decl.c:2141
+#: c/c-decl.c:2142
 #, gcc-internal-format
 msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgstr "%q+D的线程局部声明跟在其非线程局部声明之后"
 
-#: c/c-decl.c:2144
+#: c/c-decl.c:2145
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgstr "%q+D的线程局部声明跟在其非线程局部声明之后"
 
-#: c/c-decl.c:2174
+#: c/c-decl.c:2175
 #, gcc-internal-format
 msgid "extern declaration of %q+D follows declaration with no linkage"
 msgstr "%q+D声明为没有外部链接的，之前却有外部声明"
 
-#: c/c-decl.c:2210
+#: c/c-decl.c:2211
 #, gcc-internal-format
 msgid "declaration of %q+D with no linkage follows extern declaration"
 msgstr "%q+D声明为没有外部链接的，之前却有外部声明"
 
-#: c/c-decl.c:2216
+#: c/c-decl.c:2217
 #, gcc-internal-format
 msgid "redeclaration of %q+D with no linkage"
 msgstr "%q+D重声明为没有外部链接"
 
-#: c/c-decl.c:2242
+#: c/c-decl.c:2243
 #, gcc-internal-format
 msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
 msgstr "对%q+D的再次声明中指定了不同的可见性 (保留原有的可见性)"
 
-#: c/c-decl.c:2252
+#: c/c-decl.c:2253
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgstr "%q+D带有 noinline 属性的声明出现在其内联声明之后"
 
-#: c/c-decl.c:2257
+#: c/c-decl.c:2258
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgstr "%q+D带有 noinline 属性的声明出现在其内联声明之后"
 
-#: c/c-decl.c:2262 c/c-decl.c:2268 c/c-decl.c:2274 c/c-decl.c:2280
+#: c/c-decl.c:2263 c/c-decl.c:2269 c/c-decl.c:2275 c/c-decl.c:2281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows declaration with attribute %qs"
 msgstr "%q+D带有 noinline 属性的声明出现在其内联声明之后"
 
-#: c/c-decl.c:2298
+#: c/c-decl.c:2299
 #, gcc-internal-format
 msgid "redefinition of parameter %q+D"
 msgstr "形参%q+D重定义"
 
-#: c/c-decl.c:2325
+#: c/c-decl.c:2326
 #, gcc-internal-format
 msgid "redundant redeclaration of %q+D"
 msgstr "对%q+D冗余的重声明"
 
-#: c/c-decl.c:2776
+#: c/c-decl.c:2777
 #, gcc-internal-format
 msgid "declaration of %q+D shadows previous non-variable"
 msgstr "%q+D的声明隐藏了先前的一个非变量声明"
 
-#: c/c-decl.c:2782
+#: c/c-decl.c:2783
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: c/c-decl.c:2794 cp/name-lookup.c:1284
+#: c/c-decl.c:2795 cp/name-lookup.c:1284
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD的声明隐藏了一个全局声明"
 
-#: c/c-decl.c:2806
+#: c/c-decl.c:2807
 #, gcc-internal-format
 msgid "declaration of %q+D shadows a previous local"
 msgstr "%q+D的声明隐藏了先前的一个局部变量"
 
-#: c/c-decl.c:2811 cp/name-lookup.c:1227 cp/name-lookup.c:1269
+#: c/c-decl.c:2812 cp/name-lookup.c:1227 cp/name-lookup.c:1269
 #: cp/name-lookup.c:1287
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "被隐藏的声明在这里"
 
-#: c/c-decl.c:2938
+#: c/c-decl.c:2939
 #, gcc-internal-format
 msgid "nested extern declaration of %qD"
 msgstr "对%qD的嵌套的外部声明"
 
-#: c/c-decl.c:3114 c/c-decl.c:3117
+#: c/c-decl.c:3115 c/c-decl.c:3118
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "隐式声明函数%qE"
 
-#: c/c-decl.c:3363
+#: c/c-decl.c:3364
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "隐式声明与内建函数%qD不兼容"
 
-#: c/c-decl.c:3370
+#: c/c-decl.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "对%q+#D无效的重声明"
 
-#: c/c-decl.c:3379
+#: c/c-decl.c:3380
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "隐式声明与函数%qD不兼容"
 
-#: c/c-decl.c:3433
+#: c/c-decl.c:3434
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE未声明(不在函数内)"
 
-#: c/c-decl.c:3439
+#: c/c-decl.c:3440
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE未声明(在此函数内第一次使用)"
 
-#: c/c-decl.c:3442
+#: c/c-decl.c:3443
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "每个未声明的标识符在其出现的函数内只报告一次"
 
-#: c/c-decl.c:3490 cp/decl.c:2838
+#: c/c-decl.c:3491 cp/decl.c:2838
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "标号%qE在所有函数外被引用"
 
-#: c/c-decl.c:3526
+#: c/c-decl.c:3527
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "跳至具有可变类型的标识符的作用域中"
 
-#: c/c-decl.c:3529
+#: c/c-decl.c:3530
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "跳转略过了变量初始化"
 
-#: c/c-decl.c:3530 c/c-decl.c:3585 c/c-decl.c:3674
+#: c/c-decl.c:3531 c/c-decl.c:3586 c/c-decl.c:3675
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "标号%qD在此定义"
 
-#: c/c-decl.c:3531 c/c-decl.c:3802 c/c-typeck.c:7634 cp/class.c:1435
+#: c/c-decl.c:3532 c/c-decl.c:3803 c/c-typeck.c:7634 cp/class.c:1435
 #: cp/class.c:3260 cp/decl.c:3631 cp/parser.c:5464
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD在此声明"
 
-#: c/c-decl.c:3584 c/c-decl.c:3673
+#: c/c-decl.c:3585 c/c-decl.c:3674
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "跳转至语句表达式中"
 
-#: c/c-decl.c:3606
+#: c/c-decl.c:3607
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "重复的标号定义%qE"
 
-#: c/c-decl.c:3704 cp/decl.c:3182
+#: c/c-decl.c:3705 cp/decl.c:3182
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重复的标号%qD"
 
-#: c/c-decl.c:3735
+#: c/c-decl.c:3736
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "传统 C 不为标号提供一个单独的命名空间，标识符%qE冲突"
 
-#: c/c-decl.c:3800
+#: c/c-decl.c:3801
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "switch 跳过了变量初始化"
 
-#: c/c-decl.c:3801 c/c-decl.c:3812
+#: c/c-decl.c:3802 c/c-decl.c:3813
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "开关语句从此开始"
 
-#: c/c-decl.c:3811
+#: c/c-decl.c:3812
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "开关跳转至语句表达式中"
 
-#: c/c-decl.c:3882
+#: c/c-decl.c:3883
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE定义为类型错误的标记"
 
-#: c/c-decl.c:4111
+#: c/c-decl.c:4112
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "未定义任何实例的无名结构/联合"
 
-#: c/c-decl.c:4121
+#: c/c-decl.c:4122
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "带有存储类的空声明没有重声明标记"
 
-#: c/c-decl.c:4136
+#: c/c-decl.c:4137
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "带有类型限定的空声明没有重声明标记"
 
-#: c/c-decl.c:4147
+#: c/c-decl.c:4148
 #, fuzzy, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "带有类型限定的空声明没有重声明标记"
 
-#: c/c-decl.c:4169 c/c-decl.c:4177
+#: c/c-decl.c:4170 c/c-decl.c:4178
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "空声明中类型名无用"
 
-#: c/c-decl.c:4185
+#: c/c-decl.c:4186
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%>用于空声明中"
 
-#: c/c-decl.c:4191
+#: c/c-decl.c:4192
 #, fuzzy, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<inline%>用于空声明中"
 
-#: c/c-decl.c:4197
+#: c/c-decl.c:4198
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "文件作用域中出现%<auto%>空声明"
 
-#: c/c-decl.c:4203
+#: c/c-decl.c:4204
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "文件作用域中出现%<register%>空声明"
 
-#: c/c-decl.c:4210
+#: c/c-decl.c:4211
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "空声明中指定存储类无用"
 
-#: c/c-decl.c:4216
+#: c/c-decl.c:4217
 #, fuzzy, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "空声明中类型名无用"
 
-#: c/c-decl.c:4229
+#: c/c-decl.c:4230
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "空声明中类型限定无用"
 
-#: c/c-decl.c:4236
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "空声明中%<__thread%>无用"
 
-#: c/c-decl.c:4243 c/c-parser.c:1594
+#: c/c-decl.c:4244 c/c-parser.c:1594
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "空声明"
 
-#: c/c-decl.c:4314
+#: c/c-decl.c:4315
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 不支持在形参数组声明中使用%<static%>或类型限定符"
 
-#: c/c-decl.c:4318
+#: c/c-decl.c:4319
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 不支持%<[*]%>数组声明"
@@ -28933,38 +28968,38 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4324 c/c-decl.c:6788
+#: c/c-decl.c:4325 c/c-decl.c:6789
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%>不能用于函数原型以外"
 
-#: c/c-decl.c:4414 cp/decl2.c:1454
+#: c/c-decl.c:4415 cp/decl2.c:1458
 #, gcc-internal-format
 msgid "%q+D in block scope inside of declare target directive"
 msgstr ""
 
-#: c/c-decl.c:4418 cp/decl2.c:1459
+#: c/c-decl.c:4419 cp/decl2.c:1463
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:4467
+#: c/c-decl.c:4468
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D通常是一个函数"
 
-#: c/c-decl.c:4476
+#: c/c-decl.c:4477
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgstr "typedef%qD被初始化(改用 __typeof__)"
 
-#: c/c-decl.c:4481
+#: c/c-decl.c:4482
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "函数%qD像变量一样被初始化"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:4487
+#: c/c-decl.c:4488
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "形参%qD已初始化"
@@ -28973,257 +29008,257 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4506 c/c-decl.c:4521 c/c-typeck.c:6929
+#: c/c-decl.c:4507 c/c-decl.c:4522 c/c-typeck.c:6929
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "可变大小的对象不能被初始化"
 
-#: c/c-decl.c:4512
+#: c/c-decl.c:4513
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "变量%qD有初始值设定但类型不完全"
 
-#: c/c-decl.c:4601 cp/decl.c:4728 cp/decl.c:13370
+#: c/c-decl.c:4602 cp/decl.c:4732 cp/decl.c:13377
 #, gcc-internal-format
 msgid "inline function %q+D given attribute noinline"
 msgstr "为内联函数%q+D给定了 noinline 属性"
 
-#: c/c-decl.c:4652
+#: c/c-decl.c:4653
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "未初始化的常量%qD在C++中是无效的"
 
-#: c/c-decl.c:4654
+#: c/c-decl.c:4655
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD应当被赋值"
 
-#: c/c-decl.c:4732
+#: c/c-decl.c:4733
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "初始值设定无法决定%q+D的大小"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4738
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "在%q+D中缺少数组大小"
 
-#: c/c-decl.c:4749
+#: c/c-decl.c:4750
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "数组%q+D大小为 0 或负"
 
-#: c/c-decl.c:4815
+#: c/c-decl.c:4816
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "%q+D的存储大小不是常量"
 
-#: c/c-decl.c:4865
+#: c/c-decl.c:4866
 #, gcc-internal-format
 msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgstr "为非静态局部变量%q+D忽略了 asm 限定符"
 
-#: c/c-decl.c:4895
+#: c/c-decl.c:4896
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "不能将带有 volatile 字段的对象放入寄存器"
 
-#: c/c-decl.c:4982
+#: c/c-decl.c:4983
 #, gcc-internal-format
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "未初始化的常量%qD在C++中是无效的"
 
-#: c/c-decl.c:5040
+#: c/c-decl.c:5041
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C 不允许前向参数声明"
 
-#: c/c-decl.c:5137
+#: c/c-decl.c:5138
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "C++ 不允许在组合字面常量中定义类型"
 
-#: c/c-decl.c:5189 c/c-decl.c:5204
+#: c/c-decl.c:5190 c/c-decl.c:5205
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "位段%qs的宽度不是一个整数常量"
 
-#: c/c-decl.c:5199
+#: c/c-decl.c:5200
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "位段%qs的宽度不是一个整数常量表达式"
 
-#: c/c-decl.c:5210
+#: c/c-decl.c:5211
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "位段%qs宽度为负"
 
-#: c/c-decl.c:5215
+#: c/c-decl.c:5216
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "位段%qs宽度为 0"
 
-#: c/c-decl.c:5225
+#: c/c-decl.c:5226
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "位段%qs类型无效"
 
-#: c/c-decl.c:5235
+#: c/c-decl.c:5236
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "位段类型%qs是一个 GCC 扩展"
 
-#: c/c-decl.c:5241
+#: c/c-decl.c:5242
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "%qs的宽度超过它自身的类型"
 
-#: c/c-decl.c:5254
+#: c/c-decl.c:5255
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs比其类型的值要窄"
 
-#: c/c-decl.c:5269
+#: c/c-decl.c:5270
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 不允许数组%qE，因为不能计算其大小"
 
-#: c/c-decl.c:5272
+#: c/c-decl.c:5273
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 不允许任何不能确定大小的数组"
 
-#: c/c-decl.c:5279
+#: c/c-decl.c:5280
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 不允许变长数组%qE"
 
-#: c/c-decl.c:5281
+#: c/c-decl.c:5282
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 不允许变长数组"
 
-#: c/c-decl.c:5457 c/c-decl.c:5815 c/c-decl.c:5825
+#: c/c-decl.c:5458 c/c-decl.c:5816 c/c-decl.c:5826
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "文件域中的动态可变的%qE"
 
-#: c/c-decl.c:5459
+#: c/c-decl.c:5460
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "文件域中的动态可变字段"
 
-#: c/c-decl.c:5479
+#: c/c-decl.c:5480
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "在%qE的声明中，类型默认为%<int%>"
 
-#: c/c-decl.c:5483
+#: c/c-decl.c:5484
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "类型名中类型默认为%<int%>"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5516
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "重复的%<const%>"
 
-#: c/c-decl.c:5517
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "重复的%<restrict%>"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5520
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "重复的%<volatile%>"
 
-#: c/c-decl.c:5521
+#: c/c-decl.c:5522
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "重复的%<restrict%>"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5525
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "冲突的有名地址空间(%s和%s)"
 
-#: c/c-decl.c:5542 c/c-parser.c:2460
+#: c/c-decl.c:5543 c/c-parser.c:2460
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5556
+#: c/c-decl.c:5557
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "函数声明定义为%<auto%>"
 
-#: c/c-decl.c:5558
+#: c/c-decl.c:5559
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "函数声明定义为%<register%>"
 
-#: c/c-decl.c:5560
+#: c/c-decl.c:5561
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "函数声明定义为%<typedef%>"
 
-#: c/c-decl.c:5562
+#: c/c-decl.c:5563
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "函数声明定义为%<auto%>"
 
-#: c/c-decl.c:5580
+#: c/c-decl.c:5581
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "为结构字段%qE指定了存储类"
 
-#: c/c-decl.c:5583
+#: c/c-decl.c:5584
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "为结构字段指定了存储类"
 
-#: c/c-decl.c:5587
+#: c/c-decl.c:5588
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "为形参%qE指定了存储类"
 
-#: c/c-decl.c:5590
+#: c/c-decl.c:5591
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "为无名形参指定了存储类"
 
-#: c/c-decl.c:5593 cp/decl.c:9586
+#: c/c-decl.c:5594 cp/decl.c:9593
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "为类型名指定了存储类"
 
-#: c/c-decl.c:5610
+#: c/c-decl.c:5611
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE已初始化，却又被声明为%<extern%>"
 
-#: c/c-decl.c:5614
+#: c/c-decl.c:5615
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE既有%<extern%>又有初始值设定"
 
-#: c/c-decl.c:5619
+#: c/c-decl.c:5620
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "文件作用域声明%qE指定了%<auto%>"
 
-#: c/c-decl.c:5623
+#: c/c-decl.c:5624
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "文件作用域声明%qE指定了%<register%>"
 
-#: c/c-decl.c:5628
+#: c/c-decl.c:5629
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "嵌套函数%qE被声明为%<extern%>"
 
-#: c/c-decl.c:5631
+#: c/c-decl.c:5632
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "函数作用域的%qE隐式为 auto，却被声明为%<__thread%>"
@@ -29231,684 +29266,684 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5678 c/c-decl.c:6021
+#: c/c-decl.c:5679 c/c-decl.c:6022
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static 或类型限定符出现在非形参数组声明中"
 
-#: c/c-decl.c:5726
+#: c/c-decl.c:5727
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "%qE声明为 void 的数组"
 
-#: c/c-decl.c:5728
+#: c/c-decl.c:5729
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "类型名声明为 void 的数组"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5736
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "%qE声明为函数的数组"
 
-#: c/c-decl.c:5738
+#: c/c-decl.c:5739
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "类型名声明为函数的数组"
 
-#: c/c-decl.c:5746 c/c-decl.c:7709
+#: c/c-decl.c:5747 c/c-decl.c:7710
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "对包含可变数组成员的结构的无效使用"
 
-#: c/c-decl.c:5772
+#: c/c-decl.c:5773
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "数组%qE的大小的类型不是整数"
 
-#: c/c-decl.c:5776
+#: c/c-decl.c:5777
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "无名数组的大小的类型不是整数"
 
-#: c/c-decl.c:5786
+#: c/c-decl.c:5787
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C 不允许大小为 0 的数组%qE"
 
-#: c/c-decl.c:5789
+#: c/c-decl.c:5790
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C 不允许大小为 0 的数组"
 
-#: c/c-decl.c:5798
+#: c/c-decl.c:5799
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "数组%qE的大小为负"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5801
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "无名数组的大小为负"
 
-#: c/c-decl.c:5885 c/c-decl.c:6308
+#: c/c-decl.c:5886 c/c-decl.c:6309
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "数组%qE太大"
 
-#: c/c-decl.c:5888 c/c-decl.c:6310
+#: c/c-decl.c:5889 c/c-decl.c:6311
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "无名数组太大"
 
-#: c/c-decl.c:5924 c/c-decl.c:6519
+#: c/c-decl.c:5925 c/c-decl.c:6520
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 不允许可变数组成员"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:5946
+#: c/c-decl.c:5947
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%>不在声明中"
 
-#: c/c-decl.c:5959
+#: c/c-decl.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "数组元素的类型不完全"
 
-#: c/c-decl.c:6054
+#: c/c-decl.c:6055
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE声明为返回一个函数的函数"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6058
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "类型名声明为返回一个数组的函数"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6065
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE声明为返回一个数组的函数"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6068
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "类型名声明为返回一个数组的函数"
 
-#: c/c-decl.c:6095
+#: c/c-decl.c:6096
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "函数定义有限定的 void 返回类型"
 
-#: c/c-decl.c:6098 cp/decl.c:9713
+#: c/c-decl.c:6099 cp/decl.c:9720
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函数返回类型的类型限定"
 
-#: c/c-decl.c:6127 c/c-decl.c:6325 c/c-decl.c:6378 c/c-decl.c:6453
-#: c/c-decl.c:6568 c/c-parser.c:2462
+#: c/c-decl.c:6128 c/c-decl.c:6326 c/c-decl.c:6379 c/c-decl.c:6454
+#: c/c-decl.c:6569 c/c-parser.c:2462
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C 不允许使用 const 或 volatile 限定函数类型"
 
-#: c/c-decl.c:6133 c/c-decl.c:6331 c/c-decl.c:6458 c/c-decl.c:6573
+#: c/c-decl.c:6134 c/c-decl.c:6332 c/c-decl.c:6459 c/c-decl.c:6574
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C 不允许使用 const 或 volatile 限定函数类型"
 
-#: c/c-decl.c:6200
+#: c/c-decl.c:6201
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs和%<auto%>限定符同时用于%qE"
 
-#: c/c-decl.c:6204
+#: c/c-decl.c:6205
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs和%<register%>限定符同时用于%qE"
 
-#: c/c-decl.c:6210
+#: c/c-decl.c:6211
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "为 auto 变量%2$qE指定了%1$qs"
 
-#: c/c-decl.c:6226
+#: c/c-decl.c:6227
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "为形参%2$qE指定了%1$qs"
 
-#: c/c-decl.c:6229
+#: c/c-decl.c:6230
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "为无名形参指定了%qs"
 
-#: c/c-decl.c:6235
+#: c/c-decl.c:6236
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: c/c-decl.c:6238
+#: c/c-decl.c:6239
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "为结构字段指定了%qs"
 
-#: c/c-decl.c:6253
+#: c/c-decl.c:6254
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "位段%qs类型无效"
 
-#: c/c-decl.c:6255
+#: c/c-decl.c:6256
 #, fuzzy, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "位段%qs类型无效"
 
-#: c/c-decl.c:6264
+#: c/c-decl.c:6265
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "不能为%q+D指定对齐"
 
-#: c/c-decl.c:6266
+#: c/c-decl.c:6267
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "为形参%2$qE指定了%1$qs"
 
-#: c/c-decl.c:6271
+#: c/c-decl.c:6272
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "为形参%2$qE指定了%1$qs"
 
-#: c/c-decl.c:6273
+#: c/c-decl.c:6274
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "为无名形参指定了%qs"
 
-#: c/c-decl.c:6278
+#: c/c-decl.c:6279
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "不能为%q+D指定对齐"
 
-#: c/c-decl.c:6280
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "为无名形参指定了%qs"
 
-#: c/c-decl.c:6283
+#: c/c-decl.c:6284
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "向函数%qD赋值"
 
-#: c/c-decl.c:6290
+#: c/c-decl.c:6291
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6293
+#: c/c-decl.c:6294
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6339
+#: c/c-decl.c:6340
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef%q+D声明为%<inline%>"
 
-#: c/c-decl.c:6341
+#: c/c-decl.c:6342
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef%q+D声明为%<inline%>"
 
-#: c/c-decl.c:6384
+#: c/c-decl.c:6385
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C 不允许使用 const 或 volatile 限定函数类型"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6394
+#: c/c-decl.c:6395
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "结构或联合成员不能具有可变类型"
 
-#: c/c-decl.c:6411 cp/decl.c:8821
+#: c/c-decl.c:6412 cp/decl.c:8828
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "变量或字段%qE声明为 void"
 
-#: c/c-decl.c:6443
+#: c/c-decl.c:6444
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "出现在形参数组声明中的属性被忽略"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6486
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "形参%q+D声明为%<inline%>"
 
-#: c/c-decl.c:6487
+#: c/c-decl.c:6488
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "形参%q+D声明为%<inline%>"
 
-#: c/c-decl.c:6500
+#: c/c-decl.c:6501
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "字段%qE声明为一个函数"
 
-#: c/c-decl.c:6507
+#: c/c-decl.c:6508
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-decl.c:6509
+#: c/c-decl.c:6510
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "无名字段类型不完全"
 
-#: c/c-decl.c:6539 c/c-decl.c:6550 c/c-decl.c:6553
+#: c/c-decl.c:6540 c/c-decl.c:6551 c/c-decl.c:6554
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "函数%qE存储类无效"
 
-#: c/c-decl.c:6610
+#: c/c-decl.c:6611
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "不能内联%<main%>函数"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6613
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qE已初始化，却又被声明为%<extern%>"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6624
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 不支持%<_Static_assert%>"
 
-#: c/c-decl.c:6626
+#: c/c-decl.c:6627
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 不支持%<long long%>"
 
-#: c/c-decl.c:6654
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "先前被声明为%<static%>的变量重声明为%<extern%>"
 
-#: c/c-decl.c:6664
+#: c/c-decl.c:6665
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "变量%q+D声明为%<inline%>"
 
-#: c/c-decl.c:6666
+#: c/c-decl.c:6667
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "变量%q+D声明为%<inline%>"
 
-#: c/c-decl.c:6701
+#: c/c-decl.c:6702
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "非嵌套函数有动态可变类型"
 
-#: c/c-decl.c:6703
+#: c/c-decl.c:6704
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "可变类型对象不能有外部链接"
 
-#: c/c-decl.c:6794 c/c-decl.c:8352
+#: c/c-decl.c:6795 c/c-decl.c:8353
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "函数声明不是一个原型"
 
-#: c/c-decl.c:6803
+#: c/c-decl.c:6804
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "函数声明中出现形参名却未指定类型"
 
-#: c/c-decl.c:6841
+#: c/c-decl.c:6842
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "形参 %u (%q+D) 的类型不完全"
 
-#: c/c-decl.c:6845
+#: c/c-decl.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "形参 %u 的类型不完全"
 
-#: c/c-decl.c:6856
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "形参 %u (%q+D)类型为 void"
 
-#: c/c-decl.c:6860
+#: c/c-decl.c:6861
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "第 %u 个参数类型为 void"
 
-#: c/c-decl.c:6944
+#: c/c-decl.c:6945
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: c/c-decl.c:6948 c/c-decl.c:6983
+#: c/c-decl.c:6949 c/c-decl.c:6984
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%>必须是仅有的形参"
 
-#: c/c-decl.c:6977
+#: c/c-decl.c:6978
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "形参%q+D有一个前向声明"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7022
+#: c/c-decl.c:7023
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list"
 msgstr "%<%s %E%>在形参表内部声明"
 
 #. The %s will be one of 'struct', 'union', or 'enum'.
-#: c/c-decl.c:7026
+#: c/c-decl.c:7027
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list"
 msgstr "在形参列表中声明了匿名 %s"
 
-#: c/c-decl.c:7031
+#: c/c-decl.c:7032
 #, gcc-internal-format
 msgid "its scope is only this definition or declaration, which is probably not what you want"
 msgstr "它的作用域仅限于此定义或声明，这可能并不是您想要的"
 
-#: c/c-decl.c:7131
+#: c/c-decl.c:7132
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "枚举类型在此定义"
 
-#: c/c-decl.c:7137
+#: c/c-decl.c:7138
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "结构在此定义"
 
-#: c/c-decl.c:7143
+#: c/c-decl.c:7144
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "联合在此定义"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7217
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%>重定义"
 
-#: c/c-decl.c:7218
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%>重定义"
 
-#: c/c-decl.c:7227
+#: c/c-decl.c:7228
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "嵌套的%<union %E%>重定义"
 
-#: c/c-decl.c:7229
+#: c/c-decl.c:7230
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "嵌套的%<struct %E%>重定义"
 
-#: c/c-decl.c:7261 c/c-decl.c:7947
+#: c/c-decl.c:7262 c/c-decl.c:7948
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "C++ 不允许在%qs表达式中定义类型"
 
-#: c/c-decl.c:7330 cp/decl.c:4444
+#: c/c-decl.c:7331 cp/decl.c:4448
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "没有声明任何东西"
 
-#: c/c-decl.c:7335
+#: c/c-decl.c:7336
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 不支持无名结构/联合"
 
-#: c/c-decl.c:7338
+#: c/c-decl.c:7339
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 不支持无名结构/联合"
 
-#: c/c-decl.c:7429 c/c-decl.c:7448 c/c-decl.c:7511
+#: c/c-decl.c:7430 c/c-decl.c:7449 c/c-decl.c:7512
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "重复的成员%q+D"
 
-#: c/c-decl.c:7617
+#: c/c-decl.c:7618
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "联合包含无名成员"
 
-#: c/c-decl.c:7619
+#: c/c-decl.c:7620
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "联合体没有成员"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "结构不包含任何有名成员"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7627
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "结构体没有成员"
 
-#: c/c-decl.c:7689
+#: c/c-decl.c:7690
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "联合和可变数组成员"
 
-#: c/c-decl.c:7695
+#: c/c-decl.c:7696
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: c/c-decl.c:7701
+#: c/c-decl.c:7702
 #, gcc-internal-format
 msgid "flexible array member in otherwise empty struct"
 msgstr "可变数组是结构中的唯一成员"
 
-#: c/c-decl.c:7730 cp/class.c:6474
+#: c/c-decl.c:7731 cp/class.c:6493
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "数组%qE太大"
 
-#: c/c-decl.c:7826
+#: c/c-decl.c:7827
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "联合不能成为透明的"
 
-#: c/c-decl.c:7920
+#: c/c-decl.c:7921
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "嵌套的%<enum %E%>重定义"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:7927
+#: c/c-decl.c:7928
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%>重声明"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8004
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "枚举值超过了最大整数类型可表示的范围"
 
-#: c/c-decl.c:8020
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "指定的模式对枚举值来说太小"
 
-#: c/c-decl.c:8125 c/c-decl.c:8141
+#: c/c-decl.c:8126 c/c-decl.c:8142
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: c/c-decl.c:8136
+#: c/c-decl.c:8137
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: c/c-decl.c:8160
+#: c/c-decl.c:8161
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "枚举值溢出"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8169
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C 将枚举值限制在%<int%>范围内"
 
-#: c/c-decl.c:8253
+#: c/c-decl.c:8254
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "内联函数%qD给定了非内联属性"
 
-#: c/c-decl.c:8271
+#: c/c-decl.c:8272
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "返回不完全的类型"
 
-#: c/c-decl.c:8282
+#: c/c-decl.c:8283
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "返回类型默认为%<int%>"
 
-#: c/c-decl.c:8361
+#: c/c-decl.c:8362
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "%qD先前没有原型"
 
-#: c/c-decl.c:8370
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "使用%qD时先前既没有原型也没有定义"
 
-#: c/c-decl.c:8378
+#: c/c-decl.c:8379
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD先前没有声明"
 
-#: c/c-decl.c:8388
+#: c/c-decl.c:8389
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "使用%qD时先前既没有声明也没有定义"
 
-#: c/c-decl.c:8407
+#: c/c-decl.c:8408
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%qD的返回类型不是%<int%>"
 
-#: c/c-decl.c:8409
+#: c/c-decl.c:8410
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "ISO C 不允许使用 const 或 volatile 限定函数类型"
 
-#: c/c-decl.c:8416
+#: c/c-decl.c:8417
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD通常不是一个静态函数"
 
-#: c/c-decl.c:8453
+#: c/c-decl.c:8454
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "原型函数定义中使用了旧式参数声明"
 
-#: c/c-decl.c:8468
+#: c/c-decl.c:8469
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "传统 C 不接受 ISO C 风格的函数定义"
 
-#: c/c-decl.c:8484
+#: c/c-decl.c:8485
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "省略的形参名"
 
-#: c/c-decl.c:8521
+#: c/c-decl.c:8522
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "旧式的函数定义"
 
-#: c/c-decl.c:8530
+#: c/c-decl.c:8531
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "形参列表中缺少形参名"
 
-#: c/c-decl.c:8545
+#: c/c-decl.c:8546
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD没有声明为一个参数"
 
-#: c/c-decl.c:8551
+#: c/c-decl.c:8552
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "多个名为%qD的形参"
 
-#: c/c-decl.c:8560
+#: c/c-decl.c:8561
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "形参%qD被声明为有 void 类型"
 
-#: c/c-decl.c:8589 c/c-decl.c:8594
+#: c/c-decl.c:8590 c/c-decl.c:8595
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%qD的类型默认为%<int%>"
 
-#: c/c-decl.c:8614
+#: c/c-decl.c:8615
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "形参%qD类型不完全"
 
-#: c/c-decl.c:8621
+#: c/c-decl.c:8622
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "声明的形参%qD不存在"
 
-#: c/c-decl.c:8671
+#: c/c-decl.c:8672
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "实参个数与内建原型不符"
 
-#: c/c-decl.c:8682
+#: c/c-decl.c:8683
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "实参数目与原型不符"
 
-#: c/c-decl.c:8685 c/c-decl.c:8732 c/c-decl.c:8746
+#: c/c-decl.c:8686 c/c-decl.c:8733 c/c-decl.c:8747
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "原型声明"
 
-#: c/c-decl.c:8724
+#: c/c-decl.c:8725
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "提升后的实参%qD与内建原型不符"
 
-#: c/c-decl.c:8729
+#: c/c-decl.c:8730
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "提升后的实参%qD与原型不符"
 
-#: c/c-decl.c:8739
+#: c/c-decl.c:8740
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "实参%qD与内建原型不符"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8745
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "实参%qD与原型不符"
 
-#: c/c-decl.c:8971 cp/decl.c:14277
+#: c/c-decl.c:8972 cp/decl.c:14284
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有返回值的函数中未发现 return 语句"
 
-#: c/c-decl.c:8991
+#: c/c-decl.c:8992
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "形参%qD被设定但未被使用"
@@ -29916,200 +29951,200 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9080
+#: c/c-decl.c:9081
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "只允许在 C99 模式下使用%<for%>循环初始化声明"
 
-#: c/c-decl.c:9085
+#: c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "使用 -std=c99 或 -std=gnu99 来编译您的代码"
 
-#: c/c-decl.c:9120
+#: c/c-decl.c:9121
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了静态变量%qD"
 
-#: c/c-decl.c:9124
+#: c/c-decl.c:9125
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了%<extern%>变量%qD"
 
-#: c/c-decl.c:9131
+#: c/c-decl.c:9132
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.c:9136
+#: c/c-decl.c:9137
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.c:9140
+#: c/c-decl.c:9141
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.c:9144
+#: c/c-decl.c:9145
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了非变量%qD"
 
-#: c/c-decl.c:9418
+#: c/c-decl.c:9419
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "不兼容的地址空间限定符%qs和%qs"
 
-#: c/c-decl.c:9468 c/c-decl.c:9825 c/c-decl.c:10315
+#: c/c-decl.c:9469 c/c-decl.c:9826 c/c-decl.c:10316
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "重复的%qE"
 
-#: c/c-decl.c:9494 c/c-decl.c:9837 c/c-decl.c:10158
+#: c/c-decl.c:9495 c/c-decl.c:9838 c/c-decl.c:10159
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "声明指定了两个以上的数据类型"
 
-#: c/c-decl.c:9506 cp/parser.c:24675
+#: c/c-decl.c:9507 cp/parser.c:24713
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%>对 GCC 来说太长了"
 
-#: c/c-decl.c:9519
+#: c/c-decl.c:9520
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 不支持%<long long%>"
 
-#: c/c-decl.c:9716 c/c-parser.c:7557
+#: c/c-decl.c:9717 c/c-parser.c:7557
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 不支持复数类型"
 
-#: c/c-decl.c:9762
+#: c/c-decl.c:9763
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C 不支持饱和类型"
 
-#: c/c-decl.c:9880
+#: c/c-decl.c:9881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int128%> type"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C90 不支持%<__int128%>类型"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9901
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported for this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int128%>在此目标机上不受支持"
 
-#: c/c-decl.c:9942
+#: c/c-decl.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 不支持复数类型"
 
-#: c/c-decl.c:10116
+#: c/c-decl.c:10117
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C 不支持十进制浮点数"
 
-#: c/c-decl.c:10139 c/c-decl.c:10405 c/c-parser.c:7092
+#: c/c-decl.c:10140 c/c-decl.c:10406 c/c-parser.c:7092
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "定点类型在此目标机上不受支持"
 
-#: c/c-decl.c:10141
+#: c/c-decl.c:10142
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C 不支持定点类型"
 
-#: c/c-decl.c:10176
+#: c/c-decl.c:10177
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "%qD的 C++ 查询会返回一个字段而非类型"
 
-#: c/c-decl.c:10189
+#: c/c-decl.c:10190
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: c/c-decl.c:10237
+#: c/c-decl.c:10238
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE没有出现在声明的开头"
 
-#: c/c-decl.c:10258
+#: c/c-decl.c:10259
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%>与%<auto%>一起使用"
 
-#: c/c-decl.c:10260
+#: c/c-decl.c:10261
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%>与%<register%>一起使用"
 
-#: c/c-decl.c:10262
+#: c/c-decl.c:10263
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%>与%<typedef%>一起使用"
 
-#: c/c-decl.c:10276 c/c-parser.c:6681
+#: c/c-decl.c:10277 c/c-parser.c:6681
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "%s 不支持 %s"
 
-#: c/c-decl.c:10279 c/c-parser.c:6684
+#: c/c-decl.c:10280 c/c-parser.c:6684
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 不支持%<long long%>"
 
-#: c/c-decl.c:10291
+#: c/c-decl.c:10292
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%>出现在%<extern%>之前"
 
-#: c/c-decl.c:10300
+#: c/c-decl.c:10301
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%>出现在%<static%>之前"
 
-#: c/c-decl.c:10313
+#: c/c-decl.c:10314
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10321
+#: c/c-decl.c:10322
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "声明指定了多个存储类"
 
-#: c/c-decl.c:10329
+#: c/c-decl.c:10330
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs必须与%qs一起使用"
 
-#: c/c-decl.c:10402
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%>使用时缺少%<_Fract%>或%<_Accum%>"
 
-#: c/c-decl.c:10417
+#: c/c-decl.c:10418
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支持单独用%<complex%>表示%<double complex%>"
 
-#: c/c-decl.c:10468 c/c-decl.c:10481 c/c-decl.c:10507
+#: c/c-decl.c:10469 c/c-decl.c:10482 c/c-decl.c:10508
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支持复整数"
 
-#: c/c-decl.c:10925 cp/semantics.c:4930
+#: c/c-decl.c:10926 cp/semantics.c:4936
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:10929 cp/semantics.c:4934
+#: c/c-decl.c:10930 cp/semantics.c:4940
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -30119,7 +30154,7 @@
 msgid "identifier %qE conflicts with C++ keyword"
 msgstr "标识符%qE与 C++ 关键字冲突"
 
-#: c/c-parser.c:1000 cp/parser.c:24882
+#: c/c-parser.c:1000 cp/parser.c:24920
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "需要行尾"
@@ -30139,8 +30174,8 @@
 msgid "unknown type name %qE"
 msgstr "未知的类型名%qE"
 
-#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13884 cp/parser.c:31426
-#: cp/parser.c:33139
+#: c/c-parser.c:1579 c/c-parser.c:9770 c/c-parser.c:13881 cp/parser.c:31461
+#: cp/parser.c:33174
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定声明"
@@ -30155,7 +30190,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.c:1625 cp/parser.c:26480 cp/parser.c:26554
+#: c/c-parser.c:1625 cp/parser.c:26518 cp/parser.c:26592
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "此目标机不支持节属性"
@@ -30232,7 +30267,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 不支持%<_Static_assert%>"
 
-#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32869
+#: c/c-parser.c:2085 c/c-parser.c:3733 c/c-parser.c:9825 cp/parser.c:32904
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "需要字面字符串"
@@ -30289,14 +30324,14 @@
 #: c/c-parser.c:8456 c/c-parser.c:8464 c/c-parser.c:8493 c/c-parser.c:8506
 #: c/c-parser.c:8811 c/c-parser.c:8935 c/c-parser.c:9375 c/c-parser.c:9410
 #: c/c-parser.c:9463 c/c-parser.c:9516 c/c-parser.c:9532 c/c-parser.c:9578
-#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14883 c/c-parser.c:15211
-#: cp/parser.c:24885 cp/parser.c:27323 cp/parser.c:27353 cp/parser.c:27423
-#: cp/parser.c:32590 cp/parser.c:33284
+#: c/c-parser.c:10109 c/c-parser.c:12764 c/c-parser.c:14880 c/c-parser.c:15208
+#: cp/parser.c:24923 cp/parser.c:27361 cp/parser.c:27391 cp/parser.c:27461
+#: cp/parser.c:32625 cp/parser.c:33319
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要标识符"
 
-#: c/c-parser.c:2601 cp/parser.c:16064
+#: c/c-parser.c:2601 cp/parser.c:16088
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "枚举表以逗号结尾"
@@ -30748,32 +30783,32 @@
 msgid "no type or storage class may be specified here,"
 msgstr "为%qs指定了存储类"
 
-#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27383
+#: c/c-parser.c:9379 c/c-parser.c:9436 cp/parser.c:27421
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: c/c-parser.c:9400 cp/parser.c:27343
+#: c/c-parser.c:9400 cp/parser.c:27381
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%qs后断言"
 
-#: c/c-parser.c:9403 cp/parser.c:27346
+#: c/c-parser.c:9403 cp/parser.c:27384
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%qs后断言"
 
-#: c/c-parser.c:9417 cp/parser.c:27361
+#: c/c-parser.c:9417 cp/parser.c:27399
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "不能为函数指定地址区域属性"
 
-#: c/c-parser.c:9422 cp/parser.c:27367
+#: c/c-parser.c:9422 cp/parser.c:27405
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 的名字必须以%<:%>结尾"
 
-#: c/c-parser.c:9429 cp/parser.c:27375
+#: c/c-parser.c:9429 cp/parser.c:27413
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "不能为函数指定地址区域属性"
@@ -30783,47 +30818,47 @@
 msgid "%<#pragma acc update%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:9634 cp/parser.c:32945
+#: c/c-parser.c:9634 cp/parser.c:32980
 #, gcc-internal-format
 msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: c/c-parser.c:9645 cp/parser.c:32960
+#: c/c-parser.c:9645 cp/parser.c:32995
 #, gcc-internal-format
 msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%>只能用在复合语句中"
 
-#: c/c-parser.c:9656 cp/parser.c:32976
+#: c/c-parser.c:9656 cp/parser.c:33011
 #, gcc-internal-format
 msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:9667 cp/parser.c:32992
+#: c/c-parser.c:9667 cp/parser.c:33027
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:9678 cp/parser.c:33008
+#: c/c-parser.c:9678 cp/parser.c:33043
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: c/c-parser.c:9689 cp/parser.c:33024
+#: c/c-parser.c:9689 cp/parser.c:33059
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:9709 cp/parser.c:33076
+#: c/c-parser.c:9709 cp/parser.c:33111
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
 
-#: c/c-parser.c:9724 cp/parser.c:33095
+#: c/c-parser.c:9724 cp/parser.c:33130
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "需要 for 语句"
 
-#: c/c-parser.c:9736 cp/parser.c:32935
+#: c/c-parser.c:9736 cp/parser.c:32970
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%>必须是第一个"
@@ -30838,12 +30873,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:10035 cp/parser.c:27731
+#: c/c-parser.c:10035 cp/parser.c:27769
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:10056 cp/parser.c:28073
+#: c/c-parser.c:10056 cp/parser.c:28111
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -30854,29 +30889,29 @@
 msgid "expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27831 cp/parser.c:27839
+#: c/c-parser.c:10184 c/c-parser.c:10192 cp/parser.c:27869 cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not const"
 msgid "%qD is not a constant"
 msgstr "%q#D不是 const"
 
-#: c/c-parser.c:10338 c/c-parser.c:14744 cp/parser.c:28002
+#: c/c-parser.c:10338 c/c-parser.c:14741 cp/parser.c:28040
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.c:10342 cp/parser.c:28006
+#: c/c-parser.c:10342 cp/parser.c:28044
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.c:10382 cp/parser.c:28151
+#: c/c-parser.c:10382 cp/parser.c:28189
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.c:10448 cp/parser.c:28202
+#: c/c-parser.c:10448 cp/parser.c:28240
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "需要%<none%>或%<shared%>"
@@ -30909,17 +30944,17 @@
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgstr "需要%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%>或%<||%>"
 
-#: c/c-parser.c:10946 cp/parser.c:28604
+#: c/c-parser.c:10946 cp/parser.c:28642
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<runtime%>不接受一个%<chunk_size%>参数"
 
-#: c/c-parser.c:10950 cp/parser.c:28607
+#: c/c-parser.c:10950 cp/parser.c:28645
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<auto%>不接受一个%<chunk_size%>参数"
 
-#: c/c-parser.c:10968 cp/parser.c:28623
+#: c/c-parser.c:10968 cp/parser.c:28661
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "无效的调度类型"
@@ -30939,12 +30974,12 @@
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:11192 cp/semantics.c:5725
+#: c/c-parser.c:11192 cp/semantics.c:5731
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.c:11229 cp/parser.c:28795
+#: c/c-parser.c:11229 cp/parser.c:28833
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -30964,17 +30999,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.c:11369 cp/parser.c:28916 cp/parser.c:29099
+#: c/c-parser.c:11369 cp/parser.c:28954 cp/parser.c:29137
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "无效的调度类型"
 
-#: c/c-parser.c:11406 cp/parser.c:28956
+#: c/c-parser.c:11406 cp/parser.c:28994
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "无效掩码"
 
-#: c/c-parser.c:11471 cp/parser.c:29046
+#: c/c-parser.c:11471 cp/parser.c:29084
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "无效的调度类型"
@@ -30984,60 +31019,60 @@
 msgid "invalid proc_bind kind"
 msgstr "无效的调度类型"
 
-#: c/c-parser.c:11703 cp/parser.c:29255
+#: c/c-parser.c:11703 cp/parser.c:29293
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29266 cp/parser.c:29517
+#: c/c-parser.c:11714 c/c-parser.c:11943 cp/parser.c:29304 cp/parser.c:29555
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs对%qs而言无效"
 
-#: c/c-parser.c:11840 cp/parser.c:29407
+#: c/c-parser.c:11840 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs必须与%qs一起使用"
 
-#: c/c-parser.c:11932 cp/parser.c:29506
+#: c/c-parser.c:11932 cp/parser.c:29544
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:12125 cp/parser.c:31592
+#: c/c-parser.c:12125 cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> in %<#pragma acc enter data%>"
 msgstr "%<#pragma message%>后需要一个字符串"
 
-#: c/c-parser.c:12134 cp/parser.c:31602
+#: c/c-parser.c:12134 cp/parser.c:31637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid pragma"
 msgstr "无效的 #pragma %s"
 
-#: c/c-parser.c:12151 cp/parser.c:31619
+#: c/c-parser.c:12151 cp/parser.c:31654
 #, gcc-internal-format
 msgid "%<#pragma acc enter data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.c:12278 cp/parser.c:31758
+#: c/c-parser.c:12278 cp/parser.c:31793
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host/self%> clause"
 msgstr ""
 
-#: c/c-parser.c:12666 cp/parser.c:29883 cp/parser.c:29909
+#: c/c-parser.c:12666 cp/parser.c:29921 cp/parser.c:29947
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.c:12670 cp/parser.c:29940 cp/parser.c:29956
+#: c/c-parser.c:12670 cp/parser.c:29978 cp/parser.c:29994
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.c:12714 cp/semantics.c:6891 cp/semantics.c:6901
+#: c/c-parser.c:12714 cp/semantics.c:6897 cp/semantics.c:6907
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -31047,18 +31082,18 @@
 msgid "expected %<(%> or end of line"
 msgstr "需要%<(%>或行尾"
 
-#: c/c-parser.c:12825 cp/parser.c:30413 cp/parser.c:33461
+#: c/c-parser.c:12825 cp/parser.c:30451 cp/parser.c:33496
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "需要 for 语句"
 
-#: c/c-parser.c:12831 cp/parser.c:30419
+#: c/c-parser.c:12831 cp/parser.c:30457
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "_Cilk_for statement expected"
 msgstr "需要 for 语句"
 
-#: c/c-parser.c:12885 cp/semantics.c:6525 cp/semantics.c:6595
+#: c/c-parser.c:12885 cp/semantics.c:6531 cp/semantics.c:6601
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "需要迭代声明或初始化"
@@ -31068,238 +31103,238 @@
 msgid "not enough perfectly nested loops"
 msgstr "不够完美的嵌套循环"
 
-#: c/c-parser.c:13026 cp/parser.c:30632
+#: c/c-parser.c:13026 cp/parser.c:30666
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "折叠的循环没有完美的嵌套"
 
-#: c/c-parser.c:13066 cp/parser.c:30462 cp/parser.c:30508 cp/pt.c:13676
+#: c/c-parser.c:13066 cp/parser.c:30500 cp/parser.c:30542 cp/pt.c:13808
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代变量%qD不应当是 firstprivate"
 
-#: c/c-parser.c:13445 cp/parser.c:30976
+#: c/c-parser.c:13441 cp/parser.c:31010
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "需要%<operator%>"
 
-#: c/c-parser.c:13637 cp/parser.c:31163
+#: c/c-parser.c:13633 cp/parser.c:31197
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "需要%<using%>"
 
-#: c/c-parser.c:13841 cp/parser.c:31385
+#: c/c-parser.c:13838 cp/parser.c:31420
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target update%> may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:13854 cp/parser.c:31398
-#, gcc-internal-format
-msgid "%<#pragma omp target update must contain at least one %<from%> or %<to%> clauses"
-msgstr ""
+#: c/c-parser.c:13851 cp/parser.c:31433
+#, fuzzy, gcc-internal-format
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
+msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:13996
+#: c/c-parser.c:13993
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgstr ""
 
-#: c/c-parser.c:14047 c/c-parser.c:14075
+#: c/c-parser.c:14044 c/c-parser.c:14072
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:14094 cp/parser.c:31873
+#: c/c-parser.c:14091 cp/parser.c:31908
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
 
-#: c/c-parser.c:14107
+#: c/c-parser.c:14104
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14115 cp/parser.c:31929
+#: c/c-parser.c:14112 cp/parser.c:31964
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14213 cp/parser.c:31997
+#: c/c-parser.c:14210 cp/parser.c:32032
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "需要%<try%>"
 
-#: c/c-parser.c:14220 cp/parser.c:32004
+#: c/c-parser.c:14217 cp/parser.c:32039
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "需要%<decltype%>"
 
-#: c/c-parser.c:14226 cp/parser.c:32011
+#: c/c-parser.c:14223 cp/parser.c:32046
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
 
-#: c/c-parser.c:14254
+#: c/c-parser.c:14251
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "Objective-C 声明只能出现在全局作用域中"
 
-#: c/c-parser.c:14304
+#: c/c-parser.c:14301
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 msgstr "需要%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%>或%<||%>"
 
-#: c/c-parser.c:14331
+#: c/c-parser.c:14328
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14335
+#: c/c-parser.c:14332
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14338
+#: c/c-parser.c:14335
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.c:14346
+#: c/c-parser.c:14343
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.c:14355
+#: c/c-parser.c:14352
 #, fuzzy, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "上一个声明"
 
-#: c/c-parser.c:14472
+#: c/c-parser.c:14469
 #, fuzzy, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "需要%<(%>或行尾"
 
-#: c/c-parser.c:14483
+#: c/c-parser.c:14480
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "需要函数"
 
-#: c/c-parser.c:14498
+#: c/c-parser.c:14495
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:14618 cp/parser.c:32455
+#: c/c-parser.c:14615 cp/parser.c:32490
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
 
-#: c/c-parser.c:14746 cp/semantics.c:6080
+#: c/c-parser.c:14743 cp/semantics.c:6086
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE在其首次使用后被声明为%<threadprivate%>"
 
-#: c/c-parser.c:14748 cp/semantics.c:6082
+#: c/c-parser.c:14745 cp/semantics.c:6088
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自动变量%qE不能是%<threadprivate%>"
 
-#: c/c-parser.c:14752 cp/semantics.c:6084
+#: c/c-parser.c:14749 cp/semantics.c:6090
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%>%qE的类型不完全"
 
-#: c/c-parser.c:14783
+#: c/c-parser.c:14780
 #, gcc-internal-format
 msgid "pragma simd ignored because -fcilkplus is not enabled"
 msgstr ""
 
-#: c/c-parser.c:14789
+#: c/c-parser.c:14786
 #, fuzzy, gcc-internal-format
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:14833 cp/parser.c:33232
+#: c/c-parser.c:14830 cp/parser.c:33267
 #, fuzzy, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: c/c-parser.c:14835 cp/parser.c:33235
+#: c/c-parser.c:14832 cp/parser.c:33270
 #, fuzzy, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr "栈大小必须刚好是 2 的某次方"
 
-#: c/c-parser.c:14918 cp/parser.c:33342
+#: c/c-parser.c:14915 cp/parser.c:33377
 #, fuzzy, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: c/c-parser.c:15017 cp/parser.c:33435
+#: c/c-parser.c:15014 cp/parser.c:33470
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:15061 cp/parser.c:32908
+#: c/c-parser.c:15058 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "在这里不允许使用%<#pragma%>"
 
-#: c/c-parser.c:15358 cp/parser.c:32800
+#: c/c-parser.c:15355 cp/parser.c:32835
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:15364 cp/parser.c:32806
+#: c/c-parser.c:15361 cp/parser.c:32841
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:15373 cp/parser.c:32815
+#: c/c-parser.c:15370 cp/parser.c:32850
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15375 cp/parser.c:32818
+#: c/c-parser.c:15372 cp/parser.c:32853
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:15381 cp/parser.c:32824
+#: c/c-parser.c:15378 cp/parser.c:32859
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15449 cp/cp-array-notation.c:1418
+#: c/c-parser.c:15446 cp/cp-array-notation.c:1418
 #, fuzzy, gcc-internal-format
 msgid "base of array section must be pointer or array type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c/c-parser.c:15458 cp/parser.c:6476
+#: c/c-parser.c:15455 cp/parser.c:6476
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "需要%<:%>或%<::%>"
 
-#: c/c-parser.c:15469
+#: c/c-parser.c:15466
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in pointers"
 msgstr ""
 
-#: c/c-parser.c:15476 c/c-parser.c:15519
+#: c/c-parser.c:15473 c/c-parser.c:15516
 #, fuzzy, gcc-internal-format
 msgid "array notations cannot be used with function type"
 msgstr "new 不能用于函数类型"
 
-#: c/c-parser.c:15485
+#: c/c-parser.c:15482
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in dimensionless arrays"
 msgstr ""
 
-#: c/c-parser.c:15497
+#: c/c-parser.c:15494
 #, gcc-internal-format
 msgid "start-index and length fields necessary for using array notations in variable-length arrays"
 msgstr ""
 
-#: c/c-parser.c:15547 c/c-parser.c:15550
+#: c/c-parser.c:15544 c/c-parser.c:15547
 #, fuzzy, gcc-internal-format
 msgid "expected array notation expression"
 msgstr "需要布尔表达式"
@@ -31309,7 +31344,7 @@
 msgid "%qD has an incomplete type"
 msgstr "%qD类型不完全"
 
-#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3945
+#: c/c-typeck.c:261 c/c-typeck.c:9258 c/c-typeck.c:9300 cp/call.c:3955
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "对 void 表达式的使用无效"
@@ -31417,7 +31452,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "下标运算的左操作数既非数组也非指针"
 
-#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3202
+#: c/c-typeck.c:2503 cp/typeck.c:3101 cp/typeck.c:3193
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "数组下标不是一个整数"
@@ -31540,7 +31575,7 @@
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "根据原型，实参 %d (%qE) 将作为有符号数传递"
 
-#: c/c-typeck.c:3354 cp/call.c:6615
+#: c/c-typeck.c:3354 cp/call.c:6627
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
@@ -31570,7 +31605,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "在指向不完全类型的指针上执行算术运算"
 
-#: c/c-typeck.c:3588 cp/typeck.c:5146
+#: c/c-typeck.c:3588 cp/typeck.c:5137
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "在指向不完全类型的指针上执行算术运算"
@@ -31657,7 +31692,7 @@
 msgid "non-lvalue array in conditional expression"
 msgstr "非左值数组出现在条件表达式中"
 
-#: c/c-typeck.c:4568 cp/call.c:5027
+#: c/c-typeck.c:4568 cp/call.c:5037
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
@@ -31693,7 +31728,7 @@
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "条件表达式中指针/整数类型不匹配"
 
-#: c/c-typeck.c:4816 cp/typeck.c:6277
+#: c/c-typeck.c:4816 cp/typeck.c:6268
 #, fuzzy, gcc-internal-format
 msgid "spawned function call cannot be part of a comma expression"
 msgstr "函数调用不能出现在常量表达式中"
@@ -31778,7 +31813,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "从类型为%qT的函数调用转换到不匹配的类型%qT"
 
-#: c/c-typeck.c:5157 cp/typeck.c:7232
+#: c/c-typeck.c:5157 cp/typeck.c:7223
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "将一个整数转换为大小不同的指针"
@@ -31939,7 +31974,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手边可能是 format 属性的备选时"
 
-#: c/c-typeck.c:6176 cp/typeck.c:8232
+#: c/c-typeck.c:6176 cp/typeck.c:8223
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "返回类型可能是 format 属性的备选"
@@ -32076,7 +32111,7 @@
 msgid "initialization of a flexible array member"
 msgstr "对可变数组成员的初始化"
 
-#: c/c-typeck.c:6696 cp/typeck2.c:1017
+#: c/c-typeck.c:6696 cp/typeck2.c:1024
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "用宽字符串初始化 char 数组"
@@ -32122,7 +32157,7 @@
 msgid "invalid initializer"
 msgstr "无效的初始值设定"
 
-#: c/c-typeck.c:7211 cp/decl.c:5922
+#: c/c-typeck.c:7211 cp/decl.c:5929
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量类型不能被初始化"
@@ -32267,7 +32302,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C++ 不允许%<goto *expr;%>"
 
-#: c/c-typeck.c:9373 cp/typeck.c:8455
+#: c/c-typeck.c:9373 cp/typeck.c:8446
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被声明为%<noreturn%>的函数却有%<return%>语句"
@@ -32277,7 +32312,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9390 cp/typeck.c:8446
+#: c/c-typeck.c:9390 cp/typeck.c:8437
 #, fuzzy, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr "%L处 CASE 语句中的逻辑范围是不被允许的"
@@ -32383,17 +32418,17 @@
 msgid "expression statement has incomplete type"
 msgstr "表达式语句类型不完全"
 
-#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4664
+#: c/c-typeck.c:10737 c/c-typeck.c:10879 cp/typeck.c:4655
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "对不同枚举类型之间的比较给出警告"
 
-#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4676
+#: c/c-typeck.c:10744 c/c-typeck.c:10886 cp/typeck.c:4667
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "形参数量不同"
 
-#: c/c-typeck.c:10760 cp/typeck.c:4392
+#: c/c-typeck.c:10760 cp/typeck.c:4383
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "使用 == 或 != 比较浮点数是不安全的"
@@ -32444,12 +32479,12 @@
 msgstr "指针与整数 0 比较大小"
 
 #: c/c-typeck.c:10947 c/c-typeck.c:10950 c/c-typeck.c:10957 c/c-typeck.c:10960
-#: cp/typeck.c:4713 cp/typeck.c:4720
+#: cp/typeck.c:4704 cp/typeck.c:4711
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "指针与整数 0 比较大小"
 
-#: c/c-typeck.c:11008 cp/typeck.c:4793
+#: c/c-typeck.c:11008 cp/typeck.c:4784
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
@@ -32474,85 +32509,85 @@
 msgid "used vector type where scalar is required"
 msgstr "需要标量时使用了结构类型"
 
-#: c/c-typeck.c:11527 cp/semantics.c:6997
+#: c/c-typeck.c:11527 cp/semantics.c:7003
 #, gcc-internal-format
 msgid "%<#pragma omp cancel must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11566 cp/semantics.c:7034
+#: c/c-typeck.c:11566 cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:11609 cp/semantics.c:4299 cp/semantics.c:5794
+#: c/c-typeck.c:11609 cp/semantics.c:4305 cp/semantics.c:5800
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4303
-#: cp/semantics.c:5797
+#: c/c-typeck.c:11613 c/c-typeck.c:12388 cp/semantics.c:4309
+#: cp/semantics.c:5803
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4311
-#: cp/semantics.c:5803
+#: c/c-typeck.c:11621 c/c-typeck.c:12395 cp/semantics.c:4317
+#: cp/semantics.c:5809
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:11643 cp/semantics.c:4337
+#: c/c-typeck.c:11643 cp/semantics.c:4343
 #, fuzzy, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c/c-typeck.c:11650 cp/semantics.c:4344
+#: c/c-typeck.c:11650 cp/semantics.c:4350
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c/c-typeck.c:11682 cp/semantics.c:4380
+#: c/c-typeck.c:11682 cp/semantics.c:4386
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:11690 cp/semantics.c:4388
+#: c/c-typeck.c:11690 cp/semantics.c:4394
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11699 cp/semantics.c:4397
+#: c/c-typeck.c:11699 cp/semantics.c:4403
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:11716 cp/semantics.c:4414
+#: c/c-typeck.c:11716 cp/semantics.c:4420
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11741 cp/semantics.c:4439
+#: c/c-typeck.c:11741 cp/semantics.c:4445
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11756 cp/semantics.c:4454
+#: c/c-typeck.c:11756 cp/semantics.c:4460
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:11787 cp/semantics.c:4485
+#: c/c-typeck.c:11787 cp/semantics.c:4491
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "for 循环増量表达式不起作用"
 
-#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4494
-#: cp/semantics.c:4605
+#: c/c-typeck.c:11796 c/c-typeck.c:11911 cp/semantics.c:4500
+#: cp/semantics.c:4611
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "在过程入口处将数组段复制到一个连续的块中"
 
-#: c/c-typeck.c:11804 cp/semantics.c:4502
+#: c/c-typeck.c:11804 cp/semantics.c:4508
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
@@ -32562,17 +32597,17 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE的类型对%<reduction(%s)%>无效"
 
-#: c/c-typeck.c:12133 cp/semantics.c:5286
+#: c/c-typeck.c:12133 cp/semantics.c:5292
 #, gcc-internal-format
 msgid "user defined reduction not found for %qD"
 msgstr ""
 
-#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5933
+#: c/c-typeck.c:12205 c/c-typeck.c:12443 cp/semantics.c:5939
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:12217 cp/semantics.c:5973
+#: c/c-typeck.c:12217 cp/semantics.c:5979
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE必须是%<threadprivate%>方可%<copyin%>"
@@ -32582,7 +32617,7 @@
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:12255 cp/semantics.c:5391
+#: c/c-typeck.c:12255 cp/semantics.c:5397
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE在子句%qs中不是一个变量"
@@ -32592,17 +32627,17 @@
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:12278 cp/semantics.c:5415
+#: c/c-typeck.c:12278 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
 
-#: c/c-typeck.c:12299 cp/semantics.c:5437
+#: c/c-typeck.c:12299 cp/semantics.c:5443
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.c:12318 cp/semantics.c:5681
+#: c/c-typeck.c:12318 cp/semantics.c:5687
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE在子句%qs中不是一个变量"
@@ -32617,47 +32652,47 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:12353 cp/semantics.c:5751
+#: c/c-typeck.c:12353 cp/semantics.c:5757
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:12375 cp/semantics.c:5776
+#: c/c-typeck.c:12375 cp/semantics.c:5782
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "在 %L 处的推迟数组“%1$s”在初始化表达式中不被允许"
 
-#: c/c-typeck.c:12408 cp/semantics.c:5820
+#: c/c-typeck.c:12408 cp/semantics.c:5826
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:12415 cp/semantics.c:5827
+#: c/c-typeck.c:12415 cp/semantics.c:5833
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:12417 cp/semantics.c:5829
+#: c/c-typeck.c:12417 cp/semantics.c:5835
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:12430 cp/semantics.c:5843
+#: c/c-typeck.c:12430 cp/semantics.c:5849
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:12433 cp/semantics.c:5845
+#: c/c-typeck.c:12433 cp/semantics.c:5851
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:12491 cp/semantics.c:5869
+#: c/c-typeck.c:12491 cp/semantics.c:5875
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:12541 cp/semantics.c:6020
+#: c/c-typeck.c:12541 cp/semantics.c:6026
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE可被预先确定为%qs，为%qs"
@@ -32668,117 +32703,117 @@
 msgstr "C++ 在%<va_arg%>中需要提升后的类型而不是枚举"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3291
+#: cp/call.c:3301
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "将%qT作为%q#D的%<this%>实参时丢弃了类型限定"
 
-#: cp/call.c:3295
+#: cp/call.c:3305
 #, gcc-internal-format
 msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:3302
+#: cp/call.c:3312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "以从%qT转换为%qT"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3309
+#: cp/call.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion from %qT to %qT"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.c:3312
+#: cp/call.c:3322
 #, fuzzy, gcc-internal-format
 msgid "  no known conversion for argument %d from %qT to %qT"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.c:3323 cp/pt.c:5658
+#: cp/call.c:3333 cp/pt.c:5714
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] " 备选需要 %d 实参，但提供了 %d 个"
 
-#: cp/call.c:3348
+#: cp/call.c:3358
 #, gcc-internal-format
 msgid "%s%D(%T, %T, %T) <built-in>"
 msgstr "%s%D(%T, %T, %T) <内建>"
 
-#: cp/call.c:3353
+#: cp/call.c:3363
 #, gcc-internal-format
 msgid "%s%D(%T, %T) <built-in>"
 msgstr "%s%D(%T, %T) <内建>"
 
-#: cp/call.c:3357
+#: cp/call.c:3367
 #, gcc-internal-format
 msgid "%s%D(%T) <built-in>"
 msgstr "%s%D(%T) <内建>"
 
-#: cp/call.c:3361
+#: cp/call.c:3371
 #, gcc-internal-format
 msgid "%s%T <conversion>"
 msgstr "%s%T  <转换>"
 
-#: cp/call.c:3363
+#: cp/call.c:3373
 #, gcc-internal-format
 msgid "%s%#D <near match>"
 msgstr "%s%#D <就近匹配>"
 
-#: cp/call.c:3365
+#: cp/call.c:3375
 #, gcc-internal-format
 msgid "%s%#D <deleted>"
 msgstr "%s%#D <删除的>"
 
-#: cp/call.c:3367
+#: cp/call.c:3377
 #, gcc-internal-format
 msgid "%s%#D"
 msgstr "%s%#D"
 
-#: cp/call.c:3386
+#: cp/call.c:3396
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3392
+#: cp/call.c:3402
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3403
+#: cp/call.c:3413
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3408
+#: cp/call.c:3418
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/call.c:3422
+#: cp/call.c:3432
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3783
+#: cp/call.c:3793
 #, gcc-internal-format
 msgid "conversion from %qT to %qT is ambiguous"
 msgstr "从%qT到%qT的转换有歧义"
 
-#: cp/call.c:3910
+#: cp/call.c:3920
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT not considered for non-type template argument"
 msgstr "请求从%qT转换到非标量类型%qT"
 
-#: cp/call.c:4028
+#: cp/call.c:4038
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "对%<%D(%A)%>的调用没有匹配的函数"
 
-#: cp/call.c:4031
+#: cp/call.c:4041
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "调用重载的%<%D(%A)%>有歧义"
@@ -32785,465 +32820,465 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4240
+#: cp/call.c:4250
 #, gcc-internal-format
 msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgstr "没有对象不能调用成员函数指针 %E，考虑使用 .* 或 ->*"
 
-#: cp/call.c:4311
+#: cp/call.c:4321
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "对%<(%T) (%A)%>的调用没有匹配"
 
-#: cp/call.c:4324
+#: cp/call.c:4334
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "对%<(%T) (%A)%>的调用有歧义"
 
-#: cp/call.c:4372
+#: cp/call.c:4382
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "%qs在%<%s %E%>中的重载有歧义"
 
-#: cp/call.c:4373
+#: cp/call.c:4383
 #, fuzzy, gcc-internal-format
 msgid "no match for "
 msgstr "%qs在%<%s %E%>中没有匹配"
 
-#: cp/call.c:4376
+#: cp/call.c:4386
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "双目运算符 %s 操作数(%qT和%qT)无效"
 
-#: cp/call.c:4378
+#: cp/call.c:4388
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "双目运算符 %s 操作数(%qT和%qT)无效"
 
-#: cp/call.c:4380
+#: cp/call.c:4390
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4400
+#: cp/call.c:4410
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "需要%<operator%>"
 
-#: cp/call.c:4404
+#: cp/call.c:4414
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "三元%<operator?:%>在%<%E ? %E : %E%>中没有匹配"
 
-#: cp/call.c:4413 cp/call.c:4444 cp/call.c:4453
+#: cp/call.c:4423 cp/call.c:4454 cp/call.c:4463
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "需要%<operator%>"
 
-#: cp/call.c:4416
+#: cp/call.c:4426
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%>在%<%E%s%>中没有匹配"
 
-#: cp/call.c:4423
+#: cp/call.c:4433
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "需要%<operator%>"
 
-#: cp/call.c:4426
+#: cp/call.c:4436
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%>在%<%E[%E]%>中没有匹配"
 
-#: cp/call.c:4434
+#: cp/call.c:4444
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4437
+#: cp/call.c:4447
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs在%<%s %E%>中没有匹配"
 
-#: cp/call.c:4447
+#: cp/call.c:4457
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%>在%<%E %s %E%>中没有匹配"
 
-#: cp/call.c:4456
+#: cp/call.c:4466
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%>在%<%s%E%>中没有匹配"
 
-#: cp/call.c:4565
+#: cp/call.c:4575
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C 不允许省略 ?: 表达式中的第二项"
 
-#: cp/call.c:4614
+#: cp/call.c:4624
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4692
+#: cp/call.c:4702
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "条件表达式中枚举不匹配：%qT对%qT"
 
-#: cp/call.c:4780
+#: cp/call.c:4790
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "条件运算符的第二个操作数类型为%<void%>，但第三个操作数既不是异常表达式，也不拥有%<void%>类型"
 
-#: cp/call.c:4785
+#: cp/call.c:4795
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "条件运算符的第三个操作数类型为%<void%>，但第二个操作数既不是异常表达式，也不拥有%<void%>类型"
 
-#: cp/call.c:4836 cp/call.c:4952 cp/call.c:5095
+#: cp/call.c:4846 cp/call.c:4962 cp/call.c:5105
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "?: 的操作数类型不一致，分别为%qT和%qT"
 
-#: cp/call.c:4839
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5040
+#: cp/call.c:5050
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "条件表达式中枚举不匹配：%qT对%qT"
 
-#: cp/call.c:5052
+#: cp/call.c:5062
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "枚举和非枚举类型一起出现在条件表达式中"
 
-#: cp/call.c:5518
+#: cp/call.c:5528
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%>没有出现在后缀%qs中，尝试使用前缀运算符"
 
-#: cp/call.c:5520
+#: cp/call.c:5530
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "没有为后缀%2$qs声明%<%1$D(int)%>"
 
-#: cp/call.c:5613
+#: cp/call.c:5623
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "在%q#T和%q#T间比较"
 
-#: cp/call.c:5881
+#: cp/call.c:5893
 #, gcc-internal-format
 msgid "non-placement deallocation function %q+D"
 msgstr "非预定位的释放函数%q+D"
 
-#: cp/call.c:5882
+#: cp/call.c:5894
 #, gcc-internal-format
 msgid "selected for placement delete"
 msgstr "被选择为预定位删除"
 
-#: cp/call.c:5996
+#: cp/call.c:6008
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "%qD没有相应的释放函数"
 
-#: cp/call.c:6002
+#: cp/call.c:6014
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "没有合适的%<operator %s%>给%qT"
 
-#: cp/call.c:6023
+#: cp/call.c:6035
 #, gcc-internal-format
 msgid "%q+#D is private"
 msgstr "%q+#D是私有的"
 
-#: cp/call.c:6025
+#: cp/call.c:6037
 #, gcc-internal-format
 msgid "%q+#D is protected"
 msgstr "%q+#D是保护的"
 
-#: cp/call.c:6027
+#: cp/call.c:6039
 #, gcc-internal-format
 msgid "%q+#D is inaccessible"
 msgstr "%q+#D无法访问"
 
-#: cp/call.c:6028
+#: cp/call.c:6040
 #, gcc-internal-format
 msgid "within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:6079
+#: cp/call.c:6091
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "将 NULL 作为非指针实参 %P 传递给%qD"
 
-#: cp/call.c:6083
+#: cp/call.c:6095
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "将 NULL 转换到非指针类型%qT"
 
-#: cp/call.c:6092
+#: cp/call.c:6104
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "将%<false%>转换为指向%2$qD的实参 %1$P 的指针类型"
 
-#: cp/call.c:6096
+#: cp/call.c:6108
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "将%<false%>转换为指向%2$qD的实参 %1$P 的指针类型"
 
-#: cp/call.c:6159
+#: cp/call.c:6171
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "%qT的初始值设定周围花括号太多"
 
-#: cp/call.c:6170
+#: cp/call.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "converting to %qT from %qT requires direct-initialization"
 msgstr "不能在初始化时将%qT转换为%qT"
 
-#: cp/call.c:6178
+#: cp/call.c:6190
 #, fuzzy, gcc-internal-format
 msgid "invalid user-defined conversion from %qT to %qT"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/call.c:6195 cp/call.c:6219 cp/call.c:6447
+#: cp/call.c:6207 cp/call.c:6231 cp/call.c:6459
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  初始化%2$qD的实参 %1$P"
 
-#: cp/call.c:6215 cp/cvt.c:236
+#: cp/call.c:6227 cp/cvt.c:236
 #, gcc-internal-format
 msgid "invalid conversion from %qT to %qT"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/call.c:6243
+#: cp/call.c:6255
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "从初始化列表转换为%qT将使用显式构造函数%qD"
 
-#: cp/call.c:6323 cp/call.c:6475
+#: cp/call.c:6335 cp/call.c:6487
 #, fuzzy, gcc-internal-format
 #| msgid "  initializing argument %P of %qD"
 msgid "  initializing argument %P of %q+D"
 msgstr "  初始化%2$qD的实参 %1$P"
 
-#: cp/call.c:6461
+#: cp/call.c:6473
 #, gcc-internal-format
 msgid "cannot bind %qT lvalue to %qT"
 msgstr "无法将左值%qT绑定到%qT"
 
-#: cp/call.c:6465 cp/call.c:9721
+#: cp/call.c:6477 cp/call.c:9733
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "用类型为%2$qT的右值初始化类型为%1$qT的非常量引用无效"
 
-#: cp/call.c:6468
+#: cp/call.c:6480
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "binding %qT to reference of type %qT discards qualifiers"
 msgstr "将%qT作为%q#D的%<this%>实参时丢弃了类型限定"
 
-#: cp/call.c:6504
+#: cp/call.c:6516
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "无法将位段%qE绑定到%qT"
 
-#: cp/call.c:6507 cp/call.c:6524
+#: cp/call.c:6519 cp/call.c:6536
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "不能将紧实的字段%qE绑定到%qT"
 
-#: cp/call.c:6510
+#: cp/call.c:6522
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "无法将右值%qE绑定到%qT"
 
-#: cp/call.c:6632 cp/cvt.c:1734
+#: cp/call.c:6644 cp/cvt.c:1746
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-trivially-copyable type %q#T through %<...%>"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "不能通过%<...%>传递有不能平凡复制的类型%q#T"
 
-#: cp/call.c:6704
+#: cp/call.c:6716
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/call.c:6714
+#: cp/call.c:6726
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/call.c:6774
+#: cp/call.c:6786
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "递归计算%q#D的默认参数"
 
-#: cp/call.c:6783
+#: cp/call.c:6795
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "%2$qD的第 %1$d 个形参的默认实参尚未被解析到"
 
-#: cp/call.c:6885
+#: cp/call.c:6897
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "函数的实参可能是 format 属性的备选"
 
-#: cp/call.c:6932
+#: cp/call.c:6944
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "默认化函数%q+D有默认参数"
 
-#: cp/call.c:7177
+#: cp/call.c:7189
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "将%qT作为%q#D的%<this%>实参时丢弃了类型限定"
 
-#: cp/call.c:7180 cp/call.c:8961 cp/name-lookup.c:5713
+#: cp/call.c:7192 cp/call.c:8973 cp/name-lookup.c:5713
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "在调用%qD时"
 
-#: cp/call.c:7210
+#: cp/call.c:7222
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT是%qT的一个不可访问的基类"
 
-#: cp/call.c:7292
+#: cp/call.c:7304
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "演绎 %qT 为 %qT"
 
-#: cp/call.c:7295
+#: cp/call.c:7307
 #, gcc-internal-format
 msgid "  in call to %q+D"
 msgstr "在调用%q+D时"
 
-#: cp/call.c:7297
+#: cp/call.c:7309
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "(您可以用 -fno-deduce-init-lis 禁用它)"
 
-#: cp/call.c:7651
+#: cp/call.c:7663
 #, gcc-internal-format
 msgid "could not find class$ field in java interface type %qT"
 msgstr "在 java 接口类型%qT中找不到 class$ 字段"
 
-#: cp/call.c:7826
+#: cp/call.c:7838
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "inlined_to pointer 指向自身"
 
-#: cp/call.c:7916
+#: cp/call.c:7928
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "调用非函数的%qD"
 
-#: cp/call.c:7962 cp/typeck.c:2750
+#: cp/call.c:7974 cp/typeck.c:2750
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "不能直接调用构造函数%<%T::%D%>"
 
-#: cp/call.c:7964
+#: cp/call.c:7976
 #, fuzzy, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "对于函数类型的类型转换，移除冗余的%<::%D%>"
 
-#: cp/call.c:8091
+#: cp/call.c:8103
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: cp/call.c:8104
+#: cp/call.c:8116
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: cp/call.c:8130
+#: cp/call.c:8142
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "对%<%D(%A)%>的调用没有匹配的函数"
 
-#: cp/call.c:8133
+#: cp/call.c:8145
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "对重载的%<%s(%A)%>的调用有歧义"
 
-#: cp/call.c:8154
+#: cp/call.c:8166
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.c:8180
+#: cp/call.c:8192
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "没有对象无法调用成员函数%qD"
 
-#: cp/call.c:8959
+#: cp/call.c:8971
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "传递%qT时选择%qT而不是%qT"
 
-#: cp/call.c:9019
+#: cp/call.c:9031
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "选择%qD而不是%qD"
 
-#: cp/call.c:9020
+#: cp/call.c:9032
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.c:9023
+#: cp/call.c:9035
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "因为前者的实参类型转换序列更好"
 
-#: cp/call.c:9176
+#: cp/call.c:9188
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "重载解决时默认参数不匹配"
 
-#: cp/call.c:9180
+#: cp/call.c:9192
 #, gcc-internal-format
 msgid " candidate 1: %q+#F"
 msgstr "备选 1: %q+#F"
 
-#: cp/call.c:9182
+#: cp/call.c:9194
 #, gcc-internal-format
 msgid " candidate 2: %q+#F"
 msgstr "备选 2: %q+#F"
 
-#: cp/call.c:9227
+#: cp/call.c:9239
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ 认为有歧义，尽管第一个备选的最差类型转换要好于第二个备选的最差类型转换"
 
-#: cp/call.c:9405
+#: cp/call.c:9417
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "不能将%qE转换为%qT"
 
-#: cp/call.c:9598
+#: cp/call.c:9610
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:9725
+#: cp/call.c:9737
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "将类型为%qT的引用初始化为类型为%qT的表达式无效"
@@ -33400,7 +33435,7 @@
 msgid "  by %q+D"
 msgstr "%q+D所隐藏"
 
-#: cp/class.c:3053 cp/decl2.c:1533
+#: cp/class.c:3053 cp/decl2.c:1537
 #, gcc-internal-format
 msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D无效；匿名联合只能有非静态的数据成员"
@@ -33410,7 +33445,7 @@
 msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D无效；匿名联合只能有非静态的数据成员"
 
-#: cp/class.c:3069 cp/decl2.c:1539
+#: cp/class.c:3069 cp/decl2.c:1543
 #, gcc-internal-format
 msgid "private member %q+#D in anonymous union"
 msgstr "匿名联合中出现私有成员%q+#D"
@@ -33420,7 +33455,7 @@
 msgid "private member %q+#D in anonymous struct"
 msgstr "匿名联合中出现私有成员%q+#D"
 
-#: cp/class.c:3078 cp/decl2.c:1541
+#: cp/class.c:3078 cp/decl2.c:1545
 #, gcc-internal-format
 msgid "protected member %q+#D in anonymous union"
 msgstr "匿名联合中出现保护成员%q+#D"
@@ -33552,68 +33587,79 @@
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "但没有重载%<operator=(const %T&)%>"
 
-#: cp/class.c:4538
+#: cp/class.c:4300
 #, gcc-internal-format
+msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
+msgstr ""
+
+#: cp/class.c:4303
+#, fuzzy, gcc-internal-format
+#| msgid "alignment of %qD is bigger than original declaration"
+msgid "alignment of %qD will increase in -fabi-version=9"
+msgstr "%qD的对齐"
+
+#: cp/class.c:4557
+#, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "为非虚方法%q+D指定了初始值设定项"
 
-#: cp/class.c:4959
+#: cp/class.c:4978
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4980
+#: cp/class.c:4999
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5532 cp/constexpr.c:228
+#: cp/class.c:5551 cp/constexpr.c:228
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: cp/class.c:5557
+#: cp/class.c:5576
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q#T不是一个类"
 
-#: cp/class.c:5559
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "基类%q#T有一个非虚析构函数"
 
-#: cp/class.c:5564
+#: cp/class.c:5583
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5599
+#: cp/class.c:5618
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: cp/class.c:5613
+#: cp/class.c:5632
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has non-literal type"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:5619
+#: cp/class.c:5638
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %q+D has volatile type"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:5737
+#: cp/class.c:5756
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "基类%q#T有一个非虚析构函数"
 
-#: cp/class.c:5765
+#: cp/class.c:5784
 #, gcc-internal-format
 msgid "non-static reference %q+#D in class without a constructor"
 msgstr "类中有非静态引用%q+#D，却没有提供构造函数"
 
-#: cp/class.c:5770
+#: cp/class.c:5789
 #, gcc-internal-format
 msgid "non-static const member %q+#D in class without a constructor"
 msgstr "类中有非静态常量成员%q+#D却没有构造函数"
@@ -33620,103 +33666,103 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5796
+#: cp/class.c:5815
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D被声明为取常量引用，但是隐式声明取非常量引用"
 
-#: cp/class.c:6073
+#: cp/class.c:6092
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "由于存在歧义，直接基类%qT在%qT中无法访问"
 
-#: cp/class.c:6085
+#: cp/class.c:6104
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "由于存在歧义，虚基类%qT在%qT中无法访问"
 
-#: cp/class.c:6312
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D的偏移量与 ABI 不兼容，并且在 GCC 的未来版本中可能会有变化"
 
-#: cp/class.c:6554 cp/decl.c:12512 cp/parser.c:20482
+#: cp/class.c:6573 cp/decl.c:12519 cp/parser.c:20506
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T重定义"
 
-#: cp/class.c:6693
+#: cp/class.c:6712
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T有虚函数和可访问的非虚拟析构函数"
 
-#: cp/class.c:6721
+#: cp/class.c:6740
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "类型%qT大小未知"
 
-#: cp/class.c:6727
+#: cp/class.c:6746
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6731
+#: cp/class.c:6750
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "类型%qE有虚成员函数"
 
-#: cp/class.c:6737
+#: cp/class.c:6756
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:6900
+#: cp/class.c:6920
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/class.c:6911
+#: cp/class.c:6931
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "试图完成结构，但为先前的解析错误所中断"
 
-#: cp/class.c:7445
+#: cp/class.c:7465
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "语言字符串%<\"%E\"%>不可识别"
 
-#: cp/class.c:7535
+#: cp/class.c:7555
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "无法解析重载函数%qD，基于向类型%qT的转换"
 
-#: cp/class.c:7672
+#: cp/class.c:7692
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "没有可将函数%qD转换到类型%q#T的匹配项"
 
-#: cp/class.c:7700
+#: cp/class.c:7720
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "将重载函数%qD转换为类型%q#T有歧义"
 
-#: cp/class.c:7727
+#: cp/class.c:7747
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "假定是成员指针%qD"
 
-#: cp/class.c:7730
+#: cp/class.c:7750
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(成员指针只能用%<&%E%>构成)"
 
-#: cp/class.c:7805 cp/class.c:7840
+#: cp/class.c:7825 cp/class.c:7860
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "类型信息不充分"
 
-#: cp/class.c:7823 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
+#: cp/class.c:7843 cp/cvt.c:183 cp/cvt.c:210 cp/cvt.c:259
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "无法将%qE从类型%qT转换到类型%qT"
@@ -33726,12 +33772,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8101
+#: cp/class.c:8121
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "%q#D的声明"
 
-#: cp/class.c:8102
+#: cp/class.c:8122
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q+#D"
 msgstr "改变了%qD的原意%q+#D"
@@ -33771,260 +33817,260 @@
 msgid "constexpr constructor does not have empty body"
 msgstr "广义常表达式构造函数体不为空"
 
-#: cp/constexpr.c:575
+#: cp/constexpr.c:584
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:706
+#: cp/constexpr.c:715
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/constexpr.c:746
+#: cp/constexpr.c:755
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "成员%qD在%<constexpr%>构造函数里未初始化"
 
-#: cp/constexpr.c:778
+#: cp/constexpr.c:787
 #, fuzzy, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "返回语句转换无效"
 
-#: cp/constexpr.c:831
+#: cp/constexpr.c:840
 #, fuzzy, gcc-internal-format
 msgid "%q+D is not usable as a constexpr function because:"
 msgstr "%qD不是一个广义常函数"
 
-#: cp/constexpr.c:1190 cp/constexpr.c:3926
+#: cp/constexpr.c:1199 cp/constexpr.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
 msgid "call to internal function"
 msgstr "内部函数"
 
-#: cp/constexpr.c:1208
+#: cp/constexpr.c:1217
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/constexpr.c:1226 cp/constexpr.c:3943
+#: cp/constexpr.c:1235 cp/constexpr.c:4004
 #, fuzzy, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "调用非函数的%qD"
 
 #. The definition of fun was somehow unsuitable.
-#: cp/constexpr.c:1261
+#: cp/constexpr.c:1279
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:1265
+#: cp/constexpr.c:1283
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD用在其自身的初始值设定中"
 
-#: cp/constexpr.c:1318
+#: cp/constexpr.c:1336
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "调用存在循环依赖"
 
-#: cp/constexpr.c:1329
+#: cp/constexpr.c:1347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/constexpr.c:1409
+#: cp/constexpr.c:1434
 #, fuzzy, gcc-internal-format
 #| msgid "Warn on calls to these functions"
 msgid "constexpr call flows off the end of the function"
 msgstr "调用这些函数时给出警告"
 
-#: cp/constexpr.c:1496
+#: cp/constexpr.c:1521
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E不是一个常量表达式"
 
-#: cp/constexpr.c:1536
+#: cp/constexpr.c:1561
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/constexpr.c:1543
+#: cp/constexpr.c:1568
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1560
+#: cp/constexpr.c:1585
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/constexpr.c:1579
+#: cp/constexpr.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:1741
+#: cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "array subscript out of bound"
 msgstr "数组下标越界"
 
-#: cp/constexpr.c:1748
+#: cp/constexpr.c:1773
 #, fuzzy, gcc-internal-format
 msgid "negative array subscript"
 msgstr "%C处需要数组下标"
 
-#: cp/constexpr.c:1794 cp/constexpr.c:1873 cp/constexpr.c:3071
+#: cp/constexpr.c:1819 cp/constexpr.c:1898 cp/constexpr.c:3120
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:1800
+#: cp/constexpr.c:1825
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: cp/constexpr.c:1821
+#: cp/constexpr.c:1846
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "初始值设定中数组索引不是整型常量表达式"
 
-#: cp/constexpr.c:1833
+#: cp/constexpr.c:1858
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "成员%qD缺少初始值设定"
 
-#: cp/constexpr.c:2488
+#: cp/constexpr.c:2513
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: cp/constexpr.c:2525
+#: cp/constexpr.c:2550
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: cp/constexpr.c:2532
+#: cp/constexpr.c:2557
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD用在其自身的初始值设定中"
 
-#: cp/constexpr.c:2537
+#: cp/constexpr.c:2562
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D不是 const"
 
-#: cp/constexpr.c:2540
+#: cp/constexpr.c:2565
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D是 volatile"
 
-#: cp/constexpr.c:2544
+#: cp/constexpr.c:2569
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:2553
+#: cp/constexpr.c:2578
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD在此作用域中尚未声明"
 
-#: cp/constexpr.c:2556
+#: cp/constexpr.c:2581
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/constexpr.c:2646
+#: cp/constexpr.c:2686
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant-expression"
 msgstr "初始值设定中元素不是常量表达式"
 
-#: cp/constexpr.c:3115 cp/constexpr.c:4313
+#: cp/constexpr.c:3164 cp/constexpr.c:4379
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "枚举和非枚举类型一起出现在条件表达式中"
 
-#: cp/constexpr.c:3425 cp/constexpr.c:4033
+#: cp/constexpr.c:3486 cp/constexpr.c:4094
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "从类型%qT到类型%qT的 reinterpret_cast 丢失了限定符"
 
-#: cp/constexpr.c:3482 cp/constexpr.c:4190 cp/constexpr.c:4478
+#: cp/constexpr.c:3543 cp/constexpr.c:4251 cp/constexpr.c:4544
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant-expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:3533
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant-expression"
 msgstr "初始值设定中元素不是常量表达式"
 
-#: cp/constexpr.c:3536
+#: cp/constexpr.c:3597
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "表达式%qE有副作用"
 
-#: cp/constexpr.c:3603
+#: cp/constexpr.c:3664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:3616
+#: cp/constexpr.c:3677
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgstr "表达式%qE具有抽象类类型%qT，不能用于 throw 表达式中"
 
-#: cp/constexpr.c:3864
+#: cp/constexpr.c:3925
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "表达式%qE有副作用"
 
-#: cp/constexpr.c:4059
+#: cp/constexpr.c:4120
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4089
+#: cp/constexpr.c:4150
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:4202
+#: cp/constexpr.c:4263
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:4215
+#: cp/constexpr.c:4276
 #, fuzzy, gcc-internal-format
 msgid "difference of two pointer expressions is not a constant expression"
 msgstr "初始值设定中元素不是常量表达式"
 
-#: cp/constexpr.c:4234
+#: cp/constexpr.c:4295
 #, fuzzy, gcc-internal-format
 msgid "pointer comparison expression is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:4281
+#: cp/constexpr.c:4342
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "常量表达式中类型错误"
 
-#: cp/constexpr.c:4361
+#: cp/constexpr.c:4427
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant-expression"
 msgstr "初始值设定中元素不是常量表达式"
 
-#: cp/constexpr.c:4486
+#: cp/constexpr.c:4552
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "%L处需要标量初始化表达式"
 
-#: cp/constexpr.c:4495
+#: cp/constexpr.c:4566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "无效的调度类型"
@@ -34095,7 +34141,7 @@
 msgid "try statements are not allowed inside loops marked with #pragma simd"
 msgstr "%s 语句不能用在%C处 BLOCK 内"
 
-#: cp/cp-gimplify.c:1672
+#: cp/cp-gimplify.c:1690
 #, gcc-internal-format
 msgid "%qE implicitly determined as %<firstprivate%> has reference type"
 msgstr "%qE隐式地被确定，因为%<firstprivate%>有引用类型"
@@ -34135,7 +34181,7 @@
 msgid "conversion from %qT to %qT discards qualifiers"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: cp/cvt.c:501 cp/typeck.c:6823
+#: cp/cvt.c:501 cp/typeck.c:6814
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "从%qT转换到%qT并未提领指针"
@@ -34145,292 +34191,292 @@
 msgid "cannot convert type %qT to type %qT"
 msgstr "不能将类型%qT转换为类型%qT"
 
-#: cp/cvt.c:749
+#: cp/cvt.c:761
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "从%q#T到%q#T的转换"
 
-#: cp/cvt.c:766
+#: cp/cvt.c:778
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "转换的结果不能确定，因为%qE已经超过了类型%qT的范围"
 
-#: cp/cvt.c:777 cp/cvt.c:821
+#: cp/cvt.c:789 cp/cvt.c:833
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "不应使用%q#T而应使用%qT"
 
-#: cp/cvt.c:786
+#: cp/cvt.c:798
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "不能将%qE转换为%qT"
 
-#: cp/cvt.c:837
+#: cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "需要浮点数值时使用了%q#T"
 
-#: cp/cvt.c:896
+#: cp/cvt.c:908
 #, gcc-internal-format
 msgid "conversion from %qT to non-scalar type %qT requested"
 msgstr "请求从%qT转换到非标量类型%qT"
 
-#: cp/cvt.c:956
+#: cp/cvt.c:968
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "伪析构函数未被调用"
 
-#: cp/cvt.c:1033
+#: cp/cvt.c:1045
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "向 void 的类型转换不会访问具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1037
+#: cp/cvt.c:1049
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "提领不会访问作为条件表达式第二个操作数的具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1042
+#: cp/cvt.c:1054
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "提领不会访问作为条件表达式第三个操作数的具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1047
+#: cp/cvt.c:1059
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "提领不会访问作为逗号操作符右操作数的具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1052
+#: cp/cvt.c:1064
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "提领不会访问作为逗号操作符左操作数的具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1057
+#: cp/cvt.c:1069
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "提领不会访问语句中具有不完全类型的对象%qT"
 
-#: cp/cvt.c:1061
+#: cp/cvt.c:1073
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "提领不会访问 for 循环增量表达式中具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1077
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "向 void 的转换不会访问具有类型%qT的对象"
 
-#: cp/cvt.c:1081
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "隐式提领不会访问作为条件表达式第二个操作数的具有类型%qT的对象"
 
-#: cp/cvt.c:1086
+#: cp/cvt.c:1098
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "隐式提领不会访问作为条件表达式第三个操作数的具有类型%qT的对象"
 
-#: cp/cvt.c:1091
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "隐式提领不会访问作为逗号操作符右操作数的具有类型%qT的对象"
 
-#: cp/cvt.c:1096
+#: cp/cvt.c:1108
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "隐式提领不会访问作为逗号操作符左操作数的具有类型%qT的对象"
 
-#: cp/cvt.c:1101
+#: cp/cvt.c:1113
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "隐式提领不会访问语句中类型为%qT的对象"
 
-#: cp/cvt.c:1105
+#: cp/cvt.c:1117
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "隐式提领不会访问 for 循环增量表达式中具有类型%qT的对象"
 
-#: cp/cvt.c:1119
+#: cp/cvt.c:1131
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "向 void 的转换不会访问具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1124
+#: cp/cvt.c:1136
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "提领不会访问作为条件表达式第二个操作数的具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1129
+#: cp/cvt.c:1141
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "提领不会访问作为条件表达式第三个操作数的具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1134
+#: cp/cvt.c:1146
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "提领不会访问作为逗号操作符右操作数的具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1139
+#: cp/cvt.c:1151
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "提领不会访问作为逗号操作符左操作数的具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1144
+#: cp/cvt.c:1156
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "提领不会访问语句中具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1149
+#: cp/cvt.c:1161
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "提领不会访问 for 循环增量表达式中具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1187
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "向 void 的转换不会访问具有不完全类型%2$qT的对象%1$qE"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1203
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "条件表达式第二个操作数中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1196
+#: cp/cvt.c:1208
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "条件表达式第三个操作数中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1201
+#: cp/cvt.c:1213
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "逗号操作符的右操作数中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1206
+#: cp/cvt.c:1218
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "逗号操作符的左操作数中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1223
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "语句中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1227
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "for 循环增量表达式中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1264
+#: cp/cvt.c:1276
 #, fuzzy, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1280
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1272
+#: cp/cvt.c:1284
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1288
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1292
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1284
+#: cp/cvt.c:1296
 #, fuzzy, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1288
+#: cp/cvt.c:1300
 #, fuzzy, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1304
+#: cp/cvt.c:1316
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1309
+#: cp/cvt.c:1321
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1314
+#: cp/cvt.c:1326
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1319
+#: cp/cvt.c:1331
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1329
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1356
+#: cp/cvt.c:1368
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/cvt.c:1361
+#: cp/cvt.c:1373
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/cvt.c:1366
+#: cp/cvt.c:1378
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/cvt.c:1370
+#: cp/cvt.c:1382
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/cvt.c:1374
+#: cp/cvt.c:1386
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "语句不起作用"
 
-#: cp/cvt.c:1378
+#: cp/cvt.c:1390
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "for 循环増量表达式不起作用"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1547
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "将 NULL 转换为非指针类型"
 
-#: cp/cvt.c:1650
+#: cp/cvt.c:1662
 #, fuzzy, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "不能将模板参数从%qE转换到%qT"
 
-#: cp/cvt.c:1665
+#: cp/cvt.c:1677
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "%qT的默认类型转换有歧义"
 
-#: cp/cvt.c:1668
+#: cp/cvt.c:1680
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  备选转换包括%qD和%qD"
@@ -34842,243 +34888,243 @@
 msgid "template parameters do not match template %qD"
 msgstr "模板参数与模板不符"
 
-#: cp/decl.c:4354
+#: cp/decl.c:4358
 #, gcc-internal-format
 msgid "an anonymous struct cannot have function members"
 msgstr "匿名结构不能有函数成员"
 
-#: cp/decl.c:4357
+#: cp/decl.c:4361
 #, gcc-internal-format
 msgid "an anonymous union cannot have function members"
 msgstr "匿名联合不能有函数成员"
 
-#: cp/decl.c:4375
+#: cp/decl.c:4379
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "有构造函数的成员%q+#D不允许在匿名聚合中出现"
 
-#: cp/decl.c:4378
+#: cp/decl.c:4382
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "有构构函数的成员%q+#D不允许在匿名聚合中出现"
 
-#: cp/decl.c:4381
+#: cp/decl.c:4385
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "有拷贝赋值运算符的成员%q+#D不能用在联合中"
 
-#: cp/decl.c:4399
+#: cp/decl.c:4403
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "属性于%q+#T的声明中被忽略"
 
-#: cp/decl.c:4402
+#: cp/decl.c:4406
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T的属性必须跟在%qs关键字后面"
 
-#: cp/decl.c:4425
+#: cp/decl.c:4429
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一个声明指定了多个类型"
 
-#: cp/decl.c:4430
+#: cp/decl.c:4434
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "对 C++ 内建类型%qT的重声明"
 
-#: cp/decl.c:4447
+#: cp/decl.c:4451
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.c:4473
+#: cp/decl.c:4477
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef 声明中缺少类型名"
 
-#: cp/decl.c:4481
+#: cp/decl.c:4485
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ 不允许匿名结构"
 
-#: cp/decl.c:4488
+#: cp/decl.c:4492
 #, gcc-internal-format
 msgid "%qs can only be specified for functions"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.c:4494
+#: cp/decl.c:4498
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%>只能在类中指定"
 
-#: cp/decl.c:4496
+#: cp/decl.c:4500
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "只能为构造函数指定%<explicit%>"
 
-#: cp/decl.c:4498
+#: cp/decl.c:4502
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "只能为对象和函数指定存储类"
 
-#: cp/decl.c:4504
+#: cp/decl.c:4508
 #, gcc-internal-format
 msgid "qualifiers can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.c:4507
+#: cp/decl.c:4511
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "此声明中的%<typedef%>被忽略"
 
-#: cp/decl.c:4509
+#: cp/decl.c:4513
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%>不能被用作类型声明"
 
-#: cp/decl.c:4531
+#: cp/decl.c:4535
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "属性在模板实例化上被忽略"
 
-#: cp/decl.c:4534
+#: cp/decl.c:4538
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/decl.c:4606
+#: cp/decl.c:4610
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "忽略在定义之外为类类型%qT应用的属性"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4610
+#: cp/decl.c:4614
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "忽略在关联定义之外为依赖类类型%qT应用的属性"
 
-#: cp/decl.c:4679 cp/decl2.c:889
+#: cp/decl.c:4683 cp/decl2.c:889
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef%qD被初始化(改用 decltype)"
 
-#: cp/decl.c:4687
+#: cp/decl.c:4691
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D声明有%<extern%>并被初始化"
 
-#: cp/decl.c:4716
+#: cp/decl.c:4720
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "%q#D的定义被标记为 %<dllimport%>"
 
-#: cp/decl.c:4739
+#: cp/decl.c:4743
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D不是%qT的非静态数据成员"
 
-#: cp/decl.c:4748
+#: cp/decl.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D声明为模板"
 
-#: cp/decl.c:4749
+#: cp/decl.c:4753
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/decl.c:4762
+#: cp/decl.c:4766
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ 不允许将%<%T::%D%>定义为%<%T::%D%>"
 
-#: cp/decl.c:4774
+#: cp/decl.c:4778
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "ISO C++ 不允许成员%qD的初始化"
 
-#: cp/decl.c:4779
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "%qD declared %<constexpr%> outside its class"
 msgstr "%qD在其类外被声明为%<constexpr%>"
 
-#: cp/decl.c:4822
+#: cp/decl.c:4826
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "出现在类外的%q#D的声明不是定义"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4859
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4862
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F声明为%<static%>却从未定义过"
 
-#: cp/decl.c:4920
+#: cp/decl.c:4927
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "变量%q#D有初始值设定，但是类型不完全"
 
-#: cp/decl.c:4926 cp/decl.c:5789
+#: cp/decl.c:4933 cp/decl.c:5796
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "数组%q#D的元素类型不完全"
 
-#: cp/decl.c:4933 cp/decl.c:6409
+#: cp/decl.c:4940 cp/decl.c:6416
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D声明有缺少初始值设定"
 
-#: cp/decl.c:4935
+#: cp/decl.c:4942
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "聚合%q#D类型不完全，无法被定义"
 
-#: cp/decl.c:4969
+#: cp/decl.c:4976
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD声明为引用却未被初始化"
 
-#: cp/decl.c:5026
+#: cp/decl.c:5033
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "名字被用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.c:5032
+#: cp/decl.c:5039
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "名字%qD用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.c:5048 cp/typeck2.c:1253 cp/typeck2.c:1364
+#: cp/decl.c:5055 cp/typeck2.c:1273 cp/typeck2.c:1384
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "不平凡的代理初始值设定不受支持"
 
-#: cp/decl.c:5051
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "数组%qD的大小不是一个整数常表达式"
 
-#: cp/decl.c:5099
+#: cp/decl.c:5106
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初始值设定无法决定%qD的大小"
 
-#: cp/decl.c:5105
+#: cp/decl.c:5112
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD缺少数组大小"
 
-#: cp/decl.c:5116
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "大小为 0 的数组%qD"
@@ -35086,830 +35132,830 @@
 #. An automatic variable with an incomplete type: that is an error.
 #. Don't talk about array types here, since we took care of that
 #. message in grokdeclarator.
-#: cp/decl.c:5158
+#: cp/decl.c:5165
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "%qD的存储大小未知"
 
-#: cp/decl.c:5181
+#: cp/decl.c:5188
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "%qD的存储大小不是常量"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5234
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "对不起：内联函数中静态数据%q+#D的语义是错的(您会得到此变量的多份复制)"
 
-#: cp/decl.c:5231
+#: cp/decl.c:5238
 #, fuzzy, gcc-internal-format
 #| msgid "  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr " 变通的作法是删除初始值设定"
 
-#: cp/decl.c:5258
+#: cp/decl.c:5265
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "未初始化的常量%qD"
 
-#: cp/decl.c:5262
+#: cp/decl.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "成员%qD在%<constexpr%>构造函数里未初始化"
 
-#: cp/decl.c:5272
+#: cp/decl.c:5279
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T没有用户提供的默认构造函数"
 
-#: cp/decl.c:5276
+#: cp/decl.c:5283
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5278
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgstr ""
 
-#: cp/decl.c:5401
+#: cp/decl.c:5408
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "无效类型%qT被用作类型为%qT的向量的初始值设定"
 
-#: cp/decl.c:5442
+#: cp/decl.c:5449
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/decl.c:5468
+#: cp/decl.c:5475
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "名字%qD用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.c:5476
+#: cp/decl.c:5483
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT没有名为%qD的非静态数据成员"
 
-#: cp/decl.c:5496
+#: cp/decl.c:5503
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "成员函数%qD的初始值设定无效"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5533
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:5563 cp/decl.c:5768 cp/typeck2.c:1240 cp/typeck2.c:1450
-#: cp/typeck2.c:1479 cp/typeck2.c:1526
+#: cp/decl.c:5570 cp/decl.c:5775 cp/typeck2.c:1260 cp/typeck2.c:1470
+#: cp/typeck2.c:1499 cp/typeck2.c:1546
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT的初始值设定项太多"
 
-#: cp/decl.c:5602
+#: cp/decl.c:5609
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "类型%qT的标量初始化带花括号"
 
-#: cp/decl.c:5709
+#: cp/decl.c:5716
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT的初始值设定周围缺少花括号"
 
-#: cp/decl.c:5791
+#: cp/decl.c:5798
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "数组%q#T的元素类型不完全"
 
-#: cp/decl.c:5799
+#: cp/decl.c:5806
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "变长复合字面值"
 
-#: cp/decl.c:5853
+#: cp/decl.c:5860
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%qD类型不完全"
 
-#: cp/decl.c:5873
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "标量对象%qD在初始值设定中需要一个元素"
 
-#: cp/decl.c:5916
+#: cp/decl.c:5923
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "在 C++98 中%qD必须由构造函数而不是%<{...}%>初始化"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6017
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "数组%qD被有括号的字面字符串%qE所初始化"
 
-#: cp/decl.c:6041
+#: cp/decl.c:6048
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "构造函数中对静态成员的初始化无效"
 
-#: cp/decl.c:6043
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ 不允许在类内初始化非常量静态成员%qD"
 
-#: cp/decl.c:6048
+#: cp/decl.c:6055
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(需要一个类外的初始化)"
 
-#: cp/decl.c:6222
+#: cp/decl.c:6229
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "此函数中的%qD在使用前未初始化"
 
-#: cp/decl.c:6368
+#: cp/decl.c:6375
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/decl.c:6545
+#: cp/decl.c:6552
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "隐藏了早先的类型声明%q#D"
 
-#: cp/decl.c:6612
+#: cp/decl.c:6619
 #, gcc-internal-format
 msgid "Java object %qD not allocated with %<new%>"
 msgstr "Java 对象%qD并非由%<new%>所分配"
 
-#: cp/decl.c:6660
+#: cp/decl.c:6667
 #, gcc-internal-format
 msgid "non-static data member %qD has Java class type"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/decl.c:6741
+#: cp/decl.c:6748
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "函数%q#D像变量一样被初始化"
 
-#: cp/decl.c:7175
+#: cp/decl.c:7182
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:7178
+#: cp/decl.c:7185
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:7184
+#: cp/decl.c:7191
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:7418
+#: cp/decl.c:7425
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始值设定无法决定%qD的大小"
 
-#: cp/decl.c:7422
+#: cp/decl.c:7429
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "%qD缺少数组大小"
 
-#: cp/decl.c:7425
+#: cp/decl.c:7432
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "大小为 0 的数组%qD"
 
-#: cp/decl.c:7441
+#: cp/decl.c:7448
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的析构函数不能用作成员"
 
-#: cp/decl.c:7443
+#: cp/decl.c:7450
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的构造函数不能用作成员"
 
-#: cp/decl.c:7467
+#: cp/decl.c:7474
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD声明为%<virtual%>变量"
 
-#: cp/decl.c:7469
+#: cp/decl.c:7476
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> variable"
 msgstr "%qD声明为%<inline%>变量"
 
-#: cp/decl.c:7471
+#: cp/decl.c:7478
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:7476
+#: cp/decl.c:7483
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD声明为%<virtual%>参数"
 
-#: cp/decl.c:7478
+#: cp/decl.c:7485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD声明为%<inline%>参数"
 
-#: cp/decl.c:7480
+#: cp/decl.c:7487
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:7485
+#: cp/decl.c:7492
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD声明为%<virtual%>类型"
 
-#: cp/decl.c:7487
+#: cp/decl.c:7494
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD声明为%<inline%>类型"
 
-#: cp/decl.c:7489
+#: cp/decl.c:7496
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:7494
+#: cp/decl.c:7501
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD声明为%<virtual%>字段"
 
-#: cp/decl.c:7496
+#: cp/decl.c:7503
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD声明为%<inline%>字段"
 
-#: cp/decl.c:7498
+#: cp/decl.c:7505
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:7505
+#: cp/decl.c:7512
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D声明为友元"
 
-#: cp/decl.c:7511
+#: cp/decl.c:7518
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D声明时带有异常规范"
 
-#: cp/decl.c:7544
+#: cp/decl.c:7551
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD的定义不在包含%qT的命名空间中"
 
-#: cp/decl.c:7584
+#: cp/decl.c:7591
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "静态成员函数%q#D的声明带有类型限定符"
 
-#: cp/decl.c:7703
+#: cp/decl.c:7710
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "在友元声明中定义显式特例化%qD"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:7713
+#: cp/decl.c:7720
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "在基本模板的声明中对模板标识符%qD的使用无效"
 
-#: cp/decl.c:7731
+#: cp/decl.c:7738
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "友元模板特例化%qD中不允许出现默认参数"
 
-#: cp/decl.c:7738
+#: cp/decl.c:7745
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%>不允许用于友元模板特例化%qD的声明"
 
-#: cp/decl.c:7742
+#: cp/decl.c:7749
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%>不允许用于友元模板特例化%qD的声明"
 
-#: cp/decl.c:7789
+#: cp/decl.c:7796
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "不能将%<::main%>声明为一个模板"
 
-#: cp/decl.c:7791
+#: cp/decl.c:7798
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "不能将%<::main%>声明为 inline"
 
-#: cp/decl.c:7793
+#: cp/decl.c:7800
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be constexpr"
 msgstr "不能将%<::main%>声明为 inline"
 
-#: cp/decl.c:7795
+#: cp/decl.c:7802
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "不能将%<::main%>声明为 static"
 
-#: cp/decl.c:7839
+#: cp/decl.c:7846
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:7840
+#: cp/decl.c:7847
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:7848
+#: cp/decl.c:7855
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:7849
+#: cp/decl.c:7856
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:7866
+#: cp/decl.c:7873
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "模板有 C 链接"
 
-#: cp/decl.c:7875
+#: cp/decl.c:7882
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "-fdebug-prefix-map 的参数%qs无效"
 
-#: cp/decl.c:7883
+#: cp/decl.c:7890
 #, gcc-internal-format
 msgid "integer suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7889
+#: cp/decl.c:7896
 #, gcc-internal-format
 msgid "floating point suffix %<%s%> shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:7895
+#: cp/decl.c:7902
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.c:7973
+#: cp/decl.c:7980
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%>必须返回%<int%>"
 
-#: cp/decl.c:8015
+#: cp/decl.c:8022
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "隐式声明的%qD的定义"
 
-#: cp/decl.c:8020
+#: cp/decl.c:8027
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "隐式声明的%qD的定义"
 
-#: cp/decl.c:8021
+#: cp/decl.c:8028
 #, fuzzy, gcc-internal-format
 msgid "%q+#D explicitly defaulted here"
 msgstr "%q+#D已在此定义过"
 
-#: cp/decl.c:8038 cp/decl2.c:787
+#: cp/decl.c:8045 cp/decl2.c:787
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "成员函数%q#D未在类%qT中声明"
 
-#: cp/decl.c:8317
+#: cp/decl.c:8324
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:8321
+#: cp/decl.c:8328
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:8324
+#: cp/decl.c:8331
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:8337
+#: cp/decl.c:8344
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:8343
+#: cp/decl.c:8350
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ 不允许在类内初始化非常量静态成员%qD"
 
-#: cp/decl.c:8347
+#: cp/decl.c:8354
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ 不允许初始化成员常量%qD，因为它有非整数的类型%qT"
 
-#: cp/decl.c:8451 cp/decl.c:8478
+#: cp/decl.c:8458 cp/decl.c:8485
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "数组%qD的大小具有非整数类型%qT"
 
-#: cp/decl.c:8454 cp/decl.c:8480
+#: cp/decl.c:8461 cp/decl.c:8487
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "数组%qT的大小的类型不是整数"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "数组%qD的大小为负"
 
-#: cp/decl.c:8521
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "数组大小为负数"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C 不允许大小为 0 的数组%qD"
 
-#: cp/decl.c:8537
+#: cp/decl.c:8544
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ 不允许大小为 0 的数组"
 
-#: cp/decl.c:8550
+#: cp/decl.c:8557
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "数组%qD的大小不是一个整数常表达式"
 
-#: cp/decl.c:8553
+#: cp/decl.c:8560
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: cp/decl.c:8559
+#: cp/decl.c:8566
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ 不允许变长数组%qD"
 
-#: cp/decl.c:8561
+#: cp/decl.c:8568
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ 不允许变长数组"
 
-#: cp/decl.c:8567
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "使用了变长数组%qD"
 
-#: cp/decl.c:8570
+#: cp/decl.c:8577
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "使用了变长数组"
 
-#: cp/decl.c:8633
+#: cp/decl.c:8640
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "数组维数溢出"
 
-#: cp/decl.c:8686
+#: cp/decl.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D声明为友元"
 
-#: cp/decl.c:8696
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qD声明为 void 的数组"
 
-#: cp/decl.c:8698
+#: cp/decl.c:8705
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "创建 void 数组"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8710
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qD声明为函数的数组"
 
-#: cp/decl.c:8705
+#: cp/decl.c:8712
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "创建函数的数组"
 
-#: cp/decl.c:8710
+#: cp/decl.c:8717
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qD声明为引用的数组"
 
-#: cp/decl.c:8712
+#: cp/decl.c:8719
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "创建引用的数组"
 
-#: cp/decl.c:8717
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qD声明为函数成员的数组"
 
-#: cp/decl.c:8719
+#: cp/decl.c:8726
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "创建函数成员的组织"
 
-#: cp/decl.c:8733
+#: cp/decl.c:8740
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多维数组%qD的声明必须至少指定除第一维以外所有维的大小"
 
-#: cp/decl.c:8737
+#: cp/decl.c:8744
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "声明多维数组必须至少指定除第一维以外所有维的大小"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8779
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "为构造函数指定返回值无效"
 
-#: cp/decl.c:8782
+#: cp/decl.c:8789
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "指定析构函数的返回类型无效"
 
-#: cp/decl.c:8795
+#: cp/decl.c:8802
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "为%<operator %T%>指定了返回值"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8824
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "无名变量或字段声明为 void"
 
-#: cp/decl.c:8824
+#: cp/decl.c:8831
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "变量或字段声明为 void"
 
-#: cp/decl.c:9014
+#: cp/decl.c:9021
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "对限定名%<::%D%>的使用无效"
 
-#: cp/decl.c:9017 cp/decl.c:9037
+#: cp/decl.c:9024 cp/decl.c:9044
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "对限定名%<%T::%D%>的使用无效"
 
-#: cp/decl.c:9020
+#: cp/decl.c:9027
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "对限定名%<%D::%D%>的使用无效"
 
-#: cp/decl.c:9029
+#: cp/decl.c:9036
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T 不是一个类或命名空间"
 
-#: cp/decl.c:9053 cp/decl.c:9150 cp/decl.c:9159 cp/decl.c:10562
+#: cp/decl.c:9060 cp/decl.c:9157 cp/decl.c:9166 cp/decl.c:10569
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.c:9059
+#: cp/decl.c:9066
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "%qD未声明为成员"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9102
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "缺少声明标识符：使用了保留字%qD"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "函数定义未声明形参"
 
-#: cp/decl.c:9167
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "%<typedef%>的模板声明"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9179
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: cp/decl.c:9205
+#: cp/decl.c:9212
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%>不能被用于 typedef 声明"
 
-#: cp/decl.c:9213
+#: cp/decl.c:9220
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs的声明指定了两个以上的数据类型"
 
-#: cp/decl.c:9219
+#: cp/decl.c:9226
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "%qs的声明中有相互冲突的限定符"
 
-#: cp/decl.c:9260
+#: cp/decl.c:9267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支持单独用%<complex%>表示%<double complex%>"
 
-#: cp/decl.c:9303 cp/decl.c:9306 cp/decl.c:9309
+#: cp/decl.c:9310 cp/decl.c:9313 cp/decl.c:9316
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ 不允许声明无类型的%qs"
 
-#: cp/decl.c:9320
+#: cp/decl.c:9327
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int128%>不为此目标所支持"
 
-#: cp/decl.c:9326
+#: cp/decl.c:9333
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 对%qs不支持%<__int128%>"
 
-#: cp/decl.c:9348 cp/decl.c:9368
+#: cp/decl.c:9355 cp/decl.c:9375
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "为%qs使用%<signed%>或%<unsigned%>无效"
 
-#: cp/decl.c:9350
+#: cp/decl.c:9357
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "为%qs同时给定了%<signed%>和%<unsigned%>"
 
-#: cp/decl.c:9352
+#: cp/decl.c:9359
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%>对%qs无效"
 
-#: cp/decl.c:9354
+#: cp/decl.c:9361
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%>对%qs无效"
 
-#: cp/decl.c:9356
+#: cp/decl.c:9363
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%>对%qs无效"
 
-#: cp/decl.c:9358
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%>或%<short%>对%qs无效"
 
-#: cp/decl.c:9360
+#: cp/decl.c:9367
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>、%<int%>、%<short%>或%<char%>对%qs无效"
 
-#: cp/decl.c:9362
+#: cp/decl.c:9369
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "为 char%qs给定了%<long%>或%<short%>"
 
-#: cp/decl.c:9364
+#: cp/decl.c:9371
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "为%qs同时给定了%<long%>和%<short%>"
 
-#: cp/decl.c:9370
+#: cp/decl.c:9377
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<long%>或%<short%>对%qs无效"
 
-#: cp/decl.c:9378
+#: cp/decl.c:9385
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "为%qs使用 long、short、signed 或 unsigned 无效"
 
-#: cp/decl.c:9446
+#: cp/decl.c:9453
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "对%qs而言无效的复数"
 
-#: cp/decl.c:9469
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.c:9502
+#: cp/decl.c:9509
 #, gcc-internal-format
 msgid "member %qD cannot be declared both virtual and static"
 msgstr "成员%qD不能既被声明为虚函数，又被声明为静态函数"
 
-#: cp/decl.c:9513
+#: cp/decl.c:9520
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "形参声明中出现的 typedef 声明无效"
 
-#: cp/decl.c:9518
+#: cp/decl.c:9525
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "为模板参数%qs指定了存储类"
 
-#: cp/decl.c:9524
+#: cp/decl.c:9531
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "为形参声明指定了无效的存储类"
 
-#: cp/decl.c:9530
+#: cp/decl.c:9537
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "形参不能被声明为%<constexpr%>"
 
-#: cp/decl.c:9539
+#: cp/decl.c:9546
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%>用在类声明以外"
 
-#: cp/decl.c:9557
+#: cp/decl.c:9564
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs的声明指定了多个存储类"
 
-#: cp/decl.c:9580
+#: cp/decl.c:9587
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "为%qs指定了存储类"
 
-#: cp/decl.c:9584
+#: cp/decl.c:9591
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "为形参%qs指定了存储类"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9604
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "嵌套函数%qs被声明为%<extern%>"
 
-#: cp/decl.c:9601
+#: cp/decl.c:9608
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "在文件层将%qs声明为%<auto%>"
 
-#: cp/decl.c:9608
+#: cp/decl.c:9615
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "函数作用域的%qs隐式为 auto，却被声明为%<__thread%>"
 
-#: cp/decl.c:9620
+#: cp/decl.c:9627
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "为友元函数声明指定了无效的存储类"
 
-#: cp/decl.c:9729
+#: cp/decl.c:9736
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs声明为返回一个函数的函数"
 
-#: cp/decl.c:9734
+#: cp/decl.c:9741
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs声明为返回一个数组的函数"
 
-#: cp/decl.c:9771
+#: cp/decl.c:9778
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs函数使用了%<auto%>类型限定却没有迟返回类型"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9781
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:9780
+#: cp/decl.c:9787
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:9787
+#: cp/decl.c:9794
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs函数使用迟返回类型%qT作为它的类型，而不是%<auto%>"
@@ -35916,474 +35962,474 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:9798
+#: cp/decl.c:9805
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9808
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs函数使用了迟返回类型却未用%<auto%>类型限定声明"
 
-#: cp/decl.c:9838
+#: cp/decl.c:9845
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:9839
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:9843
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:9844
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:9852
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:9870
+#: cp/decl.c:9877
 #, gcc-internal-format
 msgid "constructors cannot be declared virtual"
 msgstr "构造函数不能被声明为虚函数"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:9885
+#: cp/decl.c:9892
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:9889
+#: cp/decl.c:9896
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "友元声明不在类定义内"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9898
 #, fuzzy, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "局部类定义中不能定义友元函数%qs"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9919
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "析构函数不能有参数"
 
-#: cp/decl.c:9938
+#: cp/decl.c:9945
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "无法声明指向%q#T的指针"
 
-#: cp/decl.c:9951 cp/decl.c:9958
+#: cp/decl.c:9958 cp/decl.c:9965
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "无法声明对%q#T的引用"
 
-#: cp/decl.c:9960
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "无法声明指向%q#T成员的指针"
 
-#: cp/decl.c:9989
+#: cp/decl.c:9996
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/decl.c:9990
+#: cp/decl.c:9997
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/decl.c:10060
+#: cp/decl.c:10067
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "无法声明对%q#T的引用，因为它不是 typedef 或者模板类型实参"
 
-#: cp/decl.c:10130
+#: cp/decl.c:10137
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "模板标识符%qD用作声明"
 
-#: cp/decl.c:10154
+#: cp/decl.c:10161
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成员函数隐式地成为所属类的友元"
 
-#: cp/decl.c:10159
+#: cp/decl.c:10166
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多余的限定%<%T::%>在成员%qs上"
 
-#: cp/decl.c:10189
+#: cp/decl.c:10196
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgstr "无法定义成员函数%<%T::%s%>，在%<%T%>中"
 
-#: cp/decl.c:10191
+#: cp/decl.c:10198
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgstr "无法定义成员函数%<%T::%s%>，在%<%T%>中"
 
-#: cp/decl.c:10199
+#: cp/decl.c:10206
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "无法声明成员%<%T::%s%>，在%qT中"
 
-#: cp/decl.c:10232
+#: cp/decl.c:10239
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非形参%qs不能是一个参数包"
 
-#: cp/decl.c:10242
+#: cp/decl.c:10249
 #, gcc-internal-format
 msgid "size of array %qs is too large"
 msgstr "数组%qs太大"
 
-#: cp/decl.c:10253
+#: cp/decl.c:10260
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "数据成员不能具有可变类型%qT"
 
-#: cp/decl.c:10255
+#: cp/decl.c:10262
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "参数不能具有可变类型%qT"
 
-#: cp/decl.c:10265
+#: cp/decl.c:10272
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%>用在类声明以外"
 
-#: cp/decl.c:10267
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%>用于空声明中"
 
-#: cp/decl.c:10269
+#: cp/decl.c:10276
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有构造函数才能被声明为%<explicit%>"
 
-#: cp/decl.c:10278
+#: cp/decl.c:10285
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10290
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非对象成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:10289
+#: cp/decl.c:10296
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函数%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:10294
+#: cp/decl.c:10301
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "静态%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:10299
+#: cp/decl.c:10306
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "常量%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:10304
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "函数%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:10340
+#: cp/decl.c:10347
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.c:10350
+#: cp/decl.c:10357
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允许嵌类的类型%qD与其所属的类重名"
 
-#: cp/decl.c:10490
+#: cp/decl.c:10497
 #, gcc-internal-format
 msgid "type qualifiers specified for friend class declaration"
 msgstr "为友元类声明指定了类型限定"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10502
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "友元函数声明中出现了%<inline%>"
 
-#: cp/decl.c:10503
+#: cp/decl.c:10510
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "模板参数不能是友元"
 
-#: cp/decl.c:10505
+#: cp/decl.c:10512
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "友元声明需要 class，即%<friend class %T::%D%>"
 
-#: cp/decl.c:10509
+#: cp/decl.c:10516
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "友元声明需要 class，即%<friend %#T%>"
 
-#: cp/decl.c:10522
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "试图让%qT成为全局域的友元"
 
-#: cp/decl.c:10542
+#: cp/decl.c:10549
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成员函数类型上的限定符无效"
 
-#: cp/decl.c:10552
+#: cp/decl.c:10559
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象声明%qT被用作声明"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10588
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在参数声明中使用%<::%>"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10593
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%>不能用在此上下文中"
 
-#: cp/decl.c:10588
+#: cp/decl.c:10595
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.c:10634
+#: cp/decl.c:10641
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared %<auto%>"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:10656
+#: cp/decl.c:10663
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "错误地使用了%<::%>"
 
-#: cp/decl.c:10678
+#: cp/decl.c:10685
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%qD的声明中类名无效"
 
-#: cp/decl.c:10687
+#: cp/decl.c:10694
 #, gcc-internal-format
 msgid "function %qD declared virtual inside a union"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: cp/decl.c:10696
+#: cp/decl.c:10703
 #, gcc-internal-format
 msgid "%qD cannot be declared virtual, since it is always static"
 msgstr "%qD不能声明为虚函数，因为它总是静态的"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10719
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在析构函数%qD中的友元声明需要限定名"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10726
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/decl.c:10725
+#: cp/decl.c:10732
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:10731
+#: cp/decl.c:10738
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "在构造函数%qD中的友元声明需要限定名"
 
-#: cp/decl.c:10742
+#: cp/decl.c:10749
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "模板声明%q#D"
 
-#: cp/decl.c:10745
+#: cp/decl.c:10752
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%qD 在此声明"
 
-#: cp/decl.c:10797
+#: cp/decl.c:10804
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "字段%qD类型不完全"
 
-#: cp/decl.c:10802
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名字%qT类型不完全"
 
-#: cp/decl.c:10811
+#: cp/decl.c:10818
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE既不是函数也不是成员函数；不能声明为友元"
 
-#: cp/decl.c:10870
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 msgid "constexpr static data member %qD must have an initializer"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10886
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10936
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函数%qs的存储类%<auto%>无效"
 
-#: cp/decl.c:10931
+#: cp/decl.c:10938
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函数%qs的存储类%<register%>无效"
 
-#: cp/decl.c:10935
+#: cp/decl.c:10942
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:10938
+#: cp/decl.c:10945
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:10943
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: cp/decl.c:10954
+#: cp/decl.c:10961
 #, gcc-internal-format
 msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<static%>无效"
 
-#: cp/decl.c:10958
+#: cp/decl.c:10965
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<inline%>无效"
 
-#: cp/decl.c:10966
+#: cp/decl.c:10973
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虚函数%qs不是类成员"
 
-#: cp/decl.c:10973
+#: cp/decl.c:10980
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.c:10974
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.c:11005
+#: cp/decl.c:11012
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能将成员函数%qD声明为有静态链接"
 
 #. FIXME need arm citation
-#: cp/decl.c:11012
+#: cp/decl.c:11019
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一个函数中声明一个静态函数"
 
-#: cp/decl.c:11046
+#: cp/decl.c:11053
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "与声明不同，定义静态数据成员时不能使用%<static%>"
 
-#: cp/decl.c:11053
+#: cp/decl.c:11060
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "静态成员%qD声明为%<register%>"
 
-#: cp/decl.c:11059
+#: cp/decl.c:11066
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能显式地将成员%q#D声明为有外部链接"
 
-#: cp/decl.c:11066
+#: cp/decl.c:11073
 #, gcc-internal-format
 msgid "declaration of constexpr variable %qD is not a definition"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.c:11079
+#: cp/decl.c:11086
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs已初始化，却又被声明为%<extern%>"
 
-#: cp/decl.c:11083
+#: cp/decl.c:11090
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs既有%<extern%>又有初始值设定"
 
-#: cp/decl.c:11230
+#: cp/decl.c:11237
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.c:11233
+#: cp/decl.c:11240
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.c:11314
+#: cp/decl.c:11321
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C 不允许前向参数声明"
 
-#: cp/decl.c:11318
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "不能在参数声明中使用%<::%>"
 
-#: cp/decl.c:11331
+#: cp/decl.c:11338
 #, gcc-internal-format
 msgid "parameter %qD has Java class type"
 msgstr "形参%qD具有 Java 类类型"
 
-#: cp/decl.c:11359
+#: cp/decl.c:11366
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "形参%qD被无效地被声明为具有方法类型"
 
-#: cp/decl.c:11384
+#: cp/decl.c:11391
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的指针"
 
-#: cp/decl.c:11386
+#: cp/decl.c:11393
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的引用"
@@ -36403,173 +36449,173 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:11636
+#: cp/decl.c:11643
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "无效的构造函数：您要的可能是%<%T (const %T&)%>"
 
-#: cp/decl.c:11758
+#: cp/decl.c:11765
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD不能在命名空间声明"
 
-#: cp/decl.c:11763
+#: cp/decl.c:11770
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD不能被声明为静态的"
 
-#: cp/decl.c:11772
+#: cp/decl.c:11779
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/decl.c:11799
+#: cp/decl.c:11806
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.c:11808
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD必须是一个非静态成员函数或非成员函数"
 
-#: cp/decl.c:11830
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD的实参必须有类或枚举类型"
 
-#: cp/decl.c:11859
+#: cp/decl.c:11866
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "向指向 void 的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:11861
+#: cp/decl.c:11868
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "向 void 的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11875
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "向具有相同类型的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:11870
+#: cp/decl.c:11877
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "向相同类型的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:11878
+#: cp/decl.c:11885
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "向指向基类的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:11880
+#: cp/decl.c:11887
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "向基类的转换永远不会用到类型转换运算符"
 
 #. 13.4.0.3
-#: cp/decl.c:11889
+#: cp/decl.c:11896
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ 不允许重载 ?: 运算符"
 
-#: cp/decl.c:11894
+#: cp/decl.c:11901
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD不能带可变数量的实参"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11952
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its argument"
 msgstr "后缀%qD必须使用%<int%>作为它的参数"
 
-#: cp/decl.c:11948
+#: cp/decl.c:11955
 #, gcc-internal-format
 msgid "postfix %qD must take %<int%> as its second argument"
 msgstr "后缀%qD必须使用%<int%>作为它的第二个参数"
 
-#: cp/decl.c:11956
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "%qD must take either zero or one argument"
 msgstr "%qD必须带 0 或 1 个实参"
 
-#: cp/decl.c:11958
+#: cp/decl.c:11965
 #, gcc-internal-format
 msgid "%qD must take either one or two arguments"
 msgstr "%qD必须带 1 或 2 个实参"
 
-#: cp/decl.c:11980
+#: cp/decl.c:11987
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "前缀%qD应当返回%qT"
 
-#: cp/decl.c:11986
+#: cp/decl.c:11993
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "后缀%qD应当返回%qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12002
 #, gcc-internal-format
 msgid "%qD must take %<void%>"
 msgstr "%qD必须有%<void%>类型"
 
-#: cp/decl.c:11997 cp/decl.c:12006
+#: cp/decl.c:12004 cp/decl.c:12013
 #, gcc-internal-format
 msgid "%qD must take exactly one argument"
 msgstr "%qD带且仅带 1 个实参"
 
-#: cp/decl.c:12008
+#: cp/decl.c:12015
 #, gcc-internal-format
 msgid "%qD must take exactly two arguments"
 msgstr "%qD带且仅带 2 个实参"
 
-#: cp/decl.c:12017
+#: cp/decl.c:12024
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: cp/decl.c:12031
+#: cp/decl.c:12038
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD应当返回值而非引用"
 
-#: cp/decl.c:12042 cp/decl.c:12047
+#: cp/decl.c:12049 cp/decl.c:12054
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD不能有默认参数"
 
-#: cp/decl.c:12105
+#: cp/decl.c:12112
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用模板类型形参%qT，在%qs后"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12135
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12138
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名%qD，在%qs后"
 
-#: cp/decl.c:12133
+#: cp/decl.c:12140
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+D先前在此处有过声明"
 
-#: cp/decl.c:12141
+#: cp/decl.c:12148
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT作为%qs被引用"
 
-#: cp/decl.c:12142 cp/decl.c:12149
+#: cp/decl.c:12149 cp/decl.c:12156
 #, gcc-internal-format
 msgid "%q+T has a previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:12148
+#: cp/decl.c:12155
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT作为枚举被引用"
@@ -36581,88 +36627,88 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:12163
+#: cp/decl.c:12170
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%>需要模板参数"
 
-#: cp/decl.c:12217 cp/name-lookup.c:3202
+#: cp/decl.c:12224 cp/name-lookup.c:3202
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD与其声明所在的类重名"
 
-#: cp/decl.c:12247 cp/name-lookup.c:2692 cp/name-lookup.c:3530
-#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22944
+#: cp/decl.c:12254 cp/name-lookup.c:2692 cp/name-lookup.c:3530
+#: cp/name-lookup.c:3575 cp/parser.c:5513 cp/parser.c:22982
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/decl.c:12368
+#: cp/decl.c:12375
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用枚举%q#D前没有给出声明"
 
-#: cp/decl.c:12393
+#: cp/decl.c:12400
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT重声明为非模板"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12401
 #, gcc-internal-format
 msgid "previous declaration %q+D"
 msgstr "先前的声明%q+D"
 
-#: cp/decl.c:12535
+#: cp/decl.c:12542
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "派生联合%qT无效"
 
-#: cp/decl.c:12544
+#: cp/decl.c:12551
 #, gcc-internal-format
 msgid "Java class %qT cannot have multiple bases"
 msgstr "Java 类%qT不能有多个基类"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12562
 #, gcc-internal-format
 msgid "Java class %qT cannot have virtual bases"
 msgstr "Java 类%qT不能有虚基类"
 
-#: cp/decl.c:12575
+#: cp/decl.c:12582
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基类型%qT不是结构或类"
 
-#: cp/decl.c:12608
+#: cp/decl.c:12615
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "递归的类型%qT未定义"
 
-#: cp/decl.c:12610
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重复的基类型%qT无效"
 
-#: cp/decl.c:12734
+#: cp/decl.c:12741
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12737 cp/decl.c:12745 cp/decl.c:12757 cp/parser.c:15963
+#: cp/decl.c:12744 cp/decl.c:12752 cp/decl.c:12764 cp/parser.c:15987
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "先前的定义在这里"
 
-#: cp/decl.c:12742
+#: cp/decl.c:12749
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "条件表达式中类型不匹配"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12761
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:12821
+#: cp/decl.c:12828
 #, gcc-internal-format
 msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgstr "%<%2$T%>的内在类型%<%1$T%>必须是整型"
@@ -36671,87 +36717,87 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:12955
+#: cp/decl.c:12962
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "没有一个整数类型可以表示%qT的所有枚举值"
 
-#: cp/decl.c:13117
+#: cp/decl.c:13124
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/decl.c:13164
+#: cp/decl.c:13171
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: cp/decl.c:13176
+#: cp/decl.c:13183
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD处枚举值溢出"
 
-#: cp/decl.c:13196
+#: cp/decl.c:13203
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %E is outside the range of underlying type %<%T%>"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/decl.c:13286
+#: cp/decl.c:13293
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "返回值类型%q#T不完全"
 
-#: cp/decl.c:13288
+#: cp/decl.c:13295
 #, gcc-internal-format
 msgid "return type has Java class type %q#T"
 msgstr "返回类型具有 Java 类类型%q#T"
 
-#: cp/decl.c:13412 cp/typeck.c:8614
+#: cp/decl.c:13419 cp/typeck.c:8605
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>应当返回一个对%<*this%>的引用"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13519
 #, gcc-internal-format
 msgid "no previous declaration for %q+D"
 msgstr "%q+D先前没有声明过"
 
-#: cp/decl.c:13736
+#: cp/decl.c:13743
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "无效的函数声明"
 
-#: cp/decl.c:13818
+#: cp/decl.c:13825
 #, gcc-internal-format
 msgid "parameter %qD declared void"
 msgstr "形参%qD被声明为 void"
 
-#: cp/decl.c:14208
+#: cp/decl.c:14215
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在有返回值的函数中未发现 return 语句"
 
-#: cp/decl.c:14210 cp/typeck.c:8497
+#: cp/decl.c:14217 cp/typeck.c:8488
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由于%<volatile%>，函数返回类型不兼容"
 
-#: cp/decl.c:14308
+#: cp/decl.c:14315
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D set but not used"
 msgstr "形参%qD被设定但未被使用"
 
-#: cp/decl.c:14404
+#: cp/decl.c:14411
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "无效的成员函数声明"
 
-#: cp/decl.c:14418
+#: cp/decl.c:14425
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD已在类%qT中定义过"
 
-#: cp/decl.c:14785 cp/decl2.c:4986 cp/decl2.c:5044
+#: cp/decl.c:14792 cp/decl2.c:4990 cp/decl2.c:5047
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%qD的类型默认为%<int%>"
@@ -36791,7 +36837,7 @@
 msgid "deleting %qT is undefined"
 msgstr "删除%qT未定义"
 
-#: cp/decl2.c:545 cp/pt.c:4835
+#: cp/decl2.c:545 cp/pt.c:4843
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D声明为模板"
@@ -36814,7 +36860,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:678 cp/pt.c:4805
+#: cp/decl2.c:678 cp/pt.c:4813
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "析构函数%qD被声明为一个成员模板"
@@ -36906,27 +36952,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "位段%qD非整型"
 
-#: cp/decl2.c:1449
+#: cp/decl2.c:1453
 #, fuzzy, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD不是类模板的非静态数据成员"
 
-#: cp/decl2.c:1518
+#: cp/decl2.c:1522
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "匿名结构不在有名类型内"
 
-#: cp/decl2.c:1606
+#: cp/decl2.c:1610
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "命名空间域的匿名聚合必须是静态的"
 
-#: cp/decl2.c:1615
+#: cp/decl2.c:1619
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "匿名联合没有成员"
 
-#: cp/decl2.c:1648
+#: cp/decl2.c:1652
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%>必须返回%qT"
@@ -36935,47 +36981,47 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1659
+#: cp/decl2.c:1663
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "%<operator new%>的第一个形参不能有默认参数"
 
-#: cp/decl2.c:1675
+#: cp/decl2.c:1679
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%>的第一个形参类型为%<size_t%>(%qT)"
 
-#: cp/decl2.c:1704
+#: cp/decl2.c:1708
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%>必须返回%qT"
 
-#: cp/decl2.c:1713
+#: cp/decl2.c:1717
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%>的第一个形参类型为%qT"
 
-#: cp/decl2.c:2555
+#: cp/decl2.c:2559
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2566
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT被声明为比其字段%qD的类型有更高的可见性"
 
-#: cp/decl2.c:2575
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
-#: cp/decl2.c:2581
+#: cp/decl2.c:2585
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT被声明为比其基类%qT有更高的可见性"
 
-#: cp/decl2.c:4209
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using anonymous type, is used but never defined"
 msgid "%q#D, declared using anonymous type, is used but never defined"
@@ -36985,49 +37031,49 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4218
+#: cp/decl2.c:4222
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4222
+#: cp/decl2.c:4226
 #, gcc-internal-format
 msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4226
+#: cp/decl2.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D未指明非限定类型，所以它不被用作外部链接"
 
-#: cp/decl2.c:4231
+#: cp/decl2.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using local type %qT, is used but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D声明为具有局部类型%qT，在使用前未被定义"
 
-#: cp/decl2.c:4234
+#: cp/decl2.c:4238
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "constexpr 变量%2$qD的类型%1$qT不是字面常量"
 
-#: cp/decl2.c:4237
+#: cp/decl2.c:4241
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%q+#D的早先声明有%qL链接"
 
-#: cp/decl2.c:4358 cp/decl2.c:4361
+#: cp/decl2.c:4362 cp/decl2.c:4365
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4696
+#: cp/decl2.c:4700
 #, gcc-internal-format
 msgid "inline function %q+D used but never defined"
 msgstr "使用了内联函数%q+D但从未定义过"
 
-#: cp/decl2.c:4894
+#: cp/decl2.c:4898
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "%2$q+#D的第 %1$P 个形参缺少默认实参"
@@ -37034,12 +37080,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:4958
+#: cp/decl2.c:4962
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr "将使用了%<...%>的 Lambda 转换为函数指针"
 
-#: cp/decl2.c:4965
+#: cp/decl2.c:4969
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用了被删除的函数%qD"
@@ -37617,42 +37663,42 @@
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "析构函数和类特定的 delete 运算符均不会被调用，即使它们在类定义时已经声明。"
 
-#: cp/init.c:3671
+#: cp/init.c:3682
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初始值设定在完成之前结束"
 
-#: cp/init.c:3757
+#: cp/init.c:3768
 #, gcc-internal-format
 msgid "cannot initialize multi-dimensional array with initializer"
 msgstr "不能用初始值设定项来初始化多维数组"
 
-#: cp/init.c:3964
+#: cp/init.c:3975
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete 时数组大小未知"
 
-#: cp/init.c:3988
+#: cp/init.c:3999
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "检测到调用 delete 运算符时可能出现的问题："
 
-#: cp/init.c:3993
+#: cp/init.c:4004
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "析构函数和类特定的 delete 运算符均不会被调用，即使它们在类定义时已经声明。"
 
-#: cp/init.c:4008
+#: cp/init.c:4019
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4013
+#: cp/init.c:4024
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgstr ""
 
-#: cp/init.c:4310
+#: cp/init.c:4321
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "向量 delete 的实参类型既非指针也非数组"
@@ -37783,18 +37829,18 @@
 msgid "string literal in function template signature"
 msgstr "函数模板签名里有字面字符串"
 
-#: cp/mangle.c:3530
+#: cp/mangle.c:3557
 #, fuzzy, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=4 (or =0) 可以改变向量修饰来避免这个错误"
 
-#: cp/mangle.c:3546
+#: cp/mangle.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/mangle.c:3551
+#: cp/mangle.c:3579
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %q+D changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
@@ -38210,7 +38256,7 @@
 msgid "identifier %qE is a keyword in C++11"
 msgstr "标志符%qE将会成为 C++0x 的一个关键字"
 
-#: cp/parser.c:1313 cp/parser.c:31853
+#: cp/parser.c:1313 cp/parser.c:31888
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -38235,7 +38281,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "在非类类型%2$qT中请求成员%1$qE"
 
-#: cp/parser.c:2645 cp/parser.c:15919
+#: cp/parser.c:2645 cp/parser.c:15943
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%>尚未声明"
@@ -38300,7 +38346,7 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(%qT的定义末尾可能缺少一个分号)"
 
-#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7598
+#: cp/parser.c:2790 cp/parser.c:5562 cp/pt.c:7654
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT不是一个模板"
@@ -38325,7 +38371,7 @@
 msgid "floating-point literal cannot appear in a constant-expression"
 msgstr "浮点字面值不能出现在常量表达式中"
 
-#: cp/parser.c:2836 cp/pt.c:14659
+#: cp/parser.c:2836 cp/pt.c:14791
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "常量表达式中不能出现目标不是整型或枚举型的类型转换"
@@ -38593,7 +38639,7 @@
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5249 cp/parser.c:17785
+#: cp/parser.c:5249 cp/parser.c:17809
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "需要模板 ID"
@@ -38769,7 +38815,7 @@
 msgid "capture of non-variable %qD "
 msgstr "令只读变量%qD自增"
 
-#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3195 cp/semantics.c:3205
+#: cp/parser.c:9270 cp/parser.c:9279 cp/semantics.c:3201 cp/semantics.c:3211
 #, fuzzy, gcc-internal-format
 msgid "%q+#D declared here"
 msgstr "%q+D已在此声明过"
@@ -38829,7 +38875,7 @@
 msgid "compound-statement in constexpr function"
 msgstr "%qD不是一个广义常函数"
 
-#: cp/parser.c:10273 cp/parser.c:24888
+#: cp/parser.c:10273 cp/parser.c:24926
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "需要选择语句"
@@ -38859,7 +38905,7 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/parser.c:10891 cp/parser.c:24891
+#: cp/parser.c:10891 cp/parser.c:24929
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "需要循环语句"
@@ -38890,12 +38936,12 @@
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允许计算转移"
 
-#: cp/parser.c:11107 cp/parser.c:24894
+#: cp/parser.c:11107 cp/parser.c:24932
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "需要跳转语句"
 
-#: cp/parser.c:11236 cp/parser.c:20822
+#: cp/parser.c:11236 cp/parser.c:20846
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "多余的%<;%>"
@@ -38942,7 +38988,7 @@
 msgid "class definition may not be declared a friend"
 msgstr "类定义不能被声明为友元"
 
-#: cp/parser.c:12091 cp/parser.c:21228
+#: cp/parser.c:12091 cp/parser.c:21252
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
@@ -39033,12 +39079,12 @@
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "关键字%<export%>未实现，将被忽略"
 
-#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19121
+#: cp/parser.c:13447 cp/parser.c:13545 cp/parser.c:13654 cp/parser.c:19145
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/parser.c:13451 cp/parser.c:19129
+#: cp/parser.c:13451 cp/parser.c:19153
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "模板参数包不能有默认参数"
@@ -39053,7 +39099,7 @@
 msgid "expected template-id"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:13790 cp/parser.c:24852
+#: cp/parser.c:13790 cp/parser.c:24890
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "需要%<<%>"
@@ -39130,209 +39176,209 @@
 msgid "expected type specifier"
 msgstr "需要类型限定"
 
-#: cp/parser.c:14945
+#: cp/parser.c:14969
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:14951
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:14956
+#: cp/parser.c:14980
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C 不允许前向参数声明"
 
-#: cp/parser.c:15100
+#: cp/parser.c:15124
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "  需要有%qD类型的模板，却得到了%qT"
 
-#: cp/parser.c:15127
+#: cp/parser.c:15151
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "需要类型名"
 
-#: cp/parser.c:15348
+#: cp/parser.c:15372
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:15557
+#: cp/parser.c:15581
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "声明%qD没有声明任何东西"
 
-#: cp/parser.c:15644
+#: cp/parser.c:15668
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "属性在未初始化类型上被忽略"
 
-#: cp/parser.c:15648
+#: cp/parser.c:15672
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "属性在模板实例化上被忽略"
 
-#: cp/parser.c:15653
+#: cp/parser.c:15677
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
 
-#: cp/parser.c:15787
+#: cp/parser.c:15811
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD不是一个枚举模板"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15821
 #, gcc-internal-format
 msgid "%qD is not an enumerator-name"
 msgstr "%qD不是一个枚举名"
 
-#: cp/parser.c:15809
+#: cp/parser.c:15833
 #, gcc-internal-format
 msgid "anonymous scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:15864
+#: cp/parser.c:15888
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "需要%<,%>或%<;%>"
 
-#: cp/parser.c:15913
+#: cp/parser.c:15937
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "启用模板自动实例化"
 
-#: cp/parser.c:15931 cp/parser.c:20336
+#: cp/parser.c:15955 cp/parser.c:20360
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%qD声明出现在命名空间%qD中，而后者并不包含%qD"
 
-#: cp/parser.c:15936 cp/parser.c:20341
+#: cp/parser.c:15960 cp/parser.c:20365
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qD声明出现在%qD中，而后者并不包含%qD"
 
-#: cp/parser.c:15961
+#: cp/parser.c:15985
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T多次定义"
 
-#: cp/parser.c:15974
+#: cp/parser.c:15998
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty anonymous enum"
 msgstr "ISO C++ 不允许枚举自增"
 
-#: cp/parser.c:15994
+#: cp/parser.c:16018
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:15997
+#: cp/parser.c:16021
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:16167
+#: cp/parser.c:16191
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD不是一个命名空间名"
 
-#: cp/parser.c:16168
+#: cp/parser.c:16192
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "需要命名空间名"
 
-#: cp/parser.c:16294
+#: cp/parser.c:16318
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16473
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "模板标识符不允许出现在 using 声明中"
 
-#: cp/parser.c:16495
+#: cp/parser.c:16519
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:16560
+#: cp/parser.c:16584
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:16705
+#: cp/parser.c:16729
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%qD不是一个广义常函数"
 
-#: cp/parser.c:17043
+#: cp/parser.c:17067
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:17054
+#: cp/parser.c:17078
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: cp/parser.c:17058
+#: cp/parser.c:17082
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "函数定义中不允许有属性"
 
-#: cp/parser.c:17109
+#: cp/parser.c:17133
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:17148 cp/parser.c:19309
+#: cp/parser.c:17172 cp/parser.c:19333
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "需要初始值设定"
 
-#: cp/parser.c:17228
+#: cp/parser.c:17252
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "为函数提供了初始值设定"
 
-#: cp/parser.c:17262
+#: cp/parser.c:17286
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "括起的初始值设定后出现的属性被忽略"
 
-#: cp/parser.c:17267
+#: cp/parser.c:17291
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "函数%q+D重声明为内联的"
 
-#: cp/parser.c:17705
+#: cp/parser.c:17729
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "数组边界不是一个整数常量"
 
-#: cp/parser.c:17831
+#: cp/parser.c:17855
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/parser.c:17835
+#: cp/parser.c:17859
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%>不是一个类型"
 
-#: cp/parser.c:17863
+#: cp/parser.c:17887
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "将构造函数用作模板无效"
 
-#: cp/parser.c:17865
+#: cp/parser.c:17889
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
@@ -39341,7 +39387,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:17882
+#: cp/parser.c:17906
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "无效的声明"
@@ -39348,294 +39394,294 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:17952
+#: cp/parser.c:17976
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "声明中有无效类型"
 
-#: cp/parser.c:17977
+#: cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "需要声明"
 
-#: cp/parser.c:18080
+#: cp/parser.c:18104
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD是一个命名空间"
 
-#: cp/parser.c:18082
+#: cp/parser.c:18106
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/parser.c:18103
+#: cp/parser.c:18127
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "未知的操作符‘%s’在 %%L处"
 
-#: cp/parser.c:18162
+#: cp/parser.c:18186
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "重复的 cv 限定"
 
-#: cp/parser.c:18216
+#: cp/parser.c:18240
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "重复的 cv 限定"
 
-#: cp/parser.c:18274
+#: cp/parser.c:18298
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "重复的 cv 限定"
 
-#: cp/parser.c:18481 cp/typeck2.c:541 cp/typeck2.c:1908
+#: cp/parser.c:18505 cp/typeck2.c:541 cp/typeck2.c:1928
 #, gcc-internal-format
 msgid "invalid use of %<auto%>"
 msgstr "错误地使用了%<auto%>"
 
-#: cp/parser.c:18500
+#: cp/parser.c:18524
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "不能在模板实参中定义类型"
 
-#: cp/parser.c:18505
+#: cp/parser.c:18529
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "%qs(有%qT)的实参类型无效"
 
-#: cp/parser.c:18592
+#: cp/parser.c:18616
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "需要类型限定"
 
-#: cp/parser.c:18898
+#: cp/parser.c:18922
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "需要%<,%>或%<...%>"
 
-#: cp/parser.c:18972
+#: cp/parser.c:18996
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "类型不能定义在参数类型中"
 
-#: cp/parser.c:19100
+#: cp/parser.c:19124
 #, gcc-internal-format
 msgid "deprecated use of default argument for parameter of non-function"
 msgstr "不建议为非函数指定默认参数"
 
-#: cp/parser.c:19104
+#: cp/parser.c:19128
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "默认参数只允许出现在函数参数中"
 
-#: cp/parser.c:19123
+#: cp/parser.c:19147
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%H%s模板参数包%qD不能有默认参数"
 
-#: cp/parser.c:19131
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "%H%s模板参数包不能有默认参数"
 
-#: cp/parser.c:19502
+#: cp/parser.c:19526
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:19516
+#: cp/parser.c:19540
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:19634 cp/parser.c:19759
+#: cp/parser.c:19658 cp/parser.c:19783
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "需要类名"
 
-#: cp/parser.c:19941
+#: cp/parser.c:19965
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "类定义后需要%<;%>"
 
-#: cp/parser.c:19943
+#: cp/parser.c:19967
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "结构定义后需要%<;%>"
 
-#: cp/parser.c:19945
+#: cp/parser.c:19969
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "联合定义后需要%<;%>"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20308
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "需要%<{%>或%<:%>"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20319
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "无法为类 %s 找到文件"
 
-#: cp/parser.c:20303
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:20310
+#: cp/parser.c:20334
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "%qE不是一个类"
 
-#: cp/parser.c:20322
+#: cp/parser.c:20346
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD的声明中类名无效"
 
-#: cp/parser.c:20355
+#: cp/parser.c:20379
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "不允许有多余的限定"
 
-#: cp/parser.c:20367
+#: cp/parser.c:20391
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "显式特例化前必须有%<template <>%>"
 
-#: cp/parser.c:20397
+#: cp/parser.c:20421
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "函数模板%qD重声明为类模板"
 
-#: cp/parser.c:20428
+#: cp/parser.c:20452
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "%<typename %T::%D%>指定了%q#T，但后者不是一个类型"
 
-#: cp/parser.c:20484
+#: cp/parser.c:20508
 #, gcc-internal-format
 msgid "previous definition of %q+#T"
 msgstr "%q+#T的前一个定义"
 
-#: cp/parser.c:20575 cp/parser.c:24897
+#: cp/parser.c:20599 cp/parser.c:24935
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "需要类名"
 
-#: cp/parser.c:20599
+#: cp/parser.c:20623
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:20603
+#: cp/parser.c:20627
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.c:20842
+#: cp/parser.c:20866
 #, fuzzy, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "声明友元时必须使用 class 关键字"
 
-#: cp/parser.c:20860
+#: cp/parser.c:20884
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:20878
+#: cp/parser.c:20902
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:21082
+#: cp/parser.c:21106
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "函数定义上有 pure 指定"
 
-#: cp/parser.c:21136
+#: cp/parser.c:21160
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "在%C处需要“,”或语句尾"
 
-#: cp/parser.c:21148
+#: cp/parser.c:21172
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "在%C处需要“,”或语句尾"
 
-#: cp/parser.c:21222
+#: cp/parser.c:21246
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "指定了无效的 AE 类型(%s)\n"
 
-#: cp/parser.c:21257
+#: cp/parser.c:21281
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "<花括号内的初始值列表>"
 
-#: cp/parser.c:21386
+#: cp/parser.c:21410
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specified"
 msgstr "在基类限定中指定了多于一次的%<virtual%>"
 
-#: cp/parser.c:21406
+#: cp/parser.c:21430
 #, gcc-internal-format
 msgid "more than one access specifier in base-specified"
 msgstr ""
 
-#: cp/parser.c:21430
+#: cp/parser.c:21454
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/parser.c:21433
+#: cp/parser.c:21457
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "关键字%<typename%>不允许用在此上下文中(基类隐式地是一个类型)"
 
-#: cp/parser.c:21526 cp/parser.c:21608
+#: cp/parser.c:21550 cp/parser.c:21632
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "类型不能定义在异常规范中"
 
-#: cp/parser.c:21590
+#: cp/parser.c:21614
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgstr ""
 
-#: cp/parser.c:21680
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not %<constexpr%>"
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%qD不是%<constexpr%>"
 
-#: cp/parser.c:21793
+#: cp/parser.c:21817
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:22417
+#: cp/parser.c:22441
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "需要标识符或%<(%>"
 
-#: cp/parser.c:22436
+#: cp/parser.c:22460
 #, gcc-internal-format
 msgid "%<deprecated%> is a C++14 feature; use %<gnu::deprecated%>"
 msgstr ""
 
-#: cp/parser.c:23103
+#: cp/parser.c:23141
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "特例化成员%<%T::%E%>需要%<template<>%>语法"
 
-#: cp/parser.c:23108
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "%<%T::%E%>声明无效"
 
-#: cp/parser.c:23112
+#: cp/parser.c:23150
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "模板参数表太少"
@@ -39644,534 +39690,534 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:23119
+#: cp/parser.c:23157
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "模板参数表太多"
 
-#: cp/parser.c:23443
+#: cp/parser.c:23481
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "有名返回值不再被支持"
 
-#: cp/parser.c:23540
+#: cp/parser.c:23578
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "局部类中对成员模板的声明无效"
 
-#: cp/parser.c:23549
+#: cp/parser.c:23587
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "模板有 C 链接"
 
-#: cp/parser.c:23568
+#: cp/parser.c:23606
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "显式特例化非模板%qT"
 
-#: cp/parser.c:23666
+#: cp/parser.c:23704
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:23671
+#: cp/parser.c:23709
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23783
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "%<typedef%>的模板声明"
 
-#: cp/parser.c:23822
+#: cp/parser.c:23860
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "显式特例化不能有存储类型"
 
-#: cp/parser.c:24067
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "在嵌套模板实参列表中应当使用%<> >%>而非%<>>%>"
 
-#: cp/parser.c:24080
+#: cp/parser.c:24118
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的%<>>%>，使用%<>%>来结束模板实参列表"
 
-#: cp/parser.c:24377
+#: cp/parser.c:24415
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:24532
+#: cp/parser.c:24570
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "指定链接时使用%qD无效"
 
-#: cp/parser.c:24547
+#: cp/parser.c:24585
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>出现在%qD之前"
 
-#: cp/parser.c:24681
+#: cp/parser.c:24719
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 不支持%<long long%>"
 
-#: cp/parser.c:24689
+#: cp/parser.c:24727
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "声明中同时使用了%<_Sat%>和%<char%>"
 
-#: cp/parser.c:24691
+#: cp/parser.c:24729
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重复的%qE"
 
-#: cp/parser.c:24713
+#: cp/parser.c:24751
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重复的%qs"
 
-#: cp/parser.c:24755
+#: cp/parser.c:24793
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "需要%<new%>"
 
-#: cp/parser.c:24758
+#: cp/parser.c:24796
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "需要%<delete%>"
 
-#: cp/parser.c:24761
+#: cp/parser.c:24799
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "需要%<return%>"
 
-#: cp/parser.c:24767
+#: cp/parser.c:24805
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "需要%<extern%>"
 
-#: cp/parser.c:24770
+#: cp/parser.c:24808
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "需要%<static_assert%>"
 
-#: cp/parser.c:24773
+#: cp/parser.c:24811
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "需要%<decltype%>"
 
-#: cp/parser.c:24776
+#: cp/parser.c:24814
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "需要%<operator%>"
 
-#: cp/parser.c:24779
+#: cp/parser.c:24817
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "需要%<class%>"
 
-#: cp/parser.c:24782
+#: cp/parser.c:24820
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "需要%<template%>"
 
-#: cp/parser.c:24785
+#: cp/parser.c:24823
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "需要%<namespace%>"
 
-#: cp/parser.c:24788
+#: cp/parser.c:24826
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "需要%<using%>"
 
-#: cp/parser.c:24791
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "需要%<asm%>"
 
-#: cp/parser.c:24794
+#: cp/parser.c:24832
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "需要%<try%>"
 
-#: cp/parser.c:24797
+#: cp/parser.c:24835
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "需要%<catch%>"
 
-#: cp/parser.c:24800
+#: cp/parser.c:24838
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "需要%<throw%>"
 
-#: cp/parser.c:24803
+#: cp/parser.c:24841
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "需要%<__label__%>"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24844
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "需要%<@try%>"
 
-#: cp/parser.c:24809
+#: cp/parser.c:24847
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "需要%<@synchronized%>"
 
-#: cp/parser.c:24812
+#: cp/parser.c:24850
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "需要%<@throw%>"
 
-#: cp/parser.c:24815
+#: cp/parser.c:24853
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "需要%<static_assert%>"
 
-#: cp/parser.c:24818
+#: cp/parser.c:24856
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "需要%<static_assert%>"
 
-#: cp/parser.c:24849
+#: cp/parser.c:24887
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "需要%<::%>"
 
-#: cp/parser.c:24861
+#: cp/parser.c:24899
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "需要%<...%>"
 
-#: cp/parser.c:24864
+#: cp/parser.c:24902
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "需要%<*%>"
 
-#: cp/parser.c:24867
+#: cp/parser.c:24905
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "需要%<~%>"
 
-#: cp/parser.c:24873
+#: cp/parser.c:24911
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "需要%<:%>或%<::%>"
 
-#: cp/parser.c:24901
+#: cp/parser.c:24939
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.c:25162
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了%qs标记，在命名%q#T时"
 
-#: cp/parser.c:25167
+#: cp/parser.c:25205
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "以前在此声明过"
 
-#: cp/parser.c:25186
+#: cp/parser.c:25224
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD重声明时有不同的可访问性"
 
-#: cp/parser.c:25207
+#: cp/parser.c:25245
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "用作消歧义的%<template%>只能用于模板内"
 
-#: cp/parser.c:25439
+#: cp/parser.c:25477
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "文件在默认参数处结束"
 
-#: cp/parser.c:25669 cp/parser.c:26936 cp/parser.c:27122
+#: cp/parser.c:25707 cp/parser.c:26974 cp/parser.c:27160
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: cp/parser.c:25727
+#: cp/parser.c:25765
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "需要指定声明"
 
-#: cp/parser.c:25797
+#: cp/parser.c:25835
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:25826
+#: cp/parser.c:25864
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%>必须指定一个类型作为实参"
 
-#: cp/parser.c:26202
+#: cp/parser.c:26240
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "无效的 Objective-C++ 选择子名"
 
-#: cp/parser.c:26277 cp/parser.c:26295
+#: cp/parser.c:26315 cp/parser.c:26333
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "需要指定声明"
 
-#: cp/parser.c:26289 cp/parser.c:26354
+#: cp/parser.c:26327 cp/parser.c:26392
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "不能为局部变量指定节属性"
 
-#: cp/parser.c:26397
+#: cp/parser.c:26435
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:26603 cp/parser.c:26610 cp/parser.c:26617
+#: cp/parser.c:26641 cp/parser.c:26648 cp/parser.c:26655
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "迭代变量%qE类型无效"
 
-#: cp/parser.c:26730
+#: cp/parser.c:26768
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%>需要标识符"
 
-#: cp/parser.c:26901
+#: cp/parser.c:26939
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:26908
+#: cp/parser.c:26946
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE属性为%qE所忽略"
 
-#: cp/parser.c:27181 cp/parser.c:27188 cp/parser.c:27195
+#: cp/parser.c:27219 cp/parser.c:27226 cp/parser.c:27233
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "%q+D的抽象类型无效"
 
-#: cp/parser.c:28034 cp/parser.c:28332 cp/parser.c:28398
+#: cp/parser.c:28072 cp/parser.c:28370 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected positive integer expression"
 msgstr "需要整数表达式"
 
-#: cp/parser.c:28090
+#: cp/parser.c:28128
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/parser.c:28516
+#: cp/parser.c:28554
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "无效的初始值设定"
 
-#: cp/parser.c:30268
+#: cp/parser.c:30306
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "括起的初始化不允许使用在 OpenMP %<for%>循环中"
 
-#: cp/parser.c:30271
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "括起的初始化不允许使用在 OpenMP %<for%>循环中"
 
-#: cp/parser.c:30340
+#: cp/parser.c:30378
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:30513 cp/pt.c:13679
+#: cp/parser.c:30547 cp/pt.c:13811
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代变量%qD不应当是 reduction"
 
-#: cp/parser.c:30583
+#: cp/parser.c:30617
 #, gcc-internal-format
 msgid "not enough collapsed for loops"
 msgstr "循环折叠得不够"
 
-#: cp/parser.c:31881
+#: cp/parser.c:31916
 #, fuzzy, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "函数定义中不允许有属性"
 
-#: cp/parser.c:32108
+#: cp/parser.c:32143
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "无效的初始值设定"
 
-#: cp/parser.c:32136
+#: cp/parser.c:32171
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "需要表达式类型"
 
-#: cp/parser.c:32148
+#: cp/parser.c:32183
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:32229
+#: cp/parser.c:32264
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "需要%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%>或%<||%>"
 
-#: cp/parser.c:32248
+#: cp/parser.c:32283
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在返回类型中定义新类型"
 
-#: cp/parser.c:32270 cp/semantics.c:4987
+#: cp/parser.c:32305 cp/semantics.c:4993
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32275 cp/semantics.c:4996
+#: cp/parser.c:32310 cp/semantics.c:5002
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32278 cp/pt.c:10880 cp/semantics.c:5002
+#: cp/parser.c:32313 cp/pt.c:10978 cp/semantics.c:5008
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32281 cp/semantics.c:5008
+#: cp/parser.c:32316 cp/semantics.c:5014
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:32668 cp/semantics.c:7064
+#: cp/parser.c:32703 cp/semantics.c:7070
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32670 cp/semantics.c:7066
+#: cp/parser.c:32705 cp/semantics.c:7072
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:32866
+#: cp/parser.c:32901
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma GCC pch_preprocess%>末尾有垃圾字符"
 
-#: cp/parser.c:32899
+#: cp/parser.c:32934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "操作数的约束无效"
 
-#: cp/parser.c:33085
+#: cp/parser.c:33120
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: cp/parser.c:33106
+#: cp/parser.c:33141
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: cp/parser.c:33116
+#: cp/parser.c:33151
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: cp/parser.c:33128
+#: cp/parser.c:33163
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:33186
+#: cp/parser.c:33221
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "模块间优化未为 C++ 实现"
 
-#: cp/parser.c:33296
+#: cp/parser.c:33331
 #, fuzzy, gcc-internal-format
 msgid "expected variable-name"
 msgstr "在%C处需要变量名"
 
-#: cp/parser.c:33360
+#: cp/parser.c:33395
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "需要 %<,%> 或 %<)%>"
 
-#: cp/parser.c:33701
+#: cp/parser.c:33736
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
 
-#: cp/pt.c:296
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "数据成员%qD不能是成员模板"
 
-#: cp/pt.c:308
+#: cp/pt.c:309
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/pt.c:689
+#: cp/pt.c:690
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "显式特例化出现在非命名空间作用域%qD中"
 
-#: cp/pt.c:703
+#: cp/pt.c:704
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "所包含的类模板并未被显式特例化"
 
-#: cp/pt.c:789
+#: cp/pt.c:790
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/pt.c:797
+#: cp/pt.c:798
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "在不同命名空间内对%qD的特例化"
 
-#: cp/pt.c:798 cp/pt.c:925
+#: cp/pt.c:799 cp/pt.c:926
 #, gcc-internal-format
 msgid "  from definition of %q+#D"
 msgstr "  从%q+#D的定义"
 
-#: cp/pt.c:815
+#: cp/pt.c:816
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%qD的显式实例化出现在命名空间%qD中，而后者并不包含命名空间%qD"
 
-#: cp/pt.c:838
+#: cp/pt.c:839
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "类名隐藏了模板的模板形参%qD"
 
-#: cp/pt.c:849
+#: cp/pt.c:850
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "模板声明%q#D"
 
-#: cp/pt.c:852 cp/pt.c:987
+#: cp/pt.c:853 cp/pt.c:988
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.c:884
+#: cp/pt.c:885
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "%qT的实例化在特例化之后"
 
-#: cp/pt.c:924
+#: cp/pt.c:925
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "在不同命名空间中特例化%q#T"
@@ -40178,68 +40224,68 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:965
+#: cp/pt.c:966
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "%qT的实例化在%qT的特例化之后"
 
-#: cp/pt.c:983
+#: cp/pt.c:984
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "函数模板部分特例化%qD是不允许的"
 
-#: cp/pt.c:1415
+#: cp/pt.c:1416
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "%qD的特例化在实例化之后"
 
-#: cp/pt.c:1803
+#: cp/pt.c:1804
 #, fuzzy, gcc-internal-format
 msgid "candidate is: %#D"
 msgstr "备选为：%+#D"
 
-#: cp/pt.c:1810 cp/semantics.c:4856
+#: cp/pt.c:1811 cp/semantics.c:4862
 #, fuzzy, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %+#D"
 
-#: cp/pt.c:1904
+#: cp/pt.c:1905
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD不是一个函数模板"
 
-#: cp/pt.c:1909
+#: cp/pt.c:1910
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD不是一个变量"
 
-#: cp/pt.c:2125
+#: cp/pt.c:2132
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "%2$q+D的模板标识符%1$qD不匹配任何模板声明"
 
-#: cp/pt.c:2128
+#: cp/pt.c:2135
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "发现 %d 个%<template<>%>，需要 %d 来特例化一个成员函数模板"
 
-#: cp/pt.c:2137
+#: cp/pt.c:2144
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:2343
+#: cp/pt.c:2350
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.c:2352
+#: cp/pt.c:2359
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %D (should be %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:2357
+#: cp/pt.c:2364
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
@@ -40246,59 +40292,59 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2445 cp/pt.c:2501
+#: cp/pt.c:2452 cp/pt.c:2508
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "模板标识符%qD出现在基本模板的声明中"
 
-#: cp/pt.c:2458
+#: cp/pt.c:2465
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "显式初始化中出现了模板参数列表"
 
-#: cp/pt.c:2464
+#: cp/pt.c:2471
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "为显式实例化提供的定义"
 
-#: cp/pt.c:2472
+#: cp/pt.c:2479
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/pt.c:2475
+#: cp/pt.c:2482
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD声明时模板参数表太少"
 
-#: cp/pt.c:2477
+#: cp/pt.c:2484
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "%qD的显式特例化必须由%<template <>%>引入"
 
-#: cp/pt.c:2511
+#: cp/pt.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "函数模板部分特例化%qD是不允许的"
 
-#: cp/pt.c:2514
+#: cp/pt.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "函数模板部分特例化%qD是不允许的"
 
-#: cp/pt.c:2547
+#: cp/pt.c:2554
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "显式特例化时指定了默认参数"
 
-#: cp/pt.c:2578
+#: cp/pt.c:2585
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD不是一个模板函数"
 
-#: cp/pt.c:2586
+#: cp/pt.c:2593
 #, gcc-internal-format
 msgid "%qD is not declared in %qD"
 msgstr "%qD未在%qD中声明"
@@ -40311,105 +40357,105 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:2651
+#: cp/pt.c:2658
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "特例化了隐式声明的特殊成员函数"
 
-#: cp/pt.c:2695
+#: cp/pt.c:2702
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "成员函数%qD未在%qT中声明"
 
-#: cp/pt.c:3375
+#: cp/pt.c:3382
 #, gcc-internal-format
 msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgstr "基类初始值设定展开%<%T%>不包括参数包"
 
-#: cp/pt.c:3436
+#: cp/pt.c:3443
 #, gcc-internal-format
 msgid "expansion pattern %<%T%> contains no argument packs"
 msgstr "展开样式%<%T%>不包括参数包"
 
-#: cp/pt.c:3438
+#: cp/pt.c:3445
 #, gcc-internal-format
 msgid "expansion pattern %<%E%> contains no argument packs"
 msgstr "展开样式%<%E%>不包括参数包"
 
-#: cp/pt.c:3481
+#: cp/pt.c:3488
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "参数包未能在%<...%>中被展开："
 
-#: cp/pt.c:3496 cp/pt.c:4207
+#: cp/pt.c:3503 cp/pt.c:4214
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "       %qD"
 
-#: cp/pt.c:3498
+#: cp/pt.c:3505
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <匿名>"
 
-#: cp/pt.c:3621
+#: cp/pt.c:3628
 #, gcc-internal-format
 msgid "declaration of %q+#D"
 msgstr "%q+#D的声明"
 
-#: cp/pt.c:3622
+#: cp/pt.c:3629
 #, gcc-internal-format
 msgid " shadows template parm %q+#D"
 msgstr "隐藏了模版形参%q+#D"
 
-#: cp/pt.c:4202
+#: cp/pt.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "部分特例化中未用到模板参数："
 
-#: cp/pt.c:4221
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD does not specialize any template arguments"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:4229
+#: cp/pt.c:4236
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4232
+#: cp/pt.c:4239
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "以前在此声明过"
 
-#: cp/pt.c:4279
+#: cp/pt.c:4286
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "参数包实参%qE必须出现在模板实参表末尾"
 
-#: cp/pt.c:4282
+#: cp/pt.c:4289
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "参数包实参%qT必须出现在模板实参表末尾"
 
-#: cp/pt.c:4303
+#: cp/pt.c:4310
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "模板实参%qE混杂了模板形参"
 
-#: cp/pt.c:4349
+#: cp/pt.c:4356
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "模板实参%2$qE的类型%1$qT取决于模板参数"
 
-#: cp/pt.c:4393
+#: cp/pt.c:4400
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "部分特例化模板%qT声明为%<friend%>"
 
-#: cp/pt.c:4568
+#: cp/pt.c:4576
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD没有默认参数"
@@ -40417,43 +40463,43 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:4590
+#: cp/pt.c:4598
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "参数包%qE必须出现在模板形参表末尾"
 
-#: cp/pt.c:4626
+#: cp/pt.c:4634
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "默认参数不能用在函数模板友元重声明中"
 
-#: cp/pt.c:4629
+#: cp/pt.c:4637
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend declarations"
 msgstr "默认参数不能用在函数模板友元重声明中"
 
-#: cp/pt.c:4632
+#: cp/pt.c:4640
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "只有指定了 -std=c++0x 或 -std=gnu++0x 时才能在函数模板中使用默认参数"
 
-#: cp/pt.c:4635
+#: cp/pt.c:4643
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "默认参数不能用在部分特例化中"
 
-#: cp/pt.c:4638 cp/pt.c:4689
+#: cp/pt.c:4646 cp/pt.c:4697
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:4790
+#: cp/pt.c:4798
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "模板类没有名字"
 
-#: cp/pt.c:4798
+#: cp/pt.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -40464,74 +40510,74 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:4820
+#: cp/pt.c:4828
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD模板声明无效"
 
-#: cp/pt.c:4948
+#: cp/pt.c:4956
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "对非模板%q#D的模板定义"
 
-#: cp/pt.c:4991
+#: cp/pt.c:4999
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "需要 %d 级的%q#D模板参数，却给出了 %d 级"
 
-#: cp/pt.c:5005
+#: cp/pt.c:5013
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "得到 %d 个模板参数，为%q#D"
 
-#: cp/pt.c:5008
+#: cp/pt.c:5016
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%2$q#T得到了 %1$d 个模板参数"
 
-#: cp/pt.c:5010
+#: cp/pt.c:5018
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "但实际需要 %d 个"
 
-#: cp/pt.c:5031
+#: cp/pt.c:5039
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:5035
+#: cp/pt.c:5043
 #, gcc-internal-format
 msgid "use template<> for an explicit specialization"
 msgstr "使用 template<> 来显式特例化"
 
-#: cp/pt.c:5168
+#: cp/pt.c:5181
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT不是一个模板类型"
 
-#: cp/pt.c:5181
+#: cp/pt.c:5194
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD的声明中没有 template 限定"
 
-#: cp/pt.c:5192
+#: cp/pt.c:5205
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "重声明为具有 %d 个模板参数"
 
-#: cp/pt.c:5196
+#: cp/pt.c:5209
 #, gcc-internal-format
 msgid "previous declaration %q+D used %d template parameter"
 msgid_plural "previous declaration %q+D used %d template parameters"
 msgstr[0] "先前的声明%q+D使用了 %d 个模板参数"
 
-#: cp/pt.c:5233
+#: cp/pt.c:5246
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "模板形参%q+#D"
 
-#: cp/pt.c:5234
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "在这里又被声明为%q#D"
@@ -40540,102 +40586,102 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5244
+#: cp/pt.c:5257
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "重定义%q#D的默认参数"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5259
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "原始定义在此"
 
-#: cp/pt.c:5436 cp/pt.c:5487
+#: cp/pt.c:5492 cp/pt.c:5543
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE不是类型%qT的有效模板参数"
 
-#: cp/pt.c:5439
+#: cp/pt.c:5495
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "它必须是一个具有外部链接函数的地址"
 
-#: cp/pt.c:5442
+#: cp/pt.c:5498
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "它必须是一个具有外部链接函数的地址"
 
-#: cp/pt.c:5454
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:5458
+#: cp/pt.c:5514
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5545
 #, fuzzy, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "它必须是格式为‘&X::Y’的成员指针"
 
-#: cp/pt.c:5540
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "得到 %d 个模板参数，为%q#D"
 
-#: cp/pt.c:5555
+#: cp/pt.c:5611
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:5564
+#: cp/pt.c:5620
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
 
-#: cp/pt.c:5573
+#: cp/pt.c:5629
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/pt.c:5584
+#: cp/pt.c:5640
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:5594
+#: cp/pt.c:5650
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs对%qs而言无效"
 
-#: cp/pt.c:5603
+#: cp/pt.c:5659
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/pt.c:5615
+#: cp/pt.c:5671
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:5619
+#: cp/pt.c:5675
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:5630
+#: cp/pt.c:5686
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:5641
+#: cp/pt.c:5697
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板参数"
 
-#: cp/pt.c:5653
+#: cp/pt.c:5709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -40643,172 +40689,172 @@
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] " 备选需要 %d 实参，但提供了 %d 个"
 
-#: cp/pt.c:5684
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "不能将类型%qT转换为类型%qT"
 
-#: cp/pt.c:5697
+#: cp/pt.c:5753
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT是%qT的有歧义的基类"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5757
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "类型%qT不是由类型%qT派生的"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5768
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:5722
+#: cp/pt.c:5778
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/pt.c:5732
+#: cp/pt.c:5788
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qD"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:5741
+#: cp/pt.c:5797
 #, fuzzy, gcc-internal-format
 msgid "  could not resolve address from overloaded function %qE"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/pt.c:5780
+#: cp/pt.c:5836
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE不是类型%qT的有效模板实参，因为字面字符串不能用在此上下文中"
 
-#: cp/pt.c:5934
+#: cp/pt.c:5990
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT "
 msgstr "%qD的模板实参使用了局部类型%qT"
 
-#: cp/pt.c:5981
+#: cp/pt.c:6037
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD不是一个有效模板实参，因为%qD是一个变量，而非变量的地址"
 
-#: cp/pt.c:5989
+#: cp/pt.c:6045
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD不是一个有效模板实参，因为%qD是一个变量，而非变量的地址"
 
-#: cp/pt.c:6007
+#: cp/pt.c:6063
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6014
+#: cp/pt.c:6070
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:6022
+#: cp/pt.c:6078
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6052
+#: cp/pt.c:6108
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE不是类型%qT的有效模板实参，因为 cv 限定冲突"
 
-#: cp/pt.c:6060
+#: cp/pt.c:6116
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE不是类型%qT的有效模板实参，因为它不是一个左值"
 
-#: cp/pt.c:6078
+#: cp/pt.c:6134
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D不是类型%qT的有效模板参数，因为一个引用变量没有常量地址"
 
-#: cp/pt.c:6088
+#: cp/pt.c:6144
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为它没有外部链接"
 
-#: cp/pt.c:6097
+#: cp/pt.c:6153
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:6143
+#: cp/pt.c:6199
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE不是类型%qT的有效模板实参，因为它是一个指针"
 
-#: cp/pt.c:6145
+#: cp/pt.c:6201
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "尝试使用%qE代替"
 
-#: cp/pt.c:6187 cp/pt.c:6218
+#: cp/pt.c:6243 cp/pt.c:6274
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为它的类型是%qT"
 
-#: cp/pt.c:6193
+#: cp/pt.c:6249
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "此上下文中不允许标准转换"
 
-#: cp/pt.c:6505
+#: cp/pt.c:6561
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "%qs(有%qT)的实参类型无效"
 
-#: cp/pt.c:6566
+#: cp/pt.c:6622
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "注入的类名%qD被用作模板的模板参数"
 
-#: cp/pt.c:6595
+#: cp/pt.c:6651
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "将析构函数%qD用作类型无效"
 
-#: cp/pt.c:6600
+#: cp/pt.c:6656
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某个模板参数的类型成员时，请使用%<typename %E%>"
 
-#: cp/pt.c:6616 cp/pt.c:6638 cp/pt.c:6691
+#: cp/pt.c:6672 cp/pt.c:6694 cp/pt.c:6747
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "实参 %d 的类型/值不匹配，在%qD的模板参数列表中"
 
-#: cp/pt.c:6621
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "需要一个%qT类型的常量，却给出了%qT"
 
-#: cp/pt.c:6626
+#: cp/pt.c:6682
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "需要一个类模板，却给出了%qE"
 
-#: cp/pt.c:6629
+#: cp/pt.c:6685
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "需要一个类型，却给出了%qE"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6699
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "需要一个类型，却给出了%qT"
 
-#: cp/pt.c:6646
+#: cp/pt.c:6702
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "需要一个类模板，却给出了%qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6751
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "需要有%qD类型的模板，却得到了%qT"
@@ -40815,78 +40861,78 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:6728
+#: cp/pt.c:6784
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "非类型参数包中类型不匹配"
 
-#: cp/pt.c:6751
+#: cp/pt.c:6807
 #, gcc-internal-format
 msgid "could not convert template argument %qE to %qT"
 msgstr "不能将模板参数从%qE转换到%qT"
 
-#: cp/pt.c:6862 cp/pt.c:7159
+#: cp/pt.c:6918 cp/pt.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.c:6877 cp/pt.c:7008 cp/pt.c:7184
+#: cp/pt.c:6933 cp/pt.c:7064 cp/pt.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:7004
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:7012 cp/pt.c:7187
+#: cp/pt.c:7068 cp/pt.c:7243
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "提供给%q+D"
 
-#: cp/pt.c:7033
+#: cp/pt.c:7089
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:7125
+#: cp/pt.c:7181
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:7443
+#: cp/pt.c:7499
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%qD不是一个函数模板"
 
-#: cp/pt.c:7610
+#: cp/pt.c:7666
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非模板类型%qT用作模板"
 
-#: cp/pt.c:7612
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "对于模板声明%q+D"
 
-#: cp/pt.c:8501
+#: cp/pt.c:8557
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.c:10040
+#: cp/pt.c:10138
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "展开%<%T%>时参数包长度不匹配"
 
-#: cp/pt.c:10044
+#: cp/pt.c:10142
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "展开%<%E%>时参数包长度不匹配"
 
-#: cp/pt.c:10537
+#: cp/pt.c:10635
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "重定义%q#D的默认参数"
@@ -40904,269 +40950,269 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:11365
+#: cp/pt.c:11467
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "变量%qD有函数类型"
 
-#: cp/pt.c:11523
+#: cp/pt.c:11627
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "无效的参数类型%qT"
 
-#: cp/pt.c:11525
+#: cp/pt.c:11629
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在声明%q+D中"
 
-#: cp/pt.c:11636
+#: cp/pt.c:11740
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函数返回了一个数组"
 
-#: cp/pt.c:11638
+#: cp/pt.c:11742
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函数返回了一个函数"
 
-#: cp/pt.c:11678
+#: cp/pt.c:11782
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/pt.c:12251
+#: cp/pt.c:12355
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成对 void 的引用"
 
-#: cp/pt.c:12253
+#: cp/pt.c:12357
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "生成指向引用类型%qT的指针"
 
-#: cp/pt.c:12255
+#: cp/pt.c:12359
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "生成指向引用类型%qT的引用"
 
-#: cp/pt.c:12268
+#: cp/pt.c:12372
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/pt.c:12271
+#: cp/pt.c:12375
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/pt.c:12319
+#: cp/pt.c:12423
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/pt.c:12325
+#: cp/pt.c:12429
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/pt.c:12331
+#: cp/pt.c:12435
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "创建指向 void 类型的成员指针"
 
-#: cp/pt.c:12397
+#: cp/pt.c:12501
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "生成%qT的数组"
 
-#: cp/pt.c:12428
+#: cp/pt.c:12532
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT不是类、结构或联合类型"
 
-#: cp/pt.c:12465
+#: cp/pt.c:12569
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT被解析到非枚举类型%qT"
 
-#: cp/pt.c:12473
+#: cp/pt.c:12577
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT被解析到非类类型%qT"
 
-#: cp/pt.c:12602
+#: cp/pt.c:12706
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在模板中使用%qs"
 
-#: cp/pt.c:12744
+#: cp/pt.c:12848
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定类型%qT不匹配析构函数名 ~%qT"
 
-#: cp/pt.c:12759
+#: cp/pt.c:12863
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依赖名%qE被解析为非类型，但实例化却产生了一个类型"
 
-#: cp/pt.c:12761
+#: cp/pt.c:12865
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定类型，请使用%<typename %E%>"
 
-#: cp/pt.c:12965
+#: cp/pt.c:13069
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用无效字段%qD"
 
-#: cp/pt.c:13408 cp/pt.c:14367
+#: cp/pt.c:13510 cp/pt.c:14499
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "对集展开表达式的无效使用"
 
-#: cp/pt.c:13412 cp/pt.c:14371
+#: cp/pt.c:13514 cp/pt.c:14503
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用%<...%>来展开实参集"
 
-#: cp/pt.c:15133
+#: cp/pt.c:15265
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:15145
+#: cp/pt.c:15277
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:15150
+#: cp/pt.c:15282
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:15153
+#: cp/pt.c:15285
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%E%>不是一个类型"
 
-#: cp/pt.c:15157
+#: cp/pt.c:15289
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared here, later in the translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: cp/pt.c:15428
+#: cp/pt.c:15560
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT既不是类也不是命名空间"
 
-#: cp/pt.c:15431
+#: cp/pt.c:15563
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD既不是类也不是命名空间"
 
-#: cp/pt.c:15781
+#: cp/pt.c:15917
 #, gcc-internal-format
 msgid "%qT is/uses anonymous type"
 msgstr "%qT是/使用了匿名类型"
 
-#: cp/pt.c:15783
+#: cp/pt.c:15919
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD的模板实参使用了局部类型%qT"
 
-#: cp/pt.c:15793
+#: cp/pt.c:15929
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT是一个可变类型"
 
-#: cp/pt.c:15808
+#: cp/pt.c:15944
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/pt.c:15826
+#: cp/pt.c:15962
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  试图实例化%qD"
 
-#: cp/pt.c:19437
+#: cp/pt.c:19573
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T的类模板实例化有歧义"
 
-#: cp/pt.c:19439
+#: cp/pt.c:19575
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T的类模板实例化有歧义"
 
-#: cp/pt.c:19445
+#: cp/pt.c:19581
 #, fuzzy
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:19469 cp/pt.c:19556
+#: cp/pt.c:19605 cp/pt.c:19692
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "对非模板%q#D的显式实例化"
 
-#: cp/pt.c:19488
+#: cp/pt.c:19624
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD不是类模板的非静态数据成员"
 
-#: cp/pt.c:19494 cp/pt.c:19551
+#: cp/pt.c:19630 cp/pt.c:19687
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/pt.c:19499
+#: cp/pt.c:19635
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "类型%qT用于显式实例化%qD时不匹配声明的类型%qT"
 
-#: cp/pt.c:19507
+#: cp/pt.c:19643
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "对%q#D的显式实例化"
 
-#: cp/pt.c:19543
+#: cp/pt.c:19679
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "对%q#D重复的显式实例化"
 
-#: cp/pt.c:19566 cp/pt.c:19663
+#: cp/pt.c:19702 cp/pt.c:19799
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 不允许在显式实例化时使用%<extern%>"
 
-#: cp/pt.c:19571 cp/pt.c:19680
+#: cp/pt.c:19707 cp/pt.c:19816
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "为模板实例化化应用了存储类型%qD"
 
-#: cp/pt.c:19639
+#: cp/pt.c:19775
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "对非模板%q#D的显式实例化"
 
-#: cp/pt.c:19641
+#: cp/pt.c:19777
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.c:19650
+#: cp/pt.c:19786
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.c:19668
+#: cp/pt.c:19804
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允许在显式实例化时使用%qE"
 
-#: cp/pt.c:19714
+#: cp/pt.c:19850
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "对%q#T重复的显式实例化"
@@ -41178,62 +41224,62 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:20249
+#: cp/pt.c:20385
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "显式实例化%qD时没有可用的定义"
 
-#: cp/pt.c:20475
+#: cp/pt.c:20611
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "在实例化%2$q+D时模板实例化深度超过了最大值 %1$d，可能是由于生成虚函数表所致(使用 -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.c:20811
+#: cp/pt.c:20947
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/pt.c:20813
+#: cp/pt.c:20949
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T不是一个有效的模板常量参数类型"
 
-#: cp/pt.c:22102
+#: cp/pt.c:22238
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/pt.c:22153
+#: cp/pt.c:22289
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:22156
+#: cp/pt.c:22292
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:22173
+#: cp/pt.c:22309
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:22200
+#: cp/pt.c:22336
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.c:22202
+#: cp/pt.c:22338
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.c:22217
+#: cp/pt.c:22353
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "Lambda 返回类型演绎得到不一致的类型%qT和%qT"
 
-#: cp/pt.c:22221
+#: cp/pt.c:22357
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
@@ -41471,260 +41517,260 @@
 msgid "invalid base-class specification"
 msgstr "无效的基类"
 
-#: cp/semantics.c:3172
+#: cp/semantics.c:3178
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名联合中出现保护成员%q+#D"
 
-#: cp/semantics.c:3185 cp/semantics.c:7734
+#: cp/semantics.c:3191 cp/semantics.c:7740
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD未被捕获"
 
-#: cp/semantics.c:3190
+#: cp/semantics.c:3196
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3192
+#: cp/semantics.c:3198
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3203
+#: cp/semantics.c:3209
 #, fuzzy, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "在包含函数中使用%<auto%>变量"
 
-#: cp/semantics.c:3204
+#: cp/semantics.c:3210
 #, fuzzy, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "在包含函数中使用%<auto%>变量"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3372
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "模板参数%qD(类型为%qT)不允许出现在整数表达式中，因为它的类型不是整数或枚举"
 
-#: cp/semantics.c:3517
+#: cp/semantics.c:3523
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "命名空间%qD被用作表达式"
 
-#: cp/semantics.c:3522
+#: cp/semantics.c:3528
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "将类模板%qT用作表达式"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3528
+#: cp/semantics.c:3534
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "在多继承网格中对%qD的访问有歧义"
 
-#: cp/semantics.c:3554
+#: cp/semantics.c:3560
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/semantics.c:3683
+#: cp/semantics.c:3689
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE的类型未知"
 
-#: cp/semantics.c:3711
+#: cp/semantics.c:3717
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qD不是一个枚举名"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:3860
+#: cp/semantics.c:3866
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "为形参声明指定了无效的存储类"
 
-#: cp/semantics.c:3889
+#: cp/semantics.c:3895
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "不能为析构函数%<~%T%>使用%<offsetof%>"
 
-#: cp/semantics.c:3898
+#: cp/semantics.c:3904
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:3906
+#: cp/semantics.c:3912
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "不能为成员函数%qD应用%<offsetof%>"
 
-#: cp/semantics.c:3922
+#: cp/semantics.c:3928
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4853
+#: cp/semantics.c:4859
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/semantics.c:5138
+#: cp/semantics.c:5144
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction%>"
 msgstr "%qE的类型对%<reduction%>无效"
 
-#: cp/semantics.c:5239
+#: cp/semantics.c:5245
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5333
+#: cp/semantics.c:5339
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5349
+#: cp/semantics.c:5355
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:5388
+#: cp/semantics.c:5394
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.c:5399 cp/semantics.c:5421 cp/semantics.c:5443
+#: cp/semantics.c:5405 cp/semantics.c:5427 cp/semantics.c:5449
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: cp/semantics.c:5413
+#: cp/semantics.c:5419
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD在%<firstprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:5435
+#: cp/semantics.c:5441
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:5477
+#: cp/semantics.c:5483
 #, gcc-internal-format
 msgid "num_threads expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:5500
+#: cp/semantics.c:5506
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:5532
+#: cp/semantics.c:5538
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:5545
+#: cp/semantics.c:5551
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: cp/semantics.c:5562
+#: cp/semantics.c:5568
 #, fuzzy, gcc-internal-format
 msgid "%<num_teams%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:5581
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:5619
+#: cp/semantics.c:5625
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:5638
+#: cp/semantics.c:5644
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "切片结尾必须是整数"
 
-#: cp/semantics.c:5659
+#: cp/semantics.c:5665
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:5679
+#: cp/semantics.c:5685
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.c:5693
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:5699
+#: cp/semantics.c:5705
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: cp/semantics.c:5712
+#: cp/semantics.c:5718
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:5749
+#: cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:5996
 #, gcc-internal-format
 msgid "%qE has reference type for %qs"
 msgstr "%qE有%qs的引用类型"
 
-#: cp/semantics.c:6073
+#: cp/semantics.c:6079
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%>%qD不是一个文件、命名空间或块作用域变量"
 
-#: cp/semantics.c:6087
+#: cp/semantics.c:6093
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%>%qE指示不在%qT定义中"
 
-#: cp/semantics.c:6289
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%qE和%qD之间的差不具有整数类型"
 
-#: cp/semantics.c:6613
+#: cp/semantics.c:6619
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:6888 cp/semantics.c:6898
+#: cp/semantics.c:6894 cp/semantics.c:6904
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
 #. Report the error.
-#: cp/semantics.c:7187
+#: cp/semantics.c:7193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "静态断言错误：%E"
 
-#: cp/semantics.c:7190
+#: cp/semantics.c:7196
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "静态断言中出现非常量条件"
 
-#: cp/semantics.c:7220
+#: cp/semantics.c:7226
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "decltype 的实参必须是一个表达式"
 
-#: cp/semantics.c:7248
+#: cp/semantics.c:7254
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
@@ -41739,124 +41785,124 @@
 msgid "lambda-expression in a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/tree.c:3347
+#: cp/tree.c:3375
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to Java class definitions"
 msgstr "只能为 Java 类定义应用%qE属性"
 
-#: cp/tree.c:3376
+#: cp/tree.c:3404
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to class definitions"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/tree.c:3382
+#: cp/tree.c:3410
 #, gcc-internal-format
 msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 msgstr "%qE已过时：g++ 的虚函数表现在默认与 COM 兼容"
 
-#: cp/tree.c:3407
+#: cp/tree.c:3435
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "请求的 init_priority 不是一个整数常数"
 
-#: cp/tree.c:3428
+#: cp/tree.c:3456
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "只能将%qE属性用于某个类的对象的文件作用域定义"
 
-#: cp/tree.c:3436
+#: cp/tree.c:3464
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "请求的 init_priority 越界"
 
-#: cp/tree.c:3446
+#: cp/tree.c:3474
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "请求的 init_priority 保留为内部使用"
 
-#: cp/tree.c:3457
+#: cp/tree.c:3485
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "%qE属性在此平台上不受支持"
 
-#: cp/tree.c:3484
+#: cp/tree.c:3512
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/tree.c:3490
+#: cp/tree.c:3518
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "与此处早先的声明%q+#D冲突"
 
-#: cp/tree.c:3504
+#: cp/tree.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "%qD属性需要一个 NTBS 作为实参"
 
-#: cp/tree.c:3515
+#: cp/tree.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: cp/tree.c:3528 cp/tree.c:3541
+#: cp/tree.c:3556 cp/tree.c:3569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: cp/tree.c:3530
+#: cp/tree.c:3558
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%>不是一个有效的声明"
 
-#: cp/tree.c:3543
+#: cp/tree.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%>不是一个有效的声明"
 
-#: cp/tree.c:3567
+#: cp/tree.c:3595
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: cp/tree.c:3573
+#: cp/tree.c:3601
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.c:3579
+#: cp/tree.c:3607
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.c:3585
+#: cp/tree.c:3613
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.c:3608
+#: cp/tree.c:3636
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE属性只能用于函数"
 
-#: cp/tree.c:3614
+#: cp/tree.c:3642
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%qE属性只能用于函数"
 
-#: cp/tree.c:4314
+#: cp/tree.c:4342
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "数组边界不是一个整数常量"
 
-#: cp/tree.c:4327
+#: cp/tree.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check：在 %s 中失败，于 %s:%d"
@@ -42049,566 +42095,561 @@
 msgid "rank of the array%'s index is greater than 1"
 msgstr "数组元素的对齐边界比元素大小还要大"
 
-#: cp/typeck.c:3141
+#: cp/typeck.c:3148
 #, gcc-internal-format
-msgid "ISO C++ forbids subscripting non-lvalue array"
-msgstr "ISO C++ 不允许按下标访问非左值的数组"
-
-#: cp/typeck.c:3157
-#, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "按下标访问声明为%<register%>的数组"
 
-#: cp/typeck.c:3196
+#: cp/typeck.c:3187
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "下标运算的左操作数既非数组也非指针"
 
-#: cp/typeck.c:3269
+#: cp/typeck.c:3260
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "使用%qE时缺少对象"
 
-#: cp/typeck.c:3488
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ 不允许在程序里调用%<::main%>"
 
-#: cp/typeck.c:3509
+#: cp/typeck.c:3500
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "必须用%<.*%>or%<->*%>调用%<%E (...)%>中的成员函数指针，例如%<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3526
+#: cp/typeck.c:3517
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.c:3529
+#: cp/typeck.c:3520
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.c:3532
+#: cp/typeck.c:3523
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.c:3581
+#: cp/typeck.c:3572
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/typeck.c:3582
+#: cp/typeck.c:3573
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/typeck.c:3587
+#: cp/typeck.c:3578
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "提供给函数%qE的实参太多"
 
-#: cp/typeck.c:3588
+#: cp/typeck.c:3579
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "提供给函数%qE的实参太少"
 
-#: cp/typeck.c:3594
+#: cp/typeck.c:3585
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "给予函数的实参太多"
 
-#: cp/typeck.c:3595
+#: cp/typeck.c:3586
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "给予函数的实参太少"
 
-#: cp/typeck.c:3605
+#: cp/typeck.c:3596
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/typeck.c:3606
+#: cp/typeck.c:3597
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/typeck.c:3609
+#: cp/typeck.c:3600
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "给予函数的实参太多"
 
-#: cp/typeck.c:3610
+#: cp/typeck.c:3601
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "给予函数的实参太少"
 
-#: cp/typeck.c:3689
+#: cp/typeck.c:3680
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%2$qD的第 %1$P 个形参的类型%3$qT不完全"
 
-#: cp/typeck.c:3692
+#: cp/typeck.c:3683
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "形参 %P 的类型%qT不完全"
 
-#: cp/typeck.c:3999 cp/typeck.c:4010
+#: cp/typeck.c:3990 cp/typeck.c:4001
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "假定从重载函数转换到类型%qT"
 
-#: cp/typeck.c:4056
+#: cp/typeck.c:4047
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "算术表达式中使用了 NULL"
 
-#: cp/typeck.c:4367
+#: cp/typeck.c:4358
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "循环左移次数为负"
 
-#: cp/typeck.c:4368
+#: cp/typeck.c:4359
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "循环右移次数为负"
 
-#: cp/typeck.c:4374
+#: cp/typeck.c:4365
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "循环左移次数大于或等于类型宽度"
 
-#: cp/typeck.c:4375
+#: cp/typeck.c:4366
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "循环右移次数大于或等于类型宽度"
 
-#: cp/typeck.c:4396 cp/typeck.c:4651
+#: cp/typeck.c:4387 cp/typeck.c:4642
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behaviour"
 msgstr "与字面字符串比较的结构是不可预测的"
 
-#: cp/typeck.c:4422 cp/typeck.c:4444
+#: cp/typeck.c:4413 cp/typeck.c:4435
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "%qD的地址永远不会为 NULL"
 
-#: cp/typeck.c:4459 cp/typeck.c:4467 cp/typeck.c:4729 cp/typeck.c:4737
+#: cp/typeck.c:4450 cp/typeck.c:4458 cp/typeck.c:4720 cp/typeck.c:4728
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ 不允许比较指针和整数的值"
 
-#: cp/typeck.c:4666 cp/typeck.c:4678
+#: cp/typeck.c:4657 cp/typeck.c:4669
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "在%qT和%qT间比较"
 
-#: cp/typeck.c:4690
+#: cp/typeck.c:4681
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "找不到类%qE的接口"
 
-#: cp/typeck.c:4754
+#: cp/typeck.c:4745
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "非浮点实参间的无效比较"
 
-#: cp/typeck.c:4802
+#: cp/typeck.c:4793
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "操作数类型%qT和%qT对双目%qO而言无效"
 
-#: cp/typeck.c:5102
+#: cp/typeck.c:5093
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ 不允许在减法中使用类型为%<void *%>的指针"
 
-#: cp/typeck.c:5110
+#: cp/typeck.c:5101
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ 不允许在减法中使用函数指针"
 
-#: cp/typeck.c:5118
+#: cp/typeck.c:5109
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ 不允许在减法中使用指向方法的指针"
 
-#: cp/typeck.c:5137
+#: cp/typeck.c:5128
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "在指针算术中使用指向不完全类型的指针无效"
 
-#: cp/typeck.c:5210
+#: cp/typeck.c:5201
 #, gcc-internal-format
 msgid "taking address of constructor %qE"
 msgstr "取构造函数%qE的地址"
 
-#: cp/typeck.c:5211
+#: cp/typeck.c:5202
 #, gcc-internal-format
 msgid "taking address of destructor %qE"
 msgstr "取析构函数%qE的地址"
 
-#: cp/typeck.c:5227
+#: cp/typeck.c:5218
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "用%qE形成成员函数指针的用法无效"
 
-#: cp/typeck.c:5230
+#: cp/typeck.c:5221
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "需要一个限定的标识符"
 
-#: cp/typeck.c:5237
+#: cp/typeck.c:5228
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "%qE两边的括号不能用来构造一个成员函数指针"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5389
+#: cp/typeck.c:5380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允许通过提取一个未限定的或带括号的非静态成员函数的地址来形成一个成员函数指针。请使用%<&%T::%D%>"
 
-#: cp/typeck.c:5394
+#: cp/typeck.c:5385
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允许通过取已绑定的成员函数的地址来构造成员函数指针。请改用%<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5431
+#: cp/typeck.c:5422
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "取临时变量的地址"
 
-#: cp/typeck.c:5433
+#: cp/typeck.c:5424
 #, fuzzy, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "右值的引用用作左值"
 
-#: cp/typeck.c:5450
+#: cp/typeck.c:5441
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ 不允许取函数%<::main%>的地址"
 
-#: cp/typeck.c:5505
+#: cp/typeck.c:5496
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgstr "ISO C++ 不允许取转换到非左值表达式的地址"
 
-#: cp/typeck.c:5533
+#: cp/typeck.c:5524
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "不能创建指向引用成员%qD的指针"
 
-#: cp/typeck.c:5813
+#: cp/typeck.c:5804
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ 不允许枚举自增"
 
-#: cp/typeck.c:5814
+#: cp/typeck.c:5805
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ 不允许枚举自减"
 
-#: cp/typeck.c:5830
+#: cp/typeck.c:5821
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自增"
 
-#: cp/typeck.c:5831
+#: cp/typeck.c:5822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/typeck.c:5842
+#: cp/typeck.c:5833
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ 不允许对类型为%qT的指针自增"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5834
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ 不允许对类型为%qT的指针自减"
 
-#: cp/typeck.c:5878
+#: cp/typeck.c:5869
 #, gcc-internal-format
 msgid "invalid use of Boolean expression as operand to %<operator--%>"
 msgstr "布尔表达式不能用作%<运算符--%>的操作数"
 
-#: cp/typeck.c:6040
+#: cp/typeck.c:6031
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "无法取右值表达式%<this%>的地址"
 
-#: cp/typeck.c:6062
+#: cp/typeck.c:6053
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "要求显式寄存器变量%qD的地址。"
 
-#: cp/typeck.c:6067
+#: cp/typeck.c:6058
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "请求声明为%<register%>的%qD的地址"
 
-#: cp/typeck.c:6150
+#: cp/typeck.c:6141
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/typeck.c:6162
+#: cp/typeck.c:6153
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:6166
+#: cp/typeck.c:6157
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:6170
+#: cp/typeck.c:6161
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:6207
+#: cp/typeck.c:6198
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:6297
+#: cp/typeck.c:6288
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "缺少用以解析%qE类型的上下文"
 
-#: cp/typeck.c:6330
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的类型转换丢失了限定符"
 
-#: cp/typeck.c:6336
+#: cp/typeck.c:6327
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的 static_cast 丢失了限定符"
 
-#: cp/typeck.c:6342
+#: cp/typeck.c:6333
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的 reinterpret_cast 丢失了限定符"
 
-#: cp/typeck.c:6365
+#: cp/typeck.c:6356
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %qT"
 msgstr "向函数类型%qT的转换无效"
 
-#: cp/typeck.c:6732
+#: cp/typeck.c:6723
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 static_cast 无效"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6749
 #, gcc-internal-format
 msgid "converting from %qT to %qT"
 msgstr "从%qT转换到%qT"
 
-#: cp/typeck.c:6810
+#: cp/typeck.c:6801
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "从具有类型%qT的右值表达式到类型%qT中的转换无效"
 
-#: cp/typeck.c:6880
+#: cp/typeck.c:6871
 #, gcc-internal-format
 msgid "cast from %qT to %qT loses precision"
 msgstr "从%qT到%qT的转换损失精度"
 
-#: cp/typeck.c:6920
+#: cp/typeck.c:6911
 #, gcc-internal-format
 msgid "cast from %qT to %qT increases required alignment of target type"
 msgstr "从%qT到%qT的转换增大了目标类型的对齐需求"
 
-#: cp/typeck.c:6938
+#: cp/typeck.c:6929
 #, fuzzy, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ 不允许在函数指针和对象指针间进行转换"
 
-#: cp/typeck.c:6952
+#: cp/typeck.c:6943
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/typeck.c:7013
+#: cp/typeck.c:7004
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "在类型%qT上使用 const_cast 无效，因为它既不是指针，也不是引用，也不是数据成员指针"
 
-#: cp/typeck.c:7022
+#: cp/typeck.c:7013
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "在类型%qT上使用 const_cast 无效，因为它是一个指针函数类型的指针或引用"
 
-#: cp/typeck.c:7062
+#: cp/typeck.c:7053
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 const_cast 无效"
 
-#: cp/typeck.c:7123
+#: cp/typeck.c:7114
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 const_cast 无效"
 
-#: cp/typeck.c:7204 cp/typeck.c:7212
+#: cp/typeck.c:7195 cp/typeck.c:7203
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ 不允许转换为数组类型%qT"
 
-#: cp/typeck.c:7221
+#: cp/typeck.c:7212
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "向函数类型%qT的转换无效"
 
-#: cp/typeck.c:7502
+#: cp/typeck.c:7493
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "在求%<%Q(%#T, %#T)%>值时"
 
-#: cp/typeck.c:7563
+#: cp/typeck.c:7554
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "初始值设定中数组索引不是常数"
 
-#: cp/typeck.c:7589
+#: cp/typeck.c:7580
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "将%qT赋值给%qT时类型不兼容"
 
-#: cp/typeck.c:7603
+#: cp/typeck.c:7594
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "数组被用作初始值设定"
 
-#: cp/typeck.c:7605
+#: cp/typeck.c:7596
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "无效的数组赋值"
 
-#: cp/typeck.c:7712
+#: cp/typeck.c:7703
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "在成员函数指针转换中"
 
-#: cp/typeck.c:7726
+#: cp/typeck.c:7717
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "成员指针转换经由虚基类%qT"
 
-#: cp/typeck.c:7773 cp/typeck.c:7792
+#: cp/typeck.c:7764 cp/typeck.c:7783
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "在成员指针转换中"
 
-#: cp/typeck.c:7874
+#: cp/typeck.c:7865
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: cp/typeck.c:8156
+#: cp/typeck.c:8147
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "不能将%4$qD的实参%3$qP从%1$qT转换到%2$qT"
 
-#: cp/typeck.c:8162
+#: cp/typeck.c:8153
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "不能在参数默认时将%qT转换为%qT"
 
-#: cp/typeck.c:8166
+#: cp/typeck.c:8157
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "不能在传参时将%qT转换为%qT"
 
-#: cp/typeck.c:8170
+#: cp/typeck.c:8161
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "不能将%qT转换为%qT"
 
-#: cp/typeck.c:8174
+#: cp/typeck.c:8165
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "不能在初始化时将%qT转换为%qT"
 
-#: cp/typeck.c:8178
+#: cp/typeck.c:8169
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "不能在返回时将%qT转换为%qT"
 
-#: cp/typeck.c:8182
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "不能在赋值时将%qT转换为%qT"
 
-#: cp/typeck.c:8195
+#: cp/typeck.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "返回值类型%q#T不完全"
 
-#: cp/typeck.c:8213
+#: cp/typeck.c:8204
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "%2$qE的第 %1$d 个实参可能是 format 属性的备选"
 
-#: cp/typeck.c:8217
+#: cp/typeck.c:8208
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "%2$qE的第 %1$d 个实参可能是 format 属性的备选"
 
-#: cp/typeck.c:8222
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "%2$qE的第 %1$d 个实参可能是 format 属性的备选"
 
-#: cp/typeck.c:8227
+#: cp/typeck.c:8218
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "初始化的左手边可能是 format 属性的备选时"
 
-#: cp/typeck.c:8237
+#: cp/typeck.c:8228
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "赋值的左手边可能是 format 属性的备选时"
 
-#: cp/typeck.c:8330
+#: cp/typeck.c:8321
 #, gcc-internal-format
 msgid "in passing argument %P of %q+D"
 msgstr "在传递%2$q+D的第 %1$P 个实参时"
 
-#: cp/typeck.c:8389
+#: cp/typeck.c:8380
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "返回临时变量的引用"
 
-#: cp/typeck.c:8396
+#: cp/typeck.c:8387
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "返回了一个非左值的引用"
 
-#: cp/typeck.c:8409
+#: cp/typeck.c:8400
 #, gcc-internal-format
 msgid "reference to local variable %q+D returned"
 msgstr "返回了对局部变量的%q+D的引用"
 
-#: cp/typeck.c:8412
+#: cp/typeck.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %q+D returned"
 msgstr "返回了局部变量的%q+D的地址"
 
-#: cp/typeck.c:8415
+#: cp/typeck.c:8406
 #, gcc-internal-format
 msgid "address of local variable %q+D returned"
 msgstr "返回了局部变量的%q+D的地址"
 
-#: cp/typeck.c:8461
+#: cp/typeck.c:8452
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "析构函数返回值"
@@ -42615,45 +42656,45 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8469
+#: cp/typeck.c:8460
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "不能从构造函数的异常处理中返回"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8472
+#: cp/typeck.c:8463
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "构造函数返回值"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8495 cp/typeck.c:8539
+#: cp/typeck.c:8486 cp/typeck.c:8530
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/typeck.c:8503
+#: cp/typeck.c:8494
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "<花括号内的初始值列表>"
 
-#: cp/typeck.c:8558
+#: cp/typeck.c:8549
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "在返回‘void’的函数中，返回语句带返回值"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%>不能返回 NULL，除非它被声明为%<throw()%>(或 -fcheck-new 起作用)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9200
+#: cp/typeck.c:9191
 #, fuzzy, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "右值的引用用作左值"
 
-#: cp/typeck.c:9202
+#: cp/typeck.c:9193
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "右值的引用用作左值"
@@ -42882,123 +42923,123 @@
 msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgstr "在 {} 内将%qE从%qT转换为较窄的类型%qT"
 
-#: cp/typeck2.c:954 cp/typeck2.c:961
+#: cp/typeck2.c:954 cp/typeck2.c:964
 #, gcc-internal-format
 msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgstr "在 {} 内将%qE从%qT转换为较窄的类型%qT"
 
-#: cp/typeck2.c:1026
+#: cp/typeck2.c:1033
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int 型数组由非宽字符串初始化"
 
-#: cp/typeck2.c:1032
+#: cp/typeck2.c:1039
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "int 型数组不兼容的宽字符串初始化"
 
-#: cp/typeck2.c:1052
+#: cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "用以初始化字符数组的字符串太长"
 
-#: cp/typeck2.c:1100
+#: cp/typeck2.c:1120
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "无法用复合字面常量初始化类型为%qT的聚集"
 
-#: cp/typeck2.c:1118
+#: cp/typeck2.c:1138
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "数组必须为一个由花括号包围的初始值设定所初始化"
 
-#: cp/typeck2.c:1401 cp/typeck2.c:1425
+#: cp/typeck2.c:1421 cp/typeck2.c:1445
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成员%qD缺少初始值设定"
 
-#: cp/typeck2.c:1408
+#: cp/typeck2.c:1428
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.c:1415
+#: cp/typeck2.c:1435
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.c:1501
+#: cp/typeck2.c:1521
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的联合中找不到字段%qD"
 
-#: cp/typeck2.c:1512
+#: cp/typeck2.c:1532
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在联合初始值设定中出现了索引值而不是字段名"
 
-#: cp/typeck2.c:1694
+#: cp/typeck2.c:1714
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "检测到循环指针代理"
 
-#: cp/typeck2.c:1708
+#: cp/typeck2.c:1728
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%>的基操作数具有非指针类型%qT"
 
-#: cp/typeck2.c:1734
+#: cp/typeck2.c:1754
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%>的结果给出了非指针的结果"
 
-#: cp/typeck2.c:1736
+#: cp/typeck2.c:1756
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%>的左操作数不是一个指针"
 
-#: cp/typeck2.c:1763
+#: cp/typeck2.c:1783
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE不能用作成员指针，因为它的类型为%qT"
 
-#: cp/typeck2.c:1772
+#: cp/typeck2.c:1792
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "无法将成员指针%qE应用到%qE上，因为后者的类型%qT不是一个类"
 
-#: cp/typeck2.c:1794
+#: cp/typeck2.c:1814
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成员指针类型%qT与对象类型%qT不兼容"
 
-#: cp/typeck2.c:1853
+#: cp/typeck2.c:1873
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "在算术表达式中使用了成员指针"
 
-#: cp/typeck2.c:1860
+#: cp/typeck2.c:1880
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "在算术表达式中使用了成员指针"
 
-#: cp/typeck2.c:1901
+#: cp/typeck2.c:1921
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "向函数类型%qT的转换无效"
 
-#: cp/typeck2.c:1922
+#: cp/typeck2.c:1942
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "引用类型的非法值初始化"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2168
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "调用的函数%qD会抛出不完全的类型%q#T"
 
-#: cp/typeck2.c:2151
+#: cp/typeck2.c:2171
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "调用的函数会抛出不完全的类型%q#T"
@@ -43183,8 +43224,8 @@
 
 #: fortran/array.c:213 fortran/array.c:596 fortran/check.c:2581
 #: fortran/check.c:4859 fortran/check.c:4897 fortran/check.c:4939
-#: fortran/check.c:5138 fortran/match.c:1677 fortran/match.c:2778
-#: fortran/match.c:2974 fortran/simplify.c:4646
+#: fortran/check.c:5138 fortran/match.c:1680 fortran/match.c:2781
+#: fortran/match.c:2977 fortran/simplify.c:4646
 #, fuzzy, gcc-internal-format
 #| msgid "Coarrays disabled at %C, use -fcoarray= to enable"
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
@@ -43322,7 +43363,7 @@
 msgid "Array constructor including type specification at %C"
 msgstr "Fortran 2003：%C处包含类型规格的数组构造"
 
-#: fortran/array.c:1092 fortran/match.c:3404
+#: fortran/array.c:1092 fortran/match.c:3407
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
@@ -43445,7 +43486,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "实参‘%s’(属于内建函数‘%s’，位于 %L)必须为 INTEGER 或 PROCEDURE"
 
-#: fortran/check.c:167 fortran/check.c:6243
+#: fortran/check.c:167 fortran/check.c:6252
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -44084,12 +44125,12 @@
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "‘shape’内建函数的‘source’实参在%L处不能是假定大小的数组"
 
-#: fortran/check.c:4097 fortran/check.c:6226
+#: fortran/check.c:4097 fortran/check.c:6235
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个标量"
 
-#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6218
+#: fortran/check.c:4110 fortran/check.c:4249 fortran/check.c:6227
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’不能是 INTENT(IN)"
@@ -44368,6 +44409,11 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "实参‘%s’(属于内建函数‘%s’，位于 %L)必须为 INTEGER 或 LOGICAL"
 
+#: fortran/check.c:6219
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
 #: fortran/class.c:614
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
@@ -44375,7 +44421,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:725 fortran/decl.c:7811
+#: fortran/class.c:725 fortran/decl.c:7810
 #, fuzzy, gcc-internal-format
 #| msgid "Maximum extension level reached with type '%s' at %L"
 msgid "Maximum extension level reached with type %qs at %L"
@@ -44606,413 +44652,413 @@
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "%2$C处有初始值设定的变量‘%1$s’已经出现在一个 DATA 语句中"
 
-#: fortran/decl.c:1450
+#: fortran/decl.c:1448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "不能用初始值设定项来初始化多维数组"
 
-#: fortran/decl.c:1468
+#: fortran/decl.c:1466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "%C处数据声明语法错误"
 
-#: fortran/decl.c:1563
+#: fortran/decl.c:1561
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "%C处的组件必须有 POINTER 属性"
 
-#: fortran/decl.c:1571
+#: fortran/decl.c:1569
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "%C处结构的数组组件必须有显式或延迟的外形"
 
-#: fortran/decl.c:1652
+#: fortran/decl.c:1650
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "%C处结构的指针数组组件必须有延迟的外形"
 
-#: fortran/decl.c:1661
+#: fortran/decl.c:1659
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1668
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "%C处结构的数组组件必须有显式的外形"
 
-#: fortran/decl.c:1724
+#: fortran/decl.c:1722
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "%C处的 NULL() 初始化有歧义"
 
-#: fortran/decl.c:1741
+#: fortran/decl.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "%C处的 NULL() 初始化有歧义"
 
-#: fortran/decl.c:1758
+#: fortran/decl.c:1756
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "%C处对指针的初始化不允许出现在 PURE 过程中"
 
-#: fortran/decl.c:1779
+#: fortran/decl.c:1777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "%C处过程指针组件语法错误"
 
-#: fortran/decl.c:1786
+#: fortran/decl.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Fortran 2003：%C处的的 FINAL 过程声明"
 
-#: fortran/decl.c:1809
+#: fortran/decl.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "Function name %qs not allowed at %C"
 msgstr "函数名‘%s’不允许出现在%C处"
 
-#: fortran/decl.c:1876
+#: fortran/decl.c:1874
 #, fuzzy, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr "指定CHARACTER(*) 函数‘%s’在%L处不能为指针值"
 
-#: fortran/decl.c:1886
+#: fortran/decl.c:1884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Fortran 2008：%L处格式中的‘G0’"
 
-#: fortran/decl.c:1951 fortran/decl.c:6680
+#: fortran/decl.c:1949 fortran/decl.c:6678
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "%C处 Cray 指针重复指定了数组"
 
-#: fortran/decl.c:1959
+#: fortran/decl.c:1957
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2022
+#: fortran/decl.c:2020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "扩展：%C处旧式的初始化"
 
-#: fortran/decl.c:2027
+#: fortran/decl.c:2025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "引用类型的非法值初始化"
 
-#: fortran/decl.c:2044 fortran/decl.c:5055
+#: fortran/decl.c:2042 fortran/decl.c:5053
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%C处的初始化不是为指针变量准备的"
 
-#: fortran/decl.c:2057
+#: fortran/decl.c:2055
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "在%C处的指针初始化需要‘=>’，而不是‘=’"
 
-#: fortran/decl.c:2066 fortran/decl.c:7960
+#: fortran/decl.c:2064 fortran/decl.c:7959
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "%C处需要一个初始化表达式"
 
-#: fortran/decl.c:2073
+#: fortran/decl.c:2071
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "%C处对变量的初始化不允许出现在 PURE 过程中"
 
-#: fortran/decl.c:2090
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "不允许在%C处初始化可分配的组件"
 
-#: fortran/decl.c:2144 fortran/decl.c:2180
+#: fortran/decl.c:2142 fortran/decl.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "%3$C处旧式的类型声明 %1$s*%2$d 不受支持"
 
-#: fortran/decl.c:2186
+#: fortran/decl.c:2184
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "%3$C处的 %1$s*%2$d 类型声明不符合标准"
 
-#: fortran/decl.c:2237 fortran/decl.c:2313
+#: fortran/decl.c:2235 fortran/decl.c:2311
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "%C处缺少右括号"
 
-#: fortran/decl.c:2250 fortran/decl.c:2384
+#: fortran/decl.c:2248 fortran/decl.c:2382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "%C处需要初始化表达式"
 
-#: fortran/decl.c:2258 fortran/decl.c:2390
+#: fortran/decl.c:2256 fortran/decl.c:2388
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "%C处需要标量初始化表达式"
 
-#: fortran/decl.c:2289
+#: fortran/decl.c:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "种别 %1$d 不为类型%3$C处 %2$s 所支持"
 
-#: fortran/decl.c:2302
+#: fortran/decl.c:2300
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "C 种别类型参数对应类型 %s 但%L处的类型却是 %s"
 
-#: fortran/decl.c:2311
+#: fortran/decl.c:2309
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "%C处缺少右括号或逗号"
 
-#: fortran/decl.c:2410
+#: fortran/decl.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "种别 %d 在%C处不为 CHARACTER 所支持"
 
-#: fortran/decl.c:2542
+#: fortran/decl.c:2540
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "%C处 CHARACTER 声明语法错误"
 
-#: fortran/decl.c:2627
+#: fortran/decl.c:2625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "扩展：%C处的 BYTE 类型"
 
-#: fortran/decl.c:2632
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "%C处使用到的 BYTE 类型在目标机上不可用"
 
-#: fortran/decl.c:2654
+#: fortran/decl.c:2652
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "%L处上下文中不允许使用按值传递的实参"
 
-#: fortran/decl.c:2657
+#: fortran/decl.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:2680 fortran/decl.c:2711 fortran/decl.c:2740
-#: fortran/decl.c:2919
+#: fortran/decl.c:2678 fortran/decl.c:2709 fortran/decl.c:2738
+#: fortran/decl.c:2917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "Fortran 2003：%C处的 VOLATILE 属性"
 
-#: fortran/decl.c:2736
+#: fortran/decl.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "扩展：‘%s’重初始化于 %L"
 
-#: fortran/decl.c:2810
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "Fortran 2003：%C处的 CLASS 语句"
 
-#: fortran/decl.c:2845 fortran/decl.c:2858 fortran/decl.c:3303
-#: fortran/decl.c:3311
+#: fortran/decl.c:2843 fortran/decl.c:2856 fortran/decl.c:3301
+#: fortran/decl.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "%2$C处的类型名‘%1$s’有歧义"
 
-#: fortran/decl.c:2873
+#: fortran/decl.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:2986
+#: fortran/decl.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "%C处 IMPLICIT NONE 语句重复"
 
-#: fortran/decl.c:2995
+#: fortran/decl.c:2993
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:3054
+#: fortran/decl.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "%C处 IMPLICIT 缺少字符范围"
 
-#: fortran/decl.c:3100
+#: fortran/decl.c:3098
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "%C处 IMPLICIT 语句中的字母必须按序排列"
 
-#: fortran/decl.c:3153
+#: fortran/decl.c:3151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "%C处 SAVE 语句跟随空白 SAVE 语句"
 
-#: fortran/decl.c:3163
+#: fortran/decl.c:3161
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "%C处 IMPLICIT 语句为空"
 
-#: fortran/decl.c:3269
+#: fortran/decl.c:3267
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "%C处 IMPORT 语句只允许出现在接口体中"
 
-#: fortran/decl.c:3274
+#: fortran/decl.c:3272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "%C处 IMPLICIT 语句为空"
 
-#: fortran/decl.c:3288
+#: fortran/decl.c:3286
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "%C处需要有名实体列表"
 
-#: fortran/decl.c:3317
+#: fortran/decl.c:3315
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot IMPORT '%s' from host scoping unit at %C - does not exist."
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "不能从%2$C处主机作用域单元 IMPORT‘%1$s’- 不存在。"
 
-#: fortran/decl.c:3324
+#: fortran/decl.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is already IMPORTed from host scoping unit at %C."
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "‘%s’已经从%C处主机作用域单元导入。"
 
-#: fortran/decl.c:3367
+#: fortran/decl.c:3365
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "%C处的 IMPORT 语句语法错误"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "%C处没有指定维数"
 
-#: fortran/decl.c:3668
+#: fortran/decl.c:3666
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "%C处没有维数规格"
 
-#: fortran/decl.c:3751
+#: fortran/decl.c:3749
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "重复的 %s 属性，位于 %L"
 
-#: fortran/decl.c:3770
+#: fortran/decl.c:3768
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003：%C处的 ALLOCATABLE 属性出现在 TYPE 定义中"
 
-#: fortran/decl.c:3779
+#: fortran/decl.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:3797
+#: fortran/decl.c:3795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003：属性 %s 在%L处出现在 TYPE 定义中"
 
-#: fortran/decl.c:3807
+#: fortran/decl.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%2$L处的 %1$s 属性不允许出现在模块规格说明以外"
 
-#: fortran/decl.c:3821
+#: fortran/decl.c:3819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Fortran 2003：%C处的 ASYNCHRONOUS 属性"
 
-#: fortran/decl.c:3832
+#: fortran/decl.c:3830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Fortran 2003：%C处的 PROTECT 属性"
 
-#: fortran/decl.c:3877 fortran/decl.c:6975
+#: fortran/decl.c:3875 fortran/decl.c:6974
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "%C处的 PROTECTED 仅允许出现在模块规格说明部分内"
 
-#: fortran/decl.c:3883
+#: fortran/decl.c:3881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003：%C处的 PROTECT 属性"
 
-#: fortran/decl.c:3912
+#: fortran/decl.c:3910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003：%C处的 VALUE 属性"
 
-#: fortran/decl.c:3919
+#: fortran/decl.c:3917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003：%C处的 VOLATILE 属性"
 
-#: fortran/decl.c:3926
+#: fortran/decl.c:3924
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:3964
+#: fortran/decl.c:3962
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "%C处为单个 NAME= 指定了多个标识符"
 
-#: fortran/decl.c:4062
+#: fortran/decl.c:4060
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly declared BIND(C) function '%s' at %L may not be C interoperable"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "%2$L处隐式声明的 BIND(C) 函数‘%1$s’不能与 C 互操作"
 
-#: fortran/decl.c:4084
+#: fortran/decl.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L may not be a C interoperable kind though common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "%3$L处的公共块‘%2$s’中的变量‘%1$s’可能不是 C 互操作种别，即使公共块‘%4$s’是 BIND(C)"
 
-#: fortran/decl.c:4093
+#: fortran/decl.c:4091
 #, fuzzy, gcc-internal-format
 #| msgid "Type declaration '%s' at %L is not C interoperable but it is BIND(C)"
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "%2$L处的类型声明‘%1$s’不是与 C 可互操作的，但它是个 BIND(C)"
 
-#: fortran/decl.c:4097
+#: fortran/decl.c:4095
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L may not be a C interoperable kind but it is bind(c)"
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "%2$L处的变量‘%1$s’无法与 C 互操作但被声明为 BIND(C)"
 
-#: fortran/decl.c:4109
+#: fortran/decl.c:4107
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L cannot be declared with BIND(C) since it is not a global"
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "%3$L处的公共块‘%2$s’中的变量‘%1$s’不能被声明为 BIND(C)，因为它不是全局的"
 
-#: fortran/decl.c:4123
+#: fortran/decl.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/decl.c:4131
+#: fortran/decl.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/decl.c:4143
+#: fortran/decl.c:4141
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "%2$L处的BIND(C) 函数‘%1$s’不能返回一个数组"
 
-#: fortran/decl.c:4151
+#: fortran/decl.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -45020,827 +45066,832 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:4162
+#: fortran/decl.c:4160
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is marked PRIVATE but has been given the binding label '%s'"
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "%2$L处符号‘%1$s’被标记为 PRIVATE 但是已经给定绑定标号‘%3$s’"
 
-#: fortran/decl.c:4236
+#: fortran/decl.c:4234
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "%C处的属性规格说明语句需要实体或公共块名"
 
-#: fortran/decl.c:4281
+#: fortran/decl.c:4279
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "%C处的属性规格说明语句缺少实体或公共块名"
 
-#: fortran/decl.c:4288
+#: fortran/decl.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "缺少数字"
 
-#: fortran/decl.c:4317
+#: fortran/decl.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "%C处 IMPLICIT 语句为空"
 
-#: fortran/decl.c:4395
+#: fortran/decl.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "%C处的派生类型以前尚未被定义，因此不能出现在派生类型定义中"
 
-#: fortran/decl.c:4427
+#: fortran/decl.c:4425
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "%C处数据声明语法错误"
 
-#: fortran/decl.c:4500
+#: fortran/decl.c:4498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "Fortran 2003：%C处的 PROCEDURE 语句"
 
-#: fortran/decl.c:4512
+#: fortran/decl.c:4510
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:4580 fortran/primary.c:1719
+#: fortran/decl.c:4578 fortran/primary.c:1719
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "%C处需要替代的返回标号"
 
-#: fortran/decl.c:4626
+#: fortran/decl.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "%2$C处的名字‘%1$s’是一个过程的名字"
 
-#: fortran/decl.c:4638
+#: fortran/decl.c:4636
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "%C处形参列表中有非预期的垃圾字符"
 
-#: fortran/decl.c:4655
+#: fortran/decl.c:4653
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "符号‘%s’在%C处的形参列表中重复出现"
 
-#: fortran/decl.c:4705
+#: fortran/decl.c:4703
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "%C处 RESULT 变量不能与函数重名"
 
-#: fortran/decl.c:4782
+#: fortran/decl.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "%C处的函数声明后有非预期的垃圾字符"
 
-#: fortran/decl.c:4792 fortran/decl.c:5858
+#: fortran/decl.c:4790 fortran/decl.c:5856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008：%L处的 BIND(C)属性对于内部过程不可以指定"
 
-#: fortran/decl.c:4994
+#: fortran/decl.c:4992
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "%C处的 BIND(C) 属性要求一个具有 BIND(C)的接口"
 
-#: fortran/decl.c:5001
+#: fortran/decl.c:4999
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "%C处带有 NAME 的 BIND(C)过程不能有 POINTER 属性"
 
-#: fortran/decl.c:5007
+#: fortran/decl.c:5005
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "%C处的哑过程不能有带有 NAME 的 BIND(C) 属性"
 
-#: fortran/decl.c:5030
+#: fortran/decl.c:5028
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "符号‘%s’在%L处已经有了基本类型 %s"
 
-#: fortran/decl.c:5076 fortran/decl.c:5264 fortran/decl.c:8441
+#: fortran/decl.c:5074 fortran/decl.c:5262 fortran/decl.c:8440
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:5125 fortran/decl.c:8343
+#: fortran/decl.c:5123 fortran/decl.c:8342
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%C处绑定属性后需要‘::’"
 
-#: fortran/decl.c:5132
+#: fortran/decl.c:5130
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/decl.c:5136
+#: fortran/decl.c:5134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Fortran 2003：%C处的过程指针组件"
 
-#: fortran/decl.c:5208
+#: fortran/decl.c:5206
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "%C处过程指针组件语法错误"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "%C处的 PROCEDURE 必须在一个泛型接口内"
 
-#: fortran/decl.c:5235 fortran/decl.c:7472
+#: fortran/decl.c:5233 fortran/decl.c:7471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:5304
+#: fortran/decl.c:5302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003：%C处的 PROCEDURE 语句"
 
-#: fortran/decl.c:5371
+#: fortran/decl.c:5369
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "函数定义在%C处需要形参列表"
 
-#: fortran/decl.c:5395 fortran/decl.c:5399 fortran/decl.c:5633
-#: fortran/decl.c:5637 fortran/decl.c:5826 fortran/decl.c:5830
-#: fortran/symbol.c:1612
+#: fortran/decl.c:5393 fortran/decl.c:5397 fortran/decl.c:5631
+#: fortran/decl.c:5635 fortran/decl.c:5824 fortran/decl.c:5828
+#: fortran/symbol.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "%L处的 BIND(C) 属性只能用于变量或公共块"
 
-#: fortran/decl.c:5545
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "%C处 IMPLICIT 语句为空"
 
-#: fortran/decl.c:5554
+#: fortran/decl.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "%C处的 ENTRY 语句不能出现在 PROGRAM 中"
 
-#: fortran/decl.c:5557
+#: fortran/decl.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "%C处的 ENTRY 语句不能出现在 MODULE 中"
 
-#: fortran/decl.c:5560
+#: fortran/decl.c:5558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "%C处的 ENTRY 语句不能出现在 BLOCK DATA 中"
 
-#: fortran/decl.c:5564
+#: fortran/decl.c:5562
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "%C处的 ENTRY 语句不能出现在 INTERFACE 中"
 
-#: fortran/decl.c:5568
+#: fortran/decl.c:5566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "%C处的 ENTRY 语句不能出现在 DERIVED TYPE 块中"
 
-#: fortran/decl.c:5572
+#: fortran/decl.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "%C处的 ENTRY 语句不能出现在 IF-THEN 块中"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5575
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "%C处的 ENTRY 语句不能出现在 DO 块中"
 
-#: fortran/decl.c:5581
+#: fortran/decl.c:5579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "%C处的 ENTRY 语句不能出现在 SELECT 块中"
 
-#: fortran/decl.c:5585
+#: fortran/decl.c:5583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "%C处的 ENTRY 语句不能出现在 FORALL 块中"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "%C处的 ENTRY 语句不能出现在 WHERE 块中"
 
-#: fortran/decl.c:5593
+#: fortran/decl.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "%C处的 ENTRY 语句不能出现在嵌套的子程序中"
 
-#: fortran/decl.c:5597
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
-msgid "gfc_match_entry(): Bad state"
-msgstr "gfc_trans_code()：错误的语句代码"
+#: fortran/decl.c:5595
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Unexpected END statement at %C"
+msgid "Unexpected ENTRY statement at %C"
+msgstr "%C处非预期的 END 语句"
 
-#: fortran/decl.c:5611
+#: fortran/decl.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%C处 ENTRY 语句不能出现在被包含的过程中"
 
-#: fortran/decl.c:5662 fortran/decl.c:5865
+#: fortran/decl.c:5660 fortran/decl.c:5863
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "%C 处 BIND(C) 前缺少要求的括号"
 
-#: fortran/decl.c:5922 fortran/decl.c:5929
+#: fortran/decl.c:5920 fortran/decl.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid C name in NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "%C处 NAME= 限定符中 C 名字无效"
 
-#: fortran/decl.c:5969
+#: fortran/decl.c:5967
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "%C绑定标号的 NAME= 限定符语法错误"
 
-#: fortran/decl.c:5985
+#: fortran/decl.c:5983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "必须为%L处的 ASYNCHRONOUS= 指定一个初始化表达式"
 
-#: fortran/decl.c:5993
+#: fortran/decl.c:5991
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:6012
+#: fortran/decl.c:6010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "%C处绑定标号缺少右括号"
 
-#: fortran/decl.c:6018
+#: fortran/decl.c:6016
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "%C处的 BIND(C) 中不允许有绑定名"
 
-#: fortran/decl.c:6024
+#: fortran/decl.c:6022
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "对于哑过程 %s，%C 处的 BIND(C) 中不允许有绑定名"
 
-#: fortran/decl.c:6053
+#: fortran/decl.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "%C 处的 ABSTRACT INTERFACE 的 BIND(C)上不允许有 NAME"
 
-#: fortran/decl.c:6260
+#: fortran/decl.c:6258
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "%C处非预期的 END 语句"
 
-#: fortran/decl.c:6269
+#: fortran/decl.c:6267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "Fortran 2008：%C处 CONTAINS 语句没有 FUNCTION 或 SUBROUTINE 语句"
 
 #. We would have required END [something].
-#: fortran/decl.c:6277
+#: fortran/decl.c:6275
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "需要 %s 语句在%L处"
 
-#: fortran/decl.c:6288
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "需要 %s 语句，于 %C"
 
-#: fortran/decl.c:6306
+#: fortran/decl.c:6304
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "需要块名‘%s’在‘%s’表达式中，于 %C"
 
-#: fortran/decl.c:6323
+#: fortran/decl.c:6321
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "%C处需要结束名"
 
-#: fortran/decl.c:6332 fortran/decl.c:6340
+#: fortran/decl.c:6330 fortran/decl.c:6338
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "需要标号‘%s’，为 %s 语句，于 %C"
 
-#: fortran/decl.c:6437
+#: fortran/decl.c:6435
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "%L处的 DIMENSION 语句缺少数组规格"
 
-#: fortran/decl.c:6445
+#: fortran/decl.c:6443
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialisation"
 msgstr "%2$L处在初始化后为 %1$s 指定了维数"
 
-#: fortran/decl.c:6453
+#: fortran/decl.c:6451
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "%L处的 DIMENSION 语句缺少数组指定"
 
-#: fortran/decl.c:6462
+#: fortran/decl.c:6460
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "%L处数组规格必须延迟"
 
-#: fortran/decl.c:6560
+#: fortran/decl.c:6558
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "%C处变量列表中有非预期的垃圾字符"
 
-#: fortran/decl.c:6597
+#: fortran/decl.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "在%C处需要‘(’"
 
-#: fortran/decl.c:6611 fortran/decl.c:6651
+#: fortran/decl.c:6609 fortran/decl.c:6649
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "在%C处需要变量名"
 
-#: fortran/decl.c:6627
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "%C处 Cray 指针必须是一个整数"
 
-#: fortran/decl.c:6631
+#: fortran/decl.c:6629
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "%C处的 Cray 指针精度为 %d；内存地址需要 %d 字节"
 
-#: fortran/decl.c:6637
+#: fortran/decl.c:6635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:6676
+#: fortran/decl.c:6674
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:6700
+#: fortran/decl.c:6698
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "在%C处需要“)”"
 
-#: fortran/decl.c:6712
+#: fortran/decl.c:6710
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "在%C处需要“,”或语句尾"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6736
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:6770
+#: fortran/decl.c:6768
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:6789
+#: fortran/decl.c:6787
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "%C处的 Cray 指针声明需要 -fcray-pointer 标记"
 
-#: fortran/decl.c:6828
+#: fortran/decl.c:6826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "Fortran 2003：%C处的 IMPORT 语句"
 
-#: fortran/decl.c:6926
+#: fortran/decl.c:6924
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "%2$C处的 %1$s 运算符的访问规格说明已经被指定"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6941
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "%2$C处的 .%1$s. 运算符的访问规格说明已经被指定"
 
-#: fortran/decl.c:6981
+#: fortran/decl.c:6980
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003：%C处的 PROTECTED 语句"
 
-#: fortran/decl.c:7019
+#: fortran/decl.c:7018
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/decl.c:7043
+#: fortran/decl.c:7042
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "%C处的 PRIVATE 语句仅允许出现在模块规格说明部分内"
 
-#: fortran/decl.c:7080
+#: fortran/decl.c:7079
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "%C处的 PUBLIC 语句只不允许出现在模块规格说明部分内"
 
-#: fortran/decl.c:7108
+#: fortran/decl.c:7107
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "%C处的 PARAMETER 语句需要变量名"
 
-#: fortran/decl.c:7115
+#: fortran/decl.c:7114
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "%C 在 PARAMETER 语句中需要 = 符号"
 
-#: fortran/decl.c:7121
+#: fortran/decl.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "%C 在 PARAMETER 语句中需要表达式"
 
-#: fortran/decl.c:7141
+#: fortran/decl.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "%C处初始化已经初始化的变量"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "%C处 PARAMETER 语句中有非预期的字符"
 
-#: fortran/decl.c:7200
+#: fortran/decl.c:7199
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "%C处覆盖 SAVE 语句跟随以前的 SAVE 语句"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7210
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "%C处 SAVE 语句跟随空白 SAVE 语句"
 
-#: fortran/decl.c:7257
+#: fortran/decl.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "%C SAVE 语句语法错误"
 
-#: fortran/decl.c:7271
+#: fortran/decl.c:7270
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:7275
+#: fortran/decl.c:7274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003：%C处的 VALUE 语句"
 
-#: fortran/decl.c:7313
+#: fortran/decl.c:7312
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "%C处 VALUE 语句语法错误"
 
-#: fortran/decl.c:7324
+#: fortran/decl.c:7323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003：%C处的 VOLATILE 语句"
 
-#: fortran/decl.c:7347
+#: fortran/decl.c:7346
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:7372
+#: fortran/decl.c:7371
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/decl.c:7383
+#: fortran/decl.c:7382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Fortran 2003：%C处的 ASYNCHRONOUS 语句"
 
-#: fortran/decl.c:7423
+#: fortran/decl.c:7422
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "%C处 ASYNCHRONOUS 语句语法错误"
 
-#: fortran/decl.c:7447
+#: fortran/decl.c:7446
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "%C处的 MODULE PROCEDURE 必须在一个泛型接口内"
 
-#: fortran/decl.c:7505
+#: fortran/decl.c:7504
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "%L处内建过程不能是 MODULE PROCEDURE"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7553
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "%C处 TYPE 定义中的歧义符号"
 
-#: fortran/decl.c:7563
+#: fortran/decl.c:7562
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "%2$C处符号‘%1$s’已经与主机相关联"
 
-#: fortran/decl.c:7569
+#: fortran/decl.c:7568
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in EXTENDS expression at %C is not a derived type"
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "%2$C处 EXTENDS 表达式中的‘%1$s’不是一个派生类型"
 
-#: fortran/decl.c:7576
+#: fortran/decl.c:7575
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is BIND(C)"
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%2$C 处‘%1$s’不能被扩展，因为它是 BIND(C)"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7582
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is a SEQUENCE type"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%2$C 处‘%1$s’不能被扩展，因为它是 SEQUENCE 类型"
 
-#: fortran/decl.c:7606
+#: fortran/decl.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "%C处的派生类型在模块规格说明部分内只能是 PRIVATE"
 
-#: fortran/decl.c:7618
+#: fortran/decl.c:7617
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "%C处的派生类型在模块规格说明部分内只能是 PUBLIC"
 
-#: fortran/decl.c:7639
+#: fortran/decl.c:7638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "%2$L处使用了 ABSTRACT 类型‘%1$s’"
 
-#: fortran/decl.c:7703
+#: fortran/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "%C 在 TYPE 定义中需要 ::"
 
-#: fortran/decl.c:7714
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "类型‘%s’(位于 %C)不能与内建类型重名"
 
-#: fortran/decl.c:7724
+#: fortran/decl.c:7723
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "%2$C处的派生类型名“%1$s”已经有一个基本类型 %3$s"
 
-#: fortran/decl.c:7741
+#: fortran/decl.c:7740
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%2$C处的派生类型‘%1$s’定义已经被定义"
 
-#: fortran/decl.c:7846
+#: fortran/decl.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "%C处 Cray 指针不能指向假定外形数组"
 
-#: fortran/decl.c:7866
+#: fortran/decl.c:7865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003：%C处的 ENUM 和 ENUMERATOR"
 
-#: fortran/decl.c:7898
+#: fortran/decl.c:7897
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "%C处：枚举量超过 C 整数类型"
 
-#: fortran/decl.c:7977
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L没有用整数表达式初始化"
 
-#: fortran/decl.c:8025
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "%C 前需要 ENUM 定义语句"
 
-#: fortran/decl.c:8061
+#: fortran/decl.c:8060
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "%C处 ENUMERATOR 定义中语法错误"
 
-#: fortran/decl.c:8108 fortran/decl.c:8123
+#: fortran/decl.c:8107 fortran/decl.c:8122
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "%C处重复访问限定符"
 
-#: fortran/decl.c:8143
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "捆绑属性已经指定传递，%C处 NOPASS 非法"
 
-#: fortran/decl.c:8163
+#: fortran/decl.c:8162
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "捆绑属性已经指定传递， %C处 PASS 非法"
 
-#: fortran/decl.c:8190
+#: fortran/decl.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "%C处 POINTER 属性重复"
 
-#: fortran/decl.c:8208
+#: fortran/decl.c:8207
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "%C处 NON_OVERRIDABLE 重复"
 
-#: fortran/decl.c:8224
+#: fortran/decl.c:8223
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "%C处重复的 DEFERRED 语句"
 
-#: fortran/decl.c:8237
+#: fortran/decl.c:8236
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "%C需要访问限定符"
 
-#: fortran/decl.c:8239
+#: fortran/decl.c:8238
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "%C处需要绑定属性"
 
-#: fortran/decl.c:8247
+#: fortran/decl.c:8246
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE 和 DEFERRED 不能同时出现在%C处"
 
-#: fortran/decl.c:8259
+#: fortran/decl.c:8258
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "%C处的过程指针组件需要 POINTER 属性"
 
-#: fortran/decl.c:8301
+#: fortran/decl.c:8300
 #, fuzzy, gcc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "%C处‘(’后需要接口名"
 
-#: fortran/decl.c:8307
+#: fortran/decl.c:8306
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected at %C"
 msgid "%<)%> expected at %C"
 msgstr "在 %C 处需要‘)’"
 
-#: fortran/decl.c:8327
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "%C处必须为 DEFERRED 绑定指定接口"
 
-#: fortran/decl.c:8332
+#: fortran/decl.c:8331
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "%C处的 PROCEDURE(接口) 需要声明为 DEFERRED"
 
-#: fortran/decl.c:8355
+#: fortran/decl.c:8354
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "%C处需要绑定名"
 
-#: fortran/decl.c:8359
+#: fortran/decl.c:8358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "Fortran 2003：%C处的 PROCEDURE 语句"
 
-#: fortran/decl.c:8371
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format
 #| msgid "'=> target' is invalid for DEFERRED binding at %C"
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "‘=> target’对%C处的 DEFERRED 绑定而言无效"
 
-#: fortran/decl.c:8377
+#: fortran/decl.c:8376
 #, fuzzy, gcc-internal-format
 #| msgid "'::' needed in PROCEDURE binding with explicit target at %C"
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%C处与显式目标捆绑的 PROCEDURE 中需要‘::’"
 
-#: fortran/decl.c:8387
+#: fortran/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "%C处‘=>’之后需要绑定目标"
 
-#: fortran/decl.c:8404
+#: fortran/decl.c:8403
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' containing DEFERRED binding at %C is not ABSTRACT"
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "%2$C处包含 DEFERRED 绑定的类型‘%1$s’不能是 ABSTRACT"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8414
 #, fuzzy, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "在 %3$C 处对于派生类型“%2$s”已经有一个非普通的过程用限定名“%1$s”"
 
-#: fortran/decl.c:8464
+#: fortran/decl.c:8463
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "%C处的 GENERIC 必须是在派生类型 CONTAINS 内"
 
-#: fortran/decl.c:8484
+#: fortran/decl.c:8483
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "在%C处需要‘::’"
 
-#: fortran/decl.c:8496
+#: fortran/decl.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "%C处需要泛型名或运算符描述子"
 
-#: fortran/decl.c:8522
+#: fortran/decl.c:8515
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Malformed GENERIC statement at %C"
+msgstr "%C处 IMPLICIT 语句为空"
+
+#: fortran/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '=>' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "%C 处需要“=>”"
 
-#: fortran/decl.c:8564
+#: fortran/decl.c:8568
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a non-generic procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "%3$C处派生类型‘%2$s’已经有一个绑定名为‘%1$s’的非泛型过程"
 
-#: fortran/decl.c:8572
+#: fortran/decl.c:8576
 #, fuzzy, gcc-internal-format
 #| msgid "Binding at %C must have the same access as already defined binding '%s'"
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "%C处的绑定必须有与已经定义的绑定‘%s’相同的访问权限"
 
-#: fortran/decl.c:8621
+#: fortran/decl.c:8625
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "%C处需要特定的绑定名"
 
-#: fortran/decl.c:8631
+#: fortran/decl.c:8635
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' already defined as specific binding for the generic '%s' at %C"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%3$C处‘%1$s’已经定义为泛型的‘%2$s’特定的限定"
 
-#: fortran/decl.c:8649
+#: fortran/decl.c:8653
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "%C 处的泛型绑定后有垃圾字符"
 
-#: fortran/decl.c:8684
+#: fortran/decl.c:8688
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "%C处的 FINAL 声明必须在一个派生类型的 CONTAINS 节内"
 
-#: fortran/decl.c:8695
+#: fortran/decl.c:8699
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "%C处带有 FINAL 的派生类型声明必须在 MODULE 的规格说明部分内"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8721
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "%C处的 FINAL 为空"
 
-#: fortran/decl.c:8724
+#: fortran/decl.c:8728
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "%C处期待模块过程名"
 
-#: fortran/decl.c:8734
+#: fortran/decl.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:8740
+#: fortran/decl.c:8744
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "%2$C的过程名“%1$s”未知"
 
-#: fortran/decl.c:8753
+#: fortran/decl.c:8757
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is already defined as FINAL procedure!"
 msgid "%qs at %C is already defined as FINAL procedure!"
 msgstr "%2$C 处的‘%1$s’已经被定义为 FINAL！"
 
-#: fortran/decl.c:8823
+#: fortran/decl.c:8827
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C处 !GCC$ ATTRIBUTES 语句中有未知的属性"
 
-#: fortran/decl.c:8869
+#: fortran/decl.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C处 !GCC$ ATTRIBUTES 语句中的语法错误"
@@ -46144,353 +46195,353 @@
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "%2$L处 %1$s 在第 %3$d 维上外形不同(%4$d 和 %5$d)"
 
-#: fortran/expr.c:3152
+#: fortran/expr.c:3155
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a VALUE"
 msgid "%qs at %L is not a VALUE"
 msgstr "‘%s’在%L处不是一个 VALUE"
 
-#: fortran/expr.c:3159
+#: fortran/expr.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "赋值中有不兼容的秩 %d 和 %d，位于 %L"
 
-#: fortran/expr.c:3166
+#: fortran/expr.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "%L处赋值中的变量类型是 UNKNOWN"
 
-#: fortran/expr.c:3178
+#: fortran/expr.c:3181
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "%L处赋值右手边出现 NULL"
 
-#: fortran/expr.c:3188
+#: fortran/expr.c:3191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "%L处赋值右手边出现值为 POINTER 的函数"
 
-#: fortran/expr.c:3198
+#: fortran/expr.c:3201
 #, fuzzy, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "扩展：%L处 BOZ 字面值被用来初始化非整数变量‘%s’"
 
-#: fortran/expr.c:3203 fortran/resolve.c:9312
+#: fortran/expr.c:3206 fortran/resolve.c:9308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "扩展：在 %L处的 BOZ 字面值在一个 DATA 语句之外并且也在 INT/REAL/DBLE/CMPLX 之外"
 
-#: fortran/expr.c:3214 fortran/resolve.c:9323
+#: fortran/expr.c:3217 fortran/resolve.c:9319
 #, fuzzy, gcc-internal-format
 #| msgid "BOZ literal at %L is bitwise transferred non-integer symbol '%s'"
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "%L处 BOZ 字面值按位转换后是非整数符号‘%s’"
 
-#: fortran/expr.c:3222 fortran/resolve.c:9332
+#: fortran/expr.c:3225 fortran/resolve.c:9328
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "%L处按位转换 BOZ 时算术下溢。这一检查可用 -fno-range-check 选项禁用"
 
-#: fortran/expr.c:3226 fortran/resolve.c:9336
+#: fortran/expr.c:3229 fortran/resolve.c:9332
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "%L处按位转换 BOZ 时算术上溢。这一检查可用 -fno-range-check 选项禁用"
 
-#: fortran/expr.c:3230 fortran/resolve.c:9340
+#: fortran/expr.c:3233 fortran/resolve.c:9336
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "%L处按位转换 BOZ 时产生算术 NaN。这一检查可用 -fno-range-check 选项禁用"
 
-#: fortran/expr.c:3263
+#: fortran/expr.c:3266
 #, fuzzy, gcc-internal-format
 msgid "Change of value in conversion from  %qs to %qs at %L"
 msgstr "扩展：从 %s 到 %s，位于 %L"
 
-#: fortran/expr.c:3272
+#: fortran/expr.c:3275
 #, fuzzy, gcc-internal-format
 msgid "Possible change of value in conversion from %qs to %qs at %L"
 msgstr "扩展：从 %s 到 %s，位于 %L"
 
-#: fortran/expr.c:3280
+#: fortran/expr.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Conversion from %qs to %qs at %L"
 msgstr "从 %s 转换到 %s，位于 %L"
 
-#: fortran/expr.c:3301
+#: fortran/expr.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "%L处 DATA 语句中类型不兼容；试图从 %s 转换到 %s"
 
-#: fortran/expr.c:3337
+#: fortran/expr.c:3340
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "%L处指针赋值的目标不是一个 POINTER"
 
-#: fortran/expr.c:3345
+#: fortran/expr.c:3348
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "%2$L处指针赋值中的‘%1$s’不能是一个左值，因为它是一个过程"
 
-#: fortran/expr.c:3368
+#: fortran/expr.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "Expected bounds specification for '%s' at %L"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "%2$L处‘%1$s’需要边界规格"
 
-#: fortran/expr.c:3373
+#: fortran/expr.c:3376
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Fortran 2003：%2$L处指针赋值语句中‘%1$s’的边界规格"
 
-#: fortran/expr.c:3386
+#: fortran/expr.c:3389
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3392
+#: fortran/expr.c:3395
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’不能为可选的"
 
-#: fortran/expr.c:3404
+#: fortran/expr.c:3407
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3430
+#: fortran/expr.c:3433
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/expr.c:3451
+#: fortran/expr.c:3454
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/expr.c:3475
+#: fortran/expr.c:3478
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "语句函数‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.c:3484
+#: fortran/expr.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "抽象接口‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.c:3494
+#: fortran/expr.c:3497
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "语句函数‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.c:3500
+#: fortran/expr.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "内部过程‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.c:3507
+#: fortran/expr.c:3510
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "内部过程‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.c:3515
+#: fortran/expr.c:3518
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "内部过程‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.c:3538
+#: fortran/expr.c:3541
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "%L处过程指针赋值不匹配：调用约定不匹配"
 
-#: fortran/expr.c:3594 fortran/expr.c:3601 fortran/resolve.c:2449
+#: fortran/expr.c:3597 fortran/expr.c:3604 fortran/resolve.c:2445
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/expr.c:3609
+#: fortran/expr.c:3612
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
-#: fortran/expr.c:3618
+#: fortran/expr.c:3621
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object &L must be unlimited polymorphic, a sequence derived type or of a type with the BIND attribute assignment at %L to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3641
+#: fortran/expr.c:3644
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "%L处指针赋值时类型不同；试图将 %s 赋值给 %s"
 
-#: fortran/expr.c:3650
+#: fortran/expr.c:3653
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "%L处指针赋值时参数种别类型不同"
 
-#: fortran/expr.c:3657
+#: fortran/expr.c:3660
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "%L处指针赋值时秩不同"
 
-#: fortran/expr.c:3676
+#: fortran/expr.c:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3689
+#: fortran/expr.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3693
+#: fortran/expr.c:3696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Fortran 2008：%L处格式中的‘G0’"
 
-#: fortran/expr.c:3717
+#: fortran/expr.c:3720
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/expr.c:3725
+#: fortran/expr.c:3728
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "%L处指针赋值的目标既不是 TARGET 也不是 POINTER"
 
-#: fortran/expr.c:3732
+#: fortran/expr.c:3735
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/expr.c:3741
+#: fortran/expr.c:3744
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "%L处指针赋值的右手边带有向量下标"
 
-#: fortran/expr.c:3749
+#: fortran/expr.c:3752
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "%L处指针赋值目标对象有 PROTECTED 属性"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/expr.c:3803
+#: fortran/expr.c:3806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/expr.c:3869
+#: fortran/expr.c:3872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 ALLOCATABLE"
 
-#: fortran/expr.c:3875
+#: fortran/expr.c:3878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "%L 处指针赋值目标对象有 PROTECTED 属性"
 
-#: fortran/expr.c:3890 fortran/resolve.c:1337
+#: fortran/expr.c:3893 fortran/resolve.c:1337
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "%2$L 处的对象“%1$s”对于成分的默认初始化必须有 SAVE 属性，"
 
-#: fortran/expr.c:3902
+#: fortran/expr.c:3905
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4790
+#: fortran/expr.c:4793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2003：%L处初始化表达式中非整数指数"
 
-#: fortran/expr.c:4798
+#: fortran/expr.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4806
+#: fortran/expr.c:4809
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:4815
+#: fortran/expr.c:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/expr.c:4826
+#: fortran/expr.c:4829
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:4839
+#: fortran/expr.c:4842
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:4868
+#: fortran/expr.c:4871
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "虚参‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:4876
+#: fortran/expr.c:4879
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "虚参‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:4889
+#: fortran/expr.c:4892
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:4897
+#: fortran/expr.c:4900
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:4909
+#: fortran/expr.c:4912
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:4968
+#: fortran/expr.c:4971
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:4972
+#: fortran/expr.c:4975
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:4983
+#: fortran/expr.c:4986
 #, gcc-internal-format, gfc-internal-format
 msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5025
+#: fortran/expr.c:5028
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/f95-lang.c:268
+#: fortran/f95-lang.c:269
 #, gcc-internal-format, gfc-internal-format
 msgid "can't open input file: %s"
 msgstr "不能打开输入文件：%s"
@@ -46512,28 +46563,28 @@
 msgid "Removing call to function %qs at %L"
 msgstr "%2$L处函数‘%1$s’的返回值没有设置"
 
-#: fortran/frontend-passes.c:1652
+#: fortran/frontend-passes.c:1656
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "illegal OP in optimize_comparison"
 msgstr "gimple 比较中操作数无效"
 
-#: fortran/frontend-passes.c:1844
+#: fortran/frontend-passes.c:1848
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine '%s'"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/frontend-passes.c:1851
+#: fortran/frontend-passes.c:1855
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine '%s'"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/frontend-passes.c:1916
+#: fortran/frontend-passes.c:1920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function '%s'"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/frontend-passes.c:1922
+#: fortran/frontend-passes.c:1926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function '%s'"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
@@ -46590,637 +46641,643 @@
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
 msgstr "%C处需要‘END INTERFACE ASSIGNMENT (=)’或语句尾"
 
-#: fortran/interface.c:349
+#: fortran/interface.c:350
 #, fuzzy, gcc-internal-format
+#| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, "
+msgstr "需要‘END INTERFACE ASSIGNMENT (.%s.)’在%C处"
+
+#: fortran/interface.c:353
+#, fuzzy, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %s"
 msgstr "需要‘END INTERFACE ASSIGNMENT (%s)’在%C处"
 
-#: fortran/interface.c:363
+#: fortran/interface.c:367
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
 msgstr "需要‘END INTERFACE ASSIGNMENT (.%s.)’在%C处"
 
-#: fortran/interface.c:374
+#: fortran/interface.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting 'END INTERFACE %s' at %C"
 msgid "Expecting %<END INTERFACE %s%> at %C"
 msgstr "%2$C处需要‘END INTERFACE %1$s’"
 
-#: fortran/interface.c:647
+#: fortran/interface.c:651
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return cannot appear in operator interface at %L"
 msgstr "替代返回不能出现在%L处的运算符接口中"
 
-#: fortran/interface.c:676
+#: fortran/interface.c:680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must have two arguments"
 msgstr "%L处的赋值运算符接口必须有两个实参"
 
-#: fortran/interface.c:679
+#: fortran/interface.c:683
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L has the wrong number of arguments"
 msgstr "%L处的运算符接口实参数错误"
 
-#: fortran/interface.c:692
+#: fortran/interface.c:696
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must be a SUBROUTINE"
 msgstr "%L处的运算符接口必须是一个 SUBROUTINE"
 
-#: fortran/interface.c:710
+#: fortran/interface.c:714
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
 msgstr "%L处的赋值运算符接口不能重复定义一个 INTRINSIC 类型赋值"
 
-#: fortran/interface.c:719
+#: fortran/interface.c:723
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic operator interface at %L must be a FUNCTION"
 msgstr "%L处内建运算符接口必须是一个 FUNCTION"
 
-#: fortran/interface.c:730
+#: fortran/interface.c:734
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
 msgstr "%L处定义赋值的第一个参数必须是 INTENT(OUT) 或 INTENT(INOUT)"
 
-#: fortran/interface.c:737
+#: fortran/interface.c:741
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L处定义赋值的第二个参数必须是 INTENT(IN)"
 
-#: fortran/interface.c:746 fortran/resolve.c:14874
+#: fortran/interface.c:750 fortran/resolve.c:14870
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第一个参数必须是 INTENT(IN)"
 
-#: fortran/interface.c:753 fortran/resolve.c:14892
+#: fortran/interface.c:757 fortran/resolve.c:14888
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第二个参数必须是 INTENT(IN)"
 
-#: fortran/interface.c:858
+#: fortran/interface.c:862
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L conflicts with intrinsic interface"
 msgstr "%L处运算符接口与内建接口冲突"
 
-#: fortran/interface.c:1189 fortran/interface.c:1248
+#: fortran/interface.c:1193 fortran/interface.c:1252
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1361
+#: fortran/interface.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1408
+#: fortran/interface.c:1412
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
 msgstr ""
 
-#: fortran/interface.c:1575
+#: fortran/interface.c:1579
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure %qs in %s at %L has no explicit interface"
 msgstr "%3$L处 %2$s 中的过程‘%1$s’没有显式接口"
 
-#: fortran/interface.c:1578
+#: fortran/interface.c:1582
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
 msgstr "过程‘%s’(在 %s 中，位于 %L) 既不是函数也不是子进程"
 
-#: fortran/interface.c:1590
+#: fortran/interface.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
 msgstr ""
 
-#: fortran/interface.c:1594
+#: fortran/interface.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
 msgstr ""
 
-#: fortran/interface.c:1602
+#: fortran/interface.c:1606
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
 msgstr "%3$L处 %2$s 分句中 的Cray 指针目标‘%1$s’"
 
-#: fortran/interface.c:1659 fortran/interface.c:1663
+#: fortran/interface.c:1663 fortran/interface.c:1667
 #, fuzzy, gcc-internal-format
 #| msgid "Ambiguous interfaces '%s' and '%s' in %s at %L"
 msgid "Ambiguous interfaces %qs and %qs in %s at %L"
 msgstr "有歧义的接口‘%s’和‘%s’在 %s 中，位于 %L"
 
-#: fortran/interface.c:1667
+#: fortran/interface.c:1671
 #, fuzzy, gcc-internal-format
 #| msgid "Although not referenced, '%s' has ambiguous interfaces at %L"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "尽管没有被引用，%2$L处的‘%1$s’的接口有歧义"
 
-#: fortran/interface.c:1701
+#: fortran/interface.c:1705
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a module procedure"
 msgid "%qs at %L is not a module procedure"
 msgstr "%2$L处的‘%1$s’并非一个模块过程"
 
-#: fortran/interface.c:1905
+#: fortran/interface.c:1909
 #, fuzzy, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/interface.c:1910
+#: fortran/interface.c:1914
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "%2$L处实参‘%1$s’秩不匹配(%3$d 和 %4$d)"
 
-#: fortran/interface.c:1915
+#: fortran/interface.c:1919
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "%2$L处实参‘%1$s’秩不匹配(%3$d 和 %4$d)"
 
-#: fortran/interface.c:1920
+#: fortran/interface.c:1924
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "%2$L处实参‘%1$s’秩不匹配(%3$d 和 %4$d)"
 
-#: fortran/interface.c:1963
+#: fortran/interface.c:1967
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.c:1971 fortran/interface.c:1998
+#: fortran/interface.c:1975 fortran/interface.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in dummy procedure '%s' at %L: %s"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "哑过程‘%s’接口在%L处不匹配：%s"
 
-#: fortran/interface.c:2009
+#: fortran/interface.c:2013
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2024
+#: fortran/interface.c:2028
 #, fuzzy, gcc-internal-format
 #| msgid "Type mismatch in argument '%s' at %L; passed %s to %s"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "%2$L处实参‘%1$s’类型不匹配；将 %3$s 传递给 %4$s"
 
-#: fortran/interface.c:2033
+#: fortran/interface.c:2037
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "%L处假定外形的实参由于 VOLATILE 属性而与非假定外形虚参‘%s’不兼容"
 
-#: fortran/interface.c:2049
+#: fortran/interface.c:2053
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2062
+#: fortran/interface.c:2066
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "%4$L处‘%3$s’内建函数的‘%1$s’和‘%2$s’实参类型必须相同"
 
-#: fortran/interface.c:2077
+#: fortran/interface.c:2081
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2088
+#: fortran/interface.c:2092
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2107
+#: fortran/interface.c:2111
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "%2$L处实参‘%1$s’秩不匹配(%3$d 和 %4$d)"
 
-#: fortran/interface.c:2124
+#: fortran/interface.c:2128
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2138
+#: fortran/interface.c:2142
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2156
+#: fortran/interface.c:2160
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2169
+#: fortran/interface.c:2173
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2176
+#: fortran/interface.c:2180
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2239
+#: fortran/interface.c:2243
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "%2$L 处假定外形的数组的元素传递给哑参数“%1$s”"
 
-#: fortran/interface.c:2248
+#: fortran/interface.c:2252
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgstr "%2$L处假定外形的数组的元素传递给虚参‘%1$s’"
 
-#: fortran/interface.c:2260
+#: fortran/interface.c:2264
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003：%2$L处标量 CHARACTER 实参带有数组虚参‘%1$s’"
 
-#: fortran/interface.c:2268
+#: fortran/interface.c:2272
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003：%2$L处标量 CHARACTER 实参带有数组虚参‘%1$s’"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2599
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "%2$L处关键字实参‘%1$s’不在过程里"
 
-#: fortran/interface.c:2603
+#: fortran/interface.c:2607
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "%2$L处关键字参数‘%1$s’已经与另一个实参相关联"
 
-#: fortran/interface.c:2613
+#: fortran/interface.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "%L处调用过程时实参比形参多"
 
-#: fortran/interface.c:2625 fortran/interface.c:2995
+#: fortran/interface.c:2629 fortran/interface.c:2999
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "%L处子进程调用缺少替代返回限定"
 
-#: fortran/interface.c:2633
+#: fortran/interface.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return spec in subroutine call at %L"
 msgstr "%L处子进程调用中的替代返回限定与预期不符"
 
-#: fortran/interface.c:2660
+#: fortran/interface.c:2664
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "对子进程名‘%s’非预期的使用，在%C处"
 
-#: fortran/interface.c:2663
+#: fortran/interface.c:2667
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2691
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:2709
+#: fortran/interface.c:2713
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "%4$L处实参和指针或可分配虚参‘%3$s’之间字符长度失配(%1$ld/%2$ld)"
 
-#: fortran/interface.c:2717
+#: fortran/interface.c:2721
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "%4$L处实参和假定外形虚参‘%3$s’之间字符长度失配(%1$ld/%2$ld)"
 
-#: fortran/interface.c:2731
+#: fortran/interface.c:2735
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:2748
+#: fortran/interface.c:2752
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of actual argument shorter than of dummy argument '%s' (%lu/%lu) at %L"
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "%4$L处实参的字符长度短于虚参‘%1$s’(%2$lu/%3$lu)"
 
-#: fortran/interface.c:2753
+#: fortran/interface.c:2757
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "%4$L处实参包含的元素对于虚参‘%1$s’(%2$lu/%3$lu)而言太少"
 
-#: fortran/interface.c:2772
+#: fortran/interface.c:2776
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure pointer for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "参数‘%s’在 %L 处需要一个过程指针"
 
-#: fortran/interface.c:2788
+#: fortran/interface.c:2792
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "参数‘%s’在%L处需要一个过程"
 
-#: fortran/interface.c:2802
+#: fortran/interface.c:2806
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "‘%s’的实参在%L处必须不是一个假定大小的数组"
 
-#: fortran/interface.c:2811
+#: fortran/interface.c:2815
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2821
+#: fortran/interface.c:2825
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:2831
+#: fortran/interface.c:2835
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "%L处的实参必须是可定义的，因为虚参‘%s’是 INTENT = OUT/INOUT"
 
-#: fortran/interface.c:2844
+#: fortran/interface.c:2848
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "%L处的实参必须是可定义的，因为虚参‘%s’是 INTENT = OUT/INOUT"
 
-#: fortran/interface.c:2858
+#: fortran/interface.c:2862
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2872
+#: fortran/interface.c:2876
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "%L处的实参必须是可定义的，因为虚参‘%s’是 INTENT = OUT/INOUT"
 
-#: fortran/interface.c:2884
+#: fortran/interface.c:2888
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2894
+#: fortran/interface.c:2898
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "‘%s’的实参在%L处必须是 ALLOCATABLE 的"
 
-#: fortran/interface.c:2923
+#: fortran/interface.c:2927
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "%L处带有向量下标的数组节实际参数与虚参‘%s’的 INTENT(OUT)、INTENT(INOUT) 或 VOLATILE 属性不兼容"
 
-#: fortran/interface.c:2941
+#: fortran/interface.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "%L处假定外形的实参由于 VOLATILE 属性而与非假定外形虚参‘%s’不兼容"
 
-#: fortran/interface.c:2953
+#: fortran/interface.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "%L处数组节实参由于 VOLATILE 属性而与非假定外形虚参‘%s’不兼容"
 
-#: fortran/interface.c:2972
+#: fortran/interface.c:2976
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument '%s' due to VOLATILE attribute"
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "%L处指针数组的实参由于 VOLATILE 属性要求一个假定外形或指针数组虚参‘%s’"
 
-#: fortran/interface.c:3002
+#: fortran/interface.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "参数‘%s’在%L处缺少实参"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3128
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3153
+#: fortran/interface.c:3157
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3179
+#: fortran/interface.c:3183
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3189
+#: fortran/interface.c:3193
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "%5$L处同样的实际参数与 INTENT(%1$s) 实参‘%2$s’和 INTENT(%3$s)实参‘%4$s’相关联"
 
-#: fortran/interface.c:3219
+#: fortran/interface.c:3223
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3239
+#: fortran/interface.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "%L处的过程参数对于 PURE 过程是局部的，但是有 POINTER 属性"
 
-#: fortran/interface.c:3251
+#: fortran/interface.c:3255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "%L处的过程参数对于 PURE 过程是局部的而被传递给一个 INTENT(%s) 参数"
 
-#: fortran/interface.c:3261
+#: fortran/interface.c:3265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "%L处的过程参数对于 PURE 过程是局部的而被传递给一个 INTENT(%s) 参数"
 
-#: fortran/interface.c:3272
+#: fortran/interface.c:3276
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "%L处的过程参数对于 PURE 过程是局部的而被传递给一个 INTENT(%s) 参数"
 
-#: fortran/interface.c:3300 fortran/interface.c:3310
+#: fortran/interface.c:3304 fortran/interface.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called at %L is not explicitly declared"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "%2$L处调用的过程‘%1$s’不是显式声明的"
 
-#: fortran/interface.c:3306
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "调用过程‘%s’带隐式接口，位于 %L"
 
-#: fortran/interface.c:3320
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "过程‘%s’在%C处具有显式接口，因此不能有在%L处声明的属性"
 
-#: fortran/interface.c:3328
+#: fortran/interface.c:3332
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "过程‘%s’在%C处具有显式接口，因此不能有在%L处声明的属性"
 
-#: fortran/interface.c:3336
+#: fortran/interface.c:3340
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "%2$L处的自动字符长度函数‘%1$s’必须有一个显式的接口"
 
-#: fortran/interface.c:3346
+#: fortran/interface.c:3350
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "%2$L处过程‘%1$s’的关键字参数要求显式的接口"
 
-#: fortran/interface.c:3355
+#: fortran/interface.c:3359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "符号‘%s’在%L处已经有了显式接口"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3372
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "%3$L处‘%2$s’的虚参‘%1$s’应该命名为‘%4$s’以匹配被覆盖过程的相应参数"
 
-#: fortran/interface.c:3377
+#: fortran/interface.c:3381
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3385
+#: fortran/interface.c:3389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "%2$L处过程‘%1$s’的关键字参数要求显式的接口"
 
-#: fortran/interface.c:3423
+#: fortran/interface.c:3427
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "%2$L调用过程指针组件‘%1$s’时有隐式接口"
 
-#: fortran/interface.c:3434
+#: fortran/interface.c:3438
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure pointer component '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "%2$L处过程指针组件‘%1$s’的关键字实参需要显式接口"
 
-#: fortran/interface.c:3518
+#: fortran/interface.c:3522
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:3588
+#: fortran/interface.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qE"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D是未定义符号%qE的别名"
 
-#: fortran/interface.c:3955
+#: fortran/interface.c:3959
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "%2$C处实体‘%1$s’已经出现在接口中"
 
-#: fortran/interface.c:4071
+#: fortran/interface.c:4075
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4166
+#: fortran/interface.c:4170
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC '%s' at %L"
 msgid "Can't overwrite GENERIC %qs at %L"
 msgstr "不能覆盖%2$L处的 GENERIC‘%1$s’"
 
-#: fortran/interface.c:4178
+#: fortran/interface.c:4182
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%2$L处的‘%1$s’覆盖了一个绑定声明为 NON_OVERRIDABLE 的过程"
 
-#: fortran/interface.c:4186
+#: fortran/interface.c:4190
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%2$L处的‘%1$s’不能被 DEFERRED，因为它覆盖了一个非 DEFERRED 绑定"
 
-#: fortran/interface.c:4194
+#: fortran/interface.c:4198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PURE procedure and must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%2$L处的‘%1$s’覆盖了一个 PURE 过程因此必须也是 PURE"
 
-#: fortran/interface.c:4203
+#: fortran/interface.c:4207
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%2$L处的‘%1$s’覆盖了一个 ELEMENTAL 过程因此也必须是 ELEMENTAL"
 
-#: fortran/interface.c:4209
+#: fortran/interface.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%2$L处的‘%1$s’覆盖了一个非 ELEMENTAL 过程因此必须也不是 ELEMENTAL"
 
-#: fortran/interface.c:4218
+#: fortran/interface.c:4222
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%2$L处的‘%1$s’覆盖了一个 SUBROUTINE 因此也必须是 SUBROUTINE"
 
-#: fortran/interface.c:4229
+#: fortran/interface.c:4233
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a FUNCTION and must also be a FUNCTION"
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%2$L处的‘%1$s’覆盖了一个 FUNCTION 因此也必须是 FUNCTION"
 
-#: fortran/interface.c:4237
+#: fortran/interface.c:4241
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "哑过程‘%s’接口在%L处不匹配：%s"
 
-#: fortran/interface.c:4248
+#: fortran/interface.c:4252
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%2$L处的‘%1$s’覆盖了一个 PUBLIC 过程因此必须不是 PRIVATE"
 
-#: fortran/interface.c:4278
+#: fortran/interface.c:4282
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' of '%s' at %L should be named '%s' as to match the corresponding argument of the overridden procedure"
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "%3$L处‘%2$s’的虚参‘%1$s’应该命名为‘%4$s’以匹配被覆盖过程的相应参数"
 
-#: fortran/interface.c:4289
+#: fortran/interface.c:4293
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "哑过程‘%s’接口在%L处不匹配：%s"
 
-#: fortran/interface.c:4298
+#: fortran/interface.c:4302
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have the same number of formal arguments as the overridden procedure"
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%2$L处的‘%1$s’必须有与被覆盖的过程相同数量的形式参数"
 
-#: fortran/interface.c:4307
+#: fortran/interface.c:4311
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a NOPASS binding and must also be NOPASS"
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%2$L处的‘%1$s’覆盖了一个 NOPASS 绑定因此必须也是 NOPASS"
 
-#: fortran/interface.c:4318
+#: fortran/interface.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a binding with PASS and must also be PASS"
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%2$L处的‘%1$s’覆盖了一个具有 PASS 的绑定因此也必须是 PASS"
 
-#: fortran/interface.c:4325
+#: fortran/interface.c:4329
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
@@ -47648,12 +47705,12 @@
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003：%C处的 ASYNCHRONOUS= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:1912 fortran/io.c:3352
+#: fortran/io.c:1912 fortran/io.c:3350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003：%C处的 BLANK= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:1930 fortran/io.c:3331
+#: fortran/io.c:1930 fortran/io.c:3329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003：%C处的 DECIMAL= 不允许用在 Fortran 95 中"
@@ -47663,7 +47720,7 @@
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003：%C处的 ENCODING= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:2013 fortran/io.c:3394
+#: fortran/io.c:2013 fortran/io.c:3392
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003：%C处的 ROUND= 不允许用在 Fortran 95 中"
@@ -47688,789 +47745,789 @@
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "%L处 CLOSE 语句中的 UNIT 数必须是非负的"
 
-#: fortran/io.c:2411 fortran/match.c:2631
+#: fortran/io.c:2409 fortran/match.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s 语句不允许出现在%C处的 PURE 程序中"
 
-#: fortran/io.c:2445 fortran/io.c:2876
+#: fortran/io.c:2443 fortran/io.c:2874
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "%L处的语句中 UNIT 数必须为非负的数"
 
-#: fortran/io.c:2477
+#: fortran/io.c:2475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "Fortran 2003：%C处的 FLUSH 语句"
 
-#: fortran/io.c:2532
+#: fortran/io.c:2530
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "%C处重复的 UNIT 规格"
 
-#: fortran/io.c:2606
+#: fortran/io.c:2604
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "%C处重复的格式规格"
 
-#: fortran/io.c:2623
+#: fortran/io.c:2621
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "符号‘%s’在名字列表‘%s’是 INTENT(IN)，位于 %C"
 
-#: fortran/io.c:2659
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "%C处重复的 NML 规格"
 
-#: fortran/io.c:2668
+#: fortran/io.c:2666
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C must be a NAMELIST group name"
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "%2$C处的符号‘%1$s’必须是个 NAMELIST 组名"
 
-#: fortran/io.c:2733
+#: fortran/io.c:2731
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "%C处的 END 标记不允许出现在输出语句中"
 
-#: fortran/io.c:2810
+#: fortran/io.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "%L没有指定 UNIT"
 
-#: fortran/io.c:2822
+#: fortran/io.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "%L处的 UNIT 规格必须是 INTEGER 表达式或一个 CHARACTER 变量"
 
-#: fortran/io.c:2844
+#: fortran/io.c:2842
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "%L处 WRITE 语句形式无效，需要 UNIT"
 
-#: fortran/io.c:2855
+#: fortran/io.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "%L处内部单位带向量下标"
 
-#: fortran/io.c:2869
+#: fortran/io.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "%L处的外部 IO UNIT 不能是数组"
 
-#: fortran/io.c:2897
+#: fortran/io.c:2895
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:2907
+#: fortran/io.c:2905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "扩展：%L处 i/o 项目列表前的逗号"
 
-#: fortran/io.c:2917
+#: fortran/io.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR 标号 %d 在%L处未定义"
 
-#: fortran/io.c:2929
+#: fortran/io.c:2927
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END 标号 %d 在%L处未定义"
 
-#: fortran/io.c:2941
+#: fortran/io.c:2939
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR 标号 %d 在%L处未定义"
 
-#: fortran/io.c:2951
+#: fortran/io.c:2949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT 标号 %d 在%L处未定义"
 
-#: fortran/io.c:2982
+#: fortran/io.c:2980
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3071
+#: fortran/io.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "%C处 I/O 游标语法错误"
 
-#: fortran/io.c:3102
+#: fortran/io.c:3100
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "%C READ 语句需要变量"
 
-#: fortran/io.c:3108
+#: fortran/io.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "%2$C处需要 %1$s 语句"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3165 fortran/io.c:3760 fortran/gfortran.h:2685
+#: fortran/io.c:3163 fortran/io.c:3758 fortran/gfortran.h:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s 语句在%C处语法错误"
 
-#: fortran/io.c:3249
+#: fortran/io.c:3247
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr "Fortran 2003：%L处内部文件有名字列表"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3303
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "必须为%L处的 ASYNCHRONOUS= 指定一个初始化表达式"
 
-#: fortran/io.c:3373
+#: fortran/io.c:3371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003：%C处的 PAD= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:3439
+#: fortran/io.c:3437
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003：%C处的 DELIM= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:3588
+#: fortran/io.c:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "%C处的 PRINT 名字列表是一个扩展"
 
-#: fortran/io.c:3731
+#: fortran/io.c:3729
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "%C处 I/O 列表中需要逗号"
 
-#: fortran/io.c:3794
+#: fortran/io.c:3792
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/io.c:3953 fortran/io.c:4013
+#: fortran/io.c:3951 fortran/io.c:4011
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/io.c:3981
+#: fortran/io.c:3979
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "%C处的 INQUIRE 语句中 IOLENGTH 标记无效"
 
-#: fortran/io.c:3991 fortran/trans-io.c:1315
+#: fortran/io.c:3989 fortran/trans-io.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "%L处的 INQUIRE 语句不能包含 FILE 和 UNIT 限定符"
 
-#: fortran/io.c:3998
+#: fortran/io.c:3996
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "%L处的 INQUIRE 语句需要 FILE 或 UNIT 限定符"
 
-#: fortran/io.c:4007
+#: fortran/io.c:4005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT number in statement at %L must be non-negative"
 msgid "UNIT number in INQUIRE statement at %L can not be -1"
 msgstr "%L处的语句中 UNIT 数必须为非负的数"
 
-#: fortran/io.c:4021
+#: fortran/io.c:4019
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "%L处的 INQUIRE 语句需要带有 ID= 指定的 PENDING="
 
-#: fortran/io.c:4195
+#: fortran/io.c:4193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Fortran 2003：%C处的 WAIT 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:4201
+#: fortran/io.c:4199
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "%C处的 PURE 过程中不允许 WAIT 语句"
 
-#: fortran/match.c:117
+#: fortran/match.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_op2string(): Bad code"
 msgstr "gfc_trans_code()：错误的语句代码"
 
-#: fortran/match.c:174
+#: fortran/match.c:177
 #, fuzzy, gcc-internal-format
 #| msgid "Missing ')' in statement at or before %L"
 msgid "Missing %<)%> in statement at or before %L"
 msgstr "语句在%L前缺少‘)’"
 
-#: fortran/match.c:179
+#: fortran/match.c:182
 #, fuzzy, gcc-internal-format
 #| msgid "Missing '(' in statement at or before %L"
 msgid "Missing %<(%> in statement at or before %L"
 msgstr "语句在%L前缺少‘(’"
 
-#: fortran/match.c:376
+#: fortran/match.c:379
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too large at %C"
 msgstr "%C处整数太大"
 
-#: fortran/match.c:469 fortran/parse.c:946
+#: fortran/match.c:472 fortran/parse.c:946
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "%C处语句标号中数字太多"
 
-#: fortran/match.c:475
+#: fortran/match.c:478
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label at %C is zero"
 msgstr "%C处的语句标号为零"
 
-#: fortran/match.c:508
+#: fortran/match.c:511
 #, fuzzy, gcc-internal-format
 #| msgid "Label name '%s' at %C is ambiguous"
 msgid "Label name %qs at %C is ambiguous"
 msgstr "标号名‘%s’在%C处有歧义"
 
-#: fortran/match.c:514
+#: fortran/match.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Duplicate construct label %qs at %C"
 msgstr "重复的构造标号‘%s’出现在%C处"
 
-#: fortran/match.c:545
+#: fortran/match.c:548
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid character in name at %C"
 msgstr "%C处的名字中有非法字符"
 
-#: fortran/match.c:558
+#: fortran/match.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Name at %C is too long"
 msgstr "%C 的名字太长"
 
-#: fortran/match.c:569
+#: fortran/match.c:572
 #, fuzzy, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
 msgstr "%C处无效的字符‘$’。使用 -fdollar-ok 以允许它作为一个扩展"
 
-#: fortran/match.c:888
+#: fortran/match.c:891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a coarray"
 msgstr "%C处的循环变量不能是一个子组件"
 
-#: fortran/match.c:894
+#: fortran/match.c:897
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be a sub-component"
 msgstr "%C处的循环变量不能是一个子组件"
 
-#: fortran/match.c:928
+#: fortran/match.c:931
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a step value in iterator at %C"
 msgstr "%C处的迭代子需要一个步进值"
 
-#: fortran/match.c:940
+#: fortran/match.c:943
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in iterator at %C"
 msgstr "%C处游标语法错误"
 
-#: fortran/match.c:1108
+#: fortran/match.c:1111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_match(): Bad match code %c"
 msgstr "gfc_trans_code()：错误的语句代码"
 
-#: fortran/match.c:1181
+#: fortran/match.c:1184
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of PROGRAM statement at %C"
 msgstr "%C处 PROGRAM 语句格式无效"
 
-#: fortran/match.c:1311 fortran/match.c:1391
+#: fortran/match.c:1314 fortran/match.c:1394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %C"
 msgstr "已过时的特性：%C处的算术 IF 语句"
 
-#: fortran/match.c:1366
+#: fortran/match.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-expression at %C"
 msgstr "%C处 IF 表达式语法错误"
 
-#: fortran/match.c:1377
+#: fortran/match.c:1380
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label not appropriate for arithmetic IF statement at %C"
 msgstr "%C处的块标号不适于算术 IF 语句"
 
-#: fortran/match.c:1414
+#: fortran/match.c:1417
 #, gcc-internal-format, gfc-internal-format
 msgid "Block label is not appropriate for IF statement at %C"
 msgstr "%C处的块标号不适于 IF 语句"
 
-#: fortran/match.c:1500
+#: fortran/match.c:1503
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot assign to a named constant at %C"
 msgstr "无法赋值给%C处的有名常量"
 
-#: fortran/match.c:1510
+#: fortran/match.c:1513
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable statement in IF-clause at %C"
 msgstr "%C处 IF 子句中有无法归类的语句"
 
-#: fortran/match.c:1517
+#: fortran/match.c:1520
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause at %C"
 msgstr "%C处 IF 语句语法错误"
 
-#: fortran/match.c:1560
+#: fortran/match.c:1563
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE statement at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/match.c:1566 fortran/match.c:1601
+#: fortran/match.c:1569 fortran/match.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match IF label '%s'"
 msgid "Label %qs at %C doesn't match IF label %qs"
 msgstr "%2$C处标号‘%1$s’与 IF 标号‘%3$s’不匹配"
 
-#: fortran/match.c:1595
+#: fortran/match.c:1598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after ELSE IF statement at %C"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/match.c:1659
+#: fortran/match.c:1662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in PURE procedure"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:1665
+#: fortran/match.c:1668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:1672
+#: fortran/match.c:1675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
 msgstr "Fortran 2003：%C处的 IMPORT 语句"
 
-#: fortran/match.c:1684
+#: fortran/match.c:1687
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nested CRITICAL block at %C"
 msgstr "没有在%C处发现 COMMON 块 /%s/"
 
-#: fortran/match.c:1736
+#: fortran/match.c:1739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected association list at %C"
 msgstr "%C处需要实参列表"
 
-#: fortran/match.c:1749
+#: fortran/match.c:1752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected association at %C"
 msgstr "需要 %s 语句在%L处"
 
-#: fortran/match.c:1758
+#: fortran/match.c:1761
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in association at %C"
 msgstr "%C处的名字中有非法字符"
 
-#: fortran/match.c:1766
+#: fortran/match.c:1769
 #, gcc-internal-format, gfc-internal-format
 msgid "Association target at %C must not be coindexed"
 msgstr ""
 
-#: fortran/match.c:1784
+#: fortran/match.c:1787
 #, fuzzy, gcc-internal-format
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "需要 %<,%> 或 %<)%>"
 
-#: fortran/match.c:1802
+#: fortran/match.c:1805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after ASSOCIATE statement at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/match.c:1871
+#: fortran/match.c:1874
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L may not be ABSTRACT"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "%2$L处派生类型‘%1$s’不能是 ABSTRACT"
 
-#: fortran/match.c:1934
+#: fortran/match.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "%C处类型指定无效"
 
-#: fortran/match.c:2028
+#: fortran/match.c:2031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "%C处 FORALL 游标语法错误"
 
-#: fortran/match.c:2293
+#: fortran/match.c:2296
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2418
+#: fortran/match.c:2421
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "DATA 叙述不允许出现在 %C 处 %s 叙述中的名称“%s”不是个回圈名称"
 
-#: fortran/match.c:2426
+#: fortran/match.c:2429
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "DATA 叙述不允许出现在 %C 处 %s 叙述中的名称“%s”不是个回圈名称"
 
-#: fortran/match.c:2438
+#: fortran/match.c:2441
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2446
+#: fortran/match.c:2449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
 
-#: fortran/match.c:2458
+#: fortran/match.c:2461
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "%s 语句在%C处不在循环内"
 
-#: fortran/match.c:2461
+#: fortran/match.c:2464
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "%s 语句在%C处不在循环内"
 
-#: fortran/match.c:2486
+#: fortran/match.c:2489
 #, fuzzy, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "%s 语句在%C处不在循环‘%s’内"
 
-#: fortran/match.c:2491
+#: fortran/match.c:2494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "Fortran 2003：%C处的 IMPORT 语句"
 
-#: fortran/match.c:2497
+#: fortran/match.c:2500
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "%s 语句在%C处不在循环‘%s’内"
 
-#: fortran/match.c:2505
+#: fortran/match.c:2508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
 
-#: fortran/match.c:2530
+#: fortran/match.c:2533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "%C处的 EXIT 语句终结了 !$OMP DO 循环"
 
-#: fortran/match.c:2535
+#: fortran/match.c:2538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "%C处的 EXIT 语句终结了 !$OMP DO 循环"
 
-#: fortran/match.c:2560
+#: fortran/match.c:2563
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "%C处的 EXIT 语句终结了 !$OMP DO 循环"
 
-#: fortran/match.c:2565
+#: fortran/match.c:2568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "%C处的 EXIT 语句终结了 !$OMP DO 循环"
 
-#: fortran/match.c:2625
+#: fortran/match.c:2628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:2641
+#: fortran/match.c:2644
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2646
+#: fortran/match.c:2649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:2654
+#: fortran/match.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "%L处的 UNIT 规格必须是 INTEGER 表达式或一个 CHARACTER 变量"
 
-#: fortran/match.c:2661
+#: fortran/match.c:2664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个标量"
 
-#: fortran/match.c:2669
+#: fortran/match.c:2672
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:2677
+#: fortran/match.c:2680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "%C处 Cray 指针必须是一个整数"
 
-#: fortran/match.c:2723
+#: fortran/match.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "%C处非预期的 CASE 语句"
 
-#: fortran/match.c:2744
+#: fortran/match.c:2747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "Fortran 2003：%C处的 IMPORT 语句"
 
-#: fortran/match.c:2769
+#: fortran/match.c:2772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:2784
+#: fortran/match.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:2791
+#: fortran/match.c:2794
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:2821 fortran/match.c:3033 fortran/match.c:3543
-#: fortran/match.c:3880
+#: fortran/match.c:2824 fortran/match.c:3036 fortran/match.c:3546
+#: fortran/match.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L "
 msgstr "%L处有多余的 STAT 标记"
 
-#: fortran/match.c:2842 fortran/match.c:3053 fortran/match.c:3569
-#: fortran/match.c:3905
+#: fortran/match.c:2845 fortran/match.c:3056 fortran/match.c:3572
+#: fortran/match.c:3908
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L "
 msgstr "%L有多余的 ERRMSG 标记"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgstr "%L有多余的 SOURCE 标记"
 
-#: fortran/match.c:2928
+#: fortran/match.c:2931
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "%C处 IMPLICIT 语句为空"
 
-#: fortran/match.c:2938
+#: fortran/match.c:2941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "%C处 IMPLICIT 语句为空"
 
-#: fortran/match.c:2963
+#: fortran/match.c:2966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:2969
+#: fortran/match.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "Fortran 2003：%C处的 IMPORT 语句"
 
-#: fortran/match.c:2981
+#: fortran/match.c:2984
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:2987
+#: fortran/match.c:2990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:3167
+#: fortran/match.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "已删除的特性：%C处的 ASSIGN 语句"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "已删除的特性：%C处赋值 GOTO 语句"
 
-#: fortran/match.c:3255 fortran/match.c:3306
+#: fortran/match.c:3258 fortran/match.c:3309
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "%C处 GOTO 中的语句标号列表不能为空"
 
-#: fortran/match.c:3316
+#: fortran/match.c:3319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "已过时的特性：%C处的计算转移 GOTO 语句"
 
-#: fortran/match.c:3388
+#: fortran/match.c:3391
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "%C处指定 TYPE IS 语法错误"
 
-#: fortran/match.c:3398
+#: fortran/match.c:3401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr "Fortran 2003：%L处 ALLOCATE 中有 typespec"
 
-#: fortran/match.c:3441
+#: fortran/match.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "%C处 PURE 过程中分配对象错误"
 
-#: fortran/match.c:3465
+#: fortran/match.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3470
+#: fortran/match.c:3473
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3492
+#: fortran/match.c:3495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "%C处的分配对象不是一个非过程指针或可分配的变量"
 
-#: fortran/match.c:3504
+#: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "%L处实体类型与 typepec 类型不兼容"
 
-#: fortran/match.c:3512
+#: fortran/match.c:3515
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr "%L实体的种别类型参数与类型限定中的种别类型参数不同"
 
-#: fortran/match.c:3526
+#: fortran/match.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "%C处可分配标量的外形规格说明"
 
-#: fortran/match.c:3563
+#: fortran/match.c:3566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "Fortran 2003：%L处的 ERRMSG 标记"
 
-#: fortran/match.c:3586
+#: fortran/match.c:3589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "Fortran 2003：%L处的 SOURCE 标记"
 
-#: fortran/match.c:3592
+#: fortran/match.c:3595
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L "
 msgstr "%L有多余的 SOURCE 标记"
 
-#: fortran/match.c:3599
+#: fortran/match.c:3602
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/match.c:3605
+#: fortran/match.c:3608
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr "%L处的 SOURCE 标记在分配列表中只需要一个单独的实体"
 
-#: fortran/match.c:3623
+#: fortran/match.c:3626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "Fortran 2003：%L处的 IOMSG 标记"
 
-#: fortran/match.c:3629
+#: fortran/match.c:3632
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L "
 msgstr "%L有多余的 ERRMSG 标记"
 
-#: fortran/match.c:3636
+#: fortran/match.c:3639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/match.c:3662
+#: fortran/match.c:3665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/match.c:3670
+#: fortran/match.c:3673
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3682
+#: fortran/match.c:3685
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:3744
+#: fortran/match.c:3747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/match.c:3830
+#: fortran/match.c:3833
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "%C处 PURE 过程中的分配对象非法"
 
-#: fortran/match.c:3840
+#: fortran/match.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3847
+#: fortran/match.c:3850
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3863
+#: fortran/match.c:3866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "%C处的分配对象不是一个非过程指针或可分配的变量"
 
-#: fortran/match.c:3900
+#: fortran/match.c:3903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "Fortran 2003：%L处的 ERRMSG"
 
-#: fortran/match.c:3957
+#: fortran/match.c:3960
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3963
+#: fortran/match.c:3966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:3972
+#: fortran/match.c:3975
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "%C处的替代 RETURN 语句只允许出现在 SUBROUTINE 中"
 
-#: fortran/match.c:4003
+#: fortran/match.c:4006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr "扩展：%C处 RETURN 语句出现在主程序中"
 
-#: fortran/match.c:4031
+#: fortran/match.c:4034
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "%C处需要组件引用"
 
-#: fortran/match.c:4040
+#: fortran/match.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "%C处在 CALL 以后有垃圾字符"
 
-#: fortran/match.c:4051
+#: fortran/match.c:4054
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "%C处需要一个类型限定的过程或过程指针组件"
 
-#: fortran/match.c:4272
+#: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "%C处公共块名语法错误"
@@ -48478,157 +48535,157 @@
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:4350
+#: fortran/match.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgstr "%4$C处公共块‘%3$s’中的%2$L处的变量‘%1$s’必须声明为有与 C 可互操作的种别，因为公共块‘%5$s’是 bind(c)"
 
-#: fortran/match.c:4359
+#: fortran/match.c:4362
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %C can not be bind(c) since it is not global"
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgstr "%3$C处的公共块‘%2$s’中的变量‘%1$s’不能是 bind(c)，因为它不是全局的"
 
-#: fortran/match.c:4366
+#: fortran/match.c:4369
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "符号‘%s’在%C处已经在一个 COMMON 块中"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, fuzzy, gcc-internal-format
 #| msgid "Initialized symbol '%s' at %C can only be COMMON in BLOCK DATA"
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "%2$C处已初始化的符号‘%1$s’仅可以是在 BLOCK DATA 中的 COMMON"
 
-#: fortran/match.c:4400
+#: fortran/match.c:4403
 #, fuzzy, gcc-internal-format
 #| msgid "Array specification for symbol '%s' in COMMON at %C must be explicit"
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "%2$C处 COMMON 中符号‘%1$s’的数组规格必须是显式的"
 
-#: fortran/match.c:4410
+#: fortran/match.c:4413
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in COMMON at %C cannot be a POINTER array"
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "%2$C处 COMMON 中的符号‘%1$s’不能是个 POINTER 数组"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s', in COMMON block '%s' at %C is being indirectly equivalenced to another COMMON block '%s'"
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "%3$C处 COMMON 块‘%2$s’的中符号‘%1$s’间接地等价于另一个 COMMON 块‘%4$s’"
 
-#: fortran/match.c:4570
+#: fortran/match.c:4573
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already has a basic type of %s"
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "%2$C处的组名列表‘%1$s’已经有一个基本类型 %3$s"
 
-#: fortran/match.c:4578
+#: fortran/match.c:4581
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already is USE associated and cannot be respecified."
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "%2$C处组名列表‘%1$s’已经为 USE 相关因此不能被重新指定。"
 
-#: fortran/match.c:4604
+#: fortran/match.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "%3$C处名字列表‘%2$s’中的假定大小数组‘%1$s’不被允许"
 
-#: fortran/match.c:4738
+#: fortran/match.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "派生类型组件%C不是允许的 EQUIVALENCE 成员"
 
-#: fortran/match.c:4746
+#: fortran/match.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "%C处 EQUIVALENCE 中的数组引用不能是个数组段"
 
-#: fortran/match.c:4774
+#: fortran/match.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "%C处的 EQUIVALENCE 需要两个或更多的对象"
 
-#: fortran/match.c:4788
+#: fortran/match.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "%3$C处的 EQUIVALENCE 试图间接地重叠 COMMON 块 %1$s 和 %2$s"
 
-#: fortran/match.c:4801
+#: fortran/match.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "%C处 EQUIVALENCE 中需要逗号"
 
-#: fortran/match.c:4919
+#: fortran/match.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "%L处的语句函数是递归的"
 
-#: fortran/match.c:4925
+#: fortran/match.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "%L处的语句函数是递归的"
 
-#: fortran/match.c:5010
+#: fortran/match.c:5013
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "%C处 CASE 中需要初始化表达式"
 
-#: fortran/match.c:5042
+#: fortran/match.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name '%s' of SELECT construct at %C"
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "%2$C处需要 SELECT 构造的块名‘%1$s’"
 
-#: fortran/match.c:5322
+#: fortran/match.c:5325
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/match.c:5346
+#: fortran/match.c:5349
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "%C处 SELECT TYPE 中的选择子不是一个有名变量；请使用 associate-name=>"
 
-#: fortran/match.c:5380
+#: fortran/match.c:5383
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "%C处非预期的 CASE 语句"
 
-#: fortran/match.c:5432
+#: fortran/match.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "%C处 CASE 规格语法错误"
 
-#: fortran/match.c:5450
+#: fortran/match.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "%C处非预期的 TYPE IS 语句"
 
-#: fortran/match.c:5479
+#: fortran/match.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:5491
+#: fortran/match.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "%C处 TYPE IS 规格语法错误"
 
-#: fortran/match.c:5564
+#: fortran/match.c:5573
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "%C处 CLASS IS 规格语法错误"
 
-#: fortran/match.c:5682
+#: fortran/match.c:5691
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "%C处的 ELSEWHERE 语句不在 WHERE 块中"
 
-#: fortran/match.c:5720
+#: fortran/match.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -48782,184 +48839,184 @@
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 
-#: fortran/module.c:4623
+#: fortran/module.c:4619
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4626
+#: fortran/module.c:4622
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4814
+#: fortran/module.c:4810
 #, fuzzy, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "%2$C处的名字‘%1$s’是从当前程序单元对‘%3$s’有歧义的引用"
 
-#: fortran/module.c:5165
+#: fortran/module.c:5161
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "%2$L处引用的符号‘%1$s’在模块‘%3$s’中找不到"
 
-#: fortran/module.c:5172
+#: fortran/module.c:5168
 #, fuzzy, gcc-internal-format
 #| msgid "User operator '%s' referenced at %L not found in module '%s'"
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "%2$L处引用的用户运算符‘%1$s’在模块‘%3$s’中找不到"
 
-#: fortran/module.c:5177
+#: fortran/module.c:5173
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "%2$L处引用的内建运算符‘%1$s’在模块‘%3$s’中找不到"
 
-#: fortran/module.c:5407
+#: fortran/module.c:5403
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5740
+#: fortran/module.c:5736
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:5914
+#: fortran/module.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "不能打开模块文件‘%s’写入，在%C处：%s"
 
-#: fortran/module.c:5934
+#: fortran/module.c:5930
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "写入模块文件‘%s’时出错：%s"
 
-#: fortran/module.c:5945
+#: fortran/module.c:5941
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file '%s': %s"
 msgid "Can't delete module file %qs: %s"
 msgstr "无法删除模块文件‘%s’：%s"
 
-#: fortran/module.c:5948
+#: fortran/module.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "Can't rename module file '%s' to '%s': %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "无法将模块文件‘%s’重命名为‘%s’：%s"
 
-#: fortran/module.c:5954
+#: fortran/module.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete temporary module file '%s': %s"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "无法删除临时模块文件‘%s’：%s"
 
-#: fortran/module.c:5974 fortran/module.c:6301 fortran/module.c:6334
-#: fortran/module.c:6376
+#: fortran/module.c:5970 fortran/module.c:6297 fortran/module.c:6330
+#: fortran/module.c:6372
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs already declared"
 msgstr "符号‘%s’已经被声明过"
 
-#: fortran/module.c:6044
+#: fortran/module.c:6040
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6152 fortran/module.c:6496
+#: fortran/module.c:6148 fortran/module.c:6492
 #, fuzzy, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "%2$L处引用的符号‘%1$s’在模块‘%3$s’中找不到"
 
-#: fortran/module.c:6280
+#: fortran/module.c:6276
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "%2$L处引用的符号‘%1$s’在内建模块 ISO_C_BINDING 中找不到"
 
-#: fortran/module.c:6481
+#: fortran/module.c:6477
 #, fuzzy, gcc-internal-format
 #| msgid "Use of intrinsic module '%s' at %C conflicts with non-intrinsic module name used previously"
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "%2$C处对内建模块‘%1$s’的使用与以前使用的非内建模块名字冲突"
 
-#: fortran/module.c:6503
+#: fortran/module.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %s"
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "%L处在内建模块 ISO_FORTRAN_ENV 中对 NUMERIC_STORAGE_SIZE 命名常数的使用与选项 %s 不兼容"
 
-#: fortran/module.c:6571
+#: fortran/module.c:6567
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "%C处在内建模块 ISO_FORTRAN_ENV 中对 NUMERIC_STORAGE_SIZE 命名常数的使用与选项 %s 不兼容"
 
-#: fortran/module.c:6625
+#: fortran/module.c:6621
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "%2$L处引用的符号‘%1$s’在内建模块 ISO_FORTRAN_ENV 中找不到"
 
-#: fortran/module.c:6651
+#: fortran/module.c:6647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "%C处非预期的 CASE 语句"
 
-#: fortran/module.c:6669
+#: fortran/module.c:6665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003：%C 处的 ISO_FORTRAN_ENV 内建模块"
 
-#: fortran/module.c:6681
+#: fortran/module.c:6677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003：%C处的 ISO_C_BINDING 模块"
 
-#: fortran/module.c:6694
+#: fortran/module.c:6690
 #, fuzzy, gcc-internal-format
 #| msgid "Can't find an intrinsic module named '%s' at %C"
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "%2$C处无法找到名为‘%1$s’的内建模块"
 
-#: fortran/module.c:6700
+#: fortran/module.c:6696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "Fortran 2003：%C处的“USE :: module”"
 
-#: fortran/module.c:6706
+#: fortran/module.c:6702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "Fortran 2003：%C处的 ISO_C_BINDING 模块"
 
-#: fortran/module.c:6712
+#: fortran/module.c:6708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "Fortran 2003：%C处的 ISO_C_BINDING 模块"
 
-#: fortran/module.c:6719
+#: fortran/module.c:6715
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "无法打开模块文件‘%s’读取，在%C处：%s"
 
-#: fortran/module.c:6727
+#: fortran/module.c:6723
 #, fuzzy, gcc-internal-format
 #| msgid "Use of non-intrinsic module '%s' at %C conflicts with intrinsic module name used previously"
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "%2$C处对非内建模块‘%1$s’的使用与之前对内建模块名字的使用相冲突"
 
-#: fortran/module.c:6750
+#: fortran/module.c:6746
 #, fuzzy, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "%2$C处打开的文件的‘%1$s’并非一个 GFORTRAN 模块文件"
 
-#: fortran/module.c:6758
+#: fortran/module.c:6754
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6772
+#: fortran/module.c:6768
 #, gcc-internal-format
 msgid "Can't USE the same module we're building!"
 msgstr "不能 USE 我们正在构建的模块！"
@@ -49277,7 +49334,7 @@
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L "
 msgstr ""
 
-#: fortran/openmp.c:2885 fortran/resolve.c:9167 fortran/resolve.c:10252
+#: fortran/openmp.c:2885 fortran/resolve.c:9163 fortran/resolve.c:10248
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
@@ -50036,377 +50093,371 @@
 msgid "Unexpected %s statement at %C"
 msgstr "%2$C处有非预期的 %1$s 语句"
 
-#: fortran/parse.c:2428
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected %s statement in MODULE at %C"
-msgid "Unexpected %s statement in verify_st_order() at %C"
-msgstr "非预期的 %s 语句出现在%C处的 MODULE 中"
-
-#: fortran/parse.c:2439
+#: fortran/parse.c:2438
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "%s 语句在%C处不能跟随 %s 语句在%L处"
 
-#: fortran/parse.c:2456
+#: fortran/parse.c:2455
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "‘%s’中非预期的文件结尾"
 
-#: fortran/parse.c:2488
+#: fortran/parse.c:2487
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with SEQUENCE must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "%2$C处带有 SEQUENCE 派生类型‘%1$s’不能有 CONTAINS 节"
 
-#: fortran/parse.c:2491
+#: fortran/parse.c:2490
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with BIND(C) must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "带 BIND(C) 的派生类‘%s’在%C处不能有 CONTAINS 节"
 
-#: fortran/parse.c:2511
+#: fortran/parse.c:2510
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "%C处 TYPE 中的组件必须先于 CONTAINS"
 
-#: fortran/parse.c:2515
+#: fortran/parse.c:2514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "Fortran 2003：%C处的类型限定过程"
 
-#: fortran/parse.c:2523
+#: fortran/parse.c:2522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "%C 处的泛型绑定后有垃圾字符"
 
-#: fortran/parse.c:2531
+#: fortran/parse.c:2530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "Fortran 2003：%C处的的 FINAL 过程声明"
 
-#: fortran/parse.c:2543
+#: fortran/parse.c:2542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Fortran 2008：%C的派生类型定义有空的 CONTAINS 节"
 
-#: fortran/parse.c:2553 fortran/parse.c:2656
+#: fortran/parse.c:2552 fortran/parse.c:2655
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "%C处 TYPE 中的 PRIVATE 语句必须在 MODULE 中"
 
-#: fortran/parse.c:2560
+#: fortran/parse.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "%C处 PRIVATE 语句必须先于过程绑定"
 
-#: fortran/parse.c:2567 fortran/parse.c:2669
+#: fortran/parse.c:2566 fortran/parse.c:2668
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "%C处重复的 PRIVATE 语句"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2576
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "%C处 SEQUENCE 语句必须先于 CONTAINS"
 
-#: fortran/parse.c:2581
+#: fortran/parse.c:2580
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "%C处已在一个 CONTAINS 块内部 "
 
-#: fortran/parse.c:2639
+#: fortran/parse.c:2638
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "%C处的 FINAL 声明必须在 CONTAINS 内"
 
-#: fortran/parse.c:2647
+#: fortran/parse.c:2646
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr "Fortran 2003：%C处的派生类型定义没有组件"
 
-#: fortran/parse.c:2663
+#: fortran/parse.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "%C处 PRIVATE 语句必须先于结构组件"
 
-#: fortran/parse.c:2680
+#: fortran/parse.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "%C处 SEQUENCE 语句必须先于结构组件"
 
-#: fortran/parse.c:2686
+#: fortran/parse.c:2685
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "%C处 SEQUENCE 属性已经在 TYPE 语句中指定"
 
-#: fortran/parse.c:2691
+#: fortran/parse.c:2690
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "%C处重复的 SEQUENCE 语句"
 
-#: fortran/parse.c:2701
+#: fortran/parse.c:2700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr "Fortran 2003：%C处的派生类型定义中的 CONTAINS 块"
 
-#: fortran/parse.c:2789
+#: fortran/parse.c:2788
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:2795
+#: fortran/parse.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:2800
+#: fortran/parse.c:2799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/parse.c:2804
+#: fortran/parse.c:2803
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:2809
+#: fortran/parse.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:2816
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:2868
+#: fortran/parse.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "%C处的 ENUM 声明没有 ENUMERATORS"
 
-#: fortran/parse.c:2951
+#: fortran/parse.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "非预期的 %s 语句出现在%C处的 INTERFACE 块中"
 
-#: fortran/parse.c:2975
+#: fortran/parse.c:2974
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "%2$C处的 ABSTRACT INTERFACE 的名字‘%1$s’不能与内建类型一样"
 
-#: fortran/parse.c:3008
+#: fortran/parse.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "非预期的 %s 语句出现在%C处的 INTERFACE 体中"
 
-#: fortran/parse.c:3026
+#: fortran/parse.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "%2$L处 INTERFACE 过程‘%1$s’有与外围过程相同的名字"
 
-#: fortran/parse.c:3151
+#: fortran/parse.c:3150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "%s 语句不能用在%C处 BLOCK 内"
 
-#: fortran/parse.c:3181
+#: fortran/parse.c:3180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "%s 语句不能用在%C处 BLOCK 内"
 
-#: fortran/parse.c:3265
+#: fortran/parse.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "%s 语句必须出现在 MODULE 中"
 
-#: fortran/parse.c:3273
+#: fortran/parse.c:3272
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "%2$C处 %1$s 语句出现在其他访问规格之后"
 
-#: fortran/parse.c:3337
+#: fortran/parse.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "Bad kind expression for function '%s' at %L"
 msgid "Bad kind expression for function %qs at %L"
 msgstr "%2$L处的函数‘%1$s’种类表达式错误"
 
-#: fortran/parse.c:3341
+#: fortran/parse.c:3340
 #, fuzzy, gcc-internal-format
 #| msgid "The type for function '%s' at %L is not accessible"
 msgid "The type for function %qs at %L is not accessible"
 msgstr "%2$L处函数‘%1$s’的类型是不可访问的"
 
-#: fortran/parse.c:3399
+#: fortran/parse.c:3398
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "%C处的 ELSEWHERE 语句出现在未屏蔽的 ELSEWHERE 之后"
 
-#: fortran/parse.c:3421
+#: fortran/parse.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "非预期的 %s 语句出现在%C处的 WHERE 块中"
 
-#: fortran/parse.c:3480
+#: fortran/parse.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "非预期的 %s 语句出现在%C处的 FORALL 块中"
 
-#: fortran/parse.c:3531
+#: fortran/parse.c:3530
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "%C处的 ELSE IF 语句不能出现在%L处的 ELSE 语句之后"
 
-#: fortran/parse.c:3549
+#: fortran/parse.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "%L 和%C处重复的 ELSE 语句"
 
-#: fortran/parse.c:3610
+#: fortran/parse.c:3609
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "%C处 SELECT CASE 之后需要 CASE 或 END SELECT 语句"
 
-#: fortran/parse.c:3693
+#: fortran/parse.c:3692
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "%C处的 SELECT TYPE 之后需要 TYPE IS、CLASS IS 或 END SELECT 语句"
 
-#: fortran/parse.c:3755
+#: fortran/parse.c:3754
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/parse.c:3788
+#: fortran/parse.c:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "%C处结束的非块 DO 语句在另一个块当中"
 
-#: fortran/parse.c:3798
+#: fortran/parse.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "%C处结束的非块 DO 语句与另一个 DO 循环交错"
 
-#: fortran/parse.c:3824
+#: fortran/parse.c:3823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr "Fortran 2003：%C处的派生类型定义中的 CONTAINS 块"
 
-#: fortran/parse.c:3851
+#: fortran/parse.c:3850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "%C处 ENDDO 中的语句标号与 DO 标号不匹配"
 
-#: fortran/parse.c:3919
+#: fortran/parse.c:3918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "Fortran 2008：%C处的 BLOCK 结构"
 
-#: fortran/parse.c:3949
+#: fortran/parse.c:3948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "Fortran 2008：%C处的 BLOCK 结构"
 
-#: fortran/parse.c:4049
+#: fortran/parse.c:4048
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "%C处 ENDDO 中的语句标号与 DO 标号不匹配"
 
-#: fortran/parse.c:4065
+#: fortran/parse.c:4064
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "%L处有名的块 DO 需要匹配的 ENDDO 名"
 
-#: fortran/parse.c:4236
+#: fortran/parse.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4252 fortran/parse.c:4309
+#: fortran/parse.c:4251 fortran/parse.c:4308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr "没有在%C处发现 COMMON 块 /%s/"
 
-#: fortran/parse.c:4285
+#: fortran/parse.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr "需要 %s 语句，于 %C"
 
-#: fortran/parse.c:4328
+#: fortran/parse.c:4327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "在%C处需要‘(’"
 
-#: fortran/parse.c:4348
+#: fortran/parse.c:4347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr "%L有多余的 SOURCE 标记"
 
-#: fortran/parse.c:4561
+#: fortran/parse.c:4560
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "%C处 !$omp critical 和 !$omp end critical 后的名字不匹配"
 
-#: fortran/parse.c:4618
+#: fortran/parse.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "%2$C处的 %1$s 语句不能终止一个不成块的 DO 循环"
 
-#: fortran/parse.c:4632
+#: fortran/parse.c:4631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr "%L处 FORMAT 语句没有语句标号"
 
-#: fortran/parse.c:4859
+#: fortran/parse.c:4858
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %C is already ambiguous"
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "%2$C处包含的过程‘%1$s’已经有歧义"
 
-#: fortran/parse.c:4915
+#: fortran/parse.c:4914
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "非预期的 %s 语句出现在%C处的 CONTAINS 段中"
 
-#: fortran/parse.c:4939
+#: fortran/parse.c:4938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgstr "Fortran 2008：%C处 CONTAINS 语句没有 FUNCTION 或 SUBROUTINE 语句"
 
-#: fortran/parse.c:5016
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "%C处的 CONTAINS 语句已经在包含的程序单元中"
 
-#: fortran/parse.c:5069
+#: fortran/parse.c:5068
 #, gcc-internal-format
 msgid "gfc_global_used(): Bad type"
 msgstr ""
 
-#: fortran/parse.c:5074
+#: fortran/parse.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Global binding name '%s' at %L is already being used as a %s at %L"
 msgstr "%2$L处的名字‘%1$s’已经在%4$L处被用作 %3$s"
 
-#: fortran/parse.c:5077
+#: fortran/parse.c:5076
 #, gcc-internal-format, gfc-internal-format
 msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgstr "%2$L处的名字‘%1$s’已经在%4$L处被用作 %3$s"
 
-#: fortran/parse.c:5098
+#: fortran/parse.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "%C处空白 BLOCK DATA 与%L处先前的 BLOCK DATA 冲突"
 
-#: fortran/parse.c:5124
+#: fortran/parse.c:5123
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "非预期的 %s 语句出现在%C处的 BLOCK DATA 块中"
 
-#: fortran/parse.c:5169
+#: fortran/parse.c:5168
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "非预期的 %s 语句出现在%C处的 MODULE 中"
@@ -50414,7 +50465,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:5547
+#: fortran/parse.c:5546
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "%L 和%C处有两个主 PROGRAM"
@@ -51151,7 +51202,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "%2$L处非 RECURSIVE 过程‘%1$s’可能递归地调用它自己。请将它声明为 RECURSIVE 或使用 -frecursive"
 
-#: fortran/resolve.c:1773 fortran/resolve.c:8704 fortran/resolve.c:10199
+#: fortran/resolve.c:1773 fortran/resolve.c:8700 fortran/resolve.c:10195
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "标号 %d(引用自 %L)从未被定义"
@@ -51211,91 +51262,91 @@
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "不允许按位置传递%L处的内部过程"
 
-#: fortran/resolve.c:1986
+#: fortran/resolve.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL 非 INTRINSIC 过程‘%s’不允许在%L处作为实际参数"
 
-#: fortran/resolve.c:1995
+#: fortran/resolve.c:1996
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2126
+#: fortran/resolve.c:2127
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "%2$L处的‘%1$s’是个数组且是可选的；如果它缺失, 它不能是一个 ELEMENTAL 过程的实际参数，除非有一个具有相同秩的非可选的参数(12.4.1.5)"
 
-#: fortran/resolve.c:2163
+#: fortran/resolve.c:2164
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument at %L for INTENT(%s) dummy '%s' of ELEMENTAL subroutine '%s' is a scalar, but another actual argument is an array"
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "%1$L处 ELEMENTAL 子程序‘%4$s’的 INTENT(%2$s) 哑‘%3$s’的实际参数是一个标量，但是另一个实际参数是一个数组"
 
-#: fortran/resolve.c:2440
+#: fortran/resolve.c:2436
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "函数不能返回函数"
 
-#: fortran/resolve.c:2461
+#: fortran/resolve.c:2457
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s "
 msgstr "哑过程‘%s’接口在%L处不匹配：%s"
 
-#: fortran/resolve.c:2569
+#: fortran/resolve.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "%2$L处的泛型‘%1$s’没有指定的函数"
 
-#: fortran/resolve.c:2587
+#: fortran/resolve.c:2583
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "%2$L处泛型函数‘%1$s’与特定的内建接口不一致"
 
-#: fortran/resolve.c:2625
+#: fortran/resolve.c:2621
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "%2$L处的函数‘%1$s’是 INTRINSIC，但与内建函数不兼容"
 
-#: fortran/resolve.c:2680
+#: fortran/resolve.c:2676
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "不能解析 %2$L处的函数‘%1$s’"
 
-#: fortran/resolve.c:2736 fortran/resolve.c:14809
+#: fortran/resolve.c:2732 fortran/resolve.c:14805
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
 
-#: fortran/resolve.c:2845
+#: fortran/resolve.c:2841
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "%2$L处对非 PURE 函数‘%1$s’的引用出现在 FORALL %3$s 中"
 
-#: fortran/resolve.c:2852
+#: fortran/resolve.c:2848
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "%2$L处对非 PURE 函数‘%1$s’的引用出现在 FORALL %3$s 中"
 
-#: fortran/resolve.c:2859
+#: fortran/resolve.c:2855
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "%2$L处对非 PURE 函数‘%1$s’的引用出现在 FORALL %3$s 中"
 
-#: fortran/resolve.c:2922
+#: fortran/resolve.c:2918
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a function"
 msgid "%qs at %L is not a function"
 msgstr "%2$L处的‘%1$s’不是一个函数"
 
-#: fortran/resolve.c:2930 fortran/resolve.c:3400
+#: fortran/resolve.c:2926 fortran/resolve.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "ABSTRACT INTERFACE '%s' must not be referenced at %L"
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
@@ -51302,298 +51353,298 @@
 msgstr "%2$L处的 ABSTRACT INTERFACE‘%1$s’不能被引用"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:2973
+#: fortran/resolve.c:2969
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "函数‘%s’被声明为 CHARACTER(*)从而不能被使用在%L处，因为它不是一个虚参"
 
-#: fortran/resolve.c:3007
+#: fortran/resolve.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_function(): bad function type"
 msgstr "<未解决的重载函数类型>"
 
-#: fortran/resolve.c:3027
+#: fortran/resolve.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "User defined non-ELEMENTAL function '%s' at %L not allowed in WORKSHARE construct"
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "%2$L处用户定义的非 ELEMENTAL 函数‘%1$s’不容许出现在 WORKSHARE 构造中"
 
-#: fortran/resolve.c:3089
+#: fortran/resolve.c:3085
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as function '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "%2$L处 ENTRY‘%1$s’不能递归调用，因为函数‘%3$s’并非 RECURSIVE"
 
-#: fortran/resolve.c:3093
+#: fortran/resolve.c:3089
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "%2$L处的函数‘%1$s’不能被递归调用，因为它并非 RECURSIVE"
 
-#: fortran/resolve.c:3144
+#: fortran/resolve.c:3140
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "%2$L处 FORALL 块内对‘%1$s’子例程的调用不是 PURE"
 
-#: fortran/resolve.c:3150
+#: fortran/resolve.c:3146
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "%2$L处 FORALL 块内对‘%1$s’子例程的调用不是 PURE"
 
-#: fortran/resolve.c:3156
+#: fortran/resolve.c:3152
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "%2$L处调用‘%1$s’的子例程不是 PURE"
 
-#: fortran/resolve.c:3224
+#: fortran/resolve.c:3220
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific subroutine for the generic '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "泛型‘%s’在%L处没有特定的子进程"
 
-#: fortran/resolve.c:3233
+#: fortran/resolve.c:3229
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "%2$L处泛型子进程‘%1$s’与一个内建子进程接口不一致"
 
-#: fortran/resolve.c:3268
+#: fortran/resolve.c:3264
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "%2$L处的子进程‘%1$s’是 INTRINSIC，但与内建函数不兼容"
 
-#: fortran/resolve.c:3313
+#: fortran/resolve.c:3309
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "不能解决%2$L处的指定子例程‘%1$s’"
 
-#: fortran/resolve.c:3371
+#: fortran/resolve.c:3367
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgstr "%2$L处的‘%1$s’的类型与%3$L处 CALL 的类型不一致"
 
-#: fortran/resolve.c:3410
+#: fortran/resolve.c:3406
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as subroutine '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "%2$L处 ENTRY‘%1$s’不能被递归调用，因为子进程‘%3$s’并非 RECURSIVE"
 
-#: fortran/resolve.c:3414
+#: fortran/resolve.c:3410
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "%2$L处 SUBROUTINE‘%1$s’不能递归调用，因为它并非 RECURSIVE"
 
-#: fortran/resolve.c:3459
+#: fortran/resolve.c:3455
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_subroutine(): bad function type"
 msgstr "<未解决的重载函数类型>"
 
-#: fortran/resolve.c:3497
+#: fortran/resolve.c:3493
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "%L和%L处的操作数外形不相容"
 
-#: fortran/resolve.c:3728
+#: fortran/resolve.c:3724
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3899 fortran/resolve.c:3922
+#: fortran/resolve.c:3895 fortran/resolve.c:3918
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4017
+#: fortran/resolve.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4022
+#: fortran/resolve.c:4018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4032
+#: fortran/resolve.c:4028
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4033
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4057
+#: fortran/resolve.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L 零间隔非法"
 
-#: fortran/resolve.c:4074
+#: fortran/resolve.c:4070
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组下限引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4082
+#: fortran/resolve.c:4078
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组下限引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.c:4098
+#: fortran/resolve.c:4094
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组上限引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4107
+#: fortran/resolve.c:4103
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组上限引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.c:4123
+#: fortran/resolve.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "数组引用缺少下标"
 
-#: fortran/resolve.c:4146
+#: fortran/resolve.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "%L处未指定假定大小数组段的最右端上限"
 
-#: fortran/resolve.c:4156
+#: fortran/resolve.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/resolve.c:4164
+#: fortran/resolve.c:4160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/resolve.c:4180
+#: fortran/resolve.c:4176
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个标量"
 
-#: fortran/resolve.c:4208
+#: fortran/resolve.c:4204
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L处数组索引必须是标量"
 
-#: fortran/resolve.c:4214
+#: fortran/resolve.c:4210
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%L处数组索引必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/resolve.c:4220
+#: fortran/resolve.c:4216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "扩展：%L处的 REAL 数组索引"
 
-#: fortran/resolve.c:4259
+#: fortran/resolve.c:4255
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L 实参维数必须是标量"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4262
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L处实参维数必须具有 INTEGER 类型"
 
-#: fortran/resolve.c:4311
+#: fortran/resolve.c:4307
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4322
+#: fortran/resolve.c:4318
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4333
+#: fortran/resolve.c:4329
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4376
+#: fortran/resolve.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L处数组索引是一个秩为 %d 的数组"
 
-#: fortran/resolve.c:4474
+#: fortran/resolve.c:4470
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L处的子字符串起始索引类型必须为 INTEGER"
 
-#: fortran/resolve.c:4481
+#: fortran/resolve.c:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L处的子字符串起始索引必须是标量"
 
-#: fortran/resolve.c:4490
+#: fortran/resolve.c:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L处的子字符串起始索引小于 1"
 
-#: fortran/resolve.c:4503
+#: fortran/resolve.c:4499
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L处的子字符串终止索引类型必须为 INTEGER"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L处的子字符串终止索引必须是标量"
 
-#: fortran/resolve.c:4520
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "%L处的子字符串终止索引超过了字符串长度"
 
-#: fortran/resolve.c:4530
+#: fortran/resolve.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "%L处子串结束索引太大"
 
-#: fortran/resolve.c:4668
+#: fortran/resolve.c:4664
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L处数组引用错误"
 
-#: fortran/resolve.c:4682
+#: fortran/resolve.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "%L处对有非零秩的部分引用的右侧的组件不能有 POINTER 属性"
 
-#: fortran/resolve.c:4692
+#: fortran/resolve.c:4688
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "%L处对有非零秩的部分引用的右侧的组件不能有 ALLOCATABLE 属性"
 
-#: fortran/resolve.c:4711
+#: fortran/resolve.c:4707
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "%L处不能指定两个或以上秩不为零的部分引用"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4805
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:4891
+#: fortran/resolve.c:4887
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:4901
+#: fortran/resolve.c:4897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
@@ -51602,12 +51653,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4911
+#: fortran/resolve.c:4907
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4926
+#: fortran/resolve.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
@@ -51616,257 +51667,257 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:4936
+#: fortran/resolve.c:4932
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:4947
+#: fortran/resolve.c:4943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "“%s”是必须是一个模块过程或有显式接口的外部过程于 %L 处"
 
-#: fortran/resolve.c:4956
+#: fortran/resolve.c:4952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:4971
+#: fortran/resolve.c:4967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:5061
+#: fortran/resolve.c:5057
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "用在一个规格说明表达式中的变量‘%s’在%L处的引用出现在该变量是其参数的 ENTRY 语句之前"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5062
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "变量‘%s’在%L处的使用出现在该变量是其参数的 ENTRY 语句之前"
 
-#: fortran/resolve.c:5136
+#: fortran/resolve.c:5132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "%2$L处非多态的传递对象哑元实参‘%1$s’"
 
-#: fortran/resolve.c:5149
+#: fortran/resolve.c:5145
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5487
+#: fortran/resolve.c:5483
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "%L处传递的对象必须是标量"
 
-#: fortran/resolve.c:5494
+#: fortran/resolve.c:5490
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "%L处类型限定过程调用的基类型是 ABSTRACT 类型‘%s’"
 
-#: fortran/resolve.c:5529
+#: fortran/resolve.c:5525
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for type-bound procedure call at %L is of ABSTRACT type '%s'"
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "%L处类型限定过程调用的基类型是 ABSTRACT 类型‘%s’"
 
-#: fortran/resolve.c:5538
+#: fortran/resolve.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "%L处 NOPASS 类型限定过程调用的基对象必须是标量"
 
 #. Nothing matching found!
-#: fortran/resolve.c:5726
+#: fortran/resolve.c:5722
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "%2$L处对 GENERIC‘%1$s’的调用没有找到匹配特别的限定"
 
-#: fortran/resolve.c:5753
+#: fortran/resolve.c:5749
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%2$L处的‘%1$s’应该是一个 SUBROUTINE"
 
-#: fortran/resolve.c:5804
+#: fortran/resolve.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%2$L处的‘%1$s’应该是一个 FUNCTION"
 
-#: fortran/resolve.c:6321
+#: fortran/resolve.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要表达式类型"
 
-#: fortran/resolve.c:6347
+#: fortran/resolve.c:6343
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L处)必须是一个标量"
 
-#: fortran/resolve.c:6357
+#: fortran/resolve.c:6353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s (%L处)必须是一个标量"
 
-#: fortran/resolve.c:6361 fortran/resolve.c:6368
+#: fortran/resolve.c:6357 fortran/resolve.c:6364
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L处)必须是 INTEGER"
 
-#: fortran/resolve.c:6410
+#: fortran/resolve.c:6406
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/resolve.c:6446
+#: fortran/resolve.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "%L处的 DO 循环会被执行零次"
 
-#: fortran/resolve.c:6507
+#: fortran/resolve.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 索引名必须是一个标量整数"
 
-#: fortran/resolve.c:6512
+#: fortran/resolve.c:6508
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 起始表达式必须是一个标量整数"
 
-#: fortran/resolve.c:6519
+#: fortran/resolve.c:6515
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 结束表达式必须是一个标量整数"
 
-#: fortran/resolve.c:6527
+#: fortran/resolve.c:6523
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L处 FORALL 间隔表达式必须是一个标量 %s"
 
-#: fortran/resolve.c:6532
+#: fortran/resolve.c:6528
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L处 FORALL 间隔表达式不能是零"
 
-#: fortran/resolve.c:6545
+#: fortran/resolve.c:6541
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引‘%s’不能出现在%L处的三元组规格说明中"
 
-#: fortran/resolve.c:6643 fortran/resolve.c:6935
+#: fortran/resolve.c:6639 fortran/resolve.c:6931
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/resolve.c:6651 fortran/resolve.c:6900
+#: fortran/resolve.c:6647 fortran/resolve.c:6896
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "%3$L 处“%1$s”分句对象“%2$s”有 ALLOCATABLE 组件"
 
-#: fortran/resolve.c:6757
+#: fortran/resolve.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "%L处的源表达式必须是标量或者与%L处的分配对象有相同的秩"
 
-#: fortran/resolve.c:6788
+#: fortran/resolve.c:6784
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "%L处的源表达式和%L处的分配对象必须有相同的外形"
 
-#: fortran/resolve.c:6946
+#: fortran/resolve.c:6942
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "%L处实体的类型与%L处的源表达式类型不兼容"
 
-#: fortran/resolve.c:6958
+#: fortran/resolve.c:6954
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "%L处的分配对象和%L处的源表达式应该有相同的种别类型参数"
 
-#: fortran/resolve.c:6972
+#: fortran/resolve.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6981
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "%2$L处分配具有 ABSTRACT 基类型的 %1$s 需要一个类型指定或 SOURCE="
 
-#: fortran/resolve.c:6998
+#: fortran/resolve.c:6994
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7106
+#: fortran/resolve.c:7102
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:7120
+#: fortran/resolve.c:7116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L 处的 ALLOCATE 语句中要求的数组规格说明"
 
-#: fortran/resolve.c:7147
+#: fortran/resolve.c:7143
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中有错误的数组规格"
 
-#: fortran/resolve.c:7166
+#: fortran/resolve.c:7162
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’不能出现在%L处其自身被分配的 ALLOCATE 语句的数组规格说明中"
 
-#: fortran/resolve.c:7181
+#: fortran/resolve.c:7177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "%L 处的 ALLOCATE 语句中要求的数组规格说明"
 
-#: fortran/resolve.c:7192
+#: fortran/resolve.c:7188
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L 处的 ALLOCATE 语句中坏的数组规格说明"
 
-#: fortran/resolve.c:7223
+#: fortran/resolve.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的统计变量不能在同一个 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:7257
+#: fortran/resolve.c:7253
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "%L处的 ERRMSG 没有 STAT 标记所以不起作用"
 
-#: fortran/resolve.c:7268
+#: fortran/resolve.c:7264
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.c:7291
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的错误信息变量不能在同一 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7317
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "%L处分配的对象也出现在%L处"
 
-#: fortran/resolve.c:7327 fortran/resolve.c:7333
+#: fortran/resolve.c:7323 fortran/resolve.c:7329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "%2$L 处对象“%1$s”不是一个变量"
@@ -51875,190 +51926,190 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:7537
+#: fortran/resolve.c:7533
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L处的 CASE 标号与%L处的 CASE 标号重叠"
 
-#: fortran/resolve.c:7588
+#: fortran/resolve.c:7584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L处 CASE 语句中的表达式必须具有 %s 类型"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L 处 CASE 语句中的表达式种别必须为 %d"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7608
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L处 CASE 语句中的表达式必须为标量"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7654
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/resolve.c:7677
+#: fortran/resolve.c:7673
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L处 SELECT 语句的实参不能是 %s"
 
-#: fortran/resolve.c:7687
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:7705 fortran/resolve.c:7713
+#: fortran/resolve.c:7701 fortran/resolve.c:7709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L 处 CASE 语句中的逻辑范围是不被允许的"
 
-#: fortran/resolve.c:7775 fortran/resolve.c:8148
+#: fortran/resolve.c:7771 fortran/resolve.c:8144
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L处的 DEFAULT CASE 为%L处的第二个 DEFAULT CASE 所跟随"
 
-#: fortran/resolve.c:7801
+#: fortran/resolve.c:7797
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L处 CASE 语句中的逻辑范围是不被允许的"
 
-#: fortran/resolve.c:7813
+#: fortran/resolve.c:7809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L 处 CASE 语句中的常量逻辑值被重复了"
 
-#: fortran/resolve.c:7828
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L处范围规格无法匹配"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7927
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L处逻辑 SELECT CASE 块有多于两个的情况"
 
-#: fortran/resolve.c:8003
+#: fortran/resolve.c:7999
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "%2$L 处的名字“%1$s”已经在 %4$L 处被用作 %3$s"
 
-#: fortran/resolve.c:8013
+#: fortran/resolve.c:8009
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8063
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%C处 SELECT TYPE 语句中的选择子应该是多态的"
 
-#: fortran/resolve.c:8084 fortran/resolve.c:8096
+#: fortran/resolve.c:8080 fortran/resolve.c:8092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:8112
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "%2$L处派生类型‘%1$s’必须是可扩展的"
 
-#: fortran/resolve.c:8124
+#: fortran/resolve.c:8120
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be an extension of '%s'"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "%2$L处派生类型‘%1$s’必须是‘%3$s’的一个扩展"
 
-#: fortran/resolve.c:8127
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "对子进程名‘%s’非预期的使用，在%C处"
 
-#: fortran/resolve.c:8136
+#: fortran/resolve.c:8132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8324
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "%L处 SELECT TYPE 语句中有双重的 CLASS IS 块"
 
-#: fortran/resolve.c:8417
+#: fortran/resolve.c:8413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "%%L处 NULL() 指针上下文无效"
 
 #. FIXME: Test for defined input/output.
-#: fortran/resolve.c:8445
+#: fortran/resolve.c:8441
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:8457
+#: fortran/resolve.c:8453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.c:8466
+#: fortran/resolve.c:8462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.c:8473
+#: fortran/resolve.c:8469
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 ALLOCATABLE 组件"
 
-#: fortran/resolve.c:8484 fortran/resolve.c:8490
+#: fortran/resolve.c:8480 fortran/resolve.c:8486
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8500
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L处数据传输元素不能是对一个假定大小数组的全引用"
 
-#: fortran/resolve.c:8559
+#: fortran/resolve.c:8555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:8566 fortran/resolve.c:8677
+#: fortran/resolve.c:8562 fortran/resolve.c:8673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:8578 fortran/resolve.c:8684
+#: fortran/resolve.c:8574 fortran/resolve.c:8680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.c:8590
+#: fortran/resolve.c:8586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:8654
+#: fortran/resolve.c:8650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:8658 fortran/resolve.c:8668
+#: fortran/resolve.c:8654 fortran/resolve.c:8664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L处 ACOS 的参数必须在 -1 和 1 之间"
 
-#: fortran/resolve.c:8711
+#: fortran/resolve.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L处的语句对%L处的分支语句而言不是一个有效的分支目标语句"
 
-#: fortran/resolve.c:8721
+#: fortran/resolve.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "%L处的分支可能导致无穷循环"
@@ -52065,12 +52116,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:8738 fortran/resolve.c:8761
+#: fortran/resolve.c:8734 fortran/resolve.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8742 fortran/resolve.c:8767
+#: fortran/resolve.c:8738 fortran/resolve.c:8763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
@@ -52078,161 +52129,161 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:8782
+#: fortran/resolve.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L处的标号与%L处 GOTO 语句不在相同的块中"
 
-#: fortran/resolve.c:8854
+#: fortran/resolve.c:8850
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L处的 WHERE 掩码外形不一致"
 
-#: fortran/resolve.c:8870
+#: fortran/resolve.c:8866
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L处 WHERE 赋值目标外形不一致"
 
-#: fortran/resolve.c:8878 fortran/resolve.c:8965
+#: fortran/resolve.c:8874 fortran/resolve.c:8961
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "%L处 WHERE 中用户定义的非 ELEMENTAL 用户赋值"
 
-#: fortran/resolve.c:8888 fortran/resolve.c:8975
+#: fortran/resolve.c:8884 fortran/resolve.c:8971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L处在 WHERE 内不支持的语句"
 
-#: fortran/resolve.c:8919
+#: fortran/resolve.c:8915
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.c:8928
+#: fortran/resolve.c:8924
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "%2$L处带索引‘%1$s’的 FORALL 没有被用在赋值的左侧，所以可能导致对这个对象的多个赋值"
 
-#: fortran/resolve.c:9097
+#: fortran/resolve.c:9093
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "%L处外部 FORALL 构造已经有一个同名的索引"
 
-#: fortran/resolve.c:9175
+#: fortran/resolve.c:9171
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L处的 WHERE/ELSEWHERE 子句需要一个 LOGICAL 数组"
 
-#: fortran/resolve.c:9251
+#: fortran/resolve.c:9247
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:9365
+#: fortran/resolve.c:9361
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgstr "CHARACTER 表达式在%3$L处赋值时将被截断(%1$d/%2$d)"
 
-#: fortran/resolve.c:9397
+#: fortran/resolve.c:9393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "在 %L 处 impure 变量被赋值到一个 PURE 过程(12.6)中的 POINTER 组件的派生类型变量"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "%L处一个非纯变量在 PURE 过程中被赋值给带有 POINTER 组件派生类型变量(12.6)"
 
-#: fortran/resolve.c:9412
+#: fortran/resolve.c:9408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "不能在%2$C处的 PURE 过程中读取变量‘%1$s’"
 
-#: fortran/resolve.c:9444
+#: fortran/resolve.c:9440
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:9448
+#: fortran/resolve.c:9444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.c:9453
+#: fortran/resolve.c:9449
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%L处向 FORALL 索引变量赋值"
 
 #. See PR 43366.
-#: fortran/resolve.c:9458
+#: fortran/resolve.c:9454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 msgstr "不能在%2$C处的 PURE 过程中读取变量‘%1$s’"
 
-#: fortran/resolve.c:9464
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:9475
+#: fortran/resolve.c:9471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "%L处赋值中的变量类型不能是多态的"
 
-#: fortran/resolve.c:9770
+#: fortran/resolve.c:9766
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
-#: fortran/resolve.c:10145
+#: fortran/resolve.c:10141
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "ASSIGNED GOTO 语句在%L处需要一个 INTEGER 变量"
 
-#: fortran/resolve.c:10148
+#: fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "变量‘%s’在 %L 尚未指派目标标号"
 
-#: fortran/resolve.c:10159
+#: fortran/resolve.c:10155
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "%L处的替代 RETURN 语句需要一个 SCALAR-INTEGER 返回限定符"
 
-#: fortran/resolve.c:10207
+#: fortran/resolve.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L处的 ASSIGN 语句需要一个默认标量 INTEGER 变量"
 
-#: fortran/resolve.c:10240
+#: fortran/resolve.c:10236
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgstr "%L处的算术 IF 语句要求一个数字表达式"
 
-#: fortran/resolve.c:10295
+#: fortran/resolve.c:10291
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:10300
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L处 DO WHILE 循环的退出条件必须是一个标量 LOGICAL 表达式"
 
-#: fortran/resolve.c:10384
+#: fortran/resolve.c:10380
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 FORMALL 掩码子句需要一个 LOGICAL 表达式"
 
-#: fortran/resolve.c:10453
+#: fortran/resolve.c:10449
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：错误的语句代码"
 
-#: fortran/resolve.c:10548
+#: fortran/resolve.c:10544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
@@ -52239,7 +52290,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:10561
+#: fortran/resolve.c:10557
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s from module %s with binding label %s at %L uses the same global identifier as entity at %L from module %s"
 msgstr ""
@@ -52247,61 +52298,61 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:10578
+#: fortran/resolve.c:10574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure %s with binding label %s at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
 
-#: fortran/resolve.c:10649
+#: fortran/resolve.c:10645
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER variable at %L has negative length %d, the length has been set to zero"
 msgstr "%L处的CHARACTER 变量有负的长度 %d，长度已经被设为零"
 
-#: fortran/resolve.c:10662
+#: fortran/resolve.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "%L处字符串太长"
 
-#: fortran/resolve.c:10998
+#: fortran/resolve.c:10994
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可分配的数组‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:11002
+#: fortran/resolve.c:10998
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "%2$L处标量对象‘%1$s’不能为 ALLOCATABLE"
 
-#: fortran/resolve.c:11010
+#: fortran/resolve.c:11006
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:11020
+#: fortran/resolve.c:11016
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11031
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' of CLASS variable '%s' at %L is not extensible"
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: fortran/resolve.c:11047
+#: fortran/resolve.c:11043
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable '%s' at %L must be dummy, allocatable or pointer"
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "%2$L处的 CLASS 变量‘%1$s’必须是哑元、可分配的或者指针"
 
-#: fortran/resolve.c:11078
+#: fortran/resolve.c:11074
 #, gcc-internal-format, gfc-internal-format
 msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "‘%s’在%L处不能是主机相关的，因为它被在%L处声明的一个不兼容的同名对象所阻碍"
 
-#: fortran/resolve.c:11100
+#: fortran/resolve.c:11096
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008：%2$L处模块变量‘%1$s’隐含使用了 SAVE，因为默认初始化有此需求"
@@ -52308,472 +52359,472 @@
 
 #. The shape of a main program or module array needs to be
 #. constant.
-#: fortran/resolve.c:11148
+#: fortran/resolve.c:11144
 #, gcc-internal-format, gfc-internal-format
 msgid "The module or main program array '%s' at %L must have constant shape"
 msgstr "%2$L处的模块或主程序数组‘%1$s’必须有常量外形"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11156
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:11176
+#: fortran/resolve.c:11172
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L处假定字符长度的实体必须是个虚参或是个 PARAMETER"
 
-#: fortran/resolve.c:11197
+#: fortran/resolve.c:11193
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' at %L must have constant character length in this context"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:11204
+#: fortran/resolve.c:11200
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:11251
+#: fortran/resolve.c:11247
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可分配的‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:11254
+#: fortran/resolve.c:11250
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:11258
+#: fortran/resolve.c:11254
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "哑元‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:11261
+#: fortran/resolve.c:11257
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "内建函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:11264
+#: fortran/resolve.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:11267
+#: fortran/resolve.c:11263
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自动数组‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:11310
+#: fortran/resolve.c:11306
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "%2$L处有字符值的语句函数‘%1$s’必须有常量长度"
 
-#: fortran/resolve.c:11332
+#: fortran/resolve.c:11328
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处‘%1$s’是 PRIVATE 类型因而不能是 PUBLIC 类型‘%2$s’的虚参"
 
-#: fortran/resolve.c:11354
+#: fortran/resolve.c:11350
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: %3$L处 PUBLIC 接口‘%2$s’中的过程‘%1$s’有 PRIVATE 的虚参‘%4$s’"
 
-#: fortran/resolve.c:11372
+#: fortran/resolve.c:11368
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:11381
+#: fortran/resolve.c:11377
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:11389
+#: fortran/resolve.c:11385
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%2$L处 ELEMENTAL 函数‘%1$s’必须有一个标量返回值"
 
-#: fortran/resolve.c:11399
+#: fortran/resolve.c:11395
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11414
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为数组值"
 
-#: fortran/resolve.c:11422
+#: fortran/resolve.c:11418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "指定CHARACTER(*) 函数‘%s’在%L处不能为指针值"
 
-#: fortran/resolve.c:11426
+#: fortran/resolve.c:11422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为纯函数"
 
-#: fortran/resolve.c:11430
+#: fortran/resolve.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能是递归的"
 
-#: fortran/resolve.c:11443
+#: fortran/resolve.c:11439
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为纯函数"
 
-#: fortran/resolve.c:11452
+#: fortran/resolve.c:11448
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:11458
+#: fortran/resolve.c:11454
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "哑过程‘%s’在%C处不能有泛型接口"
 
-#: fortran/resolve.c:11514
+#: fortran/resolve.c:11510
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 SAVE 属性冲突"
 
-#: fortran/resolve.c:11520
+#: fortran/resolve.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 INTENT 属性冲突"
 
-#: fortran/resolve.c:11526
+#: fortran/resolve.c:11522
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与在%2$L处‘%1$s’中的 RESULT 属性冲突"
 
-#: fortran/resolve.c:11534
+#: fortran/resolve.c:11530
 #, fuzzy, gcc-internal-format
 #| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL 属性与在%2$L处‘%1$s’中的 FUNCTION 属性冲突"
 
-#: fortran/resolve.c:11540
+#: fortran/resolve.c:11536
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer result '%s' at %L is missing the pointer attribute"
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "%2$L处过程指针结果‘%1$s’缺少指针属性"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11613
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "%2$L处 FINAL 过程‘%1$s’不是一个 SUBROUTINE"
 
-#: fortran/resolve.c:11626
+#: fortran/resolve.c:11622
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "%L处的 FINAL 过程有且只有一个参数"
 
-#: fortran/resolve.c:11635
+#: fortran/resolve.c:11631
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L处 FINAL 过程的参数必须是‘%s’类型"
 
-#: fortran/resolve.c:11643
+#: fortran/resolve.c:11639
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "%L处 FINAL 过程的参数必须不是 POINTER"
 
-#: fortran/resolve.c:11649
+#: fortran/resolve.c:11645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "%L处 FINAL 过程的参数必须不是 ALLOCATABLE"
 
-#: fortran/resolve.c:11655
+#: fortran/resolve.c:11651
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.c:11663
+#: fortran/resolve.c:11659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L处 FINAL 过程的参数必须不是 INTENT(OUT)"
 
-#: fortran/resolve.c:11672
+#: fortran/resolve.c:11668
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "%L处的非标量 FINAL 过程应当有假定外形的参数"
 
-#: fortran/resolve.c:11694
+#: fortran/resolve.c:11690
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "%2$L处声明的 FINAL 过程‘%1$s’有与‘%4$s’相同的秩(%3$d)"
 
-#: fortran/resolve.c:11731
+#: fortran/resolve.c:11727
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "仅为定义在%2$L处的派生类型‘%1$s’声明了数组 FINAL 过程，建议也定义一个标量过程"
 
-#: fortran/resolve.c:11771
+#: fortran/resolve.c:11767
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%4$L处‘%1$s’和‘%2$s’对 GENERIC‘%3$s’不能是混合的 FUNCTION/SUBROUTINE"
 
-#: fortran/resolve.c:11807
+#: fortran/resolve.c:11803
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%4$L处 GENERIC‘%3$s’的‘%1$s’和‘%2$s’有歧义"
 
-#: fortran/resolve.c:11866
+#: fortran/resolve.c:11862
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定义的指定绑定‘%1$s’用作%3$L处的 GENERIC‘%2$s’的目标"
 
-#: fortran/resolve.c:11878
+#: fortran/resolve.c:11874
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "%2$L处 GENERIC‘%1$s’必须定位一个特定的绑定，‘%3$s’也是 GENERIC"
 
-#: fortran/resolve.c:11906
+#: fortran/resolve.c:11902
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "%2$L处 GENERIC‘%1$s’无法覆盖同名的特定绑定"
 
-#: fortran/resolve.c:11962
+#: fortran/resolve.c:11958
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "%L处类型限定的操作数不能是 NOPASS"
 
-#: fortran/resolve.c:12144
+#: fortran/resolve.c:12140
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%2$L处的‘%1$s’必须是一个模块过程或带有显式接口的外部过程"
 
-#: fortran/resolve.c:12186
+#: fortran/resolve.c:12182
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处有 PASS(%2$s)的过程‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.c:12200
+#: fortran/resolve.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处有 PASS 的过程‘%1$s’必须至少带一个参数"
 
-#: fortran/resolve.c:12214 fortran/resolve.c:12709
+#: fortran/resolve.c:12210 fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 #| msgid "Non-polymorphic passed-object dummy argument of '%s' at %L"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%2$L处非多态的传递对象虚参‘%1$s’"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12218
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr " %4$L处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须具有派生类型‘%5$s’"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12227
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%2$L处‘%1$s’的传递对象虚参必须是标量"
 
-#: fortran/resolve.c:12237
+#: fortran/resolve.c:12233
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 ALLOCATABLE"
 
-#: fortran/resolve.c:12243
+#: fortran/resolve.c:12239
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 POINTER"
 
-#: fortran/resolve.c:12272
+#: fortran/resolve.c:12268
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的组件重名"
 
-#: fortran/resolve.c:12281
+#: fortran/resolve.c:12277
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的继承组件重名"
 
-#: fortran/resolve.c:12373
+#: fortran/resolve.c:12369
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' declared at %L must be ABSTRACT because '%s' is DEFERRED and not overridden"
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "%2$L处声明的派生类型‘%1$s’必须是 ABSTRACT，因为‘%3$s’是 DEFERRED 且没有被覆盖"
 
-#: fortran/resolve.c:12471
+#: fortran/resolve.c:12467
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:12484
+#: fortran/resolve.c:12480
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "%2$L处不能扩展的派生类型‘%1$s’不能是 ABSTRACT"
 
-#: fortran/resolve.c:12504
+#: fortran/resolve.c:12500
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:12514
+#: fortran/resolve.c:12510
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:12525
+#: fortran/resolve.c:12521
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:12535
+#: fortran/resolve.c:12531
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:12636
+#: fortran/resolve.c:12632
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处带有 PASS(%2$s)的过程指针组件‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.c:12651
+#: fortran/resolve.c:12647
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:12668
+#: fortran/resolve.c:12664
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "%4$L处具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须有派生类型‘%5$s’"
 
-#: fortran/resolve.c:12679
+#: fortran/resolve.c:12675
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%4$L 处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须是标量"
 
-#: fortran/resolve.c:12689
+#: fortran/resolve.c:12685
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能有 POINTER 属性"
 
-#: fortran/resolve.c:12699
+#: fortran/resolve.c:12695
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能是 ALLOCATABLE"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12737
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.c:12754
+#: fortran/resolve.c:12750
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "%2$L处组件‘%1$s’的字符长度必须是一个常量规格表达式"
 
-#: fortran/resolve.c:12765
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12796
+#: fortran/resolve.c:12792
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处组合‘%1$s’是一个 PRIVATE 类型，因此不能是 PUBLIC‘%2$s’的组合"
 
-#: fortran/resolve.c:12804
+#: fortran/resolve.c:12800
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:12813
+#: fortran/resolve.c:12809
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "%2$L处声明的有 SEQUENCE 类型的组件 %1$s 没有 SEQUENCE 属性"
 
-#: fortran/resolve.c:12831 fortran/resolve.c:12843
+#: fortran/resolve.c:12827 fortran/resolve.c:12839
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "%3$L处‘%2$s’的指针组件‘%1$s’类型尚未声明"
 
-#: fortran/resolve.c:12855
+#: fortran/resolve.c:12851
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
 msgid "Component %qs with CLASS at %L must be allocatable or pointer"
 msgstr "%2$L处具有 CLASS 的组件‘%1$s’必须是可分配的或指针"
 
-#: fortran/resolve.c:12923
+#: fortran/resolve.c:12919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.c:12979
+#: fortran/resolve.c:12975
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "不允许 %3$L 处 %2$s 名字列表中假定大小的数组“%1$s”"
 
-#: fortran/resolve.c:12985
+#: fortran/resolve.c:12981
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有假定外形"
 
-#: fortran/resolve.c:12991
+#: fortran/resolve.c:12987
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.c:12999
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.c:13009
+#: fortran/resolve.c:13005
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有 POINTER 组件"
 
-#: fortran/resolve.c:13019
+#: fortran/resolve.c:13015
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有 ALLOCATABLE 组件"
@@ -52780,424 +52831,424 @@
 
 #. FIXME: Once UDDTIO is implemented, the following can be
 #. removed.
-#: fortran/resolve.c:13027
+#: fortran/resolve.c:13023
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有 ALLOCATABLE 组件"
 
-#: fortran/resolve.c:13044
+#: fortran/resolve.c:13040
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’声明为 PRIVATE 因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13050
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有使用相关的 PRIVATE 组件因此不能是 NAMELIST‘%2$s’的成员"
 
-#: fortran/resolve.c:13065
+#: fortran/resolve.c:13061
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有 PRIVATE 组件因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13088
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 NAMELIST 属性冲突"
 
-#: fortran/resolve.c:13111
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "%2$L处的参数数组‘%1$s’不能是自动的或有延迟的外形"
 
-#: fortran/resolve.c:13123
+#: fortran/resolve.c:13119
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "%2$L处隐式类型的 PARAMETER‘%1$s’与随后的 IMPLICIT 类型不匹配"
 
-#: fortran/resolve.c:13134
+#: fortran/resolve.c:13130
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "EXTERNAL 属性与在%2$L处‘%1$s’中的 FUNCTION 属性冲突"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE 属性与在 %2$L 处“%1$s”中的 SAVE 属性冲突"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13309
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13327
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.c:13334
+#: fortran/resolve.c:13330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/resolve.c:13342
+#: fortran/resolve.c:13338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/resolve.c:13349
+#: fortran/resolve.c:13345
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:13362
+#: fortran/resolve.c:13358
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L处的符号不是一个 DUMMY 变量"
 
-#: fortran/resolve.c:13368
+#: fortran/resolve.c:13364
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:13378
+#: fortran/resolve.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "%2$L处带 VALUE 属性的字符哑元‘%1$s’必须具有常数长度"
 
-#: fortran/resolve.c:13387
+#: fortran/resolve.c:13383
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "%2$L处带 VALUE 属性与 C 可互操作的字符哑元‘%1$s’长度必须为 1"
 
-#: fortran/resolve.c:13400 fortran/resolve.c:13567
+#: fortran/resolve.c:13396 fortran/resolve.c:13563
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "%2$L处派生类型‘%1$s’的类型‘%3$s’尚未定义"
 
-#: fortran/resolve.c:13414
+#: fortran/resolve.c:13410
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13423
+#: fortran/resolve.c:13419
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:13432
+#: fortran/resolve.c:13428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:13440
+#: fortran/resolve.c:13436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:13447
+#: fortran/resolve.c:13443
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:13467
+#: fortran/resolve.c:13463
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "%2$L处假定外形数组‘%1$s’不能用在初始化表达式中"
 
-#: fortran/resolve.c:13474
+#: fortran/resolve.c:13470
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:13481
+#: fortran/resolve.c:13477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:13488
+#: fortran/resolve.c:13484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "%C处的循环变量不能是一个子组件"
 
-#: fortran/resolve.c:13513
+#: fortran/resolve.c:13509
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "%2$L处变量‘%1$s’不能是 BIND(C) 因为它既不是一个 COMMON 块也不是于模块级作用域声明的"
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13589
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003：%3$L处 PUBLIC %1$s‘%2$s’具有 PRIVATE 派生类型‘%4$s’"
 
-#: fortran/resolve.c:13608
+#: fortran/resolve.c:13604
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13626
+#: fortran/resolve.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "%2$L处INTENT(OUT) 虚参‘%1$s’是 ASSUMED SIZE，所以不能有一个默认初始值设定"
 
-#: fortran/resolve.c:13638
+#: fortran/resolve.c:13634
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.c:13650
+#: fortran/resolve.c:13646
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:13659
+#: fortran/resolve.c:13655
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13671
+#: fortran/resolve.c:13667
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13686
+#: fortran/resolve.c:13682
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:13694
+#: fortran/resolve.c:13690
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13697
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/resolve.c:13713
+#: fortran/resolve.c:13709
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:13722
+#: fortran/resolve.c:13718
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:13738
+#: fortran/resolve.c:13734
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:13744
+#: fortran/resolve.c:13740
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:13823
+#: fortran/resolve.c:13819
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "%L处的线程私有变量未被保存"
 
-#: fortran/resolve.c:13834
+#: fortran/resolve.c:13830
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:13921
+#: fortran/resolve.c:13917
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:13927
+#: fortran/resolve.c:13923
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必须在 COMMON 中"
 
-#: fortran/resolve.c:13933
+#: fortran/resolve.c:13929
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必在前一个声明中指定"
 
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13938
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "%2$L 处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:13956
+#: fortran/resolve.c:13952
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L is a pointer and so must be a full array"
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "%2$L处的 DATA 元素‘%1$s’是一个指针所以必须是一个完全的数组"
 
-#: fortran/resolve.c:14002
+#: fortran/resolve.c:13998
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "%L处 DATA 语句中有非常量数组段"
 
-#: fortran/resolve.c:14015
+#: fortran/resolve.c:14011
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L处的 DATA 语名中变量比值多"
 
-#: fortran/resolve.c:14114
+#: fortran/resolve.c:14110
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14122
+#: fortran/resolve.c:14118
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:14255
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L处的 DATA 语句中值比变量多"
 
-#: fortran/resolve.c:14420
+#: fortran/resolve.c:14416
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "标号 %d 于 %L 经定义但未被使用"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14421
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "标号 %d 于 %L 经定义但无法被使用"
 
-#: fortran/resolve.c:14509
+#: fortran/resolve.c:14505
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须有 SEQUENCE 属性方能成为 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:14518
+#: fortran/resolve.c:14514
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须没有 ALLOCATABLE 组件方能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:14526
+#: fortran/resolve.c:14522
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "%2$L处的默认初始化的派生类型变量‘%1$s’不能成为 EQUIVALENCE 对象，因为它在 COMMON 中有变量"
 
-#: fortran/resolve.c:14542
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "%2$L处的带指针组件的派生类型变量‘%1$s’不能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14641
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L处 EQUIVALENCE 语句语法错误"
 
-#: fortran/resolve.c:14660
+#: fortran/resolve.c:14656
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "%L处 EQUIVALENCE 集中的对象必须都带有或者都不带有 PROTECTED 属性"
 
-#: fortran/resolve.c:14672
+#: fortran/resolve.c:14668
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%2$L处的公共块成员‘%1$s’不能在纯过程‘%3$s’中成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14677
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处的有名常量‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:14754
+#: fortran/resolve.c:14750
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "%2$L处有非常量界限的数组‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:14765
+#: fortran/resolve.c:14761
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处结构组件‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14772
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字符串长度为零"
 
-#: fortran/resolve.c:14819
+#: fortran/resolve.c:14815
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003：%2$L处 PRIVATE 类型‘%3$s’的 PUBLIC 函数‘%1$s’"
 
-#: fortran/resolve.c:14832
+#: fortran/resolve.c:14828
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的 ENTRY‘%1$s’没有隐式类型"
 
-#: fortran/resolve.c:14849
+#: fortran/resolve.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "%2$L处的用户运算符‘%1$s’必须是一个 FUNCTION"
 
-#: fortran/resolve.c:14859
+#: fortran/resolve.c:14855
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "%2$L处用户运算符过程‘%1$s’不能有假定字符长度"
 
-#: fortran/resolve.c:14867
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "%2$L处的用户运算符‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:14881
+#: fortran/resolve.c:14877
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第一个参数不能是可选的"
 
-#: fortran/resolve.c:14899
+#: fortran/resolve.c:14895
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第二个参数不能是可选的"
 
-#: fortran/resolve.c:14906
+#: fortran/resolve.c:14902
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L处的运算符接口必须有至多两个实参"
 
-#: fortran/resolve.c:14984
+#: fortran/resolve.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -53229,49 +53280,49 @@
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
 msgstr "%C处的 !$OMP 开始了一个注释行，因为它既不是由一个空白符跟随也不是一个续行"
 
-#: fortran/scanner.c:1255 fortran/scanner.c:1432
+#: fortran/scanner.c:1255 fortran/scanner.c:1424
 #, gcc-internal-format, gfc-internal-format
 msgid "Line truncated at %L"
 msgstr "行在%L处被截断"
 
-#: fortran/scanner.c:1321 fortran/scanner.c:1492
+#: fortran/scanner.c:1311 fortran/scanner.c:1484
 #, gcc-internal-format, gfc-internal-format
 msgid "Limit of %d continuations exceeded in statement at %C"
 msgstr "%2$C处语句超出 %1$d 个续行的限制"
 
-#: fortran/scanner.c:1392
+#: fortran/scanner.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "Missing '&' in continued character constant at %C"
 msgid "Missing %<&%> in continued character constant at %C"
 msgstr "%C处的延续字符常量缺少‘&’"
 
-#: fortran/scanner.c:1642
+#: fortran/scanner.c:1634
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character at %C"
 msgstr "%C处的制表符不相容"
 
-#: fortran/scanner.c:1730 fortran/scanner.c:1733
+#: fortran/scanner.c:1722 fortran/scanner.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "'&' not allowed by itself in line %d"
 msgid "%<&%> not allowed by itself in line %d"
 msgstr "行 %d 中不允许出现游离的‘&’"
 
-#: fortran/scanner.c:1792
+#: fortran/scanner.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in column %d of line %d"
 msgstr "第 %d 列第 %d 行有不相容的制表符"
 
-#: fortran/scanner.c:2017
+#: fortran/scanner.c:2009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: file %s left but not entered"
 msgstr "%s:%d：文件 %s 被留下但未进入"
 
-#: fortran/scanner.c:2051
+#: fortran/scanner.c:2043
 #, gcc-internal-format, gfc-internal-format
 msgid "%s:%d: Illegal preprocessor directive"
 msgstr "%s:%d：无效的预处理指令"
 
-#: fortran/scanner.c:2176
+#: fortran/scanner.c:2168
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open file '%s'"
 msgid "Can't open file %qs"
@@ -53540,55 +53591,55 @@
 msgid "Reshaped array too large at %C"
 msgstr "%C处整数太大"
 
-#: fortran/simplify.c:5280
+#: fortran/simplify.c:5283
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "%L处 SCALE 的结果上溢其种别"
 
-#: fortran/simplify.c:5940
+#: fortran/simplify.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "Bad type in gfc_simplify_sign"
 msgstr "常量表达式中类型错误"
 
-#: fortran/simplify.c:5969
+#: fortran/simplify.c:5972
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:6096 fortran/simplify.c:6328
+#: fortran/simplify.c:6099 fortran/simplify.c:6331
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:6184
+#: fortran/simplify.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "%L处 SQRT 的参数为负"
 
-#: fortran/simplify.c:6200
+#: fortran/simplify.c:6203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid second argument of IBSET at %L"
 msgid "invalid argument of SQRT at %L"
 msgstr "%L处 IBSET 的第二个参数无效"
 
-#: fortran/simplify.c:6495
+#: fortran/simplify.c:6498
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6518
+#: fortran/simplify.c:6521
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:6853
+#: fortran/simplify.c:6856
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_conv_constant_to_tree(): invalid type: %s"
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree()：无效类型；%s"
 
-#: fortran/simplify.c:6939
+#: fortran/simplify.c:6942
 #, fuzzy, gcc-internal-format
 #| msgid "Character '%s' in string at %L cannot be converted into character kind %d"
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
@@ -53674,265 +53725,270 @@
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "%2$L 处的对象“%1$s”对于成分的默认初始化必须有 SAVE 属性，"
 
-#: fortran/symbol.c:484
+#: fortran/symbol.c:463
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "internal procedure '%s' at %L conflicts with DUMMY argument"
+msgstr "内部过程‘%s’在%L处不允许用作实参"
+
+#: fortran/symbol.c:489
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "Fortran 2003：%C处的过程指针"
 
-#: fortran/symbol.c:653
+#: fortran/symbol.c:658
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "%1$s 属性应用于%4$L处的 %2$s %3$s"
 
-#: fortran/symbol.c:660
+#: fortran/symbol.c:665
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) 应用于%3$L处的 %1$s %2$s"
 
-#: fortran/symbol.c:772 fortran/symbol.c:1509
+#: fortran/symbol.c:777 fortran/symbol.c:1514
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/symbol.c:775
+#: fortran/symbol.c:780
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
 msgstr "%s 属性与 %s 属性冲突，在‘%s’中，位于 %L"
 
-#: fortran/symbol.c:783
+#: fortran/symbol.c:788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute with %s attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/symbol.c:789
+#: fortran/symbol.c:794
 #, fuzzy, gcc-internal-format
 msgid "%s attribute with %s attribute in %qs at %L"
 msgstr "%s 属性与 %s 属性冲突，在‘%s’中，位于 %L"
 
-#: fortran/symbol.c:833
+#: fortran/symbol.c:838
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "不能改变%L处 USE 关联的符号的属性"
 
-#: fortran/symbol.c:836
+#: fortran/symbol.c:841
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "不能改变%2$L处 USE 关联的符号‘%1$s’的属性"
 
-#: fortran/symbol.c:852
+#: fortran/symbol.c:857
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "重复的 %s 属性在%L处被指定"
 
-#: fortran/symbol.c:894
+#: fortran/symbol.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "%L 处 ALLOCATABLE 指定在 INTERFACE 体之外"
 
-#: fortran/symbol.c:920
+#: fortran/symbol.c:925
 #, fuzzy, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "为“%s”规定的 DIMENSION 在 %L 处它的 INTERFACE 主体外面"
 
-#: fortran/symbol.c:946
+#: fortran/symbol.c:951
 #, fuzzy, gcc-internal-format
 #| msgid "DIMENSION specified for '%s' outside its INTERFACE body at %L"
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "%2$L处为‘%1$s’的 DIMENSION 指定在其 INTERFACE 体之外"
 
-#: fortran/symbol.c:1076
+#: fortran/symbol.c:1081
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "%L处 Cray 指针指向的对象出现在多个 pointer() 语句中"
 
-#: fortran/symbol.c:1095
+#: fortran/symbol.c:1100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "%L处指定了重复的 PROTECTED 属性"
 
-#: fortran/symbol.c:1128
+#: fortran/symbol.c:1133
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "%L处 PURE 过程不能指定 SAVE 属性"
 
-#: fortran/symbol.c:1139
+#: fortran/symbol.c:1144
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "%L 指定了重复的 SAVE 属性"
 
-#: fortran/symbol.c:1159
+#: fortran/symbol.c:1164
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "%L处指定了重复的 VALUE 属性"
 
-#: fortran/symbol.c:1178
+#: fortran/symbol.c:1183
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "%L处指定了重复的 VOLATILE 属性"
 
-#: fortran/symbol.c:1197
+#: fortran/symbol.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "%L处指定了重复的 ASYNCHRONOUS 属性"
 
-#: fortran/symbol.c:1505
+#: fortran/symbol.c:1510
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "‘%2$s’的 %1$s 属性与%4$L处的 %3$s 属性冲突"
 
-#: fortran/symbol.c:1539
+#: fortran/symbol.c:1544
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "%2$L处的 %1$s 过程已经被声明为 %3$s 过程"
 
-#: fortran/symbol.c:1574
+#: fortran/symbol.c:1579
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) 与 INTENT(%s) 在 %L 冲突"
 
-#: fortran/symbol.c:1598
+#: fortran/symbol.c:1603
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "%L处的 ACCESS 规格已经被指定"
 
-#: fortran/symbol.c:1615
+#: fortran/symbol.c:1620
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "%L处指定了重复的 BIND 属性"
 
-#: fortran/symbol.c:1622
+#: fortran/symbol.c:1627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "Fortran 2003：%L处的 BIND(C)"
 
-#: fortran/symbol.c:1638
+#: fortran/symbol.c:1643
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "%L处指定了重复的 EXTENDS 属性"
 
-#: fortran/symbol.c:1642
+#: fortran/symbol.c:1647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "Fortran 2003：%L处的 EXTENDS"
 
-#: fortran/symbol.c:1663
+#: fortran/symbol.c:1668
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "符号‘%s’在%L处已经有了显式接口"
 
-#: fortran/symbol.c:1670
+#: fortran/symbol.c:1675
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has attributes specified outside its INTERFACE body"
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "%2$L处的‘%1$s’有在其 INTERFACE 体外指定的属性"
 
-#: fortran/symbol.c:1704
+#: fortran/symbol.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1708
+#: fortran/symbol.c:1713
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "符号‘%s’在%L处已经有了基本类型 %s"
 
-#: fortran/symbol.c:1715
+#: fortran/symbol.c:1720
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "%2$L处过程‘%1$s’不能有基本类型 %3$s"
 
-#: fortran/symbol.c:1727
+#: fortran/symbol.c:1732
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "%2$L处的符号‘%1$s’不能有类型"
 
-#: fortran/symbol.c:1898
+#: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already declared at %L"
 msgstr "%2$C处的组件‘%1$s’已于 %3$L处被声明"
 
-#: fortran/symbol.c:1909
+#: fortran/symbol.c:1914
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %C already in the parent type at %L"
 msgstr "%2$C处的组件‘%1$s’已在%3$L处的父类中"
 
-#: fortran/symbol.c:1994
+#: fortran/symbol.c:1999
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "符号‘%s’在%C处有歧义"
 
-#: fortran/symbol.c:2026
+#: fortran/symbol.c:2031
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "%2$C处的派生类型‘%1$s’在定义前使用"
 
-#: fortran/symbol.c:2064
+#: fortran/symbol.c:2069
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "组件‘%s’在%C处是‘%s’的 PRIVATE 组件"
 
-#: fortran/symbol.c:2082
+#: fortran/symbol.c:2087
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "‘%s’在%C处不是‘%s’结构的成员"
 
-#: fortran/symbol.c:2221
+#: fortran/symbol.c:2226
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "重复的语句标号 %d 出现在 %L 和%L处"
 
-#: fortran/symbol.c:2232
+#: fortran/symbol.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "%2$C处的标号 %1$d 已作为分支目标引用"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2247
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "%2$C处的标号 %1$d 已作为格式标号引用"
 
-#: fortran/symbol.c:2248
+#: fortran/symbol.c:2253
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2290
+#: fortran/symbol.c:2295
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "%2$C处的标号 %1$d 先前用作 FORMAT 标号"
 
-#: fortran/symbol.c:2299
+#: fortran/symbol.c:2304
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "%2$C处的标号 %1$d 先前用作分支目标"
 
-#: fortran/symbol.c:2305
+#: fortran/symbol.c:2310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "%C处需要结束名"
 
-#: fortran/symbol.c:2607
+#: fortran/symbol.c:2612
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:2631
+#: fortran/symbol.c:2636
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "%2$C处的名字‘%1$s’是从模块‘%4$s’对‘%3$s’有歧义的引用"
 
-#: fortran/symbol.c:2634
+#: fortran/symbol.c:2639
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
@@ -53939,68 +53995,68 @@
 msgstr "%2$C处的名字‘%1$s’是从当前程序单元对‘%3$s’有歧义的引用"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:2855
+#: fortran/symbol.c:2860
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "%2$C处符号‘%1$s’已经与主机相关联"
 
-#: fortran/symbol.c:3846
+#: fortran/symbol.c:3851
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:3859
+#: fortran/symbol.c:3864
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' declared at %L must have the BIND attribute to be C interoperable"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "%2$L处声明的派生类型‘%1$s’必须使用 BIND 属性方可与 C 互操作"
 
-#: fortran/symbol.c:3877
+#: fortran/symbol.c:3882
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:3898
+#: fortran/symbol.c:3903
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr "%2$L处的组件‘%1$s’不能有 POINTER 属性，因为它是%4$L处派生类型 BIND(C)‘%3$s’的成员"
 
-#: fortran/symbol.c:3908
+#: fortran/symbol.c:3913
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgstr "%2$L 处的过程指针组件‘%1$s’不能是%4$L处 BIND(C) 派生类型‘%3$s’的成员"
 
-#: fortran/symbol.c:3919
+#: fortran/symbol.c:3924
 #, gcc-internal-format, gfc-internal-format
 msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgstr "%2$L处的组件‘%1$s’不能有 ALLOCATABLE 属性，因为它是%4$L处派生类型 BIND(C)‘%3$s’的成员"
 
-#: fortran/symbol.c:3958
+#: fortran/symbol.c:3963
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable, even though derived type '%s' is BIND(C)"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "%3$L处的派生类型‘%2$s’的组件‘%1$s’不能与 C 互操作，即使派生类型‘%4$s’是 BIND(C)"
 
-#: fortran/symbol.c:3968
+#: fortran/symbol.c:3973
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "%3$L处派生类型‘%2$s’中的组件‘%1$s’不能与 C 互操作"
 
-#: fortran/symbol.c:3982
+#: fortran/symbol.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "%2$L处派生类型‘%1$s’不能同时被声明为具有 PRIVATE 和 BIND(C)属性"
 
-#: fortran/symbol.c:3990
+#: fortran/symbol.c:3995
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "%2$L处派生类型‘%1$s’不能有 SEQUENCE 属性，因为它是 BIND(C)"
 
-#: fortran/symbol.c:4470 fortran/symbol.c:4475
+#: fortran/symbol.c:4475 fortran/symbol.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' is used before it is typed at %L"
 msgid "Symbol %qs is used before it is typed at %L"
@@ -54278,7 +54334,7 @@
 msgid "Bad IO basetype (%d)"
 msgstr "错误的 IO 基类型(%d)"
 
-#: fortran/trans-openmp.c:4291
+#: fortran/trans-openmp.c:4300
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr "gfc_trans_omp_workshare()：错误的语句代码"
@@ -56002,6 +56058,10 @@
 #~ msgstr "假定高位字节在前，低位字在前"
 
 #, fuzzy
+#~ msgid "Use ISA 2.07 crypto instructions"
+#~ msgstr "使用 SmartMIPS 指令"
+
+#, fuzzy
 #~ msgid "Generate GP base instructions directly."
 #~ msgstr "生成 isel 指令"
 
@@ -56092,6 +56152,9 @@
 #~ msgid "%q+D causes a section type conflict"
 #~ msgstr "%q+D导致一个节类型冲突"
 
+#~ msgid "-munix=98 option required for C89 Amendment 1 features.\n"
+#~ msgstr "使用 C89 修订版 1 的特性必须指定 -munix=98 选项。\n"
+
 #, fuzzy
 #~ msgid "invalid AE type specified (%s)"
 #~ msgstr "指定了无效的 AE 类型(%s)\n"
@@ -56344,6 +56407,9 @@
 #~ msgid "%qD has no member named %qE"
 #~ msgstr "%qD没有名为%qE的成员"
 
+#~ msgid "ISO C++ forbids subscripting non-lvalue array"
+#~ msgstr "ISO C++ 不允许按下标访问非左值的数组"
+
 #, fuzzy
 #~ msgid "taking address of array of runtime bound"
 #~ msgstr "取一个类型为%<void%>的表达式的地址"
Index: gcc/tree-ssa-dce.c
===================================================================
--- gcc/tree-ssa-dce.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/tree-ssa-dce.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1149,10 +1149,11 @@
 	if (e != e2)
 	  {
 	    cfg_altered = true;
-	    /* If we made a BB unconditionally exit a loop then this
-	       transform alters the set of BBs in the loop.  Schedule
-	       a fixup.  */
-	    if (loop_exit_edge_p (bb->loop_father, e))
+	    /* If we made a BB unconditionally exit a loop or removed
+	       an entry into an irreducible region, then this transform
+	       alters the set of BBs in the loop.  Schedule a fixup.  */
+	    if (loop_exit_edge_p (bb->loop_father, e)
+		|| (e2->dest->flags & BB_IRREDUCIBLE_LOOP))
 	      loops_state_set (LOOPS_NEED_FIXUP);
 	    remove_edge (e2);
 	  }
Index: gcc/graphite-sese-to-poly.c
===================================================================
--- gcc/graphite-sese-to-poly.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/graphite-sese-to-poly.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -2634,9 +2634,17 @@
   gcc_assert (is_gimple_assign (stmt));
   code = gimple_assign_rhs_code (stmt);
 
-  return flag_associative_math
-    && commutative_tree_code (code)
-    && associative_tree_code (code);
+  if (!commutative_tree_code (code)
+      || !associative_tree_code (code))
+    return false;
+
+  tree type = TREE_TYPE (gimple_assign_lhs (stmt));
+
+  if (FLOAT_TYPE_P (type))
+    return flag_associative_math;
+
+  return (INTEGRAL_TYPE_P (type)
+	  && TYPE_OVERFLOW_WRAPS (type));
 }
 
 /* Returns true when PHI contains an argument ARG.  */
Index: gcc/combine.c
===================================================================
--- gcc/combine.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/combine.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -11960,14 +11960,15 @@
 	      continue;
 	    }
 
-	  /* If this is (and:M1 (subreg:M2 X 0) (const_int C1)) where C1
+	  /* If this is (and:M1 (subreg:M1 X:M2 0) (const_int C1)) where C1
 	     fits in both M1 and M2 and the SUBREG is either paradoxical
 	     or represents the low part, permute the SUBREG and the AND
 	     and try again.  */
-	  if (GET_CODE (XEXP (op0, 0)) == SUBREG)
+	  if (GET_CODE (XEXP (op0, 0)) == SUBREG
+	      && CONST_INT_P (XEXP (op0, 1)))
 	    {
-	      unsigned HOST_WIDE_INT c1;
 	      tmode = GET_MODE (SUBREG_REG (XEXP (op0, 0)));
+	      unsigned HOST_WIDE_INT c1 = INTVAL (XEXP (op0, 1));
 	      /* Require an integral mode, to avoid creating something like
 		 (AND:SF ...).  */
 	      if (SCALAR_INT_MODE_P (tmode)
@@ -11977,18 +11978,22 @@
 		     have a defined value due to the AND operation.
 		     However, if we commute the AND inside the SUBREG then
 		     they no longer have defined values and the meaning of
-		     the code has been changed.  */
+		     the code has been changed.
+		     Also C1 should not change value in the smaller mode,
+		     see PR67028 (a positive C1 can become negative in the
+		     smaller mode, so that the AND does no longer mask the
+		     upper bits).  */
 		  && (0
 #ifdef WORD_REGISTER_OPERATIONS
 		      || (mode_width > GET_MODE_PRECISION (tmode)
-			  && mode_width <= BITS_PER_WORD)
+			  && mode_width <= BITS_PER_WORD
+			  && trunc_int_for_mode (c1, tmode) == (HOST_WIDE_INT) c1)
 #endif
 		      || (mode_width <= GET_MODE_PRECISION (tmode)
 			  && subreg_lowpart_p (XEXP (op0, 0))))
-		  && CONST_INT_P (XEXP (op0, 1))
 		  && mode_width <= HOST_BITS_PER_WIDE_INT
 		  && HWI_COMPUTABLE_MODE_P (tmode)
-		  && ((c1 = INTVAL (XEXP (op0, 1))) & ~mask) == 0
+		  && (c1 & ~mask) == 0
 		  && (c1 & ~GET_MODE_MASK (tmode)) == 0
 		  && c1 != mask
 		  && c1 != GET_MODE_MASK (tmode))
Index: gcc/df-problems.c
===================================================================
--- gcc/df-problems.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/df-problems.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1323,22 +1323,23 @@
 
 
 /*----------------------------------------------------------------------------
-   LIVE AND MUST-INITIALIZED REGISTERS.
+   LIVE AND MAY-INITIALIZED REGISTERS.
 
    This problem first computes the IN and OUT bitvectors for the
-   must-initialized registers problems, which is a forward problem.
-   It gives the set of registers for which we MUST have an available
-   definition on any path from the entry block to the entry/exit of
-   a basic block.  Sets generate a definition, while clobbers kill
+   may-initialized registers problems, which is a forward problem.
+   It gives the set of registers for which we MAY have an available
+   definition, i.e. for which there is an available definition on
+   at least one path from the entry block to the entry/exit of a
+   basic block.  Sets generate a definition, while clobbers kill
    a definition.
 
    In and out bitvectors are built for each basic block and are indexed by
    regnum (see df.h for details).  In and out bitvectors in struct
-   df_live_bb_info actually refers to the must-initialized problem;
+   df_live_bb_info actually refers to the may-initialized problem;
 
    Then, the in and out sets for the LIVE problem itself are computed.
    These are the logical AND of the IN and OUT sets from the LR problem
-   and the must-initialized problem.
+   and the may-initialized problem.
 ----------------------------------------------------------------------------*/
 
 /* Private data used to verify the solution for this problem.  */
@@ -1545,7 +1546,7 @@
 }
 
 
-/* Transfer function for the forwards must-initialized problem.  */
+/* Transfer function for the forwards may-initialized problem.  */
 
 static bool
 df_live_transfer_function (int bb_index)
@@ -1569,7 +1570,7 @@
 }
 
 
-/* And the LR info with the must-initialized registers, to produce the LIVE info.  */
+/* And the LR info with the may-initialized registers to produce the LIVE info.  */
 
 static void
 df_live_finalize (bitmap all_blocks)
Index: gcc/config.gcc
===================================================================
--- gcc/config.gcc	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config.gcc	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -819,6 +819,12 @@
   sol2_tm_file_head="dbxelf.h elfos.h ${cpu_type}/sysv4.h"
   sol2_tm_file_tail="${cpu_type}/sol2.h sol2.h"
   sol2_tm_file="${sol2_tm_file_head} ${sol2_tm_file_tail}"
+  case ${target} in
+    *-*-solaris2.1[2-9]*)
+      # __cxa_atexit was introduced in Solaris 12.
+      default_use_cxa_atexit=yes
+      ;;
+  esac
   use_gcc_stdint=wrap
   if test x$gnu_ld = xyes; then
     tm_file="usegld.h ${tm_file}"
Index: gcc/tree-ssa-structalias.c
===================================================================
--- gcc/tree-ssa-structalias.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/tree-ssa-structalias.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -5650,7 +5650,6 @@
   auto_vec<fieldoff_s> fieldstack;
   fieldoff_s *fo;
   unsigned int i;
-  varpool_node *vnode;
 
   if (!declsize
       || !tree_fits_uhwi_p (declsize))
@@ -5668,12 +5667,10 @@
   /* Collect field information.  */
   if (use_field_sensitive
       && var_can_have_subvars (decl)
-      /* ???  Force us to not use subfields for global initializers
-	 in IPA mode.  Else we'd have to parse arbitrary initializers.  */
+      /* ???  Force us to not use subfields for globals in IPA mode.
+	 Else we'd have to parse arbitrary initializers.  */
       && !(in_ipa_mode
-	   && is_global_var (decl)
-	   && (vnode = varpool_node::get (decl))
-	   && vnode->get_constructor ()))
+	   && is_global_var (decl)))
     {
       fieldoff_s *fo = NULL;
       bool notokay = false;
@@ -5805,13 +5802,13 @@
 
 	  /* If this is a global variable with an initializer and we are in
 	     IPA mode generate constraints for it.  */
-	  if (vnode->get_constructor ()
-	      && vnode->definition)
+	  ipa_ref *ref;
+	  for (unsigned idx = 0; vnode->iterate_reference (idx, ref); ++idx)
 	    {
 	      auto_vec<ce_s> rhsc;
 	      struct constraint_expr lhs, *rhsp;
 	      unsigned i;
-	      get_constraint_for_rhs (vnode->get_constructor (), &rhsc);
+	      get_constraint_for_address_of (ref->referred->decl, &rhsc);
 	      lhs.var = vi->id;
 	      lhs.offset = 0;
 	      lhs.type = SCALAR;
Index: gcc/config/alpha/alpha.c
===================================================================
--- gcc/config/alpha/alpha.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/alpha/alpha.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -4548,8 +4548,8 @@
   oldval = operands[3];
   newval = operands[4];
   is_weak = (operands[5] != const0_rtx);
-  mod_s = (enum memmodel) INTVAL (operands[6]);
-  mod_f = (enum memmodel) INTVAL (operands[7]);
+  mod_s = memmodel_from_int (INTVAL (operands[6]));
+  mod_f = memmodel_from_int (INTVAL (operands[7]));
   mode = GET_MODE (mem);
 
   alpha_pre_atomic_barrier (mod_s);
@@ -4587,12 +4587,12 @@
       emit_unlikely_jump (x, label1);
     }
 
-  if (mod_f != MEMMODEL_RELAXED)
+  if (!is_mm_relaxed (mod_f))
     emit_label (XEXP (label2, 0));
 
   alpha_post_atomic_barrier (mod_s);
 
-  if (mod_f == MEMMODEL_RELAXED)
+  if (is_mm_relaxed (mod_f))
     emit_label (XEXP (label2, 0));
 }
 
@@ -4653,8 +4653,8 @@
   newval = operands[4];
   align = operands[5];
   is_weak = (operands[6] != const0_rtx);
-  mod_s = (enum memmodel) INTVAL (operands[7]);
-  mod_f = (enum memmodel) INTVAL (operands[8]);
+  mod_s = memmodel_from_int (INTVAL (operands[7]));
+  mod_f = memmodel_from_int (INTVAL (operands[8]));
   scratch = operands[9];
   mode = GET_MODE (orig_mem);
   addr = XEXP (orig_mem, 0);
@@ -4706,12 +4706,12 @@
       emit_unlikely_jump (x, label1);
     }
 
-  if (mod_f != MEMMODEL_RELAXED)
+  if (!is_mm_relaxed (mod_f))
     emit_label (XEXP (label2, 0));
 
   alpha_post_atomic_barrier (mod_s);
 
-  if (mod_f == MEMMODEL_RELAXED)
+  if (is_mm_relaxed (mod_f))
     emit_label (XEXP (label2, 0));
 }
 
Index: gcc/config/s390/s390-builtins.def
===================================================================
--- gcc/config/s390/s390-builtins.def	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/s390/s390-builtins.def	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -438,15 +438,15 @@
 B_DEF      (s390_vllezg,                vec_insert_and_zerov2di,0,              B_VX,               0,                  BT_FN_UV2DI_ULONGLONGCONSTPTR)
 
 OB_DEF     (s390_vec_load_bndry,        s390_vec_load_bndry_s8,s390_vec_load_bndry_dbl,B_VX,        BT_FN_OV4SI_INTCONSTPTR_INT)
-OB_DEF_VAR (s390_vec_load_bndry_s8,     s390_vlbb,          O2_U3,              BT_OV_V16QI_SCHARCONSTPTR_USHORT)
-OB_DEF_VAR (s390_vec_load_bndry_u8,     s390_vlbb,          O2_U3,              BT_OV_UV16QI_UCHARCONSTPTR_USHORT)
-OB_DEF_VAR (s390_vec_load_bndry_s16,    s390_vlbb,          O2_U3,              BT_OV_V8HI_SHORTCONSTPTR_USHORT)
-OB_DEF_VAR (s390_vec_load_bndry_u16,    s390_vlbb,          O2_U3,              BT_OV_UV8HI_USHORTCONSTPTR_USHORT)
-OB_DEF_VAR (s390_vec_load_bndry_s32,    s390_vlbb,          O2_U3,              BT_OV_V4SI_INTCONSTPTR_USHORT)
-OB_DEF_VAR (s390_vec_load_bndry_u32,    s390_vlbb,          O2_U3,              BT_OV_UV4SI_UINTCONSTPTR_USHORT)
-OB_DEF_VAR (s390_vec_load_bndry_s64,    s390_vlbb,          O2_U3,              BT_OV_V2DI_LONGLONGCONSTPTR_USHORT)
-OB_DEF_VAR (s390_vec_load_bndry_u64,    s390_vlbb,          O2_U3,              BT_OV_UV2DI_ULONGLONGCONSTPTR_USHORT)
-OB_DEF_VAR (s390_vec_load_bndry_dbl,    s390_vlbb,          O2_U3,              BT_OV_V2DF_DBLCONSTPTR_USHORT)
+OB_DEF_VAR (s390_vec_load_bndry_s8,     s390_vlbb,          O2_U16,              BT_OV_V16QI_SCHARCONSTPTR_USHORT)
+OB_DEF_VAR (s390_vec_load_bndry_u8,     s390_vlbb,          O2_U16,              BT_OV_UV16QI_UCHARCONSTPTR_USHORT)
+OB_DEF_VAR (s390_vec_load_bndry_s16,    s390_vlbb,          O2_U16,              BT_OV_V8HI_SHORTCONSTPTR_USHORT)
+OB_DEF_VAR (s390_vec_load_bndry_u16,    s390_vlbb,          O2_U16,              BT_OV_UV8HI_USHORTCONSTPTR_USHORT)
+OB_DEF_VAR (s390_vec_load_bndry_s32,    s390_vlbb,          O2_U16,              BT_OV_V4SI_INTCONSTPTR_USHORT)
+OB_DEF_VAR (s390_vec_load_bndry_u32,    s390_vlbb,          O2_U16,              BT_OV_UV4SI_UINTCONSTPTR_USHORT)
+OB_DEF_VAR (s390_vec_load_bndry_s64,    s390_vlbb,          O2_U16,              BT_OV_V2DI_LONGLONGCONSTPTR_USHORT)
+OB_DEF_VAR (s390_vec_load_bndry_u64,    s390_vlbb,          O2_U16,              BT_OV_UV2DI_ULONGLONGCONSTPTR_USHORT)
+OB_DEF_VAR (s390_vec_load_bndry_dbl,    s390_vlbb,          O2_U16,              BT_OV_V2DF_DBLCONSTPTR_USHORT)
 
 B_DEF      (s390_vlbb,                  vlbb,               0,                  B_VX,               O2_U3,              BT_FN_UV16QI_UCHARCONSTPTR_USHORT)
 
Index: gcc/config/s390/s390.md
===================================================================
--- gcc/config/s390/s390.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/s390/s390.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -9594,7 +9594,7 @@
 {
   /* Unless this is a SEQ_CST fence, the s390 memory model is strong
      enough not to require barriers of any kind.  */
-  if (INTVAL (operands[0]) == MEMMODEL_SEQ_CST)
+  if (is_mm_seq_cst (memmodel_from_int (INTVAL (operands[0]))))
     {
       rtx mem = gen_rtx_MEM (BLKmode, gen_rtx_SCRATCH (Pmode));
       MEM_VOLATILE_P (mem) = 1;
@@ -9675,7 +9675,7 @@
    (match_operand:SI 2 "const_int_operand")]	;; model
   ""
 {
-  enum memmodel model = (enum memmodel) INTVAL (operands[2]);
+  enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
 
   if (MEM_ALIGN (operands[0]) < GET_MODE_BITSIZE (GET_MODE (operands[0])))
     FAIL;
@@ -9686,7 +9686,7 @@
     emit_insn (gen_atomic_storedi_1 (operands[0], operands[1]));
   else
     emit_move_insn (operands[0], operands[1]);
-  if (model == MEMMODEL_SEQ_CST)
+  if (is_mm_seq_cst (model))
     emit_insn (gen_mem_thread_fence (operands[2]));
   DONE;
 })
Index: gcc/config/sparc/sparc.c
===================================================================
--- gcc/config/sparc/sparc.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/sparc/sparc.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -11678,9 +11678,8 @@
 
   if (before_after & 1)
     {
-      if (model == MEMMODEL_RELEASE
-	  || model == MEMMODEL_ACQ_REL
-	  || model == MEMMODEL_SEQ_CST)
+      if (is_mm_release (model) || is_mm_acq_rel (model)
+	  || is_mm_seq_cst (model))
 	{
 	  if (load_store & 1)
 	    mm |= LoadLoad | StoreLoad;
@@ -11690,9 +11689,8 @@
     }
   if (before_after & 2)
     {
-      if (model == MEMMODEL_ACQUIRE
-	  || model == MEMMODEL_ACQ_REL
-	  || model == MEMMODEL_SEQ_CST)
+      if (is_mm_acquire (model) || is_mm_acq_rel (model)
+	  || is_mm_seq_cst (model))
 	{
 	  if (load_store & 1)
 	    mm |= LoadLoad | LoadStore;
Index: gcc/config/i386/i386.md
===================================================================
--- gcc/config/i386/i386.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/i386/i386.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -102,7 +102,6 @@
   UNSPEC_SAHF
   UNSPEC_PARITY
   UNSPEC_FSTCW
-  UNSPEC_ADD_CARRY
   UNSPEC_FLDCW
   UNSPEC_REP
   UNSPEC_LD_MPIC	; load_macho_picbase
@@ -783,7 +782,8 @@
 (define_attr "isa" "base,x64,x64_sse4,x64_sse4_noavx,x64_avx,nox64,
 		    sse2,sse2_noavx,sse3,sse4,sse4_noavx,avx,noavx,
 		    avx2,noavx2,bmi,bmi2,fma4,fma,avx512f,noavx512f,
-		    fma_avx512f,avx512bw,noavx512bw,avx512dq,noavx512dq"
+		    fma_avx512f,avx512bw,noavx512bw,avx512dq,noavx512dq,
+		    avx512vl,noavx512vl"
   (const_string "base"))
 
 (define_attr "enabled" ""
@@ -818,6 +818,8 @@
 	 (eq_attr "isa" "noavx512bw") (symbol_ref "!TARGET_AVX512BW")
 	 (eq_attr "isa" "avx512dq") (symbol_ref "TARGET_AVX512DQ")
 	 (eq_attr "isa" "noavx512dq") (symbol_ref "!TARGET_AVX512DQ")
+	 (eq_attr "isa" "avx512vl") (symbol_ref "TARGET_AVX512VL")
+	 (eq_attr "isa" "noavx512vl") (symbol_ref "!TARGET_AVX512VL")
 	]
 	(const_int 1)))
 
@@ -844,8 +846,6 @@
 (define_code_attr plusminus_mnemonic
   [(plus "add") (ss_plus "adds") (us_plus "addus")
    (minus "sub") (ss_minus "subs") (us_minus "subus")])
-(define_code_attr plusminus_carry_mnemonic
-  [(plus "adc") (minus "sbb")])
 (define_code_attr multdiv_mnemonic
   [(mult "mul") (div "div")])
 
@@ -5051,11 +5051,11 @@
   /* The DImode arrived in a pair of integral registers (e.g. %edx:%eax).
      Assemble the 64-bit DImode value in an xmm register.  */
   emit_insn (gen_sse2_loadld (operands[3], CONST0_RTX (V4SImode),
-			      gen_rtx_SUBREG (SImode, operands[1], 0)));
+			      gen_lowpart (SImode, operands[1])));
   emit_insn (gen_sse2_loadld (operands[4], CONST0_RTX (V4SImode),
-			      gen_rtx_SUBREG (SImode, operands[1], 4)));
+			      gen_highpart (SImode, operands[1])));
   emit_insn (gen_vec_interleave_lowv4si (operands[3], operands[3],
-  	    				 operands[4]));
+					 operands[4]));
 
   operands[3] = gen_rtx_REG (DImode, REGNO (operands[3]));
 })
@@ -5213,46 +5213,21 @@
   "ix86_binary_operator_ok (PLUS, <DWI>mode, operands)"
   "#"
   "reload_completed"
-  [(parallel [(set (reg:CC FLAGS_REG)
-		   (unspec:CC [(match_dup 1) (match_dup 2)]
-			      UNSPEC_ADD_CARRY))
+  [(parallel [(set (reg:CCC FLAGS_REG)
+		   (compare:CCC
+		     (plus:DWIH (match_dup 1) (match_dup 2))
+		     (match_dup 1)))
 	      (set (match_dup 0)
 		   (plus:DWIH (match_dup 1) (match_dup 2)))])
    (parallel [(set (match_dup 3)
 		   (plus:DWIH
-		     (match_dup 4)
 		     (plus:DWIH
 		       (ltu:DWIH (reg:CC FLAGS_REG) (const_int 0))
-		       (match_dup 5))))
+		       (match_dup 4))
+		     (match_dup 5)))
 	      (clobber (reg:CC FLAGS_REG))])]
   "split_double_mode (<DWI>mode, &operands[0], 3, &operands[0], &operands[3]);")
 
-(define_insn "*add<mode>3_cc"
-  [(set (reg:CC FLAGS_REG)
-	(unspec:CC
-	  [(match_operand:SWI48 1 "nonimmediate_operand" "%0,0")
-	   (match_operand:SWI48 2 "<general_operand>" "r<i>,rm")]
-	  UNSPEC_ADD_CARRY))
-   (set (match_operand:SWI48 0 "nonimmediate_operand" "=rm,r")
-	(plus:SWI48 (match_dup 1) (match_dup 2)))]
-  "ix86_binary_operator_ok (PLUS, <MODE>mode, operands)"
-  "add{<imodesuffix>}\t{%2, %0|%0, %2}"
-  [(set_attr "type" "alu")
-   (set_attr "mode" "<MODE>")])
-
-(define_insn "addqi3_cc"
-  [(set (reg:CC FLAGS_REG)
-	(unspec:CC
-	  [(match_operand:QI 1 "nonimmediate_operand" "%0,0")
-	   (match_operand:QI 2 "general_operand" "qn,qm")]
-	  UNSPEC_ADD_CARRY))
-   (set (match_operand:QI 0 "nonimmediate_operand" "=qm,q")
-	(plus:QI (match_dup 1) (match_dup 2)))]
-  "ix86_binary_operator_ok (PLUS, QImode, operands)"
-  "add{b}\t{%2, %0|%0, %2}"
-  [(set_attr "type" "alu")
-   (set_attr "mode" "QI")])
-
 (define_insn "*add<mode>_1"
   [(set (match_operand:SWI48 0 "nonimmediate_operand" "=r,rm,r,r")
 	(plus:SWI48
@@ -6160,10 +6135,10 @@
 		   (minus:DWIH (match_dup 1) (match_dup 2)))])
    (parallel [(set (match_dup 3)
 		   (minus:DWIH
-		     (match_dup 4)
-		     (plus:DWIH
-		       (ltu:DWIH (reg:CC FLAGS_REG) (const_int 0))
-		       (match_dup 5))))
+		     (minus:DWIH
+		       (match_dup 4)
+		       (ltu:DWIH (reg:CC FLAGS_REG) (const_int 0)))
+		     (match_dup 5)))
 	      (clobber (reg:CC FLAGS_REG))])]
   "split_double_mode (<DWI>mode, &operands[0], 3, &operands[0], &operands[3]);")
 
@@ -6327,29 +6302,17 @@
 
 ;; Add with carry and subtract with borrow
 
-(define_expand "<plusminus_insn><mode>3_carry"
-  [(parallel
-    [(set (match_operand:SWI 0 "nonimmediate_operand")
-	  (plusminus:SWI
-	    (match_operand:SWI 1 "nonimmediate_operand")
-	    (plus:SWI (match_operator:SWI 4 "ix86_carry_flag_operator"
-		       [(match_operand 3 "flags_reg_operand")
-			(const_int 0)])
-		      (match_operand:SWI 2 "<general_operand>"))))
-     (clobber (reg:CC FLAGS_REG))])]
-  "ix86_binary_operator_ok (<CODE>, <MODE>mode, operands)")
-
-(define_insn "*<plusminus_insn><mode>3_carry"
+(define_insn "add<mode>3_carry"
   [(set (match_operand:SWI 0 "nonimmediate_operand" "=<r>m,<r>")
-	(plusminus:SWI
-	  (match_operand:SWI 1 "nonimmediate_operand" "<comm>0,0")
+	(plus:SWI
 	  (plus:SWI
-	    (match_operator 3 "ix86_carry_flag_operator"
-	     [(reg FLAGS_REG) (const_int 0)])
-	    (match_operand:SWI 2 "<general_operand>" "<r><i>,<r>m"))))
+	    (match_operator:SWI 4 "ix86_carry_flag_operator"
+	     [(match_operand 3 "flags_reg_operand") (const_int 0)])
+	    (match_operand:SWI 1 "nonimmediate_operand" "%0,0"))
+	  (match_operand:SWI 2 "<general_operand>" "<r><i>,<r>m")))
    (clobber (reg:CC FLAGS_REG))]
   "ix86_binary_operator_ok (PLUS, <MODE>mode, operands)"
-  "<plusminus_carry_mnemonic>{<imodesuffix>}\t{%2, %0|%0, %2}"
+  "adc{<imodesuffix>}\t{%2, %0|%0, %2}"
   [(set_attr "type" "alu")
    (set_attr "use_carry" "1")
    (set_attr "pent_pair" "pu")
@@ -6358,10 +6321,11 @@
 (define_insn "*addsi3_carry_zext"
   [(set (match_operand:DI 0 "register_operand" "=r")
 	(zero_extend:DI
-	  (plus:SI (match_operand:SI 1 "nonimmediate_operand" "%0")
-		   (plus:SI (match_operator 3 "ix86_carry_flag_operator"
-			     [(reg FLAGS_REG) (const_int 0)])
-			    (match_operand:SI 2 "x86_64_general_operand" "rme")))))
+	  (plus:SI
+	    (plus:SI (match_operator:SI 3 "ix86_carry_flag_operator"
+		      [(reg FLAGS_REG) (const_int 0)])
+		     (match_operand:SI 1 "register_operand" "%0"))
+	    (match_operand:SI 2 "x86_64_general_operand" "rme"))))
    (clobber (reg:CC FLAGS_REG))]
   "TARGET_64BIT && ix86_binary_operator_ok (PLUS, SImode, operands)"
   "adc{l}\t{%2, %k0|%k0, %2}"
@@ -6370,45 +6334,96 @@
    (set_attr "pent_pair" "pu")
    (set_attr "mode" "SI")])
 
+;; There is no point to generate ADCX instruction. ADC is shorter and faster.
+
+(define_insn "addcarry<mode>"
+  [(set (reg:CCC FLAGS_REG)
+	(compare:CCC
+	  (plus:SWI48
+	    (plus:SWI48
+	      (match_operator:SWI48 4 "ix86_carry_flag_operator"
+	       [(match_operand 3 "flags_reg_operand") (const_int 0)])
+	      (match_operand:SWI48 1 "nonimmediate_operand" "%0"))
+	    (match_operand:SWI48 2 "nonimmediate_operand" "rm"))
+	  (match_dup 1)))
+   (set (match_operand:SWI48 0 "register_operand" "=r")
+	(plus:SWI48 (plus:SWI48 (match_op_dup 4
+				 [(match_dup 3) (const_int 0)])
+				(match_dup 1))
+		    (match_dup 2)))]
+  "ix86_binary_operator_ok (PLUS, <MODE>mode, operands)"
+  "adc{<imodesuffix>}\t{%2, %0|%0, %2}"
+  [(set_attr "type" "alu")
+   (set_attr "use_carry" "1")
+   (set_attr "pent_pair" "pu")
+   (set_attr "mode" "<MODE>")])
+
+(define_insn "sub<mode>3_carry"
+  [(set (match_operand:SWI 0 "nonimmediate_operand" "=<r>m,<r>")
+	(minus:SWI
+	  (minus:SWI
+	    (match_operand:SWI 1 "nonimmediate_operand" "0,0")
+	    (match_operator:SWI 4 "ix86_carry_flag_operator"
+	     [(match_operand 3 "flags_reg_operand") (const_int 0)]))
+	  (match_operand:SWI 2 "<general_operand>" "<r><i>,<r>m")))
+   (clobber (reg:CC FLAGS_REG))]
+  "ix86_binary_operator_ok (MINUS, <MODE>mode, operands)"
+  "sbb{<imodesuffix>}\t{%2, %0|%0, %2}"
+  [(set_attr "type" "alu")
+   (set_attr "use_carry" "1")
+   (set_attr "pent_pair" "pu")
+   (set_attr "mode" "<MODE>")])
+
 (define_insn "*subsi3_carry_zext"
   [(set (match_operand:DI 0 "register_operand" "=r")
 	(zero_extend:DI
-	  (minus:SI (match_operand:SI 1 "register_operand" "0")
-		    (plus:SI (match_operator 3 "ix86_carry_flag_operator"
-			      [(reg FLAGS_REG) (const_int 0)])
-			     (match_operand:SI 2 "x86_64_general_operand" "rme")))))
+	  (minus:SI
+	    (minus:SI
+	      (match_operand:SI 1 "register_operand" "0")
+	      (match_operator:SI 3 "ix86_carry_flag_operator"
+	       [(reg FLAGS_REG) (const_int 0)]))
+	    (match_operand:SI 2 "x86_64_general_operand" "rme"))))
    (clobber (reg:CC FLAGS_REG))]
   "TARGET_64BIT && ix86_binary_operator_ok (MINUS, SImode, operands)"
   "sbb{l}\t{%2, %k0|%k0, %2}"
   [(set_attr "type" "alu")
+   (set_attr "use_carry" "1")
    (set_attr "pent_pair" "pu")
    (set_attr "mode" "SI")])
-
-;; ADCX instruction
 
-(define_insn "adcx<mode>3"
+(define_insn "subborrow<mode>"
   [(set (reg:CCC FLAGS_REG)
 	(compare:CCC
+	  (match_operand:SWI48 1 "nonimmediate_operand" "0")
 	  (plus:SWI48
-	    (match_operand:SWI48 1 "nonimmediate_operand" "%0")
-	    (plus:SWI48
-	      (match_operator 4 "ix86_carry_flag_operator"
-	       [(match_operand 3 "flags_reg_operand") (const_int 0)])
-	      (match_operand:SWI48 2 "nonimmediate_operand" "rm")))
-	  (const_int 0)))
+	    (match_operator:SWI48 4 "ix86_carry_flag_operator"
+	     [(match_operand 3 "flags_reg_operand") (const_int 0)])
+	    (match_operand:SWI48 2 "nonimmediate_operand" "rm"))))
    (set (match_operand:SWI48 0 "register_operand" "=r")
-	(plus:SWI48 (match_dup 1)
-		    (plus:SWI48 (match_op_dup 4
-				 [(match_dup 3) (const_int 0)])
-				(match_dup 2))))]
-  "TARGET_ADX && ix86_binary_operator_ok (PLUS, <MODE>mode, operands)"
-  "adcx\t{%2, %0|%0, %2}"
+	(minus:SWI48 (minus:SWI48 (match_dup 1)
+				  (match_op_dup 4
+				   [(match_dup 3) (const_int 0)]))
+		     (match_dup 2)))]
+  "ix86_binary_operator_ok (MINUS, <MODE>mode, operands)"
+  "sbb{<imodesuffix>}\t{%2, %0|%0, %2}"
   [(set_attr "type" "alu")
    (set_attr "use_carry" "1")
+   (set_attr "pent_pair" "pu")
    (set_attr "mode" "<MODE>")])
 
 ;; Overflow setting add instructions
 
+(define_expand "addqi3_cconly_overflow"
+  [(parallel
+     [(set (reg:CCC FLAGS_REG)
+	   (compare:CCC
+	     (plus:QI
+	       (match_operand:QI 0 "nonimmediate_operand")
+	       (match_operand:QI 1 "general_operand"))
+	     (match_dup 0)))
+      (clobber (match_scratch:QI 2))])]
+  "!(MEM_P (operands[0]) && MEM_P (operands[1]))")
+
 (define_insn "*add<mode>3_cconly_overflow"
   [(set (reg:CCC FLAGS_REG)
 	(compare:CCC
@@ -8754,9 +8769,9 @@
      (set (match_dup 0) (neg:DWIH (match_dup 1)))])
    (parallel
     [(set (match_dup 2)
-	  (plus:DWIH (match_dup 3)
-		     (plus:DWIH (ltu:DWIH (reg:CC FLAGS_REG) (const_int 0))
-				(const_int 0))))
+	  (plus:DWIH (plus:DWIH (ltu:DWIH (reg:CC FLAGS_REG) (const_int 0))
+				(match_dup 3))
+		     (const_int 0)))
      (clobber (reg:CC FLAGS_REG))])
    (parallel
     [(set (match_dup 2)
@@ -13237,7 +13252,8 @@
 	(call:P
 	 (mem:QI (match_operand 2 "constant_call_address_operand" "Bz"))
 	 (match_operand 3)))
-   (unspec:P [(match_operand 1 "tls_symbolic_operand")]
+   (unspec:P [(match_operand 1 "tls_symbolic_operand")
+	      (reg:P SP_REG)]
 	     UNSPEC_TLS_GD)]
   "TARGET_64BIT"
 {
@@ -13261,8 +13277,9 @@
 	 (mem:QI (plus:DI (match_operand:DI 2 "register_operand" "b")
 			  (match_operand:DI 3 "immediate_operand" "i")))
 	 (match_operand 4)))
-   (unspec:DI [(match_operand 1 "tls_symbolic_operand")]
-	     UNSPEC_TLS_GD)]
+   (unspec:DI [(match_operand 1 "tls_symbolic_operand")
+	       (reg:DI SP_REG)]
+	      UNSPEC_TLS_GD)]
   "TARGET_64BIT && ix86_cmodel == CM_LARGE_PIC && !TARGET_PECOFF
    && GET_CODE (operands[3]) == CONST
    && GET_CODE (XEXP (operands[3], 0)) == UNSPEC
@@ -13283,7 +13300,8 @@
 	  (call:P
 	   (mem:QI (match_operand 2))
 	   (const_int 0)))
-     (unspec:P [(match_operand 1 "tls_symbolic_operand")]
+     (unspec:P [(match_operand 1 "tls_symbolic_operand")
+		(reg:P SP_REG)]
 	       UNSPEC_TLS_GD)])]
   "TARGET_64BIT"
   "ix86_tls_descriptor_calls_expanded_in_cfun = true;")
@@ -13333,7 +13351,7 @@
 	(call:P
 	 (mem:QI (match_operand 1 "constant_call_address_operand" "Bz"))
 	 (match_operand 2)))
-   (unspec:P [(const_int 0)] UNSPEC_TLS_LD_BASE)]
+   (unspec:P [(reg:P SP_REG)] UNSPEC_TLS_LD_BASE)]
   "TARGET_64BIT"
 {
   output_asm_insn
@@ -13351,7 +13369,7 @@
 	 (mem:QI (plus:DI (match_operand:DI 1 "register_operand" "b")
 			  (match_operand:DI 2 "immediate_operand" "i")))
 	 (match_operand 3)))
-   (unspec:DI [(const_int 0)] UNSPEC_TLS_LD_BASE)]
+   (unspec:DI [(reg:DI SP_REG)] UNSPEC_TLS_LD_BASE)]
   "TARGET_64BIT && ix86_cmodel == CM_LARGE_PIC && !TARGET_PECOFF
    && GET_CODE (operands[2]) == CONST
    && GET_CODE (XEXP (operands[2], 0)) == UNSPEC
@@ -13372,7 +13390,7 @@
 	   (call:P
 	    (mem:QI (match_operand 1))
 	    (const_int 0)))
-      (unspec:P [(const_int 0)] UNSPEC_TLS_LD_BASE)])]
+      (unspec:P [(reg:P SP_REG)] UNSPEC_TLS_LD_BASE)])]
   "TARGET_64BIT"
   "ix86_tls_descriptor_calls_expanded_in_cfun = true;")
 
@@ -17431,8 +17449,8 @@
 ;; lifetime information then.
 
 (define_peephole2
-  [(set (match_operand:SWI124 0 "nonimmediate_operand")
-	(not:SWI124 (match_operand:SWI124 1 "nonimmediate_operand")))]
+  [(set (match_operand:SWI124 0 "nonimmediate_gr_operand")
+	(not:SWI124 (match_operand:SWI124 1 "nonimmediate_gr_operand")))]
   "optimize_insn_for_speed_p ()
    && ((TARGET_NOT_UNPAIRABLE
 	&& (!MEM_P (operands[0])
@@ -17576,8 +17594,10 @@
                      [(match_dup 0)
                       (match_operand 2 "memory_operand")]))]
   "REGNO (operands[0]) != REGNO (operands[1])
-   && ((MMX_REG_P (operands[0]) && MMX_REG_P (operands[1])) 
-       || (SSE_REG_P (operands[0]) && SSE_REG_P (operands[1])))"
+   && ((MMX_REGNO_P (REGNO (operands[0]))
+        && MMX_REGNO_P (REGNO (operands[1]))) 
+       || (SSE_REGNO_P (REGNO (operands[0]))
+           && SSE_REGNO_P (REGNO (operands[1]))))"
   [(set (match_dup 0) (match_dup 2))
    (set (match_dup 0)
         (match_op_dup 3 [(match_dup 0) (match_dup 1)]))])
@@ -17725,7 +17745,7 @@
 	(match_operand 1 "const0_operand"))]
   "GET_MODE_SIZE (GET_MODE (operands[0])) <= UNITS_PER_WORD
    && (! TARGET_USE_MOV0 || optimize_insn_for_size_p ())
-   && GENERAL_REG_P (operands[0])
+   && GENERAL_REGNO_P (REGNO (operands[0]))
    && peep2_regno_dead_p (0, FLAGS_REG)"
   [(parallel [(set (match_dup 0) (const_int 0))
 	      (clobber (reg:CC FLAGS_REG))])]
@@ -17746,6 +17766,7 @@
   [(set (match_operand:SWI248 0 "register_operand")
 	(const_int -1))]
   "(optimize_insn_for_size_p () || TARGET_MOVE_M1_VIA_OR)
+   && GENERAL_REGNO_P (REGNO (operands[0]))
    && peep2_regno_dead_p (0, FLAGS_REG)"
   [(parallel [(set (match_dup 0) (const_int -1))
 	      (clobber (reg:CC FLAGS_REG))])]
@@ -18113,11 +18134,13 @@
 
   operands[1] = gen_rtx_PLUS (word_mode, base,
 			      gen_rtx_MULT (word_mode, index, GEN_INT (scale)));
-  operands[5] = base;
   if (mode != word_mode)
     operands[1] = gen_rtx_SUBREG (mode, operands[1], 0);
+
+  operands[5] = base;
   if (op1mode != word_mode)
-    operands[5] = gen_rtx_SUBREG (op1mode, operands[5], 0);
+    operands[5] = gen_lowpart (op1mode, operands[5]);
+
   operands[0] = dest;
 })
 
Index: gcc/config/i386/predicates.md
===================================================================
--- gcc/config/i386/predicates.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/i386/predicates.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -37,6 +37,12 @@
   (and (match_code "reg")
        (match_test "GENERAL_REG_P (op)")))
 
+;; True if the operand is a nonimmediate operand with GENERAL class register.
+(define_predicate "nonimmediate_gr_operand"
+  (if_then_else (match_code "reg")
+    (match_test "GENERAL_REGNO_P (REGNO (op))")
+    (match_operand 0 "nonimmediate_operand")))
+
 ;; Return true if OP is a register operand other than an i387 fp register.
 (define_predicate "register_and_not_fp_reg_operand"
   (and (match_code "reg")
Index: gcc/config/i386/sse.md
===================================================================
--- gcc/config/i386/sse.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/i386/sse.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1078,9 +1078,9 @@
       /* The DImode arrived in a pair of integral registers (e.g. %edx:%eax).
 	 Assemble the 64-bit DImode value in an xmm register.  */
       emit_insn (gen_sse2_loadld (operands[0], CONST0_RTX (V4SImode),
-				  gen_rtx_SUBREG (SImode, operands[1], 0)));
+				  gen_lowpart (SImode, operands[1])));
       emit_insn (gen_sse2_loadld (operands[2], CONST0_RTX (V4SImode),
-				  gen_rtx_SUBREG (SImode, operands[1], 4)));
+				  gen_highpart (SImode, operands[1])));
       emit_insn (gen_vec_interleave_lowv4si (operands[0], operands[0],
 					     operands[2]));
    }
@@ -8490,42 +8490,48 @@
    (set_attr "mode" "DF,DF,V1DF,V1DF,V1DF,V2DF,V1DF,V1DF,V1DF")])
 
 (define_insn "vec_dupv2df<mask_name>"
-  [(set (match_operand:V2DF 0 "register_operand"     "=x,v")
+  [(set (match_operand:V2DF 0 "register_operand"     "=x,x,v")
 	(vec_duplicate:V2DF
-	  (match_operand:DF 1 "nonimmediate_operand" " 0,vm")))]
+	  (match_operand:DF 1 "nonimmediate_operand" " 0,xm,vm")))]
   "TARGET_SSE2 && <mask_avx512vl_condition>"
   "@
    unpcklpd\t%0, %0
-   %vmovddup\t{%1, %0<mask_operand2>|%0<mask_operand2>, %1}"
-  [(set_attr "isa" "noavx,sse3")
+   %vmovddup\t{%1, %0<mask_operand2>|%0<mask_operand2>, %1}
+   vmovddup\t{%1, %0<mask_operand2>|%0<mask_operand2>, %1}"
+  [(set_attr "isa" "noavx,sse3,avx512vl")
    (set_attr "type" "sselog1")
-   (set_attr "prefix" "orig,maybe_vex")
-   (set_attr "mode" "V2DF,DF")])
+   (set_attr "prefix" "orig,maybe_vex,evex")
+   (set_attr "mode" "V2DF,DF,DF")])
 
 (define_insn "*vec_concatv2df"
-  [(set (match_operand:V2DF 0 "register_operand"     "=x,v,v,x,x,v,x,x")
+  [(set (match_operand:V2DF 0 "register_operand"     "=x,x,v,x,v,x,x,v,x,x")
 	(vec_concat:V2DF
-	  (match_operand:DF 1 "nonimmediate_operand" " 0,v,m,0,x,m,0,0")
-	  (match_operand:DF 2 "vector_move_operand"  " x,v,1,m,m,C,x,m")))]
+	  (match_operand:DF 1 "nonimmediate_operand" " 0,x,v,m,m,0,x,m,0,0")
+	  (match_operand:DF 2 "vector_move_operand"  " x,x,v,1,1,m,m,C,x,m")))]
   "TARGET_SSE"
   "@
    unpcklpd\t{%2, %0|%0, %2}
    vunpcklpd\t{%2, %1, %0|%0, %1, %2}
+   vunpcklpd\t{%2, %1, %0|%0, %1, %2}
    %vmovddup\t{%1, %0|%0, %1}
+   vmovddup\t{%1, %0|%0, %1}
    movhpd\t{%2, %0|%0, %2}
    vmovhpd\t{%2, %1, %0|%0, %1, %2}
    %vmovsd\t{%1, %0|%0, %1}
    movlhps\t{%2, %0|%0, %2}
    movhps\t{%2, %0|%0, %2}"
-  [(set_attr "isa" "sse2_noavx,avx,sse3,sse2_noavx,avx,sse2,noavx,noavx")
+  [(set_attr "isa" "sse2_noavx,avx,avx512vl,sse3,avx512vl,sse2_noavx,avx,sse2,noavx,noavx")
    (set (attr "type")
      (if_then_else
-       (eq_attr "alternative" "0,1,2")
+       (eq_attr "alternative" "0,1,2,3,4")
        (const_string "sselog")
        (const_string "ssemov")))
-   (set_attr "prefix_data16" "*,*,*,1,*,*,*,*")
-   (set_attr "prefix" "orig,vex,maybe_vex,orig,vex,maybe_vex,orig,orig")
-   (set_attr "mode" "V2DF,V2DF,DF,V1DF,V1DF,DF,V4SF,V2SF")])
+   (set (attr "prefix_data16")
+	(if_then_else (eq_attr "alternative" "5")
+		      (const_string "1")
+		      (const_string "*")))
+   (set_attr "prefix" "orig,vex,evex,maybe_vex,evex,orig,vex,maybe_vex,orig,orig")
+   (set_attr "mode" "V2DF,V2DF,V2DF, DF, DF, V1DF,V1DF,DF,V4SF,V2SF")])
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
Index: gcc/config/i386/sync.md
===================================================================
--- gcc/config/i386/sync.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/i386/sync.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -105,11 +105,11 @@
   [(match_operand:SI 0 "const_int_operand")]		;; model
   ""
 {
-  enum memmodel model = (enum memmodel) (INTVAL (operands[0]) & MEMMODEL_MASK);
+  enum memmodel model = memmodel_from_int (INTVAL (operands[0]));
 
   /* Unless this is a SEQ_CST fence, the i386 memory model is strong
      enough not to require barriers of any kind.  */
-  if (model == MEMMODEL_SEQ_CST)
+  if (is_mm_seq_cst (model))
     {
       rtx (*mfence_insn)(rtx);
       rtx mem;
@@ -217,7 +217,7 @@
 		       UNSPEC_STA))]
   ""
 {
-  enum memmodel model = (enum memmodel) (INTVAL (operands[2]) & MEMMODEL_MASK);
+  enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
 
   if (<MODE>mode == DImode && !TARGET_64BIT)
     {
@@ -233,7 +233,7 @@
       operands[1] = force_reg (<MODE>mode, operands[1]);
 
       /* For seq-cst stores, when we lack MFENCE, use XCHG.  */
-      if (model == MEMMODEL_SEQ_CST && !(TARGET_64BIT || TARGET_SSE2))
+      if (is_mm_seq_cst (model) && !(TARGET_64BIT || TARGET_SSE2))
 	{
 	  emit_insn (gen_atomic_exchange<mode> (gen_reg_rtx (<MODE>mode),
 						operands[0], operands[1],
@@ -246,7 +246,7 @@
 					   operands[2]));
     }
   /* ... followed by an MFENCE, if required.  */
-  if (model == MEMMODEL_SEQ_CST)
+  if (is_mm_seq_cst (model))
     emit_insn (gen_mem_thread_fence (operands[2]));
   DONE;
 })
Index: gcc/config/i386/intelmic-mkoffload.c
===================================================================
--- gcc/config/i386/intelmic-mkoffload.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/i386/intelmic-mkoffload.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -453,17 +453,18 @@
   fork_execute (objcopy_argv[0], CONST_CAST (char **, objcopy_argv), false);
 
   /* Objcopy has created symbols, containing the input file name with
-     special characters replaced with '_'.  We are going to rename these
-     new symbols.  */
+     non-alphanumeric characters replaced by underscores.
+     We are going to rename these new symbols.  */
   size_t symbol_name_len = strlen (target_so_filename);
   char *symbol_name = XALLOCAVEC (char, symbol_name_len + 1);
-  for (size_t i = 0; i <= symbol_name_len; i++)
+  for (size_t i = 0; i < symbol_name_len; i++)
     {
       char c = target_so_filename[i];
-      if ((c == '/') || (c == '.'))
+      if (!ISALNUM (c))
 	c = '_';
       symbol_name[i] = c;
     }
+  symbol_name[symbol_name_len] = '\0';
 
   char *opt_for_objcopy[3];
   opt_for_objcopy[0] = XALLOCAVEC (char, sizeof ("_binary__start=")
Index: gcc/config/i386/i386.c
===================================================================
--- gcc/config/i386/i386.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/i386/i386.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -8211,7 +8211,8 @@
     case SI_REG:
       return TARGET_64BIT && ix86_cfun_abi () != MS_ABI;
 
-    case FIRST_BND_REG:
+    case BND0_REG:
+    case BND1_REG:
       return chkp_function_instrumented_p (current_function_decl);
 
       /* Complex values are returned in %st(0)/%st(1) pair.  */
@@ -25140,7 +25141,8 @@
       dst = change_address (dst, BLKmode, destreg);
       set_mem_align (dst, desired_align * BITS_PER_UNIT);
       epilogue_size_needed = 0;
-      if (need_zero_guard && !min_size)
+      if (need_zero_guard
+	  && min_size < (unsigned HOST_WIDE_INT) size_needed)
 	{
 	  /* It is possible that we copied enough so the main loop will not
 	     execute.  */
@@ -25272,7 +25274,7 @@
 	  max_size -= align_bytes;
 	}
       if (need_zero_guard
-	  && !min_size
+	  && min_size < (unsigned HOST_WIDE_INT) size_needed
 	  && (count < (unsigned HOST_WIDE_INT) size_needed
 	      || (align_bytes == 0
 		  && count < ((unsigned HOST_WIDE_INT) size_needed
@@ -25557,7 +25559,7 @@
 
   /* Avoid branch in fixing the byte.  */
   tmpreg = gen_lowpart (QImode, tmpreg);
-  emit_insn (gen_addqi3_cc (tmpreg, tmpreg, tmpreg));
+  emit_insn (gen_addqi3_cconly_overflow (tmpreg, tmpreg));
   tmp = gen_rtx_REG (CCmode, FLAGS_REG);
   cmp = gen_rtx_LTU (VOIDmode, tmp, const0_rtx);
   emit_insn (ix86_gen_sub3_carry (out, out, GEN_INT (3), tmp, cmp));
@@ -39522,53 +39524,41 @@
       return target;
 
     case IX86_BUILTIN_SBB32:
-      icode = CODE_FOR_subsi3_carry;
+      icode = CODE_FOR_subborrowsi;
       mode0 = SImode;
-      goto addcarryx;
+      goto handlecarry;
 
     case IX86_BUILTIN_SBB64:
-      icode = CODE_FOR_subdi3_carry;
+      icode = CODE_FOR_subborrowdi;
       mode0 = DImode;
-      goto addcarryx;
+      goto handlecarry;
 
     case IX86_BUILTIN_ADDCARRYX32:
-      icode = TARGET_ADX ? CODE_FOR_adcxsi3 : CODE_FOR_addsi3_carry;
+      icode = CODE_FOR_addcarrysi;
       mode0 = SImode;
-      goto addcarryx;
+      goto handlecarry;
 
     case IX86_BUILTIN_ADDCARRYX64:
-      icode = TARGET_ADX ? CODE_FOR_adcxdi3 : CODE_FOR_adddi3_carry;
+      icode = CODE_FOR_addcarrydi;
       mode0 = DImode;
 
-addcarryx:
+    handlecarry:
       arg0 = CALL_EXPR_ARG (exp, 0); /* unsigned char c_in.  */
       arg1 = CALL_EXPR_ARG (exp, 1); /* unsigned int src1.  */
       arg2 = CALL_EXPR_ARG (exp, 2); /* unsigned int src2.  */
       arg3 = CALL_EXPR_ARG (exp, 3); /* unsigned int *sum_out.  */
 
-      op0 = gen_reg_rtx (QImode);
-
-      /* Generate CF from input operand.  */
       op1 = expand_normal (arg0);
       op1 = copy_to_mode_reg (QImode, convert_to_mode (QImode, op1, 1));
-      emit_insn (gen_addqi3_cc (op0, op1, constm1_rtx));
 
-      /* Gen ADCX instruction to compute X+Y+CF.  */
       op2 = expand_normal (arg1);
+      if (!register_operand (op2, mode0))
+	op2 = copy_to_mode_reg (mode0, op2);
+
       op3 = expand_normal (arg2);
-
-      if (!REG_P (op2))
-	op2 = copy_to_mode_reg (mode0, op2);
-      if (!REG_P (op3))
+      if (!register_operand (op3, mode0))
 	op3 = copy_to_mode_reg (mode0, op3);
 
-      op0 = gen_reg_rtx (mode0);
-
-      op4 = gen_rtx_REG (CCCmode, FLAGS_REG);
-      pat = gen_rtx_LTU (VOIDmode, op4, const0_rtx);
-      emit_insn (GEN_FCN (icode) (op0, op2, op3, op4, pat));
-
-      /* Store the result.  */
       op4 = expand_normal (arg3);
       if (!address_operand (op4, VOIDmode))
 	{
@@ -39575,8 +39565,17 @@
 	  op4 = convert_memory_address (Pmode, op4);
 	  op4 = copy_addr_to_reg (op4);
 	}
-      emit_move_insn (gen_rtx_MEM (mode0, op4), op0);
 
+      /* Generate CF from input operand.  */
+      emit_insn (gen_addqi3_cconly_overflow (op1, constm1_rtx));
+
+      /* Generate instruction that consumes CF.  */
+      op0 = gen_reg_rtx (mode0);
+
+      op1 = gen_rtx_REG (CCCmode, FLAGS_REG);
+      pat = gen_rtx_LTU (mode0, op1, const0_rtx);
+      emit_insn (GEN_FCN (icode) (op0, op2, op3, op1, pat));
+
       /* Return current CF value.  */
       if (target == 0)
         target = gen_reg_rtx (QImode);
@@ -39583,6 +39582,10 @@
 
       PUT_MODE (pat, QImode);
       emit_insn (gen_rtx_SET (VOIDmode, target, pat));
+
+      /* Store the result.  */
+      emit_move_insn (gen_rtx_MEM (mode0, op4), op0);
+
       return target;
 
     case IX86_BUILTIN_READ_FLAGS:
@@ -50335,6 +50338,14 @@
   unsigned int size = INTVAL (operands[1]);
   unsigned int pos = INTVAL (operands[2]);
 
+  if (GET_CODE (src) == SUBREG)
+    {
+      /* Reject non-lowpart subregs.  */
+      if (SUBREG_BYTE (src) != 0)
+       return false;
+      src = SUBREG_REG (src);
+    }
+
   if (GET_CODE (dst) == SUBREG)
     {
       pos += SUBREG_BYTE (dst) * BITS_PER_UNIT;
@@ -50341,9 +50352,6 @@
       dst = SUBREG_REG (dst);
     }
 
-  if (GET_CODE (src) == SUBREG)
-    src = SUBREG_REG (src);
-
   switch (GET_MODE (dst))
     {
     case V16QImode:
@@ -50391,6 +50399,10 @@
 	    return false;
 	  }
 
+	/* Reject insertions to misaligned positions.  */
+	if (pos & (size-1))
+	  return false;
+
 	rtx d = dst;
 	if (GET_MODE (dst) != dstmode)
 	  d = gen_reg_rtx (dstmode);
@@ -51516,7 +51528,7 @@
 static unsigned HOST_WIDE_INT
 ix86_memmodel_check (unsigned HOST_WIDE_INT val)
 {
-  unsigned HOST_WIDE_INT model = val & MEMMODEL_MASK;
+  enum memmodel model = memmodel_from_int (val);
   bool strong;
 
   if (val & ~(unsigned HOST_WIDE_INT)(IX86_HLE_ACQUIRE|IX86_HLE_RELEASE
@@ -51527,14 +51539,14 @@
 	       "Unknown architecture specific memory model");
       return MEMMODEL_SEQ_CST;
     }
-  strong = (model == MEMMODEL_ACQ_REL || model == MEMMODEL_SEQ_CST);
-  if (val & IX86_HLE_ACQUIRE && !(model == MEMMODEL_ACQUIRE || strong))
+  strong = (is_mm_acq_rel (model) || is_mm_seq_cst (model));
+  if (val & IX86_HLE_ACQUIRE && !(is_mm_acquire (model) || strong))
     {
       warning (OPT_Winvalid_memory_model,
               "HLE_ACQUIRE not used with ACQUIRE or stronger memory model");
       return MEMMODEL_SEQ_CST | IX86_HLE_ACQUIRE;
     }
-   if (val & IX86_HLE_RELEASE && !(model == MEMMODEL_RELEASE || strong))
+  if (val & IX86_HLE_RELEASE && !(is_mm_release (model) || strong))
     {
       warning (OPT_Winvalid_memory_model,
               "HLE_RELEASE not used with RELEASE or stronger memory model");
Index: gcc/config/sh/sh.c
===================================================================
--- gcc/config/sh/sh.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/sh/sh.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -13886,6 +13886,7 @@
       && !sh_insn_operands_modified_between_p (t_before_negc.insn,
 					       t_before_negc.insn,
 					       t_after_negc.insn)
+      && !modified_between_p (get_t_reg_rtx (), curr_insn, t_after_negc.insn)
       && !sh_unspec_insn_p (t_after_negc.insn)
       && !volatile_insn_p (PATTERN (t_after_negc.insn))
       && !side_effects_p (PATTERN (t_after_negc.insn))
@@ -13992,6 +13993,9 @@
   else
     {
       rtx extension_dst = XEXP (set_rtx, 0);
+      if (GET_MODE (extension_dst) != SImode)
+	extension_dst = simplify_gen_subreg (SImode, extension_dst,
+					     GET_MODE (extension_dst), 0);
       if (modified_between_p (extension_dst, insn, use_at_insn))
 	{
 	  if (dump_file)
@@ -14162,6 +14166,12 @@
   if (!can_create_pseudo_p ())
     return false;
 
+  /* expand_debug_locations may call this to compute rtx costs at
+     very early stage.  In that case, don't make new insns here to
+     avoid codegen differences with -g. */
+  if (currently_expanding_to_rtl)
+    return false;
+
   /* We are going to invoke recog in a re-entrant way and thus
      have to capture its current state and restore it afterwards.  */
   recog_data_d prev_recog_data = recog_data;
Index: gcc/config/sh/sh.md
===================================================================
--- gcc/config/sh/sh.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/sh/sh.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -7851,6 +7851,24 @@
   ""
 {
   prepare_move_operands (operands, DImode);
+  if (TARGET_SH1)
+    {
+      /* When the dest operand is (R0, R1) register pair, split it to
+	 two movsi of which dest is R1 and R0 so as to lower R0-register
+	 pressure on the first movsi.  Apply only for simple source not
+	 to make complex rtl here.  */
+      if (REG_P (operands[0])
+	  && REGNO (operands[0]) == R0_REG
+	  && REG_P (operands[1])
+	  && REGNO (operands[1]) >= FIRST_PSEUDO_REGISTER)
+	{
+	  emit_insn (gen_movsi (gen_rtx_REG (SImode, R1_REG),
+			        gen_rtx_SUBREG (SImode, operands[1], 4)));
+	  emit_insn (gen_movsi (gen_rtx_REG (SImode, R0_REG),
+			        gen_rtx_SUBREG (SImode, operands[1], 0)));
+	  DONE;
+	}
+    }
 })
 
 (define_insn "movdf_media"
@@ -10579,7 +10597,7 @@
   if (TARGET_SHMEDIA)
     {
       rtx tr = gen_rtx_REG (Pmode, TR0_REG);
-      rtx pic = operands[0];
+      rtx pic = operands[1];
       rtx lab = PATTERN (gen_call_site ());
       rtx insn, equiv;
 
Index: gcc/config/avr/avr-dimode.md
===================================================================
--- gcc/config/avr/avr-dimode.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/avr/avr-dimode.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -461,7 +461,8 @@
               (match_operand:SI 2 "general_operand" "")
               ;; Just to mention the iterator 
               (clobber (any_extend:SI (match_dup 1)))])]
-  "avr_have_dimode"
+  "avr_have_dimode
+   && AVR_HAVE_MUL"
   {
     avr_fix_inputs (operands, 1 << 2, regmask (SImode, 22));
     emit_move_insn (gen_rtx_REG (SImode, 22), operands[1]);
@@ -480,7 +481,8 @@
                  (any_extend:DI (reg:SI 22))))
    (clobber (reg:HI REG_X))
    (clobber (reg:HI REG_Z))]
-  "avr_have_dimode"
+  "avr_have_dimode
+   && AVR_HAVE_MUL"
   "%~call __<extend_u>mulsidi3"
   [(set_attr "adjust_len" "call")
    (set_attr "cc" "clobber")])
Index: gcc/config/avr/avr.c
===================================================================
--- gcc/config/avr/avr.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/avr/avr.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -9272,10 +9272,10 @@
         {
           if (TYPE_P (node))
             error ("%qT uses address space %qs beyond flash of %d KiB",
-                   node, avr_addrspace[as].name, avr_n_flash);
+                   node, avr_addrspace[as].name, 64 * avr_n_flash);
           else
             error ("%s %q+D uses address space %qs beyond flash of %d KiB",
-                   reason, node, avr_addrspace[as].name, avr_n_flash);
+                   reason, node, avr_addrspace[as].name, 64 * avr_n_flash);
         }
       else
         {
@@ -9322,7 +9322,7 @@
       if (avr_addrspace[as].segment >= avr_n_flash)
         {
           error ("variable %q+D located in address space %qs beyond flash "
-                 "of %d KiB", node, avr_addrspace[as].name, avr_n_flash);
+                 "of %d KiB", node, avr_addrspace[as].name, 64 * avr_n_flash);
         }
       else if (!AVR_HAVE_LPM && avr_addrspace[as].pointer_size > 2)
 	{
Index: gcc/config/ia64/ia64.c
===================================================================
--- gcc/config/ia64/ia64.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/ia64/ia64.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -2389,10 +2389,12 @@
 	{
 	case MEMMODEL_ACQ_REL:
 	case MEMMODEL_SEQ_CST:
+	case MEMMODEL_SYNC_SEQ_CST:
 	  emit_insn (gen_memory_barrier ());
 	  /* FALLTHRU */
 	case MEMMODEL_RELAXED:
 	case MEMMODEL_ACQUIRE:
+	case MEMMODEL_SYNC_ACQUIRE:
 	case MEMMODEL_CONSUME:
 	  if (mode == SImode)
 	    icode = CODE_FOR_fetchadd_acq_si;
@@ -2400,6 +2402,7 @@
 	    icode = CODE_FOR_fetchadd_acq_di;
 	  break;
 	case MEMMODEL_RELEASE:
+	case MEMMODEL_SYNC_RELEASE:
 	  if (mode == SImode)
 	    icode = CODE_FOR_fetchadd_rel_si;
 	  else
@@ -2426,8 +2429,7 @@
      front half of the full barrier.  The end half is the cmpxchg.rel.
      For relaxed and release memory models, we don't need this.  But we
      also don't bother trying to prevent it either.  */
-  gcc_assert (model == MEMMODEL_RELAXED
-	      || model == MEMMODEL_RELEASE
+  gcc_assert (is_mm_relaxed (model) || is_mm_release (model)
 	      || MEM_VOLATILE_P (mem));
 
   old_reg = gen_reg_rtx (DImode);
@@ -2471,6 +2473,7 @@
     {
     case MEMMODEL_RELAXED:
     case MEMMODEL_ACQUIRE:
+    case MEMMODEL_SYNC_ACQUIRE:
     case MEMMODEL_CONSUME:
       switch (mode)
 	{
@@ -2484,8 +2487,10 @@
       break;
 
     case MEMMODEL_RELEASE:
+    case MEMMODEL_SYNC_RELEASE:
     case MEMMODEL_ACQ_REL:
     case MEMMODEL_SEQ_CST:
+    case MEMMODEL_SYNC_SEQ_CST:
       switch (mode)
 	{
 	case QImode: icode = CODE_FOR_cmpxchg_rel_qi;  break;
Index: gcc/config/ia64/sync.md
===================================================================
--- gcc/config/ia64/sync.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/ia64/sync.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -33,7 +33,7 @@
   [(match_operand:SI 0 "const_int_operand" "")]		;; model
   ""
 {
-  if (INTVAL (operands[0]) == MEMMODEL_SEQ_CST)
+  if (is_mm_seq_cst (memmodel_from_int (INTVAL (operands[0]))))
     emit_insn (gen_memory_barrier ());
   DONE;
 })
@@ -60,11 +60,11 @@
    (match_operand:SI 2 "const_int_operand" "")]			;; model
   ""
 {
-  enum memmodel model = (enum memmodel) INTVAL (operands[2]);
+  enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
 
   /* Unless the memory model is relaxed, we want to emit ld.acq, which
      will happen automatically for volatile memories.  */
-  gcc_assert (model == MEMMODEL_RELAXED || MEM_VOLATILE_P (operands[1]));
+  gcc_assert (is_mm_relaxed (model) || MEM_VOLATILE_P (operands[1]));
   emit_move_insn (operands[0], operands[1]);
   DONE;
 })
@@ -75,17 +75,17 @@
    (match_operand:SI 2 "const_int_operand" "")]			;; model
   ""
 {
-  enum memmodel model = (enum memmodel) INTVAL (operands[2]);
+  enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
 
   /* Unless the memory model is relaxed, we want to emit st.rel, which
      will happen automatically for volatile memories.  */
-  gcc_assert (model == MEMMODEL_RELAXED || MEM_VOLATILE_P (operands[0]));
+  gcc_assert (is_mm_relaxed (model) || MEM_VOLATILE_P (operands[0]));
   emit_move_insn (operands[0], operands[1]);
 
   /* Sequentially consistent stores need a subsequent MF.  See
      http://www.decadent.org.uk/pipermail/cpp-threads/2008-December/001952.html
      for a discussion of why a MF is needed here, but not for atomic_load.  */
-  if (model == MEMMODEL_SEQ_CST)
+  if (is_mm_seq_cst (model))
     emit_insn (gen_memory_barrier ());
   DONE;
 })
@@ -101,7 +101,8 @@
    (match_operand:SI 7 "const_int_operand" "")]			;; fail model
   ""
 {
-  enum memmodel model = (enum memmodel) INTVAL (operands[6]);
+  /* No need to distinquish __sync from __atomic, so get base value.  */
+  enum memmodel model = memmodel_base (INTVAL (operands[6]));
   rtx ccv = gen_rtx_REG (DImode, AR_CCV_REGNUM);
   rtx dval, eval;
 
@@ -200,7 +201,8 @@
    (match_operand:SI 3 "const_int_operand" "")]			;; succ model
   ""
 {
-  enum memmodel model = (enum memmodel) INTVAL (operands[3]);
+  /* No need to distinquish __sync from __atomic, so get base value.  */
+  enum memmodel model = memmodel_base (INTVAL (operands[3]));
 
   switch (model)
     {
Index: gcc/config/aarch64/atomics.md
===================================================================
--- gcc/config/aarch64/atomics.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/aarch64/atomics.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -260,10 +260,8 @@
       UNSPECV_LDA))]
   ""
   {
-    enum memmodel model = (enum memmodel) INTVAL (operands[2]);
-    if (model == MEMMODEL_RELAXED
-	|| model == MEMMODEL_CONSUME
-	|| model == MEMMODEL_RELEASE)
+    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
+    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_release (model))
       return "ldr<atomic_sfx>\t%<w>0, %1";
     else
       return "ldar<atomic_sfx>\t%<w>0, %1";
@@ -278,10 +276,8 @@
       UNSPECV_STL))]
   ""
   {
-    enum memmodel model = (enum memmodel) INTVAL (operands[2]);
-    if (model == MEMMODEL_RELAXED
-	|| model == MEMMODEL_CONSUME
-	|| model == MEMMODEL_ACQUIRE)
+    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
+    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_acquire (model))
       return "str<atomic_sfx>\t%<w>1, %0";
     else
       return "stlr<atomic_sfx>\t%<w>1, %0";
@@ -297,10 +293,8 @@
 	UNSPECV_LX)))]
   ""
   {
-    enum memmodel model = (enum memmodel) INTVAL (operands[2]);
-    if (model == MEMMODEL_RELAXED
-	|| model == MEMMODEL_CONSUME
-	|| model == MEMMODEL_RELEASE)
+    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
+    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_release (model))
       return "ldxr<atomic_sfx>\t%w0, %1";
     else
       return "ldaxr<atomic_sfx>\t%w0, %1";
@@ -315,10 +309,8 @@
       UNSPECV_LX))]
   ""
   {
-    enum memmodel model = (enum memmodel) INTVAL (operands[2]);
-    if (model == MEMMODEL_RELAXED
-	|| model == MEMMODEL_CONSUME
-	|| model == MEMMODEL_RELEASE)
+    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
+    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_release (model))
       return "ldxr\t%<w>0, %1";
     else
       return "ldaxr\t%<w>0, %1";
@@ -335,10 +327,8 @@
       UNSPECV_SX))]
   ""
   {
-    enum memmodel model = (enum memmodel) INTVAL (operands[3]);
-    if (model == MEMMODEL_RELAXED
-	|| model == MEMMODEL_CONSUME
-	|| model == MEMMODEL_ACQUIRE)
+    enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
+    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_acquire (model))
       return "stxr<atomic_sfx>\t%w0, %<w>2, %1";
     else
       return "stlxr<atomic_sfx>\t%w0, %<w>2, %1";
@@ -349,8 +339,8 @@
   [(match_operand:SI 0 "const_int_operand" "")]
   ""
   {
-    enum memmodel model = (enum memmodel) INTVAL (operands[0]);
-    if (model != MEMMODEL_RELAXED && model != MEMMODEL_CONSUME)
+    enum memmodel model = memmodel_from_int (INTVAL (operands[0]));
+    if (!(is_mm_relaxed (model) || is_mm_consume (model)))
       emit_insn (gen_dmb (operands[0]));
     DONE;
   }
@@ -373,8 +363,8 @@
      UNSPEC_MB))]
   ""
   {
-    enum memmodel model = (enum memmodel) INTVAL (operands[1]);
-    if (model == MEMMODEL_ACQUIRE)
+    enum memmodel model = memmodel_from_int (INTVAL (operands[1]));
+    if (is_mm_acquire (model))
       return "dmb\\tishld";
     else
       return "dmb\\tish";
Index: gcc/config/aarch64/aarch64.md
===================================================================
--- gcc/config/aarch64/aarch64.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/aarch64/aarch64.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -3971,6 +3971,16 @@
         (mult:GPF
 		 (neg:GPF (match_operand:GPF 1 "register_operand" "w"))
 		 (match_operand:GPF 2 "register_operand" "w")))]
+  "TARGET_FLOAT && !flag_rounding_math"
+  "fnmul\\t%<s>0, %<s>1, %<s>2"
+  [(set_attr "type" "fmul<s>")]
+)
+
+(define_insn "*fnmul<mode>3"
+  [(set (match_operand:GPF 0 "register_operand" "=w")
+        (neg:GPF (mult:GPF
+		 (match_operand:GPF 1 "register_operand" "w")
+		 (match_operand:GPF 2 "register_operand" "w"))))]
   "TARGET_FLOAT"
   "fnmul\\t%<s>0, %<s>1, %<s>2"
   [(set_attr "type" "fmul<s>")]
Index: gcc/config/aarch64/aarch64-elf-raw.h
===================================================================
--- gcc/config/aarch64/aarch64-elf-raw.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/aarch64/aarch64-elf-raw.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -44,7 +44,12 @@
 #endif
 
 #ifndef LINK_SPEC
-#define LINK_SPEC "%{mbig-endian:-EB} %{mlittle-endian:-EL} -X \
+#define LINK_SPEC "%{h*}			\
+   %{static:-Bstatic}				\
+   %{shared:-shared}				\
+   %{symbolic:-Bsymbolic}			\
+   %{!static:%{rdynamic:-export-dynamic}}	\
+   %{mbig-endian:-EB} %{mlittle-endian:-EL} -X	\
   -maarch64elf%{mabi=ilp32*:32}%{mbig-endian:b}" \
   CA53_ERR_835769_SPEC \
   CA53_ERR_843419_SPEC
Index: gcc/config/aarch64/aarch64.c
===================================================================
--- gcc/config/aarch64/aarch64.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/aarch64/aarch64.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -5246,11 +5246,17 @@
       if (speed)
 	{
 	  /* Floating-point FMA/FMUL can also support negations of the
-	     operands.  */
-	  if (GET_CODE (op0) == NEG)
-	    op0 = XEXP (op0, 0);
-	  if (GET_CODE (op1) == NEG)
-	    op1 = XEXP (op1, 0);
+	     operands, unless the rounding mode is upward or downward in
+	     which case FNMUL is different than FMUL with operand negation.  */
+	  bool neg0 = GET_CODE (op0) == NEG;
+	  bool neg1 = GET_CODE (op1) == NEG;
+	  if (maybe_fma || !flag_rounding_math || (neg0 && neg1))
+	    {
+	      if (neg0)
+		op0 = XEXP (op0, 0);
+	      if (neg1)
+		op1 = XEXP (op1, 0);
+	    }
 
 	  if (maybe_fma)
 	    /* FMADD/FNMADD/FNMSUB/FMSUB.  */
@@ -5694,6 +5700,12 @@
               *cost = rtx_cost (op0, NEG, 0, speed);
               return true;
             }
+	  if (GET_CODE (op0) == MULT)
+	    {
+	      /* FNMUL.  */
+	      *cost = rtx_cost (op0, NEG, 0, speed);
+	      return true;
+	    }
 	  if (speed)
 	    /* FNEG.  */
 	    *cost += extra_cost->fp[mode == DFmode].neg;
@@ -9020,8 +9032,8 @@
      unlikely event of fail being ACQUIRE and succ being RELEASE we need to
      promote succ to ACQ_REL so that we don't lose the acquire semantics.  */
 
-  if (INTVAL (mod_f) == MEMMODEL_ACQUIRE
-      && INTVAL (mod_s) == MEMMODEL_RELEASE)
+  if (is_mm_acquire (memmodel_from_int (INTVAL (mod_f)))
+      && is_mm_release (memmodel_from_int (INTVAL (mod_s))))
     mod_s = GEN_INT (MEMMODEL_ACQ_REL);
 
   switch (mode)
@@ -9066,6 +9078,23 @@
   emit_insn (gen_rtx_SET (VOIDmode, bval, x));
 }
 
+/* Emit a barrier, that is appropriate for memory model MODEL, at the end of a
+   sequence implementing an atomic operation.  */
+
+static void
+aarch64_emit_post_barrier (enum memmodel model)
+{
+  const enum memmodel base_model = memmodel_base (model);
+
+  if (is_mm_sync (model)
+      && (base_model == MEMMODEL_ACQUIRE
+	  || base_model == MEMMODEL_ACQ_REL
+	  || base_model == MEMMODEL_SEQ_CST))
+    {
+      emit_insn (gen_mem_thread_fence (GEN_INT (MEMMODEL_SEQ_CST)));
+    }
+}
+
 /* Split a compare and swap pattern.  */
 
 void
@@ -9076,6 +9105,8 @@
   bool is_weak;
   rtx_code_label *label1, *label2;
   rtx x, cond;
+  enum memmodel model;
+  rtx model_rtx;
 
   rval = operands[0];
   mem = operands[1];
@@ -9082,8 +9113,10 @@
   oldval = operands[2];
   newval = operands[3];
   is_weak = (operands[4] != const0_rtx);
+  model_rtx = operands[5];
   scratch = operands[7];
   mode = GET_MODE (mem);
+  model = memmodel_from_int (INTVAL (model_rtx));
 
   label1 = NULL;
   if (!is_weak)
@@ -9093,7 +9126,13 @@
     }
   label2 = gen_label_rtx ();
 
-  aarch64_emit_load_exclusive (mode, rval, mem, operands[5]);
+  /* The initial load can be relaxed for a __sync operation since a final
+     barrier will be emitted to stop code hoisting.  */
+  if (is_mm_sync (model))
+    aarch64_emit_load_exclusive (mode, rval, mem,
+				 GEN_INT (MEMMODEL_RELAXED));
+  else
+    aarch64_emit_load_exclusive (mode, rval, mem, model_rtx);
 
   cond = aarch64_gen_compare_reg (NE, rval, oldval);
   x = gen_rtx_NE (VOIDmode, cond, const0_rtx);
@@ -9101,7 +9140,7 @@
 			    gen_rtx_LABEL_REF (Pmode, label2), pc_rtx);
   aarch64_emit_unlikely_jump (gen_rtx_SET (VOIDmode, pc_rtx, x));
 
-  aarch64_emit_store_exclusive (mode, scratch, mem, newval, operands[5]);
+  aarch64_emit_store_exclusive (mode, scratch, mem, newval, model_rtx);
 
   if (!is_weak)
     {
@@ -9118,6 +9157,10 @@
     }
 
   emit_label (label2);
+
+  /* Emit any final barrier needed for a __sync operation.  */
+  if (is_mm_sync (model))
+    aarch64_emit_post_barrier (model);
 }
 
 /* Split an atomic operation.  */
@@ -9128,6 +9171,8 @@
 {
   machine_mode mode = GET_MODE (mem);
   machine_mode wmode = (mode == DImode ? DImode : SImode);
+  const enum memmodel model = memmodel_from_int (INTVAL (model_rtx));
+  const bool is_sync = is_mm_sync (model);
   rtx_code_label *label;
   rtx x;
 
@@ -9142,7 +9187,13 @@
     old_out = new_out;
   value = simplify_gen_subreg (wmode, value, mode, 0);
 
-  aarch64_emit_load_exclusive (mode, old_out, mem, model_rtx);
+  /* The initial load can be relaxed for a __sync operation since a final
+     barrier will be emitted to stop code hoisting.  */
+ if (is_sync)
+    aarch64_emit_load_exclusive (mode, old_out, mem,
+				 GEN_INT (MEMMODEL_RELAXED));
+  else
+    aarch64_emit_load_exclusive (mode, old_out, mem, model_rtx);
 
   switch (code)
     {
@@ -9178,6 +9229,10 @@
   x = gen_rtx_IF_THEN_ELSE (VOIDmode, x,
 			    gen_rtx_LABEL_REF (Pmode, label), pc_rtx);
   aarch64_emit_unlikely_jump (gen_rtx_SET (VOIDmode, pc_rtx, x));
+
+  /* Emit any final barrier needed for a __sync operation.  */
+  if (is_sync)
+    aarch64_emit_post_barrier (model);
 }
 
 static void
Index: gcc/config/aarch64/aarch64-linux.h
===================================================================
--- gcc/config/aarch64/aarch64-linux.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/aarch64/aarch64-linux.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -35,8 +35,9 @@
    %{static:-Bstatic}				\
    %{shared:-shared}				\
    %{symbolic:-Bsymbolic}			\
-   %{rdynamic:-export-dynamic}			\
-   -dynamic-linker " GNU_USER_DYNAMIC_LINKER "	\
+   %{!static:					\
+     %{rdynamic:-export-dynamic}		\
+     %{!shared:-dynamic-linker " GNU_USER_DYNAMIC_LINKER "}} \
    -X						\
    %{mbig-endian:-EB} %{mlittle-endian:-EL}     \
    -maarch64linux%{mabi=ilp32:32}%{mbig-endian:b}"
Index: gcc/config/rs6000/vector.md
===================================================================
--- gcc/config/rs6000/vector.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/rs6000/vector.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -918,6 +918,8 @@
 ;; General shift amounts can be supported using vsro + vsr. We're
 ;; not expecting to see these yet (the vectorizer currently
 ;; generates only shifts by a whole number of vector elements).
+;; Note that the vec_shr operation is actually defined as 
+;; 'shift toward element 0' so is a shr for LE and shl for BE.
 (define_expand "vec_shr_<mode>"
   [(match_operand:VEC_L 0 "vlogical_operand" "")
    (match_operand:VEC_L 1 "vlogical_operand" "")
@@ -928,6 +930,7 @@
   rtx bitshift = operands[2];
   rtx shift;
   rtx insn;
+  rtx zero_reg, op1, op2;
   HOST_WIDE_INT bitshift_val;
   HOST_WIDE_INT byteshift_val;
 
@@ -937,19 +940,29 @@
   if (bitshift_val & 0x7)
     FAIL;
   byteshift_val = (bitshift_val >> 3);
+  zero_reg = gen_reg_rtx (<MODE>mode);
+  emit_move_insn (zero_reg, CONST0_RTX (<MODE>mode));
   if (!BYTES_BIG_ENDIAN)
-    byteshift_val = 16 - byteshift_val;
+    {
+      byteshift_val = 16 - byteshift_val;
+      op1 = zero_reg;
+      op2 = operands[1];
+    }
+  else
+    {
+      op1 = operands[1];
+      op2 = zero_reg;
+    }
+
   if (TARGET_VSX && (byteshift_val & 0x3) == 0)
     {
       shift = gen_rtx_CONST_INT (QImode, byteshift_val >> 2);
-      insn = gen_vsx_xxsldwi_<mode> (operands[0], operands[1], operands[1],
-				     shift);
+      insn = gen_vsx_xxsldwi_<mode> (operands[0], op1, op2, shift);
     }
   else
     {
       shift = gen_rtx_CONST_INT (QImode, byteshift_val);
-      insn = gen_altivec_vsldoi_<mode> (operands[0], operands[1], operands[1],
-					shift);
+      insn = gen_altivec_vsldoi_<mode> (operands[0], op1, op2, shift);
     }
 
   emit_insn (insn);
Index: gcc/config/rs6000/predicates.md
===================================================================
--- gcc/config/rs6000/predicates.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/rs6000/predicates.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1048,12 +1048,12 @@
 (define_predicate "current_file_function_operand"
   (and (match_code "symbol_ref")
        (match_test "(DEFAULT_ABI != ABI_AIX || SYMBOL_REF_FUNCTION_P (op))
-		    && ((SYMBOL_REF_LOCAL_P (op)
-			 && ((DEFAULT_ABI != ABI_AIX
-			      && DEFAULT_ABI != ABI_ELFv2)
-			     || !SYMBOL_REF_EXTERNAL_P (op)))
-		        || (op == XEXP (DECL_RTL (current_function_decl),
-						  0)))")))
+		    && (SYMBOL_REF_LOCAL_P (op)
+			|| op == XEXP (DECL_RTL (current_function_decl), 0))
+		    && !((DEFAULT_ABI == ABI_AIX
+			  || DEFAULT_ABI == ABI_ELFv2)
+			 && (SYMBOL_REF_EXTERNAL_P (op)
+			     || SYMBOL_REF_WEAK (op)))")))
 
 ;; Return 1 if this operand is a valid input for a move insn.
 (define_predicate "input_operand"
Index: gcc/config/rs6000/htm.md
===================================================================
--- gcc/config/rs6000/htm.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/rs6000/htm.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -48,7 +48,7 @@
 
 (define_insn "tabort"
   [(set (match_operand:CC 1 "cc_reg_operand" "=x")
-	(unspec_volatile:CC [(match_operand:SI 0 "gpc_reg_operand" "r")]
+	(unspec_volatile:CC [(match_operand:SI 0 "base_reg_operand" "b")]
 			    UNSPECV_HTM_TABORT))]
   "TARGET_HTM"
   "tabort. %0"
Index: gcc/config/rs6000/rs6000-cpus.def
===================================================================
--- gcc/config/rs6000/rs6000-cpus.def	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/rs6000/rs6000-cpus.def	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -53,6 +53,7 @@
 				 | OPTION_MASK_P8_VECTOR		\
 				 | OPTION_MASK_CRYPTO			\
 				 | OPTION_MASK_DIRECT_MOVE		\
+				 | OPTION_MASK_EFFICIENT_UNALIGNED_VSX	\
 				 | OPTION_MASK_HTM			\
 				 | OPTION_MASK_QUAD_MEMORY		\
   				 | OPTION_MASK_QUAD_MEMORY_ATOMIC	\
@@ -78,6 +79,7 @@
 				 | OPTION_MASK_DFP			\
 				 | OPTION_MASK_DIRECT_MOVE		\
 				 | OPTION_MASK_DLMZB			\
+				 | OPTION_MASK_EFFICIENT_UNALIGNED_VSX	\
 				 | OPTION_MASK_FPRND			\
 				 | OPTION_MASK_HTM			\
 				 | OPTION_MASK_ISEL			\
Index: gcc/config/rs6000/rs6000.opt
===================================================================
--- gcc/config/rs6000/rs6000.opt	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/rs6000/rs6000.opt	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -212,7 +212,7 @@
 ; Allow/disallow the movmisalign in DF/DI vectors
 
 mefficient-unaligned-vector
-Target Undocumented Report Var(TARGET_EFFICIENT_UNALIGNED_VSX) Init(-1) Save
+Target Undocumented Report Mask(EFFICIENT_UNALIGNED_VSX) Var(rs6000_isa_flags)
 ; Consider unaligned VSX accesses to be efficient/inefficient
 
 mallow-df-permute
Index: gcc/config/rs6000/rs6000.c
===================================================================
--- gcc/config/rs6000/rs6000.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/rs6000/rs6000.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -3692,6 +3692,45 @@
       && optimize >= 3)
     rs6000_isa_flags |= OPTION_MASK_P8_FUSION_SIGN;
 
+  /* Set -mallow-movmisalign to explicitly on if we have full ISA 2.07
+     support. If we only have ISA 2.06 support, and the user did not specify
+     the switch, leave it set to -1 so the movmisalign patterns are enabled,
+     but we don't enable the full vectorization support  */
+  if (TARGET_ALLOW_MOVMISALIGN == -1 && TARGET_P8_VECTOR && TARGET_DIRECT_MOVE)
+    TARGET_ALLOW_MOVMISALIGN = 1;
+
+  else if (TARGET_ALLOW_MOVMISALIGN && !TARGET_VSX)
+    {
+      if (TARGET_ALLOW_MOVMISALIGN > 0)
+	error ("-mallow-movmisalign requires -mvsx");
+
+      TARGET_ALLOW_MOVMISALIGN = 0;
+    }
+
+  /* Determine when unaligned vector accesses are permitted, and when
+     they are preferred over masked Altivec loads.  Note that if
+     TARGET_ALLOW_MOVMISALIGN has been disabled by the user, then
+     TARGET_EFFICIENT_UNALIGNED_VSX must be as well.  The converse is
+     not true.  */
+  if (TARGET_EFFICIENT_UNALIGNED_VSX)
+    {
+      if (!TARGET_VSX)
+	{
+	  if (rs6000_isa_flags_explicit & OPTION_MASK_EFFICIENT_UNALIGNED_VSX)
+	    error ("-mefficient-unaligned-vsx requires -mvsx");
+
+	  rs6000_isa_flags &= ~OPTION_MASK_EFFICIENT_UNALIGNED_VSX;
+	}
+
+      else if (!TARGET_ALLOW_MOVMISALIGN)
+	{
+	  if (rs6000_isa_flags_explicit & OPTION_MASK_EFFICIENT_UNALIGNED_VSX)
+	    error ("-mefficient-unaligned-vsx requires -mallow-movmisalign");
+
+	  rs6000_isa_flags &= ~OPTION_MASK_EFFICIENT_UNALIGNED_VSX;
+	}
+    }
+
   if (TARGET_DEBUG_REG || TARGET_DEBUG_TARGET)
     rs6000_print_isa_options (stderr, 0, "after defaults", rs6000_isa_flags);
 
@@ -4251,22 +4290,6 @@
 	}
     }
 
-  /* Determine when unaligned vector accesses are permitted, and when
-     they are preferred over masked Altivec loads.  Note that if
-     TARGET_ALLOW_MOVMISALIGN has been disabled by the user, then
-     TARGET_EFFICIENT_UNALIGNED_VSX must be as well.  The converse is
-     not true.  */
-  if (TARGET_EFFICIENT_UNALIGNED_VSX == -1) {
-    if (TARGET_VSX && rs6000_cpu == PROCESSOR_POWER8
-	&& TARGET_ALLOW_MOVMISALIGN != 0)
-      TARGET_EFFICIENT_UNALIGNED_VSX = 1;
-    else
-      TARGET_EFFICIENT_UNALIGNED_VSX = 0;
-  }
-
-  if (TARGET_ALLOW_MOVMISALIGN == -1 && rs6000_cpu == PROCESSOR_POWER8)
-    TARGET_ALLOW_MOVMISALIGN = 1;
-
   /* Set the builtin mask of the various options used that could affect which
      builtins were used.  In the past we used target_flags, but we've run out
      of bits, and some options like SPE and PAIRED are no longer in
@@ -17678,8 +17701,21 @@
 
   if (GET_CODE (addr) == PRE_MODIFY)
     {
+      gcc_assert (REG_P (XEXP (addr, 0))
+		  && GET_CODE (XEXP (addr, 1)) == PLUS
+		  && XEXP (XEXP (addr, 1), 0) == XEXP (addr, 0));
       scratch_or_premodify = XEXP (addr, 0);
-      gcc_assert (REG_P (scratch_or_premodify));
+      if (!HARD_REGISTER_P (scratch_or_premodify))
+	/* If we have a pseudo here then reload will have arranged
+	   to have it replaced, but only in the original insn.
+	   Use the replacement here too.  */
+	scratch_or_premodify = find_replacement (&XEXP (addr, 0));
+
+      /* RTL emitted by rs6000_secondary_reload_gpr uses RTL
+	 expressions from the original insn, without unsharing them.
+	 Any RTL that points into the original insn will of course
+	 have register replacements applied.  That is why we don't
+	 need to look for replacements under the PLUS.  */
       addr = XEXP (addr, 1);
     }
   gcc_assert (GET_CODE (addr) == PLUS || GET_CODE (addr) == LO_SUM);
@@ -20537,12 +20573,15 @@
     case MEMMODEL_RELAXED:
     case MEMMODEL_CONSUME:
     case MEMMODEL_ACQUIRE:
+    case MEMMODEL_SYNC_ACQUIRE:
       break;
     case MEMMODEL_RELEASE:
+    case MEMMODEL_SYNC_RELEASE:
     case MEMMODEL_ACQ_REL:
       emit_insn (gen_lwsync ());
       break;
     case MEMMODEL_SEQ_CST:
+    case MEMMODEL_SYNC_SEQ_CST:
       emit_insn (gen_hwsync ());
       break;
     default:
@@ -20559,10 +20598,13 @@
     case MEMMODEL_RELAXED:
     case MEMMODEL_CONSUME:
     case MEMMODEL_RELEASE:
+    case MEMMODEL_SYNC_RELEASE:
       break;
     case MEMMODEL_ACQUIRE:
+    case MEMMODEL_SYNC_ACQUIRE:
     case MEMMODEL_ACQ_REL:
     case MEMMODEL_SEQ_CST:
+    case MEMMODEL_SYNC_SEQ_CST:
       emit_insn (gen_isync ());
       break;
     default:
@@ -20662,8 +20704,8 @@
   oldval = operands[3];
   newval = operands[4];
   is_weak = (INTVAL (operands[5]) != 0);
-  mod_s = (enum memmodel) INTVAL (operands[6]);
-  mod_f = (enum memmodel) INTVAL (operands[7]);
+  mod_s = memmodel_from_int (INTVAL (operands[6]));
+  mod_f = memmodel_from_int (INTVAL (operands[7]));
   orig_mode = mode = GET_MODE (mem);
 
   mask = shift = NULL_RTX;
@@ -20751,12 +20793,12 @@
       emit_unlikely_jump (x, label1);
     }
 
-  if (mod_f != MEMMODEL_RELAXED)
+  if (!is_mm_relaxed (mod_f))
     emit_label (XEXP (label2, 0));
 
   rs6000_post_atomic_barrier (mod_s);
 
-  if (mod_f == MEMMODEL_RELAXED)
+  if (is_mm_relaxed (mod_f))
     emit_label (XEXP (label2, 0));
 
   if (shift)
@@ -22311,6 +22353,7 @@
       || ((DEFAULT_ABI == ABI_AIX || DEFAULT_ABI == ABI_ELFv2)
 	  && decl
 	  && !DECL_EXTERNAL (decl)
+	  && !DECL_WEAK (decl)
 	  && (*targetm.binds_local_p) (decl))
       || (DEFAULT_ABI == ABI_V4
 	  && (!TARGET_SECURE_PLT
@@ -32274,6 +32317,8 @@
   { "crypto",			OPTION_MASK_CRYPTO,		false, true  },
   { "direct-move",		OPTION_MASK_DIRECT_MOVE,	false, true  },
   { "dlmzb",			OPTION_MASK_DLMZB,		false, true  },
+  { "efficient-unaligned-vsx",	OPTION_MASK_EFFICIENT_UNALIGNED_VSX,
+								false, true  },
   { "fprnd",			OPTION_MASK_FPRND,		false, true  },
   { "hard-dfp",			OPTION_MASK_DFP,		false, true  },
   { "htm",			OPTION_MASK_HTM,		false, true  },
Index: gcc/config/rs6000/sync.md
===================================================================
--- gcc/config/rs6000/sync.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/rs6000/sync.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -41,7 +41,7 @@
   [(match_operand:SI 0 "const_int_operand" "")]		;; model
   ""
 {
-  enum memmodel model = (enum memmodel) INTVAL (operands[0]);
+  enum memmodel model = memmodel_from_int (INTVAL (operands[0]));
   switch (model)
     {
     case MEMMODEL_RELAXED:
@@ -48,11 +48,14 @@
       break;
     case MEMMODEL_CONSUME:
     case MEMMODEL_ACQUIRE:
+    case MEMMODEL_SYNC_ACQUIRE:
     case MEMMODEL_RELEASE:
+    case MEMMODEL_SYNC_RELEASE:
     case MEMMODEL_ACQ_REL:
       emit_insn (gen_lwsync ());
       break;
     case MEMMODEL_SEQ_CST:
+    case MEMMODEL_SYNC_SEQ_CST:
       emit_insn (gen_hwsync ());
       break;
     default:
@@ -144,9 +147,9 @@
   if (<MODE>mode == TImode && !TARGET_SYNC_TI)
     FAIL;
 
-  enum memmodel model = (enum memmodel) INTVAL (operands[2]);
+  enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
 
-  if (model == MEMMODEL_SEQ_CST)
+  if (is_mm_seq_cst (model))
     emit_insn (gen_hwsync ());
 
   if (<MODE>mode != TImode)
@@ -182,7 +185,9 @@
       break;
     case MEMMODEL_CONSUME:
     case MEMMODEL_ACQUIRE:
+    case MEMMODEL_SYNC_ACQUIRE:
     case MEMMODEL_SEQ_CST:
+    case MEMMODEL_SYNC_SEQ_CST:
       emit_insn (gen_loadsync_<mode> (operands[0]));
       break;
     default:
@@ -209,15 +214,17 @@
   if (<MODE>mode == TImode && !TARGET_SYNC_TI)
     FAIL;
 
-  enum memmodel model = (enum memmodel) INTVAL (operands[2]);
+  enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   switch (model)
     {
     case MEMMODEL_RELAXED:
       break;
     case MEMMODEL_RELEASE:
+    case MEMMODEL_SYNC_RELEASE:
       emit_insn (gen_lwsync ());
       break;
     case MEMMODEL_SEQ_CST:
+    case MEMMODEL_SYNC_SEQ_CST:
       emit_insn (gen_hwsync ());
       break;
     default:
Index: gcc/config/arm/arm.c
===================================================================
--- gcc/config/arm/arm.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/arm/arm.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -10269,7 +10269,7 @@
 
 	  *cost = COSTS_N_INSNS (1);
 
-	  if (GET_CODE (op0) == NEG)
+	  if (GET_CODE (op0) == NEG && !flag_rounding_math)
 	    op0 = XEXP (op0, 0);
 
 	  if (speed_p)
@@ -10345,6 +10345,13 @@
       if (TARGET_HARD_FLOAT && GET_MODE_CLASS (mode) == MODE_FLOAT
 	  && (mode == SFmode || !TARGET_VFP_SINGLE))
 	{
+	  if (GET_CODE (XEXP (x, 0)) == MULT)
+	    {
+	      /* VNMUL.  */
+	      *cost = rtx_cost (XEXP (x, 0), NEG, 0, speed_p);
+	      return true;
+	    }
+
 	  *cost = COSTS_N_INSNS (1);
 	  if (speed_p)
 	    *cost += extra_cost->fp[mode != SFmode].neg;
@@ -27678,8 +27685,8 @@
      promote succ to ACQ_REL so that we don't lose the acquire semantics.  */
 
   if (TARGET_HAVE_LDACQ
-      && INTVAL (mod_f) == MEMMODEL_ACQUIRE
-      && INTVAL (mod_s) == MEMMODEL_RELEASE)
+      && is_mm_acquire (memmodel_from_int (INTVAL (mod_f)))
+      && is_mm_release (memmodel_from_int (INTVAL (mod_s))))
     mod_s = GEN_INT (MEMMODEL_ACQ_REL);
 
   switch (mode)
@@ -27752,21 +27759,26 @@
   oldval = operands[2];
   newval = operands[3];
   is_weak = (operands[4] != const0_rtx);
-  mod_s = (enum memmodel) INTVAL (operands[5]);
-  mod_f = (enum memmodel) INTVAL (operands[6]);
+  mod_s = memmodel_from_int (INTVAL (operands[5]));
+  mod_f = memmodel_from_int (INTVAL (operands[6]));
   scratch = operands[7];
   mode = GET_MODE (mem);
 
+  bool is_armv8_sync = arm_arch8 && is_mm_sync (mod_s);
+
   bool use_acquire = TARGET_HAVE_LDACQ
-                     && !(mod_s == MEMMODEL_RELAXED
-                          || mod_s == MEMMODEL_CONSUME
-                          || mod_s == MEMMODEL_RELEASE);
-
+                     && !(is_mm_relaxed (mod_s) || is_mm_consume (mod_s)
+			  || is_mm_release (mod_s));
+		
   bool use_release = TARGET_HAVE_LDACQ
-                     && !(mod_s == MEMMODEL_RELAXED
-                          || mod_s == MEMMODEL_CONSUME
-                          || mod_s == MEMMODEL_ACQUIRE);
+                     && !(is_mm_relaxed (mod_s) || is_mm_consume (mod_s)
+			  || is_mm_acquire (mod_s));
 
+  /* For ARMv8, the load-acquire is too weak for __sync memory orders.  Instead,
+     a full barrier is emitted after the store-release.  */
+  if (is_armv8_sync)
+    use_acquire = false;
+
   /* Checks whether a barrier is needed and emits one accordingly.  */
   if (!(use_acquire || use_release))
     arm_pre_atomic_barrier (mod_s);
@@ -27803,14 +27815,15 @@
       emit_unlikely_jump (gen_rtx_SET (VOIDmode, pc_rtx, x));
     }
 
-  if (mod_f != MEMMODEL_RELAXED)
+  if (!is_mm_relaxed (mod_f))
     emit_label (label2);
 
   /* Checks whether a barrier is needed and emits one accordingly.  */
-  if (!(use_acquire || use_release))
+  if (is_armv8_sync
+      || !(use_acquire || use_release))
     arm_post_atomic_barrier (mod_s);
 
-  if (mod_f == MEMMODEL_RELAXED)
+  if (is_mm_relaxed (mod_f))
     emit_label (label2);
 }
 
@@ -27818,22 +27831,27 @@
 arm_split_atomic_op (enum rtx_code code, rtx old_out, rtx new_out, rtx mem,
 		     rtx value, rtx model_rtx, rtx cond)
 {
-  enum memmodel model = (enum memmodel) INTVAL (model_rtx);
+  enum memmodel model = memmodel_from_int (INTVAL (model_rtx));
   machine_mode mode = GET_MODE (mem);
   machine_mode wmode = (mode == DImode ? DImode : SImode);
   rtx_code_label *label;
   rtx x;
 
+  bool is_armv8_sync = arm_arch8 && is_mm_sync (model);
+
   bool use_acquire = TARGET_HAVE_LDACQ
-                     && !(model == MEMMODEL_RELAXED
-                          || model == MEMMODEL_CONSUME
-                          || model == MEMMODEL_RELEASE);
+                     && !(is_mm_relaxed (model) || is_mm_consume (model)
+			  || is_mm_release (model));
 
   bool use_release = TARGET_HAVE_LDACQ
-                     && !(model == MEMMODEL_RELAXED
-                          || model == MEMMODEL_CONSUME
-                          || model == MEMMODEL_ACQUIRE);
+                     && !(is_mm_relaxed (model) || is_mm_consume (model)
+			  || is_mm_acquire (model));
 
+  /* For ARMv8, a load-acquire is too weak for __sync memory orders.  Instead,
+     a full barrier is emitted after the store-release.  */
+  if (is_armv8_sync)
+    use_acquire = false;
+
   /* Checks whether a barrier is needed and emits one accordingly.  */
   if (!(use_acquire || use_release))
     arm_pre_atomic_barrier (model);
@@ -27904,7 +27922,8 @@
   emit_unlikely_jump (gen_cbranchsi4 (x, cond, const0_rtx, label));
 
   /* Checks whether a barrier is needed and emits one accordingly.  */
-  if (!(use_acquire || use_release))
+  if (is_armv8_sync
+      || !(use_acquire || use_release))
     arm_post_atomic_barrier (model);
 }
 
@@ -28792,7 +28811,39 @@
   #undef BRANCH
 }
 
+/* Returns true if the pattern is a valid symbolic address, which is either a
+   symbol_ref or (symbol_ref + addend).
 
+   According to the ARM ELF ABI, the initial addend of REL-type relocations
+   processing MOVW and MOVT instructions is formed by interpreting the 16-bit
+   literal field of the instruction as a 16-bit signed value in the range
+   -32768 <= A < 32768.  */
+
+bool
+arm_valid_symbolic_address_p (rtx addr)
+{
+  rtx xop0, xop1 = NULL_RTX;
+  rtx tmp = addr;
+
+  if (GET_CODE (tmp) == SYMBOL_REF || GET_CODE (tmp) == LABEL_REF)
+    return true;
+
+  /* (const (plus: symbol_ref const_int))  */
+  if (GET_CODE (addr) == CONST)
+    tmp = XEXP (addr, 0);
+
+  if (GET_CODE (tmp) == PLUS)
+    {
+      xop0 = XEXP (tmp, 0);
+      xop1 = XEXP (tmp, 1);
+
+      if (GET_CODE (xop0) == SYMBOL_REF && CONST_INT_P (xop1))
+	  return IN_RANGE (INTVAL (xop1), -0x8000, 0x7fff);
+    }
+
+  return false;
+}
+
 /* Returns true if a valid comparison operation and makes
    the operands in a form that is valid.  */
 bool
Index: gcc/config/arm/arm-protos.h
===================================================================
--- gcc/config/arm/arm-protos.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/arm/arm-protos.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -312,6 +312,7 @@
 
 extern void arm_emit_coreregs_64bit_shift (enum rtx_code, rtx, rtx, rtx, rtx,
 					   rtx);
+extern bool arm_valid_symbolic_address_p (rtx);
 extern bool arm_validize_comparison (rtx *, rtx *, rtx *);
 #endif /* RTX_CODE */
 
Index: gcc/config/arm/vfp.md
===================================================================
--- gcc/config/arm/vfp.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/arm/vfp.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -770,6 +770,17 @@
   [(set (match_operand:SF		   0 "s_register_operand" "=t")
 	(mult:SF (neg:SF (match_operand:SF 1 "s_register_operand" "t"))
 		 (match_operand:SF	   2 "s_register_operand" "t")))]
+  "TARGET_32BIT && TARGET_HARD_FLOAT && TARGET_VFP && !flag_rounding_math"
+  "vnmul%?.f32\\t%0, %1, %2"
+  [(set_attr "predicable" "yes")
+   (set_attr "predicable_short_it" "no")
+   (set_attr "type" "fmuls")]
+)
+
+(define_insn "*negmulsf3_vfp"
+  [(set (match_operand:SF		   0 "s_register_operand" "=t")
+	(neg:SF (mult:SF (match_operand:SF 1 "s_register_operand" "t")
+		 (match_operand:SF	   2 "s_register_operand" "t"))))]
   "TARGET_32BIT && TARGET_HARD_FLOAT && TARGET_VFP"
   "vnmul%?.f32\\t%0, %1, %2"
   [(set_attr "predicable" "yes")
@@ -781,6 +792,18 @@
   [(set (match_operand:DF		   0 "s_register_operand" "=w")
 	(mult:DF (neg:DF (match_operand:DF 1 "s_register_operand" "w"))
 		 (match_operand:DF	   2 "s_register_operand" "w")))]
+  "TARGET_32BIT && TARGET_HARD_FLOAT && TARGET_VFP_DOUBLE
+  && !flag_rounding_math"
+  "vnmul%?.f64\\t%P0, %P1, %P2"
+  [(set_attr "predicable" "yes")
+   (set_attr "predicable_short_it" "no")
+   (set_attr "type" "fmuld")]
+)
+
+(define_insn "*negmuldf3_vfp"
+  [(set (match_operand:DF		   0 "s_register_operand" "=w")
+	(neg:DF (mult:DF (match_operand:DF 1 "s_register_operand" "w")
+		 (match_operand:DF	   2 "s_register_operand" "w"))))]
   "TARGET_32BIT && TARGET_HARD_FLOAT && TARGET_VFP_DOUBLE"
   "vnmul%?.f64\\t%P0, %P1, %P2"
   [(set_attr "predicable" "yes")
Index: gcc/config/arm/constraints.md
===================================================================
--- gcc/config/arm/constraints.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/arm/constraints.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -67,7 +67,8 @@
 (define_constraint "j"
  "A constant suitable for a MOVW instruction. (ARM/Thumb-2)"
  (and (match_test "TARGET_32BIT && arm_arch_thumb2")
-      (ior (match_code "high")
+      (ior (and (match_code "high")
+		(match_test "arm_valid_symbolic_address_p (XEXP (op, 0))"))
 	   (and (match_code "const_int")
                 (match_test "(ival & 0xffff0000) == 0")))))
 
Index: gcc/config/arm/sync.md
===================================================================
--- gcc/config/arm/sync.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/arm/sync.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -73,10 +73,8 @@
       VUNSPEC_LDA))]
   "TARGET_HAVE_LDACQ"
   {
-    enum memmodel model = (enum memmodel) INTVAL (operands[2]);
-    if (model == MEMMODEL_RELAXED
-        || model == MEMMODEL_CONSUME
-        || model == MEMMODEL_RELEASE)
+    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
+    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_release (model))
       return \"ldr<sync_sfx>\\t%0, %1\";
     else
       return \"lda<sync_sfx>\\t%0, %1\";
@@ -91,10 +89,8 @@
       VUNSPEC_STL))]
   "TARGET_HAVE_LDACQ"
   {
-    enum memmodel model = (enum memmodel) INTVAL (operands[2]);
-    if (model == MEMMODEL_RELAXED
-        || model == MEMMODEL_CONSUME
-        || model == MEMMODEL_ACQUIRE)
+    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
+    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_acquire (model))
       return \"str<sync_sfx>\t%1, %0\";
     else
       return \"stl<sync_sfx>\t%1, %0\";
@@ -110,10 +106,10 @@
    (match_operand:SI 2 "const_int_operand")]		;; model
   "TARGET_HAVE_LDREXD && ARM_DOUBLEWORD_ALIGN"
 {
-  enum memmodel model = (enum memmodel) INTVAL (operands[2]);
+  enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   expand_mem_thread_fence (model);
   emit_insn (gen_atomic_loaddi_1 (operands[0], operands[1]));
-  if (model == MEMMODEL_SEQ_CST)
+  if (is_mm_seq_cst (model))
     expand_mem_thread_fence (model);
   DONE;
 })
Index: gcc/config/arm/arm.md
===================================================================
--- gcc/config/arm/arm.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/arm/arm.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -5415,7 +5415,7 @@
       if (!REG_P (operands[0]))
 	operands[1] = force_reg (DImode, operands[1]);
     }
-  if (REG_P (operands[0]) && REGNO (operands[0]) < FIRST_VIRTUAL_REGISTER
+  if (REG_P (operands[0]) && REGNO (operands[0]) <= LAST_ARM_REGNUM
       && !HARD_REGNO_MODE_OK (REGNO (operands[0]), DImode))
     {
       /* Avoid LDRD's into an odd-numbered register pair in ARM state
@@ -5434,7 +5434,7 @@
 		      gen_highpart (SImode, operands[1]));
       DONE;
     }
-  else if (REG_P (operands[1]) && REGNO (operands[1]) < FIRST_VIRTUAL_REGISTER
+  else if (REG_P (operands[1]) && REGNO (operands[1]) <= LAST_ARM_REGNUM
 	   && !HARD_REGNO_MODE_OK (REGNO (operands[1]), DImode))
     {
       /* Avoid STRD's from an odd-numbered register pair in ARM state
@@ -5662,7 +5662,7 @@
   [(set (match_operand:SI 0 "nonimmediate_operand" "=r")
 	(lo_sum:SI (match_operand:SI 1 "nonimmediate_operand" "0")
 		   (match_operand:SI 2 "general_operand"      "i")))]
-  "arm_arch_thumb2"
+  "arm_arch_thumb2 && arm_valid_symbolic_address_p (operands[2])"
   "movt%?\t%0, #:upper16:%c2"
   [(set_attr "predicable" "yes")
    (set_attr "predicable_short_it" "no")
Index: gcc/config/pa/pa.md
===================================================================
--- gcc/config/pa/pa.md	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/pa/pa.md	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -707,12 +707,12 @@
    (match_operand:SI 2 "const_int_operand")]            ;; model
   "!TARGET_64BIT && !TARGET_SOFT_FLOAT"
 {
-  enum memmodel model = (enum memmodel) INTVAL (operands[2]);
+  enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   operands[1] = force_reg (SImode, XEXP (operands[1], 0));
   operands[2] = gen_reg_rtx (DImode);
   expand_mem_thread_fence (model);
   emit_insn (gen_atomic_loaddi_1 (operands[0], operands[1], operands[2]));
-  if ((model & MEMMODEL_MASK) == MEMMODEL_SEQ_CST)
+  if (is_mm_seq_cst (model))
     expand_mem_thread_fence (model);
   DONE;
 })
@@ -734,12 +734,12 @@
    (match_operand:SI 2 "const_int_operand")]            ;; model
   "!TARGET_64BIT && !TARGET_SOFT_FLOAT"
 {
-  enum memmodel model = (enum memmodel) INTVAL (operands[2]);
+  enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   operands[0] = force_reg (SImode, XEXP (operands[0], 0));
   operands[2] = gen_reg_rtx (DImode);
   expand_mem_thread_fence (model);
   emit_insn (gen_atomic_storedi_1 (operands[0], operands[1], operands[2]));
-  if ((model & MEMMODEL_MASK) == MEMMODEL_SEQ_CST)
+  if (is_mm_seq_cst (model))
     expand_mem_thread_fence (model);
   DONE;
 })
@@ -7516,7 +7516,6 @@
 (define_insn "call_reg_64bit"
   [(call (mem:SI (match_operand:DI 0 "register_operand" "r"))
 	 (match_operand 1 "" "i"))
-   (clobber (reg:DI 1))
    (clobber (reg:DI 2))
    (clobber (match_operand 2))
    (use (reg:DI 27))
@@ -7537,7 +7536,6 @@
 (define_split
   [(parallel [(call (mem:SI (match_operand 0 "register_operand" ""))
 		    (match_operand 1 "" ""))
-	      (clobber (reg:DI 1))
 	      (clobber (reg:DI 2))
 	      (clobber (match_operand 2))
 	      (use (reg:DI 27))
@@ -7548,7 +7546,6 @@
   [(set (match_dup 2) (reg:DI 27))
    (parallel [(call (mem:SI (match_dup 0))
 		    (match_dup 1))
-	      (clobber (reg:DI 1))
 	      (clobber (reg:DI 2))
 	      (use (reg:DI 27))
 	      (use (reg:DI 29))
@@ -7558,7 +7555,6 @@
 (define_split
   [(parallel [(call (mem:SI (match_operand 0 "register_operand" ""))
 		    (match_operand 1 "" ""))
-	      (clobber (reg:DI 1))
 	      (clobber (reg:DI 2))
 	      (clobber (match_operand 2))
 	      (use (reg:DI 27))
@@ -7568,7 +7564,6 @@
   [(set (match_dup 2) (reg:DI 27))
    (parallel [(call (mem:SI (match_dup 0))
 		    (match_dup 1))
-	      (clobber (reg:DI 1))
 	      (clobber (reg:DI 2))
 	      (use (reg:DI 27))
 	      (use (reg:DI 29))
@@ -7579,7 +7574,6 @@
 (define_insn "*call_reg_64bit_post_reload"
   [(call (mem:SI (match_operand:DI 0 "register_operand" "r"))
 	 (match_operand 1 "" "i"))
-   (clobber (reg:DI 1))
    (clobber (reg:DI 2))
    (use (reg:DI 27))
    (use (reg:DI 29))
Index: gcc/config/pa/pa.c
===================================================================
--- gcc/config/pa/pa.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/pa/pa.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -2443,6 +2443,7 @@
   enum { REGOP, OFFSOP, MEMOP, CNSTOP, RNDOP } optype0, optype1;
   rtx latehalf[2];
   rtx addreg0 = 0, addreg1 = 0;
+  int highonly = 0;
 
   /* First classify both operands.  */
 
@@ -2653,7 +2654,14 @@
   else if (optype1 == OFFSOP)
     latehalf[1] = adjust_address_nv (operands[1], SImode, 4);
   else if (optype1 == CNSTOP)
-    split_double (operands[1], &operands[1], &latehalf[1]);
+    {
+      if (GET_CODE (operands[1]) == HIGH)
+	{
+	  operands[1] = XEXP (operands[1], 0);
+	  highonly = 1;
+	}
+      split_double (operands[1], &operands[1], &latehalf[1]);
+    }
   else
     latehalf[1] = operands[1];
 
@@ -2706,8 +2714,11 @@
   if (addreg1)
     output_asm_insn ("ldo 4(%0),%0", &addreg1);
 
-  /* Do that word.  */
-  output_asm_insn (pa_singlemove_string (latehalf), latehalf);
+  /* Do high-numbered word.  */
+  if (highonly)
+    output_asm_insn ("ldil L'%1,%0", latehalf);
+  else
+    output_asm_insn (pa_singlemove_string (latehalf), latehalf);
 
   /* Undo the adds we just did.  */
   if (addreg0)
Index: gcc/config/mips/mips.c
===================================================================
--- gcc/config/mips/mips.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ gcc/config/mips/mips.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -13111,7 +13111,7 @@
       model = MEMMODEL_ACQUIRE;
       break;
     default:
-      model = (enum memmodel) INTVAL (operands[memmodel_attr]);
+      model = memmodel_from_int (INTVAL (operands[memmodel_attr]));
     }
 
   mips_multi_start ();
Index: libgo/configure
===================================================================
--- libgo/configure	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgo/configure	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -602,6 +602,8 @@
 am__EXEEXT_TRUE
 LTLIBOBJS
 LIBOBJS
+HAVE_STAT_TIMESPEC_FALSE
+HAVE_STAT_TIMESPEC_TRUE
 STRUCT_EPOLL_EVENT_FD_OFFSET
 SIZEOF_STRUCT_EPOLL_EVENT
 MATH_FLAG
@@ -723,6 +725,7 @@
 am__fastdepCC_FALSE
 am__fastdepCC_TRUE
 CCDEPMODE
+am__nodep
 AMDEPBACKSLASH
 AMDEP_FALSE
 AMDEP_TRUE
@@ -3147,11 +3150,12 @@
 
 # We need awk for the "check" target.  The system "awk" is bad on
 # some platforms.
-# Always define AMTAR for backward compatibility.
+# Always define AMTAR for backward compatibility.  Yes, it's still used
+# in the wild :-(  We should find a proper way to deprecate it ...
+AMTAR='$${TAR-tar}'
 
-AMTAR=${AMTAR-"${am_missing_run}tar"}
+am__tar='$${TAR-tar} chof - "$$tardir"' am__untar='$${TAR-tar} xf -'
 
-am__tar='${AMTAR} chof - "$$tardir"'; am__untar='${AMTAR} xf -'
 
 
 
@@ -3161,7 +3165,6 @@
 
 
 
-
 ac_ext=c
 ac_cpp='$CPP $CPPFLAGS'
 ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext >&5'
@@ -3978,6 +3981,7 @@
 if test "x$enable_dependency_tracking" != xno; then
   am_depcomp="$ac_aux_dir/depcomp"
   AMDEPBACKSLASH='\'
+  am__nodep='_no'
 fi
  if test "x$enable_dependency_tracking" != xno; then
   AMDEP_TRUE=
@@ -4002,6 +4006,7 @@
   # instance it was reported that on HP-UX the gcc test will end up
   # making a dummy file named `D' -- because `-MD' means `put the output
   # in D'.
+  rm -rf conftest.dir
   mkdir conftest.dir
   # Copy depcomp to subdir because otherwise we won't find it if we're
   # using a relative directory.
@@ -4061,7 +4066,7 @@
 	break
       fi
       ;;
-    msvisualcpp | msvcmsys)
+    msvc7 | msvc7msys | msvisualcpp | msvcmsys)
       # This compiler won't grok `-c -o', but also, the minuso test has
       # not run yet.  These depmodes are late enough in the game, and
       # so weak that their functioning should not be impacted.
@@ -11121,7 +11126,7 @@
   lt_dlunknown=0; lt_dlno_uscore=1; lt_dlneed_uscore=2
   lt_status=$lt_dlunknown
   cat > conftest.$ac_ext <<_LT_EOF
-#line 11124 "configure"
+#line 11129 "configure"
 #include "confdefs.h"
 
 #if HAVE_DLFCN_H
@@ -11227,7 +11232,7 @@
   lt_dlunknown=0; lt_dlno_uscore=1; lt_dlneed_uscore=2
   lt_status=$lt_dlunknown
   cat > conftest.$ac_ext <<_LT_EOF
-#line 11230 "configure"
+#line 11235 "configure"
 #include "confdefs.h"
 
 #if HAVE_DLFCN_H
@@ -15141,6 +15146,28 @@
 STRUCT_EPOLL_EVENT_FD_OFFSET=${libgo_cv_c_epoll_event_fd_offset}
 
 
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <sys/stat.h>
+
+_ACEOF
+if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
+  $EGREP "timespec_t.*st_atim" >/dev/null 2>&1; then :
+  have_stat_timespec=yes
+else
+  have_stat_timespec=no
+fi
+rm -f conftest*
+
+ if test $have_stat_timespec = yes; then
+  HAVE_STAT_TIMESPEC_TRUE=
+  HAVE_STAT_TIMESPEC_FALSE='#'
+else
+  HAVE_STAT_TIMESPEC_TRUE='#'
+  HAVE_STAT_TIMESPEC_FALSE=
+fi
+
+
 ac_fn_c_check_type "$LINENO" "struct exception" "ac_cv_type_struct_exception" "#include <math.h>
 "
 if test "x$ac_cv_type_struct_exception" = x""yes; then :
@@ -15761,6 +15788,10 @@
   as_fn_error "conditional \"HAVE_WAIT4\" was never defined.
 Usually this means the macro was only invoked conditionally." "$LINENO" 5
 fi
+if test -z "${HAVE_STAT_TIMESPEC_TRUE}" && test -z "${HAVE_STAT_TIMESPEC_FALSE}"; then
+  as_fn_error "conditional \"HAVE_STAT_TIMESPEC\" was never defined.
+Usually this means the macro was only invoked conditionally." "$LINENO" 5
+fi
 
 : ${CONFIG_STATUS=./config.status}
 ac_write_fail=0
Index: libgo/Makefile.in
===================================================================
--- libgo/Makefile.in	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgo/Makefile.in	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11.1 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -26,6 +26,23 @@
 
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -91,6 +108,12 @@
 am__base_list = \
   sed '$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;s/\n/ /g' | \
   sed '$$!N;$$!N;$$!N;$$!N;s/\n/ /g'
+am__uninstall_files_from_dir = { \
+  test -z "$$files" \
+    || { test ! -d "$$dir" && test ! -f "$$dir" && test ! -r "$$dir"; } \
+    || { echo " ( cd '$$dir' && rm -f" $$files ")"; \
+         $(am__cd) "$$dir" && rm -f $$files; }; \
+  }
 am__installdirs = "$(DESTDIR)$(toolexeclibdir)" \
 	"$(DESTDIR)$(toolexeclibdir)" "$(DESTDIR)$(toolexeclibgodir)" \
 	"$(DESTDIR)$(toolexeclibgoarchivedir)" \
@@ -283,6 +306,11 @@
 	install-pdf-recursive install-ps-recursive install-recursive \
 	installcheck-recursive installdirs-recursive pdf-recursive \
 	ps-recursive uninstall-recursive
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 DATA = $(noinst_DATA) $(toolexeclibgo_DATA) \
 	$(toolexeclibgoarchive_DATA) $(toolexeclibgocompress_DATA) \
 	$(toolexeclibgocontainer_DATA) $(toolexeclibgocrypto_DATA) \
@@ -1107,6 +1135,8 @@
 @LIBGO_IS_DARWIN_FALSE@@LIBGO_IS_FREEBSD_FALSE@go_os_cloexec_file = go/os/sys_unix.go
 @LIBGO_IS_DARWIN_TRUE@@LIBGO_IS_FREEBSD_FALSE@go_os_cloexec_file = go/os/sys_darwin.go
 @LIBGO_IS_FREEBSD_TRUE@go_os_cloexec_file = go/os/sys_freebsd.go
+@HAVE_STAT_TIMESPEC_FALSE@@LIBGO_IS_SOLARIS_TRUE@go_os_stat_file = go/os/stat_solaris.go
+@HAVE_STAT_TIMESPEC_TRUE@@LIBGO_IS_SOLARIS_TRUE@go_os_stat_file = go/os/stat_atim.go
 @LIBGO_IS_DARWIN_FALSE@@LIBGO_IS_DRAGONFLY_FALSE@@LIBGO_IS_FREEBSD_FALSE@@LIBGO_IS_LINUX_FALSE@@LIBGO_IS_NETBSD_FALSE@@LIBGO_IS_OPENBSD_FALSE@@LIBGO_IS_SOLARIS_FALSE@go_os_stat_file = go/os/stat.go
 @LIBGO_IS_DARWIN_FALSE@@LIBGO_IS_DRAGONFLY_TRUE@@LIBGO_IS_FREEBSD_FALSE@@LIBGO_IS_LINUX_FALSE@@LIBGO_IS_NETBSD_FALSE@@LIBGO_IS_OPENBSD_FALSE@@LIBGO_IS_SOLARIS_FALSE@go_os_stat_file = go/os/stat_dragonfly.go
 @LIBGO_IS_DARWIN_FALSE@@LIBGO_IS_FREEBSD_FALSE@@LIBGO_IS_LINUX_FALSE@@LIBGO_IS_NETBSD_TRUE@@LIBGO_IS_OPENBSD_FALSE@@LIBGO_IS_SOLARIS_FALSE@go_os_stat_file = go/os/stat_atimespec.go
@@ -1114,7 +1144,6 @@
 @LIBGO_IS_DARWIN_TRUE@@LIBGO_IS_LINUX_FALSE@@LIBGO_IS_OPENBSD_FALSE@@LIBGO_IS_SOLARIS_FALSE@go_os_stat_file = go/os/stat_atimespec.go
 @LIBGO_IS_LINUX_FALSE@@LIBGO_IS_OPENBSD_TRUE@@LIBGO_IS_SOLARIS_FALSE@go_os_stat_file = go/os/stat_atim.go
 @LIBGO_IS_LINUX_TRUE@@LIBGO_IS_SOLARIS_FALSE@go_os_stat_file = go/os/stat_atim.go
-@LIBGO_IS_SOLARIS_TRUE@go_os_stat_file = go/os/stat_solaris.go
 @LIBGO_IS_LINUX_FALSE@go_os_pipe_file = go/os/pipe_bsd.go
 @LIBGO_IS_LINUX_TRUE@go_os_pipe_file = go/os/pipe_linux.go
 go_os_files = \
@@ -1848,6 +1877,10 @@
 
 # Define socket sizes and types.
 @LIBGO_IS_LINUX_TRUE@syscall_socket_file = go/syscall/socket_linux.go epoll.go
+@LIBGO_IS_LINUX_FALSE@syscall_socket_type_file = 
+@LIBGO_IS_LINUX_TRUE@@LIBGO_IS_PPC64LE_FALSE@@LIBGO_IS_PPC64_FALSE@syscall_socket_type_file = go/syscall/socket_linux_type.go
+@LIBGO_IS_LINUX_TRUE@@LIBGO_IS_PPC64LE_FALSE@@LIBGO_IS_PPC64_TRUE@syscall_socket_type_file = go/syscall/socket_linux_ppc64x_type.go
+@LIBGO_IS_LINUX_TRUE@@LIBGO_IS_PPC64LE_TRUE@syscall_socket_type_file = go/syscall/socket_linux_ppc64x_type.go
 @LIBGO_IS_SOLARIS_FALSE@syscall_socket_os_file = go/syscall/socket_posix.go
 
 # Define socket functions.
@@ -1898,6 +1931,7 @@
 	$(syscall_size_file) \
 	$(syscall_socket_file) \
 	$(syscall_socket_os_file) \
+	$(syscall_socket_type_file) \
 	$(syscall_uname_file) \
 	$(syscall_netlink_file) \
 	$(syscall_lsf_file) \
@@ -2338,7 +2372,7 @@
 
 .SUFFIXES:
 .SUFFIXES: .c .go .gox .o .obj .lo .a
-am--refresh:
+am--refresh: Makefile
 	@:
 $(srcdir)/Makefile.in: @MAINTAINER_MODE_TRUE@ $(srcdir)/Makefile.am  $(am__configure_deps)
 	@for dep in $?; do \
@@ -2374,10 +2408,8 @@
 $(am__aclocal_m4_deps):
 
 config.h: stamp-h1
-	@if test ! -f $@; then \
-	  rm -f stamp-h1; \
-	  $(MAKE) $(AM_MAKEFLAGS) stamp-h1; \
-	else :; fi
+	@if test ! -f $@; then rm -f stamp-h1; else :; fi
+	@if test ! -f $@; then $(MAKE) $(AM_MAKEFLAGS) stamp-h1; else :; fi
 
 stamp-h1: $(srcdir)/config.h.in $(top_builddir)/config.status
 	@rm -f stamp-h1
@@ -2391,7 +2423,6 @@
 	-rm -f config.h stamp-h1
 install-toolexeclibLIBRARIES: $(toolexeclib_LIBRARIES)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibdir)"
 	@list='$(toolexeclib_LIBRARIES)'; test -n "$(toolexeclibdir)" || list=; \
 	list2=; for p in $$list; do \
 	  if test -f $$p; then \
@@ -2399,6 +2430,8 @@
 	  else :; fi; \
 	done; \
 	test -z "$$list2" || { \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibdir)" || exit 1; \
 	  echo " $(INSTALL_DATA) $$list2 '$(DESTDIR)$(toolexeclibdir)'"; \
 	  $(INSTALL_DATA) $$list2 "$(DESTDIR)$(toolexeclibdir)" || exit $$?; }
 	@$(POST_INSTALL)
@@ -2415,31 +2448,28 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclib_LIBRARIES)'; test -n "$(toolexeclibdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibdir)' && rm -f "$$files" )"; \
-	cd "$(DESTDIR)$(toolexeclibdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibdir)'; $(am__uninstall_files_from_dir)
 
 clean-toolexeclibLIBRARIES:
 	-test -z "$(toolexeclib_LIBRARIES)" || rm -f $(toolexeclib_LIBRARIES)
-libgobegin-llgo.a: $(libgobegin_llgo_a_OBJECTS) $(libgobegin_llgo_a_DEPENDENCIES) 
+libgobegin-llgo.a: $(libgobegin_llgo_a_OBJECTS) $(libgobegin_llgo_a_DEPENDENCIES) $(EXTRA_libgobegin_llgo_a_DEPENDENCIES) 
 	-rm -f libgobegin-llgo.a
 	$(libgobegin_llgo_a_AR) libgobegin-llgo.a $(libgobegin_llgo_a_OBJECTS) $(libgobegin_llgo_a_LIBADD)
 	$(RANLIB) libgobegin-llgo.a
-libgobegin.a: $(libgobegin_a_OBJECTS) $(libgobegin_a_DEPENDENCIES) 
+libgobegin.a: $(libgobegin_a_OBJECTS) $(libgobegin_a_DEPENDENCIES) $(EXTRA_libgobegin_a_DEPENDENCIES) 
 	-rm -f libgobegin.a
 	$(libgobegin_a_AR) libgobegin.a $(libgobegin_a_OBJECTS) $(libgobegin_a_LIBADD)
 	$(RANLIB) libgobegin.a
-libgolibbegin.a: $(libgolibbegin_a_OBJECTS) $(libgolibbegin_a_DEPENDENCIES) 
+libgolibbegin.a: $(libgolibbegin_a_OBJECTS) $(libgolibbegin_a_DEPENDENCIES) $(EXTRA_libgolibbegin_a_DEPENDENCIES) 
 	-rm -f libgolibbegin.a
 	$(libgolibbegin_a_AR) libgolibbegin.a $(libgolibbegin_a_OBJECTS) $(libgolibbegin_a_LIBADD)
 	$(RANLIB) libgolibbegin.a
-libnetgo.a: $(libnetgo_a_OBJECTS) $(libnetgo_a_DEPENDENCIES) 
+libnetgo.a: $(libnetgo_a_OBJECTS) $(libnetgo_a_DEPENDENCIES) $(EXTRA_libnetgo_a_DEPENDENCIES) 
 	-rm -f libnetgo.a
 	$(libnetgo_a_AR) libnetgo.a $(libnetgo_a_OBJECTS) $(libnetgo_a_LIBADD)
 	$(RANLIB) libnetgo.a
 install-toolexeclibLTLIBRARIES: $(toolexeclib_LTLIBRARIES)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibdir)"
 	@list='$(toolexeclib_LTLIBRARIES)'; test -n "$(toolexeclibdir)" || list=; \
 	list2=; for p in $$list; do \
 	  if test -f $$p; then \
@@ -2447,6 +2477,8 @@
 	  else :; fi; \
 	done; \
 	test -z "$$list2" || { \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibdir)" || exit 1; \
 	  echo " $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 '$(DESTDIR)$(toolexeclibdir)'"; \
 	  $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 "$(DESTDIR)$(toolexeclibdir)"; \
 	}
@@ -2468,9 +2500,9 @@
 	  echo "rm -f \"$${dir}/so_locations\""; \
 	  rm -f "$${dir}/so_locations"; \
 	done
-libgo-llgo.la: $(libgo_llgo_la_OBJECTS) $(libgo_llgo_la_DEPENDENCIES) 
+libgo-llgo.la: $(libgo_llgo_la_OBJECTS) $(libgo_llgo_la_DEPENDENCIES) $(EXTRA_libgo_llgo_la_DEPENDENCIES) 
 	$(libgo_llgo_la_LINK) $(am_libgo_llgo_la_rpath) $(libgo_llgo_la_OBJECTS) $(libgo_llgo_la_LIBADD) $(LIBS)
-libgo.la: $(libgo_la_OBJECTS) $(libgo_la_DEPENDENCIES) 
+libgo.la: $(libgo_la_OBJECTS) $(libgo_la_DEPENDENCIES) $(EXTRA_libgo_la_DEPENDENCIES) 
 	$(libgo_la_LINK) $(am_libgo_la_rpath) $(libgo_la_OBJECTS) $(libgo_la_LIBADD) $(LIBS)
 
 mostlyclean-compile:
@@ -3364,8 +3396,11 @@
 	$(MULTICLEAN) $(AM_MAKEFLAGS) DO=maintainer-clean multi-clean # $(MAKE)
 install-toolexeclibgoDATA: $(toolexeclibgo_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgodir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgodir)"
 	@list='$(toolexeclibgo_DATA)'; test -n "$(toolexeclibgodir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgodir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgodir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3379,13 +3414,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgo_DATA)'; test -n "$(toolexeclibgodir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgodir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgodir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgodir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgoarchiveDATA: $(toolexeclibgoarchive_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgoarchivedir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoarchivedir)"
 	@list='$(toolexeclibgoarchive_DATA)'; test -n "$(toolexeclibgoarchivedir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgoarchivedir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoarchivedir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3399,13 +3435,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgoarchive_DATA)'; test -n "$(toolexeclibgoarchivedir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgoarchivedir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgoarchivedir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgoarchivedir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgocompressDATA: $(toolexeclibgocompress_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgocompressdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgocompressdir)"
 	@list='$(toolexeclibgocompress_DATA)'; test -n "$(toolexeclibgocompressdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgocompressdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgocompressdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3419,13 +3456,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgocompress_DATA)'; test -n "$(toolexeclibgocompressdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgocompressdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgocompressdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgocompressdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgocontainerDATA: $(toolexeclibgocontainer_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgocontainerdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgocontainerdir)"
 	@list='$(toolexeclibgocontainer_DATA)'; test -n "$(toolexeclibgocontainerdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgocontainerdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgocontainerdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3439,13 +3477,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgocontainer_DATA)'; test -n "$(toolexeclibgocontainerdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgocontainerdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgocontainerdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgocontainerdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgocryptoDATA: $(toolexeclibgocrypto_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgocryptodir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgocryptodir)"
 	@list='$(toolexeclibgocrypto_DATA)'; test -n "$(toolexeclibgocryptodir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgocryptodir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgocryptodir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3459,13 +3498,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgocrypto_DATA)'; test -n "$(toolexeclibgocryptodir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgocryptodir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgocryptodir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgocryptodir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgocryptox509DATA: $(toolexeclibgocryptox509_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgocryptox509dir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgocryptox509dir)"
 	@list='$(toolexeclibgocryptox509_DATA)'; test -n "$(toolexeclibgocryptox509dir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgocryptox509dir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgocryptox509dir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3479,13 +3519,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgocryptox509_DATA)'; test -n "$(toolexeclibgocryptox509dir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgocryptox509dir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgocryptox509dir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgocryptox509dir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgodatabaseDATA: $(toolexeclibgodatabase_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgodatabasedir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgodatabasedir)"
 	@list='$(toolexeclibgodatabase_DATA)'; test -n "$(toolexeclibgodatabasedir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgodatabasedir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgodatabasedir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3499,13 +3540,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgodatabase_DATA)'; test -n "$(toolexeclibgodatabasedir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgodatabasedir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgodatabasedir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgodatabasedir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgodatabasesqlDATA: $(toolexeclibgodatabasesql_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgodatabasesqldir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgodatabasesqldir)"
 	@list='$(toolexeclibgodatabasesql_DATA)'; test -n "$(toolexeclibgodatabasesqldir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgodatabasesqldir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgodatabasesqldir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3519,13 +3561,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgodatabasesql_DATA)'; test -n "$(toolexeclibgodatabasesqldir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgodatabasesqldir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgodatabasesqldir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgodatabasesqldir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgodebugDATA: $(toolexeclibgodebug_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgodebugdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgodebugdir)"
 	@list='$(toolexeclibgodebug_DATA)'; test -n "$(toolexeclibgodebugdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgodebugdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgodebugdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3539,13 +3582,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgodebug_DATA)'; test -n "$(toolexeclibgodebugdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgodebugdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgodebugdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgodebugdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgoencodingDATA: $(toolexeclibgoencoding_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgoencodingdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoencodingdir)"
 	@list='$(toolexeclibgoencoding_DATA)'; test -n "$(toolexeclibgoencodingdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgoencodingdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoencodingdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3559,13 +3603,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgoencoding_DATA)'; test -n "$(toolexeclibgoencodingdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgoencodingdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgoencodingdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgoencodingdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgoexpDATA: $(toolexeclibgoexp_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgoexpdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoexpdir)"
 	@list='$(toolexeclibgoexp_DATA)'; test -n "$(toolexeclibgoexpdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgoexpdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoexpdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3579,13 +3624,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgoexp_DATA)'; test -n "$(toolexeclibgoexpdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgoexpdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgoexpdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgoexpdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgogoDATA: $(toolexeclibgogo_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgogodir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgogodir)"
 	@list='$(toolexeclibgogo_DATA)'; test -n "$(toolexeclibgogodir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgogodir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgogodir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3599,13 +3645,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgogo_DATA)'; test -n "$(toolexeclibgogodir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgogodir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgogodir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgogodir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgohashDATA: $(toolexeclibgohash_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgohashdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgohashdir)"
 	@list='$(toolexeclibgohash_DATA)'; test -n "$(toolexeclibgohashdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgohashdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgohashdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3619,13 +3666,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgohash_DATA)'; test -n "$(toolexeclibgohashdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgohashdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgohashdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgohashdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgohtmlDATA: $(toolexeclibgohtml_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgohtmldir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgohtmldir)"
 	@list='$(toolexeclibgohtml_DATA)'; test -n "$(toolexeclibgohtmldir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgohtmldir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgohtmldir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3639,13 +3687,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgohtml_DATA)'; test -n "$(toolexeclibgohtmldir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgohtmldir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgohtmldir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgohtmldir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgoimageDATA: $(toolexeclibgoimage_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgoimagedir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoimagedir)"
 	@list='$(toolexeclibgoimage_DATA)'; test -n "$(toolexeclibgoimagedir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgoimagedir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoimagedir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3659,13 +3708,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgoimage_DATA)'; test -n "$(toolexeclibgoimagedir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgoimagedir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgoimagedir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgoimagedir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgoimagecolorDATA: $(toolexeclibgoimagecolor_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgoimagecolordir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoimagecolordir)"
 	@list='$(toolexeclibgoimagecolor_DATA)'; test -n "$(toolexeclibgoimagecolordir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgoimagecolordir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoimagecolordir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3679,13 +3729,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgoimagecolor_DATA)'; test -n "$(toolexeclibgoimagecolordir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgoimagecolordir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgoimagecolordir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgoimagecolordir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgoindexDATA: $(toolexeclibgoindex_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgoindexdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoindexdir)"
 	@list='$(toolexeclibgoindex_DATA)'; test -n "$(toolexeclibgoindexdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgoindexdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoindexdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3699,13 +3750,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgoindex_DATA)'; test -n "$(toolexeclibgoindexdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgoindexdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgoindexdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgoindexdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgoioDATA: $(toolexeclibgoio_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgoiodir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoiodir)"
 	@list='$(toolexeclibgoio_DATA)'; test -n "$(toolexeclibgoiodir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgoiodir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoiodir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3719,13 +3771,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgoio_DATA)'; test -n "$(toolexeclibgoiodir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgoiodir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgoiodir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgoiodir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgologDATA: $(toolexeclibgolog_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgologdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgologdir)"
 	@list='$(toolexeclibgolog_DATA)'; test -n "$(toolexeclibgologdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgologdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgologdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3739,13 +3792,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgolog_DATA)'; test -n "$(toolexeclibgologdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgologdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgologdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgologdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgomathDATA: $(toolexeclibgomath_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgomathdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgomathdir)"
 	@list='$(toolexeclibgomath_DATA)'; test -n "$(toolexeclibgomathdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgomathdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgomathdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3759,13 +3813,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgomath_DATA)'; test -n "$(toolexeclibgomathdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgomathdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgomathdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgomathdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgomimeDATA: $(toolexeclibgomime_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgomimedir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgomimedir)"
 	@list='$(toolexeclibgomime_DATA)'; test -n "$(toolexeclibgomimedir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgomimedir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgomimedir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3779,13 +3834,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgomime_DATA)'; test -n "$(toolexeclibgomimedir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgomimedir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgomimedir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgomimedir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgonetDATA: $(toolexeclibgonet_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgonetdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgonetdir)"
 	@list='$(toolexeclibgonet_DATA)'; test -n "$(toolexeclibgonetdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgonetdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgonetdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3799,13 +3855,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgonet_DATA)'; test -n "$(toolexeclibgonetdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgonetdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgonetdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgonetdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgonethttpDATA: $(toolexeclibgonethttp_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgonethttpdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgonethttpdir)"
 	@list='$(toolexeclibgonethttp_DATA)'; test -n "$(toolexeclibgonethttpdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgonethttpdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgonethttpdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3819,13 +3876,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgonethttp_DATA)'; test -n "$(toolexeclibgonethttpdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgonethttpdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgonethttpdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgonethttpdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgonetrpcDATA: $(toolexeclibgonetrpc_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgonetrpcdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgonetrpcdir)"
 	@list='$(toolexeclibgonetrpc_DATA)'; test -n "$(toolexeclibgonetrpcdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgonetrpcdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgonetrpcdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3839,13 +3897,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgonetrpc_DATA)'; test -n "$(toolexeclibgonetrpcdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgonetrpcdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgonetrpcdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgonetrpcdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgooldDATA: $(toolexeclibgoold_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgoolddir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoolddir)"
 	@list='$(toolexeclibgoold_DATA)'; test -n "$(toolexeclibgoolddir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgoolddir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoolddir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3859,13 +3918,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgoold_DATA)'; test -n "$(toolexeclibgoolddir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgoolddir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgoolddir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgoolddir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgoosDATA: $(toolexeclibgoos_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgoosdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoosdir)"
 	@list='$(toolexeclibgoos_DATA)'; test -n "$(toolexeclibgoosdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgoosdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoosdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3879,13 +3939,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgoos_DATA)'; test -n "$(toolexeclibgoosdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgoosdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgoosdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgoosdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgopathDATA: $(toolexeclibgopath_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgopathdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgopathdir)"
 	@list='$(toolexeclibgopath_DATA)'; test -n "$(toolexeclibgopathdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgopathdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgopathdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3899,13 +3960,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgopath_DATA)'; test -n "$(toolexeclibgopathdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgopathdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgopathdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgopathdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgoregexpDATA: $(toolexeclibgoregexp_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgoregexpdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoregexpdir)"
 	@list='$(toolexeclibgoregexp_DATA)'; test -n "$(toolexeclibgoregexpdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgoregexpdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoregexpdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3919,13 +3981,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgoregexp_DATA)'; test -n "$(toolexeclibgoregexpdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgoregexpdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgoregexpdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgoregexpdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgoruntimeDATA: $(toolexeclibgoruntime_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgoruntimedir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoruntimedir)"
 	@list='$(toolexeclibgoruntime_DATA)'; test -n "$(toolexeclibgoruntimedir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgoruntimedir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgoruntimedir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3939,13 +4002,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgoruntime_DATA)'; test -n "$(toolexeclibgoruntimedir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgoruntimedir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgoruntimedir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgoruntimedir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgosyncDATA: $(toolexeclibgosync_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgosyncdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgosyncdir)"
 	@list='$(toolexeclibgosync_DATA)'; test -n "$(toolexeclibgosyncdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgosyncdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgosyncdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3959,13 +4023,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgosync_DATA)'; test -n "$(toolexeclibgosyncdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgosyncdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgosyncdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgosyncdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgotestingDATA: $(toolexeclibgotesting_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgotestingdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgotestingdir)"
 	@list='$(toolexeclibgotesting_DATA)'; test -n "$(toolexeclibgotestingdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgotestingdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgotestingdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3979,13 +4044,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgotesting_DATA)'; test -n "$(toolexeclibgotestingdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgotestingdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgotestingdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgotestingdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgotextDATA: $(toolexeclibgotext_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgotextdir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgotextdir)"
 	@list='$(toolexeclibgotext_DATA)'; test -n "$(toolexeclibgotextdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgotextdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgotextdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -3999,13 +4065,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgotext_DATA)'; test -n "$(toolexeclibgotextdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgotextdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgotextdir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgotextdir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgotexttemplateDATA: $(toolexeclibgotexttemplate_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgotexttemplatedir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgotexttemplatedir)"
 	@list='$(toolexeclibgotexttemplate_DATA)'; test -n "$(toolexeclibgotexttemplatedir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgotexttemplatedir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgotexttemplatedir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -4019,13 +4086,14 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgotexttemplate_DATA)'; test -n "$(toolexeclibgotexttemplatedir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgotexttemplatedir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgotexttemplatedir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgotexttemplatedir)'; $(am__uninstall_files_from_dir)
 install-toolexeclibgounicodeDATA: $(toolexeclibgounicode_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(toolexeclibgounicodedir)" || $(MKDIR_P) "$(DESTDIR)$(toolexeclibgounicodedir)"
 	@list='$(toolexeclibgounicode_DATA)'; test -n "$(toolexeclibgounicodedir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(toolexeclibgounicodedir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(toolexeclibgounicodedir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -4039,9 +4107,7 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(toolexeclibgounicode_DATA)'; test -n "$(toolexeclibgounicodedir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(toolexeclibgounicodedir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(toolexeclibgounicodedir)" && rm -f $$files
+	dir='$(DESTDIR)$(toolexeclibgounicodedir)'; $(am__uninstall_files_from_dir)
 
 # This directory's subdirectories are mostly independent; you can cd
 # into them and run `make' without going through this Makefile.
@@ -4196,10 +4262,15 @@
 
 installcheck: installcheck-recursive
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:
Index: libgo/runtime/mgc0.c
===================================================================
--- libgo/runtime/mgc0.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgo/runtime/mgc0.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -2280,7 +2280,7 @@
 	heap0 = mstats.next_gc*100/(gcpercent+100);
 	// conservatively set next_gc to high value assuming that everything is live
 	// concurrent/lazy sweep will reduce this number while discovering new garbage
-	mstats.next_gc = mstats.heap_alloc+mstats.heap_alloc*gcpercent/100;
+	mstats.next_gc = mstats.heap_alloc+(mstats.heap_alloc-runtime_stacks_sys)*gcpercent/100;
 
 	t4 = runtime_nanotime();
 	mstats.last_gc = runtime_unixnanotime();  // must be Unix time to make sense to user
Index: libgo/mksysinfo.sh
===================================================================
--- libgo/mksysinfo.sh	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgo/mksysinfo.sh	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -201,6 +201,67 @@
 #ifdef TCSETS
   TCSETS_val = TCSETS,
 #endif
+#ifdef TUNSETIFF
+  TUNSETIFF_val = TUNSETIFF,
+#endif
+#ifdef TUNSETNOCSUM
+  TUNSETNOCSUM_val = TUNSETNOCSUM,
+#endif
+#ifdef TUNSETDEBUG
+  TUNSETDEBUG_val = TUNSETDEBUG,
+#endif
+#ifdef TUNSETPERSIST
+  TUNSETPERSIST_val = TUNSETPERSIST,
+#endif
+#ifdef TUNSETOWNER
+  TUNSETOWNER_val = TUNSETOWNER,
+#endif
+#ifdef TUNSETLINK
+  TUNSETLINK_val = TUNSETLINK,
+#endif
+#ifdef TUNSETGROUP
+  TUNSETGROUP_val = TUNSETGROUP,
+#endif
+#ifdef TUNGETFEATURES
+  TUNGETFEATURES_val = TUNGETFEATURES,
+#endif
+#ifdef TUNSETOFFLOAD
+  TUNSETOFFLOAD_val = TUNSETOFFLOAD,
+#endif
+#ifdef TUNSETTXFILTER
+  TUNSETTXFILTER_val = TUNSETTXFILTER,
+#endif
+#ifdef TUNGETIFF
+  TUNGETIFF_val = TUNGETIFF,
+#endif
+#ifdef TUNGETSNDBUF
+  TUNGETSNDBUF_val = TUNGETSNDBUF,
+#endif
+#ifdef TUNSETSNDBUF
+  TUNSETSNDBUF_val = TUNSETSNDBUF,
+#endif
+#ifdef TUNATTACHFILTER
+  TUNATTACHFILTER_val = TUNATTACHFILTER,
+#endif
+#ifdef TUNDETACHFILTER
+  TUNDETACHFILTER_val = TUNDETACHFILTER,
+#endif
+#ifdef TUNGETVNETHDRSZ
+  TUNGETVNETHDRSZ_val = TUNGETVNETHDRSZ,
+#endif
+#ifdef TUNSETVNETHDRSZ
+  TUNSETVNETHDRSZ_val = TUNSETVNETHDRSZ,
+#endif
+#ifdef TUNSETQUEUE
+  TUNSETQUEUE_val = TUNSETQUEUE,
+#endif
+#ifdef TUNSETIFINDEX
+  TUNSETIFINDEX_val = TUNSETIFINDEX,
+#endif
+#ifdef TUNGETFILTER
+  TUNGETFILTER_val = TUNGETFILTER,
+#endif
+
 };
 EOF
 
@@ -830,6 +891,9 @@
 grep '^const _TIOC' gen-sysinfo.go | \
     grep -v '_val =' | \
     sed -e 's/^\(const \)_\(TIOC[^= ]*\)\(.*\)$/\1\2 = _\2/' >> ${OUT}
+grep '^const _TUNSET' gen-sysinfo.go | \
+    grep -v '_val =' | \
+    sed -e 's/^\(const \)_\(TUNSET[^= ]*\)\(.*\)$/\1\2 = _\2/' >> ${OUT}
 # We need TIOCGWINSZ.
 if ! grep '^const TIOCGWINSZ' ${OUT} >/dev/null 2>&1; then
   if grep '^const _TIOCGWINSZ_val' ${OUT} >/dev/null 2>&1; then
@@ -872,6 +936,129 @@
   fi
 fi
 
+if ! grep '^const TUNSETNOCSUM' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNSETNOCSUM_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNSETNOCSUM = _TUNSETNOCSUM_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNSETDEBUG' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNSETDEBUG_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNSETDEBUG = _TUNSETDEBUG_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNSETIFF' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNSETIFF_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNSETIFF = _TUNSETIFF_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNSETPERSIST' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNSETPERSIST_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNSETPERSIST = _TUNSETPERSIST_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNSETOWNER' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNSETOWNER_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNSETOWNER = _TUNSETOWNER_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNSETLINK' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNSETLINK_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNSETLINK = _TUNSETLINK_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNSETGROUP' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNSETGROUP_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNSETGROUP = _TUNSETGROUP_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNGETFEATURES' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNGETFEATURES_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNGETFEATURES = _TUNGETFEATURES_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNSETOFFLOAD' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNSETOFFLOAD_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNSETOFFLOAD = _TUNSETOFFLOAD_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNSETTXFILTER' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNSETTXFILTER_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNSETTXFILTER = _TUNSETTXFILTER_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNGETIFF' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNGETIFF_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNGETIFF = _TUNGETIFF_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNGETSNDBUF' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNGETSNDBUF_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNGETSNDBUF = _TUNGETSNDBUF_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNSETSNDBUF' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNSETSNDBUF_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNSETSNDBUF = _TUNSETSNDBUF_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNATTACHFILTER' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNATTACHFILTER_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNATTACHFILTER = _TUNATTACHFILTER_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNDETACHFILTER' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNDETACHFILTER_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNDETACHFILTER = _TUNDETACHFILTER_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNGETVNETHDRSZ' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNGETVNETHDRSZ_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNGETVNETHDRSZ = _TUNGETVNETHDRSZ_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNSETVNETHDRSZ' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNSETVNETHDRSZ_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNSETVNETHDRSZ = _TUNSETVNETHDRSZ_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNSETQUEUE' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNSETQUEUE_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNSETQUEUE = _TUNSETQUEUE_val' >> ${OUT}
+  fi
+fi
+
+
+if ! grep '^const TUNSETIFINDEX' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNSETIFINDEX_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNSETIFINDEX = _TUNSETIFINDEX_val' >> ${OUT}
+  fi
+fi
+
+if ! grep '^const TUNGETFILTER' ${OUT} >/dev/null 2>&1; then
+  if grep '^const _TUNGETFILTER_val' ${OUT} >/dev/null 2>&1; then
+    echo 'const TUNGETFILTER = _TUNGETFILTER_val' >> ${OUT}
+  fi
+fi
+
+
+
 # The ioctl flags for terminal control
 grep '^const _TC[GS]ET' gen-sysinfo.go | grep -v _val | \
     sed -e 's/^\(const \)_\(TC[GS]ET[^= ]*\)\(.*\)$/\1\2 = _\2/' >> ${OUT}
Index: libgo/configure.ac
===================================================================
--- libgo/configure.ac	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgo/configure.ac	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -695,6 +695,12 @@
 STRUCT_EPOLL_EVENT_FD_OFFSET=${libgo_cv_c_epoll_event_fd_offset}
 AC_SUBST(STRUCT_EPOLL_EVENT_FD_OFFSET)
 
+dnl Check if <sys/stat.h> uses timespec_t for st_?tim members.  Introduced
+dnl in Solaris 12 for XPG7 compatibility.
+AC_EGREP_HEADER([timespec_t.*st_atim], [sys/stat.h],
+		[have_stat_timespec=yes], [have_stat_timespec=no])
+AM_CONDITIONAL(HAVE_STAT_TIMESPEC, test $have_stat_timespec = yes)
+
 dnl See if struct exception is defined in <math.h>.
 AC_CHECK_TYPE([struct exception],
 [libgo_has_struct_exception=yes],
Index: libgo/go/syscall/socket_linux_ppc64x_type.go
===================================================================
--- libgo/go/syscall/socket_linux_ppc64x_type.go	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libgo/go/syscall/socket_linux_ppc64x_type.go	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,14 @@
+// socket_linux_ppc64x_type.go -- Socket handling specific to ppc64 GNU/Linux.
+
+// Copyright 2015 The Go Authors. All rights reserved.
+// Use of this source code is governed by a BSD-style
+// license that can be found in the LICENSE file.
+
+package syscall
+
+// Type needed on ppc64le & ppc64
+
+type RawSockaddr struct {
+	Family uint16
+	Data   [14]uint8
+}
Index: libgo/go/syscall/socket_linux_type.go
===================================================================
--- libgo/go/syscall/socket_linux_type.go	(.../tags/gcc_5_2_0_release)	(nonexistent)
+++ libgo/go/syscall/socket_linux_type.go	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -0,0 +1,14 @@
+// socket_linux_type.go -- Socket handling specific to GNU/Linux.
+
+// Copyright 2015 The Go Authors. All rights reserved.
+// Use of this source code is governed by a BSD-style
+// license that can be found in the LICENSE file.
+
+package syscall
+
+// Type needed if not on ppc64le or ppc64
+
+type RawSockaddr struct {
+	Family uint16
+	Data   [14]int8
+}
Index: libgo/go/syscall/socket_linux.go
===================================================================
--- libgo/go/syscall/socket_linux.go	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgo/go/syscall/socket_linux.go	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -136,11 +136,6 @@
 	Groups uint32
 }
 
-type RawSockaddr struct {
-	Family uint16
-	Data   [14]int8
-}
-
 // BindToDevice binds the socket associated with fd to device.
 func BindToDevice(fd int, device string) (err error) {
 	return SetsockoptString(fd, SOL_SOCKET, SO_BINDTODEVICE, device)
Index: libgo/Makefile.am
===================================================================
--- libgo/Makefile.am	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgo/Makefile.am	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -880,7 +880,11 @@
 endif
 
 if LIBGO_IS_SOLARIS
+if HAVE_STAT_TIMESPEC
+go_os_stat_file = go/os/stat_atim.go
+else
 go_os_stat_file = go/os/stat_solaris.go
+endif
 else
 if LIBGO_IS_LINUX
 go_os_stat_file = go/os/stat_atim.go
@@ -1676,7 +1680,17 @@
 # Define socket sizes and types.
 if LIBGO_IS_LINUX
 syscall_socket_file = go/syscall/socket_linux.go epoll.go
+if LIBGO_IS_PPC64LE
+syscall_socket_type_file = go/syscall/socket_linux_ppc64x_type.go
 else
+if LIBGO_IS_PPC64
+syscall_socket_type_file = go/syscall/socket_linux_ppc64x_type.go
+else
+syscall_socket_type_file = go/syscall/socket_linux_type.go
+endif
+endif
+else
+syscall_socket_type_file =
 if LIBGO_IS_SOLARIS
 syscall_socket_file = go/syscall/socket_solaris.go
 else
@@ -1762,6 +1776,7 @@
 	$(syscall_size_file) \
 	$(syscall_socket_file) \
 	$(syscall_socket_os_file) \
+	$(syscall_socket_type_file) \
 	$(syscall_uname_file) \
 	$(syscall_netlink_file) \
 	$(syscall_lsf_file) \
Index: libgo/aclocal.m4
===================================================================
--- libgo/aclocal.m4	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgo/aclocal.m4	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,7 +1,8 @@
-# generated automatically by aclocal 1.11.1 -*- Autoconf -*-
+# generated automatically by aclocal 1.11.6 -*- Autoconf -*-
 
 # Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-# 2005, 2006, 2007, 2008, 2009  Free Software Foundation, Inc.
+# 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation,
+# Inc.
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -19,12 +20,15 @@
 If you have problems, you may need to regenerate the build system entirely.
 To do so, use the procedure documented by the package, typically `autoreconf'.])])
 
-# Copyright (C) 2002, 2003, 2005, 2006, 2007, 2008  Free Software Foundation, Inc.
+# Copyright (C) 2002, 2003, 2005, 2006, 2007, 2008, 2011 Free Software
+# Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # AM_AUTOMAKE_VERSION(VERSION)
 # ----------------------------
 # Automake X.Y traces this macro to ensure aclocal.m4 has been
@@ -34,7 +38,7 @@
 [am__api_version='1.11'
 dnl Some users find AM_AUTOMAKE_VERSION and mistake it for a way to
 dnl require some minimum version.  Point them to the right macro.
-m4_if([$1], [1.11.1], [],
+m4_if([$1], [1.11.6], [],
       [AC_FATAL([Do not call $0, use AM_INIT_AUTOMAKE([$1]).])])dnl
 ])
 
@@ -50,7 +54,7 @@
 # Call AM_AUTOMAKE_VERSION and AM_AUTOMAKE_VERSION so they can be traced.
 # This function is AC_REQUIREd by AM_INIT_AUTOMAKE.
 AC_DEFUN([AM_SET_CURRENT_AUTOMAKE_VERSION],
-[AM_AUTOMAKE_VERSION([1.11.1])dnl
+[AM_AUTOMAKE_VERSION([1.11.6])dnl
 m4_ifndef([AC_AUTOCONF_VERSION],
   [m4_copy([m4_PACKAGE_VERSION], [AC_AUTOCONF_VERSION])])dnl
 _AM_AUTOCONF_VERSION(m4_defn([AC_AUTOCONF_VERSION]))])
@@ -57,12 +61,14 @@
 
 # AM_AUX_DIR_EXPAND                                         -*- Autoconf -*-
 
-# Copyright (C) 2001, 2003, 2005  Free Software Foundation, Inc.
+# Copyright (C) 2001, 2003, 2005, 2011 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # For projects using AC_CONFIG_AUX_DIR([foo]), Autoconf sets
 # $ac_aux_dir to `$srcdir/foo'.  In other projects, it is set to
 # `$srcdir', `$srcdir/..', or `$srcdir/../..'.
@@ -144,14 +150,14 @@
 Usually this means the macro was only invoked conditionally.]])
 fi])])
 
-# Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2009
-# Free Software Foundation, Inc.
+# Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2009,
+# 2010, 2011 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
-# serial 10
+# serial 12
 
 # There are a few dirty hacks below to avoid letting `AC_PROG_CC' be
 # written in clear, in which case automake, when reading aclocal.m4,
@@ -191,6 +197,7 @@
   # instance it was reported that on HP-UX the gcc test will end up
   # making a dummy file named `D' -- because `-MD' means `put the output
   # in D'.
+  rm -rf conftest.dir
   mkdir conftest.dir
   # Copy depcomp to subdir because otherwise we won't find it if we're
   # using a relative directory.
@@ -255,7 +262,7 @@
 	break
       fi
       ;;
-    msvisualcpp | msvcmsys)
+    msvc7 | msvc7msys | msvisualcpp | msvcmsys)
       # This compiler won't grok `-c -o', but also, the minuso test has
       # not run yet.  These depmodes are late enough in the game, and
       # so weak that their functioning should not be impacted.
@@ -320,10 +327,13 @@
 if test "x$enable_dependency_tracking" != xno; then
   am_depcomp="$ac_aux_dir/depcomp"
   AMDEPBACKSLASH='\'
+  am__nodep='_no'
 fi
 AM_CONDITIONAL([AMDEP], [test "x$enable_dependency_tracking" != xno])
 AC_SUBST([AMDEPBACKSLASH])dnl
 _AM_SUBST_NOTMAKE([AMDEPBACKSLASH])dnl
+AC_SUBST([am__nodep])dnl
+_AM_SUBST_NOTMAKE([am__nodep])dnl
 ])
 
 # Generate code to set up dependency tracking.              -*- Autoconf -*-
@@ -545,12 +555,15 @@
 done
 echo "timestamp for $_am_arg" >`AS_DIRNAME(["$_am_arg"])`/stamp-h[]$_am_stamp_count])
 
-# Copyright (C) 2001, 2003, 2005, 2008  Free Software Foundation, Inc.
+# Copyright (C) 2001, 2003, 2005, 2008, 2011 Free Software Foundation,
+# Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # AM_PROG_INSTALL_SH
 # ------------------
 # Define $install_sh.
@@ -569,8 +582,8 @@
 # Add --enable-maintainer-mode option to configure.         -*- Autoconf -*-
 # From Jim Meyering
 
-# Copyright (C) 1996, 1998, 2000, 2001, 2002, 2003, 2004, 2005, 2008
-# Free Software Foundation, Inc.
+# Copyright (C) 1996, 1998, 2000, 2001, 2002, 2003, 2004, 2005, 2008,
+# 2011 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -590,7 +603,7 @@
        [disable], [m4_define([am_maintainer_other], [enable])],
        [m4_define([am_maintainer_other], [enable])
         m4_warn([syntax], [unexpected argument to AM@&t@_MAINTAINER_MODE: $1])])
-AC_MSG_CHECKING([whether to am_maintainer_other maintainer-specific portions of Makefiles])
+AC_MSG_CHECKING([whether to enable maintainer-specific portions of Makefiles])
   dnl maintainer-mode's default is 'disable' unless 'enable' is passed
   AC_ARG_ENABLE([maintainer-mode],
 [  --][am_maintainer_other][-maintainer-mode  am_maintainer_other make rules and dependencies not useful
@@ -701,12 +714,15 @@
 fi
 ])
 
-# Copyright (C) 2003, 2004, 2005, 2006  Free Software Foundation, Inc.
+# Copyright (C) 2003, 2004, 2005, 2006, 2011 Free Software Foundation,
+# Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # AM_PROG_MKDIR_P
 # ---------------
 # Check for `mkdir -p'.
@@ -729,13 +745,14 @@
 
 # Helper functions for option handling.                     -*- Autoconf -*-
 
-# Copyright (C) 2001, 2002, 2003, 2005, 2008  Free Software Foundation, Inc.
+# Copyright (C) 2001, 2002, 2003, 2005, 2008, 2010 Free Software
+# Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
-# serial 4
+# serial 5
 
 # _AM_MANGLE_OPTION(NAME)
 # -----------------------
@@ -743,13 +760,13 @@
 [[_AM_OPTION_]m4_bpatsubst($1, [[^a-zA-Z0-9_]], [_])])
 
 # _AM_SET_OPTION(NAME)
-# ------------------------------
+# --------------------
 # Set option NAME.  Presently that only means defining a flag for this option.
 AC_DEFUN([_AM_SET_OPTION],
 [m4_define(_AM_MANGLE_OPTION([$1]), 1)])
 
 # _AM_SET_OPTIONS(OPTIONS)
-# ----------------------------------
+# ------------------------
 # OPTIONS is a space-separated list of Automake options.
 AC_DEFUN([_AM_SET_OPTIONS],
 [m4_foreach_w([_AM_Option], [$1], [_AM_SET_OPTION(_AM_Option)])])
@@ -825,12 +842,14 @@
 fi
 AC_MSG_RESULT(yes)])
 
-# Copyright (C) 2001, 2003, 2005  Free Software Foundation, Inc.
+# Copyright (C) 2001, 2003, 2005, 2011 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # AM_PROG_INSTALL_STRIP
 # ---------------------
 # One issue with vendor `install' (even GNU) is that you can't
@@ -853,13 +872,13 @@
 INSTALL_STRIP_PROGRAM="\$(install_sh) -c -s"
 AC_SUBST([INSTALL_STRIP_PROGRAM])])
 
-# Copyright (C) 2006, 2008  Free Software Foundation, Inc.
+# Copyright (C) 2006, 2008, 2010 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
-# serial 2
+# serial 3
 
 # _AM_SUBST_NOTMAKE(VARIABLE)
 # ---------------------------
@@ -868,13 +887,13 @@
 AC_DEFUN([_AM_SUBST_NOTMAKE])
 
 # AM_SUBST_NOTMAKE(VARIABLE)
-# ---------------------------
+# --------------------------
 # Public sister of _AM_SUBST_NOTMAKE.
 AC_DEFUN([AM_SUBST_NOTMAKE], [_AM_SUBST_NOTMAKE($@)])
 
 # Check how to create a tarball.                            -*- Autoconf -*-
 
-# Copyright (C) 2004, 2005  Free Software Foundation, Inc.
+# Copyright (C) 2004, 2005, 2012 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -896,10 +915,11 @@
 # a tarball read from stdin.
 #     $(am__untar) < result.tar
 AC_DEFUN([_AM_PROG_TAR],
-[# Always define AMTAR for backward compatibility.
-AM_MISSING_PROG([AMTAR], [tar])
+[# Always define AMTAR for backward compatibility.  Yes, it's still used
+# in the wild :-(  We should find a proper way to deprecate it ...
+AC_SUBST([AMTAR], ['$${TAR-tar}'])
 m4_if([$1], [v7],
-     [am__tar='${AMTAR} chof - "$$tardir"'; am__untar='${AMTAR} xf -'],
+     [am__tar='$${TAR-tar} chof - "$$tardir"' am__untar='$${TAR-tar} xf -'],
      [m4_case([$1], [ustar],, [pax],,
               [m4_fatal([Unknown tar format])])
 AC_MSG_CHECKING([how to create a $1 tar archive])
Index: libgfortran/configure
===================================================================
--- libgfortran/configure	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgfortran/configure	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -16525,6 +16525,15 @@
 $as_echo "#define HAVE_STRTOLD 1" >>confdefs.h
 
    fi
+
+  # ARM, AArch64 and SH also provide ftruncate.
+  case "${host}" in
+     arm* | aarch64* | sh*)
+
+$as_echo "#define HAVE_FTRUNCATE 1" >>confdefs.h
+
+       ;;
+  esac
 else
 
 
Index: libgfortran/runtime/error.c
===================================================================
--- libgfortran/runtime/error.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgfortran/runtime/error.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -221,8 +221,16 @@
 #ifdef HAVE_STRERROR_L
   locale_t myloc = newlocale (LC_CTYPE_MASK | LC_MESSAGES_MASK, "",
 			      (locale_t) 0);
-  char *p = strerror_l (errnum, myloc);
-  freelocale (myloc);
+  char *p;
+  if (myloc)
+    {
+      p = strerror_l (errnum, myloc);
+      freelocale (myloc);
+    }
+  else
+    /* newlocale might fail e.g. due to running out of memory, fall
+       back to the simpler strerror.  */
+    p = strerror (errnum);
   return p;
 #elif defined(HAVE_STRERROR_R)
 #ifdef HAVE_USELOCALE
Index: libgfortran/configure.ac
===================================================================
--- libgfortran/configure.ac	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgfortran/configure.ac	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -295,6 +295,13 @@
    if test x"long_double_math_on_this_cpu" = x"yes"; then
      AC_DEFINE(HAVE_STRTOLD, 1, [Define if you have strtold.])
    fi
+
+  # ARM, AArch64 and SH also provide ftruncate.
+  case "${host}" in
+     arm* | aarch64* | sh*)
+       AC_DEFINE(HAVE_FTRUNCATE, 1, [Define if you have ftruncate.])
+       ;;
+  esac
 else
    AC_CHECK_FUNCS_ONCE(getrusage times mkstemp strtof strtold snprintf \
    ftruncate chsize chdir getlogin gethostname kill link symlink sleep ttyname \
Index: libgfortran/ChangeLog
===================================================================
--- libgfortran/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgfortran/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,25 @@
+2015-09-02  Janne Blomqvist  <jb@gcc.gnu.org>
+
+	PR libfortran/67414
+	* runtime/error.c (gf_strerror): Handle newlocale() failure.
+
+2015-08-28  James Greenhalgh  <james.greenhalgh@arm.com>
+
+	* configure.ac: Define HAVE_FTRUNCATE for ARM/AArch64/SH newlib
+	builds.
+	* configure: Regenerate.
+
+2015-08-18  Francois-Xavier Coudert  <fxcoudert@gcc.gnu.org>
+
+	PR libfortran/66936
+	* io/unix.c (__MINGW32__): Undefine HAVE_UMASK.
+
+2015-07-29  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR libgfortran/66650
+	* libgfortran.h (GFC_DTYPE_SIZE_MASK): Rewrite to avoid
+	"left shift of negative value" warning.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: libgfortran/libgfortran.h
===================================================================
--- libgfortran/libgfortran.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgfortran/libgfortran.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -404,8 +404,7 @@
 
 /* Macros to get both the size and the type with a single masking operation  */
 
-#define GFC_DTYPE_SIZE_MASK \
-  ((~((index_type) 0) >> GFC_DTYPE_SIZE_SHIFT) << GFC_DTYPE_SIZE_SHIFT)
+#define GFC_DTYPE_SIZE_MASK (-((index_type) 1 << GFC_DTYPE_SIZE_SHIFT))
 #define GFC_DTYPE_TYPE_SIZE_MASK (GFC_DTYPE_SIZE_MASK | GFC_DTYPE_TYPE_MASK)
 
 #define GFC_DTYPE_TYPE_SIZE(desc) ((desc)->dtype & GFC_DTYPE_TYPE_SIZE_MASK)
Index: libgfortran/io/unix.c
===================================================================
--- libgfortran/io/unix.c	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libgfortran/io/unix.c	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -101,6 +101,12 @@
 }
 
 #endif /* HAVE_WORKING_STAT */
+
+
+/* On mingw, we don't use umask in tempfile_open(), because it
+   doesn't support the user/group/other-based permissions.  */
+#undef HAVE_UMASK
+
 #endif /* __MINGW32__ */
 
 
Index: libcpp/po/nl.po
===================================================================
--- libcpp/po/nl.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libcpp/po/nl.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,15 +1,18 @@
 # Dutch translations for GNU cpplib.
-# Copyright (C) 2014 Free Software Foundation, Inc.
+# Copyright (C) 2015 Free Software Foundation, Inc.
 # This file is distributed under the same license as the gcc package.
 #
+# "If economists could manage to get themselves thought of as humble,
+# competent people, on a level with dentists, that would be splendid!"
+#
 # Tim Van Holder <tim.van.holder@telenet.be>, 2008, 2009, 2010.
-# Benno Schulenberg <benno@vertaalt.nl>, 2014.
+# Benno Schulenberg <benno@vertaalt.nl>, 2014, 2015.
 msgid ""
 msgstr ""
-"Project-Id-Version: cpplib 4.9-b20140202\n"
+"Project-Id-Version: cpplib 5.2.0\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
 "POT-Creation-Date: 2015-04-13 20:12+0000\n"
-"PO-Revision-Date: 2014-02-03 12:18+0100\n"
+"PO-Revision-Date: 2015-07-23 19:42+0200\n"
 "Last-Translator: Benno Schulenberg <benno@vertaalt.nl>\n"
 "Language-Team: Dutch <vertaling@vrijschrift.org>\n"
 "Language: nl\n"
@@ -33,7 +36,6 @@
 msgid "no iconv implementation, cannot convert from %s to %s"
 msgstr "geen implementatie van iconv beschikbaar; kan niet omzetten van %s naar %s"
 
-# of "tekenset" aangezien character door "teken" vertaald wordt?
 #: charset.c:781
 #, c-format
 msgid "character 0x%lx is not in the basic source character set\n"
@@ -53,10 +55,8 @@
 msgstr "universele tekennamen zijn alleen geldig in C++ en C99"
 
 #: charset.c:1002
-#, fuzzy
-#| msgid "universal character names are only valid in C++ and C99"
 msgid "C99's universal character names are incompatible with C90"
-msgstr "universele tekennamen zijn alleen geldig in C++ en C99"
+msgstr "universele tekennamen van C99 zijn zijn incompatibel met C90"
 
 #: charset.c:1005
 #, c-format
@@ -203,10 +203,8 @@
 msgstr "\"defined\" kan niet als macronaam gebruikt worden"
 
 #: directives.c:573
-#, fuzzy
-#| msgid "\"defined\" cannot be used as a macro name"
 msgid "\"__has_include__\" cannot be used as a macro name"
-msgstr "\"defined\" kan niet als macronaam gebruikt worden"
+msgstr "\"__has_include__\" kan niet als macronaam gebruikt worden"
 
 #: directives.c:579
 #, c-format
@@ -280,7 +278,7 @@
 msgid "\"%s\" after # is not a positive integer"
 msgstr "\"%s\" (na #) is geen positieve integer"
 
-# Shouldn't have been marked as translatable I think
+# FIXME: most likely shouldn't have been marked as translatable
 #: directives.c:1095 directives.c:1097 directives.c:1099 directives.c:1685
 #, c-format
 msgid "%s"
@@ -434,7 +432,7 @@
 msgid "stdout"
 msgstr "standaarduitvoer"
 
-# hoort niet echt een vertaalbare string te zijn :-)
+# FIXME: hoort niet echt een vertaalbare string te zijn :-)
 #: errors.c:233
 #, c-format
 msgid "%s: %s"
@@ -449,14 +447,12 @@
 msgstr "ongeldige prefix \"0b\" voor floating-point constante"
 
 #: expr.c:550
-#, fuzzy
-#| msgid "use of C99 hexadecimal floating constant"
 msgid "use of C++11 hexadecimal floating constant"
-msgstr "gebruik van C99 hexadecimale floating-point constante"
+msgstr "gebruik van een C++11 hexadecimale floating-point constante"
 
 #: expr.c:553
 msgid "use of C99 hexadecimal floating constant"
-msgstr "gebruik van C99 hexadecimale floating-point constante"
+msgstr "gebruik van een C99 hexadecimale floating-point constante"
 
 #: expr.c:597
 #, c-format
@@ -499,16 +495,12 @@
 msgstr "imaginaire constantes zijn een uitbreiding van GCC"
 
 #: expr.c:699
-#, fuzzy
-#| msgid "binary constants are a C++1y feature or GCC extension"
 msgid "binary constants are a C++14 feature or GCC extension"
-msgstr "binaire constantes zijn een C++1y-functie of een uitbreiding van GCC"
+msgstr "binaire constantes zijn een C++14-functie of een uitbreiding van GCC"
 
 #: expr.c:701
-#, fuzzy
-#| msgid "imaginary constants are a GCC extension"
 msgid "binary constants are a GCC extension"
-msgstr "imaginaire constantes zijn een uitbreiding van GCC"
+msgstr "binaire constantes zijn een uitbreiding van GCC"
 
 #: expr.c:796
 msgid "integer constant is too large for its type"
@@ -531,7 +523,6 @@
 msgid "(\"%s\" is an alternative token for \"%s\" in C++)"
 msgstr "(\"%s\" is een alternatieve schrijfwijze voor \"%s\" in C++)"
 
-# betere vertaling voor "portable"?
 #: expr.c:947
 msgid "this use of \"defined\" may not be portable"
 msgstr "dit gebruik van \"define\" is mogelijk niet overdraagbaar"
@@ -603,7 +594,7 @@
 
 #: expr.c:1890
 msgid "comma operator in operand of #if"
-msgstr "comma operator in operand van #if"
+msgstr "komma-operator in operand van '#if'"
 
 #: expr.c:2026
 msgid "division by zero in #if"
@@ -610,16 +601,12 @@
 msgstr "deling door nul in '#if'"
 
 #: expr.c:2123
-#, fuzzy
-#| msgid "operator \"defined\" requires an identifier"
 msgid "operator \"__has_include__\" requires a header string"
-msgstr "de \"defined\" operator vereist een naam als argument"
+msgstr "de \"__has_include__\" operator vereist een headerstring"
 
 #: expr.c:2139
-#, fuzzy
-#| msgid "missing ')' after \"defined\""
 msgid "missing ')' after \"__has_include__\""
-msgstr "')' ontbreekt na \"defined\""
+msgstr "')' ontbreekt na \"__has_include__\""
 
 #: files.c:513
 msgid "NULL directory in find_file"
@@ -739,10 +726,8 @@
 msgstr "poging tot gebruik van 'vergiftigde' \"%s\""
 
 #: lex.c:1275 lex.c:1364
-#, fuzzy
-#| msgid "__VA_ARGS__ can only appear in the expansion of a C99 variadic macro"
 msgid "__VA_ARGS__ can only appear in the expansion of a C++11 variadic macro"
-msgstr "__VA_ARGS__ mag enkel voorkomen in de expansie van een C99 variadische macro"
+msgstr "__VA_ARGS__ mag enkel voorkomen in de expansie van een C++11 variadische macro"
 
 #: lex.c:1279 lex.c:1368
 msgid "__VA_ARGS__ can only appear in the expansion of a C99 variadic macro"
@@ -794,10 +779,8 @@
 msgstr "(dit wordt per invoerbestand maar één keer gemeld)"
 
 #: lex.c:2458
-#, fuzzy
-#| msgid "C++ style comments are not allowed in ISO C90"
 msgid "C++ style comments are incompatible with C90"
-msgstr "commentaar in C++-stijl is niet toegestaan in ISO C90"
+msgstr "commentaar in C++-stijl is incompatibel met C90"
 
 #: lex.c:2489
 msgid "multi-line comment"
@@ -824,7 +807,6 @@
 msgid "macro \"%s\" might prevent reproducible builds"
 msgstr "macro \"%s\" kan reproduceerbare compilaties verhinderen"
 
-# betere vertaling voor 'timestamp'?
 #: macro.c:276
 msgid "could not determine file timestamp"
 msgstr "kan tijdsstempel van bestand niet achterhalen"
@@ -839,23 +821,20 @@
 
 #: macro.c:581
 msgid "invalid string literal, ignoring final '\\'"
-msgstr "ongeldige stringconstante, laatste '\\' wordt genegeerd"
+msgstr "ongeldige stringconstante; laatste '\\' wordt genegeerd"
 
 #: macro.c:643
 #, c-format
 msgid "pasting \"%s\" and \"%s\" does not give a valid preprocessing token"
-msgstr "\"%s\" en \"%s\" aan elkaar plakken levert geen geldig preprocessing token op"
+msgstr "het plakken van \"%s\" en \"%s\" levert geen geldig preprocessing token op"
 
 #: macro.c:767
 msgid "ISO C++11 requires at least one argument for the \"...\" in a variadic macro"
-msgstr ""
+msgstr "ISO C++11 vereist minstens één argument voor de \"...\" in een variadische macro"
 
-# "rest arguments"?
 #: macro.c:771
-#, fuzzy
-#| msgid "ISO C99 requires rest arguments to be used"
 msgid "ISO C99 requires at least one argument for the \"...\" in a variadic macro"
-msgstr "ISO C99 verplicht het gebruik van restargumenten"
+msgstr "ISO C99 vereist minstens één argument voor de \"...\" in een variadische macro"
 
 #: macro.c:778
 #, c-format
@@ -878,16 +857,14 @@
 msgstr "functie-achtige macro \"%s\" moet in traditioneel C altijd met argumenten gebruikt worden"
 
 #: macro.c:1814
-#, fuzzy, c-format
-#| msgid "invoking macro %s argument %d: empty macro arguments are undefined in ISO C90 and ISO C++98"
+#, c-format
 msgid "invoking macro %s argument %d: empty macro arguments are undefined in ISO C++98"
-msgstr "aanroep van macro %s argument %d: lege macro-argumenten zijn niet gedefinieerd in ISO C90 en ISO C++98"
+msgstr "aanroep van macro %s argument %d: lege macro-argumenten zijn ongedefinieerd in ISO C++98"
 
 #: macro.c:1822 macro.c:1831
-#, fuzzy, c-format
-#| msgid "invoking macro %s argument %d: empty macro arguments are undefined in ISO C90 and ISO C++98"
+#, c-format
 msgid "invoking macro %s argument %d: empty macro arguments are undefined in ISO C90"
-msgstr "aanroep van macro %s argument %d: lege macro-argumenten zijn niet gedefinieerd in ISO C90 en ISO C++98"
+msgstr "aanroep van macro %s argument %d: lege macro-argumenten zijn ongedefinieerd in ISO C90"
 
 #: macro.c:2800
 #, c-format
@@ -908,26 +885,22 @@
 msgstr "parameternaam ontbreekt"
 
 #: macro.c:2896
-#, fuzzy
-#| msgid "anonymous variadic macros were introduced in C99"
 msgid "anonymous variadic macros were introduced in C++11"
-msgstr "anonieme variadische macro's werden door C99 ingevoerd"
+msgstr "anonieme variadische macro's werden geïntroduceerd in C++11"
 
 #: macro.c:2900 macro.c:2905
 msgid "anonymous variadic macros were introduced in C99"
-msgstr "anonieme variadische macro's werden door C99 ingevoerd"
+msgstr "anonieme variadische macro's werden geïntroduceerd in C99"
 
 # variadic? " met variabele argumentenlijst" is nogal lang...
 #: macro.c:2912
-#, fuzzy
-#| msgid "ISO C does not permit named variadic macros"
 msgid "ISO C++ does not permit named variadic macros"
-msgstr "ISO C staat het gebruik benoemde variadische macro's niet toe"
+msgstr "ISO C++ staat geen benoemde variadische macro's toe"
 
 # variadic? " met variabele argumentenlijst" is nogal lang...
 #: macro.c:2915
 msgid "ISO C does not permit named variadic macros"
-msgstr "ISO C staat het gebruik benoemde variadische macro's niet toe"
+msgstr "ISO C staat geen benoemde variadische macro's toe"
 
 #: macro.c:2925
 msgid "missing ')' in macro parameter list"
@@ -938,10 +911,8 @@
 msgstr "'##' mag niet voorkomen aan het begin of einde van een macro-expansie"
 
 #: macro.c:3013
-#, fuzzy
-#| msgid "ISO C99 requires whitespace after the macro name"
 msgid "ISO C++11 requires whitespace after the macro name"
-msgstr "ISO C99 vereist witruimte na de macronaam"
+msgstr "ISO C++11 vereist witruimte na de macronaam"
 
 #: macro.c:3016
 msgid "ISO C99 requires whitespace after the macro name"
Index: libcpp/po/ChangeLog
===================================================================
--- libcpp/po/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libcpp/po/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,11 @@
+2015-07-31  Joseph Myers  <joseph@codesourcery.com>
+
+	* sv.po: Update.
+
+2015-07-24  Joseph Myers  <joseph@codesourcery.com>
+
+	* nl.po: Update.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: libcpp/po/sv.po
===================================================================
--- libcpp/po/sv.po	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ libcpp/po/sv.po	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -8,10 +8,10 @@
 #
 msgid ""
 msgstr ""
-"Project-Id-Version: cpplib 5.1.0\n"
+"Project-Id-Version: cpplib 5.2.0\n"
 "Report-Msgid-Bugs-To: http://gcc.gnu.org/bugs.html\n"
 "POT-Creation-Date: 2015-04-13 20:12+0000\n"
-"PO-Revision-Date: 2015-05-01 14:05+0200\n"
+"PO-Revision-Date: 2015-07-30 10:21+0200\n"
 "Last-Translator: Göran Uddeborg <goeran@uddeborg.se>\n"
 "Language-Team: Swedish <tp-sv@listor.tp-sv.se>\n"
 "Language: sv\n"
@@ -533,7 +533,7 @@
 
 #: expr.c:1086
 msgid "assertions are a deprecated extension"
-msgstr "försäkringar är en GCC-utvidgning som avrådes ifrån"
+msgstr "försäkringar är en utvidgning som avrådes ifrån"
 
 #: expr.c:1331
 #, c-format
Index: fixincludes/ChangeLog
===================================================================
--- fixincludes/ChangeLog	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ fixincludes/ChangeLog	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,3 +1,16 @@
+2015-08-14  David Edelsohn  <dje.gcc@gmail.com>
+
+	Backport from mainline.
+	2015-08-14  David Edelsohn  <dje.gcc@gmail.com>
+
+	* inclhack.def (aix_stdio_inline): New fix.
+	(aix_strtof_const): Limit to *-*-aix*.
+	(aix_sysmachine): Same.
+	(aix_syswait_2): Same.
+	(aix_volatile): Same.
+	* fixincl.x: Regenerated.
+	* test/base/stdio.h [AIX_STDIO_INLINE]: New test.
+
 2015-07-16  Release Manager
 
 	* GCC 5.2.0 released.
Index: fixincludes/tests/base/stdio.h
===================================================================
--- fixincludes/tests/base/stdio.h	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ fixincludes/tests/base/stdio.h	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -19,6 +19,16 @@
 #endif  /* AAB_AIX_STDIO_CHECK */
 
 
+#if defined( AIX_STDIO_INLINE_CHECK )
+#ifdef __cplusplus
+}
+#endif
+
+#if (defined(__cplusplus) && defined(__IBMCPP__))
+#ifdef ferror
+#endif  /* AIX_STDIO_INLINE_CHECK */
+
+
 #if defined( ALPHA_GETOPT_CHECK )
 extern int getopt(int, char *const[], const char *);
 #endif  /* ALPHA_GETOPT_CHECK */
Index: fixincludes/fixincl.x
===================================================================
--- fixincludes/fixincl.x	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ fixincludes/fixincl.x	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -1,12 +1,12 @@
 /*  -*- buffer-read-only: t -*- vi: set ro:
- * 
- * DO NOT EDIT THIS FILE   (fixincl.x)
- * 
- * It has been AutoGen-ed  May 21, 2015 at 02:48:12 AM by AutoGen 5.18.3
- * From the definitions    inclhack.def
- * and the template file   fixincl
+ *
+ *DO NOT EDIT THIS FILE   (fixincl.x)
+ *
+ *It has been AutoGen-ed  August 13, 2015 at 05:25:50 PM by AutoGen 5.18.3
+ *From the definitions    inclhack.def
+ *and the template file   fixincl
  */
-/* DO NOT SVN-MERGE THIS FILE, EITHER Thu May 21 02:48:12 UTC 2015
+/* DO NOT SVN-MERGE THIS FILE, EITHER Thu Aug 13 17:25:50 UTC 2015
  *
  * You must regenerate it.  Use the ./genfixes script.
  *
@@ -15,7 +15,7 @@
  * certain ANSI-incompatible system header files which are fixed to work
  * correctly with ANSI C and placed in a directory that GNU C will search.
  *
- * This file contains 229 fixup descriptions.
+ * This file contains 230 fixup descriptions.
  *
  * See README for more information.
  *
@@ -1503,6 +1503,50 @@
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * *
  *
+ *  Description of Aix_Stdio_Inline fix
+ */
+tSCC zAix_Stdio_InlineName[] =
+     "aix_stdio_inline";
+
+/*
+ *  File name selection pattern
+ */
+tSCC zAix_Stdio_InlineList[] =
+  "stdio.h\0";
+/*
+ *  Machine/OS name selection pattern
+ */
+tSCC* apzAix_Stdio_InlineMachs[] = {
+        "*-*-aix*",
+        (const char*)NULL };
+
+/*
+ *  content selection pattern - do fix if pattern found
+ */
+tSCC zAix_Stdio_InlineSelect0[] =
+       "#ifdef __cplusplus\\\n\
+}\\\n\
+\\\n\
+#ifdef ferror\\\n";
+
+#define    AIX_STDIO_INLINE_TEST_CT  1
+static tTestDesc aAix_Stdio_InlineTests[] = {
+  { TT_EGREP,    zAix_Stdio_InlineSelect0, (regex_t*)NULL }, };
+
+/*
+ *  Fix Command Arguments for Aix_Stdio_Inline
+ */
+static const char* apzAix_Stdio_InlinePatch[] = {
+    "format",
+    "#ifdef __cplusplus\n\
+}\n\
+#endif\n\n\
+#if (defined(__cplusplus) && defined(__IBMCPP__))\n\
+#ifdef ferror\n",
+    (char*)NULL };
+
+/* * * * * * * * * * * * * * * * * * * * * * * * * *
+ *
  *  Description of Aix_Strtof_Const fix
  */
 tSCC zAix_Strtof_ConstName[] =
@@ -1516,7 +1560,9 @@
 /*
  *  Machine/OS name selection pattern
  */
-#define apzAix_Strtof_ConstMachs (const char**)NULL
+tSCC* apzAix_Strtof_ConstMachs[] = {
+        "*-*-aix*",
+        (const char*)NULL };
 
 /*
  *  content selection pattern - do fix if pattern found
@@ -1551,7 +1597,9 @@
 /*
  *  Machine/OS name selection pattern
  */
-#define apzAix_SysmachineMachs (const char**)NULL
+tSCC* apzAix_SysmachineMachs[] = {
+        "*-*-aix*",
+        (const char*)NULL };
 
 /*
  *  content selection pattern - do fix if pattern found
@@ -1586,7 +1634,9 @@
 /*
  *  Machine/OS name selection pattern
  */
-#define apzAix_Syswait_2Machs (const char**)NULL
+tSCC* apzAix_Syswait_2Machs[] = {
+        "*-*-aix*",
+        (const char*)NULL };
 
 /*
  *  content selection pattern - do fix if pattern found
@@ -1621,7 +1671,9 @@
 /*
  *  Machine/OS name selection pattern
  */
-#define apzAix_VolatileMachs (const char**)NULL
+tSCC* apzAix_VolatileMachs[] = {
+        "*-*-aix*",
+        (const char*)NULL };
 
 /*
  *  content selection pattern - do fix if pattern found
@@ -9396,9 +9448,9 @@
  *
  *  List of all fixes
  */
-#define REGEX_COUNT          266
+#define REGEX_COUNT          267
 #define MACH_LIST_SIZE_LIMIT 187
-#define FIX_COUNT            229
+#define FIX_COUNT            230
 
 /*
  *  Enumerate the fixes
@@ -9435,6 +9487,7 @@
     AIX_STDINT_3_FIXIDX,
     AIX_STDINT_4_FIXIDX,
     AIX_STDINT_5_FIXIDX,
+    AIX_STDIO_INLINE_FIXIDX,
     AIX_STRTOF_CONST_FIXIDX,
     AIX_SYSMACHINE_FIXIDX,
     AIX_SYSWAIT_2_FIXIDX,
@@ -9791,6 +9844,11 @@
      AIX_STDINT_5_TEST_CT, FD_MACH_ONLY | FD_SUBROUTINE,
      aAix_Stdint_5Tests,   apzAix_Stdint_5Patch, 0 },
 
+  {  zAix_Stdio_InlineName,    zAix_Stdio_InlineList,
+     apzAix_Stdio_InlineMachs,
+     AIX_STDIO_INLINE_TEST_CT, FD_MACH_ONLY | FD_SUBROUTINE,
+     aAix_Stdio_InlineTests,   apzAix_Stdio_InlinePatch, 0 },
+
   {  zAix_Strtof_ConstName,    zAix_Strtof_ConstList,
      apzAix_Strtof_ConstMachs,
      AIX_STRTOF_CONST_TEST_CT, FD_MACH_ONLY | FD_SUBROUTINE,
Index: fixincludes/inclhack.def
===================================================================
--- fixincludes/inclhack.def	(.../tags/gcc_5_2_0_release)	(wersja 227896)
+++ fixincludes/inclhack.def	(.../branches/gcc-5-branch)	(wersja 227896)
@@ -892,10 +892,32 @@
 };
 
 /*
+ * stdio.h on AIX defines ferror, clearerr and feof as C++ inline, which
+   produces wrong code with G++.
+ */
+fix = {
+    hackname  = aix_stdio_inline;
+    mach      = "*-*-aix*";
+    files     = stdio.h;
+    select    = "#ifdef __cplusplus\\\n"
+                "}\\\n\\\n"
+                "#ifdef ferror\\\n";
+    c_fix     = format;
+    c_fix_arg = "#ifdef __cplusplus\n"
+                "}\n"
+                "#endif\n\n"
+                "#if (defined(__cplusplus) && defined(__IBMCPP__))\n"
+                "#ifdef ferror\n";
+    test_text = "#ifdef __cplusplus\n}\n\n#ifdef ferror";
+};
+
+
+/*
  * stdlib.h on AIX 4.3 declares strtof() with a non-const first argument.
  */
 fix = {
     hackname  = aix_strtof_const;
+    mach      = "*-*-aix*";
     files     = stdlib.h;
     select    = "((extern[ \t]+)?float[ \t]+strtof)\\(char \\*, char \\*\\*\\);";
     c_fix     = format;
@@ -909,6 +931,7 @@
  */
 fix = {
     hackname  = aix_sysmachine;
+    mach      = "*-*-aix*";
     files     = sys/machine.h;
     select    = "\\\\ +\n";
     c_fix     = format;
@@ -923,6 +946,7 @@
  */
 fix = {
     hackname  = aix_syswait_2;
+    mach      = "*-*-aix*";
     files     = sys/wait.h;
     select    = '\? (\(\(\(\(unsigned[^)]*\)[^)]*\) >> [^)]*\) \& 0xff\) : -1)';
     c_fix     = format;
@@ -939,6 +963,7 @@
  */
 fix = {
     hackname  = aix_volatile;
+    mach      = "*-*-aix*";
     files     = sys/signal.h;
     select    = "typedef volatile int sig_atomic_t";
     c_fix     = format;
